(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[   1078263,      17636]*)
(*NotebookOutlinePosition[   1079527,      17676]*)
(*  CellTagsIndexPosition[   1079483,      17672]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[StyleBox["Chapter 1. Basic Image Handling Tools",
  TextAlignment->Left,
  TextJustification->0,
  FormatType->InputForm,
  FontFamily->"Century",
  FontSize->24,
  FontWeight->"Bold"]], "Title",
  TextAlignment->Left,
  TextJustification->0,
  FormatType->InputForm],

Cell[CellGroupData[{

Cell[TextData[StyleBox["1.1 Introduction",
  FormatType->InputForm,
  FontFamily->"Times New Roman",
  FontWeight->"Bold"]], "Section",
  FormatType->InputForm],

Cell[TextData[{
  StyleBox[
  "\tThis chapter introduces the basic image handling tools for image \
processing by ",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"],
  StyleBox["Mathematica",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox[". ",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"],
  StyleBox["\n\t",
    TextAlignment->Left,
    TextJustification->1],
  StyleBox["The programming language ",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"],
  StyleBox["Mathematica",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox[
  " is composed of the two major frame parts [1]. One is the front-end \
processor, which is an interface between the computer and user. The front-end \
is not only used for the text and code writing for the ",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"],
  StyleBox["Mathematica",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox[
  " notebook but also it displays the computed results. Enormous capability \
is included in the functions of front-end. For further details, click the \
help menu of the ",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"],
  StyleBox["Mathematica",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox[
  " front-end. The other frame part is the kernel, which carries out the \
practical computations including a large number of functions for simple \
computation as well as plotting the figures. The kernel is a computational \
engine of the ",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"],
  StyleBox["Mathematica",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox[
  " when regarding the front-end as a driving cockpit. Both of the front-end \
and kernel require a large memory to use the ",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"],
  StyleBox["Mathematica",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox[" with comfortable environment.",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["1.2 Preparation of ",
    FontFamily->"Times New Roman"],
  StyleBox["Mathematica",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"]
}], "Section"],

Cell[TextData[{
  StyleBox["\tWe never have the machine installed infinitely large number of \
memories, so that it is preferable and essential to use the memory conserve \
command of ",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"],
  StyleBox["Mathematica",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox[". This command works to conserve the memory by interchanging the \
contents of variable when using the same name. Also, we install the warning \
messages suppressing command for the similar variable name. Warning messages \
are sometimes very important and useful for debugging the codes, but in most \
cases, that give a negative impression to user. Further, the default package \
of the ",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"],
  StyleBox["Mathematica",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox[" includes various functions, but it is required to install the \
other standard packages for handling and processing the image data. Thereby, \
in this chapter we install a \[OpenCurlyDoubleQuote]Linear algebra package\
\[CloseCurlyDoubleQuote]. These packages can be installed as follows. We \
write the package input commands and click the right-hand cell by a mouse \
cursor. After that, we push the enter plus shift keys simultaneously. ",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"],
  StyleBox["\n\t",
    TextAlignment->Left,
    TextJustification->1],
  StyleBox["Thus, we have installed the required ",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"],
  StyleBox["Mathematica",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox[" packages for starting a session of this chapter. It must be \
noted here that never push the shift plus enter keys to the cell including \
the just installed packages. When the shift pus enter operation to the \
installed packages is again carried out, you will get an enormous error \
messages punch from the ",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"],
  StyleBox["Mathematica",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox[". ",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell["\<\
<<Utilities`MemoryConserve`
$MemoryIncrement=100000;
Off[General::spell1,MemoryConserve::start,MemoryConserve::end];
<< LinearAlgebra`MatrixManipulation`;\
\>", "Input",
  CellLabel->"In[1]:="]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["1.3 ",
    FormatType->InputForm,
    FontFamily->"Times New Roman",
    FontWeight->"Bold"],
  StyleBox["Image data input",
    FontFamily->"Times New Roman",
    FontWeight->"Bold"]
}], "Section"],

Cell[TextData[{
  StyleBox["\tOne of the major aims of this book is to describe a computer \
graphics methodology, so that we have to insert the image data. Currently, we \
are available a large number of image data formats for the digital computers, \
one of the most popular and primitive image data formats is a 24-bitmap form. \
The 24-bitmap image data consist of the red, green and blue color components. \
Each of the color components has 8 bits dynamic range, and takes the \
numerical values between 0 and 1 The 24-bitmap image data is read in the ",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"],
  StyleBox["Mathematica",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox[" notebook by means of \[OpenCurlyDoubleQuote]MathLink\
\[CloseCurlyDoubleQuote] utility, which connects the ",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"],
  StyleBox["Mathematica",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox[" kernel to the external object package. In this book, we install \
a package called \[OpenCurlyDoubleQuote]RGBsplit.exe\[CloseCurlyDoubleQuote] \
in order to input the 24-bitmap image data. This package was developed by one \
of my students. In order to install the \[OpenCurlyDoubleQuote]RGBsplit.exe\
\[CloseCurlyDoubleQuote], we have to check the existence of \
\[OpenCurlyDoubleQuote]RGBsplit.exe\[CloseCurlyDoubleQuote] in the current \
directly. Typing a following command carries this out and hitting the shift \
plus enter keys simultaneously.",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell[CellGroupData[{

Cell["FileNames[]", "Input",
  CellLabel->"In[5]:="],

Cell[BoxData[
    \({"AF038-100.bmp", "AF038-128.bmp", "AF038-256.bmp", "AF038-64.bmp", 
      "BF001.bmp", "BF001M.bmp", "Chapter 1 Basic Tools.nb", 
      "Chapter 2 Monochrome Image Processing.nb", 
      "Chapter 3 Color Image Processing.nb", 
      "Chapter 4 Wavelet Image Processing.nb", 
      "Chapter 5 Eigen Pattern Image Processing.nb", 
      "Chapter 6 Image Identifications.nb", "imageDB63.m", "imageTST10.m", 
      "Preface.nb", "RGBsplit.exe", "Sor04.exe", 
      "Wall-A-128.bmp"}\)], "Output",
  CellLabel->"Out[5]="]
}, Open  ]],

Cell[TextData[StyleBox[
"\tAs you can see, there is the \[OpenCurlyDoubleQuote]RGBsplit.exe\
\[CloseCurlyDoubleQuote], so we install this object by a following command.",
  FontFamily->"Times New Roman"]], "Text"],

Cell[CellGroupData[{

Cell["link=Install[\"RGBsplit.exe\"]", "Input",
  CellLabel->"In[6]:="],

Cell[BoxData[
    \(LinkObject[".\\RGBsplit.exe", 2, 2]\)], "Output",
  CellLabel->"Out[6]="]
}, Open  ]],

Cell[TextData[{
  StyleBox[" \t",
    FontSize->10,
    FontColor->RGBColor[0, 0, 0.996109]],
  StyleBox[
  "Using this \[OpenCurlyDoubleQuote]RGBsplit.exe\[CloseCurlyDoubleQuote], we \
read in an image file \
\[OpenCurlyDoubleQuote]BF001.bmp\[CloseCurlyDoubleQuote] having 24-bitmap \
format and check up its array size in the ",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"],
  StyleBox["Mathematica",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox[
  " notebook by \[OpenCurlyDoubleQuote]Dimensions\[CloseCurlyDoubleQuote] \
command.",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell[CellGroupData[{

Cell["\<\
sample=RGBsplit[\"BF001.bmp\"];
Dimensions[sample]\
\>", "Input",
  CellLabel->"In[7]:="],

Cell[BoxData[
    \({128, 128, 3}\)], "Output",
  CellLabel->"Out[8]="]
}, Open  ]],

Cell[TextData[{
  StyleBox[
  "\tThe 24-bitmap-image file \[OpenCurlyDoubleQuote]BF001.bmp\
\[CloseCurlyDoubleQuote] has been read in the ",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"],
  StyleBox["Mathematica",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox[
  " notebook as a list named \[OpenCurlyDoubleQuote]sample\
\[CloseCurlyDoubleQuote], which is a three dimensional array of 128 by 128 by \
3 elements. The output of the command \[OpenCurlyDoubleQuote]Dimensions\
\[CloseCurlyDoubleQuote] reveals that the first, second and third figures in \
the wavy parentheses are the number of pixels used for the vertical, \
horizontal axes and color components, respectively. The 1,2 and 3 of the \
color components correspond to the red, green and blue, respectively. ",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"],
  StyleBox["\n\t",
    TextAlignment->Left,
    TextJustification->1],
  StyleBox[
  "Let us draw the red, green and blue components images, independently. The \
following steps carry this out. At first, the numerical values representing \
the red, green and blue components are respectively substituted into \
independent lists \[OpenCurlyDoubleQuote]red\[CloseCurlyDoubleQuote], \
\[OpenCurlyDoubleQuote]green\[CloseCurlyDoubleQuote] and \
\[OpenCurlyDoubleQuote]blue\[CloseCurlyDoubleQuote]. After that, \
\[OpenCurlyDoubleQuote]ListDensityPlot\[CloseCurlyDoubleQuote] command is \
used for drawing the monochrome images.",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell[CellGroupData[{

Cell["\<\
red=Table[sample[[i,j,1]],{i,128},{j,128}];
green=Table[sample[[i,j,2]],{i,128},{j,128}];
blue=Table[sample[[i,j,3]],{i,128},{j,128}];
redG=ListDensityPlot[red,
\tMesh->False,Frame->False,PlotLabel->\"Red\",
\tDisplayFunction->Identity];
greenG=ListDensityPlot[green,
\tMesh->False,Frame->False,PlotLabel->\"Green\",
\tDisplayFunction->Identity];
blueG=ListDensityPlot[blue,
\tMesh->False,Frame->False,PlotLabel->\"blue\",
\tDisplayFunction->Identity];
Show[GraphicsArray[{redG,greenG,blueG}],
\tPlotLabel->\"Fig.1. Color components\",
\tImageSize->{450,150}];\
\>", "Input",
  CellLabel->"In[9]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .3125 
%%ImageSize: 450 150 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.31746 0.00744048 0.31746 [
[.5 .325 -71 0 ]
[.5 .325 71 12.5625 ]
[ 0 0 0 0 ]
[ 1 .3125 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .325 -132 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Fig) show
81.000000 12.812500 moveto
(.1) show
93.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(.) show
105.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Color) show
141.000000 12.812500 moveto
(components) show
201.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
0 0 m
1 0 L
1 .3125 L
0 .3125 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00744048 0.321429 0.30506 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00751202 0.0192308 0.00751202 [
[.5 1.0125 -11 0 ]
[.5 1.0125 11 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Red) show
81.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
128 string
128 128 8 [128 0 0 128 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
E5F2F2F2E5F2E5E5F2E5F2E5E5E5E5E5E5E5E5E5E5F2F2A0
D7E5D7D7D7E5E5D7E5E5E5E5D7D7E5E5E5E5E5E5E5E5E5E5
E5E5E5E5F2F2F2F2F2F2F2E5F2E5E5F2F2E5E5E5E5E5E5E5
E5E5E5E5D7E5E5E5E5E5E5F2F2F2AED7D7E5E5D7D7D7D7D7
D7D7D7D7E5E5E5E5F2F2F2F2F2E5F2E5D7D7BBBBD7D7D7BB
E5D7C8D7E5F2F2E5
E5F2F2E5F2F2F2E5E5F2F2E5E5E5E5E5E5E5E5E5E5E5F2BB
E5E5D7D7D7D7D7D7E5E5E5E5E5E5E5E5E5E5E5E5E5E5E5E5
E5D7E5E5E5E5E5F2E5E5F2E5E5F2E5E5E5E5E5F2E5E5E5E5
E5E5E5E5E5D7D7E5E5E5E5E5F2F2BBC8E5E5E5D7D7D7D7D7
E5E5E5E5E5E5E5E5E5E5E5E5E5F2E5E5D7D7D7D7D7D7D7E5
E5D7D7D7E5F2E5F2
E5E5E5F2E5E5E5F2E5E5F2F2F2E5E5E5E5F2E5E5E5E5F2F2
A0D7E5D7D7D7D7E5E5E5E5E5E5E5D7E5E5E5E5E5E5E5D7D7
D7D7D7E5E5E5E5E5E5E5E5E5E5E5E5E5F2F2E5F2F2E5E5E5
E5E5E5E5E5E5E5E5E5E5E5E5E5E5F2F2A0D7D7D7E5D7D7D7
E5D7D7E5E5E5E5E5E5E5E5E5F2E5E5D7E5D7E5D7D7D7D7D7
E5D7D7D7D7E5F2F2
F2E5F2F2E5F2F2E5F2F2F2E5F2E5E5F2E5E5E5E5E5E5E5F2
E5C8D7D7D7D7D7D7D7D7E5E5E5E5D7D7E5E5E5E5E5E5D7D7
D7D7D7D7D7E5E5E5E5E5E5E5E5E5E5F2F2F2F2F2F2F2E5F2
F2E5E5E5E5E5E5E5E5E5E5E5E5E5E5F2F2C8E5E5E5E5E5E5
E5E5E5E5E5E5E5E5E5E5F2E5E5E5E5E5E5D7E5D7E5D7D7E5
D7D7D7D7E5E5E5F2
E5F2E5F2F2F2F2E5F2F2F2F2F2F2E5F2F2E5F2E5E5E5F2F2
F2C8E5E5D7D7D7D7E5D7D7E5E5E5E5E5E5E5E5E5E5E5E5E5
E5E5E5D7D7D7E5E5E5E5E5E5E5E5E5E5F2E5E5F2F2E5F2F2
F2F2E5E5E5E5E5E5E5E5E5E5E5E5E5E5F2C8D7E5E5E5E5E5
E5E5E5E5E5E5F2E5E5F2F2E5E5E5E5E5E5D7E5E5E5E5E5E5
D7F2D7D7E5F2F2E5
E5F2E5F2E5F2F2F2E5F2F2E5F2F2F2F2F2E5E5F2E5E5E5E5
F2E5E5E5E5D7D7D7D7E5D7E5E5D7D7E5D7D7E5E5D7E5E5E5
E5E5E5E5E5D7D7E5D7E5D7E5E5E5E5E5E5F2F2F2E5E5E5E5
E5F2E5F2E5E5E5E5E5E5E5E5E5E5E5E5E5F2D7D7E5E5E5E5
E5E5E5F2F2F2F2E5F2E5E5E5E5E5E5D7C8D7D7E5F2D7D7D7
E5E5D7D7F2F2F2E5
E5F2F2F2E5F2E5F2F2F2E5F2F2E5F2F2F2F2F2E5E5F2E5F2
F2F2D7E5E5E5D7D7D7D7D7D7D7D7D7C8D7D7D7D7D7E5E5E5
E5E5E5F2E5E5D7E5D7E5D7D7D7E5E5E5E5E5E5E5E5E5E5E5
E5E5E5E5E5E5E5E5E5E5E5E5E5D7E5E5D7E5F2F2D7E5E5E5
E5E5F2F2F2E5F2E5F2E5E5E5E5D7D7C8AED7E5D7E5D7D7E5
D7D7D7E5F2F2F2E5
E5F2F2F2F2F2F2F2E5E5E5E5E5F2F2F2F2F2F2E5F2F2F2F2
E5E5F2E591E5E5E5D7D7D7D7D7C8C8D7D7D7D7D7D7D7E5E5
E5E5E5F2E5E5E5D7D7D7D7D7D7D7D7D7D7D7D7E5D7D7E5D7
E5D7E5D7D7D7E5E5D7D7D7D7D7D7D7E5D7D7D7F2D7D7E5E5
E5E5E5E5F2E5E5F2F2E5E5E5D7D7BBBBAED7D7D7C8D7E5D7
D7D7D7E5F2E5F2E5
E5F2E5F2F2F2E5F2F2F2F2F2E5E5F2F2F2F2E5F2E5F2F2F2
F2F2F2F2F2BBD7E5D7D7D7D7D7D7BBD7D7E5E5E5E5D7E5E5
E5E5E5E5F2E5E5E5E5E5E5E5E5D7D7D7D7C8C8C8C8C8C8C8
C8C8C8C8C8C8C8C8C8C8C8D7D7D7D7D7D7D7D7C8D7D7BBC8
C8D7D7E5E5E5E5E5E5E5E5D7AEBBC8AEC8C8D7D7D7D7D7D7
D7D7D7E5E5F2E5E5
F2F2F2F2F2F2F2F2F2E5F2E5E5F2F2E5E5F2E5F2F2F2F2E5
F2F2F2F2F2E5D7BBD7D7C8D7D7D7BBBBC8D7D7E5E5D7D7E5
E5F2E5F2E5E5E5E5E5E5E5E5E5E5E5E5E5E5E5E5D7D7D7D7
D7D7D7D7D7E5D7E5D7D7E5E5D7E5E5E5D7E5D7D7E5E5D7D7
D74CD7C8D7D7D7D7BBA0A0A0AEC8D7D7C8D7D7D7D7D7C8E5
D7C8E5D7F2F2F2E5
E5E5F2E5F2E5E5F2F2F2E5F2F2F2F2F2F2F2F2F2F2F2E5F2
F2E5F2E5F2F2D7BBC8AEC8D7D7D7D7D7BBD7D7E5E5D7D7E5
E5E5E5E5E5E5E5E5E5E5E5E5E5E5E5E5E5E5E5E5E5E5E5D7
D7E5E5E5E5E5E5E5D7E5E5E5E5E5E5E5E5E5E5E5E5D7E5E5
D7C8D7BB9191BB91A0AEA0A0BBBBD7C8BBE5D7D7C8C8E5E5
D7D7D7E5E5E5E5F2
F2E5F2F2E5F2F2E5F2F2F2F2F2E5F2E5F2F2F2E5F2F2F2F2
E5E5E5E5F2E5D7D7AEBBBBAED7D7D7D7C8D7D7D7E5D7D7E5
E5E5E5E5E5E5E5E5E5E5E5E5E5E5E5E5E5E5E5E5E5E5E5E5
E5D7E5D7E5E5E5E5E5E5E5E5E5E5E5E5D7E5D7E5E5E5E5D7
D7D7D7D7D7BB7676A0A0A0AEAEAEAEAEBBD7BBC8D7C8D7D7
D7E5E5E5E5E5E5F2
E5F2F2E5E5F2F2F2F2F2E5F2F2F2F2F2F2F2F2F2F2F2F2F2
E5E5F2E5E5E5D7D7BBAEBBA076C8D7D7D7D7D7D7E5D7D7E5
E5E5E5E5E5E5E5E5E5E5E5E5E5E5E5E5E5E5E5E5E5E5E5E5
E5E5D7E5E5E5E5D7D7E5E5E5E5E5E5E5E5E5E5E5E5D7D7D7
D7C8BBBBA084A0A084A0AEAEAEAEC8C8C8D7C8C8D7C8D7D7
D7E5E5F2E5F2F2F2
F2F2E5F2F2F2E5F2E5F2E5F2F2F2E5F2F2F2E5F2F2F2E5F2
F2E5E5F2F2E5E5E5D7AEAEA0844CD7C8D7C8C8D7D7D7D7E5
E5E5E5E5E5E5E5E5E5E5E5E5E5E5E5E5E5E5E5E5E5E5E5E5
D7D7D7E5E5E5E5D7E5E5E5D7E5E5E5E5E5D7E5E5E5D7D7C8
C8BBAE8484A0AEAEA0A0A0AEAEC8C8C8D7C8BBC8C8D7D7D7
D7F2E5F2F2F2F2E5
E5F2F2F2E5F2F2F2F2F2F2E5F2E5F2F2F2E5F2E5F2E5F2F2
F2F2F2F2E5F2D7F2D7AEA0A0844C23C8C8C8D7D7D7D7D7D7
E5E5E5E5E5E5E5E5E5E5E5E5E5E5E5E5E5E5E5E5E5E5E5E5
E5E5E5E5E5D7E5D7D7E5E5E5E5E5D7E5E5E5E5D7D7D7C8C8
BBBBA076A0AEA0AEBBAEA0AEC8AEBBBBAEC8D7D7D7E5C8D7
E5E5F2F2E5E5F2F2
F2E5E5F2E5F2E5F2E5F2F2F2F2F2F2F2F2E5F2F2E5F2E5F2
F2F2F2F2F2E5E5E5D7BBA0A0844C2323C8C8D7C8D7D7D7E5
E5E5E5E5E5E5E5E5E5E5E5E5E5E5D7E5E5E5E5E5E5E5D7E5
D7D7E5E5E5E5D7D7D7D7E5E5E5E5E5E5D7C8C8C8BBBBBBBB
A05A4CA0BBAE76AEAEBBC8C8AEAEAEBBC8C8D7D7E5D7D7E5
E5E5E5F2F2E5F2F2
E5F2F2E5F2E5E5F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2
E5E5F2F2F2E5F2D7D7BBA0A0764C3F2308C8D7AED7D7D7E5
E5E5E5E5E5E5E5E5E5E5E5E5E5E5E5D7E5E5D7E5E5E5D7E5
D7D7D7D7D7D7D7D7D7D7E5E5D7E5C8D7D7D7C8C8BBAEA084
4C7676A0AEAEA0BBBBC8BBBBC8AEAEC8C8C8D7D7D7D7D7E5
E5D7E5F2F2E5F2F2
F2E5F2F2F2E5F2F2F2F2E5F2F2F2E5F2E5E5F2F2F2F2F2F2
E5E5F2F2F2E5E5D7E5AEA0A0764C4C3F0800BBC8C8D7D7D7
D7E5E5E5E5E5E5E5E5E5E5E5D7E5E5E5E5D7E5E5E5D7D7E5
D7E5D7C8D7E5D7D7E5D7D7D7D7C8D7C8C8C8C8BBAE847676
5A7691AEAEA0AEBBAEA0A0AEAEC8C8C8C8D7D7D7D7E5E5E5
E5F2F2F2F2F2F2F2
E5F2F2F2F2F2F2F2F2F2F2E5E5F2F2F2F2F2F2E5F2F2F2F2
F2F2F2E5F2F2E5D7D7AEA0A0764C4C3F000000C8C8D7D7D7
D7E5E5E5E5E5E5E5E5E5E5E5E5E5E5D7D7E5E5D7E5E5D7D7
D7D7D7D7D7D7C8C8C8D7C8D7C8C8C8C8BBC8BBA076763276
84A0AEAEA0A0A0C8BBBBBBC8C8C8C8BBD7D7D7D7E5E5E5E5
E5F2F2F2F2F2E5F2
F2F2E5F2F2F2F2F2F2F2E5F2F2E5E5F2F2F2F2F2F2F2E5E5
F2F2F2E5F2E5E5D7D7AEA084765A4C23000008C8C8D7D7D7
D7D7E5E5E5E5E5E5E5E5E5E5E5D7E5E5D7E5D7D7D7D7D7D7
D7D7D7C8C8C8C8C8C8D7C8BBBBBBC8C8AEAEA0A03F765A76
5AA0AEA0A0A0BBBBBBC8BBC8D7BBC8D7D7D7D7E5E5E5F2F2
F2F2F2F2F2E5F2F2
F2F2F2F2F2E5F2F2F2F2E5F2F2F2F2F2F2F2F2F2F2E5E5F2
F2F2F2F2F2E5F2D7BBAEA08476844C3F08082323C8D7D7E5
D7D7E5E5E5E5E5E5E5D7E5D7D7E5E5D7E5E5D7D7D7C8D7D7
D7D7D7C8C8AEBBC8D7C8AEAEBBAEBBAEA0A08476A076A0A0
91AEAEA0AEA0BBAEAEBBBBC8BBBBD7D7D7D7D7E5E5E5F2F2
E5E5F2F2F2F2F2F2
F2F2E5F2E5F2F2F2F2F2F2F2F2F2E5F2F2E5F2E5E5F2E5F2
F2F2F2F2E5E5E5C8BBA0A08484763F3F23323F00C8D7D7E5
D7D7E5E5D7E5E5D7E5E5D7E5D7E5E5E5D7D7D7D7C8E5C8D7
C8C8C8C8AEBBBBD7D7AEAEBBBBAE84845AA0847676A0A084
A0AEAEAEA084BBAEBBAED7BBC8D7D7D7D7D7D7E5E5E5F2F2
E5F2F2F2E5F2F2F2
F2E5F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2E5F2F2F2
E5E5F2F2F2E5E5C8BBA084765A5A3F3F4C4C2300D7D7D7D7
E5D7E5E5E5E5E5E5E5E5E5E5D7D7E5D7D7D7D7C8C8C8D7C8
C8C8C8BBAEAEC8C8AEA0A0A0A084763F76A0848484847684
A0AEAE9191AEBBAEBBAEAEC8C8C8D7D7D7E5F2E5E5E5F2F2
F2F2F2E5F2E5F2F2
F2F2F2E5F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2
E5F2F2F2E5E5D7BBBB918484763F324C4C3F0808D7D7E5D7
D7E5D7D7E5E5E5D7E5D7E5E5D7D7D7D7E5C8D7C8C8D7C8C8
C8BBBBA0AEAEBBAEA0A0A0A0845A5A5A76AEA0A0847691A0
A091AEA0BBBBBBA0AEAEAEBBD7D7E5D7E5E5E5E5E5E5F2E5
F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2
F2F2F2F2E5E5D7BBAEA08476764C4C764C080800D7D7D7C8
D7E5E5D7D7E5D7D7D7D7C8D7D7C8C8D7C8D7C8C8C8C8C8C8
BBBBAEAEA0BBA08484A084844C845A7676A0AEA084A084A0
9184A0A0BBBBBBAEAEBBAEBBD7D7D7E5E5F2E5E5E5F2F2F2
F2F2F2E5F2E5F2F2
F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2
F2F2E5F2F2E5D7BBBB918476763F5A4C32000800D7D7D7D7
D7D7E5D7D7E5D7C8D7C8C8C8C8C8C8C8C8C8C8C8C8BBC8BB
BBBBAEA0AEAE84848476764C5A5A4C5A84AEAEAEAEA0A084
8491A0A0BBBBBBA0BBC8BBC8D7D7E5F2E5D7E5E5F2F2F2F2
F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2E5F2F2F2F2F2F2F2F2F2F2F2F2F2F2E5
F2E5F2F2F2F2AEBBA0A05A5A4C5A5A5A23082308D7C8D7D7
D7D7D7D7D7D7D7C8C8C8C8C8C8C8C8C8C8C8C8BBC8BBBBBB
BBAEAEA0AEA0847676764C765A4C4C5A84A0AEA0AEA09184
8484A0BBBBBBBBBBBBAEBBC8D7D7E5D7E5F2E5E5F2F2F2F2
F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2F2F2E5F2F2F2F2F2F2F2F2E5F2F2F2F2
F2F2F2E5F2D7BBBBA08476844C5A5A4C00000808D7C8D7C8
D7D7D7D7D7C8C8C8C8C8C8C8C8AEAEAEBBBBC8BBBBAEAEAE
AEAEA0918476765A7676765A5A5A768484A0AEC8BBC8A076
7684A0A0BBBBBBBBAEAEAED7D7D7D7E5E5E5E5F2F2F2F2F2
F2F2F2F2F2E5F2F2
F2F2F2F2F2F2E5E5F2F2F2F2E5F2F2F2F2F2F2F2F2F2F2F2
F2E5F2F2F2D7BBA091845A5A4C763F3200000808D7C8D7D7
D7D7D7C8C8C8C8C8C8BBBBC8BBBBAEAEAEAEBBBBAEAEAEA0
A0A084A0845A4C765A767623233F84A0A0A0A0AEBBAEBB91
84A0A0AEA0BBBBAEAEAEAED7D7E5D7E5E5E5E5F2E5F2F2F2
F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2
F2F2E5F2D7BBBB9184765A4C4C5A3F2308080823C8C8C8C8
D7C8C8C8C8C8BBC8C8AEAEAEA0AEAEA0AEAEA0AEAEAEA0A0
A0A084AE763F5A5A5A4C32230076A084A084A0AEC8BBC891
91AE91AEA0BBAEAEA0AEC8D7E5E5E5D7E5F2F2F2F2F2F2F2
F2E5F2F2F2F2F2F2
F2F2F2F2F2F2E5F2F2F2F2F2F2F2F2F2E5F2F2E5F2F2F2F2
F2E5F2E5D7BBA084845A765A4C4C080808080808C8C8C8D7
D7D7D7D7D7D7C8C8C8BBAEA0AEA0A0A0A0A0AEAEA0A0A084
848484A05A235A763F2323234C76A0A084A076AEBBBBAEA0
A0A0A091BBBBAEBBAEBBBBC8F2E5D7E5E5F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2
F2F2F2E5E5F2F2F2F2F2F2F2F2E5F2F2F2F2F2F2F2F2F2F2
E5E5E5E5C8BBA08484765A845A4C001508080832C8D7E5E5
E5E5E5E5E5E5D7D7D7C8C8BBA0A0A0A0A0848484A0A084A0
847676A03F3F5A3F32080876325AA0A0847684AEBBC8C8BB
A0A08484BBBBA0AEBBBBD7E5E5E5E5E5F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2E5
F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2E5F2F2F2F2
E5F2F2D7BBBBA084764C5A4C5A32002315080884E5E5F2F2
F2E5E5F2E5E5E5E5D7D7C8C8C8AEA08484A0A0A08484A084
84764C844C5A8432230815843F5A84A0847684A0AEC8C8BB
BBA08491BBBBBBBBD7BBD7E5E5D7F2E5F2F2F2E5F2E5F2F2
F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2E5F2F2F2F2F2F2F2F2F2F2F2F2F2F2E5E5
F2F2F2D7AEA0917676765A4C5A000823080884E5F2F2F2F2
F2F2F2F2F2E5E5E5E5E5D7D7C8C8BBAE84848484A0848484
765A3232844CA02308000076844C84AE769184A0BBC8D7D7
BB849191AEA0BBBBBBC8E5E5E5E5F2F2F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2E5F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2
E5E5D7D7A0A0845A4C5A5A4C3200232308D7F2E5F2F2F2E5
F2E5F2F2F2F2E5E5E5E5D7C8C8D7C8BBAE84767684768476
765A3223A032AE5A08150032A03F84A084A0A0A0AEBBD7D7
BBA08491A0A0BBBBBBD7D7D7D7E5E5F2F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2
F2F2F2F2E5F2F2F2F2F2F2F2E5F2F2F2F2F2F2F2F2F2F2F2
E5E5C8BB919184764C5A4C4C0808230869E5F2E5F2F2F2F2
F2F2E5F2F2F2E5E5E5D7D7D7D7D7C8C8BBA0AE7676765A76
4C5A3215A07684840800235AA0A0A0A0A076A091A0BBBBD7
D7918491A0A0BBD7AEBBD7E5F2F2F2F2F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2
E5F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2E5F2E5
E5D7C8AE9191845A324C3F4C0008153FE5E5F2F2F2F2F2F2
F2F2F2F2F2F2E5E5E5E5E5D7D7D7C8C8C8BBAEA05A76764C
5A3223005ABB3FAE4C7608763F9176A0A09184A084BBAED7
E5918491A0A0BBBBBBD7D7E5E5F2E5F2F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2E5
E5D7C8A0A076844C4C4C3208083232E5E5E5F2F2F2F2E5E5
E5E5E5E5E5E5E5D7E5D7E5D7D7C8D7C8C8C8BBAEAE5A5A5A
3F3F08083291845AA03F844C7684A076A0915A9191BBBBAE
C8D7918491A0A0BBD7D7E5D7E5F2E5F2F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2E5F2F2F2F2E5
D7D7AE9184764C4C4C4C00080808E5E5F2E5E5E5F2E5E5D7
D7D7C8C8C8C8C8C8C8C8D7D7D7D7D7C8C8C8C8BBBBAE844C
32321508154CAE9169BBA0843276A0A0A0768484BBA0BBBB
D7D791A0BBA0A0AED7F2D7F2E5F2E5F2F2F2F2E5F2F2F2F2
F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2E5
D7C8BBA08484763F4C32080832D7E5E5F2E5E5E5E5D7D7D7
C8C8D7D7D7D7D7C8C8C8C8C8D7D7D7C8C8C8BBBBAEAEA03F
32230800083FAE764CBBA0AE845A76AEA0849184BBA0BBBB
BBD7BBBBA0A0BBBBD7E5E5F2E5F2F2F2F2F2E5F2F2F2F2F2
F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2E5D7
D7C8A084765A76323208082323E5E5E5E5E5E5E5E5C8AEC8
C8C8C8C8C8C8AEAEAEAEBBC8C8D7D7D7C8C8C8BBBBAEA0A0
23080800083276BB84A0BBAEBBA0A084A091768491BB91C8
BBD7D7A0BBA0BBD7C8D7E5E5E5E5F2F2E5F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2E5D7
D7BBA0695A5A4C2332150823E5E5E5E5E5E5E5D7C8C8C8E5
E5D7D7D7E5C8C8C8A0AEAEBBC8C8D7D7C8C8C8BBBBAEC8A0
84150000003200BBC85ABB84C8BB91A0AE76A08491A0AEBB
BBD7D79184A0BBAEE5E5E5E5E5F2F2E5F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2E5F2D7C8
AEA08469324C3F4C00080869E5E5E5E5E5E5E5C8C8C8C8C8
C8C8C8AEAEA0A0A0D7AEAEA0BBD7D7D7D7D7C8BBBBBBAEAE
A076080800083F84A08491BBA0C8E59184A0A07684AEA0BB
BBD7D7A0A0A091AEE5E5F2E5E5F2F2F2F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2D7BB
BBA0764C3F4C320823084CE5E5E5E5E5E5D7C8765A769176
9191A0845A5A5A763F765A324CC8D7D7D7C8C8C8BBBBBBBB
A0843F000008153291BB4CBB84BBD7E5AEAE84A08491A084
BBD7D7BBBBBBA0BBD7E5E5E5F2E5F2F2F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2E5D7BB
91844C3F3F3F23232332E5E5E5E5F2E5E5E5E5D7AEAEA0AE
A0AEC8A0A0A0A0A0A0BBBBBBC8C8D7D7D7D7C8D7C8BBBBBB
AEA05A00000000325ABBA05ABB84D7D7E576A0A084919184
BBBBD7D7A0BBBBD7E5E5E5E5F2F2F2F2F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2E5F2E5C8BB
845A5A3F3F3215233232E5E5E5E5E5E5E5E5F2F2F2E5E5E5
F2E5E5F2F2E5E5D7D7D7D7D7D7D7D7D7D7D7C8C8C8C8BBBB
AEAE843200003215325A915AA076A0D7D7BBAE91848491AE
BBAED7D7A0A0A0D7E5E5E5E5F2F2F2F2F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2E5C8D7A0
764C32323208232323BBE5E5E5F2F2E5F2E5F2F2F2F2F2F2
F2E5E5E5E5D7D7D7D7D7D7D7E5D7D7D7D7D7D7C8C8C8BBC8
AEAE844C00001532695AA05A4CA091C8D7E5BBA0A0A08484
84AED7D7BBBBA0E5E5D7E5F2F2F2F2F2F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2C8A084
5A5A32320823232323E5E5E5E5F2F2F2F2E5F2F2F2F2F2F2
E5E5E5E5E5D7D7E5D7D7D7E5D7E5D7D7D7D7D7C8C8C8C8BB
AEAEA05A15000015324C5A765A8469AED7D7AEBBA0918491
84BBBBD7AEA0BBD7E5E5D7F2F2F2F2F2F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2C8BB9184
5A323F082308233208E5E5E5E5F2F2F2F2F2F2F2F2E5F2F2
E5E5D7E5D7D7D7D7D7E5E5E5E5E5E5E5D7D7D7D7C8C8BBBB
C8A0A084150000153F4C5A845A3F4C91A0C8E5BBA0A05AA0
91BBBBD7AE91D7D7E5E5E5F2F2F2F2F2F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2E5C8A0915A
5A4C32232315230884D7E5E5F2F2F2F2F2F2E5F2F2F2E5E5
D7C8C8D7C8C8C8D7D7D7E5D7E5E5E5E5E5D7D7C8C8C8BBBB
BBAEA0843F00080032325A4C84325A32BBD7BBC8A0A06984
91A0BBD7BBA0D7D7F2E5F2F2F2F2F2F2F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2D791764C
3F3F230808232308D7E5E5F2F2F2F2F2F2F2E5F2F2F2E5E5
D7D7C8C8C8BBBBC8C8D7D7E5E5E5E5E5E5E5E5D7C8C8BBBB
BBA0A0844C00000015325A32845A5A23BBA0BBE5A0A0A084
84A0A0D7BBBBC8D7D7D7F2F2F2F2F2F2F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2E5BB844C32
3F08231523320800E5D7E5E5F2F2F2F2F2F2F2F2E5C8C8E5
E5E5D78484A0C884BBC8D7E5E5E5E5E5E5E5D7D7D7C8C8BB
BBAEA08476150000001532325A5A325A3F91C8BBC8A0915A
8484BBD7BBE5AEE5BBF2F2F2F2F2F2F2F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2D7A0764C5A
2323082323080032E5E5E5F2F2F2F2F2F2F2E5F2F2E5E5F2
F2E5D7C8C8D7D7C8AEBBD7E5E5E5E5E5E5E5E5E5D7C8C8BB
AEAEA0A05A3F00000000153F325A324C00BBAEAED784915A
7691A0AEC8C8A0BBF2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2D7914C4C08
1532152332000069D7F2F2F2E5F2F2F2E5F2F2F2F2E5E5E5
E5F2E5D7D7D7C8C8C8C8E5E5E5F2E5E5E5E5E5E5D7D7C8C8
C8C8A084764C00000015324C155A324C00A091BBD7849176
848491BBC8C8BBC8F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2D7763F4C32
2323323F230000D7E5F2F2F2F2F2E5F2E5F2F2E5F2F2E5F2
E5F2E5D7D7D7C8C8C8D7E5E5E5E5E5F2E5E5E5E5E5D7D7C8
C8AEA084764C00000015005A325A23323F76A0C8C8BB8491
768484AED7BBD7F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2A04C4C0815
15233223000000E5F2E5F2F2F2E5F2F2F2F2F2F2F2F2E5E5
E5F2E5D7BBC8C8BBC8D7E5E5E5E5F2E5E5E5E5E5E5D7D7C8
C8BBA08476761500000023323F4C2332155AA0AEC8D78484
5A84A0D7D7A0C8F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2E5844C320832
32322300000000E5F2F2E5E5E5E5E5E5E5E5F2F2F2E5F2F2
F2E5E5D7BBC8C8C8D7E5E5E5E5F2F2E5F2E5E5E5E5E5D7D7
BBC8AEA0765A3F000000151532325A32326991AEC8E58484
5A6984AEC8C8F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2844C232332
152332000000AEE5E5F2E5E5E5E5F2F2F2E5F2F2F2F2E5F2
F2E5E5C8C8C8D7D7D7E5E5E5F2F2F2E5F2E5E5E5E5D7D7C8
C8BBBBA0845A4C00000000323F234C5A325AA0BBC8E576A0
3F8476D7D7C8F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2C85A3F153232
3223000000E5E5F2F2F2E5E5F2E5E5E5E5E5E5E5E5F2F2F2
F2F2E5D7C8D7D7D7D7E5E5E5F2F2E5F2F2E5E5E5E5D7E5D7
C8BBBBBB845A5A15000815154C325A3F3F5ABBBBBBD79184
326984C8D7E5F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F25A4C32002315
1532000800E5E5E5F2E5E5F2F2E5E5F2F2E5E5E5E5F2E5F2
F2F2F2D7C8D7D7D7D7D7E5F2E5F2E5F2F2E5E5E5E5E5D7D7
C8C8BBBBA0844C1508080832325A4C3F4C84BBBBBBBBA076
326991BBD7F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2765A15083F32
2315080069F2E5E5E5E5F2F2E5F2E5F2F2E5F2F2E5E5F2F2
E5F2F2D7C8C8D7D7E5E5E5E5E5E5E5F2F2F2F2E5E5E5E5D7
C8C8BBBBA0844C3F00000815324C5A4C4CBBBBBBBBBBBB76
767684C8E5F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F25A5A32151532
32001532E5F2E5E5E5E5E5E5E5E5F2E5E5E5E5E5E5F2F2E5
E5E5F2D7D7C8D7D7D7D7E5E5E5E5E5E5F2E5E5E5E5E5D7D7
D7C8BBBBAE845A3215080808324C3F3232BBBBA0BBA0C84C
767669BBF2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2914C3F323F323F
080015D7F2E5F2E5E5E5E5F2E5E5F2E5E5E5E5E5F2F2F2F2
E5E5F2E5D7C8C8C8D7C8D7D7E5E5E5E5E5E5D7E5E5E5E5D7
D7C8C8BBC8A05A4C15000808155A3F3F3FA0A0BBBB5AD732
5A91A0AEF2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F269845A155A153F
001523D7F2D7E5E5F2E5E5F2E5E5E5E5D7E5E5E5E5F2E5F2
F2E5F2E5D7C8BBC8C8D7D7E5E5D7D7D7D7D7D7D7E5E5D7D7
BBD7C8BBBBA0764C32000008153F5A3F3FA0AEAEBB32C84C
3F84BBD7F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F23F843F4C323F15
005AD7E5D7E5F2E5E5E5E5E5D7E5E5E5C8C8D7D7E5E5D7E5
E5E5F2E5C8C8BBBBAEBBD7D7D7D7BBD7C8C8BBC8C8D7D7D7
D7D7C8BBAEA0845A32150000083F3F5A3291BB849132D75A
3FA0BBD7F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2FF5A69323F324C00
3232F2AEC8E5F2E5E5E5E5D7C89184BBAE91C8C8E5E5E5E5
F2F2F2E5C8BBA0BBD7C8D7D7C8A0918484A0A0A0AED7D7C8
C8C8C8BBA0A0844C321508000032323F3F849184844CD74C
3FA0BBD7FFF2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F291695A1532154C00
4CE5E5D7BBE5E5E5E5E5D78491C891151569A0C8C8E5E5D7
F2F2F2E5D7BBBB91BB5AA0A0BBC84C156969696984BBC8C8
C8C8BBBBAEA0845A3F1532000032323F5A849184844CD75A
5ABBBBE5F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F284915A3F00324C08
00F2D7D7C8E5F2E5D7D784A0BBD72315003269A091D7C8E5
F2F2E5E5D7C89184A0A076C8E53F4C234C08915A3F84BBBB
C8C8BBBBBB84765A3215000000323F155A84845A6976C832
91BBBBF2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2FFF269322300323232
4CF2C8D7C8D7E5E5C8914C0084A04C840032004C8491D7E5
F2F2F2E5D7D791845A84915AAE0084001500910015698491
BBBBBB91A0A0764C3232000000003215765A69698476BB32
91BBC8F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2F2F2F2F2F2F2F284BB694C231532324C
AEE5D7BBC8E5E5D7AEA0153232000000323F326991D7E5F2
F2F2F2E5E5D7C891A0764C69690000000015001523698484
AEBBBB9184844C3F3F150800000808155A765A5A8476BB4C
91BBE5F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2F2F2F2F2F2F2F27691843F153F32153F
A0D7BBBBC8E5D7D7D7C891843F232323324CA0BBD7E5E5F2
F2F2F2E5E5E5D7C8BB91843269695A320000155A9184A0AE
BBBB91AE91844C3F32321500000000155A845A5A8491BB5A
91BBE5F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2E5694C15151515085A
A0AEA091BBD7E5E5F2E5E5E5D7D7D7D7D7D7BBC8D7E5F2F2
E5E5F2F2E5E5D7BBC891BBBBBB919191AEBBBBBBC8D7C8BB
BBBBAEA091844C3F32080800001515085A915A5AA091C85A
91E5FFF2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2F2F2F2F2F2F2FFFF153F0008084C005A
84C8AE84BBE5D7F2F2F2E5F2F2E5D7A0695A84D7E5F2F2F2
F2E5F2E5F2F2E5D7A0765A8484D7D7E5D7D7D7D7D7D7C8BB
A084AE9184765A3F32320000000000153F765A4CA0A0D769
A0E5F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2F2F2F2F2F2F2E5FF082300081532155A
848491A0A0E5C8D7E5F2E5E5F284694C84BBE5F2F2F2F2F2
F2E5F2F2F2F2F2E5D7914C324C84C8D7D7E5E5E5D7C8C891
69AE8484765A5A3F08080000000015324C695A4C9191BB91
A0F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2F2F2F2F2F2FF91FF321515150032234C
4C4C6984A0D7E591A0BBBBC88476BBF2F2F2F2F2F2F2F2F2
E5E5E5E5F2E5F2F2F2E5D7BB844C3F5A76AE84A084696984
9191C891765A5A325A001515080000325A765A4C91BB8476
C8F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2F2F2F2F2F2F2A05A1515323215151532
4C3F5A69BBD7E5E5E5BB91C8C8E5F2F2F2F2F2F2F2F2F2F2
E5E5F2F2F2F2F2E5F2F2F2E5E5E5D7D7A06976696991A091
AEBBAE91765A7632081508000000003F4C3F6976A0A05A91
E5F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2F2F2F2F2F2F2BB5A23155A3F2332153F
3F3F7676BBE5E5E5E5F2F2E5E5E5F2F2F2F2F2F2F2F2F2F2
E5F2F2F2E5E5E5E5E5F2E5E5F2E5E5E5D7D7D7D7C8C8BBBB
BB9184847669765A15080000000000843F3FBB5A84BB5AA0
F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2F2F2F2F2F2F2AE321532694C32322332
323F695ABBD7E5E5E5F2F2E5F2F2E5F2F2F2F2F2F2F2F2F2
F2E5F2E5E5F2E5F2F2F2F2F2F2E5E5D7D7E5D7D7C8BBBBBB
BB91A0918476763F5A15000000000091693F91765ABB5ABB
FFF2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2F2F2F2F2F2F2C8323F3F5A3F3F3F3232
32325A5AA0D7E5E5E5E5F2F2E5F2F2F2F2F2F2F2F2F2F2F2
F2F2F2F2F2E5E5E5F2F2F2F2F2E5E5D7E5D7D7D7C8C8BBBB
BBBBAE8476845A5A15000800000000A0695ABB843F915AF2
F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2F2F2F2F2F2F2F23F323232323F323232
32326984A0D7D7E5E5F2F2F2E5E5F2F2F2F2F2F2F2F2F2F2
F2F2E5E5E5E5E5F2F2F2F2E5E5E5E5E5D7D7D7D7C8C8C8BB
91AEA09184765A32150015000000005ABB84BB845A4CAEF2
F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2F2F2F2F2F2F2FF233F323F3F4C3F3232
323F5A9191C8D7E5E5F2F2F2F2F2F2F2F2F2F2F2F2F2E5F2
F2F2E5E5E5F2F2F2F2F2F2E5E5E5E5E5D7D7D7D7D7C8BBBB
BBAE848484695A3F081500000000004C915AA091694CD7F2
F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2F2F2F2F2F2F2FF5A153F4C4C323F3223
4C3F5A84A0BBD7E5F2F2F2F2F2F2F2F2E5F2F2F2E5F2F2F2
E5E5F2E5F2F2F2F2F2F2F2E5F2E5E5E5D7D7D7D7C8C8BBBB
91AEA084845A5A3F150800000000233F6976A0A0BBA0F2F2
F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2F2F2F2F2F2F2FF3269693F3F323F325A
153F699184BBD7E5E5F2F2F2F2F2F2E5F2F2F2F2F2F2E5F2
F2E5E5F2E5E5F2F2F2F2E5F2E5E5E5E5E5D7D7C8C8C8BBBB
91BB84845A4C3215320000000000324C5A4CA0A0A0D7F2F2
F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2D76923233232323232
3F3F6984A0BBD7E5E5F2F2E5F2F2F2F2F2F2F2F2E5F2F2F2
E5E5F2F2F2F2E5F2F2F2F2F2E5E5E5E5E5D7D7C8C8C8C8BB
A0BB84695A5A5A230800000000004C4C5A5AA0A0BBF2F2F2
F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2FF3F23321532151523
3F5A8484BBBBD7E5F2F2F2E5F2F2F2F2E5F2F2F2F2E5E5F2
F2F2F2F2F2F2F2F2F2F2F2F2E5F2E5E5E5E5D7C8C8BBC8BB
BB918484693F3F080000000000005A4C5A4CA0AEC8F2F2F2
F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2AE32323232323215
325A6984A0C8D7E5F2F2F2E5E5F2E5F2F2F2F2F2E5F2F2E5
F2E5F2E5F2F2F2F2F2F2F2F2E5E5E5E5E5D7D7C8C8C8BBBB
AEAE9169695A3F0000000000000069843F76A0D7F2F2F2F2
F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F23F151515153223
154C8491BBC8E5E5E5E5F2F2F2F2F2F2F2F2F2E5F2F2E5F2
E5E5F2F2F2E5F2F2F2F2E5F2F2E5E5E5D7D7D7D7C8C8BBBB
BB8491695A3F32000000000000005A845AA0BBC8F2F2F2F2
F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2693F1532231523
324C5AA0BBD7D7E5F2F2F2F2F2E5E5F2F2E5F2F2E5E5E5E5
F2F2E5F2F2F2F2F2F2F2E5E5E5E5E5E5D7D7D7D7C8C8C8C8
AE8484765A3F15000000000000004C5A5A91C8E5F2F2F2F2
F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2FFAE694C4C4C23
234C6984BBD7E5E5E5F2E5F2E5E5E5E5F2F2E5F2F2E5F2F2
F2F2F2F2F2F2F2F2F2F2F2E5E5E5E5E5D7D7D7C8D7BBBBBB
848469693F321515000000000000845A84AEAEF2F2F2F2F2
F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2FFFFE54C4C323F
323F7691A0C8E5E5E5F2F2F2F2F2E5E5F2F2F2F2F2F2E5F2
F2F2F2F2F2F2F2F2F2E5E5E5E5E5E5E5D7D7D7D7C8BBBB91
9191764C32321500000000000069694C84A0D7F2F2F2F2F2
F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2FF91323215
3F3F6991BBC8D7E5E5E5F2E5E5F2F2F2F2F2F2F2F2F2F2F2
E5F2E5F2F2F2E5E5E5E5E5E5E5E5E5E5D7D7D7C8C8BBBBBB
84695A4C3F32320000000000845A5A4C91BBE5F2F2F2F2F2
F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2FFC8083269
23696991A0C8D7D7E5E5E5F2F2F2F2E5F2F2F2F2F2F2F2F2
F2F2F2E5F2E5F2E5E5E5E5E5E5E5D7E5D7D7C8C8AE91BBAE
84695A5A3215154C0000002332695A76A0D7F2F2F2FFF2F2
F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2FFAE5A3232
32696991BBC8C8D7E5E5E5F2E5F2E5F2F2F2F2F2F2F2F2F2
F2E5E5E5E5E5E5E5E5E5E5E5E5E5D7D7D7C8C8C8BB919184
765A4C323232320015001515695A8491BBBBF2FFF2F2F2F2
F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2FFA0A01532
233F5A8491A0BBD7D7E5E5F2F2E5E5E5E5F2F2F2F2E5E5E5
E5E5E5D7D7E5E5E5E5E5E5E5D7D7C8D7C8BBBBBB91918484
76695A15151515001500694C5A5ABBA0D7F2F2F2F2F2F2FF
F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2FFF2F2F2F2F2F2
F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2D7C80015
5A325A6984BBC8C8D7E5E5E5E5D7E5E5E5E5E5E5E5E5E5E5
E5D7D7D7D7D7E5D7D7D7D7C8C8D7BBC8BBBBA0BB91848484
695A3F3223153F23153F844C6991BBD7BBF2F2F2F2FFF2F2
F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2A05A23
324C3F5A6991BBD7C8BBD7D7E5E5E5E5D7D7D7D7D7D7C8C8
C8C8BBBBBBBBBBBBC8BBBBBB91AEAEAEAEA084918484845A
3F4C4C154C4C153F5A5A5A5A9184C8D7F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2914C
323F4C6984698491C8BBD7E5D7D7D7D7D7C8C8BBC8D7BBC8
BBBB91A0A0AE91BBAEAE8484848491848484846984916969
69693F3F4C6932083284848491AEBBBBF2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2FFF2F2F2F2F2F2
F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2E5
694C235A693F84A0BBD7D7D7D7D7BBC8BBAEBBBBBBBBBBBB
A0A084848484847684845A5A845A845A766969693F4C4C76
4C5A4C5A32323F5A5A6969A0BBBBA0F2F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2
6969695A69A0AE91C8AEC8BBBBC8C8BBBBBB91A0BBA0A0A0
91A084845A916991846991695A91698469696969324C695A
3F4C694C5A4C5A4C5A84BBAEAEBBD7F2F2F2F2FFF2F2F2F2
F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2
FF4C695A4C69848491C8BBC8AEBBBBA0A0A0849184918491
8491695A694C6969845A696969A03F5A5A84694C4C322315
153F323223234C84A0BBD791BB84F2F2F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2
F2FF84696991A0A0BBBBBBBBA0A0A0A091A0919184849184
69694C69693F156932846969693F5A6915155A3F323F5A4C
5A4C4C325A5AAE91BBBB3F9169C8FFF2F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2
F2F2A069325A5A69A0AEC8BBA09191849191846969846984
843FA0693F913F32693F3F4C323F321532325A32234C3F32
323F5A8484A091D7BB69699169F2F2F2F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2FFF2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2
F2F2FF155A91696984A0AEBBA06984699191845A84846984
6984325A4C3F69323F4C3232321532323215153223323232
3F69696969A0AE5A5A69A091E5F2F2F2F2F2F2F2F2F2F2FF
F2F2F2F2FFF2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2
F2F2F2F25A1584849184BBBBA06984696984694C69694C69
4C6932695A4C151569152332233215150800151515325A32
3F69A091D7AE91694CA04CE5FFFFF2F2F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2
F2F2F2F2FF69154C6984AEBBA0694C84698484844C69693F
69693F5A694C3F0015236932320832150800000000153F69
918491AE84324C84695AA0F2F2F2F2F2F2F2F2FFF2F2F2F2
F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2FFF2F2F2F2F2F2
F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2
F2F2F2F2F2C82323326991A0BB694C69844C4C693F3F5A4C
3F4C694C3F695A3F3F15153232323F325A32324C5A766991
A0C884915A154C698484F2F2F2F2F2F2FFF2F2F2F2F2F2F2
FFF2F2F2F2F2F2F2F2FFF2F2F2F2F2F2F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2
F2F2F2F2F2F2BB4C3F32326969BB3F3F5A844C4C3223233F
3F4C4C3F3F69695A4C236932324C4C3F4C5A6984A08491BB
91846969235A696969FFF2FFFFF2F2FFF2FFF2F2F2FFF2F2
F2F2F2F2F2F2F2F2F2F2F2F2F2F2FFF2F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2
F2F2FFF2F2F2F2914C4C5A6969A0A03F3F69694C69323232
5A4C5A32695A846984844C3F3F5A5A84849191BBBBA0695A
5A3F153269695A91FFF2F2F2FFFFF2F2FFF2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2AE324C698491A0A04C693F694C694C32
23153F235A5A9184C8D7BBA0C8BBBBBBD7D7C8AE693F5A4C
32233F84846969FFF2F2FFF2F2F2F2F2F2F2F2F2F2FFFFF2
F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2
F2F2F2F2F2F2FFF2F2E55A4C1569AEAEAE698469696991A0
5A233F234C84A09169BBBBBBC8D7D7BBA08484694C4C4C15
324C5A916984F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2
F2F2F2F2F2F2FFF2F2F2FF5A325A69A0C8A0A0BB91C8BBA0
D7E5F2E5E5D7D7BBC8C8C8C8D7AE69A0695A5A5A3F3F1569
69696969FFF2F2FFF2F2F2F2F2F2F2F2F2F2F2F2F2FFF2F2
F2F2F2F2F2FFF2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2FFF2F2F2
F2F2F2F2F2F2FFF2F2F2F2F2D7323F8491BBC8D7C8C8C8C8
D7C8D7D7D7E5E5D7C8D7AE91BB9184913F693F3F5A6991A0
8469A0F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2F2F2F2F2F2F2FFF2F2FFF2F2F2F2F2F2
F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2
F2F2F2F2FFF2FFFFF2FFF2F2FFE5695A69AEAEBBBBC8D7D7
D7D7E5D7D7D7E5D7C8BBAE8469915A5A4C69326991A08469
A0D7F2F2F2F2F2F2F2FFF2FFF2F2F2F2F2F2F2F2F2F2F2F2
FFF2F2F2F2F2F2F2FFF2F2F2F2FFF2F2F2F2FFF2F2F2F2F2
F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2F2F2F2F2F2FFF2F2845A69AEC8D7D7D7
D7C8D7C8C8BBA09184A0A0846932698469A0A0AEA069A0F2
F2F2F2F2F2F2FFF2F2F2F2F2F2F2FFF2FFF2F2F2F2F2FFF2
F2F2F2F2FFF2F2F2F2F2F2F2F2F2F2F2FFFFFFF2F2F2F2F2
F2F2FFF2F2F2F2F2
F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2FFF2F2F2F2
F2F2F2F2F2F2F2F2F2F2FFF2F2FFF2F2F2F2F29184A0AEBB
D7D7D7D7D7D7BBBBA09184AEC891BBC8BB9184BBE5FFFFFF
F2F2F2FFF2F2F2F2F2FFF2F2F2F2F2F2F2F2F2F2F2F2F2F2
FFF2FFFFFFFFFFF2F2F2F2F2FFF2F2F2FFFFF2FFF2F2F2F2
F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2FFF2FFF2F29191BB
A0BBC8C8D7D7E5F2E5D7C8D7C8C8A091AEC8E5F2F2FFFFF2
F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2FFF2F2F2F2F2F2F2F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2FFF2F2F2F2
F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2FFF2F2F2F2F2F2F2
F2E5E5D7F2E5C8BBBBC8C8C8C8C8E5F2F2F2F2F2F2FFFFF2
FFFFFFF2F2F2F2F2F2F2F2F2F2F2F2F2F2F2FFF2F2F2F2FF
F2F2F2F2F2F2F2F2F2FFF2FFF2F2F2F2F2F2F2F2FFF2F2F2
F2F2F2F2FFF2F2F2
F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2FFF2F2F2F2F2F2F2F2F2F2F2F2F2F2F2
FFF2F2F2F2F2F2F2F2F2FFF2F2F2F2F2F2FFFFF2F2F2FFF2
F2F2F2F2F2FFF2F2FFF2F2F2FFF2FFF2FFF2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2F2F2F2F2FFF2F2F2F2FFF2F2F2F2F2F2
F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2FFF2F2F2F2F2F2
F2F2FFF2F2F2F2F2F2F2FFF2F2F2F2F2F2F2F2F2FFF2FFF2
F2F2F2FFF2FFFFF2F2F2F2F2F2F2F2F2FFF2F2F2F2F2F2F2
F2F2F2F2F2FFF2F2F2F2F2F2FFF2F2F2F2F2FFFFF2F2F2F2
F2F2F2F2FFF2F2F2
F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2FFF2F2
F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2FFFFF2F2F2F2F2F2FF
F2F2F2FFF2F2FFF2F2F2F2F2F2F2F2F2F2F2F2FFF2F2FFFF
F2F2F2F2F2F2F2F2FFF2F2F2F2FFF2F2F2F2F2F2F2F2F2FF
F2F2F2F2F2FFF2F2FFF2F2F2F2F2F2F2F2F2F2FFF2F2F2F2
F2F2F2F2F2F2FFF2
F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2FFF2F2F2F2F2F2
F2F2F2F2F2F2F2F2F2F2F2F2FFF2F2F2F2F2F2F2F2F2FFF2
F2F2F2FFF2F2F2FFF2F2F2F2F2F2F2F2F2F2F2F2F2F2F2FF
F2F2F2F2FFF2F2F2F2FFFFF2F2F2FFF2F2F2F2FFF2F2F2FF
F2F2F2FFF2F2FFF2F2FFFFF2F2FFF2F2F2F2F2F2F2F2F2F2
F2F2FFF2F2F2F2F2
F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2FFF2
F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2
F2FFF2F2FFF2F2F2F2FFF2FFF2F2F2F2F2F2F2F2FFF2F2F2
F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2FFF2FFF2F2FF
F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2
F2F2FFF2F2F2F2F2
F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2FFF2F2F2
F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2
F2F2F2F2FFFFF2F2FFF2F2F2F2F2F2FFF2F2F2F2F2FFF2F2
FFF2FFF2F2FFF2FFF2F2F2F2F2FFF2F2F2F2F2F2F2FFF2F2
F2FFF2F2F2FFF2FFF2F2FFF2F2F2F2F2F2FFF2F2FFF2F2F2
F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2FFF2
F2F2F2F2F2F2F2F2F2F2F2FFF2F2F2F2F2F2F2F2F2F2F2FF
F2F2F2F2F2F2F2F2FFF2F2F2F2F2F2F2F2F2F2F2F2F2FFF2
FFF2F2F2F2FFF2FFF2F2F2F2F2F2F2F2F2F2F2F2FFF2F2F2
F2F2F2F2F2F2F2FFF2F2F2F2F2F2F2FFF2F2F2F2F2F2F2F2
F2F2F2F2F2F2FFF2
F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2F2FFF2F2F2F2F2F2F2F2F2F2FFFFF2F2
F2F2F2F2F2F2F2F2F2FFF2F2FFF2F2F2F2F2FFF2FFF2F2FF
F2F2F2F2F2F2FFF2F2F2F2F2FFF2FFF2F2F2F2FFF2FFF2F2
F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2F2F2F2F2FFF2FFF2F2FFFFF2F2FFF2F2
F2F2F2F2F2F2FFFFF2F2F2F2FFF2F2F2F2F2F2FFF2F2F2F2
F2FFFFFFFFF2F2F2F2F2F2FFF2F2F2FFFFFFFFF2F2F2F2F2
F2FFFFF2F2F2F2F2F2F2F2F2F2F2FFF2F2F2F2FFF2F2F2F2
FFF2FFF2F2FFF2F2
F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2FFF2FFF2F2F2
F2F2F2F2F2F2F2FFF2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2F2FFF2F2F2F2FFF2F2FFFFF2F2F2F2F2
F2F2F2F2F2F2FFF2F2F2F2F2F2F2F2F2F2F2F2FFF2FFF2F2
F2F2FFF2F2F2FFF2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2
F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2FFF2F2FFF2F2
F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2F2FFF2FFF2F2
F2F2F2F2F2F2F2F2FFFFF2F2F2F2F2F2FFFFF2F2F2F2F2F2
F2F2F2F2F2FFFFFFF2F2F2F2F2F2F2F2F2F2F2FFFFFFF2F2
F2F2F2F2F2F2F2F2F2F2F2F2F2FFF2F2F2F2F2F2FFF2F2FF
F2F2F2F2F2F2F2F2
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.35119 0.00744048 0.64881 0.30506 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00751202 0.0192308 0.00751202 [
[.5 1.0125 -17 0 ]
[.5 1.0125 17 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Green) show
93.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
128 string
128 128 8 [128 0 0 128 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
EFEFF7F7EFEFEFEFF7EFEFCECECECED6CECECECECEEFE784
C6CEC6C6BDC6C6BDC6C6C6C6BDBDC6C6CECEC6C6C6C6C6C6
B5C6C6C6CECECECECECECECECEC6C6C6CEC6C6C6C6C6C6C6
C6C6C6C6C6C6C6C6C6C6C6DEEFDE94BDBDC6C6BDBDBDC6C6
C6C6C6C6CECEC6CED6CED6D6D6CED6CEC6C6BDBDBDBDBDBD
DEDEADCEE7EFF7EF
EFEFEFEFEFF7F7EFEFF7EFEFCECECECECECECECECECEE7A5
C6CEC6C6C6BDBDBDBDC6C6C6C6C6BDC6CEC6C6C6C6B5BDC6
C6BDC6C6C6C6CEC6C6C6CEC6C6CEC6C6C6C6C6C6C6C6C6C6
C6C6C6C6C6C6BDC6C6C6C6C6DEEFAD84C6C6C6BDBDBDBDBD
C6C6C6C6CEC6CEC6CECECECECED6CECEC6C6C6C6BDBDC6E7
E7BDBDBDE7EFEFEF
EFEFEFEFEFEFEFEFEFEFF7F7EFCECECECEC6CECEC6CEDEE7
7BC6C6C6BDB5BDC6C6C6C6C6C6C6BDB5CECEC6C6BDBDBDBD
B5B5B5BDC6C6C6CEC6C6C6C6C6C6C6CECECECEC6CEC6C6C6
C6C6C6C6C6C6C6C6C6C6C6C6C6CEEFDE84BDBDBDC6C6BDBD
C6BDBDC6CECECECECECECED6D6D6CECEC6C6C6C6C6CED6D6
E7D6BDBDDEEFF7EF
EFEFEFF7EFF7F7EFF7F7EFEFEFEFEFD6C6CEC6C6C6C6C6E7
D6ADC6C6C6BDBDBDBDBDC6C6C6C6BDBDC6C6C6C6BDC6BDB5
BDBDB5B5BDC6C6C6C6C6C6C6C6C6CED6CECECED6CECECECE
CEC6C6C6C6C6C6C6C6C6C6C6C6C6CEEFDE84C6C6C6C6C6CE
C6C6C6C6CEC6CEC6CECED6D6D6CED6C6C6C6CEC6E7D6D6E7
BDDEC6BDE7E7E7EF
EFEFEFEFF7EFEFEFF7F7F7F7EFF7EFEFD6CECEC6CEC6CEE7
E7ADC6C6CEBDBDBDC6BDBDC6C6C6C6C6C6C6BDBDBDC6C6C6
C6C6BDB5BDBDC6B5B5B5C6C6C6C6C6C6CEC6C6D6D6C6CEC6
CEC6C6CECEC6C6CECECEC6CEC6C6C6CEEFADADC6CECECEC6
C6C6CECECECECECECECED6D6D6D6CECECEC6D6EFE7E7E7EF
CEDEBDBDE7F7EFEF
EFEFEFEFEFEFEFF7EFEFEFEFF7F7EFF7EFDECECECECECECE
E7E7C6CECEC6C6BDBDC6C6C6C6BDBDC6BDB5BDBDBDC6C6C6
C6C6C6C6B5B5B5BDB5C6BDC6C6C6C6C6C6C6CECEC6CECECE
CECECECECECECEC6CEC6C6C6C6CEC6C6CEEFBDADC6CECECE
C6CECECECECECECECECECED6D6D6CEC6C6BDD6E7EFC6D6C6
CEE7BDD6EFEFEFEF
EFF7F7F7EFF7EFEFEFF7EFF7F7EFF7F7F7F7EFD6D6D6D6D6
D6EFD6C6CECECEC6C6BDBDBDBDBDB5ADB5B5B5BDB5C6C6CE
CECECECEC6C6B5BDBDBDB5BDBDB5C6C6C6C6CEC6C6C6C6C6
C6C6C6CECEC6C6C6C6C6C6C6C6C6C6C6C6D6EFDEC6C6C6C6
C6CEC6CECECECECED6CED6D6D6C6C6ADADBDE7DEEFC6CECE
CECEBDE7EFEFF7EF
EFEFEFEFEFF7EFF7EFEFEFEFEFF7EFF7F7F7EFEFDEDEDEDE
DEDEEFD694CEC6C6BDBDBDBDBDADADB5B5B5B5B5B5BDC6C6
CECECECEC6C6B5B5B5B5B5BDB5B5B5B5BDBDBDC6BDBDBDBD
C6BDC6C6BDC6C6C6BDBDBDBDBDBDBDC6BDBDD6E7C6C6C6C6
C6C6C6CECECECED6D6CECECEC6BD9CADADC6D6C6ADBDC6BD
D6C6BDE7EFEFEFEF
EFF7EFF7F7F7EFEFEFEFF7EFEFEFF7EFF7F7EFF7EFF7EFEF
F7F7EFEFEFBDC6C6C6BDBDBDB5BDB5BDBDBDC6C6BDB5BDC6
CECECECECECEC6B5BDC6B5BDBDBDBDB5B5ADADADA5ADADAD
ADA5ADADADADADADADADADBDB5BDBDBDB5B5BDADCECEAD84
ADBDBDC6C6C6CECECED6CEC6949CADB5ADADC6C6BDBDBDDE
CEBDD6E7EFEFEFEF
F7EFF7EFF7F7F7EFEFEFEFEFEFEFF7EFEFF7EFF7EFF7EFEF
F7EFEFEFF7EFBD9CD6BDADBDBDBDB5B5ADB5BDBDBDB5BDC6
C6CECECECEC6C6BDBDBDBDC6BDC6C6C6BDC6BDBDBDB5BDB5
B5B5BDB5B5BDBDBDBDBDC6C6B5C6C6C6BDC6BDBDBDC6CECE
BD5AB5ADBDC6C6C6AD847B7B8CADBDBDADBDBDBDCEC6ADD6
D6ADDEDEEFEFF7EF
EFEFF7EFEFEFEFEFEFF7EFEFF7F7EFEFEFF7EFF7EFF7EFEF
EFEFF7EFEFEFBD9CADADADBDBDBDBDBDB5B5BDBDBDB5BDC6
C6C6C6CECECECEC6BDBDC6C6C6C6C6C6C6BDB5C6C6C6C6BD
BDBDBDC6C6BDBDBDBDC6C6C6C6C6BDC6BDC6C6C6C6BDC6C6
CECED6AD9494A58C7B8C7B849C9CBDADADE7BDBDC6A5CEDE
BDDEC6EFE7EFEFF7
F7EFEFF7EFF7F7EFEFEFF7EFF7EFF7EFEFEFF7EFF7F7F7F7
EFEFEFEFEFEFC6C694ADAD94BDBDB5BDADBDBDB5BDBDBDC6
C6C6C6C6CEC6CEC6C6BDBDC6C6C6C6C6C6C6C6B5BDBDC6C6
C6BDBDBDB5BDC6C6B5C6C6C6C6BDBDC6BDC6BDC6C6C6C6BD
BDBDCECECEBD636B847B8494949494ADB5DE9CADC6A5C6D6
BDEFE7EFEFEFEFF7
EFF7F7EFEFF7EFF7F7F7EFF7F7EFEFF7F7F7F7EFEFF7F7EF
EFEFEFEFEFEFCEC6AD94AD7B6BADBDB5B5BDB5BDB5B5BDC6
C6C6C6C6CEC6C6C6C6C6C6C6C6C6C6C6C6C6C6BDBDBDC6BD
BDC6BDB5BDBDBDBDBDC6C6C6C6B5C6C6BDBDBDC6C6BDBDBD
BDADA59C7B6B7B7B7B7B948C9494ADADADC6A5ADBDADD6C6
CEE7EFEFE7F7F7EF
F7EFEFEFEFF7EFF7EFF7EFF7EFF7EFF7F7F7EFEFF7F7EFF7
EFEFEFF7EFEFDEE7D68C947B6B52B5ADBDADADB5BDBDBDC6
C6C6C6C6C6C6C6C6C6C6BDBDBDBDC6BDC6C6C6BDBDBDBDBD
BDBDBDBDBDBDBDBDBDBDC6BDBDBDC6C6BDBDBDBDBDB5BDAD
AD9C94736B7B8C8C94847B9494A5ADADBDAD9CADADC6C6C6
D6EFEFEFEFEFEFEF
EFEFF7EFEFF7F7F7EFF7EFEFF7EFF7F7EFEFEFEFF7EFF7EF
EFF7EFEFEFEFD6EFC68C7B7B635239A5ADADBDB5BDB5BDBD
C6C6C6C6BDC6C6C6C6C6C6C6BDC6BDBDBDC6C6C6C6B5B5BD
BDBDBDB5BDBDB5BDBDB5C6BDC6BDBDC6C6BDBDBDB5B5ADAD
9C9C7B6B848C7B8C9C8C848CA594AD9CADA5BDBDBDDEADC6
EFEFEFE7EFEFF7EF
EFEFEFEFEFF7EFEFEFF7F7F7EFF7EFEFF7EFF7EFEFF7EFEF
F7EFF7EFEFEFDEE7C6BD7B846B523939ADADB5ADBDBDB5C6
C6C6C6C6C6BDBDC6C6BDBDBDBDB5BDBDC6C6C6BDBDBDBDB5
BDB5BDBDBDB5BDADBDBDBDBDBDBDBDBDBDADADA59C9C9C9C
8463527B9C946B8C94ADA5A58C8C949CADA5BDBDE7BDC6D6
E7E7E7EFEFEFF7EF
EFF7EFEFF7EFEFEFF7EFEFF7EFF7EFF7F7EFF7EFEFEFF7EF
EFEFEFEFEFEFEFDEDEAD847B6352423931ADB5ADBDB5BDBD
C6BDBDBDBDC6BDBDC6BDBDC6BDBDB5BDBDBDBDC6BDB5B5B5
B5B5B5B5BDB5B5ADADADB5BDADBDADBDB5ADA5A59C948473
525A638494948C9C9CA59C9CA58C94A5A5ADBDBDBDC6D6E7
E7DEE7EFEFEFF7F7
EFEFF7F7F7EFF7F7F7EFEFF7EFEFEFEFEFEFF7F7F7EFEFF7
EFEFEFEFEFE7E7CEDE8C847B5A5252423118A5ADADB5B5BD
BDBDBDBDBDC6BDC6BDBDBDBDBDBDBDB5B5BDB5BDBDBDBDB5
B5B5ADADADB5ADADB5ADBDB5ADADB5ADADADA59C8C736B63
636B8C948C8C949C948484948CA5A5A5A5BDBDBDC6E7E7DE
E7EFEFF7F7F7F7F7
EFF7EFF7F7F7EFEFF7F7EFEFEFEFF7F7F7F7EFEFEFEFEFF7
EFEFEFEFEFEFE7D6DE94847B63525242292918ADADBDB5BD
BDBDBDBDBDBDC6C6BDBDBDBDBDBDBDBDBDBDB5BDB5B5B5B5
B5B5ADADADADADA5ADADADBDA5ADADAD9CA59C7B5A6B426B
737B948C8C948CA59C9C9CA5A5A5ADADBDBDBDBDCED6DEE7
EFEFF7EFF7EFEFF7
F7F7EFF7EFF7F7F7EFEFEFEFF7EFEFEFEFF7F7EFEFF7EFEF
EFF7EFEFEFEFE7DECE94846B63635239292131ADADB5BDBD
BDBDC6BDC6BDBDBDBDBDB5BDBDBDBDB5BDB5B5B5ADB5B5B5
B5ADADADA5A5A5A5ADBDAD9C9C9C9C9C8C8C7B7B4A5A636B
637B8C84848C9C9CADAD9CA5BDADADBDBDBDBDCED6D6EFEF
F7F7EFEFF7EFF7F7
F7EFEFEFEFEFF7EFF7EFEFF7F7EFF7EFF7EFEFEFF7EFEFF7
F7EFF7EFEFEFE7D6AD9484735A6B524A3131424AADBDBDC6
BDBDC6BDBDBDBDBDBDBDBDBDB5B5BDBDB5B5BDADBDADB5BD
B5ADADA5A5949CADBDAD8C949C949C947B7B63637B6B7B7B
8C94948C8C8C9C8C949C9CA59C9CBDBDBDBDCED6E7E7EFF7
EFEFF7F7EFEFF7EF
F7F7EFF7EFEFEFF7F7EFF7F7F7F7EFEFF7EFEFEFEFF7EFEF
F7EFEFEFEFE7E7CEAD84846B736B4A4A39424229ADBDBDC6
BDBDBDB5BDBDB5BDBDBDBDB5BDB5B5BDB5B5B5BDADB5ADAD
ADADA59C949C9CBDBD8C949C9C8C7B6B637B6B636B7B7B6B
8494948C8473AD94AD94BD9CA5BDBDBDBDC6C6E7E7E7EFF7
EFF7F7F7EFF7F7F7
F7EFF7EFF7F7F7F7F7EFF7F7F7F7EFEFF7F7EFEFEFF7EFF7
EFEFF7F7EFE7E7ADAD84736B6363424A52523918BDB5BDBD
BDBDBDB5B5BDB5B5B5B5B5B5BDBDB5B5BDB5B5ADADADADAD
ADAD9C9C8C8CADAD8C84848C847B735A6B7B6B6B6B6B6B6B
8494948C8C949C949C9494A5A5A5BDBDBDD6EFE7E7EFF7F7
EFF7F7EFEFEFF7F7
F7F7F7EFF7F7EFF7EFF7EFF7F7F7F7EFEFEFEFEFF7F7EFF7
EFF7F7F7EFE7D6AD9C8C7B6B6B4A42525A4A3931BDB5C6BD
B5BDBDBDBDB5B5BDB5ADB5B5ADADADADB5ADADADADADA5A5
A59C9C848C949C94848484847B636B6B6B8C7B7B6B6B8C7B
848C8C94AD9C9C949494949CBDBDC6BDD6DEE7EFE7EFEFEF
F7F7EFF7F7F7F7F7
F7EFF7F7F7EFEFF7F7EFF7F7F7F7EFF7EFEFF7F7EFF7EFEF
EFEFEFEFEFE7D6AD9484736B6B5A526B52313129BDB5BDAD
BDBDBDADADB5B5ADADADADADADADADADA5ADA5A5A5A5A5A5
9C9C948C849C8C7B6B7B737B6373736B6B7B8C84737B7B7B
8C738C94ADADAD9494AD949CBDBDC6D6E7EFE7EFE7EFEFF7
F7F7EFEFEFEFEFF7
F7F7F7EFF7F7EFF7F7F7EFF7F7F7F7F7F7F7F7F7EFF7EFEF
F7EFEFF7F7E7BD9C9C8C736B6B4A635242293929BDBDBDBD
BDB5BDBDADB5ADADADADA5ADA5ADA5A5A5ADADA59C9CA59C
9C9C9484948C7B6B736B6B5A6B6B52636B8C8C8C947B7B73
738C9484A5AD9C94ADAD9CADBDBDD6DEE7DEE7EFEFEFEFF7
EFF7F7F7EFEFF7EF
F7F7F7F7EFEFF7EFEFF7F7F7F7EFF7F7F7F7F7EFF7F7EFEF
EFEFF7EFEFEFAD9C8C84636B5A4A634A42394231BDADBDB5
BDB5ADBDADADADADA5A5A59C9CA59C9CA5A5A59C9C9C9C9C
9C8C8C849484736B6363636B6B5A5A636B7B8C848C848C73
736B849C9C9CADADAD949CADBDC6DEDEE7EFEFE7EFF7EFF7
F7F7F7F7EFF7F7EF
F7EFEFF7EFEFF7F7F7EFEFF7F7EFF7F7EFEFEFEFF7EFEFF7
F7EFF7EFEFD6AD9C847B6B735263635A31293139BDADB5AD
B5B5ADADADA5ADA59CA59C9C9C9494949C9C9C9C9C949494
8C8C848C736B6B63636B6B636363636B6B7B8CA59CAD8C6B
6B738C849CADADAD949494BDC6C6DEE7DEEFE7F7EFF7F7F7
F7EFF7F7F7EFF7EF
EFF7F7EFEFEFEFEFEFF7F7F7EFF7EFF7EFF7EFF7F7F7F7F7
EFEFEFEFEFBDAD948C73636B5A6B4A4229293131BDADB5B5
B5ADADA5A5A5A5A59C9C9C9C9C9C949494949C9C94949484
84847B846B635A6B636B6B42424A637B7B7B84949C94AD8C
7384849484ADAD94949494BDC6E7DEE7E7E7EFF7EFEFF7F7
EFF7F7F7EFF7F7F7
F7F7F7F7EFF7F7F7F7F7F7F7F7EFEFF7EFF7EFF7EFF7EFEF
EFF7EFEFDEB5AD8C7B6B6B5A5A634A3931393939ADADADAD
ADADA5ADA5A59C9C9C949494848C8C849494849494948484
8484738C6B4A6B6B635A424229637B637B6B7B94A59CAD8C
8C948C9494AD9494848CADC6D6DEDEDEEFEFEFF7EFEFF7F7
F7EFF7EFF7EFF7F7
F7F7EFF7EFEFEFEFEFF7EFF7F7F7F7F7EFEFEFEFF7F7EFF7
F7EFEFEFC6AD9C7B7B6B63635A5A393931393939ADADADBD
ADADA5ADA5A5ADA5A59C8C848C7B848484848C8C8484847B
7B6B7384634A636B4A42394A525A7B7B737B6B949CAD9494
848C8C8CADAD949C94ADADC6EFD6DEEFE7F7F7F7F7EFF7F7
F7F7F7F7F7EFF7EF
EFF7F7EFEFF7EFF7F7EFEFF7F7EFF7EFF7EFEFEFF7F7EFEF
EFEFEFE7C6AD947B736B63734A5A214239393152ADC6C6C6
C6C6C6B5B5B5ADADADADA59C7B7B7B7B7B7B7B7B847B7B7B
736B6B7B4A4A635A4231396342637B7B736B738C9CADADAD
94947B6BADAD9494ADADBDEFE7E7E7EFEFEFF7EFF7F7F7F7
EFF7F7F7F7F7EFEF
F7EFEFF7F7F7EFF7F7F7F7F7F7EFF7F7EFF7F7EFF7EFF7EF
EFEFEFCEB59C8C7B735A635A6342294242393184C6C6D6C6
C6C6C6C6C6C6B5B5B5ADADA59C947B737B7B7B7B6B7B7B7B
736B63735A63734239314A6B42636B7B6B6B73848CADADAD
9C94738C9C9C9C9CBD9CBDEFDED6E7E7F7EFF7EFEFEFEFEF
F7F7EFF7F7F7F7F7
EFF7EFF7EFEFF7EFF7F7F7F7EFEFF7EFEFF7EFEFF7EFEFEF
EFEFEFCEAD948C736B6B635A6329394A39398CC6CED6CED6
C6D6C6CEC6C6C6C6B5B5ADADA5A59C94737373737B737B73
636B5242735A84393121296B6B526B8C6B8C73849CADBDBD
AD6B8C8C948C9CADADA5E7DECEE7EFEFF7F7EFF7F7F7F7EF
EFF7F7F7F7EFF7F7
F7EFF7F7F7F7F7EFEFEFF7F7F7EFEFF7EFEFEFEFF7F7F7F7
EFE7D6C69C947B6B5A63635A4A294A4A39C6CECECED6D6D6
D6D6C6C6C6CEC6C6C6C6BDADADADA59C946B6B6B736B6B6B
6363424284428C63394A21427B426B7B6B848484949CBDBD
AD8C7B8C9494ADADADBDDED6DEEFEFF7EFF7EFF7F7EFEFF7
EFEFF7F7F7F7F7F7
F7F7F7F7EFF7F7F7F7F7F7F7EFEFEFF7F7EFF7F7F7F7F7EF
EFE7CEBD948C7B6B63635A5A3931423984CECEC6CECED6D6
D6D6D6D6C6C6C6C6C6BDB5BDB5ADADA59C849463636B6B63
634A4A427B737B73312142637B847B7B846B8C8C949CADBD
BD8C738C7B94B5BDB5ADC6E7EFEFEFF7EFF7EFF7EFEFF7F7
F7F7EFF7F7F7EFF7
EFF7EFF7F7F7EFF7EFEFF7EFEFEFEFF7EFEFEFF7F7EFF7EF
EFDECEAD948C736B525A4A5A2939425AC6C6CECECECED6C6
D6C6C6D6C6C6C6C6C6C6C6B5B5B5ADADA59C94846363635A
634A4A296B9C4A94636B31634A8C637B7B8C84947BAD94BD
CE8C738C8C9C9CADADBDDEE7E7EFEFEFF7EFF7F7EFEFF7EF
EFF7EFEFF7EFF7F7
EFF7EFF7F7F7EFEFF7F7F7F7EFEFF7EFF7F7F7F7F7F7EFE7
E7CECE9C8C7373635A5A5239314A5AC6C6CECECECEC6CEC6
C6C6C6C6C6B5B5BDC6BDBDB5B5ADADADADA59C948C634A63
4A4A3939528C7B6B9C427B5A636B7B6B7B8C638C8C9C9CAD
ADBD8C6B8C9C94ADBDD6EFDEEFEFEFF7EFEFF7EFF7F7EFF7
EFF7F7F7EFF7F7F7
F7F7EFF7F7F7EFF7EFEFEFEFF7F7EFF7EFEFEFEFEFF7F7E7
D6CEB5947B73635A5A5A31393131C6C6CECEC6C6C6C6BDB5
ADADADADADA5ADADADADB5B5B5B5B5ADADA59C9C9C8C6B5A
524A42394A63948C7B9C7B7B426B847B7B6B7B7B9C949CAD
BDC68C949C948CADBDEFDEEFEFEFEFF7F7EFF7EFEFF7EFEF
F7F7F7F7F7F7F7EF
F7EFF7F7F7EFF7F7F7F7EFF7F7F7F7F7EFEFEFF7F7EFEFE7
D6CEAD947373634A5A5231394AC6CECECECEC6C6C6BDADAD
A59C8C8C8C8C8CA59CA5ADA5B5B5B5ADADA5A59C9494845A
424A3929396394735AA57B947B636B8C7B738C7B9C94AD9C
ADC6AD9C9C9C9CADBDE7E7EFEFEFF7EFF7F7EFF7F7F7EFF7
F7EFF7F7F7F7F7F7
F7EFF7F7EFF7F7F7F7F7EFF7F7F7F7F7F7EFEFEFF7EFEFD6
CECE9C7B736363524A3939394AC6C6C6C6C6C6C6B5736B7B
7B84848484846B6B6B6B9CADADB5B5B5ADADA59C9C948484
4A3931213152739C8484AD949C947B73848C6B738C9C8CAD
ADBDBD9CAD949CBDCED6E7EFE7EFEFF7EFEFF7EFF7F7F7EF
F7F7EFF7F7EFF7F7
F7EFF7EFF7EFF7F7F7F7EFF7F7EFEFF7F7EFF7F7EFF7E7DE
D6AD947B6B635A4A5242394ACEC6C6C6C6CEC68C848484C6
B58C8CA5B584847B84736B9CADADB5B5ADADADA59C948484
7B4A2929215229A5AD63AD7BA5AD8C849463847B8C94949C
ADBDC69484949CADE7E7EFEFE7F7F7EFEFEFF7EFF7EFEFF7
F7EFF7F7EFEFF7EF
EFF7EFF7EFF7EFF7EFEFF7EFEFEFEFEFEFEFF7F7EFF7D6CE
AD94847B525A4A5A29393984CECECEC6C6C6C67B84847B73
7373846B6B5A63638C73735AA5ADB5B5B5B5ADA59C9C9494
8473393918315A84947B8CAD84ADCE8C7384846B7B94949C
9CBDBD9C949C94ADE7E7EFE7E7F7F7F7F7F7F7F7EFF7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7EFEFF7EFEFEFF7EFEFEFF7F7EFEFF7EFEFEFD6C6
9C9473634A5A4A3142315ACECECEC6C6C68C84734A4A5273
52525A524A31424A314242425A84B5B5B5ADADAD9C9C9C9C
847B5A1818394A5A8CA55AA57B9CBDCE94946B847B8C8C7B
ADBDBDBD9CAD9CB5DEEFE7EFEFEFF7F7EFF7EFF7F7F7F7F7
F7F7F7EFF7EFF7F7
EFEFEFF7F7EFEFF7EFF7EFF7EFF7EFEFEFEFEFEFEFE7D6BD
947B634A5A4A4A4A4A42CECEC6CECEC6C6B5C68C736B636B
636B7B6363636363639CA5A5ADADB5B5ADADADADA59C9C9C
948473391818395A739C946B9C7BBDBDCE7384847B8C8C7B
ADADBDC694AD9CD6E7E7E7E7EFEFEFEFF7F7F7F7EFF7F7EF
F7F7EFF7F7EFF7F7
F7EFEFF7EFF7F7F7EFF7EFF7F7F7F7F7EFF7EFEFEFE7CEAD
846B6B5A4A4A424A4252CEC6CECEC6CEC6CECECED6D6C6C6
D6C6C6CED6C6C6BDB5BDB5B5B5B5B5B5B5ADADADA5A59C9C
94947B5231105A4A5A738C63846B84BDBD9C948C73738C94
9C94BDC69C9C8CDEE7E7E7E7F7F7F7EFF7F7F7F7F7F7EFF7
EFF7F7F7EFF7F7F7
EFF7F7F7F7F7EFF7F7F7EFF7EFEFF7F7EFEFEFEFE7C6BD9C
736352524A314A4A42B5CECECEC6CEC6CEC6CECED6CED6CE
D6C6C6C6C6B5B5B5B5BDB5BDC6B5B5BDB5ADADADA5A59C84
94947B5A21214A5284739C635A8C8CADBDC6AD84848C737B
7B94BDC69CAD94E7E7DEE7EFF7F7F7EFF7F7EFEFEFF7F7F7
F7F7F7F7F7F7F7EF
EFF7EFEFEFEFF7EFF7F7F7F7EFF7EFF7EFEFEFEFEFCE9C7B
636B4A4A394A4A4A4ACECEC6CECEC6C6CECECECECECECECE
CEC6C6C6C6B5BDBDB5BDB5C6B5C6B5B5ADADB5ADA59CA59C
9494846B4239185252636373637B7B94BDBD949C848C738C
739CADBDAD949CD6E7E7D6F7EFF7F7EFF7EFF7F7F7F7EFF7
F7F7EFEFF7F7F7F7
F7EFF7EFEFF7F7F7EFF7F7F7F7F7F7F7F7EFEFEFCEC69473
6B4A5A394A314A4A39CEC6C6CECECECEC6CECECECECECECE
C6C6B5C6B5ADB5BDB5B5BDC6B5B5C6C6B5B5ADADA5A59C9C
848484734A21294A636B73846B5A63948CA5C6AD7B8C6B94
8C9C9CBDAD8CC6D6E7E7E7EFF7F7F7F7F7F7EFF7F7F7EFF7
EFF7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7EFF7F7F7F7EFEFEFF7F7E7C6A5946B
6363424A4A4A4A3984C6C6C6CECECECED6CECECECECEC6C6
B5ADA5ADADA5ADADB5B5BDBDC6C6C6B5B5B5ADADA5A59C9C
9C947B6B5A3939425A52736373526352ADBD9CA58C947B7B
8C9C9CBDB594DEBDEFE7F7F7F7F7F7F7EFF7F7F7F7F7F7EF
EFF7F7EFF7F7F7F7
EFF7F7F7F7F7EFF7EFEFF7F7EFF7F7F7EFF7EFEFBD947363
4A4A4A39394A4A31C6C6C6C6CECECECECECECECECECEC6B5
ADB59CA5A59CA5ADADB5B5BDB5C6C6C6B5C6B5ADADA59C9C
9C84847B5A3910294A526B527363634AA5849CCE948C8C7B
8C8494BDBDBDCED6D6CEF7F7F7F7F7F7EFF7F7F7F7F7F7F7
F7F7F7EFF7F7F7F7
F7F7F7F7F7F7F7EFF7F7F7EFF7F7F7F7F7F7F7E7AD846352
4A394A424A423131C6C6C6C6CEC6D6D6CECECEC6D69C7BC6
C6B5A56363849C7B9CADB5C6C6C6C6C6C6B5B5ADADA5A59C
9C94846B63421829314A525A6B6B526B5A8CAD9CAD848C63
7B7B9CBDBDE7ADE7B5F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7EFF7
EFEFF7EFEFF7F7F7F7EFEFF7EFF7F7F7F7F7EFDE94736363
4A4A39424A393152C6C6CECED6CEC6D6C6CECECED6CEC6C6
C6C6B5ADADADB5A58C9CB5C6C6C6C6C6B5C6C6B5ADADA59C
9494847B735A10182942525A5273525A29AD8C94BD7B8C6B
738C94ADC6C6ADB5F7F7EFF7F7F7F7F7EFF7F7F7F7EFF7F7
F7F7F7EFEFF7F7F7
F7F7F7F7F7F7EFF7F7EFEFF7F7F7F7EFF7F7F7D68C635A39
4A4A424A4A29297BC6C6C6C6D6D6D6D6D6CECEC6D6C6D6D6
D6C6C6B5ADADADADA5A5B5C6C6C6C6C6C6B5B5B5B5ADAD9C
8484847B6B631021184A5263426B525A31948CADBD7B8C73
7B8494ADC6C6BDCEF7F7EFF7F7F7F7F7F7F7EFF7F7F7F7F7
F7F7F7F7EFF7F7F7
F7F7F7EFF7EFF7F7EFF7EFF7F7EFF7EFEFF7EFCE735A5A52
4A4A4A4A422939C6C6CECED6D6D6D6D6D6D6C6C6D6D6D6DE
D6C6C6BDADA5ADADA5ADB5C6C6CEC6C6C6C6C6B5B5ADADA5
9C94847B6B5A290821422963526B42525A738CA5A59C7B8C
737B7BADC6B5CEEFF7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7EFEFF7EFEFF7F7EFF7F7F7EF9463633942
424A4A4A212921C6C6CEC6D6D6D6D6D6D6D6D6CECEC6D6D6
D6CEC6ADA5A5ADA5ADB5C6C6C6CECEC6C6C6C6C6B5ADADAD
A59C847B73634A1018395A525A634A524A738494ADBD737B
737B94BDC69CCEF7EFF7EFEFEFF7F7F7EFF7F7F7F7F7F7F7
F7F7EFF7F7F7F7F7
EFEFF7F7F7EFF7F7F7F7F7F7EFF7EFF7F7F7EF84634A3952
4A4A4A18292139C6CED6D6D6D6D6D6D6D6D6D6D6C6CEC6D6
C6C6B5B5A5ADADADB5C6C6C6C6C6CEC6C6C6C6C6B5B5ADAD
A5A59484736B4A103129424A52526352527B8C94ADCE7B73
6B7B84ADC6CEEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7
F7F7EFEFF7F7F7F7
F7F7F7F7EFF7F7F7F7F7F7EFF7EFF7EFEFEFEF845A4A4A52
4A4A4A292129ADCECED6D6D6D6D6DEDEDED6D6D6D6CEC6D6
D6C6B5ADADADB5B5BDC6CEC6C6C6D6CEC6C6C6C6B5B5B5AD
A59C9C846B6B6321103129525A4A5A6352739C9CADCE738C
5A8473BDCECEF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7EFF7
EFEFEFF7F7F7F7F7F7F7EFEFEFF7F7EFEFF7C6735A425252
4A4A292118B5CEC6D6DED6D6DED6D6D6D6D6D6D6D6D6CED6
D6C6C6B5ADB5B5B5BDC6C6D6D6C6D6C6D6CECEC6C6C6B5B5
ADA59C9C7B6B634229394A4A6352635A4A73A59CADBD8C73
527B7BADD6EFF7F7F7F7F7F7F7F7F7EFF7F7EFEFF7F7EFF7
EFF7F7F7F7F7F7F7
EFF7EFF7F7F7F7F7F7EFF7F7EFF7F7F7F7F7735A52315A4A
4A4A293939C6C6D6D6D6D6DEDED6D6D6DED6D6D6D6D6CED6
D6D6C6B5ADB5BDBDBDC6CED6CED6D6D6C6CECECEC6C6BDB5
ADAD9C9C7B6B5A4A393939525263635A73849C9C9CAD8C6B
4A7B94ADDEF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EF
F7F7F7EFF7F7F7F7
EFF7F7F7F7F7F7F7F7F7F7F7EFF7F7F7EFF773634A395A52
4A42392984C6CED6D6D6DEDED6D6D6D6D6D6DEDED6D6D6D6
D6C6C6B5ADADBDBDC6C6CECECED6D6C6C6D6CECEC6C6C6BD
ADADA59C846B5A4A3131394A4A6363635A9C9C9C9CA5AD6B
6B7384ADEFF7F7F7F7F7F7F7F7F7F7F7F7F7EFF7EFF7F7F7
F7F7F7F7F7F7F7F7
F7F7EFF7EFF7F7F7EFF7F7F7F7F7F7F7F7EF7373524A4252
4A314252C6CECED6D6D6D6D6D6D6D6D6CED6D6D6D6D6D6C6
D6D6D6BDADADB5BDBDC6C6CECECED6CED6CEC6C6C6C6C6BD
BDADA59C947B6B5242313939525A63524AAD9C949C9CAD5A
737384ADEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7
F7F7F7F7F7F7F7F7
EFF7F7F7EFF7EFF7EFF7F7F7F7F7F7EFF7AD5A63525A524A
393942C6D6C6D6D6D6D6D6DED6D6D6CEC6C6CECED6D6C6CE
D6D6D6C6ADADADADBDADC6CEC6D6CECECEC6C6C6C6C6C6BD
BDADADA584846B5A4A2939394A6B5A5A5A9C949C9C6BBD42
6B8C94ADF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7
F7F7F7F7F7F7F7F7
F7F7F7EFF7F7EFF7F7F7F7F7F7F7F7EFF77B8C6B4A6B4A4A
314A4AC6C6C6D6D6DED6D6D6D6CECEB5C6C6C6C6CED6CECE
D6D6D6C6A5ADA5ADADBDC6C6CEC6C6BDC6C6C6C6C6C6C6C6
B5BDADA59C84735A4A2921394A5A635A5A9C94949C4AAD5A
5A84A5C6F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7
F7F7F7F7F7F7F7F7
F7F7F7EFF7F7F7EFF7F7F7EFEFEFEFF7F74A945A6B5A5A4A
2963ADC6ADC6D6D6D6D6D6CECEC6C6C6ADADBDC6C6CEC6C6
D6D6D6B5AD9CADA5ADB5C6C6BDBDB5ADADADA5ADADBDBDBD
BDBDADA594846B6B52421829395A5A6B52949C7B8C4ABD6B
4A94ADD6F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7
EFF7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7EFF7EFF7F7F7F7FF6B7B525A525A21
524AC694A5CED6D6D6D6CEC6AD948CA5A594ADADCECEC6C6
D6D6D6C6AD9C9C9CBDADC6ADADA59C848C9C9C9CA5BDBDAD
ADADADA59C847B5A524A3931315252635A848C7B7B5ABD5A
4A9C9CD6FFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
EFF7F7F7F7EFF7EFF7F7F7F7F7F7F7F79C7B734A524A5A31
5AB5B58CA5CECED6D6C6AD848CADAD6B73849C8484C6C6C6
D6D6D6C6B59CA594A54A5A84A5C67B5A7B7B7B7B84A5ADAD
ADADA5A594846B6B5A4A52292952525A6B8494737B52BD63
73ADADE7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7849C736331525A31
29C6ADA5ADCED6CEC6AD8484BDD6736B5A7B7B9C94ADADC6
D6D6CEC6B5A59484849C42C6E773736B8C639C736B84A5A5
ADADA59C9C84736B524A311021525A426B84846B7B63AD4A
94ADADF7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7EFF7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7FFEF84524A31525252
5AC6A58CADC6CEC6AD94733994B57BB518734A738494B5CE
D6D6CEC6BDB5948C738C946BC65ABD18735A9C31527B8C94
A5A5A5949484735A524A21182129524A73737B7B7B63AD4A
8C9CC6F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F794C68C73524A52525A
73B58C9CADC6CEB5A5844A6363422939526B637B94ADBDCE
CED6CEC6BDB5A5948473738C8C392939394A425A527B8484
949C9C94847B5A5A5A4A39213939394A6B736B637B73AD63
8C9CE7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
EFF7F7F7F7F7F7F7
F7F7F7F7EFF7F7F7EFF7F7F7F7F7F7739C9C5A4A63524A4A
84A59C9CADC6C6C6BDAD946B63525252527384A5B5C6C6CE
D6D6CEC6C6C6B5A59C9484637B847B634A424A738C8C8494
9C9C94948C6B5A5A5252422939313142737B73637B8CAD6B
8CA5EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7E78C6B4A424A4A396B
84949C94A5C6CECED6CEC6C6BDB5ADB5BDB59CA5ADC6D6CE
D6D6D6CECEC6B59C9C94A5A5A5949494949CA5A5ADADADA5
A59C94848C7B5A6352393929394A42396B8C6B638494AD73
94DEFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7EFF7
F7F7EFF7F7EFF7F7F7F7F7EFF7F7FFFF425A31393963314A
6B84948CA5CEBDCED6D6D6D6D6D6A5847B736BB5C6D6D6D6
DED6D6D6CED6BDAD8463736B8CBDC6C6C6BDBDB5B5B5ADA5
9484948C7B736B5A525229292939214A5A736B638C94BD7B
9CE7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7E7FF394A31394A524A63
637B8C849CC6C6BDC6D6D6D6C6847B736BA5C6CECED6DED6
DED6D6D6D6CECEC6AD8C5A525A6BA5ADC6C6C6B5BDADA594
7B948C84736B6B5A393929312921525A6B7B735A8C8CAD94
9CF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7EFF7FFADFF52424A4A31524A5A
5A5A7B849CC6CE949CA59C846B739CCED6D6DEDEDEDEDEDE
D6D6D6D6D6D6CECECECEB5A58C735A73636B8C84847B7B84
9494848C736B6B526B214242392929636B736B638C9C846B
CEF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7EFF7F7A5734A4A63524A4A4A52
5A63737BA5C6CECEC6A59C84ADD6DEDEDEDEDEDEDEDEDEDE
D6D6DEDEDED6D6D6D6CEC6C6C6C6C6C69C7B737B7B949C94
949C948C73737352394A393118182163735A7B63949C6B8C
E7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7EFF7F7F7EFF7F7F7F7F7C66B5A4A7B6B5A524A5A
5A6373739CC6C6CECED6D6D6D6D6DEDEDEDEDEDEDEDEDEDE
D6DEDEDED6D6D6D6D6D6CECECEC6C6C6BDC6C6B5ADADA59C
A5948C7B737B736B4A3921181818218C635A9C6B7BAD6B9C
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7EFF7F7F7F7EFF7F7F7F7F7F7B54A525A8C6B525A5A5A
5A5A7B739CC6CECECED6D6D6DEDED6D6DEDEDED6DEDEDEDE
D6D6DED6D6DED6D6D6D6D6C6CEC6C6C6BDC6B5B5ADA5A59C
9C94948C6B73735A6B422929213121947B5A94736BAD6BBD
FFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7CE526B6373636B635A52
52526B7384BDC6CECECED6D6D6DEDED6DEDEDEDEDEDEDEDE
DEDEDEDEDED6D6D6CECECECECEC6C6C6C6BDBDB5ADADA5A5
9C9C947B737B736B4A313931181821947B6B9C7363946BEF
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7EFF7F7F7F7F7F7F7F7EF635252526363525A52
5A527B7B94B5BDCECECED6D6D6D6DEDEDEDEDED6D6DEDEDE
DEDED6D6D6D6D6C6CECECECEC6C6C6B5BDBDBDB5ADADA5A5
9494848C7B736B524A394221181831739C849C7B7363ADF7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7FF526B52636B6B635A5A
5263738C94ADBDCECED6D6D6D6DEDED6D6DEDED6DEDED6DE
DEDED6D6D6D6D6D6D6CECECEC6C6C6B5B5B5B5B5ADADA5A5
9C948C84847B6B5A394A2121211829739473948C8463CEF7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7FF7B525A6B6B5A63525A
6B63738494A5BDC6CECECED6D6D6DEDED6D6DEDED6D6DED6
D6D6D6D6D6D6D6CED6CECEC6CEC6C6C6BDBDBDB5ADADA5A5
94948484846B6B5A4A392118101052637B739C94AD94F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7FF527B7B5A63635A5A63
42637B8C8CA5BDC6CECED6D6D6DEDED6DEDEDED6DED6D6DE
D6D6D6D6D6D6D6D6D6D6C6C6CEC6C6B5C6B5B5ADADADA5A5
949C8C84736B5A4A523118102910636B6B6394949CDEF7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7EFF7EFF7F7F7F7F7F7F7F7F7F7DE7B5A5A5252525A52
63637B8C9CA5BDC6CED6D6D6D6DEDED6DED6DED6D6D6DED6
D6D6D6D6D6D6D6D6D6C6CECEC6C6C6B5C6B5B5ADADADADA5
9C9C847B73736B5A3931181829186B6B7363949CA5F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FF635A524A52524A5A
636B848C9CADBDC6CEC6D6D6D6D6D6D6D6DEDEDEDED6D6DE
D6D6D6D6D6D6D6D6C6CECECEC6CEC6C6C6BDB5ADADA5ADA5
A59484847B635A393121211021187B6B63639CB5CEF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7B563525252525252
526B7B8C9CADBDC6CECED6D6D6DED6DEDEDEDEDED6DED6D6
DED6D6D6D6D6D6D6CED6CEC6CEC6C6C6C6B5B5ADADADA5A5
94948C7B7B735A393121291821217B845A7394BDF7F7EFF7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7EF6B4A4A5252525A
526B8494A5ADC6C6C6CECED6D6D6D6D6DED6DED6D6D6D6D6
D6D6D6D6D6D6D6D6CECECECEC6C6C6C6BDBDBDB5ADADA59C
9C8C8C7B736352393129212929186B846B84A5CEF7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F77B6B525A5A525A
5A6B7394ADBDBDC6CECED6D6D6D6D6DEDED6D6D6D6D6D6D6
D6D6D6D6D6D6D6CECECECECEC6C6C6C6BDBDB5ADADADA5A5
948C84736B5A4A393929212918106B736B8CADEFF7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFB57B6B6B6B5A
5A6B848C9CB5C6C6C6CECECED6D6D6D6D6D6D6DED6D6D6D6
D6D6CED6CECECECED6C6CEC6C6C6C6B5BDBDB5ADB5A5A5A5
8C8C7B7B6352424A31312118103984737394ADF7EFF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7EFF7F7F7F7F7F7F7F7F7EFF7F7F7F7F7FFFFE7736B5A63
636373949CADC6C6C6CECED6D6CED6D6D6D6D6D6D6D6D6D6
D6D6D6D6CECECED6CEC6C6C6C6C6C6BDB5B5B5B5AD9CA594
948C735A525A423939292918107B7B637B8CCEF7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FF9C526352
63637B8C9CADBDB5C6C6CECECECECED6D6D6CED6D6D6CED6
CECECECECECECEC6C6C6C6C6C6C6C6B5B5B5B5ADADA59CA5
8C7B6B635A5A5A3131291810847B6B638CB5E7F7EFEFF7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFCE395A7B
5A7B7B8C9CADBDC6C6C6C6CECED6CECED6CED6D6D6D6D6CE
CED6CEC6CEC6CEC6C6C6C6C6C6C6BDBDB5B5ADADAD949C94
847B736B5A4A526B2118215A527B6B7394BDEFF7EFFFF7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFB5735252
637B7B8C9CADADBDC6C6C6C6C6D6CECECECECECECECED6C6
C6C6C6C6B5C6C6C6C6C6C6C6C6C6B5B5B5ADADADA5949484
7373635A5A5252394A394A427B73848CADBDF7FFF7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFA59C4252
5A5A7384949CB5B5BDC6B5C6C6CECEC6C6C6CECED6C6CEC6
C6C6B5B5B5B5C6C6BDB5BDB5B5B5ADADADA5A59C94948C84
737B6B52524A4A424231846B736B9C94BDF7F7F7EFF7F7FF
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFF7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7DEC63142
6B5273848CA5ADADB5B5B5C6C6C6C6CEC6C6C6C6C6C6C6C6
BDB5ADADADB5B5ADADADADA5ADADA5ADA5A59C9C94848484
7B735A5A5A526B5A4A6B84737B8CA5BDBDEFF7F7F7FFF7F7
F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7A57B5A
5A6B63737B94A5BDADB5B5B5C6C6C6C6C6BDBDBDBDB5ADAD
ADADA5A59C9C9C9C9C9C9C9C9494949494848C948C847B6B
63736B5A6B6B4A636B6B736B8C84ADBDEFF7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7AD73
5A636B7B847B8C94ADB5BDC6C6BDBDBDBDADADA5ADBDA5A5
A5A5949C84948C9C73947B8C7B7B8C848484847B8C94848C
7B7B6363737B5A39527B847B8CADB5BDF7F7F7F7F7F7F7EF
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFF7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E7
8C735A737B638C9CBDC6C6C6BDBDB5ADA5ADA5A5A5A5A5A5
94948C8C848C84738484736B84738473737B7B7B636B7373
73737373525A6B6B737B7B94B5B59CF7F7F7F7EFF7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7EFF7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7
8C7B7B738CA5A59CADA5ADBDBDADADA5A5A5949CA59C949C
9484848473947B94847B8C7B6B947B847B7B848C636B7B7B
6B737B636B636B637384ADB5ADADCEF7F7F7F7FFF7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
FF7384736B848C8C9CADB5ADADA5AD9C9C9C8C948C948C94
84947B737B63847B8C737B7B7B94637373847B6B6B5A5A4A
526352525A5A637394ADC69CAD84F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7FF947B7B9C9CA5B5B5B5B59C9C9C9C949C949484849484
7B7B638484634A7B5A847B7B7B5A6B7B424A635A5A5A6363
6B636352636BAD94ADBD639C84CEFFF7F7F7F7F7F7F7EFF7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7A58463736B84A5B5ADB5A594948C94948C848C8C7B84
8463947B6394635A7B63636B5A5A5242525263525A635A52
4A5A7384849C94BDB5847B9C84F7F7F7F7F7EFF7F7EFF7F7
F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7FFF7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7FF5A7B9C7B8494ADB5A5A57B84849494847384847B8C
7B845A7373637B5A63635A635A525252524A42525A525252
637B7B7B7B9CB57B7B84A594E7EFEFF7F7EFF7F7EFF7F7FF
F7F7F7F7FFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F77B4A949C9C94B5B5AD7B8C7B7B847B738484737B
737B5A7B6B6B524A7B525A5A5A524A4A3939424242526B5A
63849C94BDB59C8C6B9C6BE7FFFFEFF7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7EFF7FF7B42738494B5BDAD7B6B947B8C94846B847B63
7B7B63737B736B314A5A7B525239524239313931314A5A84
948494B594637B84846BA5F7F7F7F7F7F7EFF7FFF7F7F7F7
F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7FFF7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7CE6B5A638C9CADB5846B7B8C73737B6B637373
6B6B7B73637B736B634A4A6352525A526B52525A6B737B8C
9CC6949C7B4A73849494F7F7F7F7F7F7FFF7EFF7F7F7F7F7
FFF7F7F7F7F7F7F7F7FFF7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7BD7B736363848CB5636B7B84736B5A5A5A63
636B7363637B8473735A7B5252736B63636B7B849C8C94B5
9C9C8C8C5A738C847BFFF7FFFFF7EFFFEFFFF7EFF7FFF7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFF7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7FFF7F7F7F7AD737373848C9CA56B6B84846B84525A5A
6B6B73527B738C7B84946B5A5A737384848C8CA5A5A57B7B
7B5A42527B847B94FFF7F7F7FFFFF7F7FFF7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7EFF7F7EFF7F7B563738C949CA5AD73846384737B6B52
524A635A7373948CC6C6B59CADA5A5A5C6C6ADB58C6B7B6B
5A5A6384947B7BFFF7F7FFF7F7F7F7F7F7F7EFF7F7FFFFF7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7FFF7F7EF8473638CB5B5AD848C848C7B94A5
7B526B527394A59C8CBDBDBDC6D6CEBD9C94948473736B52
52737B947B94F7F7F7EFF7F7EFEFF7F7F7EFF7F7F7F7F7F7
EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7FFF7F7F7FF7B63848CADC6ADADBDADCEBDA5
CED6EFE7D6CECEBDCEC6C6C6CEB58CA58C7B7B7B636B5A7B
8C84847BFFF7F7FFEFF7F7F7F7EFF7F7F7F7EFF7F7FFF7F7
EFF7F7EFF7FFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFF7F7F7
F7F7F7F7F7F7FFF7F7F7F7F7DE637394A5BDCED6CECECECE
D6C6C6CEC6D6DED6CECEB59CBD9C9C9C737B636B7B849C9C
8C84A5F7F7EFF7EFF7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFF7F7FFF7EFF7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7FFF7FFFFF7FFF7F7FFE784848CB5B5BDC6CED6D6
D6D6E7DED6D6DECECEBDC69C8C9C7B7B738C638C9C9C9C8C
9CDEF7F7F7EFF7F7F7FFF7FFF7F7EFF7F7F7F7F7F7F7F7F7
FFF7F7F7F7F7F7F7FFF7F7F7F7FFF7F7F7F7FFF7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7EFF7FFF7F7947B84B5C6D6D6D6
CEC6D6CEC6BDAD9C94A5AD9C8C6B7B9C8CADADB5AD8CADEF
F7F7F7F7F7F7FFF7F7F7F7EFF7F7FFF7FFF7F7F7EFF7FFF7
F7F7F7F7FFF7F7F7F7F7F7F7F7F7F7F7FFFFFFEFF7F7F7F7
F7F7FFF7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFF7F7F7F7
F7F7F7F7F7F7F7F7F7EFFFF7F7FFF7F7F7F7F79C94B5B5BD
D6D6D6D6D6D6BDBDA5A594B5CE9CBDC6BD9C94BDE7FFFFFF
F7F7F7FFF7F7F7F7F7FFF7F7F7F7F7F7EFF7F7F7F7F7F7F7
FFF7FFFFFFFFFFF7F7F7F7F7FFF7F7F7FFFFF7FFF7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFF7FFF7F7ADA5BD
A5BDCECEDED6E7EFE7D6CED6CECEA59CB5CEE7F7F7FFFFEF
F7F7F7F7F7F7F7EFF7F7EFF7F7F7EFF7F7F7F7F7F7F7EFF7
F7F7F7F7F7F7EFF7FFEFF7F7F7F7F7EFF7F7F7F7EFF7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFF7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7FFEFEFF7F7F7EFEF
EFE7E7DEEFE7CEBDBDCECEC6C6CEE7EFF7F7F7F7F7FFFFF7
FFFFFFF7F7F7F7F7EFEFF7F7F7F7F7F7EFF7FFEFF7F7F7FF
F7F7F7F7F7F7F7F7F7FFF7FFF7F7F7F7F7F7F7F7FFF7F7F7
F7F7F7F7FFF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7
F7F7F7F7F7F7F7F7FFEFF7F7F7F7EFF7F7F7F7F7F7F7F7F7
FFF7F7F7F7F7EFEFEFEFFFF7F7F7F7F7F7FFFFF7F7F7FFF7
F7F7F7EFF7FFF7F7FFF7F7F7FFF7FFF7FFF7EFF7F7EFF7F7
F7F7F7F7F7F7F7F7F7EFF7F7FFF7F7F7F7FFF7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7EFFFF7F7F7EFF7EF
F7F7FFEFF7F7F7F7F7F7FFF7F7EFF7F7F7F7F7F7FFF7FFF7
F7F7EFFFF7FFFFF7F7F7F7F7F7F7F7F7FFEFEFF7EFF7F7F7
F7F7F7F7F7FFF7F7F7F7F7F7FFF7F7F7EFF7FFFFF7F7F7F7
F7F7F7F7FFF7EFF7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFF7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFF7F7F7EFF7F7FF
F7F7F7FFF7F7FFF7F7F7EFF7F7F7F7F7F7EFF7FFF7F7FFFF
F7F7F7EFF7F7EFF7FFF7F7F7F7FFF7F7F7F7F7F7F7F7F7FF
EFF7F7F7F7FFF7F7FFF7F7EFF7F7F7F7F7F7EFFFF7F7F7F7
F7F7F7F7F7F7FFF7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFF7F7EFF7F7EF
F7F7F7F7F7F7F7F7F7F7F7EFFFF7F7F7EFF7F7F7F7EFFFEF
F7F7F7FFF7F7F7FFF7EFF7F7EFF7F7F7F7F7F7F7F7F7F7FF
F7F7EFF7FFF7F7F7EFFFFFF7F7EFFFF7F7F7F7FFF7F7F7FF
F7F7F7FFF7F7FFF7F7FFFFF7F7FFF7F7F7EFF7F7F7F7F7F7
F7F7FFF7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFF7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7
F7FFEFF7FFF7F7F7F7FFF7FFF7F7F7F7F7F7EFF7FFF7F7F7
F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7EFFFEFFFF7F7FF
F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7
F7EFFFF7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFF7F7F7
F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7EFEFF7
F7F7F7EFFFFFF7F7FFEFF7F7F7F7F7FFF7EFEFF7F7FFEFF7
FFF7FFF7F7FFF7FFF7F7F7F7F7FFF7F7F7F7F7EFF7FFF7F7
F7FFF7F7F7FFF7FFF7F7FFEFF7F7F7F7F7FFF7F7FFF7F7F7
F7F7F7F7F7F7EFEF
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFF7
F7F7F7F7F7F7F7F7F7F7F7FFF7F7EFF7EFF7F7F7F7F7F7FF
F7F7F7F7F7F7F7EFFFF7F7F7F7F7F7F7F7F7F7F7EFF7FFF7
FFF7F7F7EFFFEFFFF7F7F7EFF7F7F7F7F7F7F7F7FFEFEFF7
F7F7EFF7F7F7F7FFF7F7F7F7F7F7F7FFF7F7F7F7F7F7F7F7
F7F7F7F7EFF7FFF7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EF
F7F7F7F7F7F7F7F7EFFFF7F7EFF7F7EFEFF7F7F7FFFFF7F7
F7EFF7F7F7F7EFF7F7FFF7EFFFF7F7F7F7F7FFF7FFF7EFFF
F7EFF7EFF7F7FFF7F7EFF7F7FFEFFFF7EFF7EFFFF7FFF7F7
F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7FFF7FFF7EFFFFFF7EFFFF7F7
F7F7F7F7F7F7FFFFF7F7F7F7FFF7F7F7F7F7F7FFF7F7F7F7
F7FFFFFFFFF7F7F7F7EFF7FFF7F7F7FFFFFFFFF7F7F7F7F7
F7FFFFF7F7F7F7EFF7F7F7F7F7F7FFF7F7F7F7FFF7F7F7F7
FFF7FFF7F7FFF7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFF7FFF7F7EF
F7EFF7F7F7F7F7FFF7F7F7F7F7F7EFF7EFF7EFF7F7F7F7F7
F7F7EFF7F7F7F7F7F7FFF7F7F7F7FFEFF7FFFFF7F7F7F7F7
F7F7F7F7F7F7FFF7F7F7F7F7EFF7F7F7F7F7F7FFF7FFF7F7
EFF7FFF7F7F7FFF7F7F7F7F7F7F7F7EFF7EFF7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFF7F7FFF7F7
F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7FFF7FFF7F7
F7F7F7F7F7F7F7F7FFFFF7F7F7EFF7F7FFFFF7F7F7F7F7F7
F7F7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7FFF7EFF7EFF7F7FFF7F7FF
EFF7F7F7F7F7F7F7
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.678571 0.00744048 0.97619 0.30506 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00751202 0.0192308 0.00751202 [
[.5 1.0125 -14 0 ]
[.5 1.0125 14 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -75 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(blue) show
87.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
128 string
128 128 8 [128 0 0 128 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
F7E7F7F7F7E7E7E7F7E7E7B5B5B5BDC6BDBDBDBDBDE7DE6B
ADBDADADA5A5A59CA5ADA5ADA5A5A5A5ADADADADA5A5A5AD
9CADADADB5B5B5B5B5B5B5ADB5ADADB5B5ADADADADADA5A5
A5A5ADADADADADA5ADADA5CEE7CE6BA5A5A5A5A5A5A5ADAD
ADADADADB5ADB5ADBDB5BDBDBDBDBDB5B5ADADADA5A59CAD
CEDE8CBDE7F7F7F7
F7F7F7E7E7F7F7F7F7F7E7E7BDBDBDBDBDBDBDB5B5B5DE8C
ADB5B5ADADA5A5A59CA5ADA5ADA59CADB5ADADA5A59C9CA5
A5A5A5ADA5ADADB5ADADB5ADADB5ADADADADADB5ADADA5A5
ADADADADADADA5ADADA5ADA5CEE78473A5A5A5A5A5A5A5A5
A5ADADADADADB5ADB5B5BDBDBDBDBDBDADB5ADADA5A5ADDE
E79C94A5E7F7F7E7
E7E7E7E7F7F7F7E7F7F7F7F7F7BDB5B5B5B5B5B5B5B5D6DE
4AADB5B5A59CA5A5A5A5ADA5ADA5A59CADADADA59C9C9C9C
9C9C9C9CA5ADADADADADADADA5ADADB5B5B5ADB5B5ADADAD
ADADADADADA5ADADADADADADA5BDE7CE63A5A5A5A5ADA5A5
A5A5A5ADB5ADB5ADB5B5BDC6BDC6BDBDB5ADADADADBDCEC6
DEC69CA5D6E7F7E7
E7F7F7F7F7F7F7E7F7F7E7F7E7E7E7BDB5B5ADADADADADDE
C69CADB5B5A5A5A5A5A5A5ADADA5A5A5A5ADADAD9CA59C9C
9C9C9C94A5A5A5ADADA5ADA5A5A5ADBDB5B5B5BDB5B5ADB5
B5ADADB5B5B5ADB5B5ADADADADADBDE7CE73ADADADADADAD
ADADB5ADADADB5B5B5BDBDC6C6BDC6B5B5B5B5B5E7CEC6DE
9CD6AD9CE7E7E7E7
F7F7F7F7F7F7F7F7F7F7F7F7E7F7F7E7BDB5B5ADADADB5DE
DE9CADB5BDA5A5A5A5A5A5A5A5ADA5A5ADA59C9C9CA5A5A5
A5A59C9C9CA5A59C9C9CA5ADADADADADB5ADADBDBDB5B5B5
B5B5ADB5B5B5B5B5B5B5ADB5ADADADBDE78C9CADADADADAD
ADADADB5ADB5B5B5B5B5BDC6C6C6BDBDBDB5C6E7E7DEDEE7
BDD69C9CE7F7E7E7
F7F7E7F7F7E7F7F7E7F7F7E7F7F7F7F7F7CEB5B5B5B5B5BD
DEDEADB5B5B5ADA5A5A5ADADADA5A5A5A59C9C9C9CA5A5A5
ADA5ADAD9C9C9C9C9CA5A5A5ADADADADADB5B5B5ADBDB5B5
B5B5B5B5B5BDB5B5B5B5B5B5ADADADADBDE7A59CADB5B5AD
B5ADADB5B5B5B5B5B5BDBDC6C6C6BDB5B59CCEDEE7ADCEAD
BDE7A5CEF7F7F7E7
F7F7F7F7E7F7E7F7F7F7E7F7F7F7F7F7F7F7E7C6C6BDC6BD
BDE7D6B5BDBDBDB5ADA5A59C9CA594949494949C94A5ADAD
ADADADB5A5A59C9C9C9C9C9CA59CA5A5ADADADADADADADAD
B5ADADB5B5B5B5B5ADADADADADADADADADC6E7CEADADADAD
A5ADB5B5B5B5B5B5BDBDC6C6C6B5AD9C94A5E7D6E7B5BDB5
BDBD94E7F7E7F7F7
F7E7F7F7F7F7F7F7F7F7E7F7F7F7F7F7F7F7F7F7D6CECECE
CECEE7C67BBDB5ADA5A5A5A59C9494949494949494A5A5AD
ADADADB5ADAD9C9C94949CA59C94949CA5A5A5A5A5A59CA5
A5A5A5ADA5ADA5A5A5A5A5A5A5A5A5A5A5A5D6DEB5ADA5AD
ADADADB5B5B5B5BDBDBDBDBDADA57B8494ADCEAD8CA5A594
CEB59CDEF7E7E7F7
F7F7F7F7F7F7F7E7F7F7F7F7F7E7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7E7ADADADADA5A5A59C9CA59C9C9CA5A59C949CA5
ADADADADB5ADA5949CA59C9C9CA5A594948C948C84948C8C
8C848C8C949494949494949C9C9C9C9C9C949C94C6C68C73
94A5A5ADADADB5BDBDC6BDB563738CA58C8CB5ADA5949CD6
BD9CD6DEF7F7E7E7
F7F7F7E7F7F7F7F7F7E7E7F7F7E7F7F7E7F7F7F7F7F7F7F7
F7F7F7E7F7F79C7BC6A59CA5A59CA5A594949C9C9C949CA5
A5B5ADB5ADADAD9C9C9C9CA59CA5A5A59CA59C9C9C9C9C9C
9C9C9C9C9C9C9C9CA5A5A5A59CA5A5A5A5A5A5A59CB5BDC6
A5319C9CA5ADADB58C5A4A4A5A8C94A58C949CA5BDAD8CC6
C68CCED6E7F7F7F7
E7F7F7F7F7E7F7F7F7F7E7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F79C7394949C9C9C9C9CA5A5949C9C9C9494A5
ADA5ADADADADADA59C9CA5A5A5A5A5A5A59C9CA5A5A5A5A5
9C9C9CA5A59C9C9CA5A5A5A5A5A59CA59CA5A5ADA5A5ADA5
BDBDD68C7B7B84634A5A4A5A7373949484DE9494B57BBDCE
9CD6B5E7E7E7E7F7
F7F7E7F7F7F7F7E7E7E7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7E7E7F7E7B5AD6384846B9CA59C9C9C949C949C9494A5
A5A5ADADADA5ADA5A59C9CA5A5A5A5A5A5A5A59C9C9CA5A5
A59C9CA59C9CA5A59CA5A5A5A59C9CA5A5A59CA5A5A5A5A5
A5A5BDC6C6AD31395A4A5A63636B6394A5D67384AD7BB5C6
94E7DEE7E7F7F7F7
F7F7F7F7F7F7E7F7F7F7F7F7F7F7E7F7F7F7F7E7F7F7F7F7
F7F7F7F7F7F7C6B58C638442399C9C9C9C9C9C9C94949CA5
A5A5A5A5ADA5A5A5A5A5A5A5A5A5ADA5A5A5A59C9C9CA59C
9CA59C9C9C9C9C9CA5A5ADA5A59CA5A59C9C9CA5A5A5A5A5
9C94847B4A424A425A42635A636B84848CAD7B849484C6AD
BDDEE7F7DEF7F7F7
F7F7F7F7E7F7F7F7E7F7F7F7E7F7F7F7F7F7F7F7F7F7F7F7
E7E7F7F7E7F7CEDEC65A634239299C9C9C949C9C9C949CA5
A5A5A5A5ADA5A5A5A5A59C9C9C9CA59CA5A5A59C9C9C9C9C
9C9C9C9C9C9C9C9C9C9CA59C9C9CA5A59C9C9C9C9C949C94
8C7B634A424A5A5A6B5A426363738C849C8C738484ADADAD
C6F7E7E7E7F7F7E7
F7F7F7F7E7F7F7F7E7F7F7F7F7F7F7F7E7F7F7F7F7E7F7F7
E7F7F7F7E7E7CEE7AD5A4A42312918848C949C9C9C9494A5
A5A5A5A59CA5A5A5A5A5A5A59CA59C9C9CA5A5A5A594949C
9C9C9C9C9C9C94949C9CA59CA59C9CA5A59C9C9C94948C84
73734A395A5A4A5A7B5A5A5A73638473947B949494CE8CB5
E7E7F7DEF7E7F7F7
E7F7F7E7F7F7E7E7E7F7F7F7E7F7E7E7F7F7F7F7F7F7F7E7
F7E7F7F7E7E7CEDEB5AD425A39291818949494949C9494A5
A5A5A5A5A59C9CA5A59C9C9C9C949C9CA5A5A59C9C9C9C94
94949C9C9C949C8C9C949C9C9C9C9C9C9484847B73737373
5A39294A7363425A6B8473735A5A63738C7B9494DE9CADC6
E7DEE7E7E7F7F7F7
E7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E7E7F7F7
F7E7F7E7F7E7E7D6D6845A4A31292118188C9C949494949C
A59C9C9C9CA59C9CA59C9CA59C9C94949C9C9CA59C949494
949494949494948C8C8C949C8C9C8494948C7B7B736B5A4A
2931315A6363637373737373735A637B7B8494A59CADC6DE
E7D6E7F7F7F7F7F7
E7E7F7F7F7E7F7F7F7E7F7F7E7F7E7F7F7F7F7F7F7F7F7F7
F7F7E7F7E7E7DEBDCE5A5A42312929211808849C949494A5
9C9C9C9C9CA59CA59C9C9C9C9C9C9C949494949C9C9C9494
94948C848C948C8C948C94948C84948C8C847B7B634A3931
3942636B5A636373635A5A635A737B7B7394A5A5ADDEDECE
E7F7E7F7F7F7F7F7
E7F7F7F7F7F7E7F7F7F7F7F7E7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7E7F7E7C6D6635A4A3129292110100894949C9C9C
9C9C9C9C9C9CA5A59C9C9C9C9C9C9C94949C949C949C9494
94948C8C8C8C847B848C849C7B8C84847B84734A31392142
4A4A635A636B637373737373737B8484949CA5A5BDC6CEDE
E7E7F7F7F7F7F7F7
F7F7E7F7F7F7F7F7F7F7E7F7F7F7E7F7F7F7F7E7F7F7F7F7
F7F7F7F7E7E7DED6C6635A42313929181010189494949C9C
A59CA59CA59C9C9C9C9C949C9C949C949C9494948C949494
948C8C84847B7B7B849C847B737B73736363424A31313939
394A5A5A5A637373848C73739484849494A59CBDC6C6E7E7
F7F7F7F7F7F7F7F7
F7F7E7E7F7F7F7E7F7E7F7F7F7F7F7E7F7F7F7F7F7F7F7F7
F7F7F7E7F7E7DEC684635A4A31392929181821299C949CA5
9C9CA59C9C9C9C9C9C9C9C9C949C9C949494948C94849494
948C8C84846B738C9C8C636B736B736B4A4231314A424A4A
63636B635A63735A6B73737B73739494949CBDC6DEDEF7F7
F7E7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7E7F7F7F7F7F7F7F7F7F7E7F7F7F7F7
F7E7F7E7E7DEE7BD845A5A424A39292918212110949CA5A5
9C9C9C94949C94949C9C94949494949C949494948494848C
8C84847B6B7373949C636B7373635A523942393139424A42
5A63635A5A4A8463846B94737B94949494ADB5DEE7E7F7F7
E7F7F7F7F7F7F7F7
F7F7F7E7F7F7F7F7F7F7F7F7F7F7F7E7F7F7F7F7E7F7F7F7
F7F7F7F7E7DEDE94845A4A4239392129292918089C94A59C
9C9C9C94949C949494949494949494949494948484848C84
8C8C7B736363849463636363635A52424242393939424242
5A636B6363637B6B736B6B73737B9C9CA5C6E7DEE7E7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7DECE8473635A424229212931292118A59CA5A5
949C9C9C9C949C94948C94948C8C8C8C94848C8C848C7B84
7B7B736B6363736B5A635A5A5A394A4A395A4A423939634A
5A635A6B8473736B6B6B6B7394A5A5A5C6CEDEE7DEE7E7E7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7E7F7DEC68C6B5A4A423931293929181810A59C9C94
9C9C9C8C8C94948C8C8C848C8C84848C848C848484847B7B
73736B5A637B635A524A4A5A424A5239424A5A5A4A4A5A4A
634A636B848484636B846373949CADC6DEE7DEE7DEE7E7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7E7F7F7F7DEA57373634A4242293929211021109C9C9C9C
9C949C948C948C848C84848484848484848C847B7B7B7B7B
7B736B5A6B635A524A4242314A4A2939425A5A5A6B4A4A4A
4A636B5A84847B6B848C73849494C6CEDED6DEE7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E7
F7E7F7F7E7E79473635A394A3131393121212118A59C9C94
9C948C948C8C8C84848484737B7B7B7B847B7B7373737373
7363635A6B5A4A42424242424A31313939425A5A5A5A634A
4A425A737B738C8C846B73849CB5CED6DEE7E7DEF7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E7F7F7F7F7F7
F7F7F7E7E7C68C735A5A424A29393931211018219C949C94
94948C8C8C84847B7B7B7B7B736B6B6B73737B73736B6B6B
636363634A423939424242393939313942425A7373846339
394A635A7384848463636394ADB5D6DECEE7DEF7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7E7F7F7F7F7F7F7F7F7F7F7F7F7E7F7F7F7F7F7
F7F7F7E7E7A5846B634A394A31392921181818189C94949C
948C8C847B7B7B7B737B737373736B6B6B6B73736B6B6B63
635A5A5A42393142394242212129314242425A63736B8463
4A5A5A6B5A8C8C6B636B6394ADDED6DEDEE7F7F7E7E7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7E7F7F7E7F7F7F7F7F7F7E7
F7F7E7F7D6A584635A424A31313929181821211894948C8C
8C8C848C84847B73736B6B6B6B63636B6B6B6B6B6B6B635A
635A4A5A42294A4A393121211031423142424A63737B8463
6363636B6B846B6B5A5A84ADC6CECED6E7E7E7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E7F7F7F7F7F7F7
F7F7F7E7B58C845A5A4A42393131212118212121948C94A5
9494949494948C84847B635A635A5A5A5A5A63635A5A5A5A
5A524A5A3929394229211829293142424A42396373846B6B
5A63636384846373638484B5E7C6D6E7E7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7E7E7F7F7F7F7F7F7F7F7F7F7F7F7E7F7E7F7F7F7F7
F7F7F7DEB5846B5A4A42394A313110292121183194ADADAD
ADA5A59C9C9C9C94948C847B5A5A4A5A5A5A5A5A5A5A5A4A
4A42424A293139422118213121394A424A394A5A7B848C84
6B6B5A4284846B6B84849CE7DEDEDEE7E7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E7F7F7F7E7
F7F7F7BDA573635A523139313921102129211863ADB5BDB5
B5ADADB5ADAD9C9C9C948C847B6B4A4A5A4A4A5A525A4A5A
4A42424A31394A21181831392139424A39394A5A5A848C84
736B4A637373737394739CE7CEC6DEE7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7E7F7F7E7F7F7F7F7F7F7F7E7F7F7F7F7F7F7F7F7F7F7
E7F7F7BD946B63524242393139102129212173B5B5BDB5BD
B5BDB5B5B5ADA5AD9C9C948C847B736B4A4A4A4A4A4A5A4A
424A39214A315A18181010394229425A39634A5A738494A5
8C4263636B63738C847BE7CEBDDEE7F7F7F7E7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7E7F7F7F7E7F7F7F7F7F7F7F7F7F7F7
F7E7C6AD846B5A4A313939312910292921B5B5ADB5BDBDC6
BDC6B5B5B5B5ADA5A5A59C948C8C847B6B5242424A425242
423921215A216339213110214A21424A395A5A5A63739CA5
84635A636B6B848C8494D6CED6E7E7F7E7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7E7F7F7F7F7F7F7F7F7F7
E7E7BDAD7B635A4242393131211821216BB5B5ADB5B5BDBD
BDBDC6BDB5B5ADADADA59C9C948C94847B6B6B4242424A42
423131294A525A4A181021394A5A4A4A5A4263636B73849C
94634A634A6BA594A58CADDEE7E7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7E7F7F7F7F7F7F7F7E7F7F7F7E7F7F7E7F7F7
E7D6BD947B634A4A3931293118212942ADB5B5B5B5B5BDB5
BDB5B5BDB5B5ADA5ADADA59C9C94948C847B6B6B39424242
392929104A7B296B42421831316331424A63636B5A8463A5
B5634A63638473848C94D6DEE7E7E7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E7
E7BDBD8463524A4231313121182942B5ADADB5B5B5B5ADAD
ADADADADA59C9CA5A59C9C9C9C8C8C948C84736B63393139
3129212139635A4A84215A3142424A394A63396363737394
8C94634263846B8494CEE7D6E7E7E7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E7F7F7F7F7F7E7
CEBDA57B5A524231313121211818B5B5B5ADADADB5AD9C9C
94948C8C8C848C8C8C8C9494949C948C8C847B7B73635231
3131292131426B635A734A5A21395A424A395A5A7B6B7384
A5B5636B7B6B63949CE7D6F7E7E7E7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E7
C6BD8C6B4A4A42313131182129B5B5B5B5ADADADA5A5948C
847B7B7B7B7B7B847B848C8494949C948C84847B6B6B6342
29292118214A6B5231844A635A39425A4A4A635A736B8473
84AD84738484738CA5DEDEE7E7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E7E7F7F7E7CE
BDC6845A523942392921211829B5B5ADADADADA59C635A6B
6B73737373735A5A5A5A7B8C8C949494948C847B7B6B6B5A
292118101839527B636B8463736B4A4A5A63394A63736384
8C94A584846B7394BDCEE7E7E7E7E7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7E7F7F7F7F7F7E7F7E7D6
C68C6B5A4A39312939292129BDB5ADADA5ADAD7B737373B5
9C7B7B949C73736B6B635A7B8C94949C948C8C847B6B7363
5A311818103918848C398C5A7B84635A63315A5A636B6B7B
8CA5B57B636B7394DEDEE7E7DEF7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E7F7F7F7F7D6BD
946B635A393131311021216BB5B5B5ADA5A5A56B73736B63
6363735A5A4A4A4A7B63634A8C94949494948C847B7B6B6B
5A522121101842636B5A63845A84AD634A5A5A425A636B73
73A5A5846B847B94DEE7E7E7E7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7CEB5
736B524231312918211831BDBDB5ADADA57B735231314252
42424A39312129312131292942739494948C8C8C7B7B737B
635A420810213142638431845A7B9CAD6B6B395A5A63635A
8494A5AD738484A5D6E7DEE7F7E7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E7F7E7CEAD
7B5A4231422929292929BDBDB5B5B5ADA59CA57B635A4A5A
4A5A6B4A4A4A4A4A4A73848C8C8C94948C8C8C8C847B7B73
6B63522910102942527B6B4A735A9C9CB5525A5A5A63635A
8484A5AD6B8473C6E7E7DEDEF7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E7F7F7E7E7DEC68C
634A4A42292929292131B5ADB5ADADADA5ADB5B5BDC6B5AD
BDADA5B5BDB5ADA59CA59C94949C949C94948C8C84847B73
6B6B5A3129084231425263395A425A9C9C736B634A4A636B
736BA5AD848463D6DEDEE7DEF7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E7F7F7E7B59C84
524231313118292921A5B5B5B5B5B5ADB5ADB5B5BDB5BDB5
BDA5ADADAD9C9C9C9C9C9C9CA59C949C9C94948C84847B73
6B6B5A42101831316B528439316363949CA5845A5A634A5A
5A6BA5AD738C6BDEE7D6DEE7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7E7F7F7F7F7F7F7F7F7F7F7E7F7F7C6845A
394A29312129292929B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5
B5ADA5A5A59C9C9C9CA59CA59CA59C9C9494948C847B8473
6B6B634A2929104239423952395A5A6B94946B735A634A63
4A7384A5946B7BCEDEDEC6F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E7C6B57B4A
4A2942212918292921B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5
A5A59CA59C8C949C9C9C9CA59C9CADA59C9C948C84847B73
736B634A311018314A5252634A42427B6373A5844A634A6B
637B73A59463B5C6E7E7E7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E7B5947B4A
394229292931292163B5B5B5B5B5B5B5BDB5B5B5B5B5ADAD
9C8C849494848C94949C9CA5A5ADAD9C9C9C948C84847B7B
736B5A5242292139423952424A3139398C94737B636B5A5A
6384739CA56BD6A5F7E7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E7F7F7F79C7B5242
3131292121292918B5B5B5B5B5B5B5B5B5B5ADB5B5B5AD9C
9C947B84847B848C8C949C9C9CA5A5A59CA594948C847B7B
736B635A4229082131314A394A393929845A73AD6B63635A
735A6B9CADADBDCECEC6F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E78C634231
3121292929291821B5ADADADB5B5BDBDB5B5B5B5C67B6BAD
AD9C9442426B7B5A738C9CA5A5ADADADA59C9C948C84847B
736B635242291021213139424A4A314A42638473845A6339
5A5A7394ADE794E7A5F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7DE6B524239
2929212129212139B5ADB5B5BDB5B5BDB5B5ADB5BDB5B5B5
B5AD948C948C9484637B9CADADADADAD9CA5A5948C8C847B
6B6B635A524208102139424239523131188463639C5A634A
52636B94B5B59CA5F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E7F7F7F7CE63424221
3131292931101063ADB5B5B5C6BDBDBDC6B5B5B5BDB5C6C6
C6B5A5949C9C948C84849CADADB5ADADAD9C9C9C948C8C7B
7373635A4242081810313942294A3131216B63849C5A6352
5A637B8CB5B5ADBDF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7E7F7F7F7F7F7C652423131
29292931211829B5B5B5B5BDBDBDC6BDC6BDB5ADBDBDC6D6
C6B5ADA59494948C84949CADADADADB5ADA5A59C9C948C84
7B6B6B5A4231180818291839314A21314252637B7B735A63
525A5A94ADA5C6F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E76B42422129
29293129181018ADB5BDB5BDBDC6BDBDBDBDBDB5B5B5C6C6
C6B5AD948C848C8C949CADB5B5B5B5ADADA5ADA59C948C8C
84736B5A52423108102942394242293131525A6B8CA54A5A
525A6B9CAD84BDF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F76B42292139
31312910181029ADB5BDC6C6C6C6C6C6C6C6BDBDB5BDB5BD
B5B59C9C8C8C94949CADADADB5B5B5B5B5ADA5AD9C9C948C
84846B63524A31082918293131313931315A63638CAD5A4A
4A5A6394B5BDF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F76B31292939
31293118181894B5B5BDC6C6C6C6CECECEC6BDBDBDB5B5BD
BDAD9C94948C949CA5ADB5B5B5B5BDBDB5B5ADAD9C9C9C94
847B7363524A421808211839422931393152847384AD5263
42635294BDBDF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7C65242293131
31291818109CBDB5BDCEC6C6CEC6C6C6C6C6C6C6C6BDB5BD
BDB5AD9C9494949CA5B5B5C6BDB5C6B5BDBDBDB5ADAD9C94
8C847B735A4A392910213131423139423152847384A5634A
315A5A8CC6E7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7523131214231
3131182129ADB5C6BDC6C6CECEC6C6BDCEC6C6C6C6BDBDBD
BDBDB59C949C9CA5A5ADB5BDBDBDC6BDB5BDBDBDB5ADA59C
948C7B735A52423121212139313942425A6B7B7373846339
295A7B8CD6F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7523931214239
2929211873B5BDC6C6C6CECEC6BDC6BDBDC6CECEC6C6BDBD
C6B5B59C94949CA5ADADBDBDBDC6C6B5B5BDB5B5B5ADADA5
948C84736352423121212131314239423173737373848442
42526384E7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7525239312939
31212939B5B5BDC6C6C6C6C6C6C6BDC6BDC6C6C6C6BDBDB5
C6C6BDA594949CA5A5ADB5BDBDBDC6BDBDBDB5B5ADB5ADA5
A594847B6B5A4A392918212139314A39298C736B7B848C31
52526B84E7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7AD314A31423131
212929ADBDB5BDC6C6C6C6CEC6C6BDBDB5B5BDBDBDBDB5B5
C6C6BDAD948C949C9C9CB5BDB5C6BDBDBDB5B5B5ADADADA5
A59C8C8473634A3131182121314A424242846B73734A9421
4A636B94F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F76B734A314A3131
213129ADB5ADC6C6CEC6C6BDC6BDBD9CADADADB5BDBDB5B5
BDC6BDAD948C8C9494A5B5B5BDADADA5ADADADADADB5ADAD
A59C8C8473635231311810213142394242846B6B73318442
426B84ADF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7297B4252424231
18398CAD94B5BDC6C6C6C6BDBDB5B5AD9C94A5ADB5BDADB5
C6C6BD9C947B8C8C94A5ADB5A5A5A59C8C8C8C9C9CA5A5A5
9C9C94846B6B524A392910102142424A397B7B5A6329944A
316B84C6F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FF4A633942394210
3131B56B84B5BDC6C6C6BDB59C7B738C947B9C9CBDBDB5B5
BDBDBDAD947B847B9C9CB59C9C9C8C6B73848484949CA59C
9C9C8C84846B5A42393121212139314A426B635A5A319431
318473CEFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7945A523139314221
31949C7B8CB5BDC6C6B59C63639CAD636B73847373B5B5AD
BDBDBDA59C7B847B84314A6B8CC6734A6B635A636B8C9494
9C9C8C8C6B6B524A42313918183939424A637B4A5A299C39
528484E7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F76B8C524A21394218
18B58C9494BDBDBDAD9C6B6BB5CE736352736B847B9C94A5
BDBDB5AD9C847B6B6B8431C6E7635A5A845A9452526B8484
948C8C7B736B524A31312108183942294A6B634A5A428C29
7B8C8CF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFF76B312921393939
42B5847B94B5B5AD9C7B5A298CB56BBD186B425A6B7B9CAD
BDBDB5AD9C947B7352737B4ABD52CE186B5294294263737B
848C847B6B635242393118101818393152525A5A5A428429
637BB5F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F77BC6735A4231393942
639C7B7B8CB5B59C946B315252392129395252637B949CB5
B5BDB5AD9C9C847B6B525A84842918292931394A4263636B
6B7B7B7B6B5A424242312118292121314A524A395A528442
6373DEF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F752948C42314A393131
63947B7B8CB5B5ADA5947B524A424242395A6B849CADADB5
BDBDB5ADADA594847B7B6B4A63736B524239315263736B6B
7B7B7B6B635242423939291829212129525A52395A63844A
6384E7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7DE7B5231293131214A
636B847B8CB5B5B5BDBDADB5A59C9C9CA59C7B8494A5BDB5
C6C6BDB5ADAD94737B7B848C847B7B7B6B7B84848C8C948C
847B6B6B635A424A39212118293129214A634A395A7B9452
7BCEFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFF2942212121422131
52736B7384B5A5B5BDBDC6BDBDC6946B6352529CA5BDBDBD
CEC6BDC6B5BD9C946B42525273A5ADADADA5A59C9C9C9484
6B636B635A524A42313910181829103142524A42636B9C5A
84E7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7E7FF2129212131393139
425A636B84ADB59CB5BDC6C6B56B635A5284A5B5B5BDCEBD
CEC6BDBDBDB5B5A5946342394252849CADADAD9CA594847B
5A6B736B524A4A422121182118104242525A523163638C7B
84F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7FFADFF3129313121392931
4242636B84B5BD7B84847B7352527BB5BDBDCECECECECECE
C6C6C6C6BDC6B5B5B5AD9C84735A4252425A736B63635A6B
7B7B7363524A4A394A1829292118214A4A524A4263736B42
BDF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7945231314A3931313139
314A525A84B5B5B5AD848C739CC6CECECECECECECECECED6
C6C6CECECEBDBDC6BDB5B5ADADADADAD84635263637B847B
6B736B6352525239213121211010184A5A425A426B844A63
E7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7C64A42316B5242393142
424A52527BADB5B5B5BDBDC6C6C6CECECECECECECED6CECE
C6CECECEC6C6C6C6C6BDB5B5B5ADADADA5ADAD9C948C8C7B
847B735A525A524A31211010101018734A42734A5A844A84
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7A5294242735239424242
42425A527BADB5B5BDBDBDC6CECEC6BDCECECEBDCECECECE
BDC6CEC6C6CEC6BDBDBDBDB5B5B5ADADA5AD9C9C9484847B
7B7B6B63525252424A2918181821107B5A427B524A8C4AAD
FFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7C639524A524A524A4239
31314A526B9CB5B5B5BDBDBDC6CECEBDCECECECECECECECE
CECECECECEC6C6C6B5B5B5B5B5ADA5ADADA59C94948C8C84
7B736B5A525A524A312121211010186B634A734A4A7B4AF7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F74A3939394A4A394239
42395A5A6B9CA5ADBDB5BDBDC6C6CECECECECEBDBDCECECE
CECEC6C6C6C6C6B5B5B5B5ADADADAD9CA59CA59C8C948484
7B6B6B635A524A39312929181010215273637B5A524294F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7FF4252394A52524A4242
394A52637B8CA5B5BDBDBDBDBDCECEBDBDCECEBDCECEC6CE
CECEC6C6C6BDBDBDBDB5B5ADADADAD9C9C9C9C9C948C8C84
7B6B736363634A42213110181810215A7B526B636B42C6F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7FF6B42425252424A3942
524A526B6B8CA5ADB5B5B5BDBDBDCECEC6BDCECEC6BDCEBD
C6C6BDC6BDBDBDB5BDB5B5ADB5ADA5A5A59CA594948C8C84
7B6B6B63634A4A42312110100808424A5A52846B8C6BF7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7FF39635A424A4A424239
294A636373849CADB5B5BDBDBDCECEC6CECECEBDCEBDC6CE
BDC6C6BDC6C6BDBDBDBDADB5ADADAD9CA59C9C94948C8C84
7B73736B525242313921100821084A524A426B6B84D6F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7DE6342423939314239
4A4A5A73848C9CADB5BDBDC6BDCECEBDCEBDCEBDC6BDCEBD
C6C6BDBDBDBDC6BDBDB5B5B5ADADAD9CA59C9C948C8C8C84
847B6B6352524A42212110102110525252396B848CF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FF4A42393131423142
4A4A63737B8C9CADB5B5BDC6BDBDBDBDC6CECECECEC6C6CE
BDBDBDBDBDBDBDBDB5B5B5B5ADB5ADA5A59C9C948C8C8C84
847B6B6B634A42212118180818106352394284A5C6F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7B54A393931393942
394A6373849CA5ADB5B5BDC6C6CEC6CECECECECEC6CEBDC6
CEC6BDC6BDBDBDBDB5BDB5B5ADADADA5A59C9C9C8C8C848C
6B6B63635A524229211821181818636B42526B9CF7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F752313142423942
4252637B8494A5ADB5B5B5BDBDBDBDBDCEBDCEC6BDBDC6BD
C6C6BDBDBDC6BDBDB5B5ADB5B5ADADADA5A59C948C8C8C7B
7B736363524A39292121181818104A634A5A84CEF7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F763524242424242
4252526B8CA5A5ADB5B5BDBDBDC6C6CECEC6BDBDC6C6C6C6
BDBDC6BDBDBDBDB5B5B5ADADADA5A5ADA59C94948C8C8484
6B736B524A42312929181818100852524A638CE7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFB56352525242
42526B737B9CA5ADADB5B5B5C6C6C6C6BDBDC6CEBDC6BDBD
BDBDB5BDB5B5B5B5BDB5B5A5A5A5A59CA59C949494848484
7373635A4A3929312121181008296B524A6B94F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFE75A52424A
4A4A527B8494A5ADADB5B5BDBDB5C6C6BDBDBDBDBDBDC6BD
BDBDBDBDB5B5B5BDB5ADADADADA5AD9C9C9C9C948C7B8C7B
7B6352423942292929211818085A63425A63BDF7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FF94394A42
4A4A5A637B9CA59CADADB5ADADB5B5BDBDBDB5BDBDBDB5BD
B5B5BDB5B5B5ADADADADADA5ADA5A59C9C9C9C94948C7B84
73634A4242424221211810086B634A4263A5E7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFBD21425A
425A5A6384949CADADA5ADB5B5BDB5BDBDB5BDBDBDBDBDB5
B5BDB5ADB5ADB5ADADA5ADADA5A59C9C94949C8C947B7B6B
6B63524A4231425218101842395A4A526BA5F7F7F7FFF7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFA5523939
4A635A637B949CA5ADA5ADB5ADBDADB5B5B5B5B5B5B5BDB5
B5ADADAD9CADA5A5A5A5A5ADA5A594949C94948C847B7B6B
525242424239392931293129635263638CADF7FFF7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FF94842931
424252637B84A59CA5A59CB5B5B5B5B5ADB5B5B5BDB5B5AD
ADA59C9C9C94A5A59C9C9C949C9C8C94948C8C7B7B7B736B
525A4A424231313929216B52524A7B6B9CF7F7F7F7F7F7FF
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFF7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7DEC62129
4A39526B738C949C9C9C9CA5ADADADB5ADADADB5ADA5ADAD
9C9C8C949494948C8C8C8C848C94848C848484737B6B6363
5A5242424242524231526B5A6363849CADF7F7F7F7FFF7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7946B42
42524A52637B8C9C9CA59C9CADADADADADA5A5A5A59C9C8C
949484847B7B7B737B7B73737B6B6B6B6B6B737B736B5A4A
4A5A524A5252314A4A4A524A6363949CE7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7AD5A
424A525A6B6B737B94A5A5A5ADA5A5A59C949484949C8C84
848C7B846B6B637B636B5A735A5A6363636B6B63737B6B73
5A634A4A5A634221395A635A6394A5ADF7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFF7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E7
7B5A42525A4A7384ADB5B5B5A5A5A59C84948C8C848C8484
6B6B73736B736B526B63524A6B52635252635A634A525A52
5A525A523942524A525A5A6BA5A584F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
7B6B63637394948C9C949CADAD9C948C848C7B8484846B84
7B6B636B527B637B6363635A4A7B5A6B635A6B734A525A63
525A63424A424A42526384A5948CC6F7F7F7F7FFF7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
FF5A7363526B73738C9CA594948C8C848484737B737B737B
6B7B5A526B426B5A7352635A636B4A52526B5A5252424231
424A39394242424A6B84AD8C8C63F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7FF7B6B63948494A5A5A5A5848484847B847B7B6B6B7B63
5A63426B6B4A316342635A6363424A5A2931394242423942
4A424239394A947B8CAD4A8C6BCEFFF7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F79C734A634A6B9CA59CA5947B7B737B7B736B73736363
634A6B5A4A7B4A42634A4A52424231293939393942424239
3142526363847B9CA56B5A8C6BF7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFF7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7FF4A6B8C6B6B7B9CA58C94636B6B7B7B6B636B636373
636342525A4A5A424A42424A424239393931293942393131
4A5A5A5A5A84A563636B947BE7F7F7F7F7F7F7F7F7F7F7FF
F7F7F7F7FFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F76B317B8C8C7BA5A59C5A736363635A5A6B6B5A63
5A63425A4A5242315A424242423131312129292929314A42
4A6B847BA5A58C73528452E7FFFFF7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7FF6B2963737BA5AD9C5A527B63737B63526B5A4A
63634A525A5A522131425A3939213929212129212131426B
7B6B7BA57B4A6B636B4A9CF7F7F7F7F7F7F7F7FFF7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFF7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7CE5A424A738C9CA56B525A735A5A63524A635A
5252635A4A5A52524A31314A393942314A3131314A526363
84B57B8C6B315A6B7B7BF7F7F7F7F7F7FFF7F7F7F7F7F7F7
FFF7F7F7F7F7F7F7F7FFF7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7B56B5A524A7384A54A5263635A524242424A
4A525A4A4A5A6B525A425A39315A524A424A5A6384737BA5
8C8C73734263736B6BFFF7FFFFF7F7FFF7FFF7F7F7FFF7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFF7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7FFF7F7F7F7AD5A63636B7B849452526B6B526B394242
4A5252396B5273636B7B524242525263636363848494636B
6B422939636B637BFFF7F7F7FFFFF7F7FFF7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7B55263737B8C949C5A6B4A735A635239
42314A4263527B73B5B5A5849C8C8C8CADAD94A573526352
42424A637B636BFFF7F7FFF7F7F7F7F7F7F7F7F7F7FFFFF7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7FFF7F7F77B635273A5A5947373737B6B7B94
6B4252425A7B948C7BADB5ADB5C6C6AD847B7B73635A5242
395A637B637BF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7FFF7F7F7FF6B52737B9CC69C9CB5ADBDB59C
C6C6E7DEC6C6BDADBDB5B5B5BDA5739473636B6B4A524A63
736B6B63FFF7F7FFF7F7F7F7F7F7F7F7F7F7F7F7F7FFF7F7
F7F7F7F7F7FFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFF7F7F7
F7F7F7F7F7F7FFF7F7F7F7F7DE52637B9CB5BDCEC6BDBDBD
CEB5B5BDB5C6CECEBDC6A594AD8C8C945A5A4A526B738C84
736B9CF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFF7F7FFF7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7FFF7FFFFF7FFF7F7FFE7737384A5A5B5B5BDCECE
CECEDED6D6CECEC6BDB5BD8C8494636B5A73527B8C848C7B
84DEF7F7F7F7F7F7F7FFF7FFF7F7F7F7F7F7F7F7F7F7F7F7
FFF7F7F7F7F7F7F7FFF7F7F7F7FFF7F7F7F7FFF7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7FFF7F78C6B73B5C6CECEC6
C6C6D6C6C6B59C8C7B949C8C7B526B8C7B9C9CA59C849CF7
F7F7F7F7F7F7FFF7F7F7F7F7F7F7FFF7FFF7F7F7F7F7FFF7
F7F7F7F7FFF7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7F7F7
F7F7FFF7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFF7F7F7F7
F7F7F7F7F7F7F7F7F7F7FFF7F7FFF7F7F7F7F7948CB5B5B5
D6D6CED6D6CEB5B59C9C8CA5BD94B5C6B5947BADE7FFFFFF
F7F7F7FFF7F7F7F7F7FFF7F7F7F7F7F7F7F7F7F7F7F7F7F7
FFF7FFFFFFFFFFF7F7F7F7F7FFF7F7F7FFFFF7FFF7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFF7FFF7F7AD9CB5
9CADC6C6D6D6DEE7DECEBDCEC6BD9C8CA5BDE7F7F7FFFFF7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7FFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFF7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFF7F7F7F7F7F7F7
F7E7E7DEE7DEBDB5B5BDC6C6C6CEE7F7F7F7F7F7F7FFFFF7
FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFF7F7F7F7FF
F7F7F7F7F7F7F7F7F7FFF7FFF7F7F7F7F7F7F7F7FFF7F7F7
F7F7F7F7FFF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7FFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
FFF7F7F7F7F7F7F7F7F7FFF7F7F7F7F7F7FFFFF7F7F7FFF7
F7F7F7F7F7FFF7F7FFF7F7F7FFF7FFF7FFF7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7FFF7F7F7F7FFF7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFF7F7F7F7F7F7
F7F7FFF7F7F7F7F7F7F7FFF7F7F7F7F7F7F7F7F7FFF7FFF7
F7F7F7FFF7FFFFF7F7F7F7F7F7F7F7F7FFF7F7F7F7F7F7F7
F7F7F7F7F7FFF7F7F7F7F7F7FFF7F7F7F7F7FFFFF7F7F7F7
F7F7F7F7FFF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFF7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFF7F7F7F7F7F7FF
F7F7F7FFF7F7FFF7F7F7F7F7F7F7F7F7F7F7F7FFF7F7FFFF
F7F7F7F7F7F7F7F7FFF7F7F7F7FFF7F7F7F7F7F7F7F7F7FF
F7F7F7F7F7FFF7F7FFF7F7F7F7F7F7F7F7F7F7FFF7F7F7F7
F7F7F7F7F7F7FFF7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFF7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7FFF7F7F7F7F7F7F7F7F7FFF7
F7F7F7FFF7F7F7FFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FF
F7F7F7F7FFF7F7F7F7FFFFF7F7F7FFF7F7F7F7FFF7F7F7FF
F7F7F7FFF7F7FFF7F7FFFFF7F7FFF7F7F7F7F7F7F7F7F7F7
F7F7FFF7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFF7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7FFF7F7FFF7F7F7F7FFF7FFF7F7F7F7F7F7F7F7FFF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFF7FFF7F7FF
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7FFF7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7FFFFF7F7FFF7F7F7F7F7F7FFF7F7F7F7F7FFF7F7
FFF7FFF7F7FFF7FFF7F7F7F7F7FFF7F7F7F7F7F7F7FFF7F7
F7FFF7F7F7FFF7FFF7F7FFF7F7F7F7F7F7FFF7F7FFF7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFF7
F7F7F7F7F7F7F7F7F7F7F7FFF7F7F7F7F7F7F7F7F7F7F7FF
F7F7F7F7F7F7F7F7FFF7F7F7F7F7F7F7F7F7F7F7F7F7FFF7
FFF7F7F7F7FFF7FFF7F7F7F7F7F7F7F7F7F7F7F7FFF7F7F7
F7F7F7F7F7F7F7FFF7F7F7F7F7F7F7FFF7F7F7F7F7F7F7F7
F7F7F7F7F7F7FFF7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7FFF7F7F7F7F7F7F7F7F7F7FFFFF7F7
F7F7F7F7F7F7F7F7F7FFF7F7FFF7F7F7F7F7FFF7FFF7F7FF
F7F7F7F7F7F7FFF7F7F7F7F7FFF7FFF7F7F7F7FFF7FFF7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7FFF7FFF7F7FFFFF7F7FFF7F7
F7F7F7F7F7F7FFFFF7F7F7F7FFF7F7F7F7F7F7FFF7F7F7F7
F7FFFFFFFFF7F7F7F7F7F7FFF7F7F7FFFFFFFFF7F7F7F7F7
F7FFFFF7F7F7F7F7F7F7F7F7F7F7FFF7F7F7F7FFF7F7F7F7
FFF7FFF7F7FFF7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFF7FFF7F7F7
F7F7F7F7F7F7F7FFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7FFF7F7F7F7FFF7F7FFFFF7F7F7F7F7
F7F7F7F7F7F7FFF7F7F7F7F7F7F7F7F7F7F7F7FFF7FFF7F7
F7F7FFF7F7F7FFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFF7F7FFF7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFF7FFF7F7
F7F7F7F7F7F7F7F7FFFFF7F7F7F7F7F7FFFFF7F7F7F7F7F7
F7F7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7FFF7F7F7F7F7F7FFF7F7FF
F7F7F7F7F7F7F7F7
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[9]:=",
  ImageSize->{450, 150},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000720000UR000`400?l00000o`00003oo`3oooo3
0?ooo`00o`3oooo30?ooo`00o`3oooo30?ooo`00o`3oooo30?ooo`00o`3oooo30?ooo`00o`3oooo3
0?ooo`00o`3oooo30?ooo`008@3oool01@3UiND0l_;b0?;blP3UiND0l_;b00<0iNGU00<0l_;b0>GU
i@3UiND01P3UiND20?;blP030:2PX03GemL0iNGU0080emOG0P3UiND0103GemL0iNGU0>GUi@3UiND2
0=OGe`/0iNGU1P3bl_801@3UiND0l_;b0>GUi@3UiND0l_;b00T0iNGU00<0emOG0>GUi@3UiND00`3U
iND30?;blP040:j^[P3GemL0iNGU0>GUi@P0emOG0`3UiND40?;blP040>GUi@3bl_80iNGU0=OGe`80
^k^k0P3GemL01@2k^k/0iNGU0=OGe`38b<P0emOG0080l_;b00<0iNGU0?ooo`3oool07@3oool20>o_
k`030?Ogm`3_knl0kno_00@0kno_0`3>c/h00`3Fe]H0c/k>0<k>cP020<k>cP030>o_k`3WinL0Q8B4
00<0a/K600<0_Kfm0<K6aP36a/H01036a/H00`2m_Kd0a/K60<K6aP020<k>cPP0a/K61`3>c/h30<K6
aP030<k>cP36a/H0a/K600d0a/K600<0kno_0=kNgP2DU9@00P2m_Kd01036a/H0_Kfm0;fm_@2m_Kd5
0<K6aP050<k>cP36a/H0c/k>0=KFeP3>c/h00P3Fe]H0103>c/h0e]KF0<k>cP36a/H50;fm_@80g]kN
00D0[Jf]0<k>cP3_knl0moOg0>o_k`0O0?ooo`040?Ogm`3WinL0moOg0?Ogm`D0inOW0`2e]KD00`36
a/H0_Kfm0;fm_@020;fm_@060>OWi`3Ng]h0Jf][0:f][@2m_Kd0[Jf]0`2UYJD0102LW9`0[Jf]0:FU
Y@2][Jd30:FUY@@0[Jf]0P2UYJD0102][Jd0W9bL0:f][@2][Jd60;Fe]@050:f][@2e]KD0[Jf]0:f]
[@2e]KD0102][Jd40:FUY@@0[Jf]00L0YJFU0:f][@2UYJD0c/k>0>OWi`3>c/h0Jf][00D0YJFU1`2]
[Jd0102e]KD0[Jf]0;fm_@2e]KD40;fm_@040;Fe]@2][Jd0[Jf]0:f][@80YJFU00D0[Jf]0<k>cP3N
g]h0S8b<0;fm_@030?Ogmb<0oooo000Q0?ooo`030>GUi@3bl_80iNGU00<0l_;b00<0iNGU0?;blP3b
l_802@3UiND0103bl_80^k^k0>GUi@3UiND50=OGe`h0iNGU00<0emOG0>GUi@3UiND00P3UiND00`3b
l_80iNGU0?;blP020>GUi@030?;blP3UiND0iNGU0080iNGU00<0l_;b0>GUi@3UiND01@3UiND20=OG
e`@0iNGU0P3bl_80102k^k/0iNGU0>GUi@3UiND40=OGe`/0iNGU00<0l_;b0>GUi@3UiND01@3GemL2
0>GUi@<0emOG00<0l_;b0>GUi@3bl_807`3oool40>o_k`80moOg00@0kno_0?Ogm`3_knl0kno_203>
c/h00`3WinL0YJFU0<K6aP030<K6aP<0_Kfm1036a/H00`2m_Kd0a/K60<k>cP030<K6aP040;Fe]@2m
_Kd0a/K60;fm_@L0a/K600<0c/k>0<K6aP3>c/h04P36a/H0103Ng]h0kno_0:f][@24Q8@20<K6aP@0
_Kfm1036a/H20<k>cP030<K6aP3>c/h0c/k>0080c/k>00<0e]KF0<k>cP3>c/h00`36a/H20;fm_@80
inOW0`2m_Kd30>o_kal0oooo0P3gmoL20>OWi`@0moOg0P3WinL60;fm_@80]KFe00@0g]kN08b<S02]
[Jd0]KFe0P2][Jd40:FUY@060:f][@2UYJD0[Jf]0:FUY@2LW9`0]KFe0P2][Jd20:FUY@0309bLW02U
YJD0YJFU00<0YJFU0P2][Jd00`2e]KD0[Jf]0;Fe]@020:f][@030;Fe]@2][Jd0[Jf]0080[Jf]00@0
]KFe0:f][@2UYJD0YJFU1@2][Jd0202UYJD0[Jf]0:f][@2][Jd0YJFU0<k>cP3WinL0Q8B4202UYJD4
0:f][@040;Fe]@2][Jd0]KFe0;Fe]@D0_Kfm00<0]KFe0:f][@2][Jd00P2UYJD01@3Ng]h0inOW09bL
W02DU9@0YJFU0080moOg00<0inOW0?ooo`3oool08@3oool00240oooo0P3UiND01P3bl_80iNGU0>GU
i@3UiND0l_;b0>GUi@<0l_;b0`3UiND0103bl_80iNGU0>GUi@3UiND20?;blP030:2PX03GemL0emOG
00<0emOG1P3UiND00`3GemL0iNGU0>GUi@030>GUi@D0emOG2P3UiND20?;blP030>GUi@3bl_80l_;b
00h0iNGU00<0l_;b0:2PX03GemL00P3GemL0103UiND0emOG0=OGe`3UiND20=OGe`L0iNGU00<0l_;b
0>GUi@3UiND00P3GemL00`3UiND0emOG0=OGe`020=OGe`050>GUi@3GemL0emOG0=OGe`3UiND00P3b
l_8O0?ooo`P0kno_0P3gmoL02`3_knl0c/k>0<k>cP3>c/h0a/K60<k>cP36a/H0c/k>0=kNgP3WinL0
Ng]k0080a/K600<0_Kfm0;Fe]@2m_Kd01@36a/H01@2m_Kd0]KFe0<k>cP3>c/h0a/K600@0_Kfm0P2e
]KD0102m_Kd0a/K60<K6aP3>c/h60<K6aP<0c/k>00<0a/K60<k>cP36a/H03036a/H0103>c/h0kno_
0=kNgP24Q8@20;fm_@80a/K600D0_Kfm0<K6aP2m_Kd0_Kfm0<K6aP060<k>cP80e]KF0P3>c/h40<K6
aP040<k>cP3Fe]H0inOW0=KFeP80_Kfm00<0kno_0?Ogm`3_knl07`3oool30>OWi`<0moOg00<0inOW
0?Ogm`3gmoL00P3gmoL00`2m_Kd0]KFe0;Fe]@040;Fe]@070=KFeP3Ng]h0BTY:0:f][@2e]KD0YJFU
09bLW0030:FUY@030:f][@2UYJD0[Jf]0080YJFU0`2][Jd00`2UYJD0W9bL09bLW00409bLW0030:FU
Y@2][Jd0[Jf]00@0[Jf]00<0YJFU0:f][@2][Jd00P2e]KD00`2][Jd0]KFe0;Fe]@060:f][@030:FU
Y@2][Jd0[Jf]00<0[Jf]00@0YJFU0;fm_@3WinL0Hf=S2@2UYJD20:f][@070;Fe]@2][Jd0]KFe0;Fe
]@36a/H0_Kfm0<K6aP020;fm_@@0[Jf]00T0_Kfm0<K6aP3Ng]h0a/K609bLW02UYJD0inOW0?Ogm`3W
inL08`3oool00240oooo00<0iNGU0?;blP3bl_800`3bl_800`3UiND0l_;b0?;blP050?;blP040>GU
i@3bl_80iNGU0>GUi@<0l_;b00<0b<S80>GUi@3GemL01@3GemL>0>GUi@80emOG203UiND00`3bl_80
iNGU0>GUi@060?;blP/0iNGU00<0l_;b0<S8b03GemL02@3UiND0103bl_80iNGU0>GUi@3bl_850>GU
i@030=OGe`3UiND0iNGU00<0iNGU00@0emOG0?;blP3GemL0emOG0P3bl_800`3UiND0oooo0?ooo`0M
0?ooo`<0kno_00@0moOg0>o_k`3_knl0kno_0`3gmoL0103_knl0moOg0>o_k`3Fe]H30<k>cP040<K6
aP3>c/h0inOW0>OWi`80a/K600@0c/k>0;fm_@2m_Kd0a/K60P2m_Kd60<K6aP80_Kfm1036a/H0102m
_Kd0]KFe0;fm_@2m_Kd30;Fe]@D0a/K600H0c/k>0<K6aP3Fe]H0e]KF0<K6aP3>c/h30<K6aP80c/k>
00@0a/K60<k>cP3>c/h0c/k>1036a/H0103>c/h0kno_0:f][@36a/H30<k>cP80a/K61`3>c/h30=KF
eP80c/k>00<0a/K60=KFeP3_knl00P3WinL00`3_knl0c/k>0=kNgP020;fm_@030?Ogm`3_knl0kno_
01l0oooo2P3gmoL0103WinL0moOg0>OWi`2m_Kd20;Fe]@80[Jf]00H0]KFe0=kNgP3Ng]h0W9bL0;Fe
]@2m_Kd70:FUY@040:f][@2UYJD0[Jf]0:FUY@<0W9bL102UYJD209bLW080YJFU0P2LW9`00`2UYJD0
[Jf]0:f][@020:f][@030;Fe]@2][Jd0[Jf]0080_Kfm102e]KD00`2][Jd0]KFe0;Fe]@030;Fe]@03
0:f][@2e]KD0[Jf]0080[Jf]00<0inOW08b<S02LW9`01`2][Jd60;Fe]@<0a/K60P2m_Kd0202e]KD0
a/K60>OWi`3WinL0g]kN0>OWi`2m_Kd0e]KF0P2LW9`00`3gmoL0inOW0>OWi`0S0?ooo`008@3oool0
103UiND0l_;b0?;blP3UiND50?;blP030>GUi@3bl_80l_;b0080l_;b0P3UiND01@3bl_80iNGU0>GU
i@3UiND0l_;b00<0iNGU0`3GemL0103UiND0emOG0>GUi@3UiND40=OGe`80iNGU00<0emOG0>GUi@3U
iND0103UiND20=OGe`030>GUi@3GemL0emOG00D0iNGU0`3bl_840>GUi@030?;blP3UiND0iNGU00X0
iNGU00<0l_;b0=OGe`3GemL01P3UiND30?;blP030>GUi@3bl_80iNGU00@0iNGU0`3GemL0103UiND0
l_;b0=OGe`3GemL20>GUi@80emOG0P3bl_800`3UiND0oooo0?ooo`0M0?ooo`H0kno_00@0moOg0>o_
k`3_knl0kno_0`3gmoL00`3_knl0g]kN0<k>cP040<k>cP040>OWi`36a/H0c/k>0<k>cP80a/K600<0
_Kfm0<K6aP36a/H00P36a/H0102m_Kd0a/K60;fm_@2e]KD20;fm_@H0a/K60P2e]KD0102m_Kd0]KFe
0<K6aP2m_Kd60<K6aP030<k>cP36a/H0c/k>00L0c/k>00<0a/K60<k>cP36a/H00P36a/H01`3>c/h0
a/K60<K6aP3>c/h0_Kfm0:f][@36a/H00P3>c/h00`36a/H0c/k>0<k>cP070<k>cP80e]KF00H0c/k>
0<K6aP2m_Kd0e]KF0>OWi`3_knl20<K6aP040<k>cP3WinL0_Kfm0=KFeP<0kno_7`3oool40?Ogm`03
0>OWi`3gmoL0moOg0080moOg00<0inOW0?Ogm`3gmoL00P3gmoL00`3>c/h0]KFe0;Fe]@020;Fe]@03
0;fm_@3Ng]h0g]kN00<0]KFe00<0[Jf]0:FUY@2UYJD00`2][Jd30:FUY@@0W9bL0P2UYJD00`2][Jd0
YJFU0:f][@0509bLW080YJFU102][Jd30;Fe]@030:f][@2e]KD0]KFe00@0]KFe00<0_Kfm0;Fe]@2e
]KD00`2e]KD30:f][@080;fm_@3WinL0YJFU09bLW02][Jd0]KFe0:f][@2e]KD20:f][@D0]KFe00X0
_Kfm0<K6aP36a/H0a/K60;fm_@2e]KD0W9bL0<k>cP3Ng]h0inOW0P2][Jd0102m_Kd0inOW0:FUY@3>
c/h20?Ogm`030>OWi`3oool0oooo0240oooo000Q0?ooo`060>GUi@3bl_80l_;b0>GUi@3bl_80iNGU
0P3bl_80103UiND0l_;b0?;blP3UiND40?;blP030>GUi@3bl_80iNGU00<0l_;b0`3UiND=0=OGe`L0
iNGU00<0emOG0>GUi@3GemL00`3GemLD0>GUi@040=OGe`3UiND0emOG0>GUi@80l_;b00<0emOG0>GU
i@3UiND00P3UiND20?;blP040>GUi@3bl_80iNGU0?;blP<0iNGU0P3GemL01`38b<P0emOG0>GUi@3G
emL0iNGU0=OGe`3UiND00`3GemL0103UiND0l_;b0?;blP3UiNDO0?ooo`050>o_k`3gmoL0moOg0>o_
k`3gmoL00P3_knl01@3gmoL0kno_0?Ogm`3gmoL0kno_00<0moOg00<0kno_0=KFeP3Fe]H0103Fe]H0
1@36a/H0c/k>0<k>cP3>c/h0a/K600@0_Kfm00<0]KFe0:f][@2e]KD00`2e]KD20<K6aP@0c/k>0P36
a/H30;fm_@030;Fe]@2m_Kd0]KFe00/0a/K60P3>c/h:0<K6aP030>o_k`3Ng]h0a/K600<0a/K600<0
c/k>0<K6aP3>c/h00`3>c/h0103Fe]H0c/k>0=KFeP3Fe]H20<K6aP060:f][@2m_Kd0inOW0=kNgP3_
knl0a/K60`3>c/h01@2m_Kd0inOW0>o_k`3gmoL0kno_01l0oooo0`3gmoL00`3WinL0moOg0>OWi`02
0?Ogm`030>OWi`3gmoL0moOg00@0moOg00@0inOW0<K6aP2m_Kd0a/K60P2m_Kd00`3WinL0]KFe0;fm
_@020;fm_@030;Fe]@2UYJD0YJFU0080W9bL00<0YJFU09BDU02DU9@00P2DU9@00`2LW9`0U9BD0:f]
[@040:f][@80YJFU1@2LW9`00`2UYJD0W9bL0:FUY@070:f][@030;Fe]@2][Jd0[Jf]00@0]KFe1`2]
[Jd00`36a/H0inOW0<k>cP030:f][@030:FUY@2][Jd0]KFe00@0]KFe0P2m_Kd20<K6aP070;Fe]@2]
[Jd0W9bL0:FUY@3WinL0e]KF0>OWi`020;Fe]@80_Kfm00<0U9BD0>OWi`3WinL00P3gmoLS0?ooo`00
8@3oool00`3UiND0l_;b0?;blP040?;blP@0iNGU1@3bl_80103UiND0l_;b0?;blP3bl_830>GUi@04
096AT@3UiND0iNGU0>GUi@@0emOG0P38b<P50=OGe`P0iNGU2P3GemL01`3UiND0emOG0>GUi@3GemL0
iNGU0=OGe`3UiND00P3GemL20>GUi@T0emOG00<0l_;b0=OGe`3UiND01`3UiND20?;blP80iNGU0P3G
emL20;^k^`<0emOG00<0b<S80=OGe`3GemL00`3GemL20>GUi@030?;blP3UiND0oooo01h0oooo103_
knl00`3gmoL0kno_0?Ogm`040>o_k`@0moOg00<0kno_0=kNgP3Ng]h00`3Ng]h01@3_knl0e]KF09BD
U03>c/h0a/K600D0_Kfm00<0[Jf]0;Fe]@2e]KD00`2e]KD00`2m_Kd0a/K60<K6aP030<k>cP80a/K6
102e]KD0102m_Kd0]KFe0;Fe]@2e]KD20;fm_@030<K6aP2m_Kd0_Kfm00<0_Kfm0P36a/H00`2m_Kd0
a/K60<K6aP060;fm_@040<K6aP2m_Kd0e]KF0>OWi`H0a/K60`3>c/h20=KFeP80c/k>00P0a/K60;fm
_@2LW9`0[Jf]0<K6aP3Fe]H0a/K60:f][@80_Kfm00@0e]KF0<K6aP2m_Kd0inOW0`3_knlO0?ooo`03
0?Ogm`3WinL0moOg00D0moOg00<0inOW0?Ogm`3gmoL01P3gmoL50<k>cP050<K6aP1kNg/0_Kfm0;Fe
]@2][Jd00`2UYJD00`2LW9`0U9BD09BDU00509BDU0030:FUY@2][Jd0[Jf]00@0[Jf]0P2LW9`0102D
U9@0W9bL0:FUY@2LW9`209BDU0D0YJFU00<0W9bL0:FUY@2UYJD00`2UYJD00`2][Jd0YJFU0:FUY@08
0:FUY@040=KFeP3Ng]h0]KFe0:FUY@@0[Jf]0`2e]KD40;fm_@0>0:f][@2UYJD0Ng]k08B4Q02][Jd0
c/k>0:f][@2<S8`0YJFU09BDU03>c/h0]KFe09bLW03Ng]h20>OWi`030?Ogm`3oool0oooo0240oooo
000Q0?ooo`030>GUi@3bl_80l_;b0080l_;b00<0iNGU0?;blP3bl_800P3bl_820>GUi@<0l_;b00<0
iNGU0?;blP3bl_801P3bl_800`2k^k/0emOG0>GUi@050=OGe`030;^k^`3GemL0iNGU00P0iNGU00<0
l_;b0>GUi@3UiND01@3UiND30=OGe`l0b<S81`3GemL00`38b<P0emOG0;^k^`020<S8b080emOG1P3U
iND01P3GemL0[Zj^0;^k^`38b<P0[Zj^0<S8b0P0emOG00@0iNGU0?;blP3UiND0iNGU7`3oool00`3_
knl0moOg0?Ogm`020?Ogm`<0kno_00<0moOg0>o_k`3_knl00P3_knl20?Ogm`80kno_00@0moOg0>o_
k`3_knl0moOg0`3_knl00`2m_Kd0a/K60<K6aP030;fm_@80]KFe0`2m_Kd01@36a/H0_Kfm0;Fe]@2m
_Kd0a/K600D0c/k>00@0]KFe0;fm_@36a/H0]KFe0`2m_Kd20;Fe]@80[Jf]00D0YJFU0:f][@2][Jd0
[Jf]0:FUY@080:f][@070;Fe]@2m_Kd0_Kfm0;fm_@2e]KD0_Kfm0:f][@020<k>cP80[Jf]0P2m_Kd2
0<K6aP<0c/k>00L0e]KF0<k>cP2DU9@0W9bL0:f][@2e]KD0[Jf]0080a/K60P2m_Kd01@3Ng]h0c/k>
0;fm_@3Fe]H0inOW00<0kno_7`3oool60?Ogm`030>OWi`3gmoL0moOg0080moOg00<0inOW0?Ogm`3g
moL02@3gmoL0103WinL0[Jf]0:f][@2][Jd30:FUY@80W9bL00<0YJFU09bLW02LW9`00P2UYJD209bL
W0080:FUY@2][Jd0[Jf]0:f][@2e]KD0[Jf]0:FUY@2DU9@409bLW080YJFU00D0U9BD08b<S02DU9@0
S8b<08B4Q00308b<S00308B4Q02<S8`0U9BD00D0U9BD1@2LW9`01`2DU9@0W9bL09BDU036a/H0S8b<
07=cL`2DU9@00P2UYJD20:f][@0D0;Fe]@2m_Kd0_Kfm0<K6aP2e]KD0Hf=S07=cL`2<S8`0YJFU08b<
S02e]KD0[Jf]0:FUY@2DU9@0e]KF0;fm_@2LW9`0e]KF0=kNgP3gmoL20>OWib<0oooo000Q0?ooo`<0
iNGU00<0l_;b0>GUi@3UiND00P3bl_800`3UiND0l_;b0?;blP070?;blP030>GUi@3bl_80l_;b0080
iNGU0P3bl_80103GemL0^k^k0:j^[P38b<P40=OGe`030;^k^`3GemL0emOG0080iNGU00<0emOG0>GU
i@3UiND04P3UiND20=OGe`H0iNGU00<0emOG0>GUi@3UiND02P3UiND02P3GemL0b<S80=OGe`2k^k/0
TI6A0;^k^`2ATI40X:2P0:j^[P2PX:020;^k^`030=OGe`38b<P0iNGU0080emOG0P38b<P0103UiND0
emOG0=OGe`3GemL30>GUi@030?;blP3oool0oooo01d0oooo1`3_knl00`3gmoL0kno_0>o_k`020?Og
m`80kno_00@0moOg0>o_k`3_knl0moOg0`3_knl01@3gmoL0kno_0>o_k`3_knl0_Kfm00<0[Jf]102m
_Kd20;Fe]@80_Kfm00<0]KFe0;fm_@36a/H00P36a/H30<k>cP030<K6aP2m_Kd0_Kfm00H0a/K600<0
_Kfm0<K6aP36a/H00P36a/H30;fm_@80a/K60`2m_Kd40<K6aP030;fm_@36a/H0_Kfm00<0a/K600`0
_Kfm0<K6aP3>c/h0c/k>0=KFeP2][Jd0U9BD0:FUY@2<S8`0Ng]k08b<S01kNg/209bLW0030;fm_@2]
[Jd0inOW0080_Kfm00H0a/K60:FUY@3Ng]h0_Kfm0=kNgP36a/H30>o_k`030?Ogm`3oool0oooo01d0
oooo00D0inOW0?Ogm`3gmoL0moOg0>OWi`030?Ogm`030>OWi`3gmoL0moOg00h0moOg00<0W9bL07=c
L`2DU9@01@2LW9`00`2UYJD0U9BD09bLW00209bLW00409BDU02UYJD0[Jf]0:FUY@@0[Jf]00<0YJFU
09bLW02UYJD01@2UYJD209bLW0@0YJFU0`2LW9`0102UYJD0W9bL09bLW02LW9`50:FUY@80W9bL0P2U
YJD0102][Jd0YJFU0:f][@2UYJD20;fm_@060=KFeP2<S8`0Ng]k08B4Q01SHf<0BTY:0P1JFUX207=c
L`80U9BD00T0g]kN09BDU02DU9@0]KFe07]kN`3>c/h0W9bL0=KFeP2e]KD00`3WinL00`3gmoL0oooo
0?ooo`0Q0?ooo`008@3oool0103bl_80iNGU0?;blP3UiND20?;blP030>GUi@3bl_80l_;b0080l_;b
0P3UiND30?;blP040>GUi@3bl_80l_;b0?;blP<0iNGU00@0l_;b0>GUi@3GemL0emOG0P2k^k/01@2^
[Zh0emOG0=OGe`3GemL0b<S800<0emOG00<0iNGU0=OGe`3UiND05@3UiND00`3GemL0iNGU0>GUi@09
0>GUi@030=OGe`3UiND0emOG00<0iNGU1@3GemL00`2k^k/0MWIf07IfMP020:2PX0D0[Zj^00D0emOG
0;^k^`38b<P0emOG0<S8b0020=OGe`D0iNGU00<0l_;b0?ooo`3oool07@3oool0103gmoL0kno_0?Og
m`3_knl20?Ogm`80kno_00<0moOg0>o_k`3gmoL0103_knl50?Ogm`D0kno_00T0a/K609BDU02][Jd0
[Jf]09BDU02m_Kd0]KFe0;fm_@2][Jd01@2m_Kd40<K6aP040<k>cP36a/H0a/K60<K6aP80_Kfm1P36
a/H00`2e]KD0_Kfm0;fm_@020<K6aP<0_Kfm00@0]KFe0;fm_@36a/H0]KFe0`36a/H20;fm_@030<K6
aP2m_Kd0_Kfm00@0a/K60P2m_Kd30<k>cP0506=SH`1[Jf/0Q8B407]kN`24Q8@00`2DU9@02P2][Jd0
g]kN09bLW02][Jd0a/K60:FUY@3Fe]H0_Kfm0>o_k`3WinL30>o_k`030?Ogm`3oool0oooo01d0oooo
1P3gmoL20>OWi`h0moOg00D0inOW0?Ogm`3WinL0]KFe0:f][@0208B4Q00306][J`2LW9`0YJFU0080
W9bL00D0U9BD09bLW02DU9@0W9bL09BDU0030:FUY@80[Jf]00D0YJFU0:f][@2UYJD0YJFU09bLW007
0:FUY@80W9bL0`2UYJD409bLW080YJFU00@0W9bL0:FUY@2UYJD0YJFU0P2LW9`20:FUY@0309bLW02U
YJD0YJFU00@0YJFU00L0_Kfm0<K6aP2][Jd0<C4a03Ti>@1JFUX0BTY:0080Hf=S00d0Jf][06=SH`2D
U9@0e]KF07=cL`24Q8@0[Jf]07]kN`36a/H0U9BD0>OWi`3Ng]h0inOW00<0moOg8`3oool00240oooo
00@0iNGU0?;blP3UiND0iNGU103bl_800`3UiND0l_;b0?;blP090?;blPD0iNGU0P3GemL01@2^[Zh0
^k^k0:2PX01fMWH0b<S800D0emOG00<0iNGU0=OGe`3UiND05P3UiND0103GemL0iNGU0>GUi@3UiND2
0=OGe`X0iNGU0`3GemL01038b<P0^k^k0;^k^`24Q8@20:2PX00308B4Q02PX:00[Zj^0080[Zj^0P38
b<P01@3GemL0b<S80<S8b03GemL0b<S80080emOG0P3UiND40?;blQl0oooo00H0kno_0?Ogm`3_knl0
kno_0?Ogm`3_knl20?Ogm`040>o_k`3gmoL0moOg0>o_k`@0moOg00<0kno_0?Ogm`3gmoL01P3_knl0
1`3>c/h0[Jf]09BDU02][Jd0Ng]k06][J`2m_Kd00P2e]KD01@2m_Kd0]KFe0;Fe]@2e]KD0_Kfm00@0
a/K600<0c/k>0<K6aP36a/H02@36a/H30;fm_@050<K6aP2m_Kd0a/K60;fm_@2e]KD0102m_Kd30<K6
aP030;Fe]@36a/H0a/K60080_Kfm0P36a/H30;fm_@030:f][@2UYJD0W9bL00D0Ng]k0`2DU9@20:f]
[@080<K6aP2UYJD0[Jf]0;fm_@2][Jd0a/K60<k>cP3WinL20>o_k`80moOg00<0kno_0?ooo`3oool0
7@3oool50?Ogm`030>OWi`3gmoL0moOg00P0moOg00<0inOW0?Ogm`3gmoL01P3gmoL01P36a/H0]KFe
06=SH`24Q8@0@T9203Ti>@H0W9bL00<0U9BD09bLW02UYJD00`2UYJD00`2][Jd0YJFU0:FUY@060:FU
Y@040:f][@2UYJD0YJFU0:FUY@80W9bL00@0YJFU09bLW02LW9`0YJFU1@2LW9`01P2UYJD0[Jf]0:FU
Y@2UYJD0W9bL0:FUY@<0W9bL102UYJD0302LW9`0U9BD08B4Q01kNg/0@T9204Y:BP12@T80FUYJ0492
@P1JFUX0Hf=S06][J`80Q8B400T0[Jf]07]kN`24Q8@0U9BD08B4Q02][Jd0_Kfm0=kNgP3WinL0103g
moLS0?ooo`008@3oool50?;blP040>GUi@3bl_80l_;b0>GUi@H0l_;b00@0iNGU0?;blP3bl_80iNGU
0P3bl_800`3UiND0l_;b0?;blP030>GUi@80[Zj^00<0X:2P08B4Q01<C4`00P3GemL20<S8b0<0emOG
5@3UiND30=OGe`<0iNGU00@0emOG0>GUi@3UiND0emOG103UiND01@3GemL0iNGU0>GUi@3UiND0emOG
0080b<S800@0^k^k0:j^[P24Q8@0X:2P0P2^[Zh20:2PX080[Zj^1038b<P00`2k^k/0b<S80<S8b003
0=OGe`030?;blP3UiND0l_;b0080l_;b00<0iNGU0?ooo`3oool07@3oool01P3gmoL0kno_0>o_k`3_
knl0moOg0>o_k`80moOg00<0kno_0?Ogm`3_knl0103gmoL01@3_knl0moOg0?Ogm`3_knl0moOg0080
kno_00`0moOg0>o_k`3_knl0g]kN0=KFeP2<S8`0U9BD07]kN`1[Jf/0]KFe0:f][@2m_Kd20:f][@<0
_Kfm2@36a/H30;fm_@040<K6aP2m_Kd0a/K60<K6aPd0_Kfm00<0a/K60;fm_@2m_Kd00P36a/H40;fm
_@070;Fe]@2m_Kd0[Jf]09bLW02DU9@0Lg=c06][J`0208b<S00509BDU024Q8@0Ng]k09BDU02UYJD0
0`2][Jd00`2LW9`0[Jf]0:f][@020<K6aP030=KFeP3_knl0kno_00@0kno_7`3oool30?Ogm`030>OW
i`3gmoL0moOg00@0moOg00<0inOW0?Ogm`3gmoL01`3gmoL20>OWi`0:0?Ogm`3WinL0moOg0<k>cP3N
g]h0FUYJ06=SH`12@T80>CTi02TY:@80W9bL00<0U9BD09bLW02LW9`00P2LW9`40:FUY@030:f][@2U
YJD0YJFU0080YJFU102LW9`40:FUY@`0W9bL00D0YJFU09bLW02LW9`0W9bL0:FUY@0609bLW00409BD
U02<S8`0Ng]k06=SH`80BTY:0P1JFUX02@1[Jf/0FUYJ06=SH`1SHf<0Lg=c08b<S024Q8@0S8b<07=c
L`0208B4Q080[Jf]00@0a/K60?Ogm`3WinL0inOW0P3gmoL00`3WinL0oooo0?ooo`0Q0?ooo`008@3o
ool0103UiND0l_;b0?;blP3UiND50?;blP030>GUi@3bl_80iNGU0080l_;b00@0iNGU0?;blP3UiND0
iNGU1@3bl_801@3UiND0l_;b0=OGe`3bl_80[Zj^0080X:2P00<0Q8B404a<C00S8b<00P38b<P50=OG
eaP0iNGU00@0emOG0>GUi@3GemL0emOG103UiND0103GemL0iNGU0>GUi@3UiND20=OGe`80b<S80P2k
^k/01P2PX:00MWIf0:j^[P2PX:00[Zj^0;^k^`80[Zj^00D0b<S80:j^[P2k^k/0^k^k0<S8b0030=OG
e`040>GUi@3GemL0iNGU0>GUi@80l_;b00<0iNGU0?;blP3bl_807`3oool40>o_k`@0moOg0P3_knl0
0`3gmoL0kno_0?Ogm`030>o_k`030?Ogm`3_knl0moOg00H0kno_00<0e]KF0<K6aP2<S8`00P1kNg/0
0`1SHf<0>CTi0:FUY@020:f][@80_Kfm00<0]KFe0;fm_@2m_Kd00`36a/H00`2m_Kd0a/K60<K6aP05
0<K6aP<0_Kfm0`36a/H20;Fe]@<0_Kfm00<0]KFe0;fm_@2m_Kd00P2m_Kd00`2e]KD0a/K60<K6aP02
0;fm_@80a/K60P2m_Kd20;Fe]@0@0:f][@2LW9`0W9bL07]kN`1[Jf/0Q8B407]kN`2<S8`0W9bL08b<
S024Q8@0YJFU09BDU02][Jd0W9bL0:FUY@<0_Kfm00<0g]kN0<K6aP3_knl00P3_knl0103WinL0kno_
0?Ogm`3_knlO0?ooo`<0moOg00<0inOW0?Ogm`3gmoL01`3gmoL01@3WinL0moOg0?Ogm`3gmoL0inOW
0080moOg00<0inOW0?Ogm`3gmoL00P3WinL02P3>c/h0inOW05YJFP1:BTX0@T92034a<@0Y:BT061PH
08b<S02DU9@309bLW00309BDU02UYJD0YJFU0080YJFU00<0W9bL0:FUY@2UYJD0102UYJD0102LW9`0
YJFU09bLW02LW9`40:FUY@0309BDU02LW9`0W9bL00@0W9bL0P2DU9@0102LW9`0YJFU09bLW02UYJD2
09bLW0070:FUY@2LW9`0W9bL09bLW02DU9@0S8b<08B4Q00207=cL`0604Y:BP0i>CT0FUYJ04Y:BP1J
FUX0Ng]k0P1JFUX01@1cLg<0Hf=S08B4Q01cLg<0Ng]k00<0U9BD00L0c/k>0;Fe]@3WinL0inOW0?Og
m`3Ng]h0inOW0080moOg8`3oool00240oooo00@0iNGU0?;blP3UiND0l_;b0P3UiND>0?;blP80iNGU
0P3bl_80103UiND0l_;b0=OGe`2k^k/20:2PX00707IfMP1<C4`0?clo00P82038b<P0emOG0:j^[P02
0=OGea00iNGU00D0emOG0>GUi@3UiND0emOG0>GUi@080=OGe`80iNGU00<0emOG0>GUi@38b<P00P3G
emL20<S8b0040;^k^`2PX:00Q8B404a<C080MWIf00<0X:2P0:j^[P2PX:000P2k^k/00`38b<P0^k^k
0<S8b0020:j^[P80b<S8103GemL20>GUi@040=OGe`3UiND0l_;b0>GUi@80l_;b7`3oool0103_knl0
moOg0>o_k`3gmoL50>o_k`030?Ogm`3_knl0moOg0080moOg00D0kno_0?Ogm`3_knl0kno_0?Ogm`07
0>o_k`0<0=kNgP2][Jd0Q8B407]kN`1SHf<0@T9203Ti>@0a<C40[Jf]0;Fe]@2m_Kd0]KFe1P2m_Kd0
0`36a/H0_Kfm0<K6aP020;fm_@030<K6aP2m_Kd0]KFe00<0_Kfm00<0a/K60;fm_@2e]KD01@2e]KD0
0`2m_Kd0]KFe0:f][@020:f][@060;Fe]@2][Jd0_Kfm0:f][@2m_Kd0]KFe0P2UYJD02@2LW9`0U9BD
08B4Q01BDU80FUYJ06=SH`24Q8@0U9BD08b<S00209bLW0070:FUY@2LW9`0YJFU08b<S02DU9@0YJFU
0:f][@030;fm_@050<K6aP3WinL0inOW0=kNgP3WinL00P3_knl20?Ogmal0oooo00<0inOW0?Ogm`3g
moL03P3gmoL0103WinL0moOg0?Ogm`3gmoL20>OWi`0=0?Ogm`3WinL0inOW0=KFeP24Q8@0FUYJ04Y:
BP0a<C40:BTY024Q8@0H61P0S8b<09bLW00309BDU00309bLW02UYJD0W9bL0080W9bL00H0YJFU09bL
W02LW9`0YJFU09bLW02UYJD209bLW00609BDU02LW9`0W9bL09bLW02UYJD0W9bL202DU9@208b<S007
09BDU02LW9`0S8b<09bLW024Q8@0U9BD08b<S00207]kN`0407=cL`1JFUX0BTY:02TY:@80<C4a00<0
FUYJ06=SH`1SHf<01@1cLg<0301JFUX0Hf=S07]kN`24Q8@0U9BD0:FUY@2LW9`0[Jf]0=kNgP3WinL0
e]KF0>OWi`@0moOg8`3oool00240oooo00D0l_;b0>GUi@3bl_80l_;b0>GUi@030?;blP030>GUi@3b
l_80l_;b0080l_;b0P3UiND50?;blP80iNGU0P3bl_820>GUi@050=OGe`2^[Zh0X:2P0:2PX01fMWH0
0P1<C4`00`0820P000000;^k^`020<S8b0<0emOG2@3UiND01@3GemL0iNGU0>GUi@3UiND0emOG00<0
iNGU00@0emOG0>GUi@3GemL0iNGU0P3GemL0103UiND0emOG0=OGe`3UiND30=OGe`030<S8b03GemL0
b<S80080b<S800d0^k^k0:j^[P1fMWH0MWIf05YJFP1fMWH0TI6A0:j^[P2PX:00[Zj^0;^k^`2^[Zh0
X:2P0080[Zj^0`38b<P40=OGe`<0iNGU1P3bl_8O0?ooo`80kno_0P3gmoL00`3_knl0moOg0?Ogm`02
0>o_k`030?Ogm`3_knl0kno_00<0kno_0P3gmoL20>o_k`030?Ogm`3_knl0kno_0080kno_0P3WinL0
2`3Ng]h0S8b<08B4Q01kNg/0FUYJ059BDP12@T80<C4a01PH602UYJD0[Jf]0080]KFe1@2m_Kd20<K6
aPH0_Kfm0P2e]KD50;fm_@80]KFe0`2][Jd01@2e]KD0[Jf]0;Fe]@2][Jd0_Kfm0080[Jf]0100]KFe
0:f][@2][Jd0YJFU09bLW02<S8`0Lg=c06][J`1SHf<0Jf][08b<S02DU9@0S8b<09BDU02LW9`0U9BD
0P24Q8@0102<S8`0YJFU0:FUY@2UYJD30;fm_@040<K6aP3WinL0g]kN0>OWi`80kno_103gmoLO0?oo
o`80inOW0P3gmoL0103WinL0moOg0?Ogm`3WinL20?Ogm`030>OWi`3gmoL0moOg00X0moOg0P3WinL0
1P3Ng]h0_Kfm05YJFP1JFUX0@T92034a<@80:BTY00@061PH00P82024Q8@0W9bL0P2DU9@00`2UYJD0
W9bL09bLW00209bLW0030:FUY@2LW9`0YJFU00H0W9bL0`2DU9@209bLW0@0U9BD0P2<S8`00`2DU9@0
S8b<08b<S00309BDU00508b<S024Q8@0U9BD08b<S024Q8@00P1kNg/01`1SHf<0>CTi034a<@0i>CT0
@T9206=SH`1[Jf/00P1SHf<01P1cLg<0Hf=S05YJFP1SHf<0FUYJ07=cL`80Ng]k00T0U9BD0:FUY@2U
YJD0[Jf]0=kNgP3>c/h0inOW0?Ogm`3WinL0103gmoLS0?ooo`008@3oool00`3UiND0l_;b0?;blP06
0?;blP80iNGU1@3bl_800`3UiND0l_;b0?;blP030?;blP060>GUi@3bl_80l_;b0>GUi@3GemL0[Zj^
0P2PX:000`1fMWH0C4a<04a<C00300000080b<S80`3GemL<0>GUi@050=OGe`3UiND0iNGU0=OGe`3U
iND01`3GemL40<S8b00=0=OGe`38b<P0b<S80<S8b02k^k/0b<S80;^k^`2PX:00MWIf038b<P1fMWH0
Q8B40:2PX0020:j^[P80X:2P00<0b<S80;^k^`2k^k/01038b<P0102k^k/0emOG0=OGe`3GemL40>GU
i@@0l_;b00<0iNGU0?;blP3oool07P3oool00`3_knl0moOg0?Ogm`020?Ogm`80kno_00<0moOg0>o_
k`3_knl00P3_knl30?Ogm`@0kno_00<0moOg0>o_k`3_knl00`3_knl0203WinL0g]kN09BDU024Q8@0
Ng]k06=SH`1BDU80@T920P0Y:BT0100H61P0[Jf]0;fm_@2e]KD60;fm_@030<K6aP2m_Kd0_Kfm00P0
_Kfm1@2e]KD40:f][@050:FUY@2][Jd0[Jf]0:f][@2UYJD00`2][Jd209bLW00707]kN`1JFUX0Jf][
0492@P1cLg<0Ng]k09BDU00308b<S0040:FUY@2LW9`0W9bL09bLW080YJFU0P2][Jd30;fm_@030<k>
cP3Fe]H0inOW0080kno_00D0moOg0>o_k`3_knl0kno_0?Ogm`0O0?ooo`030>OWi`3gmoL0moOg0080
moOg00<0inOW0?Ogm`3gmoL00P3gmoL00`3WinL0moOg0?Ogm`0:0?Ogm`080>OWi`3gmoL0inOW0<K6
aP1SHf<0FUYJ04Y:BP0a<C4202TY:@80410@00<020P809BDU02DU9@01`2LW9`20:FUY@H0W9bL00@0
U9BD09bLW02DU9@0W9bL1@2DU9@308b<S00?08B4Q01kNg/0Q8B408B4Q02LW9`0Ng]k08b<S024Q8@0
Ng]k08B4Q01cLg<0BTY:034a<@0Q8B40@T920080BTY:00@0Hf=S05YJFP1[Jf/0Hf=S1@1cLg<0101k
Ng/0Q8B408B4Q02LW9`20:FUY@030;fm_@36a/H0g]kN0080inOW1@3gmoLS0?ooo`008@3oool80?;b
lP040>GUi@3bl_80l_;b0>GUi@H0l_;b0P3UiND20?;blP0;0>GUi@3bl_80iNGU0>GUi@3GemL0[Zj^
0:2PX024Q8@0MWIf05YJFP1<C4`00P0000000`0820P0b<S80<S8b0040=OGe`T0iNGU00@0emOG0>GU
i@3GemL0iNGU203GemL60<S8b0<0^k^k00<0b<S80:j^[P2^[Zh00P2PX:001P0o?cl0FUYJ07IfMP1J
FUX0X:2P0:j^[P80X:2P0`2k^k/20<S8b0030=OGe`2k^k/0b<S800<0emOG0`3UiND50?;blP030>GU
i@3bl_80l_;b01l0oooo0`3gmoL0103_knl0moOg0?Ogm`3gmoL30>o_k`040?Ogm`3_knl0kno_0>o_
k`80moOg00<0kno_0?Ogm`3_knl01P3_knl03@3WinL0c/k>09BDU024Q8@0Jf][06=SH`1BDU80>CTi
02TY:@0Q8B40<C4a0:f][@2e]KD00`2m_Kd00`36a/H0_Kfm0<K6aP040;fm_@060;Fe]@2m_Kd0_Kfm
0;fm_@2e]KD0_Kfm0P2e]KD0102][Jd0]KFe0;Fe]@2e]KD30:f][@<0YJFU00<0[Jf]0;fm_@2][Jd0
102LW9`01@2<S8`0Ng]k07]kN`1:BTX0FUYJ0080Hf=S00@0Ng]k08b<S024Q8@0Q8B40P2LW9`20:f]
[@0409bLW02m_Kd0[Jf]0:f][@<0_Kfm00@0c/k>0=KFeP3Fe]H0kno_0P3gmoL30>o_k`80moOg7`3o
ool80?Ogm`030>OWi`3gmoL0moOg00D0moOg00<0inOW0?Ogm`3gmoL0103gmoL20>OWi`080=kNgP3F
e]H0Hf=S05YJFP12@T80<C4a03Ti>@0Y:BT2010@400301PH602DU9@0U9BD0080W9bL00@0YJFU09bL
W02UYJD0YJFU102LW9`0102DU9@0W9bL09bLW02DU9@209bLW0<0U9BD00@0S8b<09BDU02DU9@0U9BD
0P2<S8`01024Q8@0Ng]k07]kN`1kNg/208B4Q00407]kN`1cLg<0Ng]k07=cL`80Hf=S00<0@T9204Y:
BP0a<C400`0i>CT0101:BTX0FUYJ05YJFP1SHf<207=cL`0408B4Q02<S8`0Lg=c09BDU080Q8B400@0
U9BD0:FUY@2LW9`0_Kfm0P36a/H00`3WinL0moOg0?Ogm`050?Ogmb<0oooo000Q0?ooo`@0l_;b00D0
iNGU0?;blP3bl_80l_;b0>GUi@080?;blP80iNGU1@3bl_802@3UiND0l_;b0=OGe`2^[Zh0X:2P08B4
Q01fMWH0Q8B404a<C00200P820808b<S00<0b<S80=OGe`3UiND00P3GemL70>GUi@80emOG103UiND8
0=OGe`050<S8b02^[Zh0^k^k0<S8b03GemL00P2^[Zh00`2k^k/0[Zj^0;^k^`020:2PX00308B4Q01f
MWH0X:2P0080X:2P00<0TI6A0:j^[P2^[Zh00P2PX:001@2k^k/0[Zj^0:j^[P2k^k/0b<S80080^k^k
103GemL30>GUi@030?;blP3UiND0iNGU00D0l_;b7`3oool00`3gmoL0kno_0>o_k`020>o_k`040?Og
m`3_knl0kno_0>o_k`80moOg0P3_knl0103gmoL0kno_0>o_k`3gmoL20>o_k`<0moOg0`3_knl0203W
inL0[Jf]09BDU024Q8@0Lg=c05YJFP1BDU80BTY:0P0a<C401`12@T80[Jf]0;fm_@2m_Kd0a/K60;fm
_@36a/H0202m_Kd00`2e]KD0_Kfm0;fm_@020;Fe]@050:f][@2m_Kd0[Jf]0;Fe]@2m_Kd00P2][Jd2
0:FUY@0:09BDU02][Jd0_Kfm0:f][@2<S8`0W9bL09BDU02LW9`0U9BD07]kN`80Hf=S00@0Ng]k06][
J`1kNg/0S8b<0P2DU9@208b<S00309bLW02<S8`0U9BD00@0W9bL0`2m_Kd01@3>c/h0e]KF0>OWi`3W
inL0moOg0080kno_0P3gmoL00`3_knl0moOg0>o_k`0O0?ooo`80moOg00@0inOW0?Ogm`3gmoL0moOg
0P3WinL40?Ogm`030>OWi`3gmoL0moOg00L0moOg00/0inOW0?Ogm`3WinL0g]kN0<K6aP1SHf<0FUYJ
04Y:BP0a<C40>CTi02TY:@0201PH6005024Q8@0Y:BT0W9bL09bLW02UYJD00P2LW9`00`2UYJD0W9bL
09bLW00509bLW00309BDU02LW9`0W9bL00<0U9BD00<0S8b<09BDU02DU9@00P2DU9@208b<S00<08B4
Q01[Jf/0Lg=c08b<S02LW9`0Hf=S06][J`1cLg<0Jf][07=cL`1:BTX0@T920P0a<C4304Y:BP80Hf=S
00P0Jf][06=SH`1SHf<0Lg=c05YJFP1[Jf/0Lg=c07]kN`80Lg=c0P2DU9@00`2LW9`0_Kfm0<K6aP02
0=kNgP80moOg00<0inOW0?Ogm`3gmoL00`3gmoLS0?ooo`008@3oool00`3bl_80iNGU0?;blP0A0?;b
lP80iNGU0P3bl_820>GUi@040<S8b02PX:00Q8B407IfMP80FUYJ00D0?clo04a<C01<C4`08b<S0000
00030=OGe`030>GUi@3GemL0iNGU00L0iNGU0P3GemL0103UiND0emOG0=OGe`3GemL20<S8b0030=OG
e`38b<P0b<S80080b<S80P2^[Zh20<S8b0050:j^[P2PX:00X:2P0:2PX024Q8@00P1fMWH01`2PX:00
Q8B408B4Q024Q8@0MWIf08B4Q02PX:000P2^[Zh01P2ATI40[Zj^0;^k^`2^[Zh0^k^k0:j^[P<0b<S8
0P3GemL00`3UiND0l_;b0>GUi@020>GUi@@0l_;b0P3UiND20?;blQl0oooo00<0moOg0>o_k`3_knl0
103gmoL00`3_knl0moOg0?Ogm`020?Ogm`030>o_k`3gmoL0moOg0080kno_00@0moOg0>o_k`3gmoL0
kno_0P3gmoL02P3_knl0inOW0>OWi`2][Jd0Q8B407=cL`1[Jf/0Hf=S0492@P1:BTX2059BDP0303Ti
>@2m_Kd0]KFe00@0_Kfm0P2e]KD00`2m_Kd0]KFe0;Fe]@030;Fe]@050;fm_@2e]KD0]KFe0;fm_@2e
]KD01P2][Jd209bLW080S8b<00<0[Jf]08b<S024Q8@00P24Q8@00`1kNg/0Lg=c05YJFP0606][J`03
08B4Q02DU9@0U9BD0080S8b<00<0W9bL09BDU02LW9`00P2DU9@20:FUY@80_Kfm00L0e]KF0>o_k`3W
inL0inOW0>o_k`3gmoL0kno_0080moOg0P3_knl20?Ogmal0oooo0P3gmoL00`3WinL0moOg0?Ogm`07
0?Ogm`030>OWi`3gmoL0moOg00P0moOg00L0inOW0=kNgP3Ng]h0U9BD05YJFP1:BTX0@T920080>CTi
00L08B4Q02TY:@0Y:BT061PH00P8202LW9`0YJFU00@0W9bL00<0U9BD09bLW02DU9@02P2DU9@208B4
Q00508b<S024Q8@0S8b<08b<S01kNg/00P1SHf<00`24Q8@0U9BD06=SH`0306=SH`0405YJFP1BDU80
@T920492@P<0>CTi0P12@T800`1JFUX0Hf=S06][J`0206=SH`0407]kN`1[Jf/0Lg=c06][J`80Lg=c
00H0Ng]k09bLW02LW9`0a/K60>OWi`3Ng]h20>OWi`P0moOg8`3oool00240oooo0P3bl_800`3UiND0
l_;b0?;blP0?0?;blP030>GUi@3bl_80l_;b0080iNGU00<0emOG0;^k^`2ATI400P24Q8@01@1fMWH0
?clo038b<P1<C4`0?clo008020P800H0emOG0>GUi@3GemL0emOG0>GUi@3GemL30>GUi@040=OGe`3U
iND0iNGU0>GUi@<0emOG00<0iNGU0<S8b03GemL01@38b<P20;^k^`80[Zj^00<0^k^k0:j^[P2PX:00
0P2PX:001@24Q8@0FUYJ05YJFP1fMWH0[Zj^0080X:2P00L0Q8B4096AT@2PX:00X:2P096AT@2^[Zh0
X:2P0080^k^k00@0X:2P0:j^[P2^[Zh0^k^k0P3GemL00`3UiND0emOG0>GUi@050>GUi@L0l_;b7`3o
ool20?Ogm`040>o_k`3gmoL0moOg0>o_k`80moOg00@0kno_0?Ogm`3gmoL0moOg103_knl20?Ogm`03
0>o_k`3gmoL0kno_0080moOg00H0kno_0>OWi`3Fe]H0W9bL08b<S01kNg/206][J`080492@P1BDU80
FUYJ04Y:BP0i>CT0_Kfm0;Fe]@36a/H50;fm_@040;Fe]@2m_Kd0]KFe0:f][@80]KFe0`2][Jd00`2e
]KD0[Jf]0:f][@020:f][@80YJFU0P2LW9`01024Q8@0S8b<09BDU02DU9@308B4Q00307]kN`1SHf<0
Jf][0080Jf][0P1kNg/206][J`0708b<S024Q8@0S8b<08b<S02DU9@0[Jf]09bLW00409BDU080_Kfm
00H0a/K60;fm_@3Ng]h0inOW0>o_k`3WinL20>o_k`80moOg00<0kno_0?Ogm`3gmoL00P3gmoLO0?oo
oaP0moOg00D0g]kN0<k>cP24Q8@0Hf=S05YJFP020492@P0602TY:@0Q8B40<C4a02TY:@0Q8B4061PH
0`2UYJD01P2DU9@0W9bL09bLW02LW9`0U9BD09bLW0@0U9BD0`2<S8`01`2DU9@0Q8B408b<S02<S8`0
Q8B407]kN`24Q8@00P1kNg/01@1cLg<0Hf=S06=SH`1cLg<0Jf][00@0FUYJ00d0>CTi04Y:BP0i>CT0
FUYJ04Y:BP12@T80>CTi06=SH`1:BTX0FUYJ06=SH`1JFUX0Jf][0080Lg=c0`1[Jf/00`1cLg<0U9BD
0:FUY@020:FUY@040<k>cP3Ng]h0inOW0=kNgP80inOW1`3gmoLS0?ooo`008@3ooolG0?;blP80iNGU
00@0emOG0;^k^`2PX:00Q8B40P1fMWH304a<C08020P800D000000=OGe`3GemL0b<S80=OGe`020>GU
i@030=OGe`3UiND0emOG0080emOG00<0b<S80=OGe`3GemL00`38b<P00`3GemL0b<S80<S8b0030<S8
b080^k^k00@0[Zj^0:2PX02k^k/0X:2P1024Q8@01`1<C4`0Q8B405YJFP1fMWH0X:2P0:j^[P2PX:00
0P24Q8@00`2PX:00TI6A08B4Q0020:2PX080^k^k0P2^[Zh20;^k^`<0emOG00<0iNGU0?;blP3UiND0
0P3UiND50?;blP80iNGU0P3bl_8O0?ooo`040?Ogm`3_knl0moOg0?Ogm`80kno_00<0moOg0>o_k`3g
moL0103gmoL20>o_k`030?Ogm`3_knl0moOg00H0kno_00D0inOW0=KFeP2DU9@0Q8B407=cL`0206][
J`03059BDP1[Jf/0DU9B0080<C4a00@0_Kfm0;Fe]@2m_Kd0[Jf]0P2m_Kd20:f][@030;Fe]@2][Jd0
[Jf]00H0[Jf]00<0YJFU0:f][@2UYJD0102UYJD02P2LW9`0U9BD08b<S024Q8@0W9bL07]kN`1[Jf/0
Ng]k07=cL`1SHf<207=cL`80Jf][00<0S8b<08B4Q01cLg<00P1kNg/0102<S8`0Lg=c08b<S02DU9@2
0:f][@80U9BD00/0[Jf]09BDU02m_Kd0_Kfm0<K6aP3Fe]H0kno_0>OWi`3_knl0inOW0>o_k`030?Og
m`@0kno_00<0moOg0?ooo`3oool07@3ooolF0?Ogm`0:0>OWi`3gmoL0g]kN0<K6aP2<S8`0FUYJ04Y:
BP12@T80>CTi034a<@80:BTY0P0H61P0100@4100YJFU09bLW02DU9@309bLW00308b<S02DU9@0U9BD
0080S8b<00<0Q8B408b<S02<S8`00`24Q8@0102<S8`0Q8B408B4Q024Q8@207]kN`80Lg=c00d0Jf][
06=SH`1kNg/0Hf=S05YJFP1BDU80BTY:05YJFP12@T80BTY:059BDP12@T80BTY:0080FUYJ00L0BTY:
05YJFP1:BTX0Hf=S04Y:BP1SHf<0Jf][0080Q8B400d0Hf=S06][J`24Q8@0Lg=c09BDU02LW9`0[Jf]
0<K6aP3WinL0g]kN0>OWi`3Ng]h0inOW00P0moOg8`3oool00240oooo603bl_801@3UiND0emOG0;^k
^`2ATI40Q8B40080MWIf00H0?clo05YJFP0b<S80000000P8200000050=OGe`060>GUi@3GemL0iNGU
0=OGe`38b<P0emOG2`38b<P30;^k^`<0[Zj^0`24Q8@01P1fMWH0C4a<05YJFP1JFUX0C4a<08B4Q0@0
[Zj^00@0X:2P08B4Q024Q8@0TI6A0P2PX:020;^k^`040:2PX02k^k/0b<S80<S8b080emOG00<0iNGU
0?;blP3GemL00P3UiND:0?;blQl0oooo0P3gmoL0103_knl0moOg0?Ogm`3_knl20?Ogm`030>o_k`3g
moL0moOg00D0moOg00H0kno_0?Ogm`3_knl0kno_0?Ogm`3_knl20?Ogm`050>OWi`2m_Kd0W9bL08b<
S01cLg<00P1[Jf/01@1SHf<0DU9B0492@P0Y:BT0>CTi00@0_Kfm00D0]KFe0;fm_@2m_Kd0[Jf]0;Fe
]@030:f][@030:FUY@2][Jd0[Jf]00<0YJFU00D0[Jf]0:FUY@2LW9`0W9bL0:FUY@0209bLW00609BD
U024Q8@0U9BD08b<S01[Jf/0Lg=c101[Jf/00`1BDU80Hf=S06][J`0208b<S00:09BDU01kNg/0Ng]k
07=cL`2<S8`0U9BD08B4Q02UYJD0W9bL09BDU080[Jf]00@0W9bL0;fm_@2m_Kd0e]KF0P3Ng]h01P3W
inL0kno_0>o_k`3_knl0moOg0>o_k`<0moOg00<0kno_0?Ogm`3_knl07`3ooolE0?Ogm`080>OWi`3g
moL0moOg0=kNgP2UYJD0Lg=c06=SH`1:BTX20492@P0602TY:@0i>CT08B4Q010@400Q8B40410@102L
W9`01`2DU9@0W9bL08b<S02DU9@0S8b<08B4Q02<S8`01P24Q8@00`2<S8`0Q8B407]kN`0407]kN`09
07=cL`1[Jf/0Jf][06=SH`1JFUX0DU9B04Y:BP12@T80<C4a0080BTY:00<0:BTY0492@P1JFUX00P1J
FUX03@1[Jf/0BTY:04Y:BP1:BTX0Hf=S06][J`1JFUX0Q8B407]kN`1[Jf/0Q8B408b<S024Q8@00P2D
U9@01@36a/H0c/k>0=KFeP3Ng]h0inOW00X0moOg8`3oool00240oooo4`3bl_800`3UiND0l_;b0>GU
i@030?;blP030:j^[P2k^k/0X:2P0080FUYJ00L0C4a<05YJFP1JFUX08b<S00P8200S8b<020P800T0
emOG2P38b<P00`2k^k/0b<S80;^k^`020;^k^`<0[Zj^00L0X:2P08B4Q01fMWH0MWIf04a<C01fMWH0
FUYJ0080C4a<00H0Q8B40:2PX02^[Zh0X:2P0:j^[P2ATI4308B4Q0030:2PX02k^k/0^k^k00<0^k^k
00L0[Zj^0<S8b03GemL0emOG0>GUi@3GemL0l_;b0080iNGU2P3bl_8O0?ooo`<0moOg0P3_knl00`3g
moL0kno_0?Ogm`030?Ogm`030>o_k`3gmoL0moOg00@0moOg0`3_knl04P3gmoL0kno_0>o_k`3_knl0
[Jf]08b<S024Q8@0Hf=S06][J`1JFUX0Hf=S04Y:BP12@T80>CTi0492@P2m_Kd0[Jf]0;fm_@80]KFe
00<0[Jf]0;fm_@2][Jd00P2][Jd30:FUY@0409bLW02UYJD0W9bL09bLW080YJFU1@2LW9`208b<S004
08B4Q02DU9@0Q8B406][J`<0Hf=S00d0Jf][05YJFP1JFUX0Hf=S06][J`2<S8`0Q8B408b<S024Q8@0
S8b<07=cL`1[Jf/0Q8B40080W9bL0`2][Jd0102DU9@0W9bL0;fm_@36a/H20=kNgP80kno_00<0inOW
0>o_k`3gmoL01`3gmoL00`3_knl0oooo0?ooo`0M0?oooa<0moOg00@0inOW0?Ogm`3WinL0moOg0P3W
inL01@2DU9@0Lg=c05YJFP0i>CT0BTY:0080<C4a00X0>CTi024Q8@0Q8B408B4Q01PH602UYJD0W9bL
09BDU02LW9`0U9BD102<S8`308B4Q00507=cL`1kNg/0Ng]k07]kN`24Q8@00P1kNg/507=cL`80Hf=S
00<0Jf][05YJFP1:BTX01012@T801@1:BTX0<C4a034a<@0i>CT0@T9200<0FUYJ00D0Hf=S04Y:BP1:
BTX0@T9205YJFP0207=cL`80S8b<00L0Q8B406][J`24Q8@0W9bL0;Fe]@3>c/h0e]KF0080inOW00<0
g]kN0?Ogm`3gmoL0203gmoLS0?ooo`008@3oool50?;blP80iNGU0`3bl_800`3UiND0l_;b0?;blP08
0?;blP070>GUi@3bl_80l_;b0=OGe`2k^k/0X:2P08B4Q00205YJFP0304a<C01fMWH0?clo00800000
0P0820P60=OGe`D0b<S800@0^k^k0<S8b02k^k/0^k^k0`2^[Zh20;^k^`80[Zj^0`2PX:0208B4Q005
05YJFP1<C4`0MWIf05YJFP1fMWH00P0S8b<00`0o?cl0Q8B40:2PX0020:2PX0050:j^[P2k^k/0^k^k
096AT@24Q8@00P2PX:000`2^[Zh0^k^k0;^k^`030:j^[P80emOG00<0iNGU0=OGe`3UiND00P3UiND0
0`3bl_80iNGU0?;blP080?;blQl0oooo00<0kno_0?Ogm`3_knl0103_knl30?Ogm`060>o_k`3gmoL0
moOg0>o_k`3gmoL0kno_103gmoL40>o_k`090;fm_@2][Jd0S8b<07=cL`1SHf<0Jf][05YJFP1:BTX0
@T920080:BTY00<0<C4a0;fm_@2][Jd00P2e]KD20:f][@@0YJFU1@2LW9`409BDU00409bLW02DU9@0
U9BD09BDU080Q8B400H0Ng]k08B4Q01[Jf/0Hf=S06][J`1SHf<206][J`030492@P1:BTX0Hf=S0080
Ng]k00H0Q8B409BDU02LW9`0U9BD0:f][@1cLg<208B4Q00309BDU024Q8@0[Jf]00@0U9BD00<0a/K6
0>OWi`3Ng]h00P3WinL01P3_knl0moOg0>o_k`3_knl0moOg0>o_k`H0moOg7`3oool40?Ogm`030>OW
i`3gmoL0moOg00P0moOg00<0inOW0?Ogm`3gmoL0103gmoL20>OWi`090:FUY@24Q8@0Jf][04Y:BP0i
>CT0BTY:034a<@0i>CT0:BTY00@061PH00@0W9bL09BDU02LW9`0U9BD0P2<S8`407]kN`D0Lg=c0`1[
Jf/207=cL`80Jf][0P1SHf<205YJFP060492@P0i>CT0<C4a0492@P0i>CT0@T920P0Q8B402P0Y:BT0
<C4a0492@P12@T80FUYJ06=SH`1cLg<0Q8B406=SH`1:BTX205YJFP0<06][J`2<S8`0S8b<06][J`1S
Hf<0Jf][09BDU02][Jd0g]kN0=KFeP3Ng]h0inOW0P3gmoL20>OWi`P0moOg8`3oool00240oooo5`3b
l_801P3GemL0^k^k0;^k^`2ATI40MWIf05YJFP80C4a<00<0FUYJ03lo?`0820P00P0820P01@0S8b<0
b<S80<S8b038b<P0emOG00@0b<S800<0^k^k0<S8b038b<P00P2^[Zh00`2PX:00[Zj^0:j^[P020:j^
[P030:2PX02^[Zh0[Zj^00@0X:2P00<0Q8B407IfMP0o?cl00`1JFUX0100b<S808b<S0000001fMWH2
0:2PX00308B4Q02PX:00[Zj^0080b<S80P2ATI40102^[Zh0TI6A0:j^[P2k^k/20:j^[P030:2PX02^
[Zh0emOG00<0iNGU00<0emOG0?;blP3bl_801@3bl_800`3UiND0l_;b0?;blP030?;blQl0oooo0`3g
moL00`3_knl0moOg0?Ogm`050?Ogm`040>o_k`3gmoL0kno_0?Ogm`80kno_00<0moOg0>o_k`3_knl0
0`3_knl0103Ng]h0]KFe0:f][@1kNg/206][J`80FUYJ00<0BTY:03Ti>@0a<C400P0i>CT50:f][@04
0:FUY@2][Jd0YJFU0:FUY@80W9bL0`2DU9@208b<S00308B4Q02DU9@0U9BD00<0U9BD0`24Q8@0301c
Lg<0S8b<06][J`1:BTX0Jf][06=SH`1JFUX0@T9202TY:@1SHf<0Ng]k06=SH`80Ng]k00L0U9BD0:FU
Y@2LW9`0[Jf]08b<S02DU9@0S8b<00@0U9BD00@0Q8B408b<S02][Jd0e]KF0`3Ng]h20>o_k`030?Og
m`3_knl0kno_0080moOg00@0kno_0?Ogm`3_knl0kno_0P3gmoLO0?ooo`/0moOg00<0inOW0?Ogm`3W
inL01@3gmoL02P3WinL0moOg0?Ogm`3gmoL0e]KF0:FUY@24Q8@0Hf=S0492@P1:BTX2034a<@0303Ti
>@0Y:BT061PH00808B4Q00<061PH09BDU02<S8`00`2<S8`308B4Q00307]kN`1cLg<0Lg=c00<0Jf][
0P1SHf<506][J`0706=SH`1JFUX0Hf=S05YJFP1:BTX0@T9202TY:@0204Y:BP0503Ti>@0Q8B408B4Q
010@400a<C400`12@T80101:BTX0Hf=S07=cL`24Q8@406=SH`0406][J`24Q8@0Jf][06][J`80FUYJ
00D0[Jf]0<K6aP3>c/h0c/k>0=KFeP020>OWi`/0moOg8`3oool00240oooo1@3bl_800`3UiND0l_;b
0?;blP050?;blP040>GUi@3bl_80l_;b0>GUi@@0l_;b0P3UiND01`3GemL0^k^k0:2PX024Q8@0FUYJ
07IfMP1JFUX00P1<C4`500P82080b<S81P3GemL30<S8b0030:j^[P2PX:00[Zj^00@0X:2P0P2^[Zh2
0:2PX0@0Q8B400D0FUYJ02<S8`1JFUX0MWIf03lo?`0202<S8`0904a<C01fMWH0X:2P08B4Q02PX:00
MWIf0:j^[P2k^k/0[Zj^00@0X:2P00/0TI6A0;^k^`2^[Zh0^k^k0:j^[P2k^k/0b<S80?;blP3UiND0
emOG0>GUi@0=0?;blQl0oooo0`3gmoL40>o_k`030?Ogm`3_knl0moOg00<0moOg0`3_knl20?Ogm`03
0>o_k`3gmoL0moOg0080kno_00D0a/K60:f][@2LW9`0Ng]k06][J`0206=SH`0405YJFP0i>CT0>CTi
034a<@80>CTi0`2][Jd0102m_Kd0[Jf]0:FUY@2][Jd40:FUY@0409bLW02<S8`0Q8B407]kN`@0Q8B4
0100S8b<08B4Q024Q8@0Q8B407]kN`1[Jf/0Lg=c08B4Q01SHf<0BTY:06][J`1:BTX0@T9203Ti>@1B
DU80FUYJ0P1kNg/01`1cLg<0Jf][09BDU02LW9`0[Jf]09BDU024Q8@00`2<S8`0102][Jd0U9BD09bL
W02DU9@20:f][@040>o_k`3Fe]H0g]kN0>o_k`@0moOg00<0kno_0?Ogm`3gmoL00`3gmoL00`3_knl0
moOg0>o_k`0O0?ooo`h0moOg00<0inOW0?Ogm`3gmoL01@3gmoL0203WinL0]KFe08b<S024Q8@0FUYJ
04Y:BP12@T80>CTi0P0a<C400`0Q8B4061PH024Q8@02024Q8@80U9BD00<0YJFU09BDU02DU9@00`2D
U9@01P2<S8`0Q8B408B4Q01SHf<0FUYJ06=SH`@0FUYJ0P1SHf<405YJFP08059BDP1:BTX0>CTi02TY
:@0i>CT0@T9202TY:@0H61P202TY:@07034a<@12@T80BTY:0492@P0i>CT0Hf=S07=cL`0206][J`0>
05YJFP1SHf<0Hf=S06=SH`24Q8@0Hf=S07=cL`1SHf<0Q8B40;Fe]@3WinL0a/K60=KFeP3WinL=0?Og
mb<0oooo000Q0?ooo`80l_;b0P3UiND70?;blP030>GUi@3bl_80l_;b00H0l_;b0`3UiND02P38b<P0
^k^k0:2PX024Q8@0MWIf05YJFP24Q8@0FUYJ04a<C000000300P82003038b<P38b<P0iNGU00H0iNGU
0`3GemL00`38b<P0^k^k0:2PX0030:2PX0<0Q8B400@0X:2P08B4Q02PX:00Q8B40P1fMWH203lo?`0?
05YJFP0o?cl0<S8b00P8201fMWH0<S8b05YJFP2PX:00Q8B407IfMP24Q8@0[Zj^0;^k^`38b<P0^k^k
0080X:2P0P24Q8@00`2k^k/0X:2P0:j^[P020;^k^`D0iNGU303bl_800`3UiND0oooo0?ooo`0M0?oo
o`070>o_k`3gmoL0kno_0>o_k`3gmoL0kno_0?Ogm`020>o_k`80moOg0P3_knl00`3gmoL0kno_0>o_
k`020?Ogm`@0kno_00/0inOW0<K6aP2][Jd0U9BD07=cL`1[Jf/0Hf=S07=cL`1:BTX08B4Q0492@P02
03Ti>@03034a<@2][Jd0a/K600@0a/K60`2e]KD30:f][@030:FUY@2LW9`0Ng]k00D0Ng]k00@0Q8B4
07]kN`1kNg/0Ng]k0P1[Jf/02@1kNg/0BTY:04Y:BP1JFUX0@T92034a<@0i>CT0@T9206=SH`0207]k
N`80Lg=c00@0S8b<09bLW02][Jd0[Jf]0P2DU9@00`1kNg/0Jf][0:f][@0209BDU080[Jf]00@0_Kfm
0>OWi`3WinL0inOW0P3_knl00`3gmoL0kno_0?Ogm`020?Ogm`030>o_k`3gmoL0moOg0080moOg0P3_
knlO0?ooo`80moOg0P3WinL:0?Ogm`030>OWi`3gmoL0inOW00D0moOg00P0g]kN0;Fe]@24Q8@0Jf][
05YJFP12@T80>CTi04Y:BP80<C4a00H0410@024Q8@0Q8B4061PH034a<@2DU9@30:f][@80YJFU0`2L
W9`209BDU00508B4Q01kNg/0FUYJ05YJFP1:BTX01P1JFUX204Y:BP80@T9200@0:BTY034a<@0i>CT0
@T920P0Q8B400`0a<C408B4Q03Ti>@0204Y:BP0603Ti>@1:BTX0FUYJ07]kN`2<S8`0Q8B40P1[Jf/0
0`1JFUX0@T9208B4Q00206][J`80Q8B400D0inOW0=kNgP3Ng]h0g]kN0>OWi`0=0?Ogmb<0oooo000Q
0?oooa00l_;b00L0iNGU0?;blP3bl_80l_;b0>GUi@3bl_80emOG0080^k^k00T0X:2P08B4Q01<C4`0
FUYJ04a<C01JFUX0<S8b0000000E5AD00P0820P00`24Q8@0iNGU0?;blP020?;blPH0iNGU00L0emOG
0<S8b038b<P0b<S80:j^[P2PX:00Q8B400<0X:2P00D0Q8B40:2PX024Q8@0Q8B407IfMP0204a<C008
05YJFP24Q8@0<S8b02<S8`0E5AD0Q8B403lo?`1JFUX208B4Q00507IfMP24Q8@0X:2P0:j^[P38b<P0
0P2k^k/00`2PX:00Q8B4096AT@030;^k^`070=OGe`2k^k/0iNGU0>GUi@3GemL0l_;b0>GUi@020?;b
lP030>GUi@3bl_80iNGU00P0l_;b7`3oool00`3gmoL0kno_0?Ogm`020?Ogm`030>o_k`3gmoL0moOg
00<0moOg00<0kno_0?Ogm`3_knl00`3gmoL00`3_knl0moOg0>o_k`020>o_k`0:0<k>cP2e]KD0W9bL
08b<S01cLg<0FUYJ06=SH`1JFUX0Hf=S02TY:@80@T9200D0>CTi034a<@36a/H0a/K60=KFeP060<K6
aP80]KFe0P2][Jd0102UYJD0U9BD07]kN`1cLg<307]kN`0E06][J`1kNg/0Ng]k07]kN`1[Jf/0Hf=S
07=cL`1JFUX0Hf=S0492@P0i>CT0<C4a04Y:BP12@T80Hf=S06][J`1kNg/0Jf][07=cL`24Q8@0S8b<
0080[Jf]00@0W9bL09BDU01cLg<0S8b<0`2LW9`01@2m_Kd0W9bL0;fm_@3Ng]h0e]KF0080inOW00<0
kno_0?Ogm`3_knl00`3_knl20?Ogm`030>o_k`3gmoL0moOg0080moOg7`3oool@0?Ogm`040>OWi`3g
moL0moOg0>OWi`80moOg0140_Kfm0:FUY@1cLg<0Hf=S05YJFP0a<C40>CTi034a<@0i>CT08B4Q010@
400Y:BT08B4Q01PH601SHf<0[Jf]0;fm_@020;Fe]@@0[Jf]0`2LW9`01P2<S8`0Q8B407]kN`1[Jf/0
BTY:05YJFP80BTY:00D0FUYJ059BDP1:BTX0FUYJ04Y:BP020492@P0:034a<@0i>CT0BTY:024Q8@0H
61P0<C4a03Ti>@0Q8B40>CTi0492@P80>CTi00T0BTY:05YJFP1JFUX0S8b<08B4Q01cLg<0Jf][04Y:
BP1SHf<00`1cLg<01`2DU9@0Lg=c0>OWi`3>c/h0a/K60=kNgP3WinL03@3gmoLS0?ooo`008@3oool6
0?;blP030>GUi@3bl_80l_;b00T0l_;b0P3UiND20?;blP040=OGe`2^[Zh0X:2P096AT@80MWIf00@0
FUYJ04a<C01JFUX000000`0820P00`24Q8@0iNGU0?;blP060?;blP@0iNGU0P3GemL20<S8b0030;^k
^`24Q8@0Q8B40080Q8B401D0X:2P08B4Q024Q8@0MWIf05YJFP0b<S80Q8B404a<C02PX:008b<S00P8
20000000MWIf08B4Q01<C4`0Q8B407IfMP2ATI40Q8B40:2PX02k^k/00P3GemL01@2k^k/0Q8B4096A
T@2ATI40X:2P00<0^k^k00@0b<S80>GUi@3UiND0iNGU3`3bl_8O0?ooo`030>o_k`3gmoL0moOg0080
kno_00<0moOg0>o_k`3gmoL00P3gmoL40>o_k`030?Ogm`3_knl0moOg00D0kno_00@0c/k>0:f][@2D
U9@0S8b<0P1[Jf/01@1SHf<0FUYJ06=SH`0i>CT0BTY:0080>CTi00@0S8b<0<k>cP3Fe]H0c/k>0P3F
e]H00`36a/H0c/k>0<K6aP020<K6aP80]KFe0P2][Jd00`2UYJD0W9bL09BDU00307=cL`0I07]kN`1c
Lg<0Ng]k07=cL`1[Jf/0DU9B0492@P1cLg<0FUYJ03Ti>@0a<C408B4Q02TY:@1[Jf/0DU9B06][J`2<
S8`0Jf][07=cL`24Q8@0W9bL0:f][@2m_Kd0[Jf]06][J`0208b<S00809BDU02LW9`0[Jf]0:f][@2U
YJD0inOW0<k>cP3WinL20>o_k`030?Ogm`3_knl0moOg0080moOg0P3_knl30?Ogm`030>o_k`3gmoL0
moOg01l0oooo103gmoL00`3WinL0moOg0?Ogm`040?Ogm`030>OWi`3gmoL0moOg00H0moOg00`0inOW
0?Ogm`2m_Kd0U9BD06][J`1SHf<0DU9B0492@P0i>CT0<C4a03Ti>@0@4103024Q8@0707=cL`2e]KD0
]KFe0;Fe]@2m_Kd0]KFe0;fm_@020;Fe]@090:f][@2UYJD0[Jf]09bLW02DU9@0S8b<08B4Q01kNg/0
Lg=c00D0BTY:00P0FUYJ04Y:BP12@T80BTY:03Ti>@1:BTX0<C4a05YJFP8061PH00h0410@03Ti>@12
@T80:BTY0492@P0i>CT0Hf=S04Y:BP1JFUX0Lg=c09BDU02UYJD0S8b<0492@P<0Hf=S00P0Lg=c08b<
S024Q8@0Ng]k0<k>cP2m_Kd0g]kN0>OWi`80moOg00<0inOW0?Ogm`3gmoL02@3gmoLS0?ooo`008@3o
ool30?;blP030>GUi@3bl_80l_;b00@0l_;b00<0iNGU0?;blP3bl_801`3bl_820>GUi@060;^k^`2A
TI40TI6A08B4Q01fMWH0FUYJ0P1<C4`200P8200502<S8`1YJFT0iNGU0?;blP3UiND01@3bl_800`3U
iND0l_;b0?;blP030>GUi@@0emOG00@0b<S80;^k^`2PX:00[Zj^0P1fMWH01`1JFUX0MWIf04a<C01J
FUX0<S8b0:2PX01fMWH00P24Q8@00`0820P08b<S05YJFP040:2PX00507IfMP2PX:00TI6A0:2PX02k
^k/00P3GemL02@2ATI40Q8B4096AT@2PX:00^k^k0=OGe`2^[Zh0^k^k0>GUi@0A0?;blQl0oooo0`3g
moL00`3_knl0moOg0?Ogm`040?Ogm`80kno_0P3gmoL00`3_knl0moOg0?Ogm`020?Ogm`80kno_00D0
c/k>0;fm_@2DU9@0S8b<07]kN`0206=SH`80FUYJ00@0>CTi0492@P0i>CT0Q8B4103>c/h50=KFeP@0
a/K600<0_Kfm0;Fe]@2m_Kd00P2][Jd00`2UYJD0W9bL08B4Q00206=SH`80Jf][00D0Hf=S04Y:BP1:
BTX0@T9207]kN`0207=cL`05034a<@0Q8B40@T9207]kN`24Q8@00P1kNg/04024Q8@0S8b<08b<S02D
U9@0W9bL0:f][@2m_Kd0S8b<07=cL`2<S8`0Ng]k0;Fe]@2m_Kd0]KFe0:f][@36a/H30>o_k`80moOg
00@0kno_0?Ogm`3_knl0kno_0`3gmoL01@3_knl0moOg0?Ogm`3_knl0moOg01l0oooo503gmoL20>OW
i`060:f][@1kNg/0Hf=S05YJFP12@T80>CTi0P0a<C40100Q8B4061PH024Q8@1[Jf/20;Fe]@030:f]
[@2e]KD0_Kfm00<0_Kfm00<0a/K60;Fe]@2e]KD00`2][Jd209bLW00409BDU02<S8`0U9BD07]kN`80
Jf][0P12@T800`1:BTX0@T920492@P02034a<@0<04Y:BP1BDU80FUYJ04Y:BP0H61P08B4Q03Ti>@1:
BTX0FUYJ04Y:BP1JFUX0@T920P1SHf<03@1[Jf/0Q8B409bLW02DU9@0Hf=S04Y:BP1SHf<0Jf][0:FU
Y@2DU9@0YJFU08b<S03Ng]h00P3WinL?0?Ogmb<0oooo000Q0?ooo`030>GUi@3bl_80l_;b00h0l_;b
00H0iNGU0?;blP3UiND0iNGU0=OGe`2^[Zh2096AT@0808B4Q01JFUX0C4a<03lo?`1<C4`0000000P8
200E5AD20>GUi@X0l_;b103UiND30=OGe`80b<S801l0^k^k0:j^[P2PX:00FUYJ07IfMP1<C4`0FUYJ
038b<P0S8b<0FUYJ0;^k^`0o?cl0[Zj^04a<C00820P0MWIf03lo?`2ATI40MWIf0:2PX02ATI40Q8B4
0:2PX024Q8@0[Zj^0=OGe`3UiND0TI6A08B4Q02ATI40X:2P00<0^k^k00D0emOG0>GUi@3UiND0l_;b
0>GUi@0>0?;blQl0oooo00<0kno_0?Ogm`3gmoL00P3gmoL0103_knl0moOg0>o_k`3gmoL30>o_k`07
0?Ogm`3_knl0kno_0>o_k`3gmoL0kno_0?Ogm`020>o_k`0<0<k>cP2][Jd0U9BD08b<S01cLg<0DU9B
05YJFP1:BTX0FUYJ02TY:@12@T80FUYJ0P36a/H30<k>cP050=KFeP36a/H0a/K60<K6aP3Fe]H01P36
a/H20;Fe]@80[Jf]00<0YJFU09bLW024Q8@00`1SHf<03@1JFUX0BTY:04Y:BP0Y:BT0Jf][09bLW02D
U9@0Hf=S06][J`0a<C40BTY:08b<S01SHf<00P1kNg/02024Q8@0U9BD07]kN`2][Jd0U9BD0<k>cP2<
S8`0Lg=c0P2<S8`01P2LW9`0[Jf]0:f][@2m_Kd0g]kN0>OWi`@0kno_0P3gmoL40>o_k`040?Ogm`3_
knl0kno_0>o_k`80moOg7`3oool50?Ogm`030>OWi`3gmoL0moOg00L0moOg00<0inOW0?Ogm`3WinL0
0P3gmoL01@3WinL0e]KF09BDU01kNg/0Hf=S0080BTY:00L0<C4a02TY:@0a<C4061PH024Q8@0Y:BT0
[Jf]00@0]KFe00<0_Kfm0;Fe]@2m_Kd0102e]KD0102][Jd0YJFU0:f][@2UYJD209bLW080U9BD00D0
Q8B407]kN`1[Jf/0Jf][03Ti>@020492@P0903Ti>@0Y:BT0:BTY04Y:BP1kNg/0:BTY06][J`12@T80
61PH0080<C4a00<0Hf=S034a<@1:BTX00P1SHf<03P1[Jf/0FUYJ06=SH`2UYJD0]KFe06=SH`1:BTX0
Hf=S08B4Q01cLg<0Q8B408b<S02DU9@0g]kN0`3WinL>0?Ogmb<0oooo000Q0?oooa<0l_;b0P3UiND0
1@3GemL0X:2P0:2PX01fMWH0Q8B40080C4a<00<0<S8b00P8200820P00P0b<S820>GUi@<0l_;b203U
iND00`3GemL0iNGU0>GUi@020=OGe`050<S8b03GemL0b<S80<S8b02k^k/00P2^[Zh205YJFP80?clo
00X020P8038b<P2ATI40Q8B405YJFP2PX:00Q8B404a<C01fMWH0Q8B40P2PX:002P2ATI40FUYJ096A
T@2ATI40^k^k0:j^[P38b<P0emOG096AT@24Q8@20:2PX0070;^k^`3GemL0emOG0=OGe`3UiND0l_;b
0>GUi@0>0?;blQl0oooo00<0kno_0?Ogm`3gmoL00P3gmoL20>o_k`<0moOg0`3_knl50?Ogm`060>o_
k`3WinL0inOW0<k>cP2LW9`0S8b<0P1cLg<205YJFP04059BDP0i>CT0<C4a05YJFP80a/K60`3>c/h0
0`36a/H0c/k>0<K6aP040<K6aP030;Fe]@2m_Kd0a/K60080_Kfm00<0]KFe0:f][@2][Jd00P2][Jd0
1`2UYJD0U9BD08b<S01SHf<0BTY:06=SH`1:BTX00P0i>CT0301BDU80S8b<06][J`2LW9`0@T9207]k
N`1SHf<0Jf][07]kN`1[Jf/0Ng]k06=SH`80S8b<0P2LW9`02@2][Jd0_Kfm08b<S01[Jf/0S8b<09BD
U02][Jd0_Kfm0=KFeP040>o_k`040?Ogm`3_knl0moOg0>o_k`<0moOg00<0kno_0?Ogm`3gmoL0103g
moLO0?oooa<0moOg0P3WinL01P2m_Kd0Q8B406=SH`1BDU80BTY:0492@P80<C4a00@08B4Q01PH600Y
:BT0@T920P2][Jd30;Fe]@D0[Jf]00<0YJFU09bLW02LW9`00P2UYJD309bLW0<0S8b<0100Q8B407=c
L`1[Jf/0Hf=S034a<@0i>CT0<C4a02TY:@0Q8B40>CTi06=SH`1JFUX0BTY:08B4Q01JFUX0<C4a0P12
@T8204Y:BP0@06=SH`0i>CT0Hf=S06=SH`1cLg<0U9BD08b<S02DU9@0Hf=S0492@P24Q8@0Jf][08B4
Q02DU9@0c/k>0=KFeP<0inOW3P3gmoLS0?ooo`008@3oool?0?;blP050>GUi@3bl_80l_;b0?;blP3U
iND00P3GemL00`2ATI40Q8B407IfMP0304a<C0060000000820P020P800P8203UiND0l_;b0`3UiND0
0`3bl_80iNGU0=OGe`020=OGe`H0b<S81@3GemL30<S8b080^k^k00@0Q8B404a<C00b<S80<S8b0P0E
5AD0201<C4`0[Zj^096AT@1YJFT0X:2P08B4Q00b<S80MWIf0P2PX:000`1fMWH0Q8B408B4Q0030;^k
^`80emOG00H0TI6A0:2PX02PX:00X:2P0:j^[P3GemL20?;blP030>GUi@3bl_80iNGU00<0l_;b00<0
iNGU0?;blP3bl_80203bl_8O0?ooo`D0moOg00<0kno_0?Ogm`3_knl00P3_knl30?Ogm`@0kno_0P3g
moL01`3WinL0e]KF0;Fe]@2DU9@0Ng]k07=cL`1SHf<00P1JFUX00`0a<C40>CTi034a<@020<K6aP80
c/k>0`36a/H00`2m_Kd0]KFe0:f][@030:f][@040:FUY@2][Jd0[Jf]0:f][@@0]KFe0P2][Jd04P2U
YJD0W9bL09bLW02<S8`0Jf][05YJFP1:BTX0@T9203Ti>@1:BTX0Hf=S08b<S01kNg/0W9bL07]kN`12
@T80Jf][08B4Q0@0Ng]k00d0W9bL09BDU02LW9`0_Kfm0<K6aP2<S8`0U9BD09bLW02<S8`0[Jf]0;fm
_@3_knl0g]kN00<0kno_00<0moOg0>o_k`3gmoL00P3_knl00`3gmoL0kno_0?Ogm`050?Ogm`030>o_
k`3oool0oooo01d0oooo3P3gmoL00`3WinL0moOg0?Ogm`020?Ogm`070>OWi`3>c/h0_Kfm07]kN`1J
FUX0DU9B0492@P02034a<@808B4Q0P0H61P20;Fe]@<0[Jf]00<0]KFe09bLW02LW9`00P2DU9@208b<
S00408B4Q02<S8`0S8b<08b<S0<0U9BD00@0W9bL09BDU02<S8`0Q8B40P1kNg/00`1cLg<0DU9B034a
<@02034a<@0=02TY:@0a<C40@T9206][J`1SHf<0FUYJ04Y:BP1JFUX08B4Q03Ti>@1JFUX0BTY:03Ti
>@0205YJFP0607]kN`1cLg<0Q8B40:FUY@2e]KD0Hf=S0P1[Jf/01@1SHf<0U9BD09bLW03WinL0moOg
00<0inOW3P3gmoLS0?ooo`008@3ooolC0?;blP040>GUi@3GemL0b<S80:2PX080Q8B400<0MWIf03lo
?`0b<S800P0820P0100b<S80emOG0>GUi@3bl_840>GUi@80emOG0P38b<P40=OGe`@0b<S80`3GemL2
0<S8b080^k^k00D0[Zj^0:2PX00o?cl0<S8b02<S8`0200P8200=03lo?`2^[Zh0MWIf04a<C02PX:00
[Zj^08B4Q01JFUX0MWIf0:2PX024Q8@0TI6A08B4Q0040;^k^`040=OGe`2k^k/0^k^k0:2PX080^k^k
00@0emOG0>GUi@3bl_80iNGU103bl_800`3UiND0l_;b0?;blP090?;blQl0oooo00D0moOg0>o_k`3g
moL0moOg0>o_k`030?Ogm`030>o_k`3gmoL0moOg0080moOg0`3_knl01`3gmoL0kno_0>o_k`3WinL0
e]KF0:f][@2DU9@00P1cLg<01P1SHf<0FUYJ059BDP0a<C40>CTi04Y:BP@0c/k>0P36a/H0102m_Kd0
[Jf]0:f][@2LW9`408b<S0050:FUY@2LW9`0YJFU0:f][@2UYJD00P2e]KD20:f][@0>0:FUY@2LW9`0
U9BD09BDU024Q8@0FUYJ04Y:BP0i>CT0:BTY03Ti>@1SHf<0Lg=c05YJFP2UYJD207]kN`0806=SH`1[
Jf/0S8b<07]kN`2<S8`0Ng]k09bLW02DU9@20:f][@030<K6aP2][Jd0W9bL0080W9bL00@0[Jf]0;fm
_@3WinL0inOW0P3_knl0103gmoL0kno_0?Ogm`3_knl50?Ogm`030>o_k`3gmoL0moOg00<0moOg7`3o
oolC0?Ogm`040>OWi`36a/H0_Kfm06][J`80BTY:00H0@T92034a<@0a<C4061PH024Q8@0Y:BT30;Fe
]@<0[Jf]00@0YJFU09BDU02<S8`0Q8B41@1kNg/01024Q8@0Ng]k08b<S024Q8@209BDU00809bLW02<
S8`0Q8B408B4Q01kNg/0Jf][06=SH`12@T8202TY:@808B4Q00T0BTY:06][J`1BDU80<C4a04Y:BP1S
Hf<0FUYJ03Ti>@12@T800P1:BTX03P1SHf<0FUYJ07=cL`24Q8@0Lg=c08B4Q02][Jd0Q8B407=cL`24
Q8@0Lg=c08b<S02UYJD0g]kN0P3WinL@0?Ogmb<0oooo000Q0?oooa80l_;b00D0iNGU0=OGe`3GemL0
^k^k06UYJ@0205YJFP0504a<C00S8b<05ADE00P8200S8b<01P3UiND00`3GemL0b<S80<S8b0020>GU
i@80emOG00L0iNGU0<S8b038b<P0b<S80:2PX02^[Zh0^k^k0080b<S800@0emOG0<S8b038b<P0b<S8
0P2k^k/01038b<P0X:2P08B4Q00E5AD20000000?038b<P000000^k^k0<S8b02k^k/0Q8B40<S8b02k
^k/0TI6A0:j^[P1fMWH0X:2P08B4Q02ATI40[Zj^0080^k^k0P3GemL0102ATI40X:2P0;^k^`2^[Zh4
0>GUi@80l_;b00<0iNGU0?;blP3bl_802`3bl_8O0?ooo`050?Ogm`3_knl0kno_0?Ogm`3_knl00`3g
moL0103_knl0moOg0?Ogm`3_knl20?Ogm`0A0>o_k`3gmoL0kno_0?Ogm`3WinL0g]kN0=KFeP2DU9@0
Ng]k06][J`1SHf<0FUYJ059BDP12@T80>CTi04Y:BP3>c/h00`36a/H00`3>c/h0a/K608B4Q00208B4
Q00<0<K6aP2<S8`0S8b<0:FUY@2e]KD0Q8B407]kN`24Q8@0Lg=c06][J`2LW9`0[Jf]0P2e]KD20:f]
[@030:FUY@2LW9`0U9BD0080Q8B40140BTY:02TY:@0Y:BT08B4Q059BDP2UYJD0[Jf]06=SH`2][Jd0
YJFU0:f][@2<S8`0Q8B409BDU024Q8@0Ng]k08b<S00209BDU0070:f][@2m_Kd0a/K609BDU024Q8@0
W9bL0:f][@020>OWi`040>o_k`3WinL0moOg0?Ogm`80kno_00@0moOg0>o_k`3gmoL0kno_0P3gmoL0
1P3_knl0moOg0?Ogm`3_knl0moOg0>o_kal0oooo4P3gmoL0203WinL0e]KF0<K6aP2<S8`0FUYJ04Y:
BP0i>CT0<C4a0P0Y:BT01P0Q8B40:BTY0;fm_@2e]KD0[Jf]0:FUY@80[Jf]00D0Ng]k07=cL`1cLg<0
]KFe09bLW00207]kN`0309bLW01cLg<0Lg=c0080Jf][00<0FUYJ07]kN`2<S8`00`2DU9@208b<S00;
08B4Q01kNg/0Lg=c06=SH`1JFUX0<C4a01PH600@4100>CTi01PH6024Q8@00P2<S8`00`1JFUX0Ng]k
08B4Q00206=SH`0=034a<@1JFUX0FUYJ06=SH`1[Jf/0Ng]k08b<S02UYJD0]KFe07]kN`1[Jf/0Lg=c
09BDU0020=kNgP030>OWi`3Ng]h0moOg00l0moOg8`3oool00240oooo4P3bl_802@3GemL0b<S80:j^
[P2PX:00JFUY038b<P1<C4`0?clo04a<C00200P8200306UYJ@3UiND0iNGU00@0iNGU1`38b<P0202^
[Zh0X:2P0:2PX02PX:00emOG0:j^[P2PX:00^k^k103GemL00`38b<P0^k^k0;^k^`020:j^[P0>0:2P
X01fMWH020P80000000820P0?clo08B4Q02PX:00TI6A0;^k^`2PX:00b<S80>GUi@24Q8@20:2PX003
07IfMP24Q8@0X:2P0080^k^k0P3GemL20:2PX003096AT@2^[Zh0iNGU00<0iNGU403bl_8O0?ooo`09
0>o_k`3gmoL0moOg0>o_k`3gmoL0kno_0?Ogm`3_knl0moOg00H0kno_00`0moOg0>o_k`3gmoL0e]KF
0<k>cP2][Jd0Q8B407]kN`1BDU80FUYJ04Y:BP0Y:BT203Ti>@0308B4Q03>c/h0c/k>00@0a/K60P24
Q8@0101kNg/0Lg=c07=cL`24Q8@206][J`0305YJFP1SHf<0S8b<0080Lg=c00<0FUYJ0:f][@2e]KD0
0`2e]KD00`2UYJD0W9bL09bLW00209BDU00A07=cL`0i>CT0>CTi01PH600a<C40Q8B409BDU01kNg/0
S8b<08B4Q02][Jd0c/k>08b<S01cLg<0Q8B406][J`1kNg/00P2DU9@0102LW9`0_Kfm0;fm_@2LW9`2
09BDU0050:f][@3WinL0inOW0>o_k`3WinL01P3gmoL00`3_knl0moOg0?Ogm`070?Ogmal0oooo3P3g
moL02P3WinL0moOg0?Ogm`3gmoL0e]KF0;fm_@2DU9@0Jf][05YJFP0i>CT3034a<@808B4Q00@0Jf][
0;Fe]@2e]KD0]KFe0`2UYJD00`1[Jf/0Lg=c06][J`0306=SH`0307=cL`1JFUX0BTY:0080BTY:00@0
Ng]k06=SH`1:BTX0S8b<102DU9@00`2<S8`0Q8B407]kN`0206][J`0>05YJFP1BDU808B4Q010@400H
61P0@T9206=SH`1[Jf/0Hf=S08B4Q01JFUX0Q8B40:f][@1:BTX205YJFP030492@P1JFUX0Jf][0080
Lg=c0P2UYJD208B4Q00307]kN`2DU9@0g]kN00<0inOW403gmoLS0?ooo`008@3ooolB0?;blP080=OG
e`2k^k/0^k^k0:2PX01<C4`0?clo04a<C00b<S8200P8200304a<C03UiND0iNGU00<0iNGU00H0emOG
0<S8b01fMWH0FUYJ096AT@1fMWH2096AT@0:0:2PX01JFUX0FUYJ05YJFP1fMWH0?clo05YJFP0b<S80
C4a<0<S8b080emOG0`38b<P30;^k^`0=0:2PX024Q8@0?clo0000000820P05ADE038b<P2ATI40C4a<
0;^k^`24Q8@0^k^k0=OGe`020:j^[P0608B4Q02PX:00Q8B40:2PX024Q8@0^k^k0P3GemL20;^k^`03
0:2PX02k^k/0emOG0080iNGU00<0l_;b0>GUi@3bl_803P3bl_8O0?ooo`<0moOg0P3_knl0103gmoL0
kno_0>o_k`3gmoL30>o_k`040?Ogm`3_knl0kno_0?Ogm`80kno_00/0e]KF0<K6aP2LW9`0Lg=c06=S
H`1:BTX0FUYJ04Y:BP12@T80<C4a05YJFP020<k>cP<0a/K600d0S8b<08B4Q01:BTX0BTY:059BDP1c
Lg<0DU9B05YJFP1BDU80BTY:034a<@1:BTX0<C4a00<0@T9200@0Q8B40;Fe]@2e]KD0]KFe0P2][Jd4
09bLW00A07]kN`1JFUX061PH01PH600i>CT0FUYJ08b<S02UYJD0FUYJ07]kN`2LW9`0_Kfm0<k>cP2D
U9@0Jf][08B4Q01kNg/00P2<S8`0102][Jd0_Kfm0;fm_@2m_Kd209bLW0040;Fe]@3Ng]h0kno_0>OW
i`80kno_0`3gmoL00`3_knl0moOg0?Ogm`050?Ogm`80kno_0P3gmoLO0?oooa80moOg00D0c/k>0;Fe
]@1cLg<0Jf][0492@P02034a<@0402TY:@0H61P061PH034a<@80_Kfm00T0]KFe0:f][@2UYJD0Ng]k
07=cL`1BDU80<C4a0492@P1BDU800P12@T801P1:BTX0<C4a024Q8@0Y:BT0<C4a024Q8@80:BTY00@0
@T9207=cL`2DU9@0U9BD0`2<S8`0401kNg/0Lg=c07]kN`1SHf<0FUYJ0492@P0@41008B4Q034a<@12
@T80Hf=S034a<@24Q8@0FUYJ07]kN`2LW9`206][J`0903Ti>@1JFUX0FUYJ06=SH`1JFUX0Q8B409BD
U02UYJD0[Jf]0080Q8B400H0YJFU0=KFeP3WinL0inOW0?Ogm`3WinL?0?Ogmb<0oooo000Q0?oooa40
l_;b00D0iNGU0=OGe`2k^k/0TI6A08B4Q00303lo?`808b<S00<0<S8b0>GUi@3UiND00P3UiND02`3b
l_80iNGU0>GUi@3UiND0emOG0:j^[P2PX:00[Zj^0:2PX02^[Zh0b<S800D0X:2P0P2k^k/20<S8b0<0
emOG00<0b<S80=OGe`38b<P00P2k^k/00`2^[Zh0X:2P05YJFP0300000009038b<P1JFUX0X:2P05YJ
FP2k^k/0Q8B40=OGe`3UiND0MWIf0080X:2P00<0Q8B4096AT@24Q8@00P2k^k/20=OGe`80^k^k00@0
emOG0>GUi@3UiND0iNGU4@3bl_8O0?ooo`80kno_0P3gmoL20>o_k`80moOg00@0kno_0?Ogm`3_knl0
moOg1@3_knl01`3WinL0e]KF0;fm_@2DU9@0Hf=S04Y:BP1JFUX00`1:BTX01@12@T80c/k>0<k>cP36
a/H0c/k>0080a/K600D0]KFe0<K6aP1cLg<0Jf][06=SH`0206][J`0307]kN`1SHf<0Hf=S00<0Hf=S
00@0W9bL0:FUY@2UYJD0[Jf]0P2e]KD30:f][@070:FUY@2LW9`0W9bL09bLW024Q8@0Lg=c03Ti>@02
01PH600605YJFP1cLg<0W9bL09BDU02LW9`0Ng]k0P2m_Kd0103>c/h0Q8B408B4Q01kNg/208b<S080
[Jf]00D0_Kfm0<K6aP2DU9@0W9bL0=KFeP030>OWi`@0kno_0`3gmoL00`3_knl0moOg0>o_k`020?Og
m`030>o_k`3gmoL0kno_0080moOg7`3oool@0?Ogm`80inOW00H0c/k>0:f][@1kNg/0FUYJ034a<@12
@T8402TY:@80_Kfm0`2e]KD02P2UYJD0W9bL0:FUY@1kNg/0Hf=S04Y:BP1JFUX0BTY:05YJFP1[Jf/5
04Y:BP0508B4Q02<S8`0S8b<08b<S02DU9@0102<S8`01P24Q8@0Ng]k07=cL`1[Jf/0Hf=S059BDP80
410@00X0:BTY0492@P1BDU80Jf][04Y:BP1cLg<0FUYJ09bLW02e]KD0DU9B0`1JFUX02@1SHf<0FUYJ
08B4Q024Q8@0YJFU0:f][@24Q8@0Lg=c0<K6aP020>OWi`030=kNgP3gmoL0moOg00l0moOg8`3oool0
0240oooo403bl_820>GUi@040<S8b02k^k/0Q8B405YJFP80?clo00@0<S8b01DE5@0S8b<0<S8b1`3U
iND30?;blP80iNGU00@0l_;b0>GUi@3UiND0l_;b0P3UiND90=OGe`<0b<S80P2k^k/20:j^[P0D08B4
Q00000000000038b<P0E5AD0<S8b096AT@1JFUX0X:2P07IfMP2PX:00emOG0;^k^`2^[Zh0TI6A08B4
Q02ATI40[Zj^0;^k^`2^[Zh20=OGe`80X:2P00@0emOG0>GUi@3UiND0iNGU4@3bl_8O0?ooo`040?Og
m`3_knl0moOg0>o_k`@0moOg00<0kno_0?Ogm`3gmoL00P3gmoL02P3_knl0moOg0>o_k`3_knl0inOW
0<k>cP2][Jd0Q8B406][J`1JFUX204Y:BP80@T9200L0DU9B0<k>cP36a/H0c/k>0<K6aP3>c/h0a/K6
0080c/k>0P3Fe]H40<K6aP060<k>cP3Fe]H0a/K60;fm_@2e]KD0_Kfm1P2e]KD20:f][@80YJFU0P2L
W9`0302DU9@0Ng]k059BDP0a<C40410@04Y:BP1JFUX0Lg=c08b<S024Q8@0Jf][08B4Q080_Kfm00`0
U9BD08b<S01cLg<0Lg=c08b<S02LW9`0U9BD0;fm_@36a/H0W9bL08b<S03Ng]h30>OWi`<0moOg00<0
kno_0?Ogm`3gmoL0103gmoL00`3_knl0moOg0?Ogm`040?Ogmal0oooo3@3gmoL02P3WinL0moOg0?Og
m`3WinL0g]kN0<K6aP2<S8`0Hf=S04Y:BP12@T8402TY:@04034a<@2e]KD0[Jf]0;Fe]@80[Jf]00h0
YJFU0:f][@2e]KD0]KFe0;fm_@2e]KD0[Jf]0;fm_@2][Jd0YJFU0;fm_@2e]KD0[Jf]0:FUY@80W9bL
0P2DU9@0102LW9`0U9BD09BDU02DU9@208b<S00308B4Q01kNg/0Lg=c0080Jf][01T0FUYJ02TY:@08
20P0@T92034a<@12@T80Hf=S03Ti>@1JFUX0@T9205YJFP2LW9`0Lg=c06][J`1SHf<0BTY:06=SH`1[
Jf/0Lg=c06][J`2UYJD0[Jf]08B4Q01SHf<0e]KF00<0g]kN4@3gmoLS0?ooo`008@3ooolA0?;blP03
0<S8b02PX:00Q8B40080FUYJ00<0<S8b00P8200S8b<00P0S8b<40>GUi@<0l_;b00<0iNGU0?;blP3b
l_800`3bl_840>GUi@80emOG00H0iNGU0=OGe`3GemL0iNGU0=OGe`3UiND40=OGe`<0b<S800D0^k^k
0:j^[P2^[Zh0X:2P01DE5@020000000701DE5@0b<S80FUYJ07IfMP1JFUX0Q8B406UYJ@020=OGe`06
0:j^[P2k^k/0X:2P08B4Q02ATI40Q8B40P2k^k/0103GemL0X:2P0;^k^`3GemL20>GUiA80l_;b7`3o
ool00`3_knl0moOg0>o_k`020>o_k`030?Ogm`3_knl0moOg0080moOg00<0kno_0?Ogm`3gmoL0103_
knl0103>c/h0W9bL07]kN`1SHf<204Y:BP0403Ti>@1:BTX0BTY:04Y:BP80c/k>00@0a/K60<k>cP36
a/H0a/K61`3>c/h40<K6aP050;Fe]@2m_Kd0]KFe0;fm_@2e]KD00P36a/H20;Fe]@<0[Jf]00T0YJFU
09bLW02UYJD0W9bL09BDU024Q8@0Jf][0492@P0i>CT00P1BDU8306=SH`80Ng]k00H0U9BD0;fm_@2D
U9@0W9bL08B4Q02<S8`207=cL`0609bLW02][Jd0_Kfm0:f][@2LW9`0e]KF0P3WinL0103Fe]H0kno_
0?Ogm`3gmoL20>o_k`L0moOg0P3_knl30?Ogmal0oooo1P3gmoL00`3WinL0moOg0?Ogm`060?Ogm`09
0>OWi`3gmoL0a/K608B4Q01JFUX0>CTi04Y:BP0a<C408B4Q00<0:BTY3P2e]KD00`2][Jd0YJFU0:FU
Y@0509bLW0040:FUY@2LW9`0YJFU09bLW0<0U9BD00@0S8b<08B4Q024Q8@0Lg=c0P1[Jf/01@1SHf<0
:BTY02TY:@0@4100@T920080>CTi00@0DU9B03Ti>@1JFUX0FUYJ0P2DU9@0301[Jf/0Lg=c05YJFP1:
BTX0Hf=S04Y:BP1cLg<0Q8B40:FUY@1[Jf/0Ng]k0<k>cP80g]kN4P3gmoLS0?ooo`008@3ooolA0?;b
lP0:0;^k^`2ATI40Q8B405YJFP0b<S8020P802<S8`0820P08b<S038b<P@0iNGU2@3bl_820>GUi@H0
emOG1@3UiND40=OGe`040<S8b02k^k/0^k^k0<S8b080X:2P01805ADE0000000000005ADE03lo?`1J
FUX0Q8B405YJFP0o?cl0C4a<0:2PX038b<P0iNGU0;^k^`2PX:00FUYJ0:2PX02ATI420;^k^`040=OG
e`2ATI40emOG0=OGe`80iNGU4P3bl_8O0?ooo`040?Ogm`3_knl0kno_0>o_k`X0moOg0P3_knl0303>
c/h0a/K609BDU01cLg<0Jf][05YJFP0i>CT0BTY:034a<@1:BTX0>CTi0<k>cP80a/K60`3>c/h00`36
a/H0c/k>0<k>cP040<k>cP060<K6aP2e]KD0a/K60;Fe]@2][Jd0_Kfm0P2e]KD00`2m_Kd0a/K60;Fe
]@020<K6aP80]KFe00<0[Jf]0:FUY@2UYJD00P2LW9`208B4Q00B07=cL`1:BTX08B4Q04Y:BP1SHf<0
Jf][07=cL`1[Jf/0FUYJ06=SH`2DU9@0S8b<0<K6aP2][Jd0Ng]k08b<S01[Jf/0S8b<0P2LW9`0102m
_Kd0[Jf]0<K6aP3Fe]H30>OWi`D0moOg00<0kno_0?Ogm`3gmoL00P3gmoL00`3_knl0moOg0?Ogm`04
0?Ogmal0oooo403gmoL00`3WinL0]KFe07]kN`0204Y:BP0402TY:@0Q8B40:BTY01PH6080:BTY3@2e
]KD20:FUY@80W9bL00<0S8b<09BDU02LW9`00P2LW9`0102UYJD0W9bL09bLW02][Jd209bLW00409BD
U02<S8`0Q8B407]kN`80Lg=c00X0Jf][06=SH`0a<C40410@01PH600a<C40BTY:059BDP1SHf<0BTY:
0P12@T80101SHf<0Lg=c0:FUY@24Q8@204Y:BP0806][J`1SHf<0Ng]k07=cL`2UYJD0Hf=S0;Fe]@36
a/H20>OWia80moOg8`3oool00240oooo403bl_800`3UiND0X:2P096AT@0205YJFP0704a<C00S8b<0
8b<S01DE5@0S8b<020P80=OGe`020>GUi@D0l_;b00<0iNGU0?;blP3bl_800P3UiND00`3GemL0b<S8
0<S8b0030<S8b080emOG00<0iNGU0=OGe`3UiND00`3UiND20=OGe`80b<S80`2k^k/0602^[Zh0X:2P
03lo?`00000020P80000000b<S80FUYJ04a<C024Q8@0<S8b05YJFP2k^k/0emOG0;^k^`38b<P0X:2P
06UYJ@24Q8@0TI6A0:2PX02k^k/0emOG0:2PX080emOG00<0l_;b0>GUi@3bl_804@3bl_8O0?ooo`L0
moOg00<0kno_0?Ogm`3gmoL00P3gmoL20>o_k`80moOg00H0a/K60:FUY@2DU9@0Jf][06=SH`12@T84
04Y:BP0408B4Q036a/H0a/K60<K6aP<0c/k>00<0e]KF0<k>cP3>c/h00P3>c/h20<K6aP060:f][@2U
YJD0[Jf]0:f][@2UYJD0[Jf]0P2e]KD20;fm_@80a/K60`2e]KD00`2][Jd0YJFU0:FUY@0209bLW008
09BDU01kNg/0Jf][05YJFP0i>CT0@T9205YJFP1BDU8207=cL`0:059BDP1SHf<0DU9B0:f][@2LW9`0
YJFU08b<S02DU9@0Ng]k08b<S080W9bL00H0_Kfm0;Fe]@3Ng]h0_Kfm0>o_k`3WinL:0?Ogm`80kno_
0P3gmoL0103_knl0moOg0?Ogm`3gmoLO0?oooa00moOg00H0inOW09BDU01kNg/0BTY:03Ti>@12@T82
02TY:@03034a<@0Y:BT08B4Q00H0]KFe00<0_Kfm0;Fe]@2e]KD00P2e]KD20:f][@0609bLW02<S8`0
Q8B409BDU024Q8@0S8b<0P2DU9@00`2LW9`0YJFU0:FUY@020:f][@80W9bL00<0U9BD08b<S024Q8@0
0P1kNg/04P1cLg<0Jf][05YJFP12@T80:BTY024Q8@0i>CT0@T92059BDP12@T80BTY:034a<@0i>CT0
S8b<09BDU01cLg<0Ng]k06=SH`80FUYJ00T0Hf=S08B4Q01cLg<0W9bL06][J`3Fe]H0YJFU0?Ogm`3W
inL04P3gmoLS0?ooo`008@3ooolA0?;blP03096AT@1fMWH0C4a<0080?clo0P0820P202<S8`0300P8
203UiND0iNGU00H0l_;b00<0iNGU0?;blP3bl_800P3UiND20=OGe`80b<S80P2k^k/20<S8b0030=OG
e`3UiND0iNGU00D0iNGU00<0emOG0<S8b02k^k/00P2k^k/20:2PX00804a<C000000000000000000E
5AD0FUYJ038b<P24Q8@205YJFP040;^k^`2PX:00^k^k0>GUi@80X:2P0P24Q8@20:2PX0030=OGe`2k
^k/0b<S800<0emOG4P3bl_8O0?ooo`030>o_k`3gmoL0moOg0080moOg00<0kno_0?Ogm`3_knl00P3g
moL02P3_knl0moOg0?Ogm`3_knl0moOg0>o_k`2m_Kd0U9BD07=cL`1SHf<204Y:BP80>CTi0P1:BTX4
0<K6aPP0c/k>00@0a/K60;Fe]@2e]KD0W9bL0P2UYJD00`2LW9`0[Jf]0:f][@020;Fe]@060;fm_@36
a/H0a/K60<K6aP2e]KD0a/K60P2][Jd00`2UYJD0W9bL09bLW00208B4Q00807]kN`1JFUX0>CTi02TY
:@1:BTX0DU9B06][J`1cLg<206=SH`0504Y:BP2UYJD0W9bL0<k>cP2DU9@00`2<S8`01@24Q8@0U9BD
0;fm_@2m_Kd0c/k>0080e]KF00<0c/k>0?Ogm`3gmoL0303gmoL0103_knl0moOg0?Ogm`3gmoLO0?oo
o`d0moOg00L0inOW0?Ogm`3gmoL0moOg07]kN`1BDU80@T920080<C4a0P0Q8B4202TY:@0301PH602e
]KD0]KFe00H0]KFe00@0[Jf]0;Fe]@2e]KD0[Jf]0P2LW9`01@2DU9@0Ng]k08B4Q01kNg/0Q8B40080
S8b<0`2LW9`20:FUY@0509bLW02UYJD0U9BD09BDU02<S8`00P1kNg/02`1cLg<0Jf][06=SH`12@T80
:BTY00P8200Q8B40<C4a04Y:BP0i>CT0BTY:0080>CTi00d0Q8B405YJFP1cLg<0[Jf]06][J`1SHf<0
FUYJ07=cL`1JFUX0Jf][09bLW02][Jd0_Kfm0080c/k>00<0a/K60?Ogm`3gmoL0403gmoLS0?ooo`00
8@3oool@0?;blP0<0>GUi@24Q8@0C4a<038b<P0o?cl020P801DE5@0S8b<0<S8b00P820000000emOG
0P3UiND70?;blP030>GUi@38b<P0iNGU0080iNGU00L0emOG08B4Q02PX:00b<S808B4Q02k^k/0emOG
00H0iNGU0`3GemL01`38b<P0^k^k0;^k^`2^[Zh0X:2P07IfMP0E5AD00`000002038b<P80FUYJ00P0
<S8b03lo?`2ATI40b<S80;^k^`38b<P0TI6A05YJFP80Q8B400H0^k^k0=OGe`3UiND0[Zj^0>GUi@2k
^k/C0?;blQl0oooo1P3gmoL0103_knl0moOg0?Ogm`3_knl60?Ogm`040:f][@24Q8@0Hf=S059BDP80
BTY:00@0@T9204Y:BP12@T80<C4a1036a/H00`3>c/h0e]KF0=KFeP030<k>cP060=KFeP2LW9`0Ng]k
0<K6aP2e]KD0YJFU0P1SHf<01@24Q8@0Ng]k09bLW02][Jd0]KFe00D0a/K600<0]KFe0:f][@2][Jd0
0P2UYJD02P2LW9`0U9BD08B4Q01[Jf/0Hf=S0492@P0Y:BT0<C4a04Y:BP1BDU8206][J`08059BDP1[
Jf/0FUYJ0:f][@2LW9`0[Jf]08B4Q02<S8`207]kN`0609bLW02m_Kd0_Kfm0:f][@3WinL0]KFe4@3g
moL00`3_knl0moOg0?ooo`0N0?oooa00moOg00<0inOW06=SH`12@T800P0a<C401P0Q8B40:BTY02TY
:@0Y:BT061PH024Q8@<0[Jf]0P2e]KD00`2m_Kd0]KFe0;Fe]@020;Fe]@0<0<K6aP1[Jf/0[Jf]0:f]
[@2LW9`0U9BD0492@P1[Jf/0Ng]k05YJFP1cLg<0W9bL0P2UYJD20:f][@0=0:FUY@2LW9`0W9bL09BD
U02<S8`0Q8B407]kN`1cLg<0Jf][06=SH`12@T80:BTY010@4002024Q8@0<03Ti>@12@T80BTY:04Y:
BP0a<C40@T9206=SH`24Q8@0Lg=c08B4Q01SHf<0>CTi0P1JFUX01P1cLg<0U9BD0>OWi`2DU9@0inOW
0:FUYA<0moOg8`3oool00240oooo403bl_80203GemL0C4a<04a<C00820P05ADE038b<P0S8b<0<S8b
0P0000001@1YJFT0l_;b0?;blP3bl_80iNGU0080l_;b00<0iNGU0?;blP3bl_800P3bl_830>GUi@04
0?;blP3UiND0emOG0=OGe`<0b<S80`3UiND00`3bl_80iNGU0>GUi@030>GUi@030=OGe`38b<P0b<S8
0080b<S800<0X:2P07IfMP1<C4`00`000000300b<S80C4a<01DE5@1JFUX0<S8b0000002PX:00TI6A
0;^k^`3GemL0TI6A07IfMP80Q8B400D0TI6A0;^k^`38b<P0^k^k0<S8b00D0?;blQl0oooo1@3gmoL0
103_knl0moOg0>o_k`3_knl30?Ogm`0:0>o_k`3gmoL0moOg0?Ogm`2<S8`0Hf=S05YJFP0i>CT0BTY:
0492@P80BTY:0P0Y:BT40<K6aP@0e]KF0P3>c/h0103Fe]H0a/K60=KFeP3Fe]H20<K6aP040;Fe]@2]
[Jd0[Jf]0:f][@80YJFU00<0]KFe0<K6aP36a/H00`36a/H30;Fe]@80[Jf]01/0W9bL08B4Q024Q8@0
Ng]k06][J`1SHf<08B4Q01PH601:BTX0DU9B0492@P1[Jf/0DU9B05YJFP0a<C40S8b<0:f][@2m_Kd0
Ng]k08b<S01kNg/0Q8B409BDU02][Jd0a/K60;fm_@3>c/h00P3gmoL00`3_knl0moOg0?Ogm`030?Og
m`030>o_k`3gmoL0moOg00T0moOg7`3oool<0?Ogm`050>OWi`3gmoL0moOg0?Ogm`3>c/h00P12@T80
1@0Q8B40<C4a034a<@0Y:BT0<C4a0080410@00D0Hf=S0;Fe]@2e]KD0]KFe0<K6aP020;fm_@050<K6
aP2e]KD0]KFe0;Fe]@2m_Kd00`36a/H0202e]KD0YJFU09bLW02LW9`0U9BD08b<S024Q8@0W9bL0P2]
[Jd00`2e]KD0[Jf]0:f][@0309bLW00309BDU02<S8`0Ng]k0080Lg=c01T0Hf=S0492@P12@T8020P8
01PH600@4100>CTi0492@P0Y:BT0BTY:034a<@0Q8B40Jf][06=SH`24Q8@0W9bL06=SH`1BDU80FUYJ
06=SH`1kNg/0S8b<0;Fe]@2][Jd0_Kfm01@0moOg8`3oool00240oooo403bl_80103GemL0?clo04a<
C00b<S8202<S8`0503lo?`0S8b<000000000003GemL01@3bl_820>GUi@80l_;b00L0iNGU0?;blP3U
iND0l_;b0>GUi@3bl_80iNGU0080emOG0`38b<P:0>GUi@070=OGe`38b<P0b<S80:j^[P2PX:00MWIf
04a<C0040000000705YJFP0b<S80FUYJ02<S8`0o?cl0MWIf0:2PX0020<S8b00308B4Q02ATI40MWIf
0080Q8B400<0[Zj^0;^k^`3GemL05@3bl_8O0?ooo`80moOg00<0kno_0?Ogm`3_knl00`3gmoL00`3_
knl0moOg0?Ogm`030>o_k`030?Ogm`3_knl0Lg=c0080FUYJ00P0DU9B04Y:BP1:BTX0BTY:0492@P0Y
:BT0>CTi0<K6aP80c/k>1P3Fe]H01@36a/H0e]KF0=KFeP3Fe]H0g]kN0080a/K600T0_Kfm0:f][@2U
YJD0[Jf]0:FUY@2][Jd0]KFe0<K6aP3>c/h01036a/H20;Fe]@80[Jf]0100YJFU09BDU024Q8@0Ng]k
06][J`1JFUX020P8024Q8@12@T80:BTY059BDP1[Jf/0@T92059BDP1JFUX0S8b<0P2UYJD00`2LW9`0
Ng]k07=cL`0207]kN`040:f][@36a/H0c/k>0>o_k`H0moOg00<0kno_0?Ogm`3gmoL02`3gmoLO0?oo
o`/0moOg00<0inOW0?Ogm`3gmoL00P3gmoL01036a/H0@T92034a<@0a<C4202TY:@04034a<@0Q8B40
61PH02TY:@<0]KFe0`2m_Kd20<K6aP090;fm_@2e]KD0[Jf]0;fm_@36a/H0e]KF0<K6aP2e]KD0[Jf]
00<0U9BD00<0S8b<08B4Q02LW9`01@2][Jd20:FUY@80W9bL00<0S8b<08B4Q01kNg/00P1[Jf/01012
@T80<C4a01PH600820P201PH600703Ti>@0a<C40BTY:024Q8@12@T80DU9B06=SH`0207]kN`0305YJ
FP1SHf<0DU9B0080FUYJ00<0U9BD0:FUY@36a/H05@3gmoLS0?ooo`008@3oool@0?;blP030:2PX01<
C4`020P800805ADE0P0S8b<300000080iNGU0`3bl_800`3UiND0l_;b0?;blP040?;blP<0iNGU00<0
l_;b0>GUi@2k^k/00P38b<P00`2k^k/0b<S80>GUi@030>GUi@030?;blP3UiND0iNGU00<0iNGU00D0
emOG0<S8b038b<P0^k^k0:2PX00207IfMP0=01DE5@000000000002<S8`0b<S80?clo04a<C00S8b<0
5ADE05YJFP2PX:00[Zj^0<S8b00208B4Q00605YJFP24Q8@0X:2P0=OGe`2PX:00b<S85@3bl_8O0?oo
o`H0moOg00@0kno_0?Ogm`3_knl0kno_1@3gmoL0103_knl0Hf=S06=SH`0i>CT20492@P80BTY:00H0
8B4Q02TY:@0Q8B40a/K60<k>cP36a/H70=KFeP070<k>cP36a/H0e]KF0=KFeP3>c/h0a/K60:f][@03
0:FUY@040:f][@2e]KD0a/K60<K6aP80c/k>1036a/H0302e]KD0[Jf]0:f][@2][Jd0W9bL08B4Q01k
Ng/0Lg=c06=SH`0@410061PH03Ti>@80FUYJ00P0Hf=S04Y:BP1BDU80BTY:08B4Q02DU9@0[Jf]0;fm
_@80Lg=c00P0Ng]k09BDU02m_Kd0a/K60<k>cP3gmoL0kno_0?Ogm`80kno_2`3gmoL00`3_knl0moOg
0?Ogm`020?Ogmal0oooo3`3gmoL0103WinL0Jf][0492@P0Q8B4402TY:@0601PH600@410061PH0:f]
[@2m_Kd0]KFe0P2m_Kd00`36a/H0_Kfm0;fm_@020;fm_@80]KFe0`36a/H0102e]KD0[Jf]08b<S024
Q8@208b<S00309BDU02][Jd0]KFe00<0]KFe00D0[Jf]0:FUY@2][Jd0YJFU09bLW00208b<S00:08B4
Q01cLg<0Jf][059BDP12@T80<C4a00P8200@4100@T9203Ti>@80@T9200h0:BTY034a<@1BDU80FUYJ
06][J`2<S8`0BTY:05YJFP1BDU80FUYJ06][J`2LW9`0Q8B40;fm_AD0moOg8`3oool00240oooo3`3b
l_80103UiND0Q8B4038b<P0820P3038b<P@0000000<0iNGU0?;blP3UiND01P3UiND60?;blP80iNGU
00D0^k^k0<S8b038b<P0b<S80=OGe`030>GUi@<0l_;b103UiND20=OGe`060;^k^`38b<P0[Zj^07If
MP1JFUX0?clo0P00000201DE5@80<S8b00H0FUYJ038b<P1YJFT0TI6A0:j^[P38b<P208B4Q00505YJ
FP1YJFT0Q8B40:j^[P38b<P05P3bl_8O0?ooo`80kno_0P3gmoL00`3_knl0moOg0?Ogm`030?Ogm`03
0>o_k`3gmoL0moOg0080moOg00D0kno_06=SH`1:BTX0>CTi059BDP0204Y:BP0501PH600Y:BT08B4Q
03Ti>@3>c/h02@3Fe]H01@36a/H0c/k>0<K6aP3Fe]H0a/K60080]KFe00@0YJFU0:f][@2][Jd0]KFe
1036a/H00`3>c/h0a/K60<K6aP020<K6aP80]KFe0P2][Jd02@2UYJD0U9BD08B4Q01cLg<0Jf][010@
400a<C40:BTY0492@P02059BDP0>06=SH`1BDU80DU9B08b<S02DU9@0[Jf]0<k>cP1kNg/0Jf][07]k
N`24Q8@0[Jf]0<K6aP3_knl<0?Ogm`040>o_k`3gmoL0moOg0?Ogm`80kno_0`3gmoLO0?oooa00moOg
00@0Jf][02TY:@0Q8B40>CTi0P0a<C401P0@410061PH010@400Y:BT0[Jf]0;fm_@L0a/K60P2m_Kd2
0;Fe]@040;fm_@2e]KD0]KFe09bLW080S8b<0P2DU9@00`2LW9`0[Jf]0:f][@040;Fe]@060:f][@2U
YJD0[Jf]09bLW02DU9@0S8b<0P24Q8@01@1[Jf/0DU9B04Y:BP0a<C4020P80080:BTY0`0a<C400`0i
>CT0<C4a05YJFP0206=SH`0808b<S01JFUX0BTY:04Y:BP1JFUX0Hf=S09BDU02m_KdF0?Ogmb<0oooo
000Q0?oooa00l_;b00H0Q8B402<S8`0S8b<0<S8b01DE5@0S8b<3000000030:j^[P3UiND0l_;b00@0
iNGU0P3bl_801@3UiND0l_;b0?;blP3bl_80iNGU0080l_;b0P3UiND20<S8b0<0emOG0P3UiND40?;b
lP@0iNGU00<0emOG0<S8b038b<P00P2k^k/00`24Q8@0FUYJ04a<C0030000000@038b<P0o?cl08b<S
04a<C00b<S80FUYJ0:2PX02k^k/0b<S807IfMP2PX:00?clo08B4Q01fMWH0emOG0<S8b1H0l_;b7`3o
ool30?Ogm`030>o_k`3gmoL0moOg00<0moOg00<0kno_0?Ogm`3_knl0103_knl0101JFUX0BTY:04Y:
BP1BDU8204Y:BP0502TY:@0Q8B40:BTY0:f][@3>c/h0103Fe]H30=kNgP<0e]KF00D0c/k>0<K6aP3F
e]H0a/K60;Fe]@030:f][@040;Fe]@2m_Kd0a/K60<k>cP80a/K600<0e]KF0<k>cP36a/H00P36a/H3
0;Fe]@040:f][@2LW9`0W9bL08B4Q080Jf][00T08B4Q010@400a<C40:BTY05YJFP1:BTX0FUYJ06=S
H`1BDU800P2LW9`0202][Jd0c/k>07=cL`1JFUX0Q8B407=cL`2m_Kd0c/k>503gmoL00`3_knl0moOg
0?ooo`0N0?oooa00moOg00H0Jf][02TY:@0Y:BT0>CTi034a<@0Y:BT301PH600309BDU02e]KD0_Kfm
00@0a/K60P3>c/h01@36a/H0_Kfm0;fm_@2m_Kd0]KFe0080_Kfm00L0[Jf]09bLW02DU9@0S8b<09BD
U02LW9`0YJFU00@0]KFe00<0_Kfm0;Fe]@2e]KD00P2][Jd209bLW00=09BDU024Q8@0Ng]k07=cL`1B
DU80BTY:0492@P0H61P020P801PH600i>CT0@T9202TY:@02034a<@0;059BDP24Q8@0Lg=c08B4Q01B
DU80Hf=S0492@P1SHf<0DU9B09BDU02m_Kd05P3gmoLS0?ooo`008@3oool?0?;blP0405YJFP1<C4`0
000002<S8`805ADE00<0<S8b00P8200000001@3UiND20?;blP80iNGU00<0l_;b0>GUi@3UiND00`3U
iND40?;blP030<S8b03GemL0emOG0080emOG00H0iNGU0?;blP3UiND0l_;b0>GUi@3bl_840>GUi@80
emOG0P38b<P01@2k^k/0X:2P08B4Q01<C4`05ADE008020P80P0b<S80101JFUX0C4a<04a<C024Q8@3
0;^k^`060:2PX01fMWH0<S8b06UYJ@2ATI40^k^k5`3bl_8O0?ooo`030>o_k`3gmoL0moOg00@0moOg
00@0kno_0?Ogm`3gmoL0kno_103gmoL0101cLg<0DU9B034a<@1JFUX204Y:BP0302TY:@0i>CT0>CTi
0080a/K60`3Fe]H20=kNgP80e]KF00<0g]kN0=KFeP3Fe]H00P3Fe]H01`3>c/h0e]KF0=KFeP36a/H0
]KFe0:f][@2e]KD00P2m_Kd00`36a/H0c/k>0=KFeP030=KFeP030<K6aP3>c/h0c/k>0080a/K600<0
_Kfm0;Fe]@2][Jd00P2LW9`00`1kNg/0Jf][04Y:BP0303Ti>@05059BDP1SHf<0Hf=S05YJFP1cLg<0
0`2LW9`01`2][Jd0S8b<04Y:BP1kNg/0U9BD0:f][@3Ng]h03P3gmoL01@3_knl0moOg0?Ogm`3gmoL0
kno_00<0moOg7`3oool?0?Ogm`04059BDP0a<C408B4Q0492@P<0<C4a00@08B4Q02TY:@2][Jd0]KFe
0`36a/H20<k>cP80a/K600<0c/k>0<K6aP36a/H00P36a/H40;fm_@040;Fe]@2DU9@0W9bL09bLW080
YJFU00H0]KFe0;fm_@2m_Kd0_Kfm0<K6aP2e]KD30;fm_@0:0;Fe]@2UYJD0W9bL09BDU02<S8`0Ng]k
05YJFP1BDU80@T92034a<@808B4Q00L0>CTi034a<@0i>CT0@T9205YJFP1[Jf/0Ng]k0080Lg=c00H0
Hf=S03Ti>@0Y:BT0FUYJ07]kN`2<S8`G0?Ogmb<0oooo000Q0?ooo`l0l_;b00X0MWIf05YJFP0820P0
?clo038b<P0S8b<05ADE0000001YJFT0l_;b0`3UiND20?;blP050>GUi@3bl_80iNGU0?;blP3UiND0
0P3bl_80103UiND0l_;b0?;blP3UiND20?;blP80b<S80P3GemL60>GUi@<0l_;b0`3UiND03`3GemL0
b<S80<S8b02k^k/0X:2P08B4Q01<C4`0?clo0000000820P05ADE038b<P1<C4`0FUYJ04a<C0050;^k
^`<0MWIf00<0Q8B40<S8b03bl_805P3bl_8O0?ooo`030>o_k`3gmoL0moOg00L0moOg0100kno_0?Og
m`3gmoL0kno_0?Ogm`1cLg<0BTY:03Ti>@1JFUX0DU9B04Y:BP0i>CT0:BTY08B4Q036a/H0c/k>0P3F
e]H20=kNgPD0e]KF00<0g]kN0=KFeP3Fe]H00P3Fe]H20<K6aP040;Fe]@2][Jd0[Jf]0;fm_@80a/K6
0P3>c/h20=KFeP80a/K600<0e]KF0<k>cP36a/H00P36a/H01`2m_Kd0[Jf]0:FUY@2LW9`0Q8B406][
J`1:BTX00P0a<C400`0i>CT0BTY:06=SH`0206=SH`0;05YJFP2LW9`0W9bL09bLW02UYJD0[Jf]06][
J`1cLg<0Q8B40:f][@3_knl02P3gmoL00`3_knl0moOg0>o_k`090?Ogmal0oooo3`3gmoL01@1BDU80
>CTi024Q8@12@T80>CTi0080:BTY00@061PH07=cL`2e]KD0_Kfm0P36a/H20<k>cP050<K6aP2m_Kd0
a/K60;fm_@36a/H00P3>c/h01036a/H0_Kfm0;fm_@36a/H20;Fe]@80U9BD00<0W9bL0:FUY@2][Jd0
0`2m_Kd20<K6aP030;Fe]@2m_Kd0]KFe0080]KFe00T0[Jf]0:FUY@2DU9@0S8b<08B4Q01SHf<0DU9B
0492@P0a<C400P0Q8B42034a<@030492@P0i>CT0<C4a00@0Lg=c00H0Q8B40492@P12@T80DU9B06=S
H`24Q8@G0?Ogmb<0oooo000Q0?ooo`l0l_;b0P1JFUX201DE5@80<S8b00@00000038b<P3UiND0l_;b
1`3UiND00`3bl_80iNGU0>GUi@030>GUi@070?;blP3UiND0iNGU0>GUi@3bl_80emOG0<S8b0030=OG
e`D0iNGU00<0l_;b0>GUi@3UiND00P3UiND30=OGe`070<S8b02k^k/0[Zj^08B4Q01JFUX0<S8b01DE
5@0200P82004038b<P1<C4`0?clo038b<P80^k^k00@0X:2P0;^k^`38b<P0C4a<0P1fMWH00`1YJFT0
^k^k0?;blP0F0?;blQl0oooo0`3gmoL00`3_knl0moOg0?Ogm`080?Ogm`0:0>o_k`1cLg<0DU9B04Y:
BP12@T80DU9B04Y:BP12@T80DU9B0<K6aP80c/k>1`3Fe]H00`3>c/h0e]KF0=KFeP030=KFeP040<K6
aP3Fe]H0e]KF0;fm_@80[Jf]0P2m_Kd20<K6aP80c/k>00@0e]KF0<k>cP3Fe]H0c/k>1036a/H04@2m
_Kd0[Jf]0:FUY@2LW9`0U9BD07]kN`1BDU80@T92034a<@0i>CT0DU9B05YJFP1SHf<0DU9B04Y:BP2L
W9`0U9BD0080W9bL00H0[Jf]07=cL`1cLg<0Q8B40:f][@3_knlF0?Ogmal0oooo3`3gmoL2059BDP06
034a<@0Y:BT0>CTi034a<@0Q8B40>CTi0P2e]KD00`2m_Kd0a/K60<K6aP040<K6aP80_Kfm1036a/H0
1@2m_Kd0]KFe0<K6aP36a/H0_Kfm0080U9BD00@0W9bL0:FUY@2UYJD0]KFe0`2m_Kd00`36a/H0_Kfm
0;fm_@020;Fe]@80[Jf]0P2UYJD01`2DU9@0Q8B406][J`1JFUX0BTY:03Ti>@0Y:BT00P0Q8B402P0i
>CT0<C4a04Y:BP0Y:BT0S8b<07=cL`1[Jf/0Ng]k08b<S00a<C42059BDP0306][J`24Q8@0moOg01H0
moOg8`3oool00240oooo3P3bl_80302ATI40C4a<03lo?`0o?cl0<S8b03lo?`0820P000000=OGe`3b
l_80iNGU0?;blP<0iNGU00@0l_;b0>GUi@3UiND0l_;b103UiND30?;blP80iNGU00<0l_;b0=OGe`38
b<P00P38b<P30=OGe`D0iNGU00@0emOG0>GUi@3UiND0iNGU0P3GemL30<S8b0040:2PX01JFUX0C4a<
01DE5@8020P800@05ADE05YJFP0o?cl0?clo0P2PX:020;^k^`060=OGe`0b<S80FUYJ096AT@2PX:00
[Zj^5`3bl_8O0?ooo`060>o_k`3gmoL0moOg0>o_k`3gmoL0kno_1P3gmoL03@3_knl0moOg0:f][@1J
FUX0DU9B05YJFP1BDU80BTY:03Ti>@12@T80a/K60=KFeP36a/H0103Fe]H0103Ng]h0e]KF0=KFeP3>
c/h20<K6aP050<k>cP3Fe]H0e]KF0<K6aP3>c/h00P3Fe]H02@36a/H0[Jf]0:f][@2][Jd0_Kfm0:f]
[@36a/H0c/k>0=KFeP030<k>cPD0a/K600@0_Kfm0:f][@2][Jd0YJFU0P24Q8@01P1JFUX0BTY:02TY
:@0i>CT0BTY:06][J`<0FUYJ00T0U9BD09bLW02LW9`0Jf][0;fm_@1[Jf/0S8b<09BDU02][Jd03@3g
moL00`3_knl0moOg0?Ogm`070?Ogmal0oooo3P3gmoL0102][Jd0<C4a04Y:BP12@T82034a<@06024Q
8@0Y:BT0[Jf]0;fm_@2e]KD0_Kfm0`36a/H0103>c/h0a/K60<K6aP2m_Kd20;Fe]@<0_Kfm0P2e]KD2
0<K6aP040;fm_@2DU9@0S8b<09BDU080W9bL00@0]KFe0;fm_@2e]KD0a/K60P2m_Kd30;Fe]@80[Jf]
0P2UYJD01@2LW9`0S8b<07=cL`1SHf<0BTY:0080<C4a0P0Q8B401P0a<C40BTY:0492@P12@T80Q8B4
06][J`80Lg=c00H0U9BD024Q8@1:BTX0Hf=S06][J`2DU9@G0?Ogmb<0oooo000Q0?ooo`h0l_;b00/0
JFUY08B4Q01JFUX0FUYJ01DE5@0o?cl0000001DE5@3GemL0l_;b0=OGe`040>GUi@050?;blP3UiND0
iNGU0>GUi@3GemL01@3UiND20?;blP050>GUi@3bl_80emOG0<S8b02k^k/00P38b<P00`3GemL0iNGU
0>GUi@060=OGe`0B0>GUi@3GemL0emOG0;^k^`3GemL0b<S80;^k^`2PX:00MWIf04a<C00b<S800000
00P8200E5AD0?clo05YJFP0o?cl0X:2P0P2^[Zh01`2k^k/0b<S804a<C00o?cl0Q8B40;^k^`3GemL0
5`3bl_8O0?ooo`80moOg00@0kno_0?Ogm`3gmoL0kno_1P3gmoL01P3_knl0moOg07]kN`2<S8`0BTY:
06][J`80BTY:00<0<C4a04Y:BP36a/H00P36a/H00`3Fe]H0g]kN0=KFeP030=KFeP030<k>cP2e]KD0
a/K60080a/K600@0c/k>0=KFeP3>c/h0c/k>0P3Fe]H00`36a/H0YJFU0:f][@020:f][@030;fm_@36
a/H0a/K60080a/K600<0_Kfm0<K6aP36a/H01@36a/H0302m_Kd0[Jf]0:FUY@2LW9`0Q8B405YJFP1:
BTX0:BTY024Q8@1:BTX0FUYJ06=SH`80FUYJ0P2DU9@01`2LW9`0BTY:0:f][@1JFUX0Q8B40:FUY@36
a/H00P3gmoL00`3_knl0moOg0?Ogm`080?Ogm`030>o_k`3gmoL0moOg00L0moOg7`3oool>0?Ogm`04
06][J`1cLg<0BTY:04Y:BP80<C4a00D08B4Q034a<@2][Jd0]KFe0:f][@040<K6aP040;fm_@36a/H0
_Kfm0;fm_@<0[Jf]00P0]KFe0;fm_@2e]KD0]KFe0;fm_@36a/H0_Kfm09BDU080S8b<0P2DU9@20;Fe
]@030;fm_@2][Jd0[Jf]00L0[Jf]00H0YJFU09bLW02<S8`0Lg=c06=SH`1BDU82034a<@07010@400Q
8B40<C4a0492@P0i>CT0@T9208B4Q00206][J`0707=cL`24Q8@0@T920492@P1[Jf/0Q8B40:f][@0G
0?Ogmb<0oooo000Q0?ooo`d0l_;b00<0oooo05YJFP1YJFT00P0b<S80201<C4`00000038b<P0b<S80
[Zj^0<S8b03UiND0l_;b0`3UiND01P3GemL0b<S8096AT@24Q8@0[Zj^096AT@80b<S80`3UiND30?;b
lP040<S8b02k^k/0X:2P0;^k^`<0emOG00@0b<S80:2PX02ATI40Q8B40`2PX:000`2^[Zh0emOG0<S8
b0030<S8b080X:2P00@0Q8B404a<C00b<S8020P80P000002038b<P0303lo?`24Q8@0TI6A0080Q8B4
00H0emOG04a<C00o?cl0X:2P0;^k^`3GemLG0?;blQl0oooo1`3gmoL00`3_knl0moOg0>o_k`030?Og
m`0<0?ooo`1[Jf/0Ng]k05YJFP1BDU80FUYJ024Q8@1BDU80a/K609BDU02UYJD0c/k>0`3Fe]H0103>
c/h0a/K60:f][@2<S8`20:FUY@0409BDU02][Jd0c/k>0<k>cP80a/K60P3Fe]H03036a/H0[Jf]09bL
W02LW9`0_Kfm0:f][@36a/H0[Jf]0:FUY@2LW9`0Q8B408b<S080W9bL00<0YJFU0;fm_@2m_Kd00`2]
[Jd0202UYJD0W9bL08B4Q01JFUX0DU9B04Y:BP0i>CT0<C4a0P1BDU800`1SHf<0FUYJ08b<S00207]k
N`0305YJFP2m_Kd0BTY:0080W9bL00<0e]KF0?ooo`3gmoL05@3gmoLO0?ooo`d0moOg00<0oooo04Y:
BP1SHf<00P0i>CT02012@T80410@034a<@0a<C40Jf][08B4Q02e]KD0_Kfm0P36a/H01`2m_Kd0]KFe
09bLW01kNg/0Lg=c09BDU01kNg/00P2LW9`00`2m_Kd0]KFe0;Fe]@030;fm_@0609BDU01kNg/0Q8B4
07]kN`2LW9`0]KFe0`2LW9`00`2<S8`0Lg=c08B4Q00208B4Q00309BDU02UYJD0W9bL0080W9bL00H0
S8b<08B4Q01[Jf/0FUYJ0492@P0i>CT3024Q8@0503Ti>@0a<C40@T9206][J`1SHf<00P1JFUX01P2D
U9@0<C4a034a<@24Q8@0Lg=c0<k>cQL0moOg8`3oool00240oooo3@3bl_800`2ATI40JFUY05YJFP02
01DE5@0604a<C0000000C4a<0>GUi@3GemL0^k^k103UiND0203GemL0Q8B4096AT@38b<P0TI6A01DE
5@1YJFT0X:2P0P38b<P00`3UiND0emOG0?;blP020?;blP050=OGe`2k^k/0^k^k096AT@2k^k/00P2P
X:000`2k^k/0b<S804a<C00406UYJ@0308B4Q038b<P0b<S80080b<S800L0^k^k0:j^[P2PX:00Q8B4
05YJFP0o?cl0<S8b008000000P0b<S800`1JFUX0Q8B4096AT@0208B4Q0030=OGe`1JFUX0FUYJ0080
^k^k00<0iNGU0?;blP3bl_805@3bl_8O0?ooo`070>o_k`3gmoL0moOg0?Ogm`3_knl0moOg0>o_k`06
0?Ogm`0;09bLW01kNg/0Lg=c059BDP1:BTX0FUYJ034a<@1JFUX0]KFe08b<S02UYJD00P3>c/h02`3F
e]H0a/K60:f][@24Q8@0S8b<0:f][@1[Jf/0Lg=c08B4Q02LW9`0Q8B400<0a/K60P3Fe]H02`36a/H0
]KFe09bLW02DU9@0YJFU04Y:BP1JFUX0Q8B40<K6aP1kNg/0FUYJ00<0Ng]k00<0Q8B40:FUY@2][Jd0
0P2][Jd20:FUY@0709BDU024Q8@0Jf][05YJFP1:BTX0DU9B02TY:@02059BDP0805YJFP1[Jf/0U9BD
07=cL`1kNg/0DU9B0;fm_@1cLg<20:f][@030>OWi`3gmoL0moOg00X0moOg00<0kno_0?Ogm`3gmoL0
203gmoLO0?ooo`d0moOg00<0U9BD05YJFP1BDU800P0a<C402`12@T808B4Q034a<@2DU9@0Ng]k08b<
S02e]KD0_Kfm0<K6aP2e]KD0W9bL0080Hf=S00D0W9bL0:f][@1[Jf/0Lg=c08B4Q00207=cL`030;Fe
]@2][Jd0_Kfm0080_Kfm00l0W9bL07]kN`24Q8@0Ng]k08B4Q01:BTX0Jf][08b<S036a/H0Lg=c06][
J`1SHf<0FUYJ06=SH`1[Jf/00P2DU9@209bLW00708b<S01[Jf/0Jf][059BDP1:BTX0@T9203Ti>@02
01PH6080>CTi00P0BTY:06=SH`1kNg/0BTY:05YJFP2LW9`0>CTi059BDP80Q8B400<0inOW0?Ogm`3g
moL05@3gmoLS0?ooo`008@3oool=0?;blP0K08B4Q02ATI40FUYJ03lo?`0b<S80C4a<00P820000000
l_;b0=OGe`38b<P0iNGU0?;blP3UiND0emOG08B4Q02PX:00^k^k0=OGe`0S8b<00000038b<P1YJFT0
X:2P096AT@38b<P0iNGU0080l_;b00X0iNGU0=OGe`38b<P0TI6A08B4Q02PX:00MWIf0<S8b03UiND0
?clo0P1<C4`0100820P0TI6A05YJFP0o?cl20;^k^`80b<S80P2k^k/01024Q8@0MWIf05YJFP0b<S83
00000003038b<P0o?cl0FUYJ0080Q8B400D0FUYJ06UYJ@38b<P0<S8b096AT@020;^k^aP0l_;b7`3o
ool90?Ogm`0C0>o_k`3gmoL0moOg0?Ogm`24Q8@0W9bL07=cL`0a<C40DU9B05YJFP0a<C40:BTY0:f]
[@2UYJD0[Jf]0<k>cP3Fe]H0a/K60:f][@0208B4Q0040;fm_@1cLg<0Jf][05YJFP80Ng]k00T0U9BD
0:f][@2][Jd0a/K60=KFeP3>c/h0a/K60;Fe]@2UYJD00P24Q8@00`2LW9`0@T920<K6aP0207=cL`06
06][J`2<S8`0Hf=S07=cL`1[Jf/0Q8B40P2UYJD0502][Jd0YJFU09bLW02LW9`0Q8B406][J`1BDU80
BTY:034a<@0Q8B40DU9B05YJFP12@T80Jf][08B4Q01[Jf/0Ng]k06=SH`2][Jd0U9BD0P2][Jd>0?Og
m`030>o_k`3gmoL0moOg00L0moOg7`3oool=0?Ogm`0606][J`2<S8`0DU9B04Y:BP0i>CT0@T920P0H
61P00`2e]KD0U9BD09BDU0030;fm_@0=09bLW01[Jf/0Jf][0;Fe]@3>c/h0Lg=c059BDP1cLg<0Jf][
08B4Q01kNg/0U9BD0:FUY@020;fm_@040;Fe]@2LW9`0Q8B407]kN`80Jf][00P0<C4a0<K6aP3WinL0
Hf=S05YJFP24Q8@0FUYJ09BDU080DU9B0P24Q8@05@2DU9@0S8b<08b<S01cLg<0Jf][059BDP1:BTX0
<C4a024Q8@0820P061PH03Ti>@12@T80BTY:06][J`1SHf<0BTY:05YJFP2<S8`0:BTY07]kN`0208b<
S1P0moOg8`3oool00240oooo303bl_801@3oool0l_;b06UYJ@0b<S808b<S00<0<S8b00D0C4a<0?;b
lP3GemL0b<S80=OGe`020>GUi@0=096AT@1<C4`0000008B4Q02PX:00C4a<0000000b<S80000004a<
C024Q8@0emOG0>GUi@030?;blP80emOG00l0TI6A08B4Q01JFUX0TI6A05YJFP2^[Zh0000008B4Q00E
5AD00000096AT@0000005ADE08B4Q02ATI400`2k^k/20:2PX00307IfMP1<C4`0<S8b00@0000000<0
<S8b07IfMP1JFUX00P1YJFT01P24Q8@0^k^k038b<P2ATI40^k^k0<S8b1P0l_;b7`3oool<0?Ogm`05
0?ooo`3_knl0Q8B4059BDP0a<C400`1BDU80:01JFUX0YJFU08b<S02][Jd0a/K60<k>cP2][Jd0U9BD
07=cL`0i>CT0U9BD07]kN`2e]KD061PH07=cL`1:BTX0Q8B409BDU02e]KD0c/k>0=KFeP3>c/h0a/K6
0;fm_@2e]KD0S8b<07=cL`2<S8`0U9BD06][J`1JFUX0_Kfm01PH601cLg<0FUYJ034a<@1BDU80Ng]k
08b<S02DU9@20:FUY@80U9BD00@0Q8B405YJFP1BDU80BTY:0P0Q8B40100Y:BT0DU9B04Y:BP1cLg<3
07]kN`0506=SH`2][Jd0S8b<09bLW036a/H0603gmoLO0?ooo``0moOg00D0oooo0?Ogm`1[Jf/0<C4a
02TY:@0303Ti>@040492@P2e]KD0Ng]k09BDU080]KFe00h0[Jf]07]kN`1JFUX0:BTY08b<S02e]KD0
Jf][01PH601[Jf/0@T9205YJFP1[Jf/0W9bL0:f][@80_Kfm01`0]KFe09bLW02DU9@0Ng]k07=cL`1B
DU80Ng]k04Y:BP2m_Kd0DU9B0<k>cP1[Jf/0DU9B09BDU00Y:BT0@T9207=cL`1kNg/0Q8B408b<S024
Q8@0Jf][06=SH`1BDU80@T9203Ti>@0H61P0410@0P0H61P00`0i>CT0DU9B059BDP0305YJFP0508B4
Q00Y:BT0Hf=S07]kN`2e]KD0603gmoLS0?ooo`008@3oool<0?;blP0508B4Q02k^k/0JFUY04a<C00S
8b<00P0b<S801@1<C4`0[Zj^0>GUi@2k^k/0b<S80080iNGU00<0emOG0:2PX00E5AD00P0b<S820000
0006038b<P0o?cl0<S8b06UYJ@2ATI40iNGU103bl_801P3UiND0emOG0<S8b02ATI40X:2P04a<C080
JFUY0`000000100E5AD0000001DE5@0S8b<208B4Q0030:j^[P2k^k/0^k^k0080Q8B400@0C4a<03lo
?`0o?cl020P80P00000200P8200:05YJFP1fMWH0FUYJ05YJFP24Q8@0^k^k04a<C02ATI40^k^k0>GU
iAP0l_;b7`3oool<0?Ogm`0509BDU036a/H0S8b<07=cL`1:BTX00P1BDU802P1JFUX0Lg=c08b<S02L
W9`0[Jf]0<K6aP3>c/h0YJFU08B4Q01:BTX206=SH`0@02TY:@0i>CT0DU9B06][J`1SHf<0U9BD0:f]
[@2m_Kd0c/k>0=KFeP3>c/h0a/K60;fm_@2e]KD0U9BD08B4Q080Lg=c00<0S8b<03Ti>@0Y:BT00P0i
>CT0101:BTX0FUYJ059BDP1kNg/208B4Q080W9bL00<0U9BD08B4Q01kNg/00P1JFUX00`1:BTX0>CTi
03Ti>@0203Ti>@0:04Y:BP1[Jf/0Jf][06=SH`1kNg/0Lg=c0:f][@2<S8`0W9bL0>OWia40moOg00<0
kno_0?Ogm`3gmoL0103gmoLO0?ooo``0moOg00D0Ng]k0<K6aP1cLg<0FUYJ0492@P0203Ti>@050492
@P1SHf<0W9bL07]kN`2<S8`00P2e]KD00`2LW9`0Jf][034a<@02059BDP0303Ti>@0Q8B40>CTi0080
DU9B00<0Hf=S07]kN`2LW9`00P2e]KD0202m_Kd0]KFe09bLW02LW9`0Q8B407]kN`1[Jf/0FUYJ0P24
Q8@0200Y:BT061PH02TY:@0a<C40>CTi04Y:BP12@T80Hf=S0P1[Jf/207]kN`0306][J`1JFUX0@T92
0080@T9200<08B4Q01PH600Y:BT00P0Q8B402P1:BTX0DU9B04Y:BP0i>CT0FUYJ08B4Q012@T80Hf=S
07=cL`3Ng]hH0?Ogmb<0oooo000Q0?ooo``0l_;b00<0iNGU06UYJ@1<C4`00`0E5AD01`0820P0FUYJ
0:2PX02^[Zh0TI6A0;^k^`3GemL01@3UiND50=OGe`030;^k^`38b<P0emOG0080l_;b0P3UiND01P3b
l_80iNGU0>GUi@3GemL0^k^k0<S8b0<0^k^k0P2ATI40102^[Zh0^k^k0;^k^`2k^k/20<S8b0<0^k^k
00L0[Zj^096AT@24Q8@0C4a<03lo?`0b<S8020P8008000000P0E5AD02P1JFUX0TI6A05YJFP1JFUX0
X:2P0<S8b01JFUX0TI6A0>GUi@3ooolH0?;blQl0oooo2P3gmoL01@3_knl0moOg0>OWi`2<S8`0Jf][
00<0BTY:00X0>CTi06][J`24Q8@0W9bL09BDU02UYJD0a/K60<k>cP3Fe]H0c/k>0P36a/H02P2m_Kd0
[Jf]0;Fe]@2m_Kd0]KFe09bLW02][Jd0a/K60=KFeP3>c/h20=KFeP80c/k>00@0a/K609bLW02LW9`0
U9BD0P2UYJD409BDU00309bLW02UYJD0[Jf]0080[Jf]00P0YJFU09bLW02DU9@0Q8B408b<S01kNg/0
Hf=S059BDP<0>CTi00<0BTY:0492@P0i>CT00P1[Jf/01`1SHf<0Q8B409BDU02][Jd0U9BD0=kNgP3o
ool05P3gmoL00`3_knl0moOg0?ooo`0N0?ooo``0moOg00`0g]kN07]kN`1BDU80<C4a02TY:@0a<C40
8B4Q04Y:BP1SHf<0Jf][07]kN`2<S8`30;Fe]@040;fm_@2][Jd0]KFe0:FUY@80W9bL00L0YJFU09bL
W01kNg/0Q8B409BDU02m_Kd0]KFe0080a/K600T0_Kfm0:f][@2][Jd0U9BD07=cL`1kNg/0Q8B408b<
S024Q8@00P1kNg/07P1[Jf/0Ng]k08B4Q024Q8@0S8b<09BDU02<S8`0Q8B407]kN`1[Jf/0Hf=S05YJ
FP12@T80BTY:03Ti>@0Q8B4061PH02TY:@0a<C40:BTY04Y:BP1SHf<0BTY:03Ti>@1JFUX0U9BD059B
DP1kNg/0c/k>0?oooaP0moOg8`3oool00240oooo303bl_803P3oool05ADE03lo?`00000020P804a<
C0000000FUYJ08B4Q038b<P0Q8B40;^k^`3UiND0emOG0P3bl_802P3UiND0l_;b0?;blP3UiND0emOG
06UYJ@1JFUX0Q8B40=OGe`3UiND30?;blP080>GUi@3bl_80l_;b0?;blP3UiND0emOG0:2PX01JFUX2
08B4Q0L0emOG00X0b<S80;^k^`2PX:00Q8B40:j^[P24Q8@0MWIf05YJFP0o?cl0<S8b1@0000002@0o
?cl0MWIf05YJFP1<C4`0X:2P0=OGe`1YJFT0X:2P0>GUi@0I0?;blQl0oooo103gmoL00`3_knl0moOg
0?Ogm`020?Ogm`0A0>o_k`3gmoL0moOg0?ooo`12@T80FUYJ034a<@0i>CT0Hf=S034a<@1:BTX0Jf][
09BDU02<S8`0YJFU0<k>cP2m_Kd01@3Fe]H01P2UYJD0Q8B407]kN`1cLg<0Jf][0<K6aPH0e]KF00P0
c/k>0=KFeP2][Jd0Q8B406=SH`1cLg<0Jf][0;fm_@<0a/K600`0_Kfm0;Fe]@2e]KD0]KFe0:f][@2U
YJD0Q8B409BDU02<S8`0Ng]k07=cL`1JFUX2059BDP80:BTY00/0>CTi024Q8@1:BTX0FUYJ06][J`1S
Hf<0S8b<09BDU02m_Kd0W9bL0>OWi`0I0?Ogmal0oooo303gmoL00`3oool0:BTY0492@P02024Q8@04
0492@P0Q8B40<C4a059BDP80Lg=c00H0Q8B40;Fe]@2UYJD0]KFe0;fm_@36a/H20;fm_@030<K6aP2D
U9@0Hf=S0080DU9B00`0W9bL0:FUY@2m_Kd0_Kfm0<k>cP36a/H0_Kfm0;Fe]@2m_Kd0W9bL09BDU01[
Jf/2059BDP0407=cL`2UYJD0[Jf]0:f][@80YJFU0P2LW9`02`2DU9@0Q8B406][J`1SHf<0Jf][05YJ
FP1BDU80BTY:0492@P0a<C40410@008061PH00/0:BTY010@4012@T80DU9B04Y:BP12@T80Hf=S09bL
W01JFUX0Q8B40>OWi`0I0?Ogmb<0oooo000Q0?ooo``0l_;b00P0oooo00P8200S8b<0000000P8200b
<S805ADE05YJFP80Q8B40P2PX:00103UiND0b<S80=OGe`3bl_820>GUi@060?;blP24Q8@0JFUY08B4
Q02k^k/0iNGU1@3bl_800`3UiND0l_;b0?;blP020?;blP080>GUi@3GemL0C4a<038b<P1<C4`0Q8B4
0<S8b03GemL30>GUi@070=OGe`38b<P0TI6A06UYJ@2^[Zh0Q8B407IfMP0205YJFP0303lo?`0820P0
000000<0000000T05ADE04a<C01YJFT0FUYJ04a<C02ATI40^k^k096AT@2PX:006P3bl_8O0?ooo``0
moOg00L0oooo03Ti>@1:BTX0<C4a04Y:BP1BDU80BTY:0080Hf=S00<0S8b<08B4Q02LW9`00`36a/H3
0=KFeP090<K6aP1kNg/0Lg=c06][J`2UYJD0a/K60<k>cP3Fe]H0g]kN00D0e]KF00T0c/k>0<K6aP2]
[Jd0S8b<05YJFP1BDU80Jf][0:FUY@2][Jd00P36a/H0102e]KD0_Kfm0:f][@2UYJD209BDU00508b<
S024Q8@0Lg=c06][J`1JFUX00P0i>CT202TY:@06024Q8@1BDU80FUYJ06][J`1cLg<0FUYJ0P2<S8`0
0`2][Jd0W9bL0?Ogm`0I0?Ogmal0oooo303gmoL00`3oool08B4Q02TY:@02024Q8@0;03Ti>@0a<C40
>CTi0492@P1JFUX0Jf][08B4Q02][Jd0]KFe09bLW02m_Kd00P36a/H01P2e]KD0Jf][06=SH`1BDU80
Q8B40:FUY@80]KFe00@0c/k>0;fm_@3>c/h0a/K60P2m_Kd20;Fe]@070:FUY@2DU9@0@T9203Ti>@12
@T80DU9B08B4Q0030:f][@0809bLW02UYJD0Q8B407]kN`1JFUX0Jf][07=cL`1BDU8204Y:BP0?0492
@P0Q8B4061PH024Q8@0H61P0410@0492@P1BDU80FUYJ059BDP0a<C40Hf=S08b<S01kNg/0Q8B401X0
moOg8`3oool00240oooo2`3bl_820?ooo`06038b<P0E5AD05ADE01DE5@0b<S808b<S0`1<C4`01@24
Q8@0X:2P0=OGe`3UiND0TI6A0080^k^k00@0b<S808B4Q01fMWH0^k^k1`3bl_830>GUi@030?;blP3U
iND0l_;b0080l_;b00`0emOG0;^k^`24Q8@0C4a<03lo?`1fMWH0[Zj^08B4Q02PX:00Q8B406UYJ@24
Q8@2096AT@060<S8b01fMWH0FUYJ05YJFP0b<S80FUYJ0P0E5AD02`0820P000000000001JFUX0MWIf
05YJFP1<C4`0TI6A08B4Q01fMWH0b<S801X0l_;b7`3oool90?Ogm`0:0>o_k`3gmoL0oooo0?ooo`1B
DU80@T9204Y:BP0a<C40DU9B04Y:BP80FUYJ00`0Ng]k08B4Q02LW9`0a/K60<k>cP2LW9`0YJFU09bL
W024Q8@0Jf][09bLW03>c/h20=KFePD0g]kN1@3Fe]H30<k>cP070;Fe]@2UYJD0Lg=c05YJFP1cLg<0
Hf=S06][J`0208B4Q080Ng]k00/0Q8B409BDU024Q8@0S8b<07=cL`1[Jf/0DU9B06][J`0Q8B40@T92
03Ti>@0202TY:@0806=SH`1[Jf/0Jf][06=SH`2<S8`0W9bL08B4Q03>c/h>0?Ogm`030>o_k`3gmoL0
moOg00T0moOg7`3oool;0?Ogm`80oooo00L0<C4a02TY:@0a<C40<C4a03Ti>@0Y:BT0<C4a0080@T92
00P0Jf][08B4Q02e]KD0_Kfm07]kN`24Q8@0Ng]k07=cL`80DU9B00<0Ng]k0;fm_@2m_Kd01@3>c/h3
0<K6aP030;fm_@36a/H0]KFe0080]KFe00@0W9bL08B4Q01cLg<0FUYJ0P12@T801P1JFUX0Lg=c06][
J`1SHf<0FUYJ06][J`80Ng]k00H0Lg=c059BDP1:BTX0BTY:03Ti>@1:BTX202TY:@0;024Q8@0H61P0
8B4Q04Y:BP1BDU80BTY:0492@P1SHf<0Jf][0492@P2m_Kd06P3gmoLS0?ooo`008@3oool<0?;blP03
05YJFP0E5AD05ADE0080<S8b0P0E5AD01P0b<S80C4a<03lo?`1YJFT0^k^k0=OGe`80iNGU00D0^k^k
096AT@38b<P0b<S80>GUi@080?;blP80iNGU103bl_800`3UiND0l_;b0?;blP030>GUi@040=OGe`2P
X:00JFUY07IfMP80JFUY00T0X:2P096AT@2^[Zh0^k^k0:j^[P1fMWH0FUYJ07IfMP0b<S800P0820P4
0000000804a<C00o?cl0JFUY07IfMP2PX:00FUYJ096AT@3UiNDJ0?;blQl0oooo2@3gmoL0103_knl0
moOg0?Ogm`1cLg<204Y:BP0@06=SH`1:BTX0BTY:04Y:BP1BDU80FUYJ07=cL`1kNg/0YJFU0<K6aP3>
c/h0a/K60:FUY@2LW9`0Q8B40:f][@T0g]kN00@0e]KF0=kNgP3Ng]h0g]kN0`3Fe]H00`3>c/h0a/K6
0<K6aP030<K6aP0:09bLW01kNg/0Ng]k07]kN`2DU9@0W9bL09BDU02LW9`0U9BD08b<S080Lg=c00@0
DU9B03Ti>@1:BTX0>CTi0P0H61P02@0Q8B40Hf=S07=cL`1kNg/0Hf=S09BDU02LW9`0Jf][0>OWi`0@
0?Ogm`030>o_k`3gmoL0moOg00L0moOg7`3oool<0?Ogm`05059BDP0a<C40<C4a04Y:BP0i>CT00P0a
<C401@0i>CT0<C4a04Y:BP1JFUX0Q8B400<0]KFe00D0Q8B408b<S01cLg<0W9bL0<K6aP070<k>cP03
0=KFeP36a/H0a/K60080c/k>0P2m_Kd00`36a/H0_Kfm0;Fe]@040:f][@0308B4Q01SHf<0DU9B0080
Hf=S00D0Q8B407]kN`1[Jf/0Lg=c06][J`03059BDP0403Ti>@0Q8B408B4Q024Q8@80410@00T061PH
05YJFP12@T80FUYJ0492@P1[Jf/0BTY:06=SH`3WinL06P3gmoLS0?ooo`008@3oool<0?;blP07038b
<P0E5AD0<S8b06UYJ@1<C4`0<S8b02<S8`02038b<P0403lo?`1JFUX0^k^k0=OGe`80iNGU0P3bl_80
103UiND0l_;b0?;blP3UiND80?;blP050>GUi@3bl_80iNGU0?;blP3UiND01@3bl_820>GUi@050=OG
e`3UiND0emOG0=OGe`38b<P00`2k^k/00`2ATI40X:2P08B4Q00207IfMP0303lo?`1JFUX0000000@0
000000@0JFUY03lo?`2ATI40MWIf0P1JFUX00`2k^k/0oooo0?;blP0I0?;blQl0oooo1P3gmoL00`3_
knl0moOg0?Ogm`030?Ogm`0504Y:BP1BDU80FUYJ08b<S01BDU80101JFUX0101kNg/0Lg=c09bLW036
a/H20<k>cP<0e]KF00<0g]kN0=KFeP3Fe]H01`3Ng]h01@3Fe]H0g]kN0=KFeP3Fe]H0g]kN00@0e]KF
1036a/H0102m_Kd0a/K60;Fe]@2][Jd20:FUY@0E09bLW02DU9@0U9BD08b<S01[Jf/0Lg=c05YJFP1[
Jf/0@T9202TY:@0Q8B40<C4a024Q8@2DU9@0Ng]k09BDU01cLg<0Jf][0:f][@1[Jf/0oooo01X0moOg
7`3oool<0?Ogm`0502TY:@12@T80@T9207=cL`1BDU801@12@T800`1BDU80Ng]k0:f][@020;Fe]@80
_Kfm00@0a/K60<k>cP3>c/h0a/K60`3>c/h02P2m_Kd0c/k>0<k>cP3>c/h0_Kfm0<K6aP3>c/h0a/K6
0<k>cP36a/H30;fm_@<0]KFe00<0[Jf]0:FUY@2][Jd00P2LW9`00`2DU9@0Q8B407]kN`0207]kN`06
06][J`1BDU80DU9B059BDP12@T80BTY:0`0H61P01P0Q8B40410@05YJFP12@T80Ng]k059BDP80BTY:
00<0[Jf]0?ooo`3gmoL06@3gmoLS0?ooo`008@3oool<0?;blP04038b<P0o?cl0?clo05YJFP80?clo
100b<S800`1JFUX0X:2P0=OGe`030>GUi@80l_;b00<0iNGU0?;blP3bl_802`3bl_830>GUi@@0l_;b
0`3UiND30=OGe`030<S8b02k^k/0^k^k0080^k^k00<0[Zj^07IfMP24Q8@00P1JFUX00`0E5AD020P8
000000030000000606UYJ@1JFUX0^k^k08B4Q00o?cl0FUYJ703bl_8O0?ooo``0moOg00L0DU9B06][
J`1SHf<0Lg=c06][J`1SHf<0FUYJ0080DU9B00D0Jf][07=cL`24Q8@0_Kfm0<K6aP020<k>cP<0e]KF
00<0g]kN0=KFeP3Ng]h02P3Ng]h20=KFeP@0c/k>1036a/H0102m_Kd0]KFe0:f][@2][Jd20:FUY@09
09bLW02DU9@0Ng]k07=cL`1kNg/0Jf][04Y:BP0a<C40>CTi008061PH00P08B4Q09BDU01kNg/0W9bL
07=cL`1SHf<0U9BD06][Ja/0moOg7`3oool<0?Ogm`0403Ti>@1BDU80BTY:059BDP80BTY:00L0@T92
03Ti>@0a<C40<C4a059BDP1[Jf/0W9bL0080]KFe0`2m_Kd00`36a/H0c/k>0<k>cP0;0<k>cP<0a/K6
102e]KD01@2][Jd0YJFU0:f][@2UYJD0W9bL0080U9BD00X0S8b<08B4Q01kNg/0Lg=c06][J`1BDU80
FUYJ059BDP1:BTX0<C4a0P0Q8B42010@400401PH601SHf<0BTY:07=cL`<0BTY:703gmoLS0?ooo`00
8@3oool<0?;blP0303lo?`0b<S80<S8b00L0<S8b00D0Q8B40:2PX03GemL0emOG0>GUi@030?;blP80
iNGU2P3bl_840>GUi@<0l_;b103UiND40=OGe`80b<S800P0^k^k096AT@2^[Zh0X:2P08B4Q01fMWH0
FUYJ038b<P805ADE100000001P2k^k/0Q8B40;^k^`24Q8@0FUYJ0:j^[Q`0l_;b7`3oool40?Ogm`03
0>o_k`3gmoL0moOg00D0moOg00T0Hf=S059BDP1BDU80DU9B06=SH`1BDU80FUYJ059BDP1JFUX00P1k
Ng/00`2DU9@0]KFe0;fm_@020<k>cP<0e]KF1@3Ng]h00`3Fe]H0g]kN0=kNgP020=kNgP@0e]KF00<0
a/K60<k>cP3>c/h00P3>c/h20<K6aP040;Fe]@2m_Kd0_Kfm0;Fe]@80[Jf]0P2UYJD02@2DU9@0Q8B4
08b<S01kNg/0Lg=c059BDP1:BTX0>CTi0492@P0201PH6008034a<@1cLg<0W9bL09bLW01kNg/0Lg=c
06=SH`2][Jd@0?Ogm`030>o_k`3gmoL0moOg00P0moOg7`3oool<0?Ogm`0@04Y:BP0i>CT0>CTi03Ti
>@1:BTX0>CTi0492@P0i>CT0@T9203Ti>@1JFUX0Jf][09bLW02UYJD0[Jf]0;Fe]@80_Kfm0P36a/H4
0<k>cP80_Kfm103>c/h40<K6aP<0]KFe102][Jd01@2UYJD0W9bL0:FUY@2LW9`0S8b<0080Q8B400X0
Ng]k06][J`1[Jf/0FUYJ059BDP1:BTX0>CTi034a<@0Y:BT061PH0P0@41001`0Q8B40Lg=c06=SH`1k
Ng/0FUYJ059BDP2DU9@0703gmoLS0?ooo`008@3oool<0?;blP0302<S8`0o?cl0<S8b00<0?clo0`0b
<S801P0o?cl0TI6A096AT@38b<P0emOG0>GUi@/0l_;b00@0iNGU0?;blP3bl_80l_;b0P3UiND50?;b
lP@0iNGU1@3GemL30;^k^`070:j^[P24Q8@0Q8B406UYJ@1JFUX0?clo00P8200500000006096AT@1J
FUX0X:2P096AT@1YJFT0emOG703bl_8O0?ooo``0moOg00H0DU9B06][J`1BDU80Hf=S06][J`1SHf<2
05YJFP07059BDP1cLg<0S8b<09BDU02][Jd0_Kfm0<k>cP040=KFeP030=kNgP3Fe]H0e]KF00@0g]kN
00<0e]KF0=kNgP3Ng]h01P3Fe]H30<k>cP80a/K6102e]KD20:f][@80YJFU00P0U9BD08b<S024Q8@0
Q8B407]kN`1JFUX0>CTi04Y:BP808B4Q00<061PH02TY:@1cLg<00P2DU9@0102<S8`0Q8B406=SH`3>
c/hK0?Ogmal0oooo303gmoL01P12@T80DU9B03Ti>@1:BTX0DU9B04Y:BP80@T9200L0>CTi04Y:BP1S
Hf<0Ng]k08b<S02UYJD0]KFe00@0_Kfm0P3>c/h01P2m_Kd0c/k>0<k>cP2m_Kd0c/k>0<K6aP<0c/k>
0P36a/H40;fm_@030;Fe]@2][Jd0[Jf]0080[Jf]102LW9`01P2DU9@0S8b<08B4Q01kNg/0Jf][07=c
L`80Hf=S00@0BTY:0492@P0Q8B40410@0P0H61P0200@41008B4Q07]kN`1BDU80Jf][06=SH`1[Jf/0
a/K6703gmoLS0?ooo`008@3oool<0?;blP0305YJFP0E5AD0?clo0080C4a<00X0?clo038b<P0S8b<0
C4a<03lo?`24Q8@0X:2P0;^k^`3GemL0iNGU1P3bl_801@3UiND0l_;b0?;blP3bl_80iNGU0080l_;b
0P3UiND70?;blP040>GUi@3bl_80iNGU0>GUi@@0emOG00L0b<S80;^k^`2k^k/0TI6A0:j^[P2PX:00
Q8B40080FUYJ00<0?clo01DE5@0000000`0000000`0S8b<0JFUY07IfMP020:2PX0030;^k^`3bl_80
l_;b01/0l_;b7`3oool<0?Ogm`0>07]kN`1BDU80FUYJ06][J`1JFUX0Hf=S059BDP1JFUX0Jf][07=c
L`24Q8@0U9BD0:FUY@2m_Kd30<k>cP80e]KF0P3Ng]h20=KFeP040=kNgP3Fe]H0e]KF0=kNgPH0e]KF
00@0c/k>0=KFeP3>c/h0c/k>1036a/H20;fm_@030;Fe]@2][Jd0[Jf]0080YJFU00T0U9BD08B4Q024
Q8@0Q8B406][J`1JFUX0BTY:03Ti>@0Q8B400P0@41001`1BDU80Hf=S07]kN`2LW9`0U9BD0:f][@2D
U9@0703gmoLO0?ooo``0moOg00<0Jf][0492@P12@T800P1BDU801@1:BTX0>CTi0492@P1BDU80BTY:
0080Jf][00<0S8b<0:FUY@2][Jd00P2e]KD30;fm_@030<k>cP36a/H0_Kfm0080c/k>00<0a/K60<k>
cP2m_Kd00P36a/H40;fm_@060;Fe]@2m_Kd0]KFe0:f][@2e]KD0[Jf]0P2UYJD01`2LW9`0YJFU09BD
U02DU9@0S8b<08B4Q01kNg/00P1[Jf/01@1SHf<0BTY:04Y:BP12@T80<C4a0080410@0P0820P01P12
@T80FUYJ059BDP24Q8@0Jf][08b<S1d0moOg8`3oool00240oooo303bl_80103GemL0JFUY02<S8`0S
8b<4038b<P80?clo00D0Q8B40:2PX02k^k/0emOG0>GUi@020?;blP030>GUi@3bl_80l_;b00D0l_;b
00<0iNGU0?;blP3bl_800P3UiND30?;blP030>GUi@3bl_80l_;b0080l_;b103UiND20=OGe`<0b<S8
00@0^k^k0:2PX02k^k/0Q8B40`1JFUX00`0S8b<020P8000000030000000304a<C01JFUX0FUYJ0080
X:2P00<0^k^k0?;blP3bl_806`3bl_8O0?ooo`<0moOg00<0kno_0?Ogm`3gmoL01P3gmoL0103Ng]h0
Ng]k05YJFP1JFUX2059BDP0905YJFP1BDU80Hf=S07]kN`2<S8`0W9bL0:FUY@2m_Kd0c/k>00@0e]KF
00D0g]kN0=KFeP3Ng]h0e]KF0=kNgP020=KFeP030=kNgP3Fe]H0e]KF00H0e]KF00<0a/K60<k>cP3>
c/h00P36a/H00`2e]KD0a/K60;Fe]@040:f][@040:FUY@2LW9`0Q8B407]kN`80Lg=c00H0FUYJ03Ti
>@0a<C4061PH02TY:@0H61P206][J`0407=cL`2DU9@0W9bL0:FUYAd0moOg7`3oool<0?Ogm`080=kN
gP1SHf<0@T920492@P0i>CT0<C4a0492@P0i>CT204Y:BP0507=cL`24Q8@0S8b<09bLW02][Jd00P2m
_Kd00`36a/H0_Kfm0<k>cP020<k>cP060;fm_@3>c/h0_Kfm0<K6aP3>c/h0_Kfm0P36a/H30;fm_@03
0<K6aP2m_Kd0_Kfm0080]KFe0`2][Jd0102UYJD0W9bL09bLW02DU9@208b<S080Q8B400L0Ng]k06][
J`1BDU80DU9B04Y:BP12@T808B4Q0080410@00P08B4Q010@401BDU80DU9B03Ti>@1[Jf/0Q8B408b<
S1d0moOg8`3oool00240oooo303bl_80103oool0?clo02<S8`0b<S8301DE5@0402<S8`0o?cl0FUYJ
08B4Q080^k^k00D0emOG0>GUi@3bl_80l_;b0>GUi@030?;blP030>GUi@3bl_80l_;b0080l_;b00<0
iNGU0?;blP3bl_802@3bl_800`3UiND0l_;b0>GUi@020>GUi@040=OGe`38b<P0b<S80<S8b080^k^k
00<0TI6A08B4Q01YJFT00P0o?cl00`0820P000000000000300000080FUYJ00@0C4a<0:2PX02^[Zh0
b<S87@3bl_8O0?ooo``0moOg00<0oooo06=SH`1JFUX00`1BDU802P1:BTX0FUYJ06=SH`24Q8@0S8b<
09bLW02][Jd0_Kfm0<k>cP36a/H60=KFeP<0g]kN0P3Fe]H00`3Ng]h0e]KF0=KFeP040=KFeP030<K6
aP3>c/h0c/k>0080c/k>0`36a/H01`2m_Kd0[Jf]0:f][@2UYJD0[Jf]0:FUY@2DU9@00P24Q8@0101k
Ng/0Hf=S03Ti>@0a<C43024Q8@0701PH601kNg/0Jf][06=SH`2LW9`0]KFe0<k>cP0M0?Ogmal0oooo
303gmoL0203oool0BTY:0492@P0i>CT0<C4a0492@P0a<C40@T920P1:BTX0201cLg<0Ng]k08b<S02L
W9`0[Jf]0;Fe]@2m_Kd0a/K60`2m_Kd00`36a/H0c/k>0<k>cP020<k>cP030<K6aP3>c/h0_Kfm00H0
_Kfm0`2e]KD0102][Jd0]KFe0:f][@2UYJD209bLW00309BDU02<S8`0S8b<0080Q8B400D0Ng]k06][
J`1SHf<0BTY:0492@P02024Q8@0:01PH600820P061PH010@401SHf<0>CTi0492@P24Q8@0YJFU0<K6
aQd0moOg8`3oool00240oooo3@3bl_800`2^[Zh0<S8b038b<P03038b<P0801DE5@0b<S80FUYJ08B4
Q02PX:00b<S80=OGe`3UiND20?;blP80iNGU00<0l_;b0>GUi@3bl_800`3bl_801@3UiND0l_;b0>GU
i@3bl_80iNGU00P0l_;b103UiND20=OGe`80b<S80P2k^k/20:j^[P04096AT@1YJFT0FUYJ03lo?`H0
000000D0JFUY03lo?`1fMWH0X:2P0=OGe`0N0?;blQl0oooo3@3gmoL00`2e]KD0Hf=S059BDP05059B
DP0507]kN`2<S8`0W9bL0:f][@2m_Kd00P3>c/h40=KFeP@0g]kN00<0e]KF0=kNgP3Fe]H01`3Fe]H0
0`3>c/h0e]KF0<k>cP050<K6aP040;Fe]@2][Jd0[Jf]0:f][@80YJFU00T0U9BD08b<S01kNg/0Ng]k
07=cL`0i>CT0<C4a024Q8@0Y:BT00P0Q8B401@1kNg/0Q8B405YJFP2DU9@0_Kfm0080moOg00<0kno_
0?Ogm`3gmoL06@3gmoLO0?ooo`d0moOg00<0]KFe04Y:BP0i>CT00`0i>CT02P12@T80>CTi04Y:BP1c
Lg<0Q8B409bLW02UYJD0[Jf]0;Fe]@2m_Kd20<K6aP030<k>cP36a/H0c/k>00<0c/k>00D0a/K60;fm
_@36a/H0c/k>0<K6aP050;fm_@<0]KFe0`2][Jd01`2UYJD0W9bL09bLW02LW9`0S8b<08B4Q02<S8`0
0P1[Jf/01@1SHf<0FUYJ059BDP12@T80:BTY00808B4Q0`0H61P01@1SHf<0@T92059BDP1[Jf/0W9bL
01h0moOg8`3oool00240oooo3P3bl_802`0o?cl05ADE01DE5@0E5AD0<S8b02<S8`0E5AD0C4a<096A
T@2k^k/0b<S800<0iNGU203bl_80103UiND0l_;b0>GUi@3bl_820>GUi@80l_;b00D0iNGU0?;blP3b
l_80l_;b0>GUi@020?;blP80iNGU103GemL02@38b<P0^k^k0;^k^`2k^k/0Q8B4096AT@1JFUX0?clo
038b<P0600000080FUYJ00<0X:2P0;^k^`38b<P07P3bl_8O0?ooo`030?Ogm`3_knl0moOg00X0moOg
00<0kno_06][J`1:BTX00`1BDU801P1JFUX0DU9B08B4Q02DU9@0YJFU0:f][@80a/K60P3>c/h40=KF
eP030=kNgP3Fe]H0g]kN00X0e]KF103>c/h30<K6aP80_Kfm00D0]KFe0:f][@2][Jd0YJFU09bLW002
08b<S00>07]kN`1cLg<0Hf=S03Ti>@0a<C40:BTY024Q8@0Y:BT061PH06][J`24Q8@0Jf][0:FUY@3>
c/hN0?Ogmal0oooo3P3gmoL01@1BDU80<C4a034a<@12@T80>CTi0080@T9200H0DU9B07]kN`24Q8@0
U9BD0:FUY@2][Jd20;Fe]@@0_Kfm00L0c/k>0;fm_@3>c/h0a/K60;fm_@36a/H0_Kfm0080a/K60P2m
_Kd01@36a/H0_Kfm0;fm_@2e]KD0[Jf]0080]KFe0P2][Jd20:FUY@0409bLW02DU9@0S8b<08b<S080
Ng]k00L0Lg=c06=SH`1BDU80BTY:03Ti>@0Y:BT08B4Q00<061PH00H0410@04Y:BP1:BTX0FUYJ08B4
Q03>c/hN0?Ogmb<0oooo000Q0?ooo`h0l_;b00X0JFUY03lo?`0E5AD08b<S01DE5@0S8b<0<S8b04a<
C02PX:00^k^k0P3GemL00`3UiND0l_;b0?;blP020?;blP80iNGU00@0l_;b0>GUi@3bl_80l_;b0`3U
iND20?;blP030>GUi@3bl_80l_;b00<0l_;b1@3UiND40=OGe`<0b<S800H0[Zj^08B4Q024Q8@0FUYJ
03lo?`0E5AD60000000504a<C01JFUX0TI6A0<S8b03UiND07P3bl_8O0?ooo`h0moOg00D0Ng]k06][
J`1JFUX0FUYJ059BDP0205YJFP0307=cL`2DU9@0[Jf]0080_Kfm0P3>c/h40=KFeP80g]kN2`3Fe]H5
0<k>cP<0a/K60P2m_Kd30:f][@80YJFU00D0S8b<08B4Q01cLg<0Jf][05YJFP0203Ti>@0902TY:@0Q
8B4061PH010@401[Jf/0Lg=c06][J`2][Jd0kno_01h0moOg7`3oool>0?Ogm`0306=SH`1BDU80@T92
00@0@T9200<0DU9B06][J`2<S8`00P2UYJD00`2][Jd0]KFe0;fm_@020;fm_@80a/K600@0c/k>0<K6
aP2m_Kd0_Kfm0`36a/H20;fm_@040<K6aP2m_Kd0_Kfm0;fm_@80]KFe0`2][Jd30:FUY@0409bLW02D
U9@0U9BD08b<S080Q8B400H0Jf][07=cL`1[Jf/0BTY:0492@P0a<C4202TY:@8061PH00L0410@00P8
201BDU80BTY:06=SH`2<S8`0inOW01h0moOg8`3oool00240oooo3P3bl_820?ooo`090>GUi@1<C4`0
<S8b03lo?`0b<S80?clo096AT@2PX:00b<S80080iNGU1@3bl_800`3UiND0l_;b0?;blP030?;blP03
0>GUi@3bl_80l_;b00L0l_;b1@3UiND40=OGe`030<S8b02k^k/0TI6A0080TI6A00@0MWIf038b<P0b
<S805ADE1@00000206UYJ@0308B4Q02PX:00emOG01l0l_;b7`3oool00`3gmoL0kno_0?Ogm`060?Og
m`030>o_k`3gmoL0moOg0080moOg0P3oool00`1cLg<0Jf][05YJFP0206=SH`0407=cL`2DU9@0W9bL
0:f][@80a/K60P3>c/h>0=KFeP80c/k>00<0e]KF0<k>cP36a/H01036a/H03@2m_Kd0]KFe0;Fe]@2e
]KD0[Jf]09bLW02UYJD0U9BD08b<S01cLg<0FUYJ059BDP1JFUX00P0i>CT202TY:@06010@401kNg/0
Ng]k06=SH`1kNg/0c/k>7`3gmoLO0?ooo`h0moOg0P3oool00`3WinL0DU9B0492@P0304Y:BP0507]k
N`24Q8@0U9BD0:FUY@2][Jd00P2e]KD20;fm_@030;Fe]@36a/H0_Kfm00@0_Kfm00<0a/K60;fm_@2m
_Kd00P2m_Kd30;Fe]@030;fm_@2e]KD0[Jf]0080[Jf]00<0YJFU0:f][@2LW9`00P2LW9`00`2DU9@0
S8b<08b<S00207]kN`0406=SH`1BDU80>CTi0492@P<0:BTY0P0H61P01P0820P0FUYJ06=SH`1JFUX0
Hf=S0;fm_Al0moOg8`3oool00240oooo403bl_80103oool0<S8b038b<P0E5AD203lo?`04096AT@2k
^k/0b<S80=OGe`80iNGU00<0l_;b0>GUi@3UiND02@3bl_800`3UiND0l_;b0>GUi@020?;blPP0iNGU
0`3GemL20<S8b080^k^k00@0Q8B406UYJ@1JFUX0?clo0P0b<S840000000608B4Q01JFUX0FUYJ096A
T@2k^k/0iNGU7`3bl_8O0?oooa00moOg00X0W9bL059BDP1SHf<0DU9B06=SH`1kNg/0S8b<09bLW02]
[Jd0_Kfm0P36a/H40<k>cP<0e]KF00D0c/k>0=KFeP3Fe]H0c/k>0=KFeP050<k>cPL0a/K60`2e]KD2
0:f][@060:FUY@2LW9`0YJFU07]kN`1[Jf/0Hf=S0P1JFUX2034a<@0902TY:@0H61P0Q8B407]kN`1[
Jf/0Hf=S08b<S03WinL0moOg0080kno_703gmoLO0?oooa00moOg00@0oooo03Ti>@1:BTX0@T920P1:
BTX01`1SHf<0Ng]k09bLW02UYJD0W9bL0:f][@2e]KD00P2][Jd20;Fe]@80_Kfm00D0]KFe0;fm_@2m
_Kd0]KFe0;fm_@020;Fe]@030;fm_@2e]KD0]KFe00@0[Jf]00@0YJFU0:f][@2UYJD0YJFU0`2LW9`2
09BDU00507]kN`24Q8@0Lg=c06=SH`1:BTX00`12@T82024Q8@08010@400820P0Jf][06=SH`1:BTX0
Hf=S0:FUY@3WinLO0?Ogmb<0oooo000Q0?oooa00l_;b00T0oooo00P8200b<S80JFUY02<S8`1YJFT0
TI6A0:2PX038b<P00P3GemL20>GUi@l0l_;b00<0iNGU0?;blP3UiND01@3UiND30=OGe`80b<S800L0
[Zj^0;^k^`2^[Zh0Q8B406UYJ@1JFUX0<S8b00805ADE00T0C4a<0000000000008b<S038b<P1YJFT0
FUYJ0:2PX03GemL0803bl_8O0?oooa00moOg00X0c/k>03Ti>@1JFUX0Ng]k05YJFP1kNg/0S8b<09bL
W02][Jd0_Kfm0`36a/H40<k>cP030=KFeP3>c/h0e]KF00<0e]KF00D0c/k>0=KFeP3>c/h0a/K60<k>
cP070<K6aP80_Kfm0P2e]KD20:f][@0E09BDU02LW9`0U9BD07]kN`1cLg<0Jf][05YJFP1:BTX0Jf][
024Q8@0H61P08B4Q059BDP1kNg/0Jf][07=cL`2DU9@0kno_0?Ogm`3_knl0oooo01`0moOg7`3oool@
0?Ogm`0=0?ooo`0Q8B40@T9205YJFP12@T80FUYJ06=SH`24Q8@0U9BD09bLW02][Jd0YJFU0:f][@02
0;Fe]@040;fm_@2e]KD0_Kfm0;Fe]@@0_Kfm0P2e]KD01@2m_Kd0]KFe0;Fe]@2][Jd0]KFe00@0[Jf]
0P2UYJD01`2LW9`0U9BD09BDU02LW9`0S8b<09BDU01kNg/00P1[Jf/01P1SHf<0DU9B0492@P0a<C40
@T92059BDP8061PH00H0@T9203Ti>@1JFUX0BTY:06][J`2UYJDP0?Ogmb<0oooo000Q0?oooa00l_;b
00<0oooo05YJFP0b<S800P0b<S800`1YJFT0TI6A0;^k^`020<S8b0070=OGe`3UiND0iNGU0?;blP3U
iND0l_;b0>GUi@080?;blP/0iNGU0P3GemL30<S8b0060;^k^`2ATI40Q8B407IfMP1JFUX0C4a<0`0b
<S801`0000005ADE01DE5@0E5AD0JFUY05YJFP24Q8@00P2k^k/00`3bl_80oooo0?;blP0M0?;blQl0
oooo403gmoL0202e]KD0Lg=c059BDP1BDU80Hf=S07]kN`2<S8`0W9bL0P2][Jd50<K6aPL0c/k>00<0
e]KF0<K6aP36a/H00P36a/H00`2e]KD0a/K60<K6aP050<K6aP<0]KFe0P2][Jd01P2UYJD0U9BD09BD
U024Q8@0Lg=c06=SH`80FUYJ00`0DU9B03Ti>@1:BTX0>CTi04Y:BP1kNg/0Lg=c08B4Q02<S8`0[Jf]
0?Ogm`3ooolN0?Ogmal0oooo403gmoL01@3oool0DU9B03Ti>@0i>CT0BTY:0080Hf=S00<0Ng]k09BD
U02LW9`00P2UYJD01@2][Jd0]KFe0:f][@2m_Kd0[Jf]00D0]KFe00<0_Kfm0;Fe]@2e]KD00P2][Jd0
0`2LW9`0[Jf]0:FUY@030:FUY@050:f][@2UYJD0YJFU09BDU02LW9`00P2DU9@0102<S8`0Q8B407]k
N`1[Jf/2059BDP80@T920P0i>CT02`0Y:BT0<C4a034a<@0Y:BT0Hf=S059BDP1SHf<0S8b<0:f][@3g
moL0oooo01h0moOg8`3oool00240oooo403bl_802`3oool0X:2P01DE5@0b<S808b<S03lo?`24Q8@0
TI6A0:2PX02k^k/0emOG0080iNGU0P3bl_830>GUi@@0l_;b1@3UiND00`3GemL0iNGU0>GUi@040>GU
i@80emOG0P38b<P30;^k^`06096AT@24Q8@0Q8B407IfMP1YJFT0FUYJ0`0E5AD0100000005ADE06UY
J@1<C4`205YJFP030;^k^`3GemL0l_;b00@0l_;b00<0oooo0?;blP3bl_80303bl_800`3oool0l_;b
0?;blP0:0?;blQl0oooo403gmoL03@2UYJD0W9bL0492@P1BDU80FUYJ07=cL`24Q8@0U9BD09bLW02e
]KD0_Kfm0<K6aP2e]KD00P36a/H0203>c/h0a/K60<K6aP36a/H0c/k>0=KFeP36a/H0c/k>0P36a/H4
0;Fe]@040<K6aP2m_Kd0]KFe0;fm_@80]KFe0`2][Jd0202UYJD0W9bL09BDU02DU9@0S8b<08B4Q01k
Ng/0Jf][0P1BDU802P1:BTX0@T920492@P0a<C40Q8B407=cL`1[Jf/0W9bL09BDU02m_Kd20?Ogm`03
0>o_k`3gmoL0moOg00h0moOg00<0oooo0?Ogm`3gmoL02P3gmoLO0?oooa00moOg00@0oooo08B4Q00Y
:BT0<C4a0P12@T801`1SHf<0Ng]k08B4Q02UYJD0W9bL0:FUY@2LW9`0102e]KD01P2][Jd0]KFe0;Fe
]@2e]KD0_Kfm0;Fe]@80[Jf]00@0YJFU09bLW02LW9`0U9BD0P2UYJD209bLW00509BDU02LW9`0W9bL
08b<S02DU9@00P2<S8`207]kN`0607=cL`1[Jf/0DU9B05YJFP1:BTX0@T920P0a<C400`0i>CT0:BTY
06][J`02059BDP0304Y:BP1kNg/0W9bL00D0moOg00<0oooo0?Ogm`3gmoL0303gmoL00`3oool0moOg
0?Ogm`0:0?Ogmb<0oooo000Q0?oooa40l_;b00/0X:2P05YJFP0S8b<0<S8b04a<C01JFUX0JFUY096A
T@2k^k/0emOG0;^k^`020=OGe`<0iNGU1@3GemL40<S8b0D0^k^k00@0b<S80;^k^`2k^k/0TI6A0`2^
[Zh00`2PX:00Q8B4096AT@0208B4Q00305YJFP0o?cl0C4a<00<0C4a<00<05ADE03lo?`1JFUX00P1J
FUX00`2ATI40Q8B40<S8b00R0?;blQl0oooo4@3gmoL02P2UYJD0Ng]k05YJFP1JFUX0Hf=S07=cL`1k
Ng/0U9BD0:FUY@2][Jd30;Fe]@@0a/K60`2m_Kd0102e]KD0[Jf]0:f][@2][Jd20:FUY@L0W9bL102D
U9@02@24Q8@0U9BD08b<S024Q8@0Ng]k06][J`1cLg<0Jf][05YJFP0206][J`0906=SH`1[Jf/0Jf][
07=cL`2<S8`0Q8B40:f][@2m_Kd0kno_0200moOg7`3ooolA0?Ogm`0409BDU01[Jf/0@T920492@P80
DU9B00D0Hf=S07]kN`2<S8`0W9bL0:FUY@0209bLW0@0[Jf]102UYJD01@2LW9`0S8b<09BDU02DU9@0
Q8B400<0Ng]k00D0Lg=c07]kN`1cLg<0Lg=c07]kN`0406][J`0407=cL`1kNg/0Lg=c05YJFP80BTY:
00D0FUYJ059BDP1BDU80DU9B034a<@0204Y:BP06059BDP1:BTX0Hf=S06=SH`2DU9@0inOW8@3gmoLS
0?ooo`008@3ooolB0?;blP0<096AT@1<C4`0<S8b03lo?`1YJFT0Q8B406UYJ@24Q8@0TI6A0;^k^`3G
emL0iNGU103GemL20<S8b0040;^k^`38b<P0^k^k0<S8b080^k^k00H0TI6A0:2PX02^[Zh0TI6A0;^k
^`2^[Zh408B4Q006096AT@24Q8@0Q8B408B4Q01YJFT0Q8B4101YJFT01P0o?cl0C4a<06UYJ@0b<S80
20P8038b<P80Q8B400<0TI6A0:j^[P2k^k/05@3bl_800`3oool0l_;b0?;blP0:0?;blQl0oooo4P3g
moL02`2][Jd0Lg=c05YJFP1[Jf/0Ng]k08B4Q01kNg/0S8b<0:f][@2e]KD0_Kfm0080a/K60`2m_Kd3
0:f][@0?0;fm_@2UYJD0YJFU0:FUY@2DU9@0W9bL08B4Q02DU9@0W9bL07=cL`2DU9@0Ng]k08b<S01k
Ng/0S8b<00<0Q8B400H0Ng]k08b<S02DU9@0Q8B408b<S01kNg/206=SH`0:07=cL`1kNg/0>CTi059B
DP1kNg/0Q8B408b<S02][Jd0]KFe0;fm_A@0moOg00<0oooo0?Ogm`3gmoL02P3gmoLO0?oooa80moOg
00D0[Jf]05YJFP12@T80BTY:05YJFP0206][J`0307=cL`1kNg/0YJFU0080YJFU00@0[Jf]0:FUY@2U
YJD0W9bL0P2DU9@00`24Q8@0U9BD08b<S00208B4Q00908b<S01kNg/0Jf][06][J`1SHf<0Ng]k06=S
H`1JFUX0Lg=c0080FUYJ0P1SHf<206][J`0A06=SH`1cLg<0Jf][07=cL`1JFUX0Hf=S04Y:BP1JFUX0
Hf=S0492@P0Q8B40>CTi06=SH`1JFUX0Hf=S09BDU02UYJD05@3gmoL00`3oool0moOg0?Ogm`0:0?Og
mb<0oooo000Q0?oooa<0l_;b00P0iNGU06UYJ@1<C4`0FUYJ06UYJ@0o?cl0Q8B40:2PX0D0emOG0P2k
^k/00`2^[Zh0^k^k0;^k^`030;^k^`80X:2P1024Q8@0201fMWH0Q8B405YJFP1JFUX0Q8B405YJFP24
Q8@0MWIf0`1YJFT01P0o?cl0C4a<07IfMP1<C4`0FUYJ04a<C080<S8b00D0?clo05YJFP1JFUX0JFUY
0:2PX0020;^k^`030:2PX03bl_80l_;b0200l_;b7`3ooolC0?Ogm`080>OWi`2<S8`0FUYJ07=cL`1k
Ng/0Hf=S08b<S02m_Kd30<K6aP050;fm_@2e]KD0[Jf]0:FUY@2][Jd01@2UYJD01P2DU9@0S8b<08b<
S024Q8@0S8b<07=cL`80Q8B400@0Lg=c06][J`1cLg<0Q8B40P1cLg<207]kN`0306=SH`1[Jf/0Lg=c
00@0Lg=c00@0DU9B05YJFP1[Jf/0Lg=c0P1kNg/20;Fe]@0509bLW03gmoL0moOg0?Ogm`3_knl03P3g
moL00`3_knl0moOg0?Ogm`0=0?Ogmal0oooo4`3gmoL0203WinL0Ng]k05YJFP1BDU80FUYJ04Y:BP1c
Lg<0Q8B40`2e]KD30:FUY@0408B4Q02DU9@0S8b<08b<S0<0Q8B40P1[Jf/0701cLg<0Jf][07=cL`1[
Jf/0DU9B06][J`1BDU80BTY:06][J`1BDU80Hf=S059BDP1SHf<0FUYJ06=SH`1:BTX0FUYJ059BDP1J
FUX0DU9B05YJFP0i>CT0@T92059BDP1:BTX0DU9B05YJFP1[Jf/20:FUY@0308B4Q03gmoL0moOg0200
moOg8`3oool00240oooo503bl_8206UYJ@0705YJFP1YJFT0X:2P0:j^[P2ATI40[Zj^0<S8b0020;^k
^`80b<S80P2k^k/00`2ATI40X:2P0;^k^`020:2PX00<096AT@2PX:00Q8B405YJFP2ATI40JFUY096A
T@24Q8@0TI6A06UYJ@1JFUX0TI6A1@1YJFT0300b<S80JFUY05YJFP0o?cl0C4a<06UYJ@1JFUX0C4a<
05YJFP1<C4`0FUYJ0;^k^`80[Zj^00<0^k^k0=OGe`3bl_800P3bl_800`3oool0l_;b0?;blP0L0?;b
lQl0oooo1P3gmoL20>o_k``0moOg00@0S8b<07]kN`1cLg<0S8b<0P2UYJD00`2][Jd0YJFU0:f][@02
0;fm_@090:f][@2UYJD0YJFU0:FUY@2DU9@0YJFU09bLW02DU9@0W9bL00<0Q8B400X0Lg=c09BDU02D
U9@0Q8B407]kN`2<S8`0Ng]k09BDU01kNg/0Q8B40P1kNg/00`2<S8`0Hf=S06][J`0207]kN`0407=c
L`1kNg/0Hf=S06][J`80Hf=S00<0Lg=c08B4Q02][Jd00P2][Jd01@3>c/h0moOg0?Ogm`3gmoL0oooo
01h0moOg7`3ooolD0?Ogm`0407]kN`1[Jf/0Hf=S07=cL`80U9BD00<0S8b<09BDU02LW9`00P2][Jd0
1@2LW9`0U9BD08B4Q02<S8`0Ng]k0080Q8B400T0Jf][08B4Q01kNg/0Jf][06=SH`1BDU80Ng]k06=S
H`1kNg/00P1SHf<0601JFUX0BTY:07]kN`1JFUX0Hf=S05YJFP1[Jf/0Lg=c04Y:BP1JFUX0Hf=S059B
DP1JFUX0Hf=S04Y:BP12@T80BTY:0492@P1BDU80Q8B40:FUY@2DU9@0S8b<0<K6aP<0moOg00<0oooo
0?Ogm`3gmoL0703gmoLS0?ooo`008@3ooolD0?;blP050?ooo`1<C4`0FUYJ04a<C01YJFT00P24Q8@0
1038b<P0^k^k0<S8b02^[Zh20;^k^`80X:2P00L0Q8B4096AT@24Q8@0Q8B4096AT@24Q8@0TI6A0080
JFUY00@0C4a<06UYJ@1YJFT0Q8B40`1YJFT01@2PX:00?clo05YJFP24Q8@0JFUY0080C4a<00D08b<S
01DE5@0E5AD0?clo038b<P0202<S8`0704a<C024Q8@0X:2P0=OGe`2ATI40^k^k08B4Q00S0?;blQl0
oooo503gmoL02@3oool0Q8B407=cL`1[Jf/0Q8B408b<S02LW9`0[Jf]0;Fe]@030:f][@<0W9bL0P2<
S8`02`2DU9@0S8b<09BDU02DU9@0Ng]k07=cL`1kNg/0Hf=S07]kN`2<S8`0Lg=c0080Ng]k00D0U9BD
06=SH`1cLg<0Lg=c08B4Q00206][J`80FUYJ00@0BTY:06=SH`1BDU80DU9B0P1JFUX01P1cLg<0U9BD
0:f][@36a/H0[Jf]08B4Q2<0moOg7`3ooolD0?Ogm`050?ooo`1JFUX0Hf=S059BDP1[Jf/00P1cLg<0
102LW9`0YJFU09BDU02DU9@208b<S080Q8B401D0Lg=c07]kN`1cLg<0Lg=c07]kN`1[Jf/0Ng]k05YJ
FP1[Jf/0@T9206][J`1JFUX0Lg=c06=SH`1JFUX0Hf=S06][J`1:BTX0DU9B06][J`1JFUX00P1BDU80
1@12@T80<C4a0492@P1:BTX0>CTi00<0@T9200<0BTY:06][J`2][Jd00P2<S8`00`1SHf<0moOg0?Og
m`0Q0?Ogmb<0oooo000Q0?oooaD0l_;b00@0oooo06UYJ@1YJFT0TI6A0P2PX:030;^k^`<0X:2P00L0
TI6A0:2PX02ATI40TI6A08B4Q02ATI40Q8B40080JFUY00H0C4a<06UYJ@0o?cl05ADE06UYJ@0b<S83
06UYJ@0:03lo?`1JFUX05ADE01DE5@1JFUX0?clo038b<P1JFUX0C4a<05YJFP80C4a<0P1JFUX0202^
[Zh0TI6A0;^k^`0o?cl0TI6A06UYJ@38b<P0oooo8P3bl_8O0?oooaD0moOg00<0U9BD07]kN`1kNg/0
0P2LW9`40;Fe]@<0W9bL00<0U9BD09bLW02DU9@00P24Q8@0102DU9@0Q8B407]kN`1SHf<208B4Q004
06=SH`1kNg/0FUYJ08B4Q080Ng]k00D0FUYJ06][J`1kNg/0@T9204Y:BP0305YJFP@0Hf=S00X0DU9B
06=SH`1[Jf/0U9BD0:f][@2m_Kd0Hf=S08B4Q03>c/h0oooo1P3gmoL00`3_knl0moOg0?Ogm`0I0?Og
mal0oooo5@3gmoL01P3oool0Jf][06=SH`2DU9@0Q8B409BDU0<0YJFU0`24Q8@0401kNg/0Q8B407]k
N`1kNg/0Jf][07]kN`1SHf<0FUYJ06=SH`12@T80Jf][04Y:BP0a<C40Hf=S0492@P1JFUX206=SH`05
0492@P1:BTX0:BTY034a<@0i>CT00P12@T800`0i>CT0@T9204Y:BP020492@P0:03Ti>@1:BTX0U9BD
07]kN`2<S8`0BTY:08b<S01[Jf/0c/k>0?ooob80moOg8`3oool00240oooo5P3bl_800`0E5AD0FUYJ
096AT@0206UYJ@060:2PX02^[Zh0^k^k0:2PX01YJFT0Q8B40P2ATI403@24Q8@0FUYJ08B4Q01YJFT0
Q8B406UYJ@24Q8@0<S8b04a<C00o?cl0JFUY038b<P0o?cl00`0b<S800`0E5AD0<S8b038b<P0201DE
5@05038b<P0S8b<0<S8b038b<P0o?cl00`1YJFT01`2PX:00[Zj^05YJFP1JFUX0X:2P096AT@3UiND0
203bl_800`3oool0l_;b0?;blP0I0?;blQl0oooo5@3gmoL0203oool0FUYJ07]kN`2LW9`0Ng]k09BD
U02][Jd0]KFe0P2UYJD208B4Q080U9BD0`24Q8@0101kNg/0S8b<08B4Q01JFUX207=cL`0606=SH`1J
FUX0Hf=S06=SH`1JFUX0Hf=S101BDU800`1:BTX0DU9B05YJFP03059BDP@0Ng]k00H0W9bL07]kN`1k
Ng/0Q8B40:FUY@3WinL20>o_k`@0moOg00<0kno_0?Ogm`3gmoL0103gmoL00`3oool0moOg0?Ogm`0D
0?Ogmal0oooo5P3gmoL00`1:BTX0Jf][08b<S00206][J`0609bLW02UYJD0S8b<09BDU01SHf<0Jf][
0P1kNg/01@1[Jf/0Hf=S06][J`1SHf<0Lg=c0080Hf=S00P0@T9205YJFP1:BTX0FUYJ0492@P1:BTX0
@T9204Y:BP80@T920P0i>CT0100a<C40:BTY03Ti>@12@T82034a<@0604Y:BP1JFUX0FUYJ05YJFP24
Q8@0YJFU0P1SHf<00`2DU9@0Ng]k0>OWi`080?Ogm`030?ooo`3gmoL0moOg01T0moOg8`3oool00240
oooo5`3bl_800`1JFUX05ADE08B4Q00208B4Q080^k^k00l0X:2P06UYJ@24Q8@0JFUY08B4Q01YJFT0
C4a<06UYJ@1<C4`0JFUY04a<C01YJFT0<S8b05YJFP1<C4`00P0E5AD0201YJFT08b<S038b<P0S8b<0
<S8b01DE5@0820P000000`0E5AD02@1JFUX0<S8b03lo?`1YJFT0X:2P0=OGe`2^[Zh0TI6A06UYJ@02
04a<C0030>GUi@3oool0oooo02<0l_;b7`3ooolG0?Ogm`0507]kN`1:BTX0U9BD09bLW02DU9@00P2e
]KD01P2][Jd0S8b<07]kN`1kNg/0Q8B407]kN`80Q8B400D0Lg=c07]kN`1kNg/0FUYJ07]kN`0206][
J`0304Y:BP1kNg/0DU9B0080FUYJ00<0DU9B04Y:BP1:BTX00P0i>CT20492@P0<059BDP1[Jf/0FUYJ
08B4Q02LW9`0U9BD0;fm_@2e]KD0S8b<06][J`2LW9`0Jf][0P3oool00`3_knl0moOg0?Ogm`0P0?Og
mal0oooo5`3gmoL01@1[Jf/0<C4a07]kN`2<S8`0Ng]k0080YJFU00<0W9bL05YJFP1cLg<00P1SHf<2
05YJFP0;06][J`1JFUX0Hf=S05YJFP1SHf<0@T9204Y:BP1BDU80@T92034a<@1JFUX00`12@T82034a
<@03024Q8@0Y:BT0:BTY0080:BTY00D0BTY:0492@P1:BTX0Jf][08B4Q0020:FUY@0508b<S01cLg<0
DU9B059BDP3WinL00P3ooolS0?Ogmb<0oooo000Q0?oooaL0l_;b00/0oooo06UYJ@0E5AD0C4a<08B4
Q02^[Zh0^k^k0:2PX01YJFT0C4a<06UYJ@0308B4Q00304a<C01YJFT0?clo0080JFUY00L0?clo06UY
J@1<C4`0?clo0000000E5AD0JFUY0080<S8b00<020P8038b<P0820P0100000002`0o?cl0JFUY096A
T@24Q8@0TI6A08B4Q00b<S80C4a<08B4Q01YJFT0X:2P00L0l_;b00<0oooo0?;blP3bl_803`3bl_80
0`3oool0l_;b0?;blP0:0?;blQl0oooo5@3gmoL08@3_knl0moOg0?ooo`1kNg/0@T9208B4Q02DU9@0
]KFe0;fm_@2][Jd0Jf][09BDU01kNg/0S8b<09BDU01[Jf/0Q8B407]kN`1SHf<0Ng]k06=SH`1cLg<0
Ng]k07=cL`0a<C40BTY:05YJFP1kNg/0DU9B03Ti>@1BDU80@T9203Ti>@03034a<@0804Y:BP1JFUX0
Q8B408B4Q02DU9@0]KFe09BDU01SHf<208B4Q00306][J`2UYJD0moOg00D0moOg00<0oooo0?Ogm`3g
moL01`3gmoL00`3_knl0moOg0?Ogm`050?Ogm`030?ooo`3gmoL0moOg00X0moOg7`3ooolG0?Ogm`0A
0?ooo`1[Jf/0:BTY06=SH`1kNg/0YJFU0:f][@2LW9`0FUYJ059BDP1SHf<0Lg=c07]kN`1SHf<0DU9B
05YJFP1:BTX00P1SHf<01`1:BTX0FUYJ05YJFP1BDU808B4Q034a<@1JFUX00P0i>CT01@0Q8B40>CTi
024Q8@0Q8B40:BTY00808B4Q00@0@T9206][J`1kNg/0Jf][0P1kNg/01@1:BTX0Jf][06=SH`1[Jf/0
W9bL00L0moOg00<0oooo0?Ogm`3gmoL03`3gmoL00`3oool0moOg0?Ogm`0:0?Ogmb<0oooo000Q0?oo
oaP0l_;b00X0b<S802<S8`0S8b<0JFUY096AT@2PX:00^k^k06UYJ@1<C4`0Q8B40P1<C4`02P1YJFT0
?clo05YJFP1<C4`0?clo04a<C01YJFT0?clo06UYJ@1JFUX203lo?`0601DE5@0b<S80<S8b038b<P0o
?cl0FUYJ0P0b<S80301<C4`0FUYJ06UYJ@2ATI40X:2P0<S8b024Q8@0FUYJ01DE5@1<C4`0JFUY08B4
Q0D0l_;b00<0oooo0?;blP3bl_80103bl_800`3oool0l_;b0?;blP050?;blP030?ooo`3bl_80l_;b
0100l_;b7`3oool40?Ogm`030>o_k`3gmoL0moOg0140moOg00X0c/k>06][J`1SHf<0S8b<09bLW02]
[Jd0]KFe06][J`1kNg/0S8b<0P1cLg<02`1[Jf/0Hf=S07=cL`1cLg<0Jf][07]kN`1cLg<0Hf=S07]k
N`1[Jf/0Hf=S0080BTY:0140Hf=S059BDP1JFUX0DU9B06][J`1BDU80FUYJ06][J`1cLg<0Ng]k08b<
S036a/H0U9BD09bLW01kNg/0BTY:08B4Q00209BDU0D0moOg00<0oooo0>o_k`3gmoL00`3gmoL00`3o
ool0moOg0?Ogm`050?Ogm`030?ooo`3gmoL0moOg0100moOg7`3ooolH0?Ogm`0:0<k>cP1JFUX0@T92
07=cL`2<S8`0W9bL0:FUY@1[Jf/0DU9B07=cL`80FUYJ00@0Hf=S059BDP1SHf<0FUYJ0P1BDU800`1S
Hf<0BTY:05YJFP02059BDP0304Y:BP0a<C40BTY:0080>CTi00<0@T9204Y:BP0a<C400P0a<C402`1:
BTX0Hf=S06=SH`24Q8@0]KFe07]kN`1[Jf/0<C4a05YJFP1[Jf/0Ng]k00D0moOg00<0oooo0?Ogm`3g
moL0103gmoL00`3oool0moOg0?Ogm`050?Ogm`030?ooo`3gmoL0moOg0100moOg8`3oool00240oooo
6@3bl_80102k^k/0C4a<038b<P0b<S8206UYJ@040;^k^`0o?cl0FUYJ08B4Q080C4a<00@0<S8b02<S
8`0o?cl0?clo0P1<C4`01P0o?cl0JFUY06UYJ@1JFUX0C4a<06UYJ@80<S8b0`1<C4`02`1JFUX0JFUY
08B4Q02PX:00TI6A0;^k^`2ATI40Q8B406UYJ@0S8b<0FUYJ00<0JFUY00<0l_;b0?ooo`3oool00`3b
l_800`3oool0l_;b0?;blP0?0?;blP030?ooo`3bl_80l_;b00`0l_;b7`3ooolI0?Ogm`0;0;fm_@1c
Lg<0Hf=S06=SH`24Q8@0S8b<06=SH`1[Jf/0Ng]k08B4Q01cLg<00`1JFUX00`1SHf<0Jf][07=cL`02
06=SH`0807]kN`1cLg<0Lg=c05YJFP1kNg/0DU9B07=cL`1[Jf/206=SH`0706][J`24Q8@0W9bL08b<
S02DU9@0]KFe09bLW00208b<S00?05YJFP1cLg<0Q8B407]kN`3oool0moOg0?ooo`3gmoL0kno_0?oo
o`3_knl0moOg0>o_k`3gmoL0oooo00d0moOg00<0oooo0?Ogm`3gmoL0303gmoLO0?oooaT0moOg00P0
]KFe06][J`1BDU80BTY:07=cL`24Q8@0YJFU04Y:BP80Hf=S00@0FUYJ059BDP12@T80@T920P1:BTX0
1P1BDU80FUYJ04Y:BP1JFUX0Jf][059BDP80FUYJ00/0>CTi034a<@1JFUX0DU9B0492@P1:BTX0FUYJ
06=SH`24Q8@0Ng]k0:FUY@0208b<S00407=cL`12@T80Hf=S07=cL`80Jf][00<0moOg0?ooo`3oool0
0`3gmoL00`3oool0moOg0?Ogm`0?0?Ogm`030?ooo`3gmoL0moOg00`0moOg8`3oool00240oooo6`3b
l_802P0b<S80C4a<06UYJ@24Q8@0TI6A0:2PX01<C4`0JFUY03lo?`1YJFT204a<C004038b<P0S8b<0
5ADE03lo?`80FUYJ00H0TI6A08B4Q038b<P0^k^k0:2PX038b<P20;^k^`80emOG00T0b<S80:j^[P1Y
JFT0FUYJ04a<C00b<S808b<S03lo?`24Q8@00P1YJFT00`3oool0l_;b0?ooo`090?;blP030?ooo`3b
l_80l_;b01X0l_;b7`3ooolE0?Ogm`0F0>o_k`3gmoL0moOg0>o_k`3gmoL0]KFe06=SH`1cLg<0S8b<
09BDU02UYJD0[Jf]07=cL`24Q8@0Hf=S07=cL`1kNg/0Jf][059BDP1:BTX0Hf=S05YJFP80Lg=c00D0
S8b<0<K6aP36a/H0]KFe09bLW0030:FUY@80a/K600/0]KFe08b<S01[Jf/0Ng]k06][J`1JFUX0Hf=S
08B4Q02DU9@0Ng]k0?ooo`020?Ogm`030?ooo`3gmoL0moOg00<0moOg00<0kno_0?Ogm`3gmoL00P3o
oolK0?Ogmal0oooo6`3gmoL0601BDU80Hf=S07=cL`1kNg/0S8b<09BDU01JFUX0Jf][04Y:BP1cLg<0
FUYJ059BDP0i>CT0@T92034a<@1:BTX0Hf=S059BDP1kNg/0Lg=c0;Fe]@2UYJD0Q8B409bLW080S8b<
0P2][Jd01@2DU9@0YJFU07=cL`1SHf<0DU9B0080@T9200L0BTY:07]kN`1SHf<0Jf][0?ooo`3gmoL0
oooo00T0moOg00<0oooo0?Ogm`3gmoL06P3gmoLS0?ooo`008@3ooolI0?;blP070?ooo`3bl_80iNGU
05YJFP1<C4`05ADE06UYJ@020:j^[P0>06UYJ@24Q8@0JFUY06UYJ@2ATI40X:2P05YJFP0S8b<0?clo
04a<C024Q8@0X:2P096AT@1YJFT20;^k^`040<S8b03GemL0emOG0:2PX080Q8B400T0JFUY04a<C01<
C4`05ADE038b<P1<C4`0FUYJ06UYJ@24Q8@0:P3bl_8O0?oooaT0moOg00H0oooo0?Ogm`3_knl0Q8B4
07=cL`1SHf<20;Fe]@0>0:f][@24Q8@0S8b<08b<S01kNg/0U9BD0:FUY@1BDU80Jf][059BDP1cLg<0
U9BD09bLW02<S8`30;fm_@060=KFeP3>c/h0_Kfm09bLW02DU9@0Q8B40P1cLg<01`1[Jf/0DU9B07=c
L`1kNg/0U9BD07]kN`2DU9@00P3gmoL0103_knl0moOg0>o_k`3_knl80?Ogm`030>o_k`3gmoL0moOg
01P0moOg7`3ooolI0?Ogm`090?ooo`3gmoL0moOg07]kN`1SHf<0DU9B07=cL`2UYJD0U9BD00<0Lg=c
0P1kNg/0302DU9@0Jf][0492@P1BDU80FUYJ07]kN`2DU9@0S8b<07]kN`2e]KD0[Jf]0;Fe]@80a/K6
00T0Q8B407]kN`1kNg/0Lg=c06=SH`1BDU80@T9203Ti>@1JFUX00P1SHf<00`1kNg/0moOg0?Ogm`0X
0?Ogmb<0oooo000Q0?oooaT0l_;b00T0oooo0?;blP3bl_80oooo05YJFP0b<S80FUYJ06UYJ@38b<P0
0P2PX:00202k^k/0TI6A0;^k^`2PX:00emOG0>GUi@3bl_80iNGU0P3GemL01P2k^k/0b<S80<S8b038
b<P0emOG0:j^[P80JFUY0`1JFUX00`0o?cl05ADE06UYJ@0306UYJ@040?ooo`3bl_80l_;b0?oooa40
l_;b00<0oooo0?;blP3bl_80503bl_8O0?oooaT0moOg00T0oooo0?Ogm`3gmoL0oooo07]kN`1SHf<0
S8b<0:f][@36a/H00`2][Jd02P3>c/h0_Kfm0:FUY@3Fe]H0kno_0>OWi`3Fe]H0c/k>0;fm_@3>c/h3
0<K6aP040;Fe]@2<S8`0YJFU08b<S080Ng]k00@0Hf=S06][J`1JFUX0Ng]k0P24Q8@01@1kNg/0oooo
0?Ogm`3oool0kno_00<0moOg00D0kno_0?Ogm`3gmoL0moOg0>o_k`020?Ogm`030?ooo`3gmoL0kno_
0080moOg00<0kno_0?Ogm`3gmoL05@3gmoLO0?oooaT0moOg00T0oooo0?Ogm`3gmoL0oooo06][J`1B
DU80Lg=c07]kN`36a/H00P2LW9`0102e]KD0[Jf]0;Fe]@2LW9`20<K6aP060>OWi`36a/H0a/K60;fm
_@2][Jd0_Kfm0P2e]KD01@2m_Kd0YJFU07=cL`1cLg<0Hf=S0080Jf][0P1:BTX01@1SHf<0Lg=c06][
J`1[Jf/0oooo0080moOg00<0oooo0?Ogm`3gmoL03`3gmoL00`3oool0moOg0?Ogm`0D0?Ogmb<0oooo
000Q0?oooaT0l_;b00<0oooo0?;blP3bl_800P3bl_801`3GemL0<S8b03lo?`2ATI40^k^k0<S8b03G
emL00`38b<P0103GemL0b<S80=OGe`3GemL20>GUi@090=OGe`38b<P0[Zj^096AT@2k^k/0TI6A08B4
Q00o?cl0JFUY0080?clo00H0FUYJ096AT@2PX:00Q8B406UYJ@2PX:0M0?;blP030?ooo`3bl_80oooo
00`0l_;b7`3oool@0?Ogm`030?ooo`3gmoL0moOg00H0moOg00<0oooo0?Ogm`3gmoL00P3gmoL01@3N
g]h0Lg=c09BDU02UYJD0_Kfm00D0c/k>0P36a/H0103>c/h0a/K60=KFeP3Fe]H20<k>cP030;Fe]@2L
W9`0W9bL0080W9bL00D0Lg=c07]kN`1[Jf/0Ng]k08B4Q00209bLW00408B4Q02UYJD0moOg0?Ogm`80
kno_1P3gmoL00`3_knl0moOg0?Ogm`0@0?Ogm`050?ooo`3gmoL0oooo0?Ogm`3_knl02P3gmoLO0?oo
oaT0moOg00<0oooo0?Ogm`3gmoL00P3gmoL0203Ng]h0DU9B06=SH`2LW9`0]KFe0;fm_@3>c/h0a/K6
0P2m_Kd01@3>c/h0]KFe0;Fe]@2e]KD0a/K60080c/k>00@0_Kfm0:FUY@2DU9@0[Jf]0P2<S8`205YJ
FP0804Y:BP1BDU80Jf][08b<S024Q8@0Lg=c06][J`2LW9`M0?Ogm`030?ooo`3gmoL0oooo00`0moOg
8`3oool00240oooo5`3bl_800`3oool0l_;b0?ooo`020?ooo`80l_;b00@0oooo0>GUi@1YJFT0JFUY
0P2^[Zh20;^k^`@0emOG01@0iNGU0=OGe`3GemL0iNGU0=OGe`38b<P0[Zj^08B4Q01YJFT0TI6A05YJ
FP1<C4`0JFUY038b<P1YJFT0TI6A08B4Q01YJFT0X:2P0=OGe`L0l_;b00<0oooo0?;blP3bl_80203b
l_800`3oool0l_;b0?;blP040?;blP050?ooo`3bl_80l_;b0?;blP3oool00`3bl_800`3oool0l_;b
0?;blP090?;blQl0oooo5`3gmoL01@3oool0moOg0?ooo`3gmoL0oooo0080moOg00@0oooo08B4Q024
Q8@0S8b<0P2e]KD00`36a/H0c/k>0=KFeP020=KFeP040>OWi`3Ng]h0e]KF0=KFeP80c/k>00@0_Kfm
0<K6aP2LW9`0W9bL0P1kNg/00`1cLg<0S8b<08b<S00309bLW00308b<S03Ng]h0moOg0080moOg00@0
kno_0?Ogm`3gmoL0oooo0`3gmoL00`3_knl0moOg0?Ogm`050?Ogm`030?ooo`3gmoL0moOg00@0moOg
00D0oooo0?Ogm`3gmoL0moOg0?ooo`030?Ogm`030?ooo`3gmoL0moOg00T0moOg7`3ooolG0?Ogm`03
0?ooo`3gmoL0oooo0080oooo0P3gmoL0103oool0inOW07=cL`24Q8@20:FUY@80]KFe103>c/h01@3N
g]h0e]KF0<k>cP3>c/h0a/K60080_Kfm00P0S8b<08B4Q02DU9@0Hf=S05YJFP1cLg<0DU9B07]kN`80
S8b<00<0Ng]k08B4Q03Ng]h01`3gmoL00`3oool0moOg0?Ogm`080?Ogm`030?ooo`3gmoL0moOg00@0
moOg00D0oooo0?Ogm`3gmoL0moOg0?ooo`030?Ogm`030?ooo`3gmoL0moOg00T0moOg8`3oool00240
oooo403bl_800`3oool0l_;b0?;blP090?;blP040?ooo`3bl_80l_;b0?ooo`@0l_;b00@0TI6A08B4
Q02^[Zh0^k^k1@3GemL20;^k^`050:2PX024Q8@0[Zj^0<S8b02ATI400P2k^k/0102ATI40Q8B40;^k
^`3UiND20?oooa@0l_;b00<0oooo0?;blP3oool00`3oool40?;blP070?ooo`3bl_80l_;b0?;blP3o
ool0l_;b0?ooo`0:0?;blQl0oooo6`3gmoL00`3_knl0oooo0?Ogm`060?Ogm`0409BDU02e]KD0]KFe
0;fm_@D0e]KF00`0_Kfm0:FUY@2UYJD0U9BD0;Fe]@2LW9`0_Kfm0<K6aP2m_Kd0W9bL0;fm_@3WinL3
0?ooo`80moOg00<0oooo0?Ogm`3gmoL00P3gmoL00`3oool0moOg0?Ogm`030?Ogm`030>o_k`3gmoL0
moOg00<0moOg00<0oooo0?Ogm`3oool00`3oool40?Ogm`070?ooo`3gmoL0moOg0?Ogm`3oool0moOg
0?ooo`0:0?Ogmal0oooo403gmoL00`3oool0moOg0?Ogm`090?Ogm`040?ooo`3gmoL0moOg0?ooo`@0
moOg00@0U9BD08b<S02e]KD0]KFe0P3Fe]H00`3>c/h0e]KF0<k>cP020;Fe]@0509bLW02<S8`0YJFU
0;fm_@2DU9@00P2e]KD0102DU9@0Ng]k0:f][@3WinL20?oooa@0moOg00<0oooo0?Ogm`3oool00`3o
ool40?Ogm`070?ooo`3gmoL0moOg0?Ogm`3oool0moOg0?ooo`0:0?Ogmb<0oooo000Q0?ooob40l_;b
00<0oooo0?;blP3oool00P3bl_801@2ATI40^k^k0:2PX02k^k/0b<S80080emOG00D0iNGU0?;blP3U
iND0b<S80=OGe`020<S8b0040:2PX02^[Zh0b<S80>GUi@80l_;b00<0oooo0?;blP3bl_806P3bl_80
0`3oool0l_;b0?;blP0A0?;blQl0oooo3`3gmoL00`3_knl0moOg0?Ogm`0?0?Ogm`060?ooo`3gmoL0
oooo0?Ogm`2][Jd0YJFU0P2m_Kd20<k>cP0<0=kNgP3Fe]H0kno_0>OWi`3Fe]H0c/k>0=KFeP3>c/h0
YJFU09bLW02e]KD0c/k>0P3gmoL20?ooo`030>o_k`3gmoL0moOg00<0moOg00@0kno_0?Ogm`3gmoL0
kno_0P3gmoL00`3_knl0moOg0?Ogm`040?Ogm`030>o_k`3gmoL0moOg00<0moOg00@0kno_0?Ogm`3o
ool0kno_103gmoL01@3_knl0moOg0?Ogm`3gmoL0kno_00T0moOg7`3ooolQ0?Ogm`030?ooo`3gmoL0
oooo0080moOg00D0W9bL0;Fe]@2LW9`0[Jf]0<K6aP020=KFeP0;0=kNgP3WinL0g]kN0;fm_@3>c/h0
a/K60;fm_@2LW9`0YJFU0;fm_@3WinL00P3gmoL00`3oool0moOg0?Ogm`0J0?Ogm`030?ooo`3gmoL0
moOg0140moOg8`3oool00240oooo403bl_800`3oool0l_;b0?;blP0>0?;blP030?ooo`3bl_80l_;b
00D0l_;b0P3UiND00`3bl_80iNGU0<S8b0020;^k^`@0b<S800<0iNGU0?;blP3bl_800`3bl_800`3o
ool0l_;b0?ooo`020?ooo``0l_;b00D0oooo0?;blP3bl_80l_;b0?ooo`080?;blP80oooo1`3bl_80
0`3oool0l_;b0?;blP070?;blQl0oooo8@3gmoL00`3oool0kno_0>o_k`020?Ogm`80kno_0P3WinL0
0`3Ng]h0kno_0>OWi`020;fm_@80c/k>00@0a/K60<k>cP3WinL0kno_103gmoL20?ooo`030?Ogm`3o
ool0oooo00@0moOg0P3_knl50?Ogm`030>o_k`3oool0kno_00/0moOg00<0oooo0?Ogm`3gmoL01P3g
moL00`3oool0moOg0?Ogm`070?Ogmal0oooo403gmoL00`3oool0moOg0?Ogm`0>0?Ogm`030?ooo`3g
moL0moOg00D0moOg0`3WinL0103Ng]h0_Kfm0;Fe]@2e]KD30<K6aP030<k>cP3WinL0moOg00@0moOg
00<0oooo0?Ogm`3oool00P3oool<0?Ogm`050?ooo`3gmoL0moOg0?Ogm`3oool0203gmoL20?ooo`L0
moOg00<0oooo0?Ogm`3gmoL01`3gmoLS0?ooo`008@3ooolX0?;blP030?ooo`3bl_80l_;b00D0l_;b
00<0oooo0?;blP3bl_800`3bl_820?ooo`80l_;b00<0oooo0?;blP3bl_800`3bl_80103oool0l_;b
0?;blP3oool20?;blP040?ooo`3bl_80oooo0?oooa00l_;b00D0oooo0?;blP3bl_80l_;b0?ooo`0<
0?;blQl0oooo403gmoL00`3_knl0moOg0?Ogm`070?Ogm`030?ooo`3_knl0moOg0080moOg00<0kno_
0?Ogm`3gmoL02`3gmoL30>o_k`030?ooo`3gmoL0moOg00<0moOg00D0oooo0?Ogm`3gmoL0moOg0?oo
o`030?Ogm`050>o_k`3gmoL0oooo0?Ogm`3oool00P3gmoL01P3oool0moOg0?ooo`3gmoL0oooo0>o_
k`80moOg00<0kno_0?Ogm`3gmoL01`3gmoL00`3_knl0moOg0?ooo`030?Ogm`030?ooo`3gmoL0moOg
00X0moOg7`3ooolX0?Ogm`030?ooo`3gmoL0moOg00D0moOg00<0oooo0?Ogm`3gmoL00`3gmoL20?oo
o`80moOg00<0oooo0?Ogm`3gmoL00`3gmoL0103oool0moOg0?Ogm`3oool20?Ogm`040?ooo`3gmoL0
oooo0?oooa00moOg00D0oooo0?Ogm`3gmoL0moOg0?ooo`0<0?Ogmb<0oooo000Q0?ooob80l_;b00<0
oooo0?;blP3bl_801@3bl_800`3oool0l_;b0?;blP030?;blP030?ooo`3bl_80l_;b00H0l_;b0P3o
ool50?;blP80oooo1`3bl_800`3oool0l_;b0?;blP080?;blP030?ooo`3bl_80l_;b00<0l_;b00<0
oooo0?;blP3bl_800P3bl_820?ooo`X0l_;b7`3ooolQ0?Ogm`0:0>o_k`3oool0moOg0?Ogm`3_knl0
moOg0>o_k`3gmoL0oooo0>o_k`D0moOg00<0oooo0?Ogm`3_knl01@3gmoL00`3oool0moOg0?ooo`02
0?Ogm`040>o_k`3oool0moOg0?ooo`P0moOg00@0oooo0>o_k`3gmoL0kno_303gmoL00`3oool0moOg
0?Ogm`020?Ogm`80oooo203gmoL00`3_knl0moOg0?ooo`0N0?ooob80moOg00<0oooo0?Ogm`3gmoL0
1@3gmoL00`3oool0moOg0?Ogm`030?Ogm`030?ooo`3gmoL0moOg00H0moOg0P3oool50?Ogm`80oooo
1`3gmoL00`3oool0moOg0?Ogm`080?Ogm`030?ooo`3gmoL0moOg00<0moOg00<0oooo0?Ogm`3gmoL0
0P3gmoL20?ooo`X0moOg8`3oool00240oooo3P3bl_800`3oool0l_;b0?;blP0=0?;blP030?ooo`3b
l_80l_;b00D0l_;b00<0oooo0?;blP3bl_801@3bl_800`3oool0l_;b0?;blP0:0?;blP050?ooo`3b
l_80l_;b0?;blP3oool0103bl_801@3oool0l_;b0?;blP3bl_80oooo00<0l_;b00@0oooo0?;blP3b
l_80oooo0`3bl_800`3oool0l_;b0?ooo`020?;blP040?ooo`3bl_80l_;b0?ooo`X0l_;b00<0oooo
0?;blP3bl_800P3bl_8O0?ooo`h0moOg00<0oooo0?Ogm`3_knl00P3gmoL00`3_knl0moOg0?Ogm`07
0?Ogm`050>o_k`3oool0moOg0?Ogm`3_knl00`3gmoL00`3_knl0oooo0>o_k`020?Ogm`060?ooo`3g
moL0moOg0?ooo`3gmoL0kno_2`3gmoL01@3oool0moOg0>o_k`3gmoL0oooo0080moOg00H0kno_0?oo
o`3oool0moOg0>o_k`3oool30?Ogm`030?ooo`3gmoL0moOg00@0moOg00<0oooo0?Ogm`3oool00P3g
moL20?ooo`050?Ogm`3oool0moOg0?Ogm`3_knl01`3gmoL00`3oool0moOg0?Ogm`020?Ogmal0oooo
3P3gmoL00`3oool0moOg0?Ogm`0=0?Ogm`030?ooo`3gmoL0moOg00D0moOg00<0oooo0?Ogm`3gmoL0
1@3gmoL00`3oool0moOg0?Ogm`0:0?Ogm`050?ooo`3gmoL0moOg0?Ogm`3oool0103gmoL01@3oool0
moOg0?Ogm`3gmoL0oooo00<0moOg00@0oooo0?Ogm`3gmoL0oooo0`3gmoL00`3oool0moOg0?ooo`02
0?Ogm`040?ooo`3gmoL0moOg0?ooo`X0moOg00<0oooo0?Ogm`3gmoL00P3gmoLS0?ooo`008@3ooolB
0?;blP030?ooo`3bl_80l_;b01@0l_;b00<0oooo0?;blP3oool01@3bl_800`3oool0l_;b0?;blP05
0?;blP030?ooo`3bl_80l_;b00l0l_;b00D0oooo0?;blP3oool0l_;b0?ooo`0F0?;blP030?ooo`3b
l_80l_;b0080l_;b7`3ooolB0?Ogm`030?ooo`3gmoL0moOg0100moOg00L0kno_0?Ogm`3gmoL0oooo
0>o_k`3gmoL0oooo00<0moOg00<0oooo0?Ogm`3oool01P3gmoL00`3oool0moOg0?Ogm`090?Ogm`03
0>o_k`3gmoL0moOg00<0moOg00<0oooo0>o_k`3oool0103gmoL00`3_knl0moOg0?Ogm`080?Ogm`03
0>o_k`3gmoL0moOg00D0moOg00<0kno_0?ooo`3gmoL00`3gmoLO0?oooa80moOg00<0oooo0?Ogm`3g
moL0503gmoL00`3oool0moOg0?ooo`050?Ogm`030?ooo`3gmoL0moOg00D0moOg00<0oooo0?Ogm`3g
moL03`3gmoL01@3oool0moOg0?ooo`3gmoL0oooo01H0moOg00<0oooo0?Ogm`3gmoL00P3gmoLS0?oo
o`008@3oool[0?;blP80oooo0P3bl_800`3oool0l_;b0?;blP0:0?;blP070?ooo`3bl_80oooo0?;b
lP3oool0l_;b0?ooo`040?;blP030?ooo`3bl_80l_;b00L0l_;b00H0oooo0?;blP3bl_80oooo0?;b
lP3oool70?;blP040?ooo`3bl_80l_;b0?ooo`T0l_;b7`3oool@0?Ogm`030?ooo`3gmoL0moOg00T0
moOg00<0kno_0?Ogm`3gmoL01P3gmoL20>o_k`<0moOg00H0kno_0?ooo`3oool0moOg0?ooo`3_knl4
0?Ogm`030?ooo`3gmoL0kno_0080moOg00D0oooo0>o_k`3gmoL0moOg0?ooo`020?Ogm`80oooo103g
moL00`3oool0moOg0?Ogm`020?Ogm`030>o_k`3gmoL0oooo0080moOg00<0oooo0?Ogm`3gmoL00P3g
moL0103oool0moOg0?Ogm`3oool40?Ogm`040?ooo`3gmoL0moOg0?ooo`L0moOg0P3_knlO0?ooob/0
moOg0P3oool20?Ogm`030?ooo`3gmoL0moOg00X0moOg00L0oooo0?Ogm`3oool0moOg0?ooo`3gmoL0
oooo00@0moOg00<0oooo0?Ogm`3gmoL01`3gmoL01P3oool0moOg0?Ogm`3oool0moOg0?ooo`L0moOg
00@0oooo0?Ogm`3gmoL0oooo2@3gmoLS0?ooo`008@3ooolB0?;blP030?ooo`3bl_80l_;b00P0l_;b
00<0oooo0?;blP3bl_801`3bl_800`3oool0l_;b0?;blP050?;blP030?ooo`3bl_80l_;b00P0l_;b
00<0oooo0?;blP3oool00`3bl_800`3oool0l_;b0?ooo`0:0?;blP030?ooo`3bl_80l_;b00H0l_;b
00<0oooo0?;blP3bl_80103bl_800`3oool0l_;b0?;blP090?;blP030?ooo`3bl_80oooo01h0oooo
4P3gmoL00`3oool0moOg0?Ogm`080?Ogm`050?ooo`3gmoL0kno_0?Ogm`3_knl01@3gmoL00`3oool0
moOg0?Ogm`030?Ogm`030>o_k`3oool0moOg00P0moOg00<0kno_0?Ogm`3oool0103gmoL00`3_knl0
oooo0?ooo`0:0?Ogm`030?ooo`3_knl0kno_0080moOg00D0kno_0?Ogm`3gmoL0moOg0?ooo`060?Og
m`030?ooo`3gmoL0moOg00T0moOg00<0oooo0?Ogm`3oool07P3ooolB0?Ogm`030?ooo`3gmoL0moOg
00P0moOg00<0oooo0?Ogm`3gmoL01`3gmoL00`3oool0moOg0?Ogm`050?Ogm`030?ooo`3gmoL0moOg
00P0moOg00<0oooo0?Ogm`3oool00`3gmoL00`3oool0moOg0?ooo`0:0?Ogm`030?ooo`3gmoL0moOg
00H0moOg00<0oooo0?Ogm`3gmoL0103gmoL00`3oool0moOg0?Ogm`090?Ogm`030?ooo`3gmoL0oooo
0280oooo000Q0?oooa/0l_;b00<0oooo0?;blP3bl_801`3bl_800`3oool0l_;b0?;blP0:0?;blP03
0?ooo`3bl_80l_;b0080l_;b00D0oooo0?;blP3oool0l_;b0?ooo`050?;blP030?ooo`3bl_80l_;b
0080l_;b00<0oooo0?;blP3oool00`3bl_800`3oool0l_;b0?;blP0L0?;blQl0oooo4`3gmoL00`3_
knl0moOg0?Ogm`040?Ogm`060>o_k`3oool0moOg0?Ogm`3_knl0moOg0P3_knl20?Ogm`80oooo0P3g
moL00`3_knl0moOg0?Ogm`040?Ogm`030?ooo`3gmoL0kno_00H0moOg00L0oooo0?Ogm`3_knl0oooo
0>o_k`3gmoL0kno_00@0moOg00H0kno_0?Ogm`3oool0kno_0?ooo`3gmoL20>o_k`030?ooo`3gmoL0
oooo0080moOg00<0kno_0?Ogm`3gmoL02P3gmoL00`3_knl0moOg0?Ogm`0:0?Ogmal0oooo6`3gmoL0
0`3oool0moOg0?Ogm`070?Ogm`030?ooo`3gmoL0moOg00X0moOg00<0oooo0?Ogm`3gmoL00P3gmoL0
1@3oool0moOg0?ooo`3gmoL0oooo00D0moOg00<0oooo0?Ogm`3gmoL00P3gmoL00`3oool0moOg0?oo
o`030?Ogm`030?ooo`3gmoL0moOg01`0moOg8`3oool00240oooo3`3bl_800`3oool0l_;b0?;blP08
0?;blP030?ooo`3bl_80l_;b01L0l_;b00@0oooo0?;blP3oool0oooo2@3bl_800`3oool0l_;b0?;b
lP080?;blP030?ooo`3bl_80l_;b00<0l_;b00@0oooo0?;blP3bl_80oooo5@3bl_8O0?ooo`l0moOg
0P3oool20?Ogm`030>o_k`3gmoL0moOg00T0moOg00D0kno_0?Ogm`3_knl0moOg0>o_k`050?Ogm`03
0>o_k`3gmoL0moOg00<0moOg00P0oooo0?Ogm`3gmoL0moOg0?ooo`3_knl0moOg0?ooo`h0moOg00<0
kno_0?Ogm`3gmoL00`3gmoL01`3oool0moOg0?ooo`3gmoL0kno_0?Ogm`3oool00P3gmoL00`3oool0
moOg0?Ogm`050?Ogm`80kno_303gmoLO0?ooo`l0moOg00<0oooo0?Ogm`3gmoL0203gmoL00`3oool0
moOg0?Ogm`0G0?Ogm`040?ooo`3gmoL0oooo0?ooo`T0moOg00<0oooo0?Ogm`3gmoL0203gmoL00`3o
ool0moOg0?Ogm`030?Ogm`040?ooo`3gmoL0moOg0?oooaD0moOg8`3oool00240oooo3`3bl_800`3o
ool0l_;b0?ooo`0B0?;blP030?ooo`3bl_80l_;b00P0l_;b00<0oooo0?;blP3bl_800`3bl_820?oo
o`T0l_;b0`3oool90?;blP80oooo3@3bl_800`3oool0l_;b0?;blP030?;blP030?ooo`3bl_80oooo
00L0l_;b7`3oool?0?Ogm`030?ooo`3gmoL0oooo00`0moOg00<0kno_0?Ogm`3gmoL0103gmoL00`3o
ool0moOg0?Ogm`060?Ogm`80oooo0P3gmoL00`3_knl0moOg0?Ogm`020?ooo`T0moOg0P3oool90?Og
m`<0oooo303gmoL0103oool0moOg0>o_k`3_knl20?Ogm`040?ooo`3gmoL0oooo0>o_k`H0moOg7`3o
ool?0?Ogm`030?ooo`3gmoL0oooo0180moOg00<0oooo0?Ogm`3gmoL0203gmoL00`3oool0moOg0?Og
m`030?Ogm`80oooo2@3gmoL30?ooo`T0moOg0P3oool=0?Ogm`030?ooo`3gmoL0moOg00<0moOg00<0
oooo0?Ogm`3oool01`3gmoLS0?ooo`00o`3oooo30?ooo`00o`3oooo30?ooo`00o`3oooo30?ooo`00
o`3oooo30?ooo`00o`3oooo30?ooo`00o`3oooo30?ooo`00o`3oooo30?ooo`00CP3oool3@0000080
oooo00=000000?ooo`3oool00d0000030?ooo`A00000L`3oool2@00000<0oooo140000030?ooo`=0
00000`3oool3@00000030?oood00001000000080oooo0T00001^0?ooo`A000000`3oool3@00000@0
oooo140000020?ooo`=00000CP3oool004l0oooo00A000000?ooo`3ooom000000P3oool00d000000
oooo0?ooo`030?ooo`04@000003oool0oooo@00007<0oooo00A000000?ooo`3ooom000000`3oool0
0d000000oooo0?ooo`020?ooo`03@000003oool0oooo00<0oooo00=000000?ooo`3oool00`3oool0
14000000oooo0?oood00001`0?ooo`04@000003oool0oooo@00000<0oooo00=000000?ooo`3oool0
0P3oool014000000oooo0?oood0000020?ooo`03@000003oool0oooo04l0oooo001?0?ooo`=00000
0`3oool4@0000080oooo00A000000?ooo`3ooom00000L`3oool00d000000oooo@0000002@0000080
oooo00=000000?ooo`3oool00P3oool4@0000080oooo140000020?ooo`04@000003oool0oooo@000
0700oooo00A000000?ooo`3ooom000000`3oool00d000000oooo0?ooo`020?ooo`04@000003oool0
oooo@0000080oooo1400001>0?ooo`00C`3oool014000000oooo0?oood0000030?ooo`900000103o
ool3@00007<0oooo00=000000?ooo`3oool00`3oool4@00000<0oooo0T0000040?ooo`9000000P3o
ool4@0000740oooo0d0000040?ooo`04@000003oool0oooo0?ooo`90000000<0oooo@00004000000
0`3oool2@00004l0oooo001?0?ooo`04@000003oool0oooo@00000/0oooo00=000000?ooo`3oool0
L@3oool00d000000oooo0?ooo`290?ooo`03@000003oool0oooo00@0oooo00=000000?ooo`3oool0
FP3oool004h0oooo1400000;0?ooo`900000M03oool3@00008L0oooo0T0000050?ooo`900000G03o
ool00?l0oooo``3oool00?l0oooo``3oool00?l0oooo``3oool00?l0oooo``3oool00?l0oooo``3o
ool00?l0oooo``3oool00?l0oooo``3oool00?l0oooo``3oool00?l0oooo``3oool00?l0oooo``3o
ool00?l0oooo``3oool00?l0oooo``3oool00?l0oooo``3oool00:P0oooo0d00001@0?ooo`=00000
a03oool00:/0oooo00=000000?ooo`3oool0CP3oool00d000000oooo0?ooo`330?ooo`00W03oool3
@00000@0oooo0d0000030?ooo`=000000`3oool2@00000<0oooo1D0000020?ooo`9000002P3oool3
@00000<0oooo0T0000030?ooo`=00000103oool2@00000<0oooo140000090?ooo`=000000`3oool2
@0000080oooo0T0000001@3ooom000000?oood000000oooo00=00000103oool2@0000080oooo0T00
00020?ooo`9000000P3oool3@00000030?oood00001000000080oooo0T0000020?ooo`9000000`3o
ool3@00009l0oooo002M0?ooo`03@000003oool0oooo00@0oooo00E000000?ooo`3oool0oooo@000
00020?ooo`03@000003oool0oooo00P0oooo00=000000?ooo`3oool03@3oool00d000000oooo0?oo
o`030?ooo`04@000003oool0oooo@00000<0oooo00=000000?ooo`3oool00P3oool014000000oooo
0?oood0000030?ooo`03@000003oool0oooo00P0oooo00=000000?ooo`3oool00`3oool014000000
oooo0?oood0000020?ooo`07@000003ooom000000?oood000000oooo@00000020?ooo`04@000003o
ool0oooo@0000080oooo00A000000?ooo`3ooom000000P3oool014000000oooo0?oood0000050?oo
o`04@000003oool0oooo@0000080oooo00A000000?ooo`3ooom000001@3oool00d000000oooo0?oo
o`2L0?ooo`00W@3oool00d000000oooo0?ooo`040?ooo`05@000003oool0oooo0?oood0000000P3o
ool00d000000oooo0?ooo`080?ooo`03@000003oool0oooo00d0oooo00=000000?ooo`3oool00`3o
ool014000000oooo0?oood0000030?ooo`03@000003oool0oooo0080oooo00A000000?ooo`3ooom0
00000`3oool00d000000oooo0?ooo`080?ooo`03@000003oool0oooo00<0oooo00A000000?ooo`3o
oom000000P3oool01d000000oooo@000003ooom000000?oood0000000P3oool014000000oooo0?oo
od0000020?ooo`04@000003oool0oooo@0000080oooo00=000000?ooo`3oool0140000020?ooo`04
@000003oool0oooo@0000080oooo00=000000?ooo`3oool00`3oool3@00009l0oooo002M0?ooo`90
0000103oool2@00000@0oooo140000090?ooo`03@000003oool0oooo00d0oooo00=000000?ooo`3o
ool0103oool2@00000@0oooo00=000000?ooo`3oool00`3oool2@00000<0oooo140000090?ooo`=0
00000`3oool2@0000080oooo0d0000000`3ooom000000?ooo`04@00000@0oooo0T0000020?ooo`A0
0000103oool2@0000080oooo140000020?ooo`E000000P3oool4@00009h0oooo002M0?ooo`04@000
003oool0oooo@00001D0oooo00=000000?ooo`3oool03@3oool014000000oooo0?oood0000090?oo
o`03@000003oool0oooo04@0oooo00=000000?ooo`3oool0Y@3oool009`0oooo1D0000030?ooo`03
@000003oool0oooo00h0oooo0T00000@0?ooo`=00000203oool2@0000>h0oooo003o0?oool<0oooo
003o0?oool<0oooo0000\
\>"],
  ImageRangeCache->{{{0, 449}, {149, 0}} -> {-0.184538, -0.0234427, \
0.00750352, 0.00750352}, {{24.5625, 149.5}, {145.875, 20.875}} -> {-40.3294, \
-6.3068, 1.19876, 1.19876}, {{162, 286.938}, {145.875, 20.875}} -> {-205.084, \
-6.3068, 1.19876, 1.19876}, {{299.438, 424.375}, {145.875, 20.875}} -> \
{-369.838, -6.3068, 1.19876, 1.19876}}]
}, Open  ]],

Cell[TextData[{
  StyleBox[
  "\tThe meanings of the option commands such as \[OpenCurlyDoubleQuote]Mesh\
\[CloseCurlyDoubleQuote], \
\[OpenCurlyDoubleQuote]Frame\[CloseCurlyDoubleQuote] and \
\[OpenCurlyDoubleQuote]DisplayFunction\[CloseCurlyDoubleQuote] can be \
obtained by the command \[OpenCurlyDoubleQuote]Options[ListDensityPlot]\
\[CloseCurlyDoubleQuote] or clicking the help menu of the ",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"],
  StyleBox["Mathematica",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox[" front-end, e.g.",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell[CellGroupData[{

Cell["Options[ListDensityPlot]", "Input",
  CellLabel->"In[16]:="],

Cell[BoxData[
    \({AspectRatio \[Rule] 1, Axes \[Rule] False, AxesLabel \[Rule] None, 
      AxesOrigin \[Rule] Automatic, AxesStyle \[Rule] Automatic, 
      Background \[Rule] Automatic, ColorFunction \[Rule] Automatic, 
      ColorOutput \[Rule] Automatic, DefaultColor \[Rule] Automatic, 
      Epilog \[Rule] {}, Frame \[Rule] True, FrameLabel \[Rule] None, 
      FrameStyle \[Rule] Automatic, FrameTicks \[Rule] Automatic, 
      ImageSize \[Rule] Automatic, Mesh \[Rule] True, 
      MeshRange \[Rule] Automatic, MeshStyle \[Rule] Automatic, 
      PlotLabel \[Rule] None, PlotRange \[Rule] Automatic, 
      PlotRegion \[Rule] Automatic, Prolog \[Rule] {}, 
      RotateLabel \[Rule] True, Ticks \[Rule] Automatic, 
      DefaultFont \[RuleDelayed] $DefaultFont, 
      DisplayFunction \[RuleDelayed] $DisplayFunction, 
      FormatType \[RuleDelayed] $FormatType, 
      TextStyle \[RuleDelayed] $TextStyle}\)], "Output",
  CellLabel->"Out[16]="]
}, Open  ]],

Cell[TextData[{
  StyleBox[
  "\tThe readers are very surprised by so many options even though a \
relatively simple command \[OpenCurlyDoubleQuote]ListDensityPlot\
\[CloseCurlyDoubleQuote], but never mind such a too many options. The readers \
are essentially led to use a limited number of options and commands in ",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"],
  StyleBox["Mathematica",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox[" depending on demands of their affectivities.",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"],
  StyleBox["\n\t",
    TextAlignment->Left,
    TextJustification->1],
  StyleBox["Thus, we have succeeded in reading the image file into the ",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"],
  StyleBox["Mathematica",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox[
  " notebook. To conserve the memory used for the \
\[OpenCurlyDoubleQuote]RGBsplit.exe\[CloseCurlyDoubleQuote] object from an \
entire computer memory, we remove this object from the memory by \
\[OpenCurlyDoubleQuote]Uninstall\[CloseCurlyDoubleQuote] command.",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell["\<\
Uninstall[link];
Off[General::spell1];\
\>", "Input",
  CellLabel->"In[17]:="]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["1.4 ",
    FormatType->InputForm,
    FontFamily->"Times New Roman",
    FontWeight->"Bold"],
  StyleBox["Monochrome image",
    FontFamily->"Times New Roman",
    FontSize->16,
    FontWeight->"Bold"]
}], "Section"],

Cell[TextData[{
  StyleBox[
  "\tMany of the digital cameras can take a color image, but still the \
monochrome images are used for the industrial use for sake of its cost \
performance. Two types of monochrome images are considered in this book. One \
is the bitmap image file having only the monochrome information. When we read \
such a monochrome image in the ",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"],
  StyleBox["Mathematica",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox[
  " notebook by the \[OpenCurlyDoubleQuote]RGBsplit.exe\
\[CloseCurlyDoubleQuote] command,",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell["\<\
link=Install[\"RGBsplit\"];
monoSample=RGBsplit[\"BF001M.bmp\"];
Uninstall[link];
Off[General::spell1];\
\>", "Input",
  CellLabel->"In[19]:="],

Cell[TextData[StyleBox[
"then after substituting the numerical values included in the list \
\[OpenCurlyDoubleQuote]monoSample\[CloseCurlyDoubleQuote] into a list \
\[OpenCurlyDoubleQuote]monoData\[CloseCurlyDoubleQuote], we check up the \
numerical values included in the list \[OpenCurlyDoubleQuote]monoData\
\[CloseCurlyDoubleQuote] by a command \[OpenCurlyDoubleQuote]==\
\[OpenCurlyDoubleQuote]. The command \[OpenCurlyDoubleQuote]==\
\[OpenCurlyDoubleQuote] gives the \[OpenCurlyDoubleQuote]True\
\[CloseCurlyDoubleQuote] if the objects are the same else \
\[OpenCurlyDoubleQuote]False\[CloseCurlyDoubleQuote].",
  TextAlignment->Left,
  TextJustification->1,
  FontFamily->"Times New Roman"]], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell["\<\
dim=Dimensions[monoSample];
monoData=
\tTable[monoSample[[i,j,k]],
\t\t{k,dim[[3]]},{i,dim[[1]]},{j,dim[[2]]}];\
\>", "Input",
  CellLabel->"In[23]:="],

Cell[TextData[{
  StyleBox["\t",
    FontFamily->"Times New Roman",
    FontSize->10.5],
  StyleBox["The first, we compare the first and second components.",
    FontFamily->"Times New Roman"]
}], "Text"],

Cell[CellGroupData[{

Cell["monoData[[1]]==monoData[[2]]", "Input",
  CellLabel->"In[25]:="],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[25]="]
}, Open  ]],

Cell[TextData[{
  StyleBox["\t",
    FontFamily->"Times New Roman",
    FontSize->10.5],
  StyleBox[
  "This result means that the first and second image components in the list \
\[OpenCurlyDoubleQuote]monoData\[CloseCurlyDoubleQuote] are the same \
numerical values. Similarly, we check up equivalence between the first and \
third components in the list \[OpenCurlyDoubleQuote]monoData\
\[CloseCurlyDoubleQuote].",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell[CellGroupData[{

Cell["monoData[[1]]==monoData[[3]]", "Input",
  CellLabel->"In[26]:="],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[26]="]
}, Open  ]],

Cell[TextData[{
  StyleBox["\t",
    FontFamily->"Times New Roman",
    FontSize->10.5],
  StyleBox[
  "Thereby, the monochrome image data in the list \
\[OpenCurlyDoubleQuote]monoData\[CloseCurlyDoubleQuote] by installing the \
command \[OpenCurlyDoubleQuote]RGBsplit.exe\[CloseCurlyDoubleQuote] have the \
same color components, which represent a monochrome image as shown in Fig.2.",
    
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell[CellGroupData[{

Cell["\<\
ListDensityPlot[monoData[[1]],
\tMesh->False,Frame->False,PlotLabel->\"Fig.2. Monochrome\"];\
\>", "Input",
  CellLabel->"In[27]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00751202 0.0192308 0.00751202 [
[.5 1.0125 -53 0 ]
[.5 1.0125 53 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -114 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Fig) show
81.000000 12.812500 moveto
(.2) show
93.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(.) show
105.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Monochrome) show
165.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
128 string
128 128 8 [128 0 0 128 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
EFF0F7F7EFF0EEEEF7EEF0D5D5D5D6DBD6D6D6D6D6F0EA95
CDD6CDCDC6CECEC5CECFCECFC6C6CECED4D4CFCFCECECECF
C3CFCFCFD7D7D7D7D7D7D7D4D7CFCFD2D7CFCFCFCFCFCECE
CECECFCFCDCFCFCECFCFCEE3F0E3A0C6C6CECEC6C6C6CDCD
CDCDCDCDD5D4D0D4DDD7DDDDDDD6DDD5CECDC2C2C6C6C5C2
E1E0B8D3E9F2F7EF
EFF2F2EEF0F7F7EFEFF7F0EED6D6D6D6D6D6D6D5D5D5EAB0
CFD5CECDCDC6C6C6C8CECFCECFCEC8CFD5CFCFCECEC3C8CE
CEC6CECFCECFD4D2CFCFD7CFCFD7CFCFCFCFCFD2CFCFCECE
CFCFCFCFCFCDC6CFCFCECFCEE3F0B49DCECECEC6C6C6C6C6
CECFCFCFD4CFD5CFD5D5D6D6D6DDD6D6CDCECDCDC6C6CDE8
E9C5C5C6E9F2EFF0
EEEEEEF0EFEFEFF0EFEFF7F7F2D6D5D5D5D2D5D5D0D5E4EA
8CCDD0CEC6C1C6CECECECFCECFCEC6C3D4D4CFCEC8C8C5C5
C1C1C1C8CECFCFD4CFCFCFCFCECFCFD5D7D7D4D2D7CFCFCF
CFCFCFCFCFCECFCFCFCFCFCFCED6F0E394C6C6C6CECDC6C6
CEC6C6CFD5D4D5D4D5D5D6DBDDDBD6D3D0CDCFCDCDD3DAD9
E8D9C5C6DFEEF7F0
F0EFF2F7EFF7F7EEF7F7F0EFF0EEEEDDD0D5CFCFCFCFCFEA
DBB9CDCECEC6C6C6C6C6CECFCFCEC6C6CECFCFCFC8CEC5C1
C5C5C1C0C6CECECFCFCECFCECECED4DDD7D7D7DDD7D7D4D7
D7CFCFD0D0D0CFD0D0CFCFCFCFCFD6F0E39DCFCFCFCFCFD4
CFCFD0CFD4CFD5D0D5D6DDDBDBD6DBD0D0CED5CEE9DAD9E8
C5DFCDC5E9E9E9F0
EFF2EFF2F7F2F2EFF7F7F7F7F0F7EFF0DDD5D7CFD4CFD7EA
EAB9CFD0D3C6C6C6CEC6C6CECECFCECECFCEC8C8C8CECECE
CECEC8C1C5C6CEC3C3C3CECFCFCFCFCFD7CFCFDDDDD0D7D2
D7D2CFD5D5D0D0D5D5D5CFD5CFCFCFD6F0B8BCCFD4D4D4CF
CFCFD4D5D4D5D7D5D5D7DDDBDBDBD6D6D6CEDBEEE9E8E8EE
D3E4C5C5E9F7F0EE
EFF2EEF2EFF0F2F7EEF2F2EEF7F7F2F7F2E1D5D7D5D5D5D6
EAE8CFD5D5CECDC6C6CECDCFCFC6C6CEC6C1C8C8C5CECECE
CFCECFCFC3C1C1C8C1CEC6CECFCFCFCFCFD2D7D7CFD6D5D5
D5D7D5D7D5D6D5D0D5D0D0D0CFD4CFCFD6F0C6BCCFD5D5D4
D0D4D4D7D7D7D7D5D7D6D6DBDBDBD6CECBC5DAE8F0CDDACD
D6E9C6DAF2F2F2EE
EFF7F7F7EEF7EEF2F2F7EEF7F7EFF7F7F7F7F0DBDBDDDBDD
DDF0DBD0D6D6D3CECDC6C6C5C5C6C0B8C0C0C0C5C0CECFD4
D4D4D4D7CECEC1C8C5C8C1C5C6C3CECECFCFD4CFCFCFCFCF
D0CFCFD5D5D0D0D0CFCFCFCFCFCDCFCFCDDBF0E3CDCFCFCF
CED4D2D7D7D5D7D5DDD6DBDBDBCECDB9B4C6E9DFEECED3D5
D3D3C5E9F2F0F7EF
EFF0F2F2F2F7F2F7EFEFEEEFEFF7F2F7F7F7F2EFE4E3E3E3
E1E1F0DB9DD6D0CFC6C6C6C6C5B8B8C0C0C0C0C0C0C6CECF
D4D4D4D7CFCFC3C1C0C0C1C6C1C0C0C1C6C6C6CEC6C6C8C6
CEC6CECDC6CDCECEC6C6C6C6C6C6C6CEC6C6DBEACECDCECF
CFCFCFD5D7D5D5DDDDD6D6D6CDC6A9B4B4CDDACDB8C6CEC5
DACEC5E8F2EEF0EF
EFF7EFF7F7F7EFF0F2F2F7F2EFEEF7F2F7F7EFF7EFF7F2F2
F7F7F2F2F0C2CDCFCDC6C6C6C1C5BDC5C5C8CECEC8C0C8CE
D4D4D4D4D7D4CEC2C8CEC3C8C8C6C6C0C0B8B8B8B2B8B8B8
B8B2B8B8B8B8B8B8B8B8B8C5C1C5C5C5C1C0C5B8D4D4B59D
B8C6C6CFCFCFD5D6D6DBD6CEA0A8B8BAB8B8CECDC6C5C5DF
D3C5DBE8EFF2EEEE
F7F2F7F0F7F7F7F2F2EEF0EFEFF0F7EFEEF7EFF7F2F7F2EF
F7F2F2F0F7EFC5A9D9C6B9C6C6C5BDBDB8C0C5C8C8C0C5CE
CED7D4D7D4CFCFC8C8C8C8CEC8CECECEC8CEC8C8C5C1C5C1
C1C1C5C1C1C8C5C8C6C6CECEC1CECECEC6CEC6C6C8D0D3D4
C666C1B9C6CDCDCEB5938C8C9AB8C5C6B8C5C5C6D3CDB8DB
D9B8E1DFF0F2F7EF
EEEFF7EFF2EEEFF2F2F7EEF2F7F7F2F2F2F7F2F7F2F7EFF2
F2EFF7EFF2F2C5A8B8B4B9C5C5C5C5C6BDC0C5C8C8C0C5CE
CFCECFD4D4D4D4CEC8C8CECECECECECECEC8C3CECECECEC6
C5C8C8CECEC8C8C8C6CECECECECEC8CEC8CECECFCEC6CFCE
D3D0DBB59D9DB0968C9A8C93A8A8C5B8B4E8C5C5CBB1D6E1
C5DFCEEEE9EEEEF7
F7EFF0F7EFF7F7EEF0F0F7F2F7EFF7EFF2F2F7EFF7F7F7F7
EFEFEEEEF2EECECDA0B4B4A0C5C6C1C5B9C5C5C0C8C5C5CE
CECECFCFD4CED4CECEC8C8CECECECECECECECEC3C8C8CECE
CEC5C8C6C3C8CECEC3CECECECEC8C8CEC6CEC5CECECECEC6
C6C6D3D4D4C27379938C93A0A0A0A0B4BDDFA8B7CDB1CED9
C5EEE8EEEEEFEFF7
EFF7F7EFEFF7F0F7F7F7EFF7F7F2F0F7F7F7F7F0F2F7F7F2
EFEFF2EFEFEFD4CEB5A0B48B79B9C5C1C1C5C1C5C2C0C5CE
CECECECED4CECECECECECECECECECFCECECECEC8C8C8CEC8
C8CEC5C3C8C8C8C5C6CECFCECEC3CECEC8C8C8CECEC6C6C6
C5B8B0A98C7C8C8B888BA09AA0A0B7B7B8CDB1B7C5B7D9CD
D3E8EEF2E8F7F7F2
F7F2EFF2F0F7EFF7EEF7EFF7F0F7EFF7F7F7EFF2F7F7EFF7
F0EEEFF7F0EFE1E8D99AA08B7B61C1B9C5B8B9C1C5C5C5CE
CECECECECFCECECECECEC8C8C8C8CEC8CECECEC8C8C8C8C8
C5C5C5C8C8C8C8C5C8C8CEC5C8C8CECEC8C5C8C8C8C0C5B8
B8A9A0827C8C9A9A9E938BA0A0B0B8B7C5B8A8B7B7CDCDCD
D9F2EEF0F0F2F2EE
EFF2F7F2EEF7F7F7F0F7F2EFF7EFF7F7F0EFF2EFF7EEF7F2
F0F7F2F2EEF0DAF0CD9A8C8B766149B2B8B8C5C1C5C0C5C6
CECECECEC8CECECECECECECEC8CEC8C8C8CECECECEC2C2C8
C8C8C8C3C8C5C2C5C5C3CEC8CEC8C5CECEC8C8C5C0C0B8B7
A8A88C79939A8C9AA99A939AB0A0B4A8B4B1C5C5C5E1B8CE
EEEEF2EAEFEEF7F2
F0EFEFF0EFF7EEF0EEF7F7F7F0F7F0F0F7EFF7F2EFF7EFF0
F7F0F7F2F0EEE1E8CEC28B937B614949B8B8C0B8C5C5C0CE
CECECECECEC8C8CECEC8C8C8C8C2C5C8CECECEC8C8C8C5C2
C5C0C8C8C8C2C5BAC5C5C8C8C8C8C8C8C5B7B7B1A8A8A8A8
936F618CA8A07A9AA0B4B0B09A9AA0A8B8B1C5C5E8C5CDDB
E9E8E9F0F0EFF7F2
EEF7F2EFF7EFEFF2F7F2F2F7F2F7F2F7F7F2F7F2F0F0F7F2
EFEEF2F0F2EEF0DFDFB4938C736154493FB8C1B4C5C0C5C8
CEC8C8C8C8CEC8C8CEC8C8CEC8C8C2C5C8C8C5CEC8C2C0C2
C0C0C0C0C5C0C0BABABAC2C8BAC8B7C5C0BAB1B1A8A09382
616E7393A0A098A8A8B0A8A8B09AA0B1B1B7C5C6C5CDD9E8
E9DFE9F2F2EFF7F7
F0EEF7F7F7EEF7F7F7F0EFF7F0F2EEF2EFEFF7F7F7F2F2F7
EFEFF0F2F0E9E8D3E19A938B6E6161543F25B0B9B8C0C0C6
C5C8C8C8C8CEC8CEC8C8C8C8C5C8C8C2C2C5C2C8C8C5C5C2
C0C2BAB7BAC2BABAC2BAC5C0BAB7C0B8B8B7B1A99B827973
6F7A96A09A98A0A8A09393A09AB0B1B1B0C5C6C6CDE8E8E1
E9F2F0F7F7F7F7F7
EEF7F2F7F7F7F0F2F7F7F2EFEEF2F7F7F7F7F2EFF2F2F2F7
F2F2F2EFF0F2E9D9DFA0938C73616154373725B8B8C5C1C5
C5C8C8C8C8C8CECEC8C8C8C8C8C8C8C5C5C8C2C5C2C3C0C0
C0C0BABABABAB7B1B7BAB7C5B1B8B7B7A9B2A88C6E79527A
828CA09A989E98B0A8A8A8B0B0B1B7B4C5C5C6C6D6DBE1E8
EEF0F7F2F7F2EFF7
F7F7EEF7F2F7F7F7F2F2EEF2F7EFEEF2F2F7F7F0F2F7EFEF
F2F7F2EFF0EEE8DFD4A0937C736F6149372D3FB8B8C0C5C5
C6C5CEC8CEC8C8C8C8C8C2C8C8C5C8C2C5C2C0C0BAC0C0C0
C0BABAB7B2B1B1B1B7C5B7A9A8A9ABAB9B9B8B8C5B6E6F79
6F8C9A939398A8A8B4B8A8B0C5B4B7C5C5C6C5D6DBDBF0F0
F7F7F2F2F7EFF7F7
F7F2F0F0F2EFF7F0F7F0EFF7F7F2F7F0F7F2F2F2F7EFEFF7
F7F2F7F0F2EEEAD9B4A093826E7B615A3F3F4F55B9C5C5CE
C5C5CEC8C8C8C8C8C8C5C8C5C0C3C8C5C2C2C5BAC5B7C0C5
C0BABAB2B2A0A8B8C5B89BA0A8A0A8A08C8B76738C7A8C8C
96A0A0989A98A89AA0A8A8B1A8A8C5C5C5C5D3DBE8E8F2F7
EFEEF7F7F2F2F7F2
F7F7EFF7EFF2F2F7F7F0F7F7F7F7EFF2F7EFF2EEEFF7EFF2
F7F0F2F0EEE8E9D0B493937C82795A5A49525437B8C5C6CE
C5C5C8C2C5C8C2C5C8C8C5C2C5C2C2C8C0C0C0C5B7C2B7BA
B8B7B2ACA0A8A8C5C59BA0A8A89B887E6F8B7B73798B8C7C
93A0A09A9382B4A0B4A0C5A8B1C5C5C5C5CDCEE8E9E9F2F7
EEF7F7F7EFF7F7F7
F7EFF7F0F7F7F7F7F7F2F7F7F7F7F2F0F7F7F2F2EEF7F2F7
EFEFF7F7F0E8E8B8B493827A6F6F545A61614925C5C0C6C5
C8C5C8C2C2C8C2C2C2C2C2C2C5C5C2C0C5C0C0B7B7B7BAB7
B8B8ACA89B9BB7B89B949498948880667A8B7B7B7B7C7A7C
93A0A09696A0A9A0A8A0A0B0B0B1C5C5C6DBF0E8E9EEF7F7
F2F7F7EFF2EFF7F7
F7F7F7EFF7F7F2F7F2F7F2F7F7F7F7F2F2F2F2F2F7F7F2F7
EFF7F7F7EFE8DAB4A896887C7A5A5261665A453FC6C1CEC6
C0C8C5C5C8C2C3C5C2BAC2C2BABABABAC2B7BAB8B7BAB1B2
B1A9A8959BA0A8A093949393886F7676799A8C8B7B79968C
93969A9EB4A8A89EA0A0A0A8C5C6CEC6DBE1E8EEE8EEF0EE
F7F7F2F7F7F7F7F7
F7F2F7F7F7F2F2F7F7F2F7F7F7F7F2F7F2F2F7F7F2F7F2F2
F2F2F2F0EFE8D9B5A093827A79666179613F3F37C6C1C5B8
C5C8C8BABAC2C0BABABAB7BABAB7B7BAB2BAB2B2B2B2B1B1
A8A8A09A94A998887E8C82886E827B797A8C9A93828C888C
9682989EB4B4B4A0A0B4A0A8C5C5CDDBE8F0E8EEE8F0F0F7
F7F7F2EFF2EFF2F7
F7F7F7F2F7F7F2F7F7F7F2F7F7F7F7F7F7F7F7F7F2F7F2F2
F7F0EFF7F7E8C6A8A896827A7A5A6F6152374537C5C5C5C5
C5C0C8C5BAC2BAB7BAB7B2B7B2B7B2B2B2B8B7B1ACA9B1A9
A9A8A093A09B887E827A7A667676616F7C9A9A9AA08C8C82
82969E93B0B4A99EB4B8A8B7C5C5DBE3E8DFE8EEF2F2F2F7
F2F7F7F7F2F2F7F2
F7F7F7F7F2F2F7F2EFF7F7F7F7F2F7F7F7F7F7F2F7F7F2EE
F2EEF7F2F0F0B4A898936F76665F6F5F4F454F3FC6B9C5C0
C5C0BAC5BABABAB7B2B2B2ABACB1ACACB2B1B1A8ABA8A8A8
A89B9B93A093827A75756E7A7666666F7B8B9A939A939682
827C93A8A9A8B5B5B4A0A8B7C5CEE1DFE8F0EEE8F2F7F2F7
F7F7F7F7F2F7F7F2
F7F2F2F7F2F2F7F7F7F2EFF7F7F2F7F7F2F2F0EFF7F2F2F7
F7F2F7EEF0D9B5A893887A82616F6F663B373F45C5B8C1B8
C0C0BABABAB2B7B1ACB1ACACABA0A0A0A8A8ACA8A8A0A0A0
9B9B9496827A796F757A7A6F6F6F737B7C8B9AB0A8B79879
79829893A8B4B4B4A0A0A0C5CDCEDFE8E1EEE8F7F2F7F7F7
F7F2F7F7F7EFF7F2
F2F7F7F2F2F0EFEFF2F7F7F7EFF7F2F7F2F7F0F7F7F7F7F7
F2EFF2F0F0C6B49E96826F7666795A5233333F3FC5B8C0C1
C0BABAB2B1B1B1B1ABA9A8ABA8A8A0A0A0A0A8A8A0A0A094
949388937C6F667A6F7A7A4F4F5A768B8B8B93A0A8A0B496
829393A093B5B5A0A0A0A0C5CDE8DFE8E8E9EFF7EEF0F7F7
F2F7F7F7F2F7F7F7
F7F7F7F7F2F7F7F7F7F7F7F7F7F0F2F7F0F7F2F7F2F7F2F0
F2F7EEF2DFBDB496887A7666666F5A493F454549B8B8B8B8
BAB8B2B8B2B2A9ABABA0A0A0959B9B95A0A095A0A0A09493
9493829A7A5A76766F66524F37738B768B7C8CA0B0A9B796
96A096A09EB4A0A0939AB7CDDBE1E1DFEEF0F0F7F2F2F7F7
F7EFF7F2F7F2F7F7
F7F7F2F7F2F2EFF2F2F7F2F7F7F7F7F7EFF0F2EFF7F7F2F7
F7EFF2EECEB5A5888876756F666645453F454545B8B8B8C6
BBBBB6BBB6B6B8B2B2A99B939B8D939393939B9B93939388
887E82936F556F7A5A4F4955616E8B8B828B79A0A8B4A09E
93989896B4B4A0A8A0B4B4CBF0DBDFEEE9F7F7F7F7F2F7F7
F7F7F7F7F7F2F7F2
F2F7F7EEEEF7F2F7F7F2F2F7F7EFF7F2F7F0F2F0F7F7F2F2
EFEFEFE8CBB49E88827A6F825F662D4D45453F5DB8CDCFCF
CFCECEC3C3C3BCBBBBB8B2A98D8D8C8D8D888888938D888C
827A7A8C5A5B6F66523F4573526F8C8B8279829AA9B7B8B4
9E9E887CB4B49EA0B4B4C5EEE8E8E8EEF0F2F7F2F7F7F7F7
F2F7F7F7F7F7F2EF
F7F2F2F7F7F7F2F7F7F7F7F7F7F2F7F7F2F7F7EEF7F2F7F0
EFF2F2D3BDA8988880666F666F52374F4D453F8FCFD0DDD2
D2CFCFD2CFCFC3C3C1BBB8B2ACA08C82888C8C8D7E888C88
827A6E82666F8252493F537B546F7C8C7B7982939AB7B8B4
A89E8296A8A8A8A8C5A8C5EEE1D9EAE9F7F2F7EFF2EFF2F2
F7F7F2F7F7F7F7F7
F2F7F0F7F2F0F7EFF7F7F7F7F2F0F7F2F2F7F2F2F7F2EFEF
F0F2F2D3B49E96807A7A6F666F374555454595D0D7DDD7DD
D2DDD2D7D2CFCECFC3C3BBBAB2B1A8A0828282828C828882
75765E52826693493F2D37797C617C9A79968293A8B7C5C6
B57C9696A098A8B5B4B1E9E1D6E8F0F2F7F7F0F7F7F7F7F2
F2F7F7F7F7F2F7F7
F7F2F7F7F7F7F7EFF2F0F7F7F7F0F2F7F2F2F2F2F7F7F7F7
EFE9D9CDA59E8876666F6F665737555545CED7D4D7DDDDDB
DDDBD2D2D2D7CFCECECEC5B8B8BAB2A9A07E7A7A827A7E7A
756F524F93529B6F45532D528C547C8C7B939393A0A8C5C6
B49888969E9EB4B5B4C5DFDADFEEEEF7F0F7F2F7F7F2F2F7
F2F2F7F7F7F7F7F7
F7F7F7F7EFF7F7F7F7F7F7F7EFF2F0F7F7F2F7F7F7F7F7F2
EEE9D0C29D96887A6E6F6666453F4F458BD5D7CFD7D7DDDD
DDDDDBDDD2D2CFCFCFC6C1C5C0BAB8B2A995A075757A7675
6E5F584D8C8088823F2D4F6F8C938C8C937A98969EA8B4C5
C59682968C9EBDC5BAB5CDE8F0F0F2F7F2F7F2F7F2F2F7F7
F7F7F2F7F7F7F2F7
EFF7F2F7F7F7F0F7F2F2F7F2F2F2F0F7F2F2F0F7F7EEF7EF
EEDFD0B49D9682765E665A6633454D66CFD0D7D7D7D7DDD2
DDD2D2DDD2D2CFCECFCFCEC1C1C0B8B8B2A9A0956F757568
6F57553776A95AA06E7A3F735B96738B8C968F9E88B4A0C6
D596829698A5A8B4B5C5DFE8E9F0EEF2F7F2F7F7F2F2F7F2
F2F7F2F2F7F2F7F7
F2F7F2F7F7F7F2F2F7F7F7F7F2F2F7F2F7F7F7F7F7F7F2E9
E9D3D0A59880826E66665D453F5763D0CFD4D7D7D7D2D4CF
CFCFCFCFCEC3C3C6CEC5C8C1C1B8BAB8B8B2A8A09B6F5F6F
5B5A45455E968876A5548866757C8C798C966F9696A8A8B4
B8C5967C96A59EB4C5DAEEDFEEF0EEF7F2F2F7F2F7F7F2F7
F2F7F7F7F2F7F7F7
F7F7F2F7F7F7F2F7F2F2F2F2F7F7F2F7F2F0EFF2F2F7F7E9
DAD3BA9D88806E6666663B453F3FD0D0D7D4CFCFD2CFC8C1
BBBBB8B8B8B2B8B8B8B8C0C0C0C1C0B8B8B2ACA9A89B7E66
5D584D45536EA09683A88C885279938B8C798888A99EA8B4
C6CE969EA99E98B4C5F0DFF2EEF0EEF7F7F2F7EFF2F7F2F2
F7F7F7F7F7F7F7F2
F7F2F7F7F7F2F7F7F7F7F2F7F7F7F7F7F2F2F2F7F7F2F2E9
D9D0B59E8282755B665D3F4557CED5D5D7D4CFCFCEC6BBBA
B2ACA5A5A5A5A5B2ACB2B8B2C0C0C1B8B8B2B0A9A0A09466
53554533456CA08066B08CA0886F7A9A8C829688A89EB4A8
B4CDB4A8A5A5A8B5C6E8E8F0EEF2F7F2F7F7EFF7F7F7F2F7
F7F2F7F7F7F7F7F7
F7F2F7F7F2F7F7F7F7F7F2F7F7F7F7F7F7F2F0F0F7F2EEDA
D3D1A588806F755E5745454955D0D0CFCFCFCFCEC3918696
969D9D9D9D9D86868686A9B8B8C0C0C0B8B8B2A9A9A09593
55453F2D3F5E80A98F95B4A0A89E8C829396798296A896B7
B5C5C6A5B49EA8C5D0DAE9EEE9EEF0F7EFF2F7F2F7F7F7F2
F7F7F2F7F7F2F7F7
F7F2F7F2F7F2F7F7F7F7F2F7F7F2F0F7F7F2F7F7F0F7E9DF
D9B59E83766F66555E4D4555D6D0CFCFCED4CFA59D9D9DD0
C3A5A5B6C39D9D96958C86A9B8B8C0C1B8B8B8B0A9A09D94
885333332D5E33B0B86FB588B1B49693A0739388969EA0A9
B5C6CE9D8F9EA8B4E8E8EEEEE8F7F7EFF2F2F7F2F7F2F2F7
F7F2F7F7F2F2F7F2
F2F7F2F7F2F7F2F7F2F2F7F2F2F2F2F2F2F0F7F7EFF7DBD0
B49E8F835E665B663745458BD5D5D5CFCECECE969D9D9691
91919D8686787D7DA58C8C78B0BBC0C0C0C0B8B0A9A9A0A0
93804545213F668F9E8896B493B7D4968293937A88A09EA8
A8C6C6A59EA59DB4E8E9F0E9E9F7F7F7F7F7F7F7F2F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F2F2F7F2F2F2F7F2F2F2F7F7F2F2F7F2F2F2DAC8
A89E806E5B66573F4F3F66D6D6D5CFCFCEA59D805F647080
7070786C5F4F5A644A605A53689DC0C0C0B8B8B8A9A9A8A9
948866252145536396B066B088A9C5D4A0A07B9388969888
B4C5C6C2A8B4A5BDDFEEE8EEF2EEF7F7F2F7F2F7F7F7F7F7
F7F7F7F2F7F2F7F7
F2F2F2F7F7F2F2F7F2F7F2F7F2F7F2F2F2F2F2F0F2E9DAC2
9D886E5B665A55555553D6D6D0D5D7CFCEC3CEA58C867D86
7D86967D7D7D7D7D7DA8B0B0B8B8C0C0BABAB8BAB2A9A9A8
A0947B41212141637BA99E76A888C5C5D580939388969688
B4B4C6CD9EB4A8D9E9E9E8E8F2F2F2F2F7F7F7F7F2F7F7F2
F7F7F2F7F7F2F7F7
F7F2F2F7F2F7F7F7F2F7F2F7F7F7F7F7F0F7F2EEF0E8D1B5
8F7676665A574D55525DD5CFD5D4CFD4CED4D7D7DDDBD0CF
DDCFCED7DDD0CFC6C1C6C1C0C0C1C0C1C0BBB8B8B2B2A9A8
A0A0885D35166353637B966F937A93C5C5A8A096828296A0
A8A0C6CDA5A598DFE8E8E9E8F7F7F7F2F7F7F7F7F7F7F2F7
F2F7F7F7F2F7F7F7
F2F7F7F7F7F7F2F7F7F7F2F7F2F2F7F7F2F0F2F2E9CBC5A5
806E5D5D583F55554FBDD5D5D5D2D7CFD7CFD7D7DDD7DDD7
DDCECFCFCFC1C1C1C1C5C1C5CEC1C0C5C1BBBBB8B2B2A99D
A0A088682D29535D8B7BA56F669896B8C5CEB49393988288
88A0C6CDA8B59EE8E9DFE8F0F7F7F7F2F7F7F2F2F2F7F7F7
F7F7F7F7F7F7F7F2
F2F7F2F2F2F2F7F0F7F7F7F7F2F7F2F7F2F2F0F2F2D1A588
6F7657584555555555D5D5D0D5D7D2D2D7D5D7D7D7D7D7D7
D5CFCECECEC1C5C8C1C6C1CEC1CEC1C1BBBBC0B8B2ACB2A8
A0A094764D41215A5E6E6F806F8883A0C5C5A0A893968296
82A8B4C6B49EA9DAE8E8D9F7F2F7F7F2F7F2F7F7F7F7F2F7
F7F7F2F2F7F7F7F7
F7F2F7F2F2F7F7F7F2F7F7F7F7F7F7F7F7F2F2F0D1C89D82
76576645553F555745D5D0D0D5D7D7D7D2D7D7D7D7D5D7D7
CECEC1CEC1BAC0C5C1C3C8CEC3C3CFCEC1C1BBBAB2B2A9A8
9D959482532D33536C747B8F76666E9D98B0CEB48C98769E
96A9A8C6B496CED9E9E9E9F2F7F7F7F7F7F7F2F7F7F7F2F7
F2F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F2F7F7F7F7F2F2F2F7F7E9CBAD9D76
6F6E5355555355458FCED0D0D7D7D7D7DDD7D5D7D7D7CFCF
C1B8B2BBB8B2B8BBC0C1C8C6CECFCFC3C3C1BBB8B2B2A9A9
A8A08D7E66414548635E7B6E825D6F5EB5C5A8B1989E8388
96A5A8C5BD9EDFC6F2E9F7F7F7F7F7F7F2F7F7F7F7F7F7F2
F2F7F7F2F7F7F7F7
F2F7F7F7F7F7F2F7F2F2F7F7F2F7F7F7F0F7F2F2C59D806E
5B5B55454555553FCED0D0D2D7D7D7D7D7D7D4D7D7D7CFC3
BCC0ACB2B2A9B0B8B8C0C1C8C3CECECEC3CEC2BBB8B2A9A9
A89594886841162F535D765E826F6F55B093A8D49E989888
95939EC5C2C2D0DADAD4F7F7F7F7F7F7F2F7F7F7F7F7F7F7
F7F7F7F2F7F7F7F7
F7F7F7F7F7F7F7F2F7F7F7F2F7F7F7F7F7F7F7E9B58F6E5D
5B45554D55533F3BD0CDCFCFD7D2DDDDD7D7D7D2DBAC96CF
CFC3B6777795AC88A8B8C1CECECFCFCFCEC3C1BBBAB2B2A9
A8A0947E754D212F3B535E6376765D766696B7A8B793966F
8888A8C5C2E9B4E9BDF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F2F7
F2F2F7F2F2F7F7F7F7F2F2F7F2F7F7F7F7F7F2E09E806E6F
5555454F55453B5ED0CFD5D7DDD7D2DDD2D7D4D7DDD5D0D2
D2CFC0B8B8BAC0B29BA9C1CFCFCFCFCFC3CECEC2BAB8B2A9
A0A0948D7B6616212F485A665E7B5D6633B49BA0C5889676
80969EB4CBCBB2BDF7F7F2F7F7F7F7F7F2F7F7F7F7F2F7F7
F7F7F7F2F2F7F7F7
F7F7F7F7F7F7F2F7F7F2F2F7F7F7F7F0F7F7F7DA966E6845
53584D5558373784CDD2D2D2DBDDDDDDDBD7D7D2DDD0DBDB
DBD2CEC0BCBCB8B8B2B2C3CFCFD2CFCFCFC3C3C3C0BAB8AC
9D9D94887A6E162921535E6E4D765D663B9E96B4C5889680
888F9DB5CBCBC2D0F7F7F2F7F7F7F7F7F7F7F2F7F7F7F7F7
F7F7F7F7F2F7F7F7
F7F7F7F2F7F2F7F7F2F7F2F7F7F0F7F2F2F7F2D48066665D
5555575B4F3341CED0D7D7DDDDDDDBDDDBDDD2CFDDDDDBE4
DBD2CFC6BBB6B8B8B2BBC3CFCFD4CFD2CFCECEC3C3BBBAB2
ACA095887A66330C294D336F5D764F5D668098B1B1A88896
808888B4CDBDD4F2F7F7F7F7F7F7F7F2F2F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F2F2F7F2F2F7F7F2F7F7F7F09E6E6E454D
4D555855293729CFD2D6D2DDDDDBDDDDDDDDDDD7D7D2DBDB
DBD7CFBBB0B2B8B0B8C1CFD0D0D5D7CFCFCECFCEC3BBBAB8
B2A89588807553142141615E666E555D537B93A0B8C68288
7B889EC5CDA5D0F7F2F7F2F2F2F7F7F7F2F7F7F7F7F7F7F7
F7F7F2F7F7F7F7F7
F2F2F7F7F7F2F7F7F7F7F7F7F2F7F2F7F7F7EF8F6E57455E
58585521332D41CFD7DDDBDBDBDBDBDBDBDBDDDDD2D6D2DD
D2D0C3C1B0B8B8B8C1CFCFCFD0D2D7D0D2CFCECFC3C3BBBA
B0B2A09480765B1635334D535D5D6F5D5D8396A0B8D48882
76838FB4CBD0F2F7F7F7F7F7F7F7F7F7F7F7F7F7F7F2F7F7
F7F7F2F2F7F7F7F7
F7F7F7F7F2F7F7F7F7F7F7F2F7F2F7F2F2F2F28F6655555E
535558332933B4D5D5DDDBDBDBDBE3E3E3DBDDDDDDD7D0DD
DDCFC3B8B8B8C0C1C6CFD5D0D2D2DDD6D2D0CFCFC3C1C1B8
B2A9A8947E766E29143B335E6655666F5D7BA5A8B7D48098
668F80C5D3D0F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F2F7
F2F2F2F7F7F7F7F7F7F7F2F2F2F7F7F2F2F7CD7B664D5D5D
5855332921C3D6D2DDE3DBDBE3DBDBDBDBDBDBDBDBDDD7DD
DDD2CFC1B8C0C0C1C6D0D0DBDDD2DBD2DDD6D6D0CFCDC3C0
B8B0A9A888766F4D374553536E5D6F665B7BB0A8B4C69682
5D8388B8D9EEF7F7F7F7F7F7F7F7F7F2F7F7F2F2F7F7F2F7
F2F7F7F7F7F7F7F7
F2F7F2F7F7F7F7F7F7F2F7F7F2F7F7F7F7F77B665D3B6153
5358334541CFD0DBDDDBDBE3E3DBDBDDE3DBDBDBDBDDD6DD
DDDDD2C1B8C1C5C6C6CDD5DDD6DDDBDDD2D6D6D6D0CFC6C1
B8B8A9A88D7E68534545455E5D6F6E667A8FA9A8A8B49879
57839DB5DFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F2
F7F7F7F2F7F7F7F7
F2F7F7F7F7F7F7F7F7F7F7F7F2F7F7F7F2F7806F5345665E
554D45338CD2D6DBDBDBE3E3DBDDDBDDDDDBE3E3DBDBDDDD
DBD2D2C1B8B8C5C6CFCFD6D6D6DBDBD2D2DDD7D5D0CFCFC6
B8B8B0A8947E685B3B3B4553586E6F6E66A8A8A8A8B0B47A
7A808FB7EEF7F7F7F7F7F7F7F7F7F7F7F7F7F2F7F2F7F7F7
F7F7F7F7F7F7F7F7
F7F7F2F7F2F7F7F7F2F7F7F7F7F7F7F7F7F27B7B5E534D5E
583B4D5ED0D7D6DBDBDBDBDBDBDBDDDBD6DBDBDBDBDDDDD0
DBDBDDC6BBB8C1C6C6CDD0D6D6D6DBD6DDD6D0D0CFD0CDC6
C6B8B0A9A088765E4D3F45455E666C5E57B5A89EA9A5B866
80808BB4F0F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F2F7
F7F7F7F7F7F7F7F7
F2F7F7F7F2F7F2F7F2F7F7F7F7F7F7F2F7B1666C5D665D5B
45414DCDDDD0DDDBDBDBDBE3DBDBDDD6D0D0D6D6DDDDD2D7
DBDBDDCFBBB8B8B9C5B9CED3D0DBD6D6D6D0CED0CFCFCFC6
C6B9B8B09D947666533345455376666666A59EA8A876C552
76969EB4F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F2F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F2F7F7F2F7F7F7F7F7F7F7F7F2F78595765376535B
3B5355CDD2CDDBDBE3DBDBDDDBD6D6C3CDCFCFD0D6DDD5D7
DDDBDDCFB6B8B0B8B8C6CED0D6CDCDC6CDCDCDCDCFD0CDCD
BDC5B8B0A894806658332D4553666F6666A5A0A0A858B768
668FB0CDF7F7F7F2F7F7F7F7F7F7F7F7F7F7F7F7F2F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F2F7F7F7F2F7F7F7F2F2F2F2F7F75A9B6674636653
336FBACFBBD0DDDBDBDBDBD6D3D0D0CFB9B8C6CDD0D6CDD0
DBDBDDC3B8ACB5B0B4BDCDCEC6C6BDBCB8B8B0B9B9C6C6C6
C5C5B8B0A0957E765E4D2137456666765E9DA9889657C576
5B9EB4D9F7F7F7F7F7F7F7F7F2F7F7F7F7F7F7F7F7F7F7F7
F2F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F2F7F2F7F7F7F7FF76845E665E682D
5D58D2A0B2D5DDDBDBDBD6CEB99D95B0AF9DB9B9D6D6D0D0
DDDDDDCFB8A9A5A9C5B9CEBCB9ADA48F95A5A5A5AFC5C6B9
B9B9B8B0A59588685E53453B3B5E5D6C668F96888866C566
5BA5A8DAFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F2F7F7F7F7F2F7F2F7F7F7F7F7F7F7F7A5837B535E53683B
66C2C3A5B0D5D6DBDBD0BC8F96B9B16C728CA59D9DD0D0CD
DDDDDDCEC1A9B09DB05F7895B0CD815F858483848FB0B8B8
B9B9B0B0A0957E7666535E33335E5E66768F9D828861C56F
7BB4B4E9F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F2F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F2F7F7F7F78FA47B6C3B5E683F
33D2BAB6B8D6DDD6CDBC8F95C3DA756C5B7C85A59DBCB8CE
DDDDD5CFC1B29D8F95A560CDE9787A6D8D64A57B728FB0B0
B8B8B0A9A88F80765D533B16295E664D768F8F768375B857
9DB5B5F7F7F7F7F7F7F7F7F7F7F7F7F7F2F7F7F7F2F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F2F7F7F7F7F7F7FFF28B5D553B5E5E5E
68D2B2A5B8CED5CFB99D7A419DBA80B51A774D7A8F9DC1D4
DDDDD7CFC5C09D957B959D76C75BBC1A725BA5355A84959D
B0B0B09D9E9480685E58292129335E53807B83838875B457
96A9CBF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F79BCA907A5C535E5E68
8CC3A5A9B8D0D5C1AF95536B6B482F415E726B849DBBC8D7
D7DDD7CFC8C1B29D95807A92924133414153485F5C848F8F
A0A9A99D8F88686666534529414545537680766F8880B46E
96A8E8F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F2F7F7F7F7F7F7F7
F7F7F7F7F2F7F7F7F2F7F7F7F7F7F780A5A166536C5E535B
94B6A9A9B8D0CECDC6B89D7E6C5C5C5C5E7A95B0C1CFCFD7
DDDDD7CFCFCEC0B2A99D8F6A848C836B5048537B969595A0
A9A99DA0967E68665E5E4D33413B3B4D7B887B6F8896B476
96B0EEF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F2F7F7E89174534D53534576
94A0A59DB0CED5D5DDD6CFD0C6C1BCC1C6C1A9B2BBCEDDD7
DBDBDDD7D4CFC0A8AC9DB0B0B09D9D9DA0A9B0B0B8BAB8B0
B0A9A0959688686C5E45453341534D457696766F939DB87B
9DE1FFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F2F7
F7F7F2F7F7F2F7F7F7F7F7F2F7F7FFFF4D663B45456E3B5F
7E9DA095B0D5C6D7DDDDDBDDDDDBB695847B7EC1CEDDDDDD
E3DBDDDBD7DDC8BB95757B7E95C6CDCFCDC6C6C1C1C1B8B0
9E8FA096888076665D5E373333412D536680766E989EC583
A5E9F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7E9FF45553B45535E536F
77889695A5CFCBC5D0DDDBDBD28F847A7EB0CED7D7DDE3DD
E3DBDDDDDDD7D7CEBB96685E687EB2BCCDCFCFC3C6B8B29D
83A0958F807676664545333B332D5A6374837B669696B59D
A5F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F2F7FFB1FF5D4D53533B5E5566
6868848FA5CED69DA5B0A99D7E80A9D7DDDDE3E3E3E3E3E3
DBDBDBDBDDDBD7D7D7D4C1B0957A667B758695958F84838F
9D9D9D968076765E76294D4D45332F6A7680766E96A88F7A
D0F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F2F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F2F7F7AD7B53536A5E5353535E
666C7B83B0CED5D5CFB0A49DB9DBE3E3E3E3E3E3E3E3E3E4
DBDBE3E3E3DDDDDBDDD7D2CFCFCFCDCDA5848084849DA59D
A0A8A096807B805E4553453B2121296C7A6683759EA57696
E9F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F2F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F2F7F7F7F2F7F7F7F7F7CA7661538372615E5366
666C8080A9CFD0D5D5DDDDDBDBDBE3E3E3E3E3E3E3E4E3E3
DBE3E3E3DBDBDBDBDBDDD5D5D7CFCFCFC6CDCDC1B8B8B0A9
B09D95888083807653452D21212129956C66A87688B476A5
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F2F7F7F7F7F2F7F7F7F7F7F7BA575A6390745E636163
6366837BA9CDD5D5D6DDDDDBE3E3DBDDE3E3E3DDE3E3E3E3
DDDBE3DBDBE3DBDDDDDDDDD2D7D0CFCDC6CFC1C1B8B0B0A9
A99D9E967E808066764D3333293B2D9D83669D8076B576C2
FFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7D15E726C7B6C726C635E
5D5D767B95C5D0D5D5D6DDDDDBE3E3DDE3E3E3E3E3E3E3E3
E3E3E3E3E3DBDBDBD7D7D7D7D7CFCECDCFC6C5C0B8B8B0B0
A9A8A08880887B76533B453B2121299E8476A8826C9D76F2
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F2F7F7F7F7F7F7F7F7F26C5E5E5E6A6C5E635E
635E83889EC1C6D4D6D7DDDDDBDBE3E3E3E3E3DDDDE3E3E3
E3E3DBDBDBDBDBD2D7D7D7D4CFCFCFC3C6C5C6C1B8B8B2B0
9DA095968880765E53414D2921213B7BA88FA9887B6EB4F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F2F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7FF5C725E6C72746C6363
5E6C7B969DB8C6D5D6DDDDDDDDE3E3DDDDE3E3DDE3E3DBE3
E3E3DBDBDBDDDDDDDDD7D7D4CFCFCFC3C1C1C1C1BBB8B0B0
A9A0958F8F84766645532D2929212F7A9D7B9E968B6ED4F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7FF835A667474636C5E61
746C7B8F9EB0C6CFD7D7D7DDDDDDE3E3DBDDE3E3DBDDE3DD
DBDBDDDBDDDDDDD7DDD7D7CFD7CFCECEC6C5C6C0B8B8B0B0
9DA0958F8F76766653452D2116165C6C8380A59EB59EF7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7FF5E8483666C6A66636F
4D6C849695B0C5CFD5D7DDDDDDE3E3DBE3E3E3DDE3DDDBE3
DDDBDBDDDBDBDDDDDDDDCFD2D4CFCFC3CEC1C1B8B8B8B0B0
9DA8958F7B7463535E3B21162F166A74766E9E9EA5DFF7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F2F7F2F7F7F7F7F7F7F7F7F7F7E08461615E5E5D635E
6C6C8395A5B0C5CFD5DDDDDBDDE3E3DDE3DDE3DDDBDDE3DD
DBDBDDDDDDDDDBDDDDD2D7D7CFCFCFC3CEC1C1B8B8B8B8B0
A5A98F847B7B7661453B21212F2174747B6F9EA5B0F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FF6C615E535D5A5361
6C768F95A9B5C5CFD7D2DDDBDDDDDDDDDBE3E3E3E3DBDBE3
DDDDDDDDDDDDDDDDD2D7D7D7CFD7CFCECEC8C1B8B8B0B8B0
B09D8F8F846C66453B292916272182746F6EA5BAD1F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7BC6A5E5E5D5E5E5A
5E768495A5B9C6CFD7D7DDDBDBE3DBE3E3E3E3E3DBE3DDDB
E3DBDDDBDDDDDDDDD7DDD7D2D4CFCFCECEC1C1B9B8B8B0B0
A0A09684837B66413B292F1F2929848F66809EC5F7F7F2F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F2F7F7F7F7F7F7F7F7F7F7F7F7F7F7F27253535A5A5E61
5A748F9DB0B8CECFD0D5D7DDDDDDDDDDE3DDE3DBDDDDDBDD
DBDBDDDDDDDBDDDDD7D7D4D7D2CFCFCFC6C6C5C0B8B8B0A9
A99596847B6C5E413B2F29333321768F7693B0D2F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F784725A63615A61
63747B9EB5C6C6CFD7D7DDDDDDDBDBE3E3DBDDDDDBDBDBDB
DDDDDBDDDDDDDDD7D7D7D4D4CFCECECFC6C5C0BBB8B8B2B2
A0958F8076665341413329332116747B7696B8EEF7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFBC8474747461
61748B95A9C1CECFCFD7D5D7DBDBDBDBDDDDDBE3DDDBDDDD
DDDDD7DDD7D7D7D7DDD2D7CECECECEC3C6C5C0B8C0B0B0B0
959584836C5E4D533B3B292114418F7B82A0B4F7F2F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F2F7F7F7F7F7F7F7F7F7F2F7F7F7F7F7FFFFE97A74636C
6A6C809DA5B8CECFCFD7D7DDDDD7DBDBDDDDDDDDDDDDDBDD
DDDDDDDDD7D7D7DDD7CFCFCFCFCECFC8C1C1C1C0B8A9B09D
9D9680685E634D41412F331A1483846E8898D3F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFA55E6A5A
6C6C8396A9B9C6C3CFCFD7D4D4D7D7DDDDDDD7DDDDDDD7DD
D5D7D6D7D7D7D4CFCFCFCFCECFCECEC3C1C1C1B8B8B0A9B0
9584766E6663633B3B3321168F82766E96BDE9F7F2F2F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFD0456383
61838396A5B8C5CDCFCECFD7D7DDD7D6DDD7DDDDDDDDDDD7
D7DDD7CFD7CFD7CFCFCECFCFCECEC5C8C0C0B9B8B49DA9A0
8F847B7663535A74292127615E8376809EC6F2F7F2FFF7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFBA7B5E5E
6A848396A9B8B9C6CFCECFD2CFDDD4D7D7D7D7D7D7D7DDD2
D2CFCFCFC3CFCECECECECECFCECEC0C0C1B8B8B8B09D9D8F
807B6E63635E5E415341534D847B8F96B5C2F7FFF7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFADA54D5D
61667B8F9DA5BDC1C6CEC3D2D2D5D5D0CFD2D7D7DDD0D5CF
CFCEC3C1C1C2CECEC8C3C8C2C1C1B8BBB8B0B0A99D9D958F
8083765A5A5353484D3B8B747B76A99EC5F7F7F7F2F7F7FF
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFF7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E0CD3B4D
765E7B8B95B0B8B9C1C3C3CECFCDCFD5CFCFCFD0CFCECFCF
C8C1BABBBBC0C2BABABABAB2B8BBB0B8B0B0A5A89D8F8F8F
837B6663615A726153728F7A8496B0C5C2F2F7F7F7FFF7F7
F7F7F7F7F7F7F7F7F7F7F7F2F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7AD8361
63746C7B849DB0C5B9BDC1C1CFCFCFCFCDC6C6C6C6C1B9B8
B8B8B0B0A9A9A9A8ACA9A8A89DA0A0A0A095959D958F8876
6C7A745F7474536C76767B76968FB8C5F0F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7B17A
636C74838F85959DB8BDC6CECDC6C6C6C5B8B8B0B8C5B0B2
B0B09DA595A096A98CA088958888968F8F8F8F84959D8B90
83846C6C7A8463455E888F8896B4BDC2F7F7F7F7F7F7F7F2
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFF7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E9
917A617B836C95A5C2CECECEC6C6BDB9B0B4B0B0B0B0B0B0
9E9E95958F958F808F8F7B768F7B8F7B808483846C747A80
7A7B7A7B5E6372767B83839EBDBDA5F7F7F7F7F2F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F2F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F2F7F2F7F7F7F7F7F7F7F7F7F7F7F7F7F7
9185847D90ADAFA4B9AFB9C2C2B9B8B0B0B09DA5B0A59EA5
9D958F8F7B9D849D8F849683769D838F84838B906A748382
727A846E766E766E7B8FB4BAB4B5D4F7F7F7F7FFF7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F2F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
FF7A8C7D748B9595A4B9BDB8B4B0B5A5A5A5959D959D959D
8F9D837B856E8B83957B8483849E6C7B7B8F837474636153
5A6C5E5E61616E829EB4CDA4B58FF7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7FF9B8584A5A5ADBDBDBDBDA5A5A5A59DA59D9D8F8F9D8F
83846E8B8B6C5384638F8384846676834D536F6663666F6E
766E6E5E6F76B49DB5C26CA48BD2FFF7F7F7F7F7F7F7F2F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7AD8C6A7D768BADBAB9BDAD9D9D959D9D958B9095848F
8F6C9E836C9D6C63846C6C7463665D4D5E5E6F5E616E665E
58667B8F8FA59DC5BD8B83A48BF7F7F7F7F7F2F7F7F2F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F2F7F7FFF7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7FF5F83A4858B9BB2BAB0AD848F8B9D9D8F7D8F8F8495
848F637B7A6C83636C6E636A635A5E5E5E534D5E615E5D5D
6C83838383A5BA82828BAD9DE9F2F2F7F7F2F7F7F2F7F7FF
F7F7F7F7FFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F783539BA1A49BBDBDB2839584848F837A8B8B7A84
7A84638376745A53835A6163615D535345414D4D4D5D7663
6C8BA59DC6BAA49074A574E9FFFFF2F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F2F7FF854D7B8C9BBAC2B283749B84959B8F748B836C
84846C7B837A723B5361835E5E455E4D453B413B3B53668B
9D8F9DBA9B6A808F8B76ADF7F7F7F7F7F7F2F7FFF7F7F7F7
F7F7F7F7F7F7F7F2F7F7F7F7F7F7F7F7F7FFF7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F2F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7D26D616A90A4B2BD8B7483957A7A84726C7D7A
7274847A6C837B726C53536A5E5E665D765D5D6676808496
A5CB9BA483537A8B9B9BF7F7F7F7F7F7FFF7F2F7F7F7F7F7
FFF7F7F7F7F7F7F7F7FFF7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7C380776B6A8C92BD6C72828F7A746361616C
6C747A6C6C838B7B7A61835E5D7A746C6E76838FA5959DBD
A4A19090617D908B85FFF7FFFFF7F2FFF2FFF7F2F7FFF7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFF7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7FFF7F7F7F7B17A7B7D8B91A5AD72728B8B748B5E6363
76747B5E857B95848F9B7466667B7B8F8F9696B0B0AD8483
83664D5E848B829DFFF7F7F7FFFFF7F7FFF7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F2F7F7F2F7F7BC6B7B909BA4ADB27A8B6C8C7A84745E
5C536C617D7B9D95CBCEBDA5B9B0B0B0CDCDB8BA90728274
63616C8F9B8485FFF7F7FFF7F7F7F7F7F7F7F2F7F7FFFFF7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7FFF7F7EF8A7B6590BABAB48C958C91859DAD
835C725C7A9BADA491C2C3C2CBD9D4C2A59B9B8C7B7A745A
5E7A829D849BF7F7F7F2F7F7F2F2F7F7F7F2F7F7F7F7F7F7
F2F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7FFF7F7F7FF836B8991B2CDB2B2C3B1D0C3AD
D4DBF0E8DBD4D3C2D0CBCBCBD3BA90AD908283836C725F84
908B8B84FFF7F7FFF2F7F7F7F7F2F7F7F7F7F2F7F7FFF7F7
F2F7F7F2F7FFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFF7F7F7
F7F7F7F7F7F7FFF7F7F7F7F7E06B789BABC3D0DAD1D0D0D0
DACBCED3CEDBE1DAD0D4BAA5C2A4A1A577836C72838CA4A5
958BADF7F7F2F7F2F7F7F7F7F7F7F7F2F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFF7F7FFF7F2F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7FFF7FFFFF7FFF7F7FFE98C8992BABAC3C8D0DADA
DADAE8DFDBDAE1D4D0C3C7A192A582837A906B91A4A5A191
A5E0F7F7F7F2F7F7F7FFF7FFF7F7F2F7F7F7F7F7F7F7F7F7
FFF7F7F7F7F7F7F7FFF7F7F7F7FFF7F7F7F7FFF7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F2F7FFF7F79D838CBCCDDADAD9
D4CDDBD1CDC3B2A49BADB2A1916F85A191B2B2BAB292B2F2
F7F7F7F7F7F7FFF7F7F7F7F2F7F7FFF7FFF7F7F7F2F7FFF7
F7F7F7F7FFF7F7F7F7F7F7F7F7F7F7F7FFFFFFF2F7F7F7F7
F7F7FFF7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFF7F7F7F7
F7F7F7F7F7F7F7F7F7F2FFF7F7FFF7F7F7F7F7A59DBABCC3
DBDBDADBDBDAC3C3ADAB9DBAD0A5C3CDC3A59BC2E9FFFFFF
F7F7F7FFF7F7F7F7F7FFF7F7F7F7F7F7F2F7F7F7F7F7F7F7
FFF7FFFFFFFFFFF7F7F7F7F7FFF7F7F7FFFFF7FFF7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F2F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFF7FFF7F7B1ABC3
ADC2D1D1DFDBE8F0E8DAD0DAD1D0ADA4BAD0E9F7F7FFFFF2
F7F7F7F7F7F7F7F2F7F7F2F7F7F7F2F7F7F7F7F7F7F7F2F7
F7F7F7F7F7F7F2F7FFF2F7F7F7F7F7F2F7F7F7F7F2F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFF7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F2F7F7FFF2F2F7F7F7F2F2
F2E9E9E0F0E8D0C3C3D0D1CDCDD2E9F2F7F7F7F7F7FFFFF7
FFFFFFF7F7F7F7F7F2F2F7F7F7F7F7F7F2F7FFF2F7F7F7FF
F7F7F7F7F7F7F7F7F7FFF7FFF7F7F7F7F7F7F7F7FFF7F7F7
F7F7F7F7FFF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F2F7F7F7
F7F7F7F7F7F7F7F7FFF2F7F7F7F7F2F7F7F7F7F7F7F7F7F7
FFF7F7F7F7F7F2F2F2F2FFF7F7F7F7F7F7FFFFF7F7F7FFF7
F7F7F7F2F7FFF7F7FFF7F7F7FFF7FFF7FFF7F2F7F7F2F7F7
F7F7F7F7F7F7F7F7F7F2F7F7FFF7F7F7F7FFF7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F2F7F7F2FFF7F7F7F2F7F2
F7F7FFF2F7F7F7F7F7F7FFF7F7F2F7F7F7F7F7F7FFF7FFF7
F7F7F2FFF7FFFFF7F7F7F7F7F7F7F7F7FFF2F2F7F2F7F7F7
F7F7F7F7F7FFF7F7F7F7F7F7FFF7F7F7F2F7FFFFF7F7F7F7
F7F7F7F7FFF7F2F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFF7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFF7F7F7F2F7F7FF
F7F7F7FFF7F7FFF7F7F7F2F7F7F7F7F7F7F2F7FFF7F7FFFF
F7F7F7F2F7F7F2F7FFF7F7F7F7FFF7F7F7F7F7F7F7F7F7FF
F2F7F7F7F7FFF7F7FFF7F7F2F7F7F7F7F7F7F2FFF7F7F7F7
F7F7F7F7F7F7FFF7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFF7F7F2F7F7F2
F7F7F7F7F7F7F7F7F7F7F7F2FFF7F7F7F2F7F7F7F7F2FFF2
F7F7F7FFF7F7F7FFF7F2F7F7F2F7F7F7F7F7F7F7F7F7F7FF
F7F7F2F7FFF7F7F7F2FFFFF7F7F2FFF7F7F7F7FFF7F7F7FF
F7F7F7FFF7F7FFF7F7FFFFF7F7FFF7F7F7F2F7F7F7F7F7F7
F7F7FFF7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFF7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F2F7F7
F7FFF2F7FFF7F7F7F7FFF7FFF7F7F7F7F7F7F2F7FFF7F7F7
F7F7F7F7F7F7F7F7F7F7F2F7F7F7F7F7F7F2FFF2FFF7F7FF
F7F7F2F7F7F7F7F7F7F7F7F7F7F7F7F2F7F7F7F7F7F7F7F7
F7F2FFF7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFF7F7F7
F7F7F7F7F7F7F7F7F7F7F2F7F7F7F7F7F7F7F7F7F7F2F2F7
F7F7F7F2FFFFF7F7FFF2F7F7F7F7F7FFF7F2F2F7F7FFF2F7
FFF7FFF7F7FFF7FFF7F7F7F7F7FFF7F7F7F7F7F2F7FFF7F7
F7FFF7F7F7FFF7FFF7F7FFF2F7F7F7F7F7FFF7F7FFF7F7F7
F7F7F7F7F7F7F2F2
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFF7
F7F7F7F7F7F7F7F7F7F7F7FFF7F7F2F7F2F7F7F7F7F7F7FF
F7F7F7F7F7F7F7F2FFF7F7F7F7F7F7F7F7F7F7F7F2F7FFF7
FFF7F7F7F2FFF2FFF7F7F7F2F7F7F7F7F7F7F7F7FFF2F2F7
F7F7F2F7F7F7F7FFF7F7F7F7F7F7F7FFF7F7F7F7F7F7F7F7
F7F7F7F7F2F7FFF7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F2
F7F7F7F7F7F7F7F7F2FFF7F7F2F7F7F2F2F7F7F7FFFFF7F7
F7F2F7F7F7F7F2F7F7FFF7F2FFF7F7F7F7F7FFF7FFF7F2FF
F7F2F7F2F7F7FFF7F7F2F7F7FFF2FFF7F2F7F2FFF7FFF7F7
F7F2F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F2F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7FFF7FFF7F2FFFFF7F2FFF7F7
F7F7F7F7F7F7FFFFF7F7F7F7FFF7F7F7F7F7F7FFF7F7F7F7
F7FFFFFFFFF7F7F7F7F2F7FFF7F7F7FFFFFFFFF7F7F7F7F7
F7FFFFF7F7F7F7F2F7F7F7F7F7F7FFF7F7F7F7FFF7F7F7F7
FFF7FFF7F7FFF7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFF7FFF7F7F2
F7F2F7F7F7F7F7FFF7F7F7F7F7F7F2F7F2F7F2F7F7F7F7F7
F7F7F2F7F7F7F7F7F7FFF7F7F7F7FFF2F7FFFFF7F7F7F7F7
F7F7F7F7F7F7FFF7F7F7F7F7F2F7F7F7F7F7F7FFF7FFF7F7
F2F7FFF7F7F7FFF7F7F7F7F7F7F7F7F2F7F2F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFF7F7FFF7F7
F7F7F7F7F7F7F7F7F7F7F7F7F2F7F7F7F7F7F7FFF7FFF7F7
F7F7F7F7F7F7F7F7FFFFF7F7F7F2F7F7FFFFF7F7F7F7F7F7
F7F7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7FFF7F2F7F2F7F7FFF7F7FF
F2F7F7F7F7F7F7F7
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[27]:=",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`003@3oool20>o_k`80l?3`103gmoL20>o_k`80l?3`103^k^h20?Ogm`80
k^k^0P3`l?060=GEe@80e]KF0`3Kfm/:0=KFeP80l?3`0P3Zj^X209FEU@80cLg=0P3Fe]H40<g=c@80
a/K6103>c/h20<G5a@80c/k>0P3?cll20<k>cP80clo?1036a/H40<k>cP@0e=CD103?cll60<k>cP<0
clo?0P33`l<60<o?c`h0emOG0P3De=@20=OGe`@0clo?0P3Bd]820=OGe`X0clo?203>c/h40<o?c`80
cLg=103?cll30<k>cP@0clo?0P3>c/h20>?Sh`80l?3`0P3Shn<20:2PX0@0a/K6103>c/h60<K6aP`0
cLg=0P3EeMD20=CDe080d=3@0P3De=@20=gMg@80emOG1P3MgMd20=KFeP80gMgM0`3EeMD20<k>cP80
cLg=1032`/840<K6aP80aLG50P32`/820>7Qh@80h>3P0P2h^;P20=?Cd`80jNWY0P3bl_820?Ogm`80
kno_3`3oool000d0oooo0P3_knl20?3`l0@0moOg0P3_knl20?3`l0@0k^k^0P3gmoL20>k^kP80l?3`
1P3EeMD20=KFeP<0fm_K2P3Fe]H20?3`l080j^[Z0P2EUID20<g=c@80e]KF103=cLd20<K6aP@0c/k>
0P35aLD20<k>cP80clo?0P3>c/h20<o?c`@0a/K6103>c/h40=CDe0@0clo?1P3>c/h30<o?c`80`l?3
1P3?cll>0=OGe`80e=CD0P3GemL40<o?c`80d];B0P3GemL:0<o?c`P0c/k>103?cll20<g=c@@0clo?
0`3>c/h40<o?c`80c/k>0P3Shn<20?3`l080hn?S0P2PX:040<K6aP@0c/k>1P36a/H<0<g=c@80eMGE
0P3De=@20=3@d080e=CD0P3MgMd20=OGe`H0gMgM0P3Fe]H20=gMg@<0eMGE0P3>c/h20<g=c@@0`/;2
1036a/H20<G5a@80`/;20P3QhN420>3Ph080^;Rh0P3Cdm<20>WYj@80l_;b0P3gmoL20>o_k`l0oooo
000=0?ooo`80kno_103bl_820>k^kP80l?3`103gmoL40>o_k`80moOg0P3`l?020>k^kPl0e]KF1P3E
eMD20>[ZjP80/;2`0P3?cll20=GEe@80c/k>103=cLd60<K6aP80b<S80P3>c/h20<o?c`80c/k>0P3?
cll20<k>cP80b<S80P3?cll20=GEe@@0clo?103>c/h20<?3``80b<S81@3>c/h20<K6aP80c/k>0P3?
cll20<k>cP80clo?0P3De=@20=;BdP@0clo?0P3GemL40<o?c`80emOG2P3?cll20=;BdP@0clo?103>
c/h:0<o?c`80cLg=0P36a/H50<o?c`80c/k>0P3?cll20<k>cP80hn?S0P3`l?020;Bd]080WIfM1P3>
c/h:0<K6aP80c/k>1P3?cll20=CDe080clo?0P3EeMD20<o?c`@0eMGE1P3Fe]H20=gMg@D0e]KF0P3=
cLd20<k>cP@0cLg=1036a/H20<g=c@80j>SX0P3YjNT40<G5a@80a/K60P3YjNT20?;blP80kno_0P3`
l?0?0?ooo`003@3oool20>o_k`@0l_;b0P3^k^h20?3`l0@0moOg103_knl20?Ogm`80l?3`0P3^k^h?
0=KFePH0eMGE0P3Zj^X20;2`/080clo?0P3EeMD20<k>cP@0cLg=1P36a/H20<S8b080c/k>0P3?cll2
0<k>cP80clo?0P3>c/h20<S8b080clo?0P3EeMD40<o?c`@0c/k>0P33`l<20<S8b0D0c/k>0P36a/H2
0<k>cP80clo?0P3>c/h20<o?c`80e=CD0P3Bd]840<o?c`80emOG103?cll20=OGe`X0clo?0P3Bd]84
0<o?c`@0c/k>2P3?cll20<g=c@80a/K61@3?cll20<k>cP80clo?0P3>c/h20>?Sh`80l?3`0P2d];@2
09fMW@H0c/k>2P36a/H20<k>cPH0clo?0P3De=@20<o?c`80eMGE0P3?cll40=GEe@H0e]KF0P3MgMd5
0=KFeP80cLg=0P3>c/h40<g=c@@0a/K60P3=cLd20>SXj080jNWY1035aLD20<K6aP80jNWY0P3bl_82
0>o_k`80l?3`3`3oool000d0oooo1P3^k^h20?3`l0H0kno_0P3`l?040>o_k`@0moOg0P3bl_820=KF
ePL0eMGE0P3Bd]840=GEe@80d=3@0P3EeMD20>CTi080j^[Z0P2<S8`20<g=c@80d=3@0P3>c/h20<K6
aP80`L710P36a/H60<k>cP80clo?0P3>c/h20<o?c`80c/k>0P36a/H20<?3``@0e=CD0P3?cll20<k>
cP@0b<S81@35aLD60<71`@80b<S80P3>c/h40<o?c`80e=CD203?cll20<k>cP@0clo?0P3EeMD40=OG
e`80e=CD0P3Bd]820=OGea00clo?0P3>c/h=0<o?c`80c/k>0P3Fe]H20?3`l080hn?S0P2DU9@60<K6
aP80c/k>0P3=cLd40<K6aP80c/k>1036a/H20<o?c`80eMGE0P3De=@20=GEe@80e=CD103EeMD20=KF
eP80fm_K0P3MgMd20=_Kf`80e]KF0`3Cdm<20=3@d080cLg=0P3?cll40<g=c@80dm?C0P3Jf]X20=WI
f@80j>SX0P3IfMT20<G5a@80a/K60P3Ogml20>k^kP80moOg0P3`l?0?0?ooo`003@3oool60>k^kP80
l?3`1P3_knl20?3`l0@0kno_103gmoL20?;blP80e]KF1`3EeMD20=;BdP@0eMGE0P3@d=020=GEe@80
i>CT0P3Zj^X208b<S080cLg=0P3@d=020<k>cP80a/K60P31`L420<K6aPH0c/k>0P3?cll20<k>cP80
clo?0P3>c/h20<K6aP80`l?3103De=@20<o?c`80c/k>1038b<P50<G5a@H0`L710P38b<P20<k>cP@0
clo?0P3De=@80<o?c`80c/k>103?cll20=GEe@@0emOG0P3De=@20=;BdP80emOG403?cll20<k>cPd0
clo?0P3>c/h20=KFeP80l?3`0P3Shn<209BDU0H0a/K60P3>c/h20<g=c@@0a/K60P3>c/h40<K6aP80
clo?0P3EeMD20=CDe080eMGE0P3De=@40=GEe@80e]KF0P3Kfm/20=gMg@80fm_K0P3Fe]H30=?Cd`80
d=3@0P3=cLd20<o?c`@0cLg=0P3Cdm<20=[JfP80fMWI0P3Xj>P20=WIf@80aLG50P36a/H20=oOg`80
k^k^0P3gmoL20?3`l0l0oooo000=0?ooo`80l?3`0P3_knl20?;blP80moOg0P3_knl40?Ogm`80k^k^
103gmoL20?3`l080kno_0P3`l?040>k^kP<0gMgM0P3@d=020=GEe@X0clo?0P3Zj^X20=_Kf`80^KVi
0P3=cLd40<k>cPX0a/K60P3>c/h40<o?c`80c/k>1036a/H20<k>cPH0clo?0P38b<P20<k>cP80aLG5
0`31`L440<G5a@80`L710P30`<020<K6aP@0c/k>103?cll20<k>cP80clo?1P3>c/h20=CDe080gMgM
1P3GemL20=gMg@@0emOG0P3De=@40=OGe`@0clo?1P3@d=020<o?c`D0d=3@2P3?cll20=KFeP80l?3`
0P3Shn<209fMW@X0clo?0P3De=@40<o?c`80d=3@0P3?cll20=CDe080clo?0P3EeMD20=3@d080eMGE
0P3Fe]H20=gMg@@0fm_K0P3Fe]H20=_Kf`D0d=3@0P3>c/h20=GEe@80c/k>0P3YjNT20=[JfP80fMWI
0P3Xj>P20<G5a@80gmoO0P3=cLd20<G5a@H0jNWY0P3`l?0?0?ooo`003@3oool20?3`l080kno_0P3b
l_820?Ogm`80kno_103gmoL20>k^kP@0moOg0P3`l?020>o_k`80l?3`103^k^h30=gMg@80d=3@0P3E
eMD:0<o?c`80j^[Z0P3Kfm/20;Vi^@80cLg=103>c/h:0<K6aP80c/k>103?cll20<k>cP@0a/K60P3>
c/h60<o?c`80b<S80P3>c/h20<G5a@<0`L711035aLD20<71`@80`<300P36a/H40<k>cP@0clo?0P3>
c/h20<o?c`H0c/k>0P3De=@20=gMg@H0emOG0P3MgMd40=OGe`80e=CD103GemL40<o?c`H0d=3@0P3?
cll50=3@d0X0clo?0P3Fe]H20?3`l080hn?S0P2MWId:0<o?c`80e=CD103?cll20=3@d080clo?0P3D
e=@20<o?c`80eMGE0P3@d=020=GEe@80e]KF0P3MgMd40=_Kf`80e]KF0P3Kfm/50=3@d080c/k>0P3E
eMD20<k>cP80jNWY0P3Jf]X20=WIf@80j>SX0P35aLD20=oOg`80cLg=0P35aLD60>WYj@80l?3`3`3o
ool000d0oooo0P3_knl20?;blP80kno_0P3bl_820?Ogm`@0l_;b0P3_knl80?Ogm`80l?3`0P3gmoL2
0>o_k`<0l?3`0P3MgMd20=GEe@80emOG0P3?cll20=CDe080clo?0P3GemL40>[ZjP80^KVi0P3?cll2
0=3@d080dm?C1P36a/H20<k>cP@0a/K6103>c/h20<o?c`@0c/k>0P3?cll20<k>cPH0b<S82`3>c/h2
0<S8b080`L710P35aLD20<K6aP80c/k>1P33`l<20<k>cPX0clo?0P3GemL40<o?c`@0gMgM0P3@d=02
0=OGe`80d];B0P3GemL20=;BdP80clo?103EeMD40=3@d0L0eMGE0P3?cll20=GEe@H0clo?0P3Fe]H2
0?3`l080^;Rh0P2l_;`20<o?c`H0e=CD1P3?cll20=CDe080eMGE0P3De=@20=GEe@80emOG103EeMD2
0=OGe`80gMgM1P3Kfm/70=KFeP80c/k>0P3Kfm/20>k^kP80jNWY103Xj>P20>k^kP80dm?C0P3Ti>@4
0<G5a@80jNWY0P3gmoL20?3`l080k^k^3`3oool000d0oooo0P3_knl20?;blP80kno_0P3bl_820?Og
m`@0l_;b0P3_knl80?Ogm`80l?3`0P3gmoL20>o_k`<0l?3`0P3MgMd20=GEe@80emOG0P3?cll20=CD
e080clo?0P3GemL40>[ZjP80^KVi0P3?cll20=3@d080dm?C1P36a/H20<k>cP@0a/K6103>c/h20<o?
c`@0c/k>0P3?cll20<k>cPH0b<S82`3>c/h20<S8b080`L710P35aLD20<K6aP80c/k>1P33`l<20<k>
cPX0clo?0P3GemL40<o?c`@0gMgM0P3@d=020=OGe`80d];B0P3GemL20=;BdP80clo?103EeMD40=3@
d0L0eMGE0P3?cll20=GEe@H0clo?0P3Fe]H20?3`l080^;Rh0P2l_;`20<o?c`H0e=CD1P3?cll20=CD
e080eMGE0P3De=@20=GEe@80emOG103EeMD20=OGe`80gMgM1P3Kfm/70=KFeP80c/k>0P3Kfm/20>k^
kP80jNWY103Xj>P20>k^kP80dm?C0P3Ti>@40<G5a@80jNWY0P3gmoL20?3`l080k^k^3`3oool000d0
oooo0P3_knl20?;blP80k^k^0P3bl_820>o_k`80l?3`0P3bl_820?Ogm`80k^k^103bl_820>k^kP@0
moOg0P3bl_830?Ogm`80l_;b0P3QhN420=GEe@80emOG1P3EeMD20=KFeP80j^[Z0P3Xj>P20<o?c`@0
eMGE0P3>c/h20<g=c@@0a/K60P3>c/h20<g=c@@0clo?1036a/H20<k>cP80a/K60P31`L440<S8b080
aLG51`3>c/h20<o?c`80c/k>103?cll20<?3``@0`L710P38b<P20<71`@80c/k>0P36a/H20<k>cPX0
clo?0P3Bd]840=OGe`80clo?0P3Fe]H60=GEe@80emOG0P3EeMD20=OGe`80eMGE0P3Fe]H20=GEe@<0
d=3@0P3EeMD60=3@d080clo?0P3De=@40<o?c`80e]KF0P3`l?020<K6aP80_;bl0P3?cll40=GEe@80
e=CD0P3@d=040=CDe0P0emOG0P3EeMD20=OGe`@0e]KF1P3Kfm/20=KFeP<0c/k>0P3;bl/20<G5a@80
f][J0P3Xj>P20?3`l080cLg=0P3Jf]X20<g=c@80e]KF0P3YjNT20<K6aP80f][J1P3bl_820>k^kPl0
oooo000=0?ooo`80kno_0P3bl_820>k^kP80l_;b0P3_knl20?3`l080l_;b0P3gmoL20>k^kP@0l_;b
0P3^k^h40?Ogm`80l_;b0`3gmoL20?;blP80hN7Q0P3EeMD20=OGe`H0eMGE0P3Fe]H20>[ZjP80j>SX
0P3?cll40=GEe@80c/k>0P3=cLd40<K6aP80c/k>0P3=cLd40<o?c`@0a/K60P3>c/h20<K6aP80`L71
1038b<P20<G5a@L0c/k>0P3?cll20<k>cP@0clo?0P33`l<40<71`@80b<S80P31`L420<k>cP80a/K6
0P3>c/h:0<o?c`80d];B103GemL20<o?c`80e]KF1P3EeMD20=OGe`80eMGE0P3GemL20=GEe@80e]KF
0P3EeMD30=3@d080eMGE1P3@d=020<o?c`80e=CD103?cll20=KFeP80l?3`0P36a/H20;bl_080clo?
103EeMD20=CDe080d=3@103De=@80=OGe`80eMGE0P3GemL40=KFePH0fm_K0P3Fe]H30<k>cP80bl_;
0P35aLD20=[JfP80j>SX0P3`l?020<g=c@80f][J0P3=cLd20=KFeP80jNWY0P36a/H20=[JfPH0l_;b
0P3^k^h?0?ooo`003@3oool20>o_k`H0moOg0P3^k^h20?Ogm`80k^k^103bl_820?Ogm`80k^k^103g
moL20>o_k`T0moOg0P3`l?040=_Kf`80gMgM0P3Kfm/40=gMg@80l?3`0P3Kfm/20=3@d0@0e]KF0P3C
dm<20<k>cP80cLg=1036a/H40<G5a@80a/K60P30`<020;Rh^0H0`<300P35aLD20<30`080c/k>0P3?
cll90=CDe080emOG103>c/h20<71`@80b<S80P35aLD20<S8b080`L710P35aLD20<K6aP80`l?3103>
c/h40<o?c`80e=CD2P3?cll20=3@d0@0clo?103EeMD70=3@d0X0clo?0P3=cLd40<o?c`80cLg=0P3K
fm/20?3`l080hn?S0P3=cLd60<o?c`80c/k>0P3De=@20=;BdP@0emOG0P3EeMD20=OGe`80eMGE0P3M
gMd20=KFePH0fm_K0P3>c/h20<g=c@<0^KVi0P2d];@20<K6aP80jNWY0P3Ogml20>k^kP80c/k>0P3C
dm<20=GEe@@0dm?C0P35aLD20>WYj@80l_;b0P3`l?020?Ogm`80kno_3`3oool000d0oooo0P3_knl6
0?Ogm`80k^k^0P3gmoL20>k^kP@0l_;b0P3gmoL20>k^kP@0moOg0P3_knl90?Ogm`80l?3`103Kfm/2
0=gMg@80fm_K103MgMd20?3`l080fm_K0P3@d=040=KFeP80dm?C0P3>c/h20<g=c@@0a/K61035aLD2
0<K6aP80`<300P2h^;P60<30`080aLG50P30`<020<k>cP80clo?2@3De=@20=OGe`@0c/k>0P31`L42
0<S8b080aLG50P38b<P20<71`@80aLG50P36a/H20<?3``@0c/k>103?cll20=CDe0X0clo?0P3@d=04
0<o?c`@0eMGE1`3@d=0:0<o?c`80cLg=103?cll20<g=c@80fm_K0P3`l?020>?Sh`80cLg=1P3?cll2
0<k>cP80e=CD0P3Bd]840=OGe`80eMGE0P3GemL20=GEe@80gMgM0P3Fe]H60=_Kf`80c/k>0P3=cLd3
0;Vi^@80];Bd0P36a/H20>WYj@80gmoO0P3^k^h20<k>cP80dm?C0P3EeMD40=?Cd`80aLG50P3YjNT2
0?;blP80l?3`0P3gmoL20>o_k`l0oooo000=0?ooo`80kno_0P3`l?060?;blP80moOg0P3bl_820?Og
m`@0kno_0P3^k^h40>o_k`80moOg0P3bl_870?Ogm`80l_;b0P3_knl20>CTi0H0hn?S103QhN420?3`
l080fm_K0P2MWId20=KFeP80d=3@0P3?cll80<K6aP80aLG5102h^;P<0<30`080a/K60P3>c/h30<o?
c`H0e=CD0P3GemL40<o?c`80`l?30P31`L440<30`080`L710P36a/H20<71`@@0`<300P31`L460<K6
aP80c/k>1036a/H20<S8b080a/K60P3>c/h20<K6aP80c/k>0P3=cLd20<K6aP80cLg=1@3>c/h>0<K6
aP80c/k>1036a/H20=_Kf`80j^[Z0P3>c/h20<g=c@80c/k>203?cll20=GEe@80emOG103EeMD40=gM
g@H0e]KF0P3=cLd20<K6aP80ZJVY1@2d];@20<g=c@80f][J0P3=cLd20;Rh^080a/K60P3>c/h20<G5
a@80f][J0P3>c/h20<G5a@80j>SX0P3bl_820>k^kP80l?3`0P3_knl?0?ooo`003@3oool20>o_k`80
l?3`1P3bl_820?Ogm`80l_;b0P3gmoL40>o_k`80k^k^103_knl20?Ogm`80l_;b1`3gmoL20?;blP80
kno_0P3Ti>@60>?Sh`@0hN7Q0P3`l?020=_Kf`80WIfM0P3Fe]H20=3@d080clo?2036a/H20<G5a@@0
^;Rh3030`<020<K6aP80c/k>0`3?cll60=CDe080emOG103?cll20<?3``80`L711030`<020<71`@80
a/K60P31`L440<30`080`L711P36a/H20<k>cP@0a/K60P38b<P20<K6aP80c/k>0P36a/H20<k>cP80
cLg=0P36a/H20<g=c@D0c/k>3P36a/H20<k>cP@0a/K60P3Kfm/20>[ZjP80c/k>0P3=cLd20<k>cPP0
clo?0P3EeMD20=OGe`@0eMGE103MgMd60=KFeP80cLg=0P36a/H20:VYZ@D0];Bd0P3=cLd20=[JfP80
cLg=0P2h^;P20<K6aP80c/k>0P35aLD20=[JfP80c/k>0P35aLD20>SXj080l_;b0P3^k^h20?3`l080
kno_3`3oool000d0oooo0P3_knl20?Ogm`80kno_1P3gmoL20>o_k`80l?3`103bl_820?Ogm`80l_;b
0P3_knl20>k^kP80moOg0`3bl_840?Ogm`80kno_0P3gmoL20>o_k`80moOg103bl_840?Ogm`@0l_;b
0P3`l?020<;2`P80cLg=0P3?cll20<g=c@H0a/K60P31`L420<G5a@80_Kfm1035aLD20<S8b0@0c/k>
0P38b<P20<30`080b<S80`3>c/h80=CDe080emOG0P3De=@20<k>cP80`/;20P38b<P20<k>cP80`l?3
1038b<P40<K6aP@0`<301P2h^;P20;:b/PP0^;Rh0P2b/[8C0;Rh^080aLG50P31`L460<G5a@80`L71
0P30`<020<G5a@80^;Rh103De=@20;Fe]@80WIfM0P2h^;P40<K6aPH0clo?0P3EeMD40=KFeP80fm_K
0P3Fe]H20<k>cP80X:2P0P2XZ:P20;Rh^0<0^[Zj102h^;P20<k>cP80cLg=0P36a/H40<G5a@80gmoO
0P3Cdm<20<G5a@80fm_K0P3Xj>P20>o_k`80l_;b103^k^h?0?ooo`003@3oool20>o_k`80moOg0P3_
knl60?Ogm`80kno_0P3`l?040?;blP80moOg0P3bl_820>o_k`80k^k^0P3gmoL30?;blP@0moOg0P3_
knl20?Ogm`80kno_0P3gmoL40?;blP@0moOg103bl_820?3`l080`/;20P3=cLd20<o?c`80cLg=1P36
a/H20<71`@80aLG50P2m_Kd40<G5a@80b<S8103>c/h20<S8b080`<300P38b<P30<k>cPP0e=CD0P3G
emL20=CDe080c/k>0P32`/820<S8b080c/k>0P33`l<40<S8b0@0a/K61030`<060;Rh^080/[:b202h
^;P20;:b/Q<0^;Rh0P35aLD20<71`@H0aLG50P31`L420<30`080aLG50P2h^;P40=CDe080]KFe0P2M
WId20;Rh^0@0a/K61P3?cll20=GEe@@0e]KF0P3Kfm/20=KFeP80c/k>0P2PX:020:RXZ080^;Rh0`2j
^[X40;Rh^080c/k>0P3=cLd20<K6aP@0aLG50P3Ogml20=?Cd`80aLG50P3Kfm/20>SXj080kno_0P3b
l_840>k^kPl0oooo000=0?ooo`80moOg0P3bl_820?Ogm`80l?3`1P3gmoL40?;blP80k^k^0P3`l?04
0>o_k`80l?3`0P3gmoL30>o_k`80k^k^0P3gmoL20>o_k`80moOg0P3bl_820?Ogm`80l_;b0P3_knl2
0?Ogm`@0l_;b0P3`l?020?Ogm`80kno_0P35aLD20:VYZ@80fMWI0P36a/H20;Vi^@@0a/K60P35aLD4
0;fm_@80^;Rh0P30`<020<G5a@@0b<S80P30`<020<G5a@D0c/k>0P3GemL20=CDe080emOG0P3De=@4
0<o?c`P0b<S80P3>c/h20<S8b0H0c/k>0P38b<P20<k>cP@0b<S80P35aLD20<71`@80aLG51P31`L42
0<G5a@@0`L710P38b<P20<G5a@<0b<S81036a/H40<k>cP80`L711P3>c/h20<K6aP80c/k>1036a/H2
0<S8b080d=3@0P3Cdm<20=CDe080a/K60P1VIVH20<71`@80^KVi0P36a/H40<g=c@80c/k>0P2e]KD2
09>CT`@0S8b<0P2JVYX20;Rh^080aLG50`36a/H20;Rh^0@0aLG50P36a/H20=?Cd`80cLg=0P2h^;P2
0=_Kf`80fMWI0P2h^;P20>7Qh@80gmoO0P3`l?020?;blP80moOg0P3_knl?0?ooo`003@3oool20?Og
m`80l_;b0P3gmoL20?3`l0H0moOg103bl_820>k^kP80l?3`103_knl20?3`l080moOg0`3_knl20>k^
kP80moOg0P3_knl20?Ogm`80l_;b0P3gmoL20?;blP80kno_0P3gmoL40?;blP80l?3`0P3gmoL20>o_
k`80aLG50P2YZJT20=WIf@80a/K60P2i^KT40<K6aP80aLG5102m_Kd20;Rh^080`<300P35aLD40<S8
b080`<300P35aLD50<k>cP80emOG0P3De=@20=OGe`80e=CD103?cll80<S8b080c/k>0P38b<P60<k>
cP80b<S80P3>c/h40<S8b080aLG50P31`L420<G5a@H0`L710P35aLD40<71`@80b<S80P35aLD30<S8
b0@0a/K6103>c/h20<71`@H0c/k>0P36a/H20<k>cP@0a/K60P38b<P20=3@d080dm?C0P3De=@20<K6
aP80IVIV0P31`L420;Vi^@80a/K6103=cLd20<k>cP80]KFe0P2CTi<408b<S080VYZJ0P2h^;P20<G5
a@<0a/K60P2h^;P40<G5a@80a/K60P3Cdm<20<g=c@80^;Rh0P3Kfm/20=WIf@80^;Rh0P3QhN420=oO
g`80l?3`0P3bl_820?Ogm`80kno_3`3oool000d0oooo0P3^k^h20>o_k`80moOg0P3_knl20?;blP80
k^k^0P3_knl40?;blP80moOg0P3^k^h20?;blP@0moOg1`3bl_820?Ogm`80l_;b0P3gmoL20?;blP80
moOg0P3_knl40?;blP80kno_0P3gmoL20>o_k`@0l_;b0P35aLD20:RXZ080^;Rh0P2d];@20;Vi^@P0
aLG50P36a/H20;fm_@80`<300P35aLD40<S8b080`<300P35aLD30<k>cP80clo?0P3>c/h20<o?c`P0
e=CD0P3>c/h40<S8b0h0c/k>0P38b<P20<?3``P0c/k>0P36a/H20<G5a@@0b<S8103>c/h70<S8b080
a/K62P3>c/h20<S8b080c/k>0P38b<P40<k>cP80clo?0P3>c/h20<K6aP80clo?0P3>c/h20=?Cd`80
d=3@0P3Kfm/20;Fe]@@0WIfM0P2`/;0209JFUP80S8b<0P2JVYX208b<S080Ti>C102XZ:P20<G5a@<0
^;Rh0P2d];@20>SXj0@0aLG50P3;bl/20;6a/@80e]KF0P3QhN420<G5a@80gmoO0P3>c/h20>k^kP80
jNWY103^k^h20?Ogm`l0oooo000=0?ooo`80k^k^0P3_knl20?Ogm`80kno_0P3bl_820>k^kP80kno_
103bl_820?Ogm`80k^k^0P3bl_840?Ogm`L0l_;b0P3gmoL20?;blP80moOg0P3bl_820?Ogm`80kno_
103bl_820>o_k`80moOg0P3_knl40?;blP80aLG50P2XZ:P20;Rh^080];Bd0P2i^KT80<G5a@80a/K6
0P2m_Kd20<30`080aLG51038b<P20<30`080aLG50`3>c/h20<o?c`80c/k>0P3?cll80=CDe080c/k>
1038b<P>0<k>cP80b<S80P33`l<80<k>cP80a/K60P35aLD40<S8b0@0c/k>1`38b<P20<K6aPX0c/k>
0P38b<P20<k>cP80b<S8103>c/h20<o?c`80c/k>0P36a/H20<o?c`80c/k>0P3Cdm<20=3@d080fm_K
0P2e]KD409fMW@80/;2`0P2FUYH208b<S080VYZJ0P2<S8`209>CT`@0Z:RX0P35aLD30;Rh^080];Bd
0P3Xj>P40<G5a@80bl_;0P2a/K420=KFeP80hN7Q0P35aLD20=oOg`80c/k>0P3^k^h20>WYj@@0k^k^
0P3gmoL?0?ooo`003@3oool20?Ogm`80kno_0P3`l?020?Ogm`80kno_103gmoL20>k^kP@0l?3`0P3g
moL20?;blP80moOg0P3_knl20?Ogm`<0kno_103bl_820?Ogm`80kno_203gmoL40>o_k`@0k^k^0P3b
l_820>k^kP80c/k>0P3=cLd20:2PX0@0];Bd0P2PX:020<G5a@80a/K60P31`L420<G5a@80^KVi1035
aLD20<30`080b<S81035aLD70<k>cP@0clo?0P3De=@20<k>cP80e=CD103>c/h40<S8b100c/k>0P33
`l<40<S8b0H0c/k>0P35aLD20<S8b080a/K60P33`l<20<S8b0D0c/k>0P33`l<80<k>cP@0b<S80P3>
c/h20<K6aP80c/k>0P35aLD80<k>cPH0a/K60P3Cdm<40=CDe080`/;20P1cLg<207UiN@80Ti>C0P2<
S8`209>CT`P0X:2P0`2d];@20;fm_@80gmoO0P2XZ:P20;Ng]`80cLg=0P2a/K420<k>cP80fMWI0P35
aLD20>k^kP80j>SX103^k^h40>o_k`80moOg3`3oool000d0oooo0P3gmoL20>o_k`80l?3`0P3gmoL2
0>o_k`@0moOg0P3^k^h40?3`l080moOg0P3bl_820?Ogm`80kno_0P3gmoL30>o_k`@0l_;b0P3gmoL2
0>o_k`P0moOg103_knl40>k^kP80l_;b0P3^k^h20<k>cP80cLg=0P2PX:040;Bd]080X:2P0P35aLD2
0<K6aP80`L710P35aLD20;Vi^@@0aLG50P30`<020<S8b0@0aLG51`3>c/h40<o?c`80e=CD0P3>c/h2
0=CDe0@0c/k>1038b<P@0<k>cP80`l?31038b<P60<k>cP80aLG50P38b<P20<K6aP80`l?30P38b<P5
0<k>cP80`l?3203>c/h40<S8b080c/k>0P36a/H20<k>cP80aLG5203>c/h60<K6aP80dm?C103De=@2
0<;2`P80Lg=c0P1iNGT209>CT`80S8b<0P2CTi<80:2PX0<0];Bd0P2m_Kd20=oOg`80Z:RX0P2g]kL2
0<g=c@80/K6a0P3>c/h20=WIf@80aLG50P3^k^h20>SXj0@0k^k^103_knl20?Ogm`l0oooo000=0?oo
o`80kno_103gmoL40>o_k`80moOg0P3`l?060?Ogm`80kno_103gmoL20?;blP80l?3`2@3gmoL20?3`
l080l_;b103gmoL20?;blP@0kno_0P3bl_860>o_k`80e=CD0P3>c/h20;Fe]@80X:2P0P2d];@208^;
R`80NGUi0P2i^KT20<G5a@@0`L710P35aLD20<71`@80aLG50P32`/820<30`080aLG52`3>c/h20=CD
e180c/k>0P3?cll80<k>cPH0b<S80P3>c/h40<S8b080c/k>0P35aLD20<?3``H0b<S80`35aLD20<K6
aP80c/k>0P3?cll40<k>cP80`l?3103>c/h60<S8b0@0c/k>1P36a/H20<G5a@80^;Rh0P2`/;020:VY
Z@80S8b<0P1lO7`208b<S080Rh^;0P28R8P208^;R`80X:2P0P2JVYX40:2PX0D0]kNg0P2h^;P20<g=
c@80/K6a0P2g]kL20<G5a@80]kNg0P3IfMT20<g=c@80dm?C0P3Xj>P20>k^kP80l_;b0P3Xj>P40?Og
m`80l_;b3`3oool000d0oooo0P3_knl40?Ogm`@0kno_0P3gmoL20?3`l0H0moOg0P3_knl40?Ogm`80
l_;b0P3`l?090?Ogm`80l?3`0P3bl_840?Ogm`80l_;b103_knl20?;blPH0kno_0P3De=@20<k>cP80
]KFe0P2PX:020;Bd]080Rh^;0P1iNGT20;Vi^@80aLG51031`L420<G5a@80`L710P35aLD20<;2`P80
`<300P35aLD;0<k>cP80e=CD4P3>c/h20<o?c`P0c/k>1P38b<P20<k>cP@0b<S80P3>c/h20<G5a@80
`l?31P38b<P30<G5a@80a/K60P3>c/h20<o?c`@0c/k>0P33`l<40<k>cPH0b<S8103>c/h60<K6aP80
aLG50P2h^;P20;2`/080ZJVY0P2<S8`207alO080S8b<0P2;Rh/208R8R080Rh^;0P2PX:0209ZJVP@0
X:2P1@2g]kL20;Rh^080cLg=0P2a/K420;Ng]`80aLG50P2g]kL20=WIf@80cLg=0P3Cdm<20>SXj080
k^k^0P3bl_820>SXj0@0moOg0P3bl_8?0?ooo`003@3oool20?Ogm`80l_;b0P3_knl20?;blP80l?3`
0P3gmoL20>o_k`80moOg0P3^k^h20?Ogm`80kno_0P3gmoL20?3`l080moOg0P3_knl70?Ogm`80kno_
0P3bl_840?Ogm`80kno_0P3gmoL20?3`l080k^k^0P3_knl20?Ogm`80l?3`0P3_knl20>7Qh@80j>SX
0P3IfMT209ZJVP80X:2P0P2;Rh/207]kN`80HF5Q0P31`L420;Vi^@80aLG50P2h^;P20;Vi^@80`L71
1P35aLD;0<k>cP80clo?2P3>c/h80<S8b080c/k>0P38b<P60<k>cPX0b<S81P35aLD80<S8b0<0aLG5
1038b<P20<k>cP80aLG51038b<P40<k>cP80b<S80P35aLD60<S8b080`<300P35aLD40;Rh^080ZJVY
0P2PX:0208:2PP80O7al0P2<S8`409ZJVP80WYjN0P2CTi<208^;R`@0X:2P0P2`/;020;Rh^0<0]kNg
0P35aLD20;Rh^080Z:RX102g]kL60<g=c@80fMWI0P3bl_820>k^kP@0l?3`103bl_820>k^kPl0oooo
000=0?ooo`80moOg0P3bl_820>o_k`80l_;b0P3`l?020?Ogm`80kno_0P3gmoL20>k^kP80moOg0P3_
knl20?Ogm`80l?3`0P3gmoL20>o_k`L0moOg0P3_knl20?;blP@0moOg0P3_knl20?Ogm`80l?3`0P3^
k^h20>o_k`80moOg0P3`l?020>o_k`80hN7Q0P3Xj>P20=WIf@80VYZJ0P2PX:0208^;R`80Ng]k0P1Q
HF420<71`@80^KVi0P35aLD20;Rh^080^KVi0P31`L460<G5a@/0c/k>0P3?cll:0<k>cPP0b<S80P3>
c/h20<S8b0H0c/k>2P38b<P60<G5a@P0b<S80`35aLD40<S8b080c/k>0P35aLD40<S8b0@0c/k>0P38
b<P20<G5a@H0b<S80P30`<020<G5a@@0^;Rh0P2YZJT20:2PX080PX:20P1lO7`208b<S0@0VYZJ0P2N
WYh209>CT`80Rh^;102PX:020;2`/080^;Rh0`2g]kL20<G5a@80^;Rh0P2XZ:P40;Ng]`H0cLg=0P3I
fMT20?;blP80k^k^103`l?040?;blP80k^k^3`3oool000d0oooo0P3_knl20?;blP80moOg0P3bl_82
0>k^kPH0moOg0P3`l?020?Ogm`80l_;b0P3_knl20?Ogm`80kno_1@3gmoL20?3`l080kno_0P3bl_82
0>o_k`80moOg0P3^k^h20?Ogm`80l_;b0P3`l?020?Ogm`@0l_;b0P3^k^h20?3`l080f][J0P3`l?02
0<g=c@80VYZJ0P2<S8`208^;R`80MWIf0P1QHF4204U9B@80/[:b102h^;P20<G5a@80`L710P35aLD2
0<30`080aLG50`36a/H80<k>cP80b<S83P3>c/h20<S8b080c/k>1P38b<P80<k>cP@0`/;22038b<P2
0<?3``80b<S80P35aLD20<;2`PD0aLG50P33`l<20<k>cP80b<S80P3>c/h20<S8b080aLG5103>c/h4
0<S8b080aLG51030`<020;Rh^080]kNg102XZ:P208b<S080NGUi0P2CTi<209ZJVP80S8b<0P2JVYX2
0:VYZ@80VYZJ0P2CTi<209ZJVP80/;2`0P2PX:020;Bd]0<0Z:RX0P2d];@20;6a/@H0aLG50P3QhN42
0;Rh^080c/k>103^k^h20?;blP80j^[Z0P3_knl20>k^kP80moOg0P3bl_8?0?ooo`003@3oool20>o_
k`80l_;b0P3gmoL20?;blP80k^k^1P3gmoL20?3`l080moOg0P3bl_820>o_k`80moOg0P3_knl50?Og
m`80l?3`0P3_knl20?;blP80kno_0P3gmoL20>k^kP80moOg0P3bl_820?3`l080moOg103bl_820>k^
kP80l?3`0P3Jf]X20?3`l080cLg=0P2JVYX208b<S080Rh^;0P1fMWH2065QH@80BDU90P2b/[840;Rh
^080aLG50P31`L420<G5a@80`<300P35aLD30<K6aPP0c/k>0P38b<P>0<k>cP80b<S80P3>c/h60<S8
b0P0c/k>1032`/880<S8b080`l?30P38b<P20<G5a@80`/;21@35aLD20<?3``80c/k>0P38b<P20<k>
cP80b<S80P35aLD40<k>cP@0b<S80P35aLD40<30`080^;Rh0P2g]kL40:RXZ080S8b<0P1iNGT209>C
T`80VYZJ0P2<S8`209ZJVP80ZJVY0P2JVYX209>CT`80VYZJ0P2`/;020:2PX080];Bd0`2XZ:P20;Bd
]080/K6a1P35aLD20>7Qh@80^;Rh0P3>c/h40>k^kP80l_;b0P3Zj^X20>o_k`80k^k^0P3gmoL20?;b
lPl0oooo000=0?ooo`80l?3`103_knl20?3`l080kno_0P3gmoL20>k^kP80l?3`0P3^k^h60?Ogm`80
l?3`0P3gmoL50?3`l080moOg0P3_knl20?Ogm`80l_;b0P3_knl20?Ogm`80kno_0P3`l?020?Ogm`80
l?3`0P3gmoL20?;blP80l?3`0P3^k^h20>7Qh@80j>SX0P3>c/h20<;2`P80Rh^;0P2CTi<207]kN`80
HF5Q1019BDT40;Rh^080`<300P2h^;P40<G5a@80`<303@3>c/h40<S8b0@0c/k>2038b<P20<;2`P80
aLG50P38b<P60<k>cPH0b<S80P35aLD20<;2`P80aLG50P30`<060<S8b080`/;20P35aLD30;Zj^P@0
aLG53038b<P20<G5a@@0]kNg0P2a/K480:RXZ080Ti>C0P1_Kfl2065QH@80S8b<0P2XZ:P20:2PX080
NWYj0P2JVYX20:2PX080];Bd102`/;0409ZJVP80X:2P0`2XZ:P20;Rh^080/K6a1035aLD20>SXj080
aLG50P3=cLd20=_Kf`80jNWY0P3Xj>P20>WYj@@0l?3`0P3_knl20?Ogm`80l_;b3`3oool000d0oooo
0P3`l?040>o_k`80l?3`0P3_knl20?Ogm`80k^k^0P3`l?020>k^kPH0moOg0P3`l?020?Ogm`D0l?3`
0P3gmoL20>o_k`80moOg0P3bl_820>o_k`80moOg0P3_knl20?3`l080moOg0P3`l?020?Ogm`80l_;b
0P3`l?020>k^kP80hN7Q0P3Xj>P20<k>cP80`/;20P2;Rh/209>CT`80Ng]k0P1QHF4404U9B@@0^;Rh
0P30`<020;Rh^0@0aLG50P30`<0=0<k>cP@0b<S8103>c/h80<S8b080`/;20P35aLD20<S8b0H0c/k>
1P38b<P20<G5a@80`/;20P35aLD20<30`0H0b<S80P32`/820<G5a@<0^[Zj1035aLD<0<S8b080aLG5
102g]kL20;6a/@P0Z:RX0P2CTi<206m_K`80HF5Q0P2<S8`20:RXZ080X:2P0P1jNWX209ZJVP80X:2P
0P2d];@40;2`/0@0VYZJ0P2PX:030:RXZ080^;Rh0P2a/K440<G5a@80j>SX0P35aLD20<g=c@80fm_K
0P3YjNT20>SXj080jNWY103`l?020>o_k`80moOg0P3bl_8?0?ooo`003@3oool20?3`l0@0kno_0P3`
l?020>o_k`80moOg0P3^k^h20?3`l080k^k^1P3gmoL20?3`l080moOg1@3`l?020?Ogm`80kno_0P3g
moL20?;blP80kno_0P3gmoL20>o_k`80l?3`0P3gmoL20?3`l080moOg0P3bl_820?3`l080k^k^0P3Q
hN420>SXj080c/k>0P32`/8208^;R`80Ti>C0P1kNg/2065QH@@0BDU9102h^;P20<30`080^;Rh1035
aLD20<30`0d0c/k>1038b<P40<k>cPP0b<S80P32`/820<G5a@80b<S81P3>c/h60<S8b080aLG50P32
`/820<G5a@80`<301P38b<P20<;2`P80aLG50`2j^[X40<G5a@`0b<S80P35aLD40;Ng]`80/K6a202X
Z:P209>CT`80Kfm_0P1QHF4208b<S080Z:RX0P2PX:0207YjNP80VYZJ0P2PX:020;Bd]0@0/;2`102J
VYX20:2PX0<0Z:RX0P2h^;P20;6a/@@0aLG50P3Xj>P20<G5a@80cLg=0P3Kfm/20>WYj@80j>SX0P3Y
jNT40?3`l080kno_0P3gmoL20?;blPl0oooo000=0?ooo`80k^k^0P3gmoL20?;blP80kno_0P3gmoL4
0>o_k`80l_;b0P3gmoL40?;blP80moOg0P3bl_820?Ogm`80l_;b1@3gmoL20?;blP80moOg0P3bl_84
0?3`l080moOg0P3bl_820>o_k`80k^k^0P3bl_820?3`l080l_;b0P3^k^h20?3`l0@0gmoO0P2d];@2
09>CT`80S8b<0P1cLg<2065QH@80E5AD0P19BDT203lo?`80^;Rh0P31`L420;Bd]080aLG50P30`<02
0<G5a@<0b<S80P3>c/h80<S8b080c/k>1038b<P20<k>cP@0b<S80P3>c/h40<S8b080`/;20P35aLD4
0<S8b080aLG50P3>c/h20<S8b080`/;20P30`<020<;2`PP0`<300P35aLD40<30`0L0^[Zj0P32`/82
0<S8b080^[Zj0P38b<P20;Ng]`80aLG50P30`<020;Zj^P@0/K6a0P2XZ:P20:2PX080Ti>C0P22PX82
065QH@80KVi^0P1cLg<209>CT`@0X:2P0P2HV9P40:RXZ080/;2`102XZ:P20;2`/080VYZJ0P2PX:05
0;6a/@80]kNg0P35aLD20<K6aP80aLG50P3=cLd20=WIf@80j>SX0P3YjNT20=oOg`80jNWY103bl_82
0>o_k`@0moOg3`3oool000d0oooo0P3^k^h20?Ogm`80l_;b0P3_knl20?Ogm`@0kno_0P3bl_820?Og
m`@0l_;b0P3gmoL20?;blP80moOg0P3bl_850?Ogm`80l_;b0P3gmoL20?;blP@0l?3`0P3gmoL20?;b
lP80kno_0P3^k^h20?;blP80l?3`0P3bl_820>k^kP80l?3`103Ogml20;Bd]080Ti>C0P2<S8`207=c
L`80HF5Q0P1DE5@204U9B@80?clo0P2h^;P20<71`@80];Bd0P35aLD20<30`080aLG50`38b<P20<k>
cPP0b<S80P3>c/h40<S8b080c/k>1038b<P20<k>cP@0b<S80P32`/820<G5a@@0b<S80P35aLD20<k>
cP80b<S80P32`/820<30`080`/;22030`<020<G5a@@0`<301`2j^[X20<;2`P80b<S80P2j^[X20<S8
b080]kNg0P35aLD20<30`080^[Zj102a/K420:RXZ080X:2P0P2CTi<208:2PP80HF5Q0P1^KVh207=c
L`80Ti>C102PX:0209RHV0@0Z:RX0P2`/;040:RXZ080/;2`0P2JVYX20:2PX0D0/K6a0P2g]kL20<G5
a@80a/K60P35aLD20<g=c@80fMWI0P3Xj>P20>WYj@80gmoO0P3YjNT40?;blP80kno_103gmoL?0?oo
o`003@3oool20?3`l080k^k^1P3gmoL20>k^kPH0moOg0P3`l?020>o_k`80moOg0P3`l?020?;blP80
k^k^0`3bl_840>o_k`H0moOg103bl_820?Ogm`@0kno_0P3`l?020?;blP80l?3`0P3YjNT20>SXj080
dm?C0P3QhN4209ZJVP80Ti>C0P2;Rh/206i^KP@0HF5Q0P1DE5@203lo?`809BDU0P2`/;020;Vi^@80
^;Rh1030`<030<K6aP80aLG52038b<P20<k>cP80b<S80P3>c/h80<S8b080aLG51038b<P40<;2`P80
aLG50P32`/840<S8b0@0aLG50P32`/820<30`080`/;20P2j^[X20;Ng]`80^[Zj0P32`/850;Zj^P80
`/;20P2j^[X20<G5a@80`<300P2j^[X20;Ng]`80`<30102h^;P20;Ng]`80/K6a0P2YZJT209^KV`80
PX:20P1iNGT207=cL`80Kfm_0P1jNWX209JFUP80X:2P0P2JVYX209RHV080X:2P0P2XZ:P20:2PX0@0
Ti>C0P2PX:0209ZJVP80/;2`1@2a/K420;2`/080aLG51036a/H20<g=c@@0j>SX0P3QhN420>WYj@80
l_;b0P3`l?0:0?Ogm`l0oooo000=0?ooo`80l?3`0P3^k^h60?Ogm`80k^k^1P3gmoL20?3`l080kno_
0P3gmoL20?3`l080l_;b0P3^k^h30?;blP@0kno_1P3gmoL40?;blP80moOg103_knl20?3`l080l_;b
0P3`l?020>WYj@80j>SX0P3Cdm<20>7Qh@80VYZJ0P2CTi<208^;R`80KVi^101QHF4205ADE080?clo
0P0U9BD20;2`/080^KVi0P2h^;P40<30`0<0a/K60P35aLD80<S8b080c/k>0P38b<P20<k>cPP0b<S8
0P35aLD40<S8b0@0`/;20P35aLD20<;2`P@0b<S81035aLD20<;2`P80`<300P32`/820;Zj^P80]kNg
0P2j^[X20<;2`PD0^[Zj0P32`/820;Zj^P80aLG50P30`<020;Zj^P80]kNg0P30`<040;Rh^080]kNg
0P2a/K420:VYZ@80Vi^K0P22PX8207UiN@80Lg=c0P1_Kfl207YjNP80UYJF0P2PX:0209ZJVP80V9RH
0P2PX:020:RXZ080X:2P102CTi<20:2PX080VYZJ0P2`/;050;6a/@80/;2`0P35aLD40<K6aP80cLg=
103Xj>P20>7Qh@80jNWY0P3bl_820?3`l0X0moOg3`3oool000d0oooo0P3^k^h20?Ogm`80l_;b1P3g
moL20?3`l080l_;b103gmoL20?;blP80kno_0P3^k^h20?;blPT0moOg0P3bl_820>o_k`H0l_;b0P3g
moL60?;blP80kno_0P3`l?020?;blP80jNWY0P3IfMT20=oOg`80X:2P0P2CTi<208b<S080Lg=c101Q
HF4205ADE0@0=cLg0P0U9BD40;Rh^080aLG50P31`L450<G5a@X0b<S8103>c/h>0<S8b0@0aLG50P38
b<P20<;2`P80aLG50P32`/820<?3``P0`<30202j^[X20;Ng]`<0/K6a0P2g]kL20;Zj^P80]kNg0P35
aLD20;6a/@80^;Rh102g]kL20:VYZ@80/[:b0P2XZ:P208b<S080KVi^0P1iNGT2059BDP80NWYj0P22
PX8208b<S080X:2P0P2JVYX209RHV080WYjN0P2HV9P20;2`/0H0Z:RX102`/;020;6a/@80]kNg0`2d
];@40<G5a@@0a/K60P3Fe]H20=_Kf`80hN7Q0P3Xj>P20>k^kP80l?3`0P3gmoL20?;blP80moOg0P3b
l_820>o_k`80moOg3`3oool000d0oooo0P3^k^h20?Ogm`80l_;b1P3gmoL20?3`l080l_;b103gmoL2
0?;blP80kno_0P3^k^h20?;blPT0moOg0P3bl_820>o_k`H0l_;b0P3gmoL60?;blP80kno_0P3`l?02
0?;blP80jNWY0P3IfMT20=oOg`80X:2P0P2CTi<208b<S080Lg=c101QHF4205ADE0@0=cLg0P0U9BD4
0;Rh^080aLG50P31`L450<G5a@X0b<S8103>c/h>0<S8b0@0aLG50P38b<P20<;2`P80aLG50P32`/82
0<?3``P0`<30202j^[X20;Ng]`<0/K6a0P2g]kL20;Zj^P80]kNg0P35aLD20;6a/@80^;Rh102g]kL2
0:VYZ@80/[:b0P2XZ:P208b<S080KVi^0P1iNGT2059BDP80NWYj0P22PX8208b<S080X:2P0P2JVYX2
09RHV080WYjN0P2HV9P20;2`/0H0Z:RX102`/;020;6a/@80]kNg0`2d];@40<G5a@@0a/K60P3Fe]H2
0=_Kf`80hN7Q0P3Xj>P20>k^kP80l?3`0P3gmoL20?;blP80moOg0P3bl_820>o_k`80moOg3`3oool0
00d0oooo103gmoL20>k^kP80moOg0P3bl_860?Ogm`@0l_;b0P3^k^h20?;blP80moOg0P3_knl20>k^
kPD0l_;b103gmoL20?3`l080l_;b0P3gmoL40>o_k`80l_;b0P3gmoL20?;blP80kno_0P3`l?020>k^
kP80j>SX0P3Ogml20=CDe080X:2P0P2CTi<207alO080Lg=c0P1_Kfl2065QH@80BDU90P0g=cL202d]
;@80?clo102h^;P20<30`0D0aLG50P36a/H20<G5a@80c/k>0P38b<P20<k>cPX0b<S80P32`/840<S8
b080aLG50P38b<P20<;2`P80aLG50P32`/840<30`080^[Zj2030`<040;Zj^P80]kNg0P2b/[870;6a
/@80]kNg0P35aLD20;Ng]`80ZJVY0P2XZ:P20:VYZ@@0Zj^[102KVi/208^;R`80S8b<0P1KFe/206i^
KP80Kfm_0P1iNGT206m_K`80S8b<0P2JVYX409>CT`80V9RH102XZ:P20;Bd]080^;Rh0P2XZ:P20;2`
/080aLG50P2d];@20;Ng]`D0aLG50P36a/H20<G5a@80e]KF103Kfm/40?3`l0@0moOg103bl_820?Og
m`80kno_103gmoL?0?ooo`003@3oool40?Ogm`80k^k^0P3gmoL20?;blPH0moOg103bl_820>k^kP80
l_;b0P3gmoL20>o_k`80k^k^1@3bl_840?Ogm`80l?3`0P3bl_820?Ogm`@0kno_0P3bl_820?Ogm`80
l_;b0P3_knl20?3`l080k^k^0P3Xj>P20=oOg`80e=CD0P2PX:0209>CT`80O7al0P1cLg<206m_K`80
HF5Q0P19BDT203Lg=`80;Bd]0P0o?cl40;Rh^080`<301@35aLD20<K6aP80aLG50P3>c/h20<S8b080
c/k>2P38b<P20<;2`P@0b<S80P35aLD20<S8b080`/;20P35aLD20<;2`P@0`<300P2j^[X80<30`0@0
^[Zj0P2g]kL20;:b/PL0/K6a0P2g]kL20<G5a@80]kNg0P2YZJT20:RXZ080ZJVY102[Zj/409^KV`80
Rh^;0P2<S8`205]KF`80KVi^0P1_Kfl207UiN@80Kfm_0P2<S8`209ZJVP@0Ti>C0P2HV9P40:RXZ080
];Bd0P2h^;P20:RXZ080/;2`0P35aLD20;Bd]080]kNg1@35aLD20<K6aP80aLG50P3Fe]H40=_Kf`@0
l?3`103gmoL40?;blP80moOg0P3_knl40?Ogm`l0oooo000=0?ooo`80moOg0P3bl_840?3`l080l_;b
0P3_knl20?Ogm`80l?3`0P3gmoL20?3`l080kno_103gmoL20?;blP80moOg0`3`l?020?Ogm`H0l_;b
0P3gmoL40>o_k`@0moOg0P3bl_820?Ogm`80l?3`0P3bl_820>k^kP80j^[Z0P3IfMT20;Bd]080X:2P
0P2CTi<208:2PP80KVi^0P1kNg/2065QH@80FUYJ100o?cl204m?C`80EEEE0P2i^KT40<G5a@<0c/k>
1035aLD20<k>cP`0b<S80P35aLD20<S8b080aLG50P30`<020<?3``80b<S80P35aLD40<;2`P80aLG5
0P2j^[X20<G5a@80]kNg0P30`<020<G5a@80`<30102j^[X40;:b/P80X:2P0P2XZ:P30;Rh^080aLG5
0P2h^;P209^KV`80X:2P0P2XZ:P20:2PX080Z:RX0P2PX:0208b<S080Rh^;0P1fMWH207=cL`80S8b<
0P1jNWX408b<S080UYJF102PX:0209RHV080VYZJ0P2HV9P20:RXZ080VYZJ0P2PX:040:RXZ080/K6a
102XZ:P90<G5a@80dm?C0P3Kfm/40>SXj080l_;b0P3gmoL20>o_k`80k^k^103gmoL40?;blP80moOg
0P3bl_8?0?ooo`003@3oool20?Ogm`80l_;b103`l?020?;blP80kno_0P3gmoL20?3`l080moOg0P3`
l?020>o_k`@0moOg0P3bl_820?Ogm`<0l?3`0P3gmoL60?;blP80moOg103_knl40?Ogm`80l_;b0P3g
moL20?3`l080l_;b0P3^k^h20>[ZjP80fMWI0P2d];@20:2PX080Ti>C0P22PX8206i^KP80Ng]k0P1Q
HF4205YJFP@0?clo0P1?Cdl205EEE@80^KVi1035aLD30<k>cP@0aLG50P3>c/h<0<S8b080aLG50P38
b<P20<G5a@80`<300P33`l<20<S8b080aLG51032`/820<G5a@80^[Zj0P35aLD20;Ng]`80`<300P35
aLD20<30`0@0^[Zj102b/[820:2PX080Z:RX0`2h^;P20<G5a@80^;Rh0P2KVi/20:2PX080Z:RX0P2P
X:020:RXZ080X:2P0P2<S8`208^;R`80MWIf0P1cLg<208b<S080NWYj102<S8`209JFUP@0X:2P0P2H
V9P209ZJVP80V9RH0P2XZ:P209ZJVP80X:2P102XZ:P20;6a/@@0Z:RX2@35aLD20=?Cd`80fm_K103X
j>P20?;blP80moOg0P3_knl20>k^kP@0moOg103bl_820?Ogm`80l_;b3`3oool000d0oooo103gmoL2
0>o_k`80moOg0P3_knl40?;blP@0moOg0P3`l?080?Ogm`80kno_0`3bl_820?Ogm`80kno_0P3bl_82
0>k^kP80kno_0P3gmoL20>o_k`80l_;b0P3gmoL20?3`l080l_;b0P3`l?020>k^kP80j>SX0P3YjNT2
0=3@d080];Bd102CTi<207alO080PX:20P1iNGT405YJFP80BDU90P1BDU8205ADE080=cLg0P2h^;P2
0<G5a@80a/K60`3>c/h40<G5a@80b<S80P32`/820<G5a@80b<S80P32`/820<G5a@@0b<S80P35aLD2
0<;2`P80aLG51032`/820<S8b0H0`<300P35aLD20;Ng]`80`/;20P2g]kL20;Zj^P80^;Rh0P2g]kL2
0;:b/P80[:b/0P2PX:040:RXZ0D0aLG50P2KVi/20:2PX0@0Z:RX0P2KVi/208R8R080OWin0P1_Kfl2
08^;R`80Ng]k0P1cLg<207UiN@80Rh^;0P2<S8`207alO080Ti>C102PX:0209ZJVP80Ti>C0P22PX82
0;Bd]080X:2P0P2d];@20:2PX080aLG50P2XZ:P20;6a/@T0aLG50P3=cLd20<k>cP80j>SX103YjNT2
0?;blP80moOg0P3^k^h60?Ogm`80kno_1P3gmoL?0?ooo`003@3oool40?Ogm`80kno_0P3gmoL20>o_
k`@0l_;b103gmoL20?3`l0P0moOg0P3_knl30?;blP80moOg0P3_knl20?;blP80k^k^0P3_knl20?Og
m`80kno_0P3bl_820?Ogm`80l?3`0P3bl_820?3`l080k^k^0P3Xj>P20>WYj@80d=3@0P2d];@409>C
T`80O7al0P22PX8207UiN@@0FUYJ0P19BDT2059BDP80E5AD0P0g=cL20;Rh^080aLG50P36a/H30<k>
cP@0aLG50P38b<P20<;2`P80aLG50P38b<P20<;2`P80aLG51038b<P20<G5a@80`/;20P35aLD40<;2
`P80b<S81P30`<020<G5a@80]kNg0P32`/820;Ng]`80^[Zj0P2h^;P20;Ng]`80/[:b0P2/[:`20:2P
X0@0Z:RX1@35aLD209^KV`80X:2P102XZ:P209^KV`80R8R80P1nOWh206m_K`80Rh^;0P1kNg/207=c
L`80NGUi0P2;Rh/208b<S080O7al0P2CTi<40:2PX080VYZJ0P2CTi<208:2PP80];Bd0P2PX:020;Bd
]080X:2P0P35aLD20:RXZ080/K6a2@35aLD20<g=c@80c/k>0P3Xj>P40>WYj@80l_;b0P3gmoL20>k^
kPH0moOg0P3_knl60?Ogm`l0oooo000=0?ooo`80moOg0P3_knl20?Ogm`80l?3`2P3gmoL20?;blPP0
moOg0P3bl_830?3`l0@0moOg103bl_820>k^kP80moOg0P3bl_820?Ogm`@0kno_103gmoL20?3`l0@0
j>SX0P2h^;P20;Bd]080Ti>C0P22PX8207YjNP@0Kfm_0P1DE5@205YJFP@0HF5Q0P19BDT202DU9@80
aLG50P30`<020<K6aP<0aLG50P38b<P20<G5a@80b<S81032`/820<S8b0`0`/;21035aLD20<;2`P80
`<300P35aLD40<30`0H0]kNg0P2j^[X20;Ng]`@0^;Rh0P2/[:`20:RXZ0@0Vi^K0P2g]kL30;Rh^080
Vi^K102DU9@209RHV080U9BD0P28R8P20820P080IVIV0P1jNWX208^;R`H0Ng]k0P1lO7`207YjNP80
O7al0P2CTi<40:2PX0@0UYJF0P2PX:020:VYZ@80X:2P0P2XZ:P40:2PX0@0/;2`0P2a/K450<G5a@80
a/K60P3Kfm/20?3`l080j>SX0P3YjNT20>k^kP@0moOg0P3bl_840?Ogm`80kno_0P3bl_820>o_k`@0
moOg3`3oool000d0oooo0P3gmoL20>o_k`80moOg0P3`l?0:0?Ogm`80l_;b203gmoL20?;blP<0l?3`
103gmoL40?;blP80k^k^0P3gmoL20?;blP80moOg103_knl40?Ogm`80l?3`103Xj>P20;Rh^080];Bd
0P2CTi<208:2PP80NWYj101_Kfl205ADE080FUYJ101QHF4204U9B@809BDU0P35aLD20<30`080a/K6
0`35aLD20<S8b080aLG50P38b<P40<;2`P80b<S83032`/840<G5a@80`/;20P30`<020<G5a@@0`<30
1P2g]kL20;Zj^P80]kNg102h^;P20:b/[080Z:RX102KVi/20;Ng]`<0^;Rh0P2KVi/409BDU080V9RH
0P2DU9@208R8R080P8200P1VIVH207YjNP80Rh^;1P1kNg/207alO080NWYj0P1lO7`209>CT`@0X:2P
102FUYH20:2PX080ZJVY0P2PX:020:RXZ0@0X:2P102`/;020;6a/@D0aLG50P36a/H20=_Kf`80l?3`
0P3Xj>P20>WYj@80k^k^103gmoL20?;blP@0moOg0P3_knl20?;blP80kno_103gmoL?0?ooo`003@3o
ool60?Ogm`80kno_103gmoL20?;blP80moOg0P3bl_820?Ogm`80l_;b203gmoL;0?;blP@0moOg0P3b
l_820?Ogm`80kno_1P3gmoL20>o_k`80j>SX0P3Jf]X20;Bd]080Z:RX0P2FUYH208R8R080O7al0P1j
NWX205YJFP80DU9B0P1QHF4206IVIP80FUYJ0P15ADD203lo?`80a/K60P31`L420<k>cP<0a/K60P30
`<020<S8b0@0aLG50P38b<P20<;2`P80`l?30P35aLD20<;2`P80^[Zj1032`/880;Zj^P80`/;20P2g
]kL20;Zj^P80^;Rh0P2g]kL20;Zj^P80/K6a0P2b/[820;6a/@80ZJVY0P2XZ:P209FEU@80Vi^K0P2P
X:020:RXZ0<0X:2P0P2CTi<209BDU0@0Ti>C0P28R8P206m_K`@0MWIf0P1iNGT209ZJVP80S8b<0P2;
Rh/207]kN`80NGUi0P2FUYH208b<S080Ti>C0P2FUYH209ZJVP80WYjN0P2d];@40:RXZ080WYjN1P2P
X:020:RXZ080aLG50P36a/H20<k>cP<0a/K60P3Kfm/20>7Qh@80j>SX0P3^k^h20>SXj080k^k^0P3`
l?020>k^kP@0moOg0P3bl_8:0?Ogm`l0oooo000=0?ooo`H0moOg0P3_knl40?Ogm`80l_;b0P3gmoL2
0?;blP80moOg0P3bl_880?Ogm`/0l_;b103gmoL20?;blP80moOg0P3_knl60?Ogm`80kno_0P3Xj>P2
0=[JfP80];Bd0P2XZ:P209JFUP80R8R80P1lO7`207YjNP80FUYJ0P1BDU82065QH@80IVIV0P1JFUX2
04E5A@80?clo0P36a/H20<71`@80c/k>0`36a/H20<30`080b<S81035aLD20<S8b080`/;20P33`l<2
0<G5a@80`/;20P2j^[X40<;2`PP0^[Zj0P32`/820;Ng]`80^[Zj0P2h^;P20;Ng]`80^[Zj0P2a/K42
0;:b/P80/K6a0P2YZJT20:RXZ080UIFE0P2KVi/20:2PX080Z:RX0`2PX:0209>CT`80U9BD102CTi<2
08R8R080Kfm_101fMWH207UiN@80VYZJ0P2<S8`208^;R`80Ng]k0P1iNGT209JFUP80S8b<0P2CTi<2
09JFUP80VYZJ0P2NWYh20;Bd]0@0Z:RX0P2NWYh60:2PX080Z:RX0P35aLD20<K6aP80c/k>0`36a/H2
0=_Kf`80hN7Q0P3Xj>P20>k^kP80j>SX0P3^k^h20?3`l080k^k^103gmoL20?;blPX0moOg3`3oool0
00d0oooo0P3gmoL20?;blPH0moOg103bl_840?Ogm`80l_;b203gmoL20?;blP<0moOg103bl_840?Og
m`80l_;b0P3gmoL:0?;blP80l?3`0P3_knl20>SXj080fMWI0P2e]KD20:2PX080Ti>C0P22PX8207Yj
NP80NGUi0P1VIVH2065QH@80NGUi0P1QHF4403lo?`80=cLg0P36a/H20<71`@80aLG50`2h^;P20<G5
a@@0b<S8102j^[X20<;2`P80`<301P2j^[X20;Ng]`@0^[Zj102g]kL20;Zj^P80/[:b0P2j^[X80;:b
/P@0/K6a102XZ:P20:2PX080VYZJ0P2DU9@20:VYZ@80V9RH0`28R8P207inOP80S8b<0P22PX8208R8
R080KVi^0P22PX8207]kN`80NGUi0P1jNWX208b<S080VYZJ0P2CTi<208:2PP80S8b<0P28R8P208b<
S080UYJF0P22PX8209RHV080WYjN1P2d];@40:2PX080];Bd0P2PX:020:RXZ0@0aLG50P3=cLd30=_K
f`80j>SX0P3`l?020>SXj080k^k^0P3Xj>P40?3`l0H0moOg0P3bl_820>o_k`80l_;b0P3_knl20?;b
lP80moOg3`3oool000d0oooo0P3gmoL20?;blPH0moOg103bl_840?Ogm`80l_;b203gmoL20?;blP<0
moOg103bl_840?Ogm`80l_;b0P3gmoL:0?;blP80l?3`0P3_knl20>SXj080fMWI0P2e]KD20:2PX080
Ti>C0P22PX8207YjNP80NGUi0P1VIVH2065QH@80NGUi0P1QHF4403lo?`80=cLg0P36a/H20<71`@80
aLG50`2h^;P20<G5a@@0b<S8102j^[X20<;2`P80`<301P2j^[X20;Ng]`@0^[Zj102g]kL20;Zj^P80
/[:b0P2j^[X80;:b/P@0/K6a102XZ:P20:2PX080VYZJ0P2DU9@20:VYZ@80V9RH0`28R8P207inOP80
S8b<0P22PX8208R8R080KVi^0P22PX8207]kN`80NGUi0P1jNWX208b<S080VYZJ0P2CTi<208:2PP80
S8b<0P28R8P208b<S080UYJF0P22PX8209RHV080WYjN1P2d];@40:2PX080];Bd0P2PX:020:RXZ0@0
aLG50P3=cLd30=_Kf`80j>SX0P3`l?020>SXj080k^k^0P3Xj>P40?3`l0H0moOg0P3bl_820>o_k`80
l_;b0P3_knl20?;blP80moOg3`3oool000d0oooo1P3gmoL20?;blP@0moOg0P3bl_860?Ogm`80l_;b
4`3gmoL20?;blP80moOg103bl_820?Ogm`80l?3`0P3_knl40?Ogm`80j>SX0P36a/H40:RXZ080UYJF
0P22PX8407YjNP80FUYJ0P1_Kfl2065QH@80DU9B0P0g=cL204E5A@80=cLg2`35aLD20<30`080b<S8
0P35aLD20;Zj^P80`/;20P2j^[X20;Ng]`80^[Zj0P2g]kL20;:b/P80]kNg0P2b/[820;Ng]`H0/[:b
0P2h^;P20;Ng]`80/K6a0P2/[:`20:VYZ@80/K6a102YZJT20:RXZ080X:2P0P2CTi<20:2PX080Vi^K
0P28R8P307inOP80PX:2101jNWX206IVIP@0MWIf0P1QHF4206m_K`80O7al1P2JVYX20:2PX0@0S8b<
1022PX8209JFUP80WYjN0P2CTi<20;2`/080];Bd0P2YZJT209jNWP80];Bd0P2h^;P20:RXZ080]kNg
1035aLD20=_Kf`<0hn?S0P3Xj>P20=oOg`80j>SX0P3^k^h60?;blP80moOg0P3bl_860?Ogm`@0l_;b
0P3gmoL20?;blPl0oooo000=0?ooo`H0moOg0P3bl_840?Ogm`80l_;b1P3gmoL20?;blQ<0moOg0P3b
l_820?Ogm`@0l_;b0P3gmoL20?3`l080kno_103gmoL20>SXj080a/K6102XZ:P209JFUP80PX:2101j
NWX205YJFP80Kfm_0P1QHF42059BDP80=cLg0P15ADD203Lg=`/0aLG50P30`<020<S8b080aLG50P2j
^[X20<;2`P80^[Zj0P2g]kL20;Zj^P80]kNg0P2b/[820;Ng]`80/[:b0P2g]kL60;:b/P80^;Rh0P2g
]kL20;6a/@80[:b/0P2YZJT20;6a/@@0ZJVY0P2XZ:P20:2PX080Ti>C0P2PX:0209^KV`80R8R80`1n
OWh208:2PP@0NWYj0P1VIVH407IfMP80HF5Q0P1_Kfl207alO0H0VYZJ0P2PX:0408b<S0@0PX:20P2F
UYH209jNWP80Ti>C0P2`/;020;Bd]080ZJVY0P2NWYh20;Bd]080^;Rh0P2XZ:P20;Ng]`@0aLG50P3K
fm/30>?Sh`80j>SX0P3Ogml20>SXj080k^k^1P3bl_820?Ogm`80l_;b1P3gmoL40?;blP80moOg0P3b
l_8?0?ooo`003@3oool80?Ogm`@0l_;b0P3gmoL20?;blP80kno_203gmoL20?;blP/0moOg0P3bl_84
0?Ogm`80l_;b0P3^k^h20?;blP80k^k^0P3gmoL20?;blP@0l?3`0P2d];@20:RXZ080V9RH0P2CTi<2
06m_K`80MWIf0P1VIVH205mOG`80Kfm_0P1OGel204m?C`80ADE50P1?Cdl203lo?`80a/K60P2i^KT2
0<G5a@<0`<300P35aLD20<30`080^[Zj0P35aLD60;Zj^P80]kNg1P2b/[820:^[Z`80[:b/0P2a/K44
0:b/[080/[:b102a/K420:RXZ080Zj^[202XZ:P409^KV`80Ti>C0P2PX:0209>CT`80PX:20`1jNWX4
07EeM@80KVi^0P1jNWX207IfMP@0IVIV0P1_Kfl207]kN`80Rh^;0P2JVYX209>CT`80VYZJ0P2CTi<2
09JFUP@0PX:20P1lO7`209>CT`80Z:RX0P2YZJT20:RXZ0@0]KFe0P2d];@20:2PX080Z:RX0P2g]kL2
0<G5a@80c/k>0P3QhN430=oOg`80j>SX0P3`l?020>k^kP80j>SX0P3bl_820?Ogm`80l_;b2P3gmoL2
0?;blP@0moOg0P3bl_8?0?ooo`003@3oool80?Ogm`@0l_;b0P3gmoL20?;blP80kno_203gmoL20?;b
lP/0moOg0P3bl_840?Ogm`80l_;b0P3^k^h20?;blP80k^k^0P3gmoL20?;blP@0l?3`0P2d];@20:RX
Z080V9RH0P2CTi<206m_K`80MWIf0P1VIVH205mOG`80Kfm_0P1OGel204m?C`80ADE50P1?Cdl203lo
?`80a/K60P2i^KT20<G5a@<0`<300P35aLD20<30`080^[Zj0P35aLD60;Zj^P80]kNg1P2b/[820:^[
Z`80[:b/0P2a/K440:b/[080/[:b102a/K420:RXZ080Zj^[202XZ:P409^KV`80Ti>C0P2PX:0209>C
T`80PX:20`1jNWX407EeM@80KVi^0P1jNWX207IfMP@0IVIV0P1_Kfl207]kN`80Rh^;0P2JVYX209>C
T`80VYZJ0P2CTi<209JFUP@0PX:20P1lO7`209>CT`80Z:RX0P2YZJT20:RXZ0@0]KFe0P2d];@20:2P
X080Z:RX0P2g]kL20<G5a@80c/k>0P3QhN430=oOg`80j>SX0P3`l?020>k^kP80j>SX0P3bl_820?Og
m`80l_;b2P3gmoL20?;blP@0moOg0P3bl_8?0?ooo`003@3oool20?Ogm`@0l_;b0P3gmoL40?;blPH0
moOg0P3bl_820>o_k`@0moOg0P3bl_850?Ogm`@0l_;b0P3`l?020>o_k`80moOg103bl_840?Ogm`80
l_;b0P3gmoL20>k^kP80l?3`0P3IfMT20;Fe]@80Z:RX0P2CTi<208R8R080NWYj0P22PX82065QH@@0
Kfm_0P1VIVH203/k>`80=cLg0P0o?cl204E5A@80aLG50P2h^;P20<71`@<0^;Rh1030`<060;Zj^P80
/[:b0P2g]kL20;6a/@80[:b/0P2a/K440:b/[080Zj^[1P2PX:040:RXZ080[:b/102XZ:P60:2PX0@0
Vi^K0P2DU9@209JFUP80PX:20P1jNWX207UiN@<0Kfm_0P1eMGD407YjNPH0Kfm_0P1cLg<207]kN`80
O7al0P2;Rh/209ZJVP80/;2`0P2XZ:P20;Ng]`80V9RH101iNGT208:2PP80V9RH0P2CTi<20:RXZ0H0
];Bd1P2PX:020<G5a@80cLg=0P3>c/h20=oOg`<0j>SX0P3QhN420>k^kP80j>SX0P3gmoL20?;blPP0
moOg0P3bl_860?Ogm`80kno_0P3gmoL20?;blPl0oooo000=0?ooo`80moOg103bl_820?Ogm`@0l_;b
1P3gmoL20?;blP80kno_103gmoL20?;blPD0moOg103bl_820?3`l080kno_0P3gmoL40?;blP@0moOg
0P3bl_820?Ogm`80k^k^0P3`l?020=WIf@80]KFe0P2XZ:P209>CT`80R8R80P1jNWX208:2PP80HF5Q
101_Kfl206IVIP80>c/k0P0g=cL203lo?`80ADE50P35aLD20;Rh^080`L710`2h^;P40<30`0H0^[Zj
0P2b/[820;Ng]`80/K6a0P2/[:`20;6a/@@0[:b/0P2[Zj/60:2PX0@0Z:RX0P2/[:`40:RXZ0H0X:2P
102KVi/209BDU080UYJF0P22PX8207YjNP80NGUi0`1_Kfl207EeM@@0NWYj1P1_Kfl207=cL`80Ng]k
0P1lO7`208^;R`80VYZJ0P2`/;020:RXZ080]kNg0P2HV9P407UiN@80PX:20P2HV9P209>CT`80Z:RX
1P2d];@60:2PX080aLG50P3=cLd20<k>cP80gmoO0`3Xj>P20>7Qh@80k^k^0P3Xj>P20?Ogm`80l_;b
203gmoL20?;blPH0moOg0P3_knl20?Ogm`80l_;b3`3oool000d0oooo0P3bl_840?Ogm`@0l_;b0P3`
l?040>o_k`80l_;b1P3gmoL20>o_k`80moOg0P3bl_830?Ogm`80l_;b0P3gmoL20?3`l0X0moOg0P3b
l_820>o_k`80l_;b103`l?020<K6aP80];Bd0P2NWYh209JFUP80PX:20P1_Kfl207IfMP80IVIV0P1i
NGT205YJFP80DU9B100c<c<403lo?`80aLG50P2h^;P20<30`0<0`L710P30`<040;Zj^P80/[:b202a
/K420:^[Z`80ZJVY0P2XZ:P20:^[Z`@0Z:RX202PX:040:RXZ0H0X:2P102DU9@209>CT`80R8R80P2C
Ti<207alO080Kfm_0P1VIVH307YjNP80Kfm_101jNWX404m?C`80FUYJ0P1fMWH608^;R`80Ti>C0P2P
X:020:RXZ080X:2P0P2d];@209JFUP80PX:2102CTi<20:2PX080Ti>C102e]KD80:2PX080aLG50P3=
cLd20>SXj080gmoO1@3Xj>P20>WYj@80kno_0P3gmoL20>k^kP80l?3`103gmoL20?;blPH0moOg0P3b
l_860?Ogm`l0oooo000=0?ooo`80l_;b103gmoL40?;blP80l?3`103_knl20?;blPH0moOg0P3_knl2
0?Ogm`80l_;b0`3gmoL20?;blP80moOg0P3`l?0:0?Ogm`80l_;b0P3_knl20?;blP@0l?3`0P36a/H2
0;Bd]080WYjN0P2FUYH208:2PP80Kfm_0P1fMWH206IVIP80NGUi0P1JFUX2059BDP@0<c<c100o?cl2
0<G5a@80^;Rh0P30`<030<71`@80`<30102j^[X20;:b/PP0/K6a0P2[Zj/20:VYZ@80Z:RX0P2[Zj/4
0:RXZ0P0X:2P102XZ:P60:2PX0@0U9BD0P2CTi<208R8R080Ti>C0P1lO7`206m_K`80IVIV0`1jNWX2
06m_K`@0NWYj101?Cdl205YJFP80MWIf1P2;Rh/209>CT`80X:2P0P2XZ:P20:2PX080];Bd0P2FUYH2
08:2PP@0Ti>C0P2PX:0209>CT`@0]KFe202PX:020<G5a@80cLg=0P3Xj>P20=oOg`D0j>SX0P3YjNT2
0>o_k`80moOg0P3^k^h20?3`l0@0moOg0P3bl_860?Ogm`80l_;b1P3gmoL?0?ooo`003@3oool80?Og
m`80l_;b403gmoL20?3`l080l_;b0`3gmoL20?3`l080moOg0P3bl_820?Ogm`80l_;b0P3gmoL20?;b
lP80l?3`0P3bl_820?Ogm`80k^k^0P3bl_820=oOg`80_Kfm0P2d];@209JFUP80R8R80P1jNWX207If
MP@0IVIV0P1_Kfl205YJFP80BDU90P0o?cl404E5A@80BDU92@2h^;P20;Zj^P80^;Rh0P2b/[820;Rh
^0@0/[:b0P2YZJT40:^[Z`H0X:2P0P2EUID409^KV`80UIFE102PX:0209FEU@H0X:2P0P2DU9@209>C
T`80U9BD0P2CTi<208:2PP80VYZJ0P1jNWX205YJFPD0MWIf0P1_Kfl206IVIP80DU9B0P1?Cdl203Lg
=`80Lg=c0P2;Rh/207IfMP80Rh^;0P1lO7`208b<S080X:2P0P2`/;020:VYZ@80]kNg102FUYH20:2P
X080UYJF0P2PX:0209jNWP80];Bd102PX:0209>CT`80VYZJ0P2g]kL20<g=c@80fm_K103QhN430=oO
g`80k^k^103`l?020?Ogm`@0l_;b1P3gmoL20>o_k`80moOg0P3bl_820?Ogm`80l_;b103gmoL?0?oo
o`003@3oool80?Ogm`80l_;b403gmoL20?3`l080l_;b0`3gmoL20?3`l080moOg0P3bl_820?Ogm`80
l_;b0P3gmoL20?;blP80l?3`0P3bl_820?Ogm`80k^k^0P3bl_820=oOg`80_Kfm0P2d];@209JFUP80
R8R80P1jNWX207IfMP@0IVIV0P1_Kfl205YJFP80BDU90P0o?cl404E5A@80BDU92@2h^;P20;Zj^P80
^;Rh0P2b/[820;Rh^0@0/[:b0P2YZJT40:^[Z`H0X:2P0P2EUID409^KV`80UIFE102PX:0209FEU@H0
X:2P0P2DU9@209>CT`80U9BD0P2CTi<208:2PP80VYZJ0P1jNWX205YJFPD0MWIf0P1_Kfl206IVIP80
DU9B0P1?Cdl203Lg=`80Lg=c0P2;Rh/207IfMP80Rh^;0P1lO7`208b<S080X:2P0P2`/;020:VYZ@80
]kNg102FUYH20:2PX080UYJF0P2PX:0209jNWP80];Bd102PX:0209>CT`80VYZJ0P2g]kL20<g=c@80
fm_K103QhN430=oOg`80k^k^103`l?020?Ogm`@0l_;b1P3gmoL20>o_k`80moOg0P3bl_820?Ogm`80
l_;b103gmoL?0?ooo`003@3oool40?Ogm`80l_;b0P3gmoL40?;blP80kno_103bl_820?Ogm`80l_;b
2`3gmoL20>o_k`80l?3`0P3bl_820>o_k`@0moOg0P3bl_840?Ogm`80kno_0P3bl_820>k^kP80c/k>
0P2e]KD20:FUY@@0R8R80P1fMWH207EeM@80Kfm_101VIVH404E5A@80?clo1P15ADD60;Rh^0<0a/K6
102k^k/20;Jf]P80^k^k102f][H20;Rh^0@0/[:b0P2YZJT209^KV`80Ti>C0P2KVi/208f=S@P0Ti>C
102KVi/609>CT`@0R8R80P1nOWh208:2PP80Ti>C0P1_Kfl205EEE@80Kfm_0`1jNWX205YJFP80Cdm?
0P19BDT205EEE@80HF5Q0P1^KVh408^;R`80PX:20P2;Rh/207UiN@80X:2P0P2XZ:P20;Bd]080X:2P
0P2NWYh209>CT`@0V9RH0P2FUYH40;Bd]080X:2P0P2XZ:P20:2PX0@0];Bd0P3;bl/20?3`l080fm_K
0P3Ogml30>k^kP80jNWY203gmoL20?;blPh0moOg0P3bl_820?Ogm`80l_;b3`3oool000d0oooo103g
moL20?;blP80moOg103bl_820>o_k`@0l_;b0P3gmoL20?;blP/0moOg0P3_knl20?3`l080l_;b0P3_
knl40?Ogm`80l_;b103gmoL20>o_k`80l_;b0P3^k^h20<k>cP80]KFe0P2UYJD408R8R080MWIf0P1e
MGD206m_K`@0IVIV1015ADD203lo?`H0ADE51P2h^;P30<K6aP@0^k^k0P2f][H20;^k^`@0][Jf0P2h
^;P40;:b/P80ZJVY0P2KVi/209>CT`80Vi^K0P2=SHd809>CT`@0Vi^K1P2CTi<408R8R080OWin0P22
PX8209>CT`80Kfm_0P1EEED206m_K`<0NWYj0P1JFUX204m?C`80BDU90P1EEED2065QH@80KVi^102;
Rh/208:2PP80Rh^;0P1iNGT20:2PX080Z:RX0P2d];@20:2PX080WYjN0P2CTi<409RHV080UYJF102d
];@20:2PX080Z:RX0P2PX:040;Bd]080bl_;0P3`l?020=_Kf`80gmoO0`3^k^h20>WYj@P0moOg0P3b
l_8>0?Ogm`80l_;b0P3gmoL20?;blPl0oooo000=0?ooo`80l_;b103gmoL40>k^kP80moOg0P3bl_84
0?Ogm`@0l_;b103gmoL20>o_k`80moOg0`3bl_820?Ogm`80l?3`0P3bl_820?3`l0@0moOg103bl_86
0>o_k`80j>SX0P3;bl/20;Bd]080WYjN0P28R8P208:2PP80NWYj0P1_Kfl208:2PP80GemO0P1VIVH2
02d];@80CDe=1015ADD203lo?`80GEeM0P2h^;P20<g=c@L0clo?103>c/h60<?3``80_;bl102k^k/2
0;Rh^080/[:b0P2YZJT408f=S@80S8b<102=SHd608R8R080Ti>C0P2=SHd208R8R080S8b<0P22PX84
07YjNP80S8b<0P1JFUX205]KF`80Kfm_0`1VIVH2059BDP80?clo0P15ADD207=cL`80DU9B0P1_Kfl2
08b<S080Rh^;0P22PX8207UiN@80PX:20P2JVYX20:VYZ@80]kNg0P2h^;P20;Bd]0@0WYjN0P28R8P2
07alO0@0];Bd0P2NWYh20:2PX0@0];Bd0P35aLD20>k^kPH0j>SX0`3^k^h20?3`l080l_;b0P3gmoL2
0?;blPP0moOg0P3bl_8:0?Ogm`80l_;b0P3_knl?0?ooo`003@3oool20?;blP@0moOg103^k^h20?Og
m`80l_;b103gmoL40?;blP@0moOg0P3_knl20?Ogm`<0l_;b0P3gmoL20?3`l080l_;b0P3`l?040?Og
m`@0l_;b1P3_knl20>SXj080bl_;0P2d];@209jNWP80R8R80P22PX8207YjNP80Kfm_0P22PX8205mO
G`80IVIV0P0];Bd204e=C@@0ADE50P0o?cl205eMG@80^;Rh0P3=cLd70<o?c`@0c/k>1P33`l<20;bl
_0@0^k^k0P2h^;P20;:b/P80ZJVY102=SHd208b<S0@0SHf=1P28R8P209>CT`80SHf=0P28R8P208b<
S080PX:2101jNWX208b<S080FUYJ0P1KFe/206m_K`<0IVIV0P1BDU8203lo?`80ADE50P1cLg<2059B
DP80Kfm_0P2<S8`208^;R`80PX:20P1iNGT208:2PP80VYZJ0P2YZJT20;Ng]`80^;Rh0P2d];@409jN
WP80R8R80P1lO7`40;Bd]080WYjN0P2PX:040;Bd]080aLG50P3^k^h60>SXj0<0k^k^0P3`l?020?;b
lP80moOg0P3bl_880?Ogm`80l_;b2P3gmoL20?;blP80kno_3`3oool000d0oooo0P3gmoL40?;blPH0
moOg0P3bl_8<0?Ogm`80l_;b1@3gmoL20?;blP@0moOg0P3^k^h20?Ogm`80l_;b0P3gmoL20?3`l080
kno_103bl_820=?Cd`80_Kfm0P2XZ:P209RHV080R8R80P20P80206IVIP80Kfm_0P1VIVH206m_K`80
DU9B0P0g=cL204m?C`80CDe=0P15ADD203lo?`80Shn?0P3?cll20=3@d080gMgM1@3Bd]840<o?c`80
d];B103?cll40<?3``80`L710P2k^k/20;Rh^080/[:b0P2/[:`20:2PX080S8b<0P22PX8208R8R0@0
S8b<0P2=SHd207inOP80R8R80P2<S8`208R8R080PX:20P1jNWX206i^KP80PX:20P1VIVH206m_K`80
PX:20`1BDU8204U9B@80?clo0P1CDe<207]kN`80E5AD0P1_Kfl207alO080S8b<0P1kNg/207UiN@80
PX:20P2CTi<209ZJVP80]kNg0P2h^;P20;Bd]080Z:RX0P2NWYh208:2PP80UYJF202XZ:P20<G5a@80
Z:RX0P35aLD20>k^kP80hN7Q0P3IfMT20>[ZjP<0jNWY0P3gmoL20?;blP80moOg0P3_knl20?;blP80
kno_103bl_840?Ogm`80l_;b2P3gmoL?0?ooo`003@3oool20?Ogm`@0l_;b1P3gmoL20?;blP`0moOg
0P3bl_850?Ogm`80l_;b103gmoL20>k^kP80moOg0P3bl_820?Ogm`80l?3`0P3_knl40?;blP80dm?C
0P2m_Kd20:RXZ080V9RH0P28R8P20820P080IVIV0P1_Kfl206IVIP80Kfm_0P1BDU8203Lg=`80Cdm?
0P1=CDd204E5A@80?clo0P2?Shl20<o?c`80d=3@0P3MgMd50=;BdP@0clo?0P3Bd]840<o?c`@0`l?3
0P31`L420;^k^`80^;Rh0P2b/[820:b/[080X:2P0P2<S8`208:2PP80R8R8102<S8`208f=S@80OWin
0P28R8P208b<S080R8R80P22PX8207YjNP80KVi^0P22PX8206IVIP80Kfm_0P22PX83059BDP80BDU9
0P0o?cl205=CD`80Ng]k0P1DE5@206m_K`80O7al0P2<S8`207]kN`80NGUi0P22PX8209>CT`80VYZJ
0P2g]kL20;Rh^080];Bd0P2XZ:P209jNWP80PX:20P2FUYH80:RXZ080aLG50P2XZ:P20<G5a@80k^k^
0P3QhN420=WIf@80j^[Z0`3YjNT20?Ogm`80l_;b0P3gmoL20>o_k`80l_;b0P3_knl40?;blP@0moOg
0P3bl_8:0?Ogm`l0oooo000=0?ooo`80l_;b0P3gmoL20?3`l080moOg0P3bl_820?3`l080moOg0P3_
knl80?Ogm`80l_;b0P3`l?020?Ogm`D0l_;b0P3gmoL40?;blP80moOg0P3bl_840>o_k`80l?3`103b
l_820=?Cd`80];Bd0P2NWYh209JFUP80P820101jNWX206m_K`80IVIV0P1_Kfl203Lg=`80ADE50P1E
EED404E5A@80UIFE0P3@d=020=OGe`80gMgM0P3GemL30=gMg@80d];B0P3MgMd20=;BdP80emOG0P3B
d]820<o?c`80c/k>0P3?cll40<?3``80^k^k0P2j^[X20;:b/P80/K6a0P2XZ:P20:2PX0P0PX:20P2<
S8`208:2PP80R8R80P22PX8207EeM@80MWIf0P1NGUh2059BDP80PX:20P1VIVH209>CT`<0BDU90P0o
?cl202d];@80=cLg0P1iNGT207alO080HF5Q0P1lO7`209ZJVP80NGUi0P2FUYH208:2PP80Ti>C0P2X
Z:P20;Ng]`80aLG50P36a/H20;Fe]@80O7al102FUYH20:2PX080V9RH0P2XZ:P20;Fe]@80];Bd0P2a
/K420>WYj@80hN7Q0P3Fe]H20>SXj080l?3`0`3bl_840?Ogm`80l?3`203gmoL40?;blPP0moOg0P3b
l_840?Ogm`l0oooo000=0?ooo`80l_;b0P3gmoL20?3`l080moOg0P3bl_820?3`l080moOg0P3_knl8
0?Ogm`80l_;b0P3`l?020?Ogm`D0l_;b0P3gmoL40?;blP80moOg0P3bl_840>o_k`80l?3`103bl_82
0=?Cd`80];Bd0P2NWYh209JFUP80P820101jNWX206m_K`80IVIV0P1_Kfl203Lg=`80ADE50P1EEED4
04E5A@80UIFE0P3@d=020=OGe`80gMgM0P3GemL30=gMg@80d];B0P3MgMd20=;BdP80emOG0P3Bd]82
0<o?c`80c/k>0P3?cll40<?3``80^k^k0P2j^[X20;:b/P80/K6a0P2XZ:P20:2PX0P0PX:20P2<S8`2
08:2PP80R8R80P22PX8207EeM@80MWIf0P1NGUh2059BDP80PX:20P1VIVH209>CT`<0BDU90P0o?cl2
02d];@80=cLg0P1iNGT207alO080HF5Q0P1lO7`209ZJVP80NGUi0P2FUYH208:2PP80Ti>C0P2XZ:P2
0;Ng]`80aLG50P36a/H20;Fe]@80O7al102FUYH20:2PX080V9RH0P2XZ:P20;Fe]@80];Bd0P2a/K42
0>WYj@80hN7Q0P3Fe]H20>SXj080l?3`0`3bl_840?Ogm`80l?3`203gmoL40?;blPP0moOg0P3bl_84
0?Ogm`l0oooo000=0?ooo`80moOg0P3bl_8:0?Ogm`80kno_0P3bl_820?3`l0H0moOg0P3`l?020?;b
lP<0moOg203bl_880?Ogm`80kno_0P3YjNT20=WIf@80cLg=0P2UYJD209jNWP80R8R80P1fMWH206IV
IP@0Kfm_0P1VIVH205MGE`80=cLg101EEED204E5A@80c/k>0P3GemL20=CDe080emOG103MgMd30=_K
f`80gMgM0P3Kfm/60=;BdP80emOG0P3?cll60<k>cP80aLG5102h^;P20;Zj^P80/[:b0P2YZJT20:2P
X080OWin101jNWX208:2PP80NWYj0P1nOWh207YjNP80MGEe0P1_Kfl2059BDP80Cdm?0P2CTi<2059B
DP80Vi^K0`1_Kfl204E5A@80De=C0P0];Bd2059BDP80S8b<0P1DE5@207alO080S8b<0P1kNg/609>C
T`80X:2P0P2XZ:P20<G5a@80a/K60P2d];@209RHV080R8R80P2FUYH409jNWP80];Bd0P2e]KD20;Bd
]080aLG50P3Ogml20=[JfP80gmoO103^k^h30?Ogm`80l?3`0P3gmoL20?;blP@0moOg103bl_820?Og
m`@0l_;b303gmoL?0?ooo`003@3oool20?Ogm`80l_;b2P3gmoL20>o_k`80l_;b0P3`l?060?Ogm`80
l?3`0P3bl_830?Ogm`P0l_;b203gmoL20>o_k`80jNWY0P3IfMT20<g=c@80YJFU0P2NWYh208R8R080
MWIf0P1VIVH406m_K`80IVIV0P1GEeL203Lg=`@0EEEE0P15ADD20<k>cP80emOG0P3De=@20=OGe`@0
gMgM0`3Kfm/20=gMg@80fm_K1P3Bd]820=OGe`80clo?1P3>c/h20<G5a@@0^;Rh0P2j^[X20;:b/P80
ZJVY0P2PX:0207inOP@0NWYj0P22PX8207YjNP80OWin0P1jNWX207EeM@80Kfm_0P1BDU8204m?C`80
Ti>C0P1BDU8209^KV`<0Kfm_0P15ADD205=CD`80;Bd]0P1BDU8208b<S080E5AD0P1lO7`208b<S080
Ng]k1P2CTi<20:2PX080Z:RX0P35aLD20<K6aP80];Bd0P2HV9P208R8R080UYJF102NWYh20;Bd]080
]KFe0P2d];@20<G5a@80gmoO0P3Jf]X20=oOg`@0k^k^0`3gmoL20?3`l080moOg0P3bl_840?Ogm`@0
l_;b0P3gmoL40?;blP`0moOg3`3oool000d0oooo203gmoL20>o_k`h0moOg0P3_knl20?;blP80l?3`
1@3gmoL20?;blPX0moOg0P3bl_820>k^kP80jNWY0P3@d=020<;2`P80WIfM0P2FUYH208R8R080NWYj
0P1^KVh206m_K`@0IVIV0P15ADD203lo?`80Cdm?0P15ADD208^;R`80eMGE0P3GemL20<o?c`@0emOG
2@3MgMd20=_Kf`80gMgM103Bd]860<o?c`80a/K60P31`L420<G5a@80`<300P2j^[X20;Rh^080/[:b
0P2YZJT209FEU@80X:2P101eMGD207YjNP80MWIf0P1eMGD206i^KP80GemO0P1HF5P204e=C@80S8b<
0P20P80208R8R0<0PX:20P0o?cl202d];@80Cdm?0P1_Kfl208b<S080Ti>C102<S8`209>CT`80NWYj
0P2HV9P209JFUP80WYjN0P2XZ:P20;Bd]0@0aLG50P2FUYH208:2PP80UYJF0P2<S8`209jNWP80_Kfm
0P35aLD20;Zj^P80]KFe0P3=cLd20>SXj0@0l?3`0P3bl_830?Ogm`80l_;b0P3gmoL20?;blP80moOg
103bl_880?Ogm`80l_;b1P3gmoL20?;blP80moOg3`3oool000d0oooo203gmoL20>o_k`h0moOg0P3_
knl20?;blP80l?3`1@3gmoL20?;blPX0moOg0P3bl_820>k^kP80jNWY0P3@d=020<;2`P80WIfM0P2F
UYH208R8R080NWYj0P1^KVh206m_K`@0IVIV0P15ADD203lo?`80Cdm?0P15ADD208^;R`80eMGE0P3G
emL20<o?c`@0emOG2@3MgMd20=_Kf`80gMgM103Bd]860<o?c`80a/K60P31`L420<G5a@80`<300P2j
^[X20;Rh^080/[:b0P2YZJT209FEU@80X:2P101eMGD207YjNP80MWIf0P1eMGD206i^KP80GemO0P1H
F5P204e=C@80S8b<0P20P80208R8R0<0PX:20P0o?cl202d];@80Cdm?0P1_Kfl208b<S080Ti>C102<
S8`209>CT`80NWYj0P2HV9P209JFUP80WYjN0P2XZ:P20;Bd]0@0aLG50P2FUYH208:2PP80UYJF0P2<
S8`209jNWP80_Kfm0P35aLD20;Zj^P80]KFe0P3=cLd20>SXj0@0l?3`0P3bl_830?Ogm`80l_;b0P3g
moL20?;blP80moOg103bl_880?Ogm`80l_;b1P3gmoL20?;blP80moOg3`3oool000d0oooo0P3_knl2
0?Ogm`80l_;b1P3gmoL20?3`l080moOg103bl_820?Ogm`H0l_;b0P3`l?030?Ogm`@0l_;b0P3`l?04
0?Ogm`80k^k^0P3gmoL20>o_k`80k^k^0P3Ogml20=3@d080];Bd0P2MWId209JFUP80PX:20P1fMWH2
05iNGP80IVIV0P1JFUX206IVIP80<c<c0P15ADD204e=C@80IVIV0P3?cll20=3@d0P0emOG0P3MgMd3
0=;BdP80gMgM103Bd]820=gMg@@0d];B0P3?cll20<k>cP@0clo?0P3>c/h40<71`@80`<30102h^;P2
0;:b/P80ZJVY0P2PX:0209FEU@80Kfm_101eMGD206QXJ080Kfm_0P1GEeL205EEE@80=cLg0P1fMWH2
0:VYZ@80FUYJ0`2PX:0206i^KP80NWYj0P0o?cl207=cL`80Fe]K0P2FUYH207=cL`80Rh^;0P2<S8`2
09JFUP80Shn?0P2NWYh208R8R080];Bd0P2PX:020<K6aP80eMGE0P2FUYH208:2PP80UYJF0P2HV9P2
0:FUY@80Z:RX0P2d];@20;Fe]@80aLG50P3Ogml20>SXj080jNWY0P3`l?020>k^kP<0l_;b0P3gmoL2
0?;blP@0moOg103bl_820?Ogm`@0l_;b0P3gmoL40?;blP80moOg0P3bl_840?Ogm`l0oooo000=0?oo
o`80kno_0P3gmoL20?;blPH0moOg0P3`l?020?Ogm`@0l_;b0P3gmoL60?;blP80l?3`0`3gmoL40?;b
lP80l?3`103gmoL20>k^kP80moOg0P3_knl20>k^kP80gmoO0P3@d=020;Bd]080WIfM0P2FUYH208:2
PP80MWIf0P1NGUh206IVIP80FUYJ0P1VIVH203<c<`80ADE50P1=CDd206IVIP80clo?0P3@d=080=OG
e`80gMgM0`3Bd]820=gMg@@0d];B0P3MgMd40=;BdP80clo?0P3>c/h40<o?c`80c/k>1031`L420<30
`0@0^;Rh0P2b/[820:VYZ@80X:2P0P2EUID206m_K`@0MGEe0P1XJ6P206m_K`80EeMG0P1EEED203Lg
=`80MWIf0P2YZJT205YJFP<0X:2P0P1^KVh207YjNP80?clo0P1cLg<205]KF`80UYJF0P1cLg<208^;
R`80S8b<0P2FUYH208n?S`80WYjN0P28R8P20;Bd]080X:2P0P36a/H20=GEe@80UYJF0P22PX8209JF
UP80V9RH0P2UYJD20:RXZ080];Bd0P2e]KD20<G5a@80gmoO0P3Xj>P20>WYj@80l?3`0P3^k^h30?;b
lP80moOg0P3bl_840?Ogm`@0l_;b0P3gmoL40?;blP80moOg103bl_820?Ogm`80l_;b103gmoL?0?oo
o`003@3oool20?;blP80moOg0P3bl_860?Ogm`@0l_;b203gmoL40?;blP80moOg0`3bl_8<0?Ogm`80
l_;b103YjNT20=?Cd`80d=3@0P2UYJD209RHV080P8200P22PX8206i^KP@0IVIV0P1MGEd204E5A@80
?clo0P1GEeL206=SH`80d=3@0P3?cll20=CDe0H0emOG0P3Bd]820=CDe0/0clo?0P3>c/h40<?3``80
a/K60P3>c/h20<G5a@80b<S81031`L420;Rh^080^[Zj102h^;P20;:b/P80Z:RX0P2PX:0209^KV`80
Kfm_0P1OGel206m_K`80Fe]K0P1JFUX404E5A@80GUiN0P2FUYH208R8R0<0MWIf0P2UYJD205ADE080
R8R80P1VIVH207EeM@80O7al0P2<S8`207UiN@80S8b<0P2FUYH206m_K`@0UYJF102XZ:P20;Bd]080
^;Rh0P35aLD209JFUP80O7al0P2FUYH20:FUY@80WYjN0P2d];@20<G5a@80f][J0P3^k^h20=oOg`80
k^k^0P3`l?020>k^kP<0moOg103bl_820?Ogm`80l_;b103gmoL20?;blP80moOg0P3bl_860?Ogm`80
l_;b1P3gmoL?0?ooo`003@3oool20?;blP80moOg0P3bl_860?Ogm`@0l_;b203gmoL40?;blP80moOg
0`3bl_8<0?Ogm`80l_;b103YjNT20=?Cd`80d=3@0P2UYJD209RHV080P8200P22PX8206i^KP@0IVIV
0P1MGEd204E5A@80?clo0P1GEeL206=SH`80d=3@0P3?cll20=CDe0H0emOG0P3Bd]820=CDe0/0clo?
0P3>c/h40<?3``80a/K60P3>c/h20<G5a@80b<S81031`L420;Rh^080^[Zj102h^;P20;:b/P80Z:RX
0P2PX:0209^KV`80Kfm_0P1OGel206m_K`80Fe]K0P1JFUX404E5A@80GUiN0P2FUYH208R8R0<0MWIf
0P2UYJD205ADE080R8R80P1VIVH207EeM@80O7al0P2<S8`207UiN@80S8b<0P2FUYH206m_K`@0UYJF
102XZ:P20;Bd]080^;Rh0P35aLD209JFUP80O7al0P2FUYH20:FUY@80WYjN0P2d];@20<G5a@80f][J
0P3^k^h20=oOg`80k^k^0P3`l?020>k^kP<0moOg103bl_820?Ogm`80l_;b103gmoL20?;blP80moOg
0P3bl_860?Ogm`80l_;b1P3gmoL?0?ooo`003@3oool40?Ogm`80l_;b1P3gmoL20?;blP80moOg203b
l_840?Ogm`80l_;b0`3gmoL20?;blP80l?3`0P3_knl40?;blP@0moOg0P3YjNT20=[JfP80dm?C0P2j
^[X209fMW@80R8R80P20P80206i^KPH0IVIV0P0k>c/204E5A@@0?clo103@d=020=OGe`80e=CD103?
cll20=;BdP80clo?0P38b<P30<71`@@0^k^k1P2h^;P20;:b/PP0^;Rh1P30`<020<71`@80`<30102h
^;P20;:b/P80[:b/0P2YZJT20:RXZ080Vi^K0P1nOWh206IVIP80GEeM0P1HF5P204e=C@80ADE50P1C
De<206i^KP80X:2P0`2FUYH208>3P`80Z:RX0P2<S8`208R8R080DU9B0P1iNGT209>CT`80Rh^;0P2<
S8`207UiN@@0R8R80P2YZJT209jNWP80Z:RX0P2d];@20<K6aP80c/k>0P2FUYH209jNWP80ZJVY0P2N
WYh209RHV080];Bd0P35aLD20?3`l080gmoO0P3bl_820>k^kP80l?3`0P3^k^h50?Ogm`80l_;b0P3g
moL20>o_k`80l_;b0P3gmoL40?;blPh0moOg0P3bl_8?0?ooo`003@3oool40?Ogm`80l_;b1P3gmoL2
0?;blP80moOg203bl_840?Ogm`80l_;b0`3gmoL20?;blP80l?3`0P3_knl40?;blP@0moOg0P3YjNT2
0=[JfP80dm?C0P2j^[X209fMW@80R8R80P20P80206i^KPH0IVIV0P0k>c/204E5A@@0?clo103@d=02
0=OGe`80e=CD103?cll20=;BdP80clo?0P38b<P30<71`@@0^k^k1P2h^;P20;:b/PP0^;Rh1P30`<02
0<71`@80`<30102h^;P20;:b/P80[:b/0P2YZJT20:RXZ080Vi^K0P1nOWh206IVIP80GEeM0P1HF5P2
04e=C@80ADE50P1CDe<206i^KP80X:2P0`2FUYH208>3P`80Z:RX0P2<S8`208R8R080DU9B0P1iNGT2
09>CT`80Rh^;0P2<S8`207UiN@@0R8R80P2YZJT209jNWP80Z:RX0P2d];@20<K6aP80c/k>0P2FUYH2
09jNWP80ZJVY0P2NWYh209RHV080];Bd0P35aLD20?3`l080gmoO0P3bl_820>k^kP80l?3`0P3^k^h5
0?Ogm`80l_;b0P3gmoL20>o_k`80l_;b0P3gmoL40?;blPh0moOg0P3bl_8?0?ooo`003@3oool20?Og
m`80l_;b1P3gmoL20?;blPP0moOg0P3bl_8;0?Ogm`H0l_;b103gmoL40?;blP80jNWY0P3IfMT20=3@
d080]KFe0P2NWYh408:2PP80MGEe0P1KFe/206IVIP80GEeM0P0o?cl204E5A@80EeMG0P3>c/h40=GE
e@80emOG0P3De=@40<o?c`80c/k>0P36a/H20;^k^`<0^[Zj0P2b/[820:b/[0X0YJFU0P2b/[820:b/
[080/[:b0P2h^;P20;:b/P@0`<300P31`L440;Rh^080/[:b0P2`/;020:VYZ@@0X:2P0P2DU9@206IV
IP80De=C0P1EEED204E5A@80<c<c0P15ADD206a/K080X:2P0`20P80206IVIP80/;2`0P2<S8`20:2P
X080R8R80P1_Kfl207YjNP80VYZJ0P2<S8`208:2PP80UYJF0P28R8P20:RXZ080WYjN0P2d];@20:RX
Z080];Bd0P3=cLd20;Bd]080Z:RX102UYJD20:RXZ080]KFe0P36a/H40>SXj080l?3`0P3^k^h20?;b
lP80moOg0`3bl_840?Ogm`80kno_1P3gmoL20?;blP@0moOg0P3bl_8<0?Ogm`l0oooo000=0?ooo`80
moOg0P3bl_860?Ogm`80l_;b203gmoL20?;blP/0moOg1P3bl_840?Ogm`@0l_;b0P3YjNT20=WIf@80
d=3@0P2e]KD209jNWP@0PX:20P1eMGD205]KF`80IVIV0P1MGEd203lo?`80ADE50P1GEeL20<k>cP@0
eMGE0P3GemL20=CDe0@0clo?0P3>c/h20<K6aP80^k^k0`2j^[X20;:b/P80[:b/2P2UYJD20;:b/P80
[:b/0P2b/[820;Rh^080/[:b1030`<020<71`@@0^;Rh0P2b/[820;2`/080ZJVY102PX:0209BDU080
IVIV0P1CDe<205EEE@80ADE50P0c<c<204E5A@80K6a/0P2PX:030820P080IVIV0P2`/;0208b<S080
X:2P0P28R8P206m_K`80NWYj0P2JVYX208b<S080PX:20P2FUYH208R8R080Z:RX0P2NWYh20;Bd]080
Z:RX0P2d];@20<g=c@80];Bd0P2XZ:P40:FUY@80Z:RX0P2e]KD20<K6aP@0j>SX0P3`l?020>k^kP80
l_;b0P3gmoL30?;blP@0moOg0P3_knl60?Ogm`80l_;b103gmoL20?;blP`0moOg3`3oool000d0oooo
0P3gmoL20?;blP@0moOg0P3bl_8:0?Ogm`80l_;b3@3gmoL20?;blP@0l?3`0P3gmoL20?;blP80k^k^
0P3Jf]X20=?Cd`80dM7A0P2UYJD208R8R080P8200P1_Kfl207EeM@80GUiN0P1GEeL404E5A@80BDU9
0P1EEED40=3@d0P0clo?0P3>c/h20<?3``80TI6A0P26QXH509JFUPX0WIfM2026QXH20:VYZ@@0^;Rh
1P30`<040;Rh^080/[:b102YZJT20:2PX080UIFE0P2CTi<205EEE@80ADE50P0o?cl202d];@80?clo
0P1NGUh20820P0<0ZJVY0P2?Shl209FEU@80];Bd0P2PX:020:RXZ080WYjN0P2<S8`208:2PP80Ti>C
0P2FUYH207UiN@80PX:20P2FUYH20:RXZ080UYJF0P2g]kL20;Fe]@80aLG50P36a/H20:FUY@80];Bd
0P2NWYh20:RXZ080aLG50P3@d=020=[JfP80jNWY0P3^k^h20>WYj@80k^k^0P3`l?030?Ogm`80kno_
0P3bl_820?Ogm`80l_;b1P3gmoL20?;blP@0moOg0P3bl_840?Ogm`80l_;b103gmoL?0?ooo`003@3o
ool20?Ogm`80l_;b103gmoL20?;blPX0moOg0P3bl_8=0?Ogm`80l_;b103`l?020?Ogm`80l_;b0P3^
k^h20=[JfP80dm?C0P3AdM420:FUY@80R8R80P20P80206m_K`80MGEe0P1NGUh205MGE`@0ADE50P19
BDT205EEE@@0d=3@203?cll20<k>cP80`l?30P2ATI4208J6QPD0UYJF2P2MWId808J6QP80ZJVY102h
^;P60<30`0@0^;Rh0P2b/[840:VYZ@80X:2P0P2EUID209>CT`80EEEE0P15ADD203lo?`80;Bd]0P0o
?cl205iNGP80P8200`2YZJT208n?S`80UIFE0P2d];@20:2PX080Z:RX0P2NWYh208b<S080PX:20P2C
Ti<209JFUP80NGUi0P22PX8209JFUP80Z:RX0P2FUYH20;Ng]`80]KFe0P35aLD20<K6aP80YJFU0P2d
];@209jNWP80Z:RX0P35aLD20=3@d080f][J0P3YjNT20>k^kP80jNWY0P3^k^h20?3`l0<0moOg0P3_
knl20?;blP80moOg0P3bl_860?Ogm`80l_;b103gmoL20?;blP@0moOg0P3bl_840?Ogm`l0oooo000=
0?ooo`80moOg0P3bl_820?Ogm`80l_;b0P3gmoL20?;blPP0moOg0P3bl_840?Ogm`80l_;b0P3`l?05
0?Ogm`80l_;b103gmoL20?3`l080moOg0P3YjNT20=oOg`80fMWI0P2e]KD209jNWP80Ph>30P1fMWH2
06m_K`80IVIV0P1EEED205iNGP80CDe=0P15ADD205EEE@80e]KF0P3@d=040<o?c`80c/k>0P3De=@2
0<o?c`80YJFU1P2MWId30=3@d080`l?3102UYJD20;Jf]P80`l?3102MWId209JFUP80UIFE0P2<S8`2
08J6QP80ZJVY102h^;P20<30`080`L711P2h^;P20;2`/080ZJVY0P2PX:0209fMW@80U9BD0P28R8P2
05=CD`@0<c<c0P0];Bd205iNGP80<c<c0`2`/;020;Rh^080Kfm_0P2e]KD208R8R080/K6a0P2d];@2
09JFUP80Ti>C0P2PX:0207=cL`80Ti>C0P28R8P209JFUP80WYjN0P2PX:020:VYZ@80]KFe0P36a/H2
0<k>cP80WIfM0P2?Shl209jNWP80Z:RX0P2d];@40>SXj0@0k^k^0P3Xj>P40?Ogm`<0kno_103bl_82
0?Ogm`80l_;b0P3gmoL40?;blP@0moOg0P3bl_840?Ogm`@0l_;b0P3gmoL20?;blPl0oooo000=0?oo
o`80moOg0P3bl_820?Ogm`80l_;b0P3gmoL20?;blPP0moOg0P3bl_840?Ogm`80l_;b0P3`l?050?Og
m`80l_;b103gmoL20?3`l080moOg0P3YjNT20=oOg`80fMWI0P2e]KD209jNWP80Ph>30P1fMWH206m_
K`80IVIV0P1EEED205iNGP80CDe=0P15ADD205EEE@80e]KF0P3@d=040<o?c`80c/k>0P3De=@20<o?
c`80YJFU1P2MWId30=3@d080`l?3102UYJD20;Jf]P80`l?3102MWId209JFUP80UIFE0P2<S8`208J6
QP80ZJVY102h^;P20<30`080`L711P2h^;P20;2`/080ZJVY0P2PX:0209fMW@80U9BD0P28R8P205=C
D`@0<c<c0P0];Bd205iNGP80<c<c0`2`/;020;Rh^080Kfm_0P2e]KD208R8R080/K6a0P2d];@209JF
UP80Ti>C0P2PX:0207=cL`80Ti>C0P28R8P209JFUP80WYjN0P2PX:020:VYZ@80]KFe0P36a/H20<k>
cP80WIfM0P2?Shl209jNWP80Z:RX0P2d];@40>SXj0@0k^k^0P3Xj>P40?Ogm`<0kno_103bl_820?Og
m`80l_;b0P3gmoL40?;blP@0moOg0P3bl_840?Ogm`@0l_;b0P3gmoL20?;blPl0oooo000=0?ooo`80
l_;b0P3gmoL20?;blP80moOg0P3bl_820?Ogm`80l_;b0P3gmoL40?;blP80moOg3@3bl_820?3`l0@0
moOg0P3_knl20?Ogm`80fm_K0P3@d=020;Bd]080WYjN0P2?Shl208>3P`80GUiN0P1VIVH205]KF`80
IVIV0P0g=cL404E5A@80Rh^;1P3EeMD20<o?c`H0c/k>0P2FUYH409fMW@80UYJF1`2ATI4209fMW@@0
QXJ60P1hN7P407emO@80YJFU102<S8`207QhN080/;2`0P2k^k/80<30`080^;Rh0P2`/;040:VYZ@@0
X:2P0P2CTi<20820P0@0ADE50P0Q8B4203lo?`80IVIV0`2?Shl209jNWP80R8R80P2FUYH20;Bd]080
Ti>C0P2g]kL20=CDe080UYJF0P22PX8409>CT`80NWYj0P28R8P20:2PX080WYjN102XZ:P40<K6aP80
YJFU0P2NWYh20:FUY@80WIfM0P2d];@20>SXj080jNWY0P3`l?040>WYj@l0moOg0P3bl_8F0?Ogm`l0
oooo000=0?ooo`80l_;b0P3gmoL20?;blP80moOg0P3bl_820?Ogm`80l_;b0P3gmoL40?;blP80moOg
3@3bl_820?3`l0@0moOg0P3_knl20?Ogm`80fm_K0P3@d=020;Bd]080WYjN0P2?Shl208>3P`80GUiN
0P1VIVH205]KF`80IVIV0P0g=cL404E5A@80Rh^;1P3EeMD20<o?c`H0c/k>0P2FUYH409fMW@80UYJF
1`2ATI4209fMW@@0QXJ60P1hN7P407emO@80YJFU102<S8`207QhN080/;2`0P2k^k/80<30`080^;Rh
0P2`/;040:VYZ@@0X:2P0P2CTi<20820P0@0ADE50P0Q8B4203lo?`80IVIV0`2?Shl209jNWP80R8R8
0P2FUYH20;Bd]080Ti>C0P2g]kL20=CDe080UYJF0P22PX8409>CT`80NWYj0P28R8P20:2PX080WYjN
102XZ:P40<K6aP80YJFU0P2NWYh20:FUY@80WIfM0P2d];@20>SXj080jNWY0P3`l?040>WYj@l0moOg
0P3bl_8F0?Ogm`l0oooo000=0?ooo`P0moOg103bl_820?Ogm`H0l_;b0P3gmoL60?;blPD0moOg103b
l_820?Ogm`H0l_;b0P3Jf]X20<S8b080Z:RX0P2NWYh20820P080KVi^0P1KFe/206IVIP80EeMG0P0o
?cl204m?C`80?clo0P1VIVH40=KFeP80eMGE103?cll20<k>cP80YJFU0P2MWId20820P080GemO0P1T
I6@2071`L0<0P820101`L70207QhN080K6a/0P1OGel204m?C`80FUYJ0P1TI6@204Y:BP80H61P0P1J
FUX205=CD`80J6QX0P2MWId60<30`0H0^;Rh102YZJT20:RXZ080ZJVY0P2DU9@208R8R080IVIV0P0U
9BD2024Q8@80ADE50P1CDe<306=SH`80UYJF0P2`/;0206IVIP80/;2`0P28R8P20:VYZ@80aLG50P3D
e=@40:2PX080Ng]k0P2CTi<208R8R080UYJF0P2HV9P208R8R080];Bd0P35aLD20<K6aP80`/;20P2X
Z:P20;Bd]080YJFU0P2m_Kd20=oOg`80k^k^0P3Xj>P20>k^kP80l_;b0P3^k^h50?Ogm`80l_;b0P3g
moL20?;blQ00moOg0P3bl_820?Ogm`80l_;b103gmoL?0?ooo`003@3oool80?Ogm`@0l_;b0P3gmoL6
0?;blP80moOg1P3bl_850?Ogm`@0l_;b0P3gmoL60?;blP80f][J0P38b<P20:RXZ080WYjN0P20P802
06i^KP80Fe]K0P1VIVH205MGE`80?clo0P1?Cdl203lo?`80IVIV103Fe]H20=GEe@@0clo?0P3>c/h2
0:FUY@80WIfM0P20P80205mOG`80I6AT0P1`L7030820P0@0L71`0P1hN7P206a/K080GemO0P1?Cdl2
05YJFP80I6AT0P1:BTX2061PH080FUYJ0P1CDe<206QXJ080WIfM1P30`<060;Rh^0@0ZJVY0P2XZ:P2
0:VYZ@80U9BD0P28R8P206IVIP809BDU0P0Q8B4204E5A@80De=C0`1SHf<209JFUP80/;2`0P1VIVH2
0;2`/080R8R80P2YZJT20<G5a@80e=CD102PX:0207]kN`80Ti>C0P28R8P209JFUP80V9RH0P28R8P2
0;Bd]080aLG50P36a/H20<;2`P80Z:RX0P2d];@20:FUY@80_Kfm0P3Ogml20>k^kP80j>SX0P3^k^h2
0?;blP80k^k^1@3gmoL20?;blP80moOg0P3bl_8@0?Ogm`80l_;b0P3gmoL20?;blP@0moOg3`3oool0
00d0oooo1P3bl_840?Ogm`@0l_;b0P3gmoL20?;blP80moOg0P3bl_820?Ogm`80l_;b0P3gmoL;0?;b
lP80l?3`0P3bl_820>WYj@80f][J0P32`/8209fMW@80R8R80P1^KVh205]KF`80IVIV0P1JFUX605EE
E@80De=C103Fe]H20=3@d080eMGE0P3GemL20<o?c`80c/k>0P33`l<20<k>cP80YJFU0P2<S8`208J6
QP80OGem0`26QXH207emO@80QXJ60P2FUYH<07emO@80Z:RX102`/;040;Rh^0@0`<30102j^[X20;Rh
^080^[Zj0P2b/[840:VYZ@80Z:RX0P2PX:0209BDU080Ng]k0P11@D44024Q8@80@D510`1SHf<207]k
N`80ZJVY0P2NWYh207IfMP80Z:RX0P28R8P40<G5a@80eMGE0P20P80409>CT`80R8R8102FUYH208R8
R0@0];Bd0P36a/H20<g=c@80WYjN0P2d];@20:RXZ080fMWI103YjNT40>SXj0T0l_;b203gmoL20?;b
lP@0moOg0P3bl_840?Ogm`80l_;b103gmoL20?;blP@0moOg3`3oool000d0oooo1P3bl_840?Ogm`@0
l_;b0P3gmoL20?;blP80moOg0P3bl_820?Ogm`80l_;b0P3gmoL;0?;blP80l?3`0P3bl_820>WYj@80
f][J0P32`/8209fMW@80R8R80P1^KVh205]KF`80IVIV0P1JFUX605EEE@80De=C103Fe]H20=3@d080
eMGE0P3GemL20<o?c`80c/k>0P33`l<20<k>cP80YJFU0P2<S8`208J6QP80OGem0`26QXH207emO@80
QXJ60P2FUYH<07emO@80Z:RX102`/;040;Rh^0@0`<30102j^[X20;Rh^080^[Zj0P2b/[840:VYZ@80
Z:RX0P2PX:0209BDU080Ng]k0P11@D44024Q8@80@D510`1SHf<207]kN`80ZJVY0P2NWYh207IfMP80
Z:RX0P28R8P40<G5a@80eMGE0P20P80409>CT`80R8R8102FUYH208R8R0@0];Bd0P36a/H20<g=c@80
WYjN0P2d];@20:RXZ080fMWI103YjNT40>SXj0T0l_;b203gmoL20?;blP@0moOg0P3bl_840?Ogm`80
l_;b103gmoL20?;blP@0moOg3`3oool000d0oooo0P3gmoL40?;blP80moOg0P3bl_860?Ogm`80l_;b
0P3gmoL20?;blP/0moOg0P3`l?020?Ogm`80l_;b0P3^k^h20?3`l080j>SX0P3AdM420;Fe]@80Shn?
101fMWH206IVIP80FUYJ0P1GEeL204e=C@80EEEE0P1BDU8205eMG@80eMGE0P3?cll20=GEe@80e=CD
0P3?cll20=CDe080c/k>0P3De=@40=OGe`80gMgM0P3Kfm/20=3@d0<0clo?0P3MgMd20<o?c`80c/k>
0P3GemL20=gMg@80d=3@0P3?cll20<K6aP80`L710P36a/H20<71`@@0`<300P31`L420<30`080`L71
0P30`<020;^k^`@0^;Rh102b/[820:VYZ@80Z:RX102PX:0208R8R080GEeM0P0e=CD201HF5P80Hf=S
0`1CDe<206=SH`80Ng]k0P2FUYH206m_K`80Ti>C0P1jNWX209>CT`@0aLG50P2XZ:P20:2PX080UYJF
1022PX8209JFUP80X:2P0P2XZ:P20:2PX080a/K60P3=cLd40:FUY@80V9RH0P3Ogml40>SXj080jNWY
0P3Xj>P60?Ogm`<0l_;b303gmoL20?;blP80moOg0P3bl_860?Ogm`80l_;b1P3gmoL?0?ooo`003@3o
ool20?Ogm`@0l_;b0P3gmoL20?;blPH0moOg0P3bl_820?Ogm`80l_;b2`3gmoL20?3`l080moOg0P3b
l_820>k^kP80l?3`0P3Xj>P20=7Ad@80]KFe0P2?Shl407IfMP80IVIV0P1JFUX205MGE`80CDe=0P1E
EED2059BDP80GEeM0P3EeMD20<o?c`80eMGE0P3De=@20<o?c`80e=CD0P3>c/h20=CDe0@0emOG0P3M
gMd20=_Kf`80d=3@0`3?cll20=gMg@80clo?0P3>c/h20=OGe`80gMgM0P3@d=020<o?c`80a/K60P31
`L420<K6aP80`L711030`<020<71`@80`<300P31`L420<30`080^k^k102h^;P40;:b/P80ZJVY0P2X
Z:P40:2PX080R8R80P1MGEd203De=@805QHF0P1SHf<305=CD`80Hf=S0P1kNg/209JFUP80Kfm_0P2C
Ti<207YjNP80Ti>C1035aLD20:RXZ080X:2P0P2FUYH408:2PP80UYJF0P2PX:020:RXZ080X:2P0P36
a/H20<g=c@@0YJFU0P2HV9P20=oOg`@0j>SX0P3YjNT20>SXj0H0moOg0`3bl_8<0?Ogm`80l_;b0P3g
moL20?;blPH0moOg0P3bl_860?Ogm`l0oooo000=0?ooo`80l_;b2P3gmoL20?;blPH0moOg0P3bl_82
0?Ogm`@0l_;b1@3gmoL20?;blP80l?3`103bl_820>WYj@80bl_;0P35aLD20:FUY@80P8200P1^KVh4
05eMG@80F5QH0P0o?cl405EEE@80Cdm?0P2m_Kd60=GEe@80d];B0P3GemL20<o?c`80emOG0P3?cll4
0=OGe`80gMgM0P3GemL20=gMg@<0emOG0P3MgMd20<k>cPH0clo?2031`L420<G5a@80`L710P35aLD2
0<k>cP80`L710P30`<020<G5a@80`L71102k^k/20;Rh^0@0/[:b0P2YZJT209fMW@@0X:2P0P28R8P2
06QXJ080;Bd]0P0Y:BT205=CD`<0GEeM0P2;Rh/207]kN`80YJFU0P1_Kfl206IVIP80V9RH0P2FUYH2
0;Rh^080aLG50P3>c/h20;Bd]0@0Ti>C0P2HV9P208:2PP@0R8R80P2PX:020<K6aP80cLg=0P2XZ:P2
0;Fe]@80WYjN0P3Xj>P20>WYj@80gmoO0P3Xj>P20?3`l0H0moOg0`3bl_840?Ogm`H0l_;b503gmoL2
0?;blPl0oooo000=0?ooo`80l_;b2P3gmoL20?;blPH0moOg0P3bl_820?Ogm`@0l_;b1@3gmoL20?;b
lP80l?3`103bl_820>WYj@80bl_;0P35aLD20:FUY@80P8200P1^KVh405eMG@80F5QH0P0o?cl405EE
E@80Cdm?0P2m_Kd60=GEe@80d];B0P3GemL20<o?c`80emOG0P3?cll40=OGe`80gMgM0P3GemL20=gM
g@<0emOG0P3MgMd20<k>cPH0clo?2031`L420<G5a@80`L710P35aLD20<k>cP80`L710P30`<020<G5
a@80`L71102k^k/20;Rh^0@0/[:b0P2YZJT209fMW@@0X:2P0P28R8P206QXJ080;Bd]0P0Y:BT205=C
D`<0GEeM0P2;Rh/207]kN`80YJFU0P1_Kfl206IVIP80V9RH0P2FUYH20;Rh^080aLG50P3>c/h20;Bd
]0@0Ti>C0P2HV9P208:2PP@0R8R80P2PX:020<K6aP80cLg=0P2XZ:P20;Fe]@80WYjN0P3Xj>P20>WY
j@80gmoO0P3Xj>P20?3`l0H0moOg0`3bl_840?Ogm`H0l_;b503gmoL20?;blPl0oooo000=0?ooo`80
l_;b0P3gmoL80?;blP80moOg0P3`l?080?Ogm`80l_;b0P3gmoL20?;blP<0moOg103bl_820?3`l0@0
l_;b0P3AdM420:FUY@80R8R80P1_Kfl207IfMP80EeMG0P1HF5P204E5A@P0EEEE103EeMD20=3@d080
eMGE0P3GemL40=;BdP80emOG0P3EeMD=0=OGe`80eMGE0P3?cll60<k>cP80`L710P35aLD20<S8b080
`L710P36a/H20<71`@80c/k>0P31`L420<k>cP@0`L71102k^k/20<30`080^;Rh0P2b/[820:b/[080
/[:b0P2XZ:P40:2PX080U9BD0P1fMWH204e=C@80@D510P0Q8B4305YJFP80GUiN0P1^KVh206m_K`80
P8200P1_Kfl208R8R080Ph>30P2PX:040<G5a@80X:2P0P2XZ:P209>CT`80UYJF0P22PX8209JFUP80
PX:20P2XZ:P20;Bd]080a/K60P2d];@209jNWP80ZJVY0P3Jf]X40>SXj080fMWI0P3gmoL20?;blP@0
moOg0`3bl_820?Ogm`80l_;b203gmoL20?;blPH0moOg103bl_880?Ogm`l0oooo000=0?ooo`80l_;b
0P3gmoL80?;blP80moOg0P3`l?080?Ogm`80l_;b0P3gmoL20?;blP<0moOg103bl_820?3`l0@0l_;b
0P3AdM420:FUY@80R8R80P1_Kfl207IfMP80EeMG0P1HF5P204E5A@P0EEEE103EeMD20=3@d080eMGE
0P3GemL40=;BdP80emOG0P3EeMD=0=OGe`80eMGE0P3?cll60<k>cP80`L710P35aLD20<S8b080`L71
0P36a/H20<71`@80c/k>0P31`L420<k>cP@0`L71102k^k/20<30`080^;Rh0P2b/[820:b/[080/[:b
0P2XZ:P40:2PX080U9BD0P1fMWH204e=C@80@D510P0Q8B4305YJFP80GUiN0P1^KVh206m_K`80P820
0P1_Kfl208R8R080Ph>30P2PX:040<G5a@80X:2P0P2XZ:P209>CT`80UYJF0P22PX8209JFUP80PX:2
0P2XZ:P20;Bd]080a/K60P2d];@209jNWP80ZJVY0P3Jf]X40>SXj080fMWI0P3gmoL20?;blP@0moOg
0`3bl_820?Ogm`80l_;b203gmoL20?;blPH0moOg103bl_880?Ogm`l0oooo000=0?ooo`80l_;b0P3g
moL80?;blP80moOg0P3`l?080?Ogm`80l_;b0P3gmoL20?;blP<0moOg103bl_820?3`l0@0l_;b0P3A
dM420:FUY@80R8R80P1_Kfl207IfMP80EeMG0P1HF5P204E5A@P0EEEE103EeMD20=3@d080eMGE0P3G
emL40=;BdP80emOG0P3EeMD=0=OGe`80eMGE0P3?cll60<k>cP80`L710P35aLD20<S8b080`L710P36
a/H20<71`@80c/k>0P31`L420<k>cP@0`L71102k^k/20<30`080^;Rh0P2b/[820:b/[080/[:b0P2X
Z:P40:2PX080U9BD0P1fMWH204e=C@80@D510P0Q8B4305YJFP80GUiN0P1^KVh206m_K`80P8200P1_
Kfl208R8R080Ph>30P2PX:040<G5a@80X:2P0P2XZ:P209>CT`80UYJF0P22PX8209JFUP80PX:20P2X
Z:P20;Bd]080a/K60P2d];@209jNWP80ZJVY0P3Jf]X40>SXj080fMWI0P3gmoL20?;blP@0moOg0`3b
l_820?Ogm`80l_;b203gmoL20?;blPH0moOg103bl_880?Ogm`l0oooo000=0?ooo`80moOg0P3bl_82
0?Ogm`@0l_;b1P3gmoL20?;blQ40moOg103bl_820?3`l080dM7A0P38b<P209fMW@80PX:20P1fMWH2
05MGE`80IVIV0P15ADD205EEE@80?clo0P1EEED205MGE`80ADE50P3EeMD40=3@d080eMGE1P3GemL2
0=;BdPP0emOG0P3EeMD50=OGe`@0c/k>0P31`L420<k>cP80`L710P2j^[X20<30`080aLG50P31`L42
0<?3``80b<S80P3>c/h40<?3``80clo?0P3>c/h40<71`@80^k^k0P2j^[X40;:b/P80ZJVY0P2XZ:P2
09fMW@80UIFE0P2DU9@208:2PP80De=C0P0];Bd203<c<`<0De=C0P1/K6`207AdM080Ng]k0P2?Shl2
07IfMP80IVIV0P1^KVh209fMW@80V9RH0P2`/;020<k>cP80];Bd0P2<S8`209RHV080MWIf0P2NWYh2
09JFUP80ZJVY0P2XZ:P20<K6aP80];Bd0P2FUYH20<k>cP80fMWI1P3YjNT20?;blPd0moOg0P3bl_86
0?Ogm`80l_;b0P3gmoL20?;blPh0moOg3`3oool000d0oooo0P3gmoL20?;blP80moOg103bl_860?Og
m`80l_;b4@3gmoL40?;blP80l?3`0P3AdM420<S8b080WIfM0P22PX8207IfMP80EeMG0P1VIVH204E5
A@80EEEE0P0o?cl205EEE@80EeMG0P15ADD20=GEe@@0d=3@0P3EeMD60=OGe`80d];B203GemL20=GE
e@D0emOG103>c/h20<71`@80c/k>0P31`L420;Zj^P80`<300P35aLD20<71`@80`l?30P38b<P20<k>
cP@0`l?30P3?cll20<k>cP@0`L710P2k^k/20;Zj^P@0/[:b0P2YZJT20:RXZ080WIfM0P2EUID209BD
U080PX:20P1CDe<202d];@80<c<c0`1CDe<206a/K080M7Ad0P1kNg/208n?S`80MWIf0P1VIVH206i^
KP80WIfM0P2HV9P20;2`/080c/k>0P2d];@208b<S080V9RH0P1fMWH209jNWP80UYJF0P2YZJT20:RX
Z080a/K60P2d];@209JFUP80c/k>0P3IfMT60>WYj@80l_;b3@3gmoL20?;blPH0moOg0P3bl_820?Og
m`80l_;b3P3gmoL?0?ooo`003@3ooolB0?Ogm`80l_;b203gmoL70?;blP@0moOg0P3YjNT20<_;b`80
[Jf]0P2MWId207IfMP80Kfm_0P1^KVh205=CD`@0EEEE0P1CDe<205EEE@80ADE50P2?Shl20<k>cP@0
d=3@203GemL20=gMg@80emOG0P3EeMD60=OGe`D0clo?0P31`L420;Rh^080/[:b0P2k^k/20;Rh^080
/[:b0P2h^;P20;^k^`80`<300P31`L420<S8b080a/K60P3>c/h40<o?c`@0`l?30P31`L420;^k^`80
^;Rh102b/[840:VYZ@80Z:RX0P2PX:0208f=S@80OWin0P1VIVH20451@@80ADE50`18B4P206=SH`80
GUiN0P1kNg/206i^KP80PX:20P1MGEd206m_K`80GUiN0P2e]KD20<G5a@80Z:RX0P2a/K4209RHV080
WYjN0P23Ph<208R8R080UYJF0P2UYJD20:RXZ080aLG50P2m_Kd209jNWP80gmoO0P36a/H20?;blP80
jNWY3@3gmoL20?;blP`0moOg103bl_840?Ogm`80l_;b203gmoL?0?ooo`003@3ooolB0?Ogm`80l_;b
203gmoL70?;blP@0moOg0P3YjNT20<_;b`80[Jf]0P2MWId207IfMP80Kfm_0P1^KVh205=CD`@0EEEE
0P1CDe<205EEE@80ADE50P2?Shl20<k>cP@0d=3@203GemL20=gMg@80emOG0P3EeMD60=OGe`D0clo?
0P31`L420;Rh^080/[:b0P2k^k/20;Rh^080/[:b0P2h^;P20;^k^`80`<300P31`L420<S8b080a/K6
0P3>c/h40<o?c`@0`l?30P31`L420;^k^`80^;Rh102b/[840:VYZ@80Z:RX0P2PX:0208f=S@80OWin
0P1VIVH20451@@80ADE50`18B4P206=SH`80GUiN0P1kNg/206i^KP80PX:20P1MGEd206m_K`80GUiN
0P2e]KD20<G5a@80Z:RX0P2a/K4209RHV080WYjN0P23Ph<208R8R080UYJF0P2UYJD20:RXZ080aLG5
0P2m_Kd209jNWP80gmoO0P36a/H20?;blP80jNWY3@3gmoL20?;blP`0moOg103bl_840?Ogm`80l_;b
203gmoL?0?ooo`003@3oool20?;blPX0moOg0P3bl_820?Ogm`@0l_;b103gmoL20?;blPL0moOg0P3`
l?020?Ogm`@0l_;b0P35aLD209fMW@80P8200P1^KVh405]KF`80EEEE1015ADD405EEE@80?clo0P3>
c/h40=3@d080d];B303GemL20=CDe0H0emOG0P3?cll30<?3``80_;bl0P30`<020:b/[0@0/[:b0P2Y
ZJT20;2`/0@0^;Rh0P30`<020<71`@80b<S80P33`l<60<k>cP80`l?30P3>c/h20<;2`P80^k^k0P2h
^;P20;:b/P@0ZJVY0P2XZ:P209FEU@80U9BD0P28R8P206QXJ080@D510P0F5QH302l_;`80De=C0P1M
GEd207IfMP80GUiN0P22PX8406m_K`80EEEE0P2`/;0209>CT`80Z:RX0P3De=@209jNWP@0V9RH0P28
R8P209FEU@80Ti>C0P2NWYh20<G5a@@0`/;20P3@d=040=[JfP80e=CD3@3gmoL20?;blQ@0moOg0P3b
l_880?Ogm`l0oooo000=0?ooo`80l_;b2P3gmoL20?;blP80moOg103bl_840?Ogm`80l_;b1`3gmoL2
0?3`l080moOg103bl_820<G5a@80WIfM0P20P80206i^KP@0Fe]K0P1EEED404E5A@@0EEEE0P0o?cl2
0<k>cP@0d=3@0P3Bd]8<0=OGe`80e=CD1P3GemL20<o?c`<0`l?30P2l_;`20<30`080[:b/102b/[82
0:VYZ@80/;2`102h^;P20<30`080`L710P38b<P20<?3``H0c/k>0P33`l<20<k>cP80`/;20P2k^k/2
0;Rh^080/[:b102YZJT20:RXZ080UIFE0P2DU9@208R8R080J6QX0P11@D4201HF5P<0;bl_0P1CDe<2
05eMG@80MWIf0P1NGUh208:2PP@0Kfm_0P1EEED20;2`/080Ti>C0P2XZ:P20=CDe080WYjN102HV9P2
08R8R080UIFE0P2CTi<209jNWP80aLG51032`/820=3@d0@0f][J0P3De=@=0?Ogm`80l_;b503gmoL2
0?;blPP0moOg3`3oool000d0oooo3P3gmoL20?;blPH0moOg0P3bl_8?0?Ogm`80jNWY0P2e]KD208n?
S`80KVi^0P1MGEd205]KF`80ADE50P1EEED204e=C@80EEEE0P1CDe<203lo?`80>c/k0P3@d=020<g=
c@@0clo?0P3GemL20=;BdP@0gMgM1P3GemL20=;BdP80fm_K0P2/[:`209JFUPD0clo?0P33`l<20;Jf
]P@0MgMg0P2EUID20:b/[080R8R80P2XZ:P20;Rh^080`L71103>c/h60<o?c`80c/k>0P33`l<20<71
`@80^k^k0P2j^[X40;:b/P80ZJVY0P2XZ:P20:2PX080U9BD0P1nOWh207EeM@80CDe=0P0Q8B4302l_
;`80>c/k0P1CDe<205iNGP80Hf=S101fMWH205eMG@80MWIf0P1VIVH209JFUP80]kNg0P2XZ:P20;Ng
]`80Ti>C0P2FUYH206m_K`@0R8R80P2XZ:P20<G5a@80`/;20P3YjNT20;Bd]080jNWY0P2m_Kd[0?Og
m`80l_;b0P3gmoL?0?ooo`003@3oool>0?Ogm`80l_;b1P3gmoL20?;blPl0moOg0P3YjNT20;Fe]@80
Shn?0P1^KVh205eMG@80Fe]K0P15ADD205EEE@80CDe=0P1EEED205=CD`80?clo0P0k>c/20=3@d080
cLg=103?cll20=OGe`80d];B103MgMd60=OGe`80d];B0P3Kfm/20:b/[080UYJF1@3?cll20<?3``80
][Jf101gMgL209FEU@80[:b/0P28R8P20:RXZ080^;Rh0P31`L440<k>cPH0clo?0P3>c/h20<?3``80
`L710P2k^k/20;Zj^P@0/[:b0P2YZJT20:RXZ080X:2P0P2DU9@207inOP80MGEe0P1=CDd2024Q8@<0
;bl_0P0k>c/205=CD`80GUiN0P1SHf<407IfMP80GEeM0P1fMWH206IVIP80UYJF0P2g]kL20:RXZ080
]kNg0P2CTi<209JFUP80Kfm_1028R8P20:RXZ080aLG50P32`/820>WYj@80];Bd0P3YjNT20;fm_B/0
moOg0P3bl_820?Ogm`l0oooo000=0?ooo`@0l_;b0P3gmoL40?;blPP0moOg103bl_820?Ogm`80l_;b
2`3gmoL20?;blP80h>3P0P2NWYh20820P080KVi^0P1_Kfl405EEE@80ADE50P1?Cdl205EEE@80ADE5
0P0k>c/205iNGP80d=3@0P3?cll20=GEe@80emOG0P3MgMd20=OGe`80d];B0P3MgMd20=;BdP80emOG
0P3De=@20=OGe`80gMgM0P3EeMD20=3@d0D0d];B0P3?cll20<30`0@0^;Rh0P2j^[X20<30`080/[:b
0P2KVi/20:VYZ@80`L712P3?cll20<?3``@0c/k>0P32`/820;Zj^P80^;Rh0P2b/[820:VYZ@@0X:2P
0P2DU9@208f=S@80Ng]k0P1VIVH201HF5P<08B4Q0P0_;bl204Q8B080FUYJ0P1VIVH205iNGP80Ng]k
0P1MGEd206IVIP80<c<c0P2d];@209^KV`80X:2P0P35aLD208R8R080UYJF0P1fMWH20820P080UYJF
0P2NWYh20;Bd]0@0bl_;0P2b/[820;fm_@@0moOg0P3bl_8;0?Ogm`80l_;b203gmoL20?;blPX0moOg
103bl_860?Ogm`l0oooo000=0?ooo`@0l_;b0P3gmoL40?;blPP0moOg103bl_820?Ogm`80l_;b2`3g
moL20?;blP80h>3P0P2NWYh20820P080KVi^0P1_Kfl405EEE@80ADE50P1?Cdl205EEE@80ADE50P0k
>c/205iNGP80d=3@0P3?cll20=GEe@80emOG0P3MgMd20=OGe`80d];B0P3MgMd20=;BdP80emOG0P3D
e=@20=OGe`80gMgM0P3EeMD20=3@d0D0d];B0P3?cll20<30`0@0^;Rh0P2j^[X20<30`080/[:b0P2K
Vi/20:VYZ@80`L712P3?cll20<?3``@0c/k>0P32`/820;Zj^P80^;Rh0P2b/[820:VYZ@@0X:2P0P2D
U9@208f=S@80Ng]k0P1VIVH201HF5P<08B4Q0P0_;bl204Q8B080FUYJ0P1VIVH205iNGP80Ng]k0P1M
GEd206IVIP80<c<c0P2d];@209^KV`80X:2P0P35aLD208R8R080UYJF0P1fMWH20820P080UYJF0P2N
WYh20;Bd]0@0bl_;0P2b/[820;fm_@@0moOg0P3bl_8;0?Ogm`80l_;b203gmoL20?;blPX0moOg103b
l_860?Ogm`l0oooo000=0?ooo``0moOg0P3bl_840?Ogm`@0l_;b203gmoL30?3`l0H0moOg0P3Jf]X2
09JFUP80KVi^0P1XJ6P204E5A@80De=C0P1HF5P204e=C@80EEEE0P1HF5P403Lg=`80Q8B40P3=cLd6
0=;BdP80fm_K1P3MgMd20=_Kf`@0emOG0P3Bd]820=gMg@80d=3@1`3Kfm/20=;BdP80c/k>0P30`<04
0;bl_0@0^;Rh102b/[820<?3``@0clo?0P3Bd]860<o?c`H0`l?30P30`<020;Zj^P80^;Rh0P2/[:`4
09fMW@80U9BD0P28R8P207YjNP80KVi^0P0F5QH302TY:@808B4Q0P1CDe<205iNGP80KVi^0P1=CDd2
07IfMP80GEeM0P1VIVH203/k>`80WYjN0P2FUYH20;Bd]080aLG50P28R8P209JFUP80P8200P28R8P2
08n?S`80WIfM0P2e]KD40<_;b`80`/;20P3@d=040?Ogm`80l_;b3`3gmoL20?;blQ80moOg0P3bl_86
0?Ogm`l0oooo000=0?ooo``0moOg0P3bl_840?Ogm`@0l_;b203gmoL30?3`l0H0moOg0P3Jf]X209JF
UP80KVi^0P1XJ6P204E5A@80De=C0P1HF5P204e=C@80EEEE0P1HF5P403Lg=`80Q8B40P3=cLd60=;B
dP80fm_K1P3MgMd20=_Kf`@0emOG0P3Bd]820=gMg@80d=3@1`3Kfm/20=;BdP80c/k>0P30`<040;bl
_0@0^;Rh102b/[820<?3``@0clo?0P3Bd]860<o?c`H0`l?30P30`<020;Zj^P80^;Rh0P2/[:`409fM
W@80U9BD0P28R8P207YjNP80KVi^0P0F5QH302TY:@808B4Q0P1CDe<205iNGP80KVi^0P1=CDd207If
MP80GEeM0P1VIVH203/k>`80WYjN0P2FUYH20;Bd]080aLG50P28R8P209JFUP80P8200P28R8P208n?
S`80WIfM0P2e]KD40<_;b`80`/;20P3@d=040?Ogm`80l_;b3`3gmoL20?;blQ80moOg0P3bl_860?Og
m`l0oooo000=0?ooo`H0moOg0P3bl_820?Ogm`80l_;b103gmoL20?;blP80moOg0P3bl_840?Ogm`80
l?3`0P3gmoL50?;blP80moOg0P3bl_820=CDe080P820101VIVH205eMG@@0EEEE0P1GEeL205]KF`80
Cdm?0P0c<c<20451@@80c/k>0P3@d=040=OGe`H0gMgM0P3Kfm/20=gMg@80fm_K0P3MgMd20=;BdP80
clo?103MgMd20=_Kf`<0i>CT0P3Kfm/20=;BdP80clo?0P36a/H20;^k^`80][Jf102h^;P20;:b/P80
^k^k0P33`l<40<o?c`80e=CD0P3?cll20=;BdP80clo?103>c/h40<?3``80^k^k0P2j^[X20;:b/P80
[:b/0P2PX:0209FEU@80R8R80P1jNWX206IVIP80<c<c0`0<30`202TY:@80CDe=0P0c<c<206m_K`80
GEeM0P1fMWH204m?C`80GEeM0P1VIVH20820P080V9RH102a/K420:RXZ080R8R80P2FUYH20820P0@0
R8R80P2d];@20<g=c@80_Kfm0P3De=@20?;blPh0moOg1@3bl_8N0?Ogm`l0oooo000=0?ooo`H0moOg
0P3bl_820?Ogm`80l_;b103gmoL20?;blP80moOg0P3bl_840?Ogm`80l?3`0P3gmoL50?;blP80moOg
0P3bl_820=CDe080P820101VIVH205eMG@@0EEEE0P1GEeL205]KF`80Cdm?0P0c<c<20451@@80c/k>
0P3@d=040=OGe`H0gMgM0P3Kfm/20=gMg@80fm_K0P3MgMd20=;BdP80clo?103MgMd20=_Kf`<0i>CT
0P3Kfm/20=;BdP80clo?0P36a/H20;^k^`80][Jf102h^;P20;:b/P80^k^k0P33`l<40<o?c`80e=CD
0P3?cll20=;BdP80clo?103>c/h40<?3``80^k^k0P2j^[X20;:b/P80[:b/0P2PX:0209FEU@80R8R8
0P1jNWX206IVIP80<c<c0`0<30`202TY:@80CDe=0P0c<c<206m_K`80GEeM0P1fMWH204m?C`80GEeM
0P1VIVH20820P080V9RH102a/K420:RXZ080R8R80P2FUYH20820P0@0R8R80P2d];@20<g=c@80_Kfm
0P3De=@20?;blPh0moOg1@3bl_8N0?Ogm`l0oooo000=0?ooo`h0moOg103bl_820?Ogm`@0l_;b103g
moL20?;blPL0moOg0P3`l?0209jNWP@0KVi^0P15ADD404e=C@80EEEE0P1HF5P205EEE@80:BTY0P0g
=cL202TY:@80clo?0P3Bd]820=KFeP80d];B103MgMd20=_Kf`X0gMgM103GemL20=;BdPL0fm_K0P3G
emL20<o?c`80^k^k0P2`/;020;:b/P80^;Rh0P2`/;020;Rh^080`L710P3?cll40=3@d080eMGE0P3G
emL40<o?c`80c/k>0P3?cll20<k>cP80`l?30P2k^k/20;Zj^P80^;Rh0P2b/[820:RXZ080UIFE0P28
R8P20820P080MGEe0P1CDe<301@D50808B4Q0P11@D42065QH@80GUiN0P1VIVH206i^KP80EEEE0P1M
GEd205=CD`80Ng]k0P2CTi<20:2PX080^;Rh0P36a/H208:2PP80R8R80P1kNg/208R8R080WYjN0P35
aLD20<g=c@80YJFU0P3@d=020?Ogm`80l_;b0P3gmoL60?;blPL0moOg0P3bl_8B0?Ogm`80l_;b2P3g
moL?0?ooo`003@3oool>0?Ogm`@0l_;b0P3gmoL40?;blP@0moOg0P3bl_870?Ogm`80l?3`0P2NWYh4
06i^KP80ADE5101=CDd205EEE@80F5QH0P1EEED202TY:@80=cLg0P0Y:BT20<o?c`80d];B0P3Fe]H2
0=;BdP@0gMgM0P3Kfm/:0=gMg@@0emOG0P3Bd]870=_Kf`80emOG0P3?cll20;^k^`80/;2`0P2b/[82
0;Rh^080/;2`0P2h^;P20<71`@80clo?103@d=020=GEe@80emOG103?cll20<k>cP80clo?0P3>c/h2
0<?3``80^k^k0P2j^[X20;Rh^080/[:b0P2XZ:P209FEU@80R8R80P20P80207EeM@80De=C0`0D51@2
024Q8@80@D510P1QHF4205iNGP80IVIV0P1^KVh205EEE@80GEeM0P1CDe<207]kN`80Ti>C0P2PX:02
0;Rh^080a/K60P22PX8208R8R080Ng]k0P28R8P209jNWP80aLG50P3=cLd20:FUY@80d=3@0P3gmoL2
0?;blP80moOg1P3bl_870?Ogm`80l_;b4P3gmoL20?;blPX0moOg3`3oool000d0oooo103bl_860?Og
m`80l_;b303gmoL20?;blP80moOg0P3bl_870?Ogm`80kno_0P2?Shl206i^KP80EeMG0P15ADD205iN
GP@0F5QH0P1EEED2024Q8@80<c<c0P0];Bd20451@@80clo?0P3GemL20=gMgA00fm_K103MgMd20=;B
dP80e]KF0P3Bd]830=gMg@80d];B0P3@d=020<?3``80`L710P2`/;060;Rh^080`L711P3?cll20=3@
d080d];B0P3GemL20=3@d080d];B0P3?cll20<k>cP80clo?1033`l<20;^k^`80^[Zj0P2`/;020;:b
/P80X:2P0P2DU9@20820P080MWIf0P1KFe/301HF5P80=CDe0P0c<c<204e=C@80De=C101MGEd206m_
K`@0GEeM0P23Ph<209JFUP80X:2P0P2h^;P20=CDe080R8R80P22PX8207IfMP80Ph>30P2?Shl20;Bd
]080bl_;0P3@d=020?;blQd0moOg0P3bl_880?Ogm`@0l_;b203gmoL?0?ooo`003@3oool40?;blPH0
moOg0P3bl_8<0?Ogm`80l_;b0P3gmoL20?;blPL0moOg0P3_knl208n?S`80KVi^0P1GEeL204E5A@80
GUiN101HF5P205EEE@808B4Q0P0c<c<202d];@80@D510P3?cll20=OGe`80gMgM403Kfm/40=gMg@80
d];B0P3Fe]H20=;BdP<0gMgM0P3Bd]820=3@d080`l?30P31`L420;2`/0H0^;Rh0P31`L460<o?c`80
d=3@0P3Bd]820=OGe`80d=3@0P3Bd]820<o?c`80c/k>0P3?cll40<?3``80^k^k0P2j^[X20;2`/080
/[:b0P2PX:0209BDU080P8200P1fMWH205]KF`<05QHF0P0e=CD203<c<`80CDe=0P1CDe<405eMG@80
Kfm_101MGEd208>3P`80UYJF0P2PX:020;Rh^080e=CD0P28R8P208:2PP80MWIf0P23Ph<208n?S`80
];Bd0P3;bl/20=3@d080l_;b7@3gmoL20?;blPP0moOg103bl_880?Ogm`l0oooo000=0?ooo`P0moOg
0P3bl_8<0?Ogm`80l_;b0P3gmoL20?;blP80moOg2@3bl_8208n?S`80IVIV101EEED205iNGP80De=C
0P1EEED205QHF080<c<c0P0Y:BT203<c<`80];Bd103EeMD20=gMg@P0fm_K1P3Shn<20=_Kf`H0gMgM
0P3GemL20=3@d0D0gMgM0P3?cll20<?3``H0^;Rh0P30`<020<71`@80a/K60P3?cll20=GEe@80d=3@
103Bd]820=gMg@80e]KF0P3Bd]820=3@d0@0clo?0P33`l<40<71`@80^;Rh0P2b/[820:VYZ@80Z:RX
0P2DU9@207inOP80MWIf0P1^KVh302TY:@8051@D0P0k>c/203<c<`80GUiN0P1VIVH205EEE@80IVIV
0P1_Kfl205eMG@80Ng]k0P2UYJD20:RXZ080]kNg0P3De=@20820P080V9RH0P1VIVH208n?S`80P820
0P35aLD20=?Cd`80d=3@<@3gmoL20?;blP80moOg3`3oool000d0oooo203gmoL20?;blP`0moOg0P3b
l_820?Ogm`80l_;b0P3gmoL90?;blP80Shn?0P1VIVH405EEE@80GUiN0P1CDe<205EEE@80F5QH0P0c
<c<202TY:@80<c<c0P2d];@40=GEe@80gMgM203Kfm/60>?Sh`80fm_K1P3MgMd20=OGe`80d=3@1@3M
gMd20<o?c`80`l?31P2h^;P20<30`080`L710P36a/H20<o?c`80eMGE0P3@d=040=;BdP80gMgM0P3F
e]H20=;BdP80d=3@103?cll20<?3``@0`L710P2h^;P20;:b/P80ZJVY0P2XZ:P209BDU080OWin0P1f
MWH206i^KP<0:BTY0P0D51@203/k>`80<c<c0P1NGUh206IVIP80EEEE0P1VIVH206m_K`80GEeM0P1k
Ng/20:FUY@80Z:RX0P2g]kL20=CDe080P8200P2HV9P206IVIP80Shn?0P20P8020<G5a@80dm?C0P3@
d=0a0?Ogm`80l_;b0P3gmoL?0?ooo`003@3oool60?;blPh0moOg1P3bl_840?Ogm`D0l_;b0P3gmoL2
0<g=c@80Ng]k0P1VIVH204e=C@@0GEeM0P1HF5P205EEE@80<c<c0P0Y:BT2024Q8@80`l?30P3Fe]H2
0=;BdP80gMgM0P3Shn<40=_Kf`80hn?S403Kfm/20=gMg@80emOG1@3MgMd20=;BdP80clo?0P31`L42
0;Rh^0@0`<300P31`L420<K6aP@0d=3@0P3Kfm/20=gMg@80d];B0P3Kfm/20=;BdP80gMgM103Fe]H2
0=3@d080clo?0P3=cLd20<?3``80`<300P2h^;P20;2`/080ZJVY0P2XZ:P208R8R080MWIf0P1_Kfl3
04e=C@80=cLg0P15ADD405=CD`80KVi^0P1MGEd206m_K`80IVIV0P1KFe/207]kN`80/;2`0P2XZ:P2
0;Bd]080a/K60P2FUYH208:2PP80GEeM0P23Ph<208R8R080^;Rh0P3IfMT20>k^kQ80moOg0`3bl_84
0?Ogm`@0l_;b103gmoL20?;blP80moOg0P3bl_8>0?Ogm`l0oooo000=0?ooo`H0l_;b3P3gmoL60?;b
lP@0moOg1@3bl_820?Ogm`80cLg=0P1kNg/206IVIP80CDe=101MGEd205QHF080EEEE0P0c<c<202TY
:@808B4Q0P33`l<20=KFeP80d];B0P3MgMd20>?Sh`@0fm_K0P3Shn<@0=_Kf`80gMgM0P3GemL50=gM
g@80d];B0P3?cll20<71`@80^;Rh1030`<020<71`@80a/K6103@d=020=_Kf`80gMgM0P3Bd]820=_K
f`80d];B0P3MgMd40=KFeP80d=3@0P3?cll20<g=c@80`l?30P30`<020;Rh^080/;2`0P2YZJT20:RX
Z080R8R80P1fMWH206m_K`<0CDe=0P0g=cL204E5A@@0De=C0P1^KVh205eMG@80Kfm_0P1VIVH205]K
F`80Ng]k0P2`/;020:RXZ080];Bd0P36a/H209JFUP80PX:20P1MGEd208>3P`80R8R80P2h^;P20=WI
f@80k^k^4P3gmoL30?;blP@0moOg103bl_840?Ogm`80l_;b0P3gmoL20?;blPh0moOg3`3oool000d0
oooo0P3bl_820?Ogm`80l_;b303gmoL20?;blP@0moOg0P3bl_8;0?Ogm`80Ng]k0P1VIVH205eMG@80
>c/k0P1QHF4405=CD`80F5QH0P0c<c<204E5A@80@D510P3?cll20=3@d080fm_K0P3MgMd40=_Kf`@0
hn?S103Kfm/20=gMg@80hn?S203Kfm/20=gMg@80e]KF1`3MgMd20=;BdP80`L710P2h^;P20<71`@80
aLG51036a/H20<g=c@80eMGE0P3MgMd20=KFeP80gMgM0P3Kfm/20=gMg@80d];B1P3Fe]H20=3@d080
clo?0P36a/H20<71`@@0^;Rh0P2YZJT20:RXZ080SHf=0P1nOWh206QXJ0<0De=C1P15ADD205iNGP80
GEeM0P1_Kfl206i^KP80IVIV0P1jNWX208n?S`80ZJVY102XZ:P20;Bd]080V9RH0P1iNGT205MGE`80
Ph>30P2MWId20;Fe]@80gmoO9@3gmoL20?;blPH0moOg0P3bl_880?Ogm`l0oooo000=0?ooo`80l_;b
0P3gmoL20?;blP`0moOg0P3bl_840?Ogm`80l_;b2`3gmoL207]kN`80IVIV0P1MGEd203/k>`80HF5Q
101CDe<205QHF080<c<c0P15ADD20451@@80clo?0P3@d=020=_Kf`80gMgM103Kfm/40>?Sh`@0fm_K
0P3MgMd20>?Sh`P0fm_K0P3MgMd20=KFePL0gMgM0P3Bd]820<71`@80^;Rh0P31`L420<G5a@@0a/K6
0P3=cLd20=GEe@80gMgM0P3Fe]H20=gMg@80fm_K0P3MgMd20=;BdPH0e]KF0P3@d=020<o?c`80a/K6
0P31`L440;Rh^080ZJVY0P2XZ:P208f=S@80OWin0P1XJ6P305=CD`H0ADE50P1NGUh205eMG@80Kfm_
0P1^KVh206IVIP80NWYj0P2?Shl20:VYZ@@0Z:RX0P2d];@209RHV080NGUi0P1GEeL208>3P`80WIfM
0P2e]KD20=oOgbD0moOg0P3bl_860?Ogm`80l_;b203gmoL?0?ooo`003@3oool20?;blQH0moOg0P3b
l_870?Ogm`80l_;b0P3gmoL20820P080Kfm_0P1CDe<204E5A@80IVIV0P1NGUh205EEE@80CDe=0P15
ADD203<c<`80S8b<0P3Bd]820=KFePH0fm_K103Shn<20=_Kf`80gMgM0P3Kfm/40=gMg@80fm_K103S
hn<40=_Kf`D0gMgM0P3Kfm/40=;BdP80`L71102h^;P20<G5a@80a/K6103?cll60=KFeP@0fm_K103B
d]820=gMg@80emOG0P3EeMD20=3@d0@0clo?0P36a/H40;Rh^080/;2`0P2XZ:P209BDU080OWin0P1X
J6P305]KF`@0>c/k0P15ADD205=CD`80F5QH0P1^KVh206m_K`80KVi^0P1VIVH80:RXZ080/;2`0P2d
];@407YjNP80P8200P2?Shl20;Ng]`80k^k^6`3gmoL20?;blP80moOg0P3bl_8F0?Ogm`l0oooo000=
0?ooo`80l_;b5P3gmoL20?;blPL0moOg0P3bl_820?Ogm`80P8200P1_Kfl205=CD`80ADE50P1VIVH2
05iNGP80EEEE0P1=CDd204E5A@80<c<c0P2<S8`20=;BdP80e]KF1P3Kfm/40>?Sh`80fm_K0P3MgMd2
0=_Kf`@0gMgM0P3Kfm/40>?Sh`@0fm_K1@3MgMd20=_Kf`@0d];B0P31`L440;Rh^080aLG50P36a/H4
0<o?c`H0e]KF103Kfm/40=;BdP80gMgM0P3GemL20=GEe@80d=3@103?cll20<K6aP@0^;Rh0P2`/;02
0:RXZ080U9BD0P1nOWh206QXJ0<0Fe]K100k>c/204E5A@80De=C0P1HF5P206i^KP80Kfm_0P1^KVh2
06IVIPP0Z:RX0P2`/;020;Bd]0@0NWYj0P20P80208n?S`80]kNg0P3^k^hK0?Ogm`80l_;b0P3gmoL2
0?;blQH0moOg3`3oool000d0oooo103gmoL20?;blP80moOg0P3bl_860?Ogm`80l_;b4@3gmoL20?;b
lP@0Ng]k0P1NGUh205=CD`80CDe=0P1NGUh205QHF080>c/k0P1=CDd205iNGP80d=3@0P3GemL20=KF
ePh0fm_K0P3MgMd20=_Kf`80e]KF203Kfm/40=gMg@<0d=3@103Kfm/20=gMg@80a/K60P2k^k/20;Rh
^080`L711036a/H20<g=c@80d=3@1P3Fe]H20=_Kf`80e]KF0P3MgMd20=KFeP@0d=3@0P3?cll20=3@
d080cLg=1036a/H20;Rh^080/;2`0P2YZJT20:2PX080R8R80P1fMWH305iNGP80CDe=0P0o?cl404E5
A@80GUiN0P1VIVH206a/K080GUiN0P1GEeL20;Fe]@80Z:RX0P2NWYh20:VYZ@80YJFU0P2h^;P206IV
IP@0P8200P2;Rh/20;Bd]080l?3`8`3gmoL20?;blQ80moOg3`3oool000d0oooo103gmoL20?;blP80
moOg0P3bl_860?Ogm`80l_;b4@3gmoL20?;blP@0Ng]k0P1NGUh205=CD`80CDe=0P1NGUh205QHF080
>c/k0P1=CDd205iNGP80d=3@0P3GemL20=KFePh0fm_K0P3MgMd20=_Kf`80e]KF203Kfm/40=gMg@<0
d=3@103Kfm/20=gMg@80a/K60P2k^k/20;Rh^080`L711036a/H20<g=c@80d=3@1P3Fe]H20=_Kf`80
e]KF0P3MgMd20=KFeP@0d=3@0P3?cll20=3@d080cLg=1036a/H20;Rh^080/;2`0P2YZJT20:2PX080
R8R80P1fMWH305iNGP80CDe=0P0o?cl404E5A@80GUiN0P1VIVH206a/K080GUiN0P1GEeL20;Fe]@80
Z:RX0P2NWYh20:VYZ@80YJFU0P2h^;P206IVIP@0P8200P2;Rh/20;Bd]080l?3`8`3gmoL20?;blQ80
moOg3`3oool000d0oooo0P3bl_860?Ogm`80l_;b0P3gmoL20?;blP80moOg0P3bl_8<0?Ogm`<0l_;b
0P3gmoL20;6a/@80IVIV0P1/K6`205eMG@80IVIV0P1MGEd205]KF`80ADE50P11@D4204e=C@80cLg=
0P3MgMd20=3@d080gMgM203Kfm/20>?Sh`@0fm_K0P3MgMd20=KFeP@0d=3@103Fe]H40=gMg@80d];B
0`3GemL40=_Kf`80gMgM0P3?cll20;^k^`@0^;Rh0P2i^KT20<G5a@80^KVi0P3>c/h20=?Cd`80d=3@
0P3Kfm/60=KFeP80d=3@0P3>c/h20=3@d0H0clo?1036a/H20;Vi^@80^;Rh0P2`/;0209fMW@80U9BD
0P1fMWH306IVIP80De=C0P0c<c<404E5A@80De=C0P1fMWH606IVIP80YJFU0P2NWYh40:RXZ080MWIf
0P35aLD2059BDP80MWIf0P2FUYH209jNWP80];Bd8@3gmoL20?;blQH0moOg3`3oool000d0oooo0P3b
l_860?Ogm`80l_;b0P3gmoL20?;blP80moOg0P3bl_8<0?Ogm`<0l_;b0P3gmoL20;6a/@80IVIV0P1/
K6`205eMG@80IVIV0P1MGEd205]KF`80ADE50P11@D4204e=C@80cLg=0P3MgMd20=3@d080gMgM203K
fm/20>?Sh`@0fm_K0P3MgMd20=KFeP@0d=3@103Fe]H40=gMg@80d];B0`3GemL40=_Kf`80gMgM0P3?
cll20;^k^`@0^;Rh0P2i^KT20<G5a@80^KVi0P3>c/h20=?Cd`80d=3@0P3Kfm/60=KFeP80d=3@0P3>
c/h20=3@d0H0clo?1036a/H20;Vi^@80^;Rh0P2`/;0209fMW@80U9BD0P1fMWH306IVIP80De=C0P0c
<c<404E5A@80De=C0P1fMWH606IVIP80YJFU0P2NWYh40:RXZ080MWIf0P35aLD2059BDP80MWIf0P2F
UYH209jNWP80];Bd8@3gmoL20?;blQH0moOg3`3oool000d0oooo1P3gmoL20?;blP@0moOg0P3bl_8@
0?Ogm`<0l_;b0P3gmoL208F5Q@80UIFE0P1fMWH205=CD`80MWIf0P1CDe<205]KF`80>c/k0P1CDe<2
05EEE@80cLg=0P3Bd]820<g=c@@0fm_K0P3Shn<40=_Kf`80gMgM0P3Kfm/40=KFeP80`l?30P3=cLd4
0<o?c`80d=3@0P3Fe]H20=gMg@80eMGE0`3GemL20=gMg@80fm_K0P3MgMd20<o?c`80][Jf0P2h^;P2
0;2`/0@0^;Rh0P36a/H20<k>cP80d=3@0P3Fe]H40<g=c@80a/K6203=cLd20<o?c`80d=3@103=cLd2
0;fm_@80aLG50P2h^;P20;2`/080Z:RX0P2DU9@20820P0<0IVIV0P1HF5P203<c<`80;Bd]0P15ADD2
05=CD`80IVIV0P1_Kfl406IVIP80YJFU102PX:020:RXZ080F5QH0P2g]kL206QXJ080IVIV0P2?Shl2
0;2`/080cLg=1P3gmoL20?;blQT0moOg0P3bl_8F0?Ogm`l0oooo000=0?ooo`H0moOg0P3bl_840?Og
m`80l_;b403gmoL30?;blP80moOg0P25QHD209FEU@80MWIf0P1CDe<207IfMP80De=C0P1KFe/203/k
>`80De=C0P1EEED20<g=c@80d];B0P3=cLd40=_Kf`80hn?S103Kfm/20=gMg@80fm_K103Fe]H20<?3
``80cLg=103?cll20=3@d080e]KF0P3MgMd20=GEe@<0emOG0P3MgMd20=_Kf`80gMgM0P3?cll20;Jf
]P80^;Rh0P2`/;040;Rh^080a/K60P3>c/h20=3@d080e]KF103=cLd20<K6aPP0cLg=0P3?cll20=3@
d0@0cLg=0P2m_Kd20<G5a@80^;Rh0P2`/;020:RXZ080U9BD0P20P80306IVIP80F5QH0P0c<c<202d]
;@80ADE50P1CDe<206IVIP80Kfm_101VIVH20:FUY@@0X:2P0P2XZ:P205QHF080]kNg0P1XJ6P206IV
IP80Shn?0P2`/;020<g=c@H0moOg0P3bl_8I0?Ogm`80l_;b5P3gmoL?0?ooo`003@3oool60?Ogm`80
l_;b1P3gmoL20?;blPH0moOg203bl_850?Ogm`80FUYJ0P2KVi/206IVIP80M7Ad0P1SHf<206IVIP80
De=C0P0c<c<206m_K`80^[Zj0P3?cll20;^k^`80d=3@0P3MgMd80=_Kf`80e]KF0P3Cdm<40=3@d080
clo?0P2i^KT20;Rh^080a/K60P3=cLd20=3@d080e]KF0P3=cLd30=3@d0@0fm_K0P3MgMd20<?3``80
^;Rh0P2/[:`20;Fe]@80/;2`0P2d];@20;fm_@80cLg=0P3>c/h40<K6aP80_Kfm0P2l_;`40;Rh^080
/;2`102i^KT60<K6aP@0aLG50P2h^;P20;2`/080X:2P0P2EUID207inOP<0MWIf0P1NGUh204e=C@80
8B4Q0P0g=cL204E5A@@0IVIV0P1fMWH205iNGP80WIfM0P2YZJT208R8R080UYJF0P1GEeL20<G5a@80
MWIf0P1KFe/209jNWP80];Bd0P3IfMT@0?Ogm`80l_;b5`3gmoL20?;blPh0moOg3`3oool000d0oooo
1P3gmoL20?;blPH0moOg0P3bl_860?Ogm`P0l_;b1@3gmoL205YJFP80Vi^K0P1VIVH207AdM080Hf=S
0P1VIVH205=CD`80<c<c0P1_Kfl20;Zj^P80clo?0P2k^k/20=3@d080gMgM203Kfm/20=KFeP80dm?C
103@d=020<o?c`80^KVi0P2h^;P20<K6aP80cLg=0P3@d=020=KFeP80cLg=0`3@d=040=_Kf`80gMgM
0P33`l<20;Rh^080[:b/0P2e]KD20;2`/080];Bd0P2m_Kd20<g=c@80c/k>1036a/H20;fm_@80_;bl
102h^;P20;2`/0@0^KVi1P36a/H40<G5a@80^;Rh0P2`/;020:2PX080UIFE0P1nOWh307IfMP80GUiN
0P1=CDd2024Q8@80=cLg0P15ADD406IVIP80MWIf0P1NGUh209fMW@80ZJVY0P28R8P209JFUP80EeMG
0P35aLD207IfMP80Fe]K0P2NWYh20;Bd]080fMWI403gmoL20?;blQL0moOg0P3bl_8>0?Ogm`l0oooo
000=0?oooa80moOg0P3bl_820?Ogm`80l_;b2@3gmoL20?ooo`80MWIf0P24Q8@205iNGP80IVIV0P1N
GUh206QXJ080;Bd]0P1MGEd205QHF080d];B0P2PX:020;:b/P80eMGE0P3MgMd60=_Kf`80e]KF0P3>
c/h20;Vi^@80WIfM0P2EUID20;2`/080[jn_0P2MWId40;Vi^@@0e]KF1@3@d=060=gMg@80clo?0P2h
^;P20:VYZ@80YJFU0P2YZJT20<G5a@80^KVi0P3>c/h20;bl_080^KVi0P2][Jd20:BTY080Shn?0P2E
UID60:FUY@80[jn_0P35aLD20<K6aPH0^KVi0P2h^;P20;2`/080YJFU0P2EUID208R8R0<0J6QX0P1N
GUh205=CD`80ADE5100k>c/205iNGP80GEeM0P1/K6`206IVIP80Shn?0P2FUYH408R8R080IVIV0P35
aLD206IVIP80Fe]K0P2UYJD20:RXZ080f][J0P3ooolg0?Ogm`l0oooo000=0?oooa80moOg0P3bl_82
0?Ogm`80l_;b2@3gmoL20?ooo`80MWIf0P24Q8@205iNGP80IVIV0P1NGUh206QXJ080;Bd]0P1MGEd2
05QHF080d];B0P2PX:020;:b/P80eMGE0P3MgMd60=_Kf`80e]KF0P3>c/h20;Vi^@80WIfM0P2EUID2
0;2`/080[jn_0P2MWId40;Vi^@@0e]KF1@3@d=060=gMg@80clo?0P2h^;P20:VYZ@80YJFU0P2YZJT2
0<G5a@80^KVi0P3>c/h20;bl_080^KVi0P2][Jd20:BTY080Shn?0P2EUID60:FUY@80[jn_0P35aLD2
0<K6aPH0^KVi0P2h^;P20;2`/080YJFU0P2EUID208R8R0<0J6QX0P1NGUh205=CD`80ADE5100k>c/2
05iNGP80GEeM0P1/K6`206IVIP80Shn?0P2FUYH408R8R080IVIV0P35aLD206IVIP80Fe]K0P2UYJD2
0:RXZ080f][J0P3ooolg0?Ogm`l0oooo000=0?ooo`80l_;b203gmoL20?;blP80moOg0P3bl_8A0?Og
m`80YJFU0P23Ph<207]kN`80De=C0P1NGUh205=CD`80J6QX0P0k>c/206IVIP80`/;20P33`l<20:FU
Y@80/;2`0P3EeMD20=KFeP@0fm_K0P3@d=020;bl_080Shn?0P2FUYH20;Vi^@80/K6a0P1/K6`2079b
LP80S8b<0P2UYJD409fMW@@0d=3@0`3=cLd60=gMg@80c/k>0P31`L420:VYZ@80/;2`0P2MWId20;2`
/080GemO0P1hN7P209FEU@80/;2`0P3=cLd20861P@80GemO0P25QHD208B4Q080Ph>30P24Q8@208n?
S`80/;2`102h^;P40;Vi^@@0/;2`0P2PX:0209FEU@80OWin0`1fMWH206IVIP80De=C0P1NGUh403<c
<`@0GUiN0P1VIVH207IfMP80Shn?0P2MWId208:2PP80R8R80P1QHF420<G5a@80Kfm_0P1kNg/40;Bd
]080jNWY7`3gmoL20?;blQP0moOg3`3oool000d0oooo0P3bl_880?Ogm`80l_;b0P3gmoL20?;blQ40
moOg0P2UYJD208>3P`80Ng]k0P1CDe<205iNGP80De=C0P1XJ6P203/k>`80IVIV0P32`/820<?3``80
YJFU0P2`/;020=GEe@80e]KF103Kfm/20=3@d080_;bl0P2?Shl209JFUP80^KVi0P2a/K4206a/K080
LW9b0P2<S8`20:FUY@@0WIfM103@d=030<g=c@H0gMgM0P3>c/h20<71`@80ZJVY0P2`/;0209fMW@80
/;2`0P1OGel207QhN080UIFE0P2`/;020<g=c@80PH610P1OGel208F5Q@80Q8B40P23Ph<208B4Q080
Shn?0P2`/;040;Rh^0@0^KVi102`/;020:2PX080UIFE0P1nOWh307IfMP80IVIV0P1CDe<205iNGP@0
<c<c101NGUh206IVIP80MWIf0P2?Shl209fMW@80PX:20P28R8P2065QH@80aLG50P1_Kfl207]kN`@0
];Bd0P3YjNTO0?Ogm`80l_;b603gmoL?0?ooo`003@3ooolF0?Ogm`80l_;b2@3gmoL208n?S`80Y:BT
0P1kNg/206a/K080>c/k0P1NGUh206QXJ080?clo0P0c<c<20=;BdP80^[Zj0P2f][H20;Rh^080e]KF
0P3MgMd20=KFeP80cLg=0P2l_;`208n?S`80UIFE0P33`l<20=[JfP80MGEe0P1/K6`205]KF`80O7al
0P25QHD20:FUY@80WIfM0P2l_;`20;Rh^0<0c/k>103MgMd20=GEe@80clo?0P31`L420;:b/P80WIfM
0P2?Shl209FEU@80YJFU0P1PH6020<g=c@80jNWY0P1hN7P207YjNP80KFe]0P2=SHd206ATI080YJFU
0P1kNg/2079bLP80Shn?102`/;040;Rh^080/;2`0P2YZJT20:RXZ080Shn?0P20P80307IfMP80GEeM
0P1CDe<203/k>`805QHF0P0Y:BT205iNGP80IVIV0P1=CDd207IfMP@0Shn?0P1fMWH208>3P`80MGEe
0P2h^;P205MGE`80WIfM102e]KDK0?Ogm`80l_;b1P3gmoL20?;blQH0moOg3`3oool000d0oooo5P3g
moL20?;blPT0moOg0P2?Shl20:BTY080Ng]k0P1/K6`203/k>`80GUiN0P1XJ6P203lo?`80<c<c0P3B
d]820;Zj^P80][Jf0P2h^;P20=KFeP80gMgM0P3Fe]H20<g=c@80_;bl0P2?Shl209FEU@80`l?30P3J
f]X207EeM@80K6a/0P1KFe/207alO080QHF50P2UYJD209fMW@80_;bl0P2h^;P30<k>cP@0gMgM0P3E
eMD20<o?c`80`L710P2b/[8209fMW@80Shn?0P2EUID20:FUY@80H61P0P3=cLd20>WYj@80N7Qh0P1j
NWX206e]K@80SHf=0P1TI6@20:FUY@80Ng]k0P1bLW8208n?S`@0/;2`102h^;P20;2`/080ZJVY0P2X
Z:P208n?S`80P8200`1fMWH205eMG@80De=C0P0k>c/201HF5P80:BTY0P1NGUh206IVIP80CDe=0P1f
MWH408n?S`80MWIf0P23Ph<207EeM@80^;Rh0P1GEeL209fMW@@0]KFe6`3gmoL20?;blPH0moOg0P3b
l_8F0?Ogm`l0oooo000=0?oooa00moOg0P3bl_8<0?Ogm`<0oooo0P3bl_8208^;R`80GEeM0P1EEED2
03/k>`H0GUiN0P1XJ6P20=;BdP80/[:b0P2UYJD20;Rh^080c/k>0P3EeMD20<o?c`80^KVi0P2MWId2
07YjNP80@D510P2MWId20;Zj^P80P8200P2e]KD201XJ6P80MgMg0P1=CDd207YjNP80Shn?0P2MWId2
0<71`@<0e=CD103MgMd20=OGe`80clo?0P35aLD20<30`080WIfM0P2EUID207]kN`80UIFE0P2MWId2
07IfMP80alO70P1KFe/20;bl_0806QXJ0P1bLW8205]KF`80YJFU0P0e=CD205YJFP80Q8B40P2EUID2
09fMW@H0/;2`0P2MWId209jNWP80U9BD0P20P80306QXJ080GUiN0P1HF5P202TY:@808B4Q0P0Y:BT2
03<c<`80GUiN0P1CDe<20820P080Ng]k1023Ph<208R8R080MGEe0P2d];@205MGE`80UYJF0P2YZJT2
0<_;bc/0moOg3`3oool000d0oooo403gmoL20?;blP`0moOg0`3oool20?;blP80Rh^;0P1MGEd205EE
E@80>c/k1P1NGUh206QXJ080d];B0P2b/[820:FUY@80^;Rh0P3>c/h20=GEe@80clo?0P2i^KT209fM
W@80NWYj0P11@D4209fMW@80^[Zj0P20P8020;Fe]@806QXJ0P1gMgL204e=C@80NWYj0P2?Shl209fM
W@80`L710`3De=@40=gMg@80emOG0P3?cll20<G5a@80`<300P2MWId209FEU@80Ng]k0P2EUID209fM
W@80MWIf0P37alL205]KF`80_;bl0P0J6QX2079bLP80Fe]K0P2UYJD203De=@80FUYJ0P24Q8@209FE
U@80WIfM1P2`/;0209fMW@80WYjN0P2DU9@20820P0<0J6QX0P1NGUh205QHF080:BTY0P0Q8B4202TY
:@80<c<c0P1NGUh205=CD`80P8200P1kNg/408>3P`80R8R80P1eMGD20;Bd]080EeMG0P2FUYH20:VY
Z@80bl_;>`3gmoL?0?ooo`003@3ooolN0?Ogm`<0Vi^K0P3:b/X2092@T080NWYj0P1LG5`205=CD`@0
GUiN0P1XJ6P208b<S080`l?30P2UYJD20:VYZ@80^;Rh0P3@d=020=GEe@80`L710P2_[jl209FEU@80
De=C101[Jf/204Q8B080;bl_0P11@D4205iNGP80LW9b0P1[Jf/208B4Q080WIfM0P2k^k/20<S8b0D0
emOG0P3MgMd20=OGe`80clo?0P38b<P20<71`@80/[:b0P2MWId209FEU@80P8200P1jNWX409:BTP80
@D510P0c<c<40451@@80De=C0P18B4P205mOG`80G5aL0P24Q8@408n?S`80X:2P102YZJT209fMW@80
Shn?0P28R8P206QXJ0D0IVIV0P1CDe<204E5A@80:BTY0P11@D4404E5A@80De=C0P1fMWH20820P080
MWIf0P1_Kfl208R8R080P8200P2d];@206i^KP80UYJF0P2XZ:P20>SXj2/0moOg0P3bl_8>0?Ogm`l0
oooo000=0?oooah0moOg0`2KVi/20<[:bP80T92@0P1jNWX205aLG080De=C101NGUh206QXJ080S8b<
0P33`l<20:FUY@80ZJVY0P2h^;P20=3@d080eMGE0P31`L420:n_[`80UIFE0P1CDe<406][J`80B4Q8
0P0_;bl20451@@80GUiN0P1bLW8206][J`80Q8B40P2MWId20;^k^`80b<S81@3GemL20=gMg@80emOG
0P3?cll20<S8b080`L710P2b/[8209fMW@80UIFE0P20P80207YjNP@0TY:B0P11@D4203<c<`@0@D51
0P1CDe<204Q8B080GemO0P1LG5`208B4Q0@0Shn?0P2PX:040:VYZ@80WIfM0P2?Shl208R8R080J6QX
1@1VIVH205=CD`80ADE50P0Y:BT20451@@@0ADE50P1CDe<207IfMP80P8200P1fMWH206m_K`80R8R8
0P20P8020;Bd]080KVi^0P2FUYH20:RXZ080j>SX:`3gmoL20?;blPh0moOg3`3oool000d0oooo203g
moL20?;blPH0moOg0P3bl_8<0?Ogm`<0P8200P2UYJD20:6QX@80IVIV0P1CDe<206a/K080GUiN0P1C
De<205]KF`80U9BD0P2f][H40:VYZ@80^;Rh0P3@d=020<k>cP80cLg=0P36a/H20;Rh^080WIfM0P1n
OWh206a/K0H0G5aL0P1NGUh207YjNP80UIFE0P2`/;020<71`@@0clo?0`3GemL40=gMg@80emOG103?
cll20<k>cP80`<300P2b/[820:VYZ@80WIfM0P2?Shl206YZJP80Q8B40P2<S8`208>3P`80Jf][0P1@
D50204Q8B080De=C0P1kNg/209JFUP@0UIFE0P2PX:040:VYZ@80WIfM0P2PX:0209JFUP80OWin0P1X
J6P306IVIP@0GUiN0P1=CDd203<c<`80@D51100k>c/204e=C@80Ng]k0P28R8P207]kN`80Kfm_0P28
R8P209JFUP80];Bd0P1fMWH209JFUP80/;2`0P3^k^hk0?Ogm`l0oooo000=0?ooo`P0moOg0P3bl_86
0?Ogm`80l_;b303gmoL30820P080YJFU0P2QXJ4206IVIP80De=C0P1/K6`205iNGP80De=C0P1KFe/2
09BDU080][Jf102YZJT20;Rh^080d=3@0P3>c/h20<g=c@80a/K60P2h^;P209fMW@80OWin0P1/K6`6
05aLG080GUiN0P1jNWX209FEU@80/;2`0P31`L440<o?c`<0emOG103MgMd20=OGe`@0clo?0P3>c/h2
0<30`080/[:b0P2YZJT209fMW@80Shn?0P1ZJVX208B4Q080S8b<0P23Ph<206][J`80D51@0P18B4P2
05=CD`80Ng]k0P2FUYH409FEU@80X:2P102YZJT209fMW@80X:2P0P2FUYH207inOP80J6QX0`1VIVH4
05iNGP80CDe=0P0c<c<20451@@@0>c/k0P1=CDd207]kN`80R8R80P1kNg/206m_K`80R8R80P2FUYH2
0;Bd]080MWIf0P2FUYH20;2`/080k^k^>`3gmoL?0?ooo`003@3ooolH0?Ogm`80l_;b103gmoL30>SX
j080TI6A0P1dM7@205=CD`80CDe=101CDe<204E5A@80MWIf0P2DU9@20:2PX080YJFU0P2MWId20;2`
/080c/k>103EeMD20=gMg@80e]KF0P3?cll20=3@d080a/K60P31`L420;bl_080`L710P36a/H20<71
`@80ZJVY0P2b/[820;^k^`80c/k>0P3MgMd30=OGe`@0fm_K0P3MgMd20=OGe`80e=CD0P3?cll20<30
`080Z:RX0P2/[:`209fMW@H0/;2`1P2MWId20:2PX080ZJVY102`/;020;Rh^080^[Zj0P2h^;P40;2`
/080ZJVY0P2PX:0209FEU@80UYJF0P28R8P206QXJ0<0K6a/0P1NGUh404E5A@80<c<c0P11@D4205=C
D`80CDe=0P15ADD207IfMP80UYJF0P1fMWH206m_K`80Ti>C0P2MWId20;Rh^080Ng]k0P2MWId20>7Q
h@80oooo=`3gmoL20?;blP80moOg3`3oool000d0oooo603gmoL20?;blP@0moOg0`3Xj>P2096AT@80
M7Ad0P1CDe<204e=C@@0De=C0P15ADD207IfMP80U9BD0P2PX:020:FUY@80WIfM0P2`/;020<k>cP@0
eMGE0P3MgMd20=KFeP80clo?0P3@d=020<K6aP80`L710P2l_;`20<71`@80a/K60P31`L420:VYZ@80
/[:b0P2k^k/20<k>cP80gMgM0`3GemL40=_Kf`80gMgM0P3GemL20=CDe080clo?0P30`<020:RXZ080
[:b/0P2MWId60;2`/0H0WIfM0P2PX:020:VYZ@@0/;2`0P2h^;P20;Zj^P80^;Rh102`/;020:VYZ@80
X:2P0P2EUID209JFUP80R8R80P1XJ6P306a/K080GUiN1015ADD203<c<`80@D510P1CDe<204e=C@80
ADE50P1fMWH209JFUP80MWIf0P1_Kfl209>CT`80WIfM0P2h^;P207]kN`80WIfM0P3QhN420?ooocL0
moOg0P3bl_820?Ogm`l0oooo000=0?ooo`@0moOg0P3bl_840?Ogm`80l_;b2P3gmoL20?;blP@0moOg
1@3oool204e=C@80IVIV0P0k>c/404E5A@80KVi^0P0k>c/205mOG`80OWin0P2MWId20:2PX080UIFE
0P2`/;020=GEe@80a/K60P3GemL40=gMg@80fm_K103MgMd20=_Kf`80][Jf0P2EUID208B4Q080Ng]k
0P1nOWh20<71`@80c/k>1`3MgMd20>?Sh`80fm_K0P3MgMd20=_Kf`80emOG0P3MgMd20<S8b080^k^k
0P2EUID207EeM@80Ng]k0P1nOWh209FEU@80a/K60P3=cLd20<o?c`80cLg=1036a/H60<71`@80^;Rh
0P2`/;0209jNWP80Shn?0P2PX:0209JFUP80R8R80P20P80207IfMP<0IVIV0P1MGEd205iNGP80=cLg
100c<c<20451@@80;Bd]0P1CDe<206IVIP80P8200P1fMWH206i^KP80V9RH0P2NWYh20<G5a@80Ph>3
0P2UYJD20>WYjCd0moOg3`3oool000d0oooo103gmoL20?;blP@0moOg0P3bl_8:0?Ogm`80l_;b103g
moL50?ooo`80CDe=0P1VIVH203/k>`@0ADE50P1^KVh203/k>`80GemO0P1nOWh209fMW@80X:2P0P2E
UID20;2`/080eMGE0P36a/H20=OGe`@0gMgM0P3Kfm/40=gMg@80fm_K0P2f][H209FEU@80Q8B40P1k
Ng/207inOP80`L710P3>c/h70=gMg@80hn?S0P3Kfm/20=gMg@80fm_K0P3GemL20=gMg@80b<S80P2k
^k/209FEU@80MGEe0P1kNg/207inOP80UIFE0P36a/H20<g=c@80clo?0P3=cLd40<K6aPH0`L710P2h
^;P20;2`/080WYjN0P2?Shl20:2PX080UYJF0P28R8P20820P080MWIf0`1VIVH205eMG@80GUiN0P0g
=cL403<c<`80@D510P0];Bd205=CD`80IVIV0P20P80207IfMP80KVi^0P2HV9P209jNWP80aLG50P23
Ph<20:FUY@80jNWY?@3gmoL?0?ooo`003@3ooolL0?Ogm`80jNWY0`3oool204E5A@80EEEE0P0k>c/2
04E5A@80De=C0P1NGUh205=CD`80Kfm_0P1gMgL208R8R080UYJF0P2EUID20:FUY@80clo?0P3;bl/2
0<G5a@80d=3@0P3MgMd40=_Kf`80d];B0P2?Shl208B4Q080NWYj0P1nOWh20;2`/080c/k>103GemL2
0=gMg@80hn?S0`3MgMd20>?Sh`80fm_K1P3MgMd40=OGe`80c/k>0P2k^k/209JFUP80J6QX0P1NGUh2
06QXJ080OWin0P2b/[820;bl_080cLg=103?cll20<?3``80a/K60P2h^;P20;:b/P80WIfM0P23Ph<2
0:2PX080UIFE0P2?Shl20820P0@0MWIf0`1VIVH404E5A@80<c<c0P0k>c/203<c<`80;Bd]0P1JFUX2
06=SH`80M7Ad0P23Ph<207]kN`80IVIV102FUYH20;Fe]@80WIfM0P2UYJDo0?Ogm`l0oooo000=0?oo
oa`0moOg0P3YjNT30?ooo`80ADE50P1EEED203/k>`80ADE50P1CDe<205iNGP80De=C0P1_Kfl207Mg
M`80R8R80P2FUYH209FEU@80YJFU0P3?cll20<_;b`80aLG50P3@d=020=gMg@@0fm_K0P3Bd]8208n?
S`80Q8B40P1jNWX207inOP80/;2`0P3>c/h40=OGe`80gMgM0P3Shn<30=gMg@80hn?S0P3Kfm/60=gM
g@@0emOG0P3>c/h20;^k^`80UYJF0P1XJ6P205iNGP80J6QX0P1nOWh20;:b/P80_;bl0P3=cLd40<o?
c`80`l?30P36a/H20;Rh^080/[:b0P2MWId208>3P`80X:2P0P2EUID208n?S`80P820101fMWH306IV
IP@0ADE50P0c<c<203/k>`80<c<c0P0];Bd205YJFP80Hf=S0P1dM7@208>3P`80Ng]k0P1VIVH409JF
UP80]KFe0P2MWId20:FUYCl0moOg3`3oool000d0oooo5P3gmoL20?;blP80moOg0P3oool20;6a/@<0
oooo0P1MGEd204e=C@@0De=C0P0k>c/205iNGP80EEEE0P1VIVH406QXJ080Q8B40P2?Shl20:FUY@80
c/k>0P3Fe]H209fMW@80YJFU0P2`/;020:VYZ@80WIfM0P1nOWh20820P080ZJVY0P3GemL40=gMg@d0
hn?S203Kfm/20=gMg@80fm_K1P3GemL20=CDe080`L710P2`/;0209FEU@80NWYj0P1VIVH207]kN`80
MGEe0P26QXH409FEU@80Shn?0P24Q8@208>3P`80Shn?1P2MWId209JFUP80P820101fMWH305iNGP80
MWIf0P0Y:BT404e=C@80ADE50P0c<c<202l_;`80JVYZ0P1fMWH20820P080MWIf0P1^KVh209JFUP80
Z:RX0P2?Shl207YjNP80d=3@8`3gmoL20?;blQX0moOg3`3oool000d0oooo5P3gmoL20?;blP80moOg
0P3oool20;6a/@<0oooo0P1MGEd204e=C@@0De=C0P0k>c/205iNGP80EEEE0P1VIVH406QXJ080Q8B4
0P2?Shl20:FUY@80c/k>0P3Fe]H209fMW@80YJFU0P2`/;020:VYZ@80WIfM0P1nOWh20820P080ZJVY
0P3GemL40=gMg@d0hn?S203Kfm/20=gMg@80fm_K1P3GemL20=CDe080`L710P2`/;0209FEU@80NWYj
0P1VIVH207]kN`80MGEe0P26QXH409FEU@80Shn?0P24Q8@208>3P`80Shn?1P2MWId209JFUP80P820
101fMWH305iNGP80MWIf0P0Y:BT404e=C@80ADE50P0c<c<202l_;`80JVYZ0P1fMWH20820P080MWIf
0P1^KVh209JFUP80Z:RX0P2?Shl207YjNP80d=3@8`3gmoL20?;blQX0moOg3`3oool000d0oooo5P3g
moL20?;blP@0moOg0P2][Jd307]kN`@0De=C0P1ZJVX205iNGPH0De=C0P1NGUh206IVIP80K6a/0P1k
Ng/208>3P`80/;2`0P3>c/h40=GEe@80clo?0P2`/;020:BTY080WIfM0P2i^KT20=_Kfa80hn?S0`3T
i>@40=_Kf`H0hn?S103MgMd20=_Kf`80gMgM0P3GemL20=;BdPH0clo?103=cLd20:FUY@80Q8B40P20
P80408B4Q080WIfM0P2UYJD209fMW@80X:2P0P2XZ:P20:2PX080UYJF0P20P80207]kN`80P8200`1N
GUh204E5A@80De=C0P15ADD203/k>`@08B4Q0P0Y:BT206a/K080NWYj0P1VIVH208>3P`80MGEe0P2N
WYh20:FUY@80MWIf0P2FUYH20>WYjBL0moOg0P3bl_8F0?Ogm`l0oooo000=0?oooaH0moOg0P3bl_84
0?Ogm`80[Jf]0`1kNg/405=CD`80JVYZ0P1NGUh605=CD`80GUiN0P1VIVH206a/K080Ng]k0P23Ph<2
0;2`/080c/k>103EeMD20<o?c`80/;2`0P2TY:@209fMW@80^KVi0P3Kfm/B0>?Sh`<0i>CT103Kfm/6
0>?Sh`@0gMgM0P3Kfm/20=gMg@80emOG0P3Bd]860<o?c`@0cLg=0P2UYJD208B4Q080P8201024Q8@2
09fMW@80YJFU0P2MWId20:2PX080Z:RX0P2PX:0209JFUP80P8200P1kNg/20820P0<0GUiN0P15ADD2
05=CD`80ADE50P0k>c/4024Q8@80:BTY0P1/K6`207YjNP80IVIV0P23Ph<207EeM@80WYjN0P2UYJD2
07IfMP80UYJF0P3YjNTW0?Ogm`80l_;b5P3gmoL?0?ooo`003@3oool80?Ogm`80l_;b1P3gmoL20?;b
lPX0moOg0P3:b/X307IfMP80HF5Q0P1CDe<208>3P`80LW9b0P1QHF4205iNGP80De=C101VIVH206a/
K0@0P8200P2YZJT20<o?c`80d=3@103EeMD40=gMg@H0fm_K3P3Shn<20>CTi0D0hn?S0P3Kfm/60>?S
h`X0fm_K0P3MgMd40=GEe@80emOG1P3?cll20<K6aP@0cLg=0P31`L440;Rh^080/;2`0P2YZJT20;2`
/080WIfM0P2EUID208R8R080P8200P23Ph<20820P0<0MWIf0P1CDe<204E5A@80;Bd]1P0Q8B4202TY
:@80UIFE0P1/K6`206IVIP80Z:RX0P1fMWH208R8R080];Bd0P1fMWH20:FUYD40moOg3`3oool000d0
oooo203gmoL20?;blPH0moOg0P3bl_8:0?Ogm`80b/[:0`1fMWH2065QH@80De=C0P23Ph<2079bLP80
HF5Q0P1NGUh205=CD`@0IVIV0P1/K6`40820P080ZJVY0P3?cll20=3@d0@0eMGE103MgMd60=_Kf`h0
hn?S0P3Ti>@50>?Sh`80fm_K1P3Shn<:0=_Kf`80gMgM103EeMD20=OGe`H0clo?0P36a/H40<g=c@80
`L71102h^;P20;2`/080ZJVY0P2`/;0209fMW@80UIFE0P28R8P20820P080Ph>30P20P80307IfMP80
De=C0P15ADD202d];@H08B4Q0P0Y:BT209FEU@80K6a/0P1VIVH20:RXZ080MWIf0P28R8P20;Bd]080
MWIf0P2UYJE10?Ogm`l0oooo000=0?ooo`@0moOg0P3bl_880?Ogm`80l_;b303gmoL20;Zj^P<0EeMG
0P1JFUX206=SH`80T92@0P1dM7@205iNGP80Hf=S0P1QHF4406=SH`80IVIV0P23Ph<207]kN`80ZJVY
0P3=cLd40=GEe@80e]KF103MgMd20=_Kf`@0hn?S0P3Kfm/20=gMg@H0hn?S0P3MgMd90>?Sh`80gMgM
0P3Kfm/20>?Sh`@0fm_K0P3Shn<20=_Kf`P0gMgM0P3Bd]820=OGe`80d=3@0P3?cll20<g=c@80a/K6
0P3?cll40<71`@80^;Rh102`/;040:VYZ@80WIfM0P2NWYh209JFUP80OWin1020P80306IVIP80MWIf
0P1=CDd403<c<`80:BTY0P0k>c/202d];@80WIfM0P23Ph<206IVIP80WIfM0P20P80207IfMP80]KFe
0P1fMWH20<;2`P80oooo?`3gmoL?0?ooo`003@3oool40?Ogm`80l_;b203gmoL20?;blP`0moOg0P2j
^[X305MGE`80FUYJ0P1SHf<2092@T080M7Ad0P1NGUh206=SH`80HF5Q101SHf<206IVIP80Ph>30P1k
Ng/20:VYZ@80cLg=103EeMD20=KFeP@0gMgM0P3Kfm/40>?Sh`80fm_K0P3MgMd60>?Sh`80gMgM2@3S
hn<20=gMg@80fm_K0P3Shn<40=_Kf`80hn?S0P3Kfm/80=gMg@80d];B0P3GemL20=3@d080clo?0P3=
cLd20<K6aP80clo?1031`L420;Rh^0@0/;2`102YZJT209fMW@80WYjN0P2FUYH207inOP@0P8200`1V
IVH207IfMP80CDe=100c<c<202TY:@80>c/k0P0];Bd209fMW@80Ph>30P1VIVH209fMW@80P8200P1f
MWH20;Fe]@80MWIf0P32`/820?ooocl0moOg3`3oool000d0oooo703gmoL20=7Ad@<0GUiN0P1bLW82
06a/K080Ng]k0P1/K6`2079bLP80K6a/0P1SHf<205iNGP@0GEeM0P1fMWH207]kN`80UIFE0P35aLD2
0=3@d0@0eMGE0P3Fe]H40=gMg@80fm_K103Shn<20=gMgA/0hn?S1P3Kfm/:0=OGe`80clo?0P3>c/h2
0<g=c@80clo?0P36a/H20<G5a@80`<30102h^;P40;2`/080ZJVY0P2XZ:P20:2PX080R8R80P20P802
08R8R080Ng]k0`1fMWH205=CD`80>c/k0P15ADD203/k>`@08B4Q0P0Y:BT209jNWP80Q8B40P1fMWH2
0:RXZ080PX:20P1/K6`209fMW@80MWIf0P3bl_910?Ogm`l0oooo000=0?oooa`0moOg0P3AdM4305iN
GP80LW9b0P1/K6`207]kN`80K6a/0P1bLW8206a/K080Hf=S0P1NGUh405eMG@80MWIf0P1kNg/209FE
U@80aLG50P3@d=040=GEe@80e]KF103MgMd20=_Kf`@0hn?S0P3MgMdK0>?Sh`H0fm_K2P3GemL20<o?
c`80c/k>0P3=cLd20<o?c`80a/K60P35aLD20<30`0@0^;Rh102`/;020:VYZ@80Z:RX0P2PX:0208R8
R080P8200P28R8P207]kN`<0MWIf0P1CDe<203/k>`80ADE50P0k>c/4024Q8@80:BTY0P2NWYh208B4
Q080MWIf0P2XZ:P208:2PP80K6a/0P2MWId207IfMP80l_;b@@3gmoL?0?ooo`003@3oool:0?Ogm`80
l_;b403gmoL20?;blP<0K6a/1P1NGUh206YZJP80K6a/0P1NGUh206=SH`80GUiN0P1SHf<205iNGP80
Ph>30P28R8P209jNWP80`L710P36a/H20=CDe080e]KF0P3GemL40=gMg@@0fm_K2P3Shn<40=gMg@/0
hn?S2P3Kfm/20=;BdPH0emOG0P3De=@60<o?c`80`l?30P36a/H20<G5a@80a/K60P31`L440;Rh^080
/[:b0P2`/;0209fMW@80X:2P0P2EUID209JFUP80R8R80P20P80207IfMP<0GUiN0P1CDe<20451@@80
CDe=0P0Y:BT4024Q8@80>c/k0P1kNg/20:RXZ080Shn?0P2YZJT208R8R080Ng]k0P1^KVh20;Bd]2T0
moOg0P3bl_8H0?Ogm`l0oooo000=0?ooo`X0moOg0P3bl_8@0?Ogm`80l_;b0`1/K6`605iNGP80JVYZ
0P1/K6`205iNGP80Hf=S0P1NGUh206=SH`80GUiN0P23Ph<208R8R080WYjN0P31`L420<K6aP80e=CD
0P3Fe]H20=OGe`@0gMgM103Kfm/:0>?Sh`@0gMgM2`3Shn<:0=_Kf`80d];B1P3GemL20=CDe0H0clo?
0P33`l<20<K6aP80aLG50P36a/H20<71`@@0^;Rh0P2b/[820;2`/080WIfM0P2PX:0209FEU@80UYJF
0P28R8P20820P080MWIf0`1NGUh205=CD`80@D510P1=CDd202TY:@@08B4Q0P0k>c/207]kN`80Z:RX
0P2?Shl20:VYZ@80R8R80P1kNg/206i^KP80];Bd:@3gmoL20?;blQP0moOg3`3oool000d0oooo2P3g
moL20?;blQ00moOg0P3bl_8306a/K0H0GUiN0P1ZJVX206a/K080GUiN0P1SHf<205iNGP80Hf=S0P1N
GUh208>3P`80R8R80P2NWYh20<71`@80a/K60P3De=@20=KFeP80emOG103MgMd40=_Kf`X0hn?S103M
gMd;0>?Sh`X0fm_K0P3Bd]860=OGe`80e=CD1P3?cll20<?3``80a/K60P35aLD20<K6aP80`L71102h
^;P20;:b/P80/;2`0P2MWId20:2PX080UIFE0P2FUYH208R8R080P8200P1fMWH305iNGP80De=C0P11
@D4204e=C@80:BTY100Q8B4203/k>`80Ng]k0P2XZ:P208n?S`80ZJVY0P28R8P207]kN`80KVi^0P2d
];@Y0?Ogm`80l_;b603gmoL?0?ooo`003@3ooolL0?Ogm`80oooo0`1LG5`2079bLP80GUiN0P1/K6`2
079bLP80M7Ad0P1/K6`406=SH`80GUiN0P1/K6`207]kN`80UYJF0P2MWId20;Rh^080a/K60P3EeMD2
0=KFePP0gMgM103Shn<40=gMg@@0hn?S0P3MgMd40>?Sh`80fm_K1`3Shn<60=_Kf`P0gMgM103GemL2
0=CDe0H0clo?0P33`l<80<71`@80^k^k0P2h^;P40;2`/080ZJVY0P2PX:0209FEU@@0Shn?0P24Q8@2
07IfMP<0IVIV0P15ADD205=CD`80;Bd]100Y:BT2024Q8@80;bl_0P1jNWX209fMW@80Ng]k0P2NWYh2
09JFUP80Rh^;0P1^KVh20=CDe4<0moOg3`3oool000d0oooo703gmoL20?ooo`<0G5aL0P1bLW8205iN
GP80K6a/0P1bLW8207AdM080K6a/101SHf<205iNGP80K6a/0P1kNg/209JFUP80WIfM0P2h^;P20<K6
aP80eMGE0P3Fe]H80=gMg@@0hn?S103MgMd40>?Sh`80gMgM103Shn<20=_Kf`L0hn?S1P3Kfm/80=gM
g@@0emOG0P3De=@60<o?c`80`l?32031`L420;^k^`80^;Rh102`/;020:VYZ@80X:2P0P2EUID408n?
S`80Q8B40P1fMWH306IVIP80ADE50P1CDe<202d];@@0:BTY0P0Q8B4202l_;`80NWYj0P2MWId207]k
N`80WYjN0P2FUYH208^;R`80KVi^0P3De=A30?Ogm`l0oooo000=0?oooa`0moOg0P3oool308>3P`80
FUYJ0P1VIVH407AdM080Hf=S0P1/K6`205iNGP80HF5Q0P1dM7@206a/K080Ng]k0P2?Shl209jNWP80
/;2`0P36a/H20<o?c`H0emOG1P3MgMd40>?Sh`80fm_K0P3MgMd40>?Sh`80fm_K0P3MgMd20>?Sh`<0
gMgM103Kfm/20=gMg@80fm_K1P3MgMd20=OGe`80gMgM103GemL20<o?c`80emOG0P3?cll40<k>cP80
a/K60P35aLD20<K6aP80`<30102h^;P40;2`/080WIfM0P2PX:0209FEU@@0Shn?101fMWH306IVIP80
De=C0P15ADD202d];@808B4Q100F5QH205aLG080K6a/0P23Ph<20820P080YJFU0P2NWYh20;Fe]@80
WYjNA@3gmoL?0?ooo`003@3ooolL0?Ogm`80oooo0`23Ph<205YJFP80IVIV101dM7@206=SH`80K6a/
0P1NGUh2065QH@80M7Ad0P1/K6`207]kN`80Shn?0P2NWYh20;2`/080a/K60P3?cll60=OGe`H0gMgM
103Shn<20=_Kf`80gMgM103Shn<20=_Kf`80gMgM0P3Shn<30=gMg@@0fm_K0P3MgMd20=_Kf`H0gMgM
0P3GemL20=gMg@@0emOG0P3?cll20=OGe`80clo?103>c/h20<K6aP80aLG50P36a/H20<30`0@0^;Rh
102`/;0209fMW@80X:2P0P2EUID408n?S`@0MWIf0`1VIVH205=CD`80ADE50P0];Bd2024Q8@@05QHF
0P1LG5`206a/K080Ph>30P20P8020:FUY@80WYjN0P2e]KD209jNWTD0moOg3`3oool000d0oooo703g
moL20?ooo`<0GUiN0P24Q8@208>3P`80IVIV0P1/K6`206YZJP80IVIV0P1SHf<206m_K`80CDe=0P1/
K6`208B4Q080UYJF0P2EUID20;2`/080aLG50P3?cll20=GEe@80emOG1P3MgMd40>?Sh`80fm_K1P3S
hn<20=gMg@80hn?S0P3MgMd20=_Kf`<0hn?S0P3MgMd40=_Kf`80gMgM103Kfm/80=gMg@80clo?0P3B
d]820=CDe0@0clo?0P33`l<20<k>cP@0`L711P2h^;P40;2`/080WIfM0P2XZ:P209FEU@80Shn?0P1k
Ng/207AdM080Hf=S0`1CDe<205iNGP80>c/k0P0Q8B4201HF5P80;bl_0P0F5QH206YZJP80M7Ad0P1f
MWH206i^KP@0WYjN0P2UYJD20=oOgdD0moOg3`3oool000d0oooo703gmoL20?ooo`<0GUiN0P24Q8@2
08>3P`80IVIV0P1/K6`206YZJP80IVIV0P1SHf<206m_K`80CDe=0P1/K6`208B4Q080UYJF0P2EUID2
0;2`/080aLG50P3?cll20=GEe@80emOG1P3MgMd40>?Sh`80fm_K1P3Shn<20=gMg@80hn?S0P3MgMd2
0=_Kf`<0hn?S0P3MgMd40=_Kf`80gMgM103Kfm/80=gMg@80clo?0P3Bd]820=CDe0@0clo?0P33`l<2
0<k>cP@0`L711P2h^;P40;2`/080WIfM0P2XZ:P209FEU@80Shn?0P1kNg/207AdM080Hf=S0`1CDe<2
05iNGP80>c/k0P0Q8B4201HF5P80;bl_0P0F5QH206YZJP80M7Ad0P1fMWH206i^KP@0WYjN0P2UYJD2
0=oOgdD0moOg3`3oool000d0oooo103gmoL20?;blP80moOg0P3bl_8D0?Ogm`<0h>3P0P24Q8@4065Q
H@@0GUiN0P1MGEd206=SH`80GUiN101/K6`208>3P`80UIFE0P2UYJD20;2`/080aLG50P3?cll20=GE
e@@0gMgM0P3Kfm/20=gMg@@0hn?S0P3MgMd20>?Sh`80gMgM0P3Shn<20=gMg@80fm_K0P3MgMd20>?S
h`<0gMgM103Kfm/80=gMg@80fm_K103MgMd20=;BdP@0emOG1P3?cll20<?3``80c/k>1031`L480;Rh
^080/;2`0P2UYJD20:VYZ@80Shn?0P24Q8@407]kN`80MWIf0`1QHF4204E5A@80>c/k100Q8B4202l_
;`808B4Q101dM7@207]kN`80Kfm_0P2NWYh20:FUY@80/;2`A`3gmoL?0?ooo`003@3oool40?Ogm`80
l_;b0P3gmoL20?;blQ@0moOg0`3Ph>0208B4Q0@0HF5Q101NGUh205eMG@80Hf=S0P1NGUh406a/K080
Ph>30P2EUID20:FUY@80/;2`0P35aLD20<o?c`80eMGE103MgMd20=_Kf`80gMgM103Shn<20=gMg@80
hn?S0P3MgMd20>?Sh`80gMgM0P3Kfm/20=gMg@80hn?S0`3MgMd40=_Kf`P0gMgM0P3Kfm/40=gMg@80
d];B103GemL60<o?c`80`l?30P3>c/h40<71`@P0^;Rh0P2`/;020:FUY@80ZJVY0P2?Shl208B4Q0@0
Ng]k0P1fMWH3065QH@80ADE50P0k>c/4024Q8@80;bl_0P0Q8B4407AdM080Ng]k0P1_Kfl209jNWP80
YJFU0P2`/;170?Ogm`l0oooo000=0?oooah0moOg0`3oool206a/K080HF5Q0P1NGUh205=CD`80GEeM
0P1JFUX205=CD`80HF5Q0P1/K6`207IfMP80Shn?0P2EUID20:VYZ@80]KFe0P35aLD20<o?c`80emOG
0P3Bd]820=gMg@80fm_K203MgMd20=_Kf`P0hn?S103Kfm/30>?Sha00gMgM0P3Bd]860=OGe`80clo?
0P3GemL20<o?c`@0c/k>0P38b<P20<71`@@0^;Rh0P2`/;020;Rh^0@0/;2`0P2MWId408n?S`80Q8B4
0P1/K6`206IVIP<0ADE50P0k>c/402TY:@805QHF0P0W9bL2024Q8@80PX:20P1dM7@206m_K`80KVi^
0P2UYJD20;Zj^P80dM7AA`3gmoL?0?ooo`003@3ooolN0?Ogm`<0oooo0P1/K6`2065QH@80GUiN0P1C
De<205eMG@80FUYJ0P1CDe<2065QH@80K6a/0P1fMWH208n?S`80UIFE0P2YZJT20;Fe]@80aLG50P3?
cll20=OGe`80d];B0P3MgMd20=_Kf`P0gMgM0P3Kfm/80>?Sh`@0fm_K0`3Shn<@0=gMg@80d];B1P3G
emL20<o?c`80emOG0P3?cll40<k>cP80b<S80P31`L440;Rh^080/;2`0P2h^;P40;2`/080WIfM102?
Shl208B4Q080K6a/0P1VIVH304E5A@80>c/k100Y:BT201HF5P809bLW0P0Q8B4208:2PP80M7Ad0P1_
Kfl206i^KP80YJFU0P2j^[X20=7AdDL0moOg3`3oool000d0oooo8@3gmoL20;bl_080JVYZ101NGUh2
05eMG@@0GUiN0P1JFUX205iNGP80MWIf0P24Q8@209FEU@80YJFU0P2i^KT20<K6aP80clo?103GemL2
0=gMg@@0fm_K0P3Shn<20=_Kf`X0hn?S0P3Kfm/20>?Sh`80gMgM0`3Kfm/20>?Sh`80fm_K0P3MgMd2
0=_Kf`P0gMgM0P3GemL20=gMg@80emOG0P3Bd]820=CDe0@0clo?103>c/h40<71`@80^KVi102h^;P4
0;2`/0@0X:2P0P2FUYH208B4Q080Ph>30P1kNg/206IVIP<0@D510P0k>c/202TY:@80;bl_0P0O7al4
02TY:@80Q8B40P2?Shl206IVIP80P8200P2NWYh20<G5a@@0moOg0P3bl_930?Ogm`l0oooo000=0?oo
ob40moOg0P2l_;`206YZJP@0GUiN0P1MGEd405iNGP80FUYJ0P1NGUh207IfMP80Q8B40P2EUID20:FU
Y@80^KVi0P36a/H20<o?c`@0emOG0P3MgMd40=_Kf`80hn?S0P3Kfm/:0>?Sh`80fm_K0P3Shn<20=gM
g@<0fm_K0P3Shn<20=_Kf`80gMgM0P3Kfm/80=gMg@80emOG0P3MgMd20=OGe`80d];B0P3De=@40<o?
c`@0c/k>1031`L420;Vi^@@0^;Rh102`/;040:2PX080UYJF0P24Q8@208>3P`80Ng]k0P1VIVH30451
@@80>c/k0P0Y:BT202l_;`807alO100Y:BT208B4Q080Shn?0P1VIVH20820P080WYjN0P35aLD40?Og
m`80l_;b@`3gmoL?0?ooo`003@3oool20?Ogm`80l_;b7@3gmoL20?;blP80LW9b101CDe<405YJFP80
GUiN0P1QHF4205YJFP80M7Ad0P2?Shl209fMW@80/;2`0P2h^;P20<k>cP80clo?0P3@d=020=GEe@80
emOG2P3MgMd20>?Sh`80gMgM0P3Shn<20=_Kf`@0gMgM0P3Kfm/30=gMg@@0fm_K1P3MgMd20=_Kf`@0
gMgM103GemL20=CDe080emOG0P3Bd]860<o?c`@0a/K60P35aLD20<30`0@0^;Rh0P2`/;040:VYZ@80
UIFE0P2FUYH208B4Q080Ng]k0P1/K6`205iNGP<0@D510P0k>c/202l_;`80:BTY100c<c<2024Q8@80
MWIf0P2?Shl207IfMP80Ti>C0P2`/;020=;BdTT0moOg3`3oool000d0oooo0P3gmoL20?;blQd0moOg
0P3bl_82079bLP@0De=C101JFUX205iNGP80HF5Q0P1JFUX207AdM080Shn?0P2MWId20;2`/080^;Rh
0P3>c/h20<o?c`80d=3@0P3EeMD20=OGe`X0gMgM0P3Shn<20=gMg@80hn?S0P3Kfm/40=gMg@80fm_K
0`3MgMd40=_Kf`H0gMgM0P3Kfm/40=gMg@@0emOG0P3De=@20=OGe`80d];B1P3?cll40<K6aP80aLG5
0P30`<040;Rh^080/;2`102YZJT209FEU@80UYJF0P24Q8@207]kN`80K6a/0P1NGUh30451@@80>c/k
0P0_;bl202TY:@@0<c<c0P0Q8B4207IfMP80Shn?0P1fMWH209>CT`80/;2`0P3Bd]990?Ogm`l0oooo
000=0?ooob<0moOg0P24Q8@2079bLP80FUYJ0P1SHf<2065QH@80FUYJ0P1QHF4206=SH`80M7Ad0P1k
Ng/209jNWP80]KFe1036a/H20<o?c`@0emOG1P3MgMd40=_Kf`@0hn?S0P3Kfm/40=gMg@T0fm_K103M
gMd20=_Kf`P0gMgM1P3GemL40=CDe080clo?103>c/h20<o?c`80a/K60P35aLD20<30`080^k^k102h
^;P40;:b/P80X:2P0P2EUID208n?S`80P8200P1fMWH206IVIP80De=C1@11@D4203<c<`80:BTY0P0c
<c<2024Q8@805QHF0P1dM7@207]kN`80MWIf0P2FUYH20;Rh^080k^k^B@3gmoL?0?ooo`003@3ooolS
0?Ogm`80Q8B40P1bLW8205YJFP80Hf=S0P1QHF4205YJFP80HF5Q0P1SHf<207AdM080Ng]k0P2NWYh2
0;Fe]@@0a/K60P3?cll40=OGe`H0gMgM103Kfm/40>?Sh`80fm_K103MgMd90=_Kf`@0gMgM0P3Kfm/8
0=gMg@H0emOG103De=@20<o?c`@0c/k>0P3?cll20<K6aP80aLG50P30`<020;^k^`@0^;Rh102b/[82
0:2PX080UIFE0P2?Shl20820P080MWIf0P1VIVH205=CD`D0@D510P0c<c<202TY:@80<c<c0P0Q8B42
01HF5P80M7Ad0P1kNg/207IfMP80UYJF0P2h^;P20>k^kTT0moOg3`3oool000d0oooo8`3gmoL20?oo
o`80_;bl0P24Q8@607AdM0@0HF5Q0P1dM7@208^;R`80UIFE0P2YZJT20<71`@80c/k>103?cll20=OG
e`80eMGE0P3GemL80=_Kf`@0gMgM0P3Kfm/20>?Sh`80gMgM0P3Kfm/90=gMg@80emOG0P3MgMd80=OG
e`80gMgM0P3Bd]820=OGe`P0c/k>0P33`l<20<K6aP80aLG50P30`<020;Rh^080`<301P2`/;0409FE
U@80Q8B40P23Ph<206a/K080GUiN0P1=CDd305=CD`@0>c/k0P0Y:BT2024Q8@8051@D0P11@D4208n?
S`80Ng]k0P22PX820:2PX080];Bd0P3gmoL20?;blTL0moOg3`3oool000d0oooo8`3gmoL20?ooo`80
_;bl0P24Q8@607AdM0@0HF5Q0P1dM7@208^;R`80UIFE0P2YZJT20<71`@80c/k>103?cll20=OGe`80
eMGE0P3GemL80=_Kf`@0gMgM0P3Kfm/20>?Sh`80gMgM0P3Kfm/90=gMg@80emOG0P3MgMd80=OGe`80
gMgM0P3Bd]820=OGe`P0c/k>0P33`l<20<K6aP80aLG50P30`<020;Rh^080`<301P2`/;0409FEU@80
Q8B40P23Ph<206a/K080GUiN0P1=CDd305=CD`@0>c/k0P0Y:BT2024Q8@8051@D0P11@D4208n?S`80
Ng]k0P22PX820:2PX080];Bd0P3gmoL20?;blTL0moOg3`3oool000d0oooo0P3gmoL20?;blQ80moOg
0P3bl_8;0?Ogm`@0oooo0P3YjNT207YjNP80M7Ad0P1SHf<206a/K080JVYZ0P1/K6`20820P080WIfM
0P2UYJD20;Rh^080c/k>103?cll40=OGe`@0gMgM0P3GemL40=_Kf``0gMgM0P3Kfm/;0=gMg@H0emOG
0P3MgMd20=OGe`P0clo?0P3>c/h20<o?c`80b<S81P31`L420<30`080^;Rh0P2YZJT20;2`/0@0WIfM
0P2FUYH20820P080J6QX0P1NGUh206=SH`80CDe=1@11@D4202l_;`80<c<c0P0J6QX201@D5080Ph>3
0P24Q8@206i^KP80R8R80P2HV9P20=?Cdd/0moOg3`3oool000d0oooo0P3gmoL20?;blQ80moOg0P3b
l_8;0?Ogm`@0oooo0P3YjNT207YjNP80M7Ad0P1SHf<206a/K080JVYZ0P1/K6`20820P080WIfM0P2U
YJD20;Rh^080c/k>103?cll40=OGe`@0gMgM0P3GemL40=_Kf``0gMgM0P3Kfm/;0=gMg@H0emOG0P3M
gMd20=OGe`P0clo?0P3>c/h20<o?c`80b<S81P31`L420<30`080^;Rh0P2YZJT20;2`/0@0WIfM0P2F
UYH20820P080J6QX0P1NGUh206=SH`80CDe=1@11@D4202l_;`80<c<c0P0J6QX201@D5080Ph>30P24
Q8@206i^KP80R8R80P2HV9P20=?Cdd/0moOg3`3oool000d0oooo9`3gmoL20?ooo`80YJFU0P1NGUh2
06YZJP80FUYJ101/K6`208>3P`80UYJF0P2YZJT20;Vi^@80a/K60P33`l<40<o?c`80emOG103De=@4
0=OGe`H0gMgM0P3GemL60=gMg@80emOG0`3MgMd20=GEe@80emOG0P3Fe]H60=OGe`80e=CD203?cll2
0<k>cP80clo?103>c/h20<?3``H0`L71102h^;P20;2`/080ZJVY0P2`/;0209FEU@80Q8B40P1fMWH2
06i^KP80IVIV101SHf<503/k>`80<c<c0P0Q8B4201HF5P80Shn?0P22PX8207IfMP80KVi^0P2FUYH2
0;fm_@80jNWY0P3gmoL40?;blTD0moOg3`3oool000d0oooo9`3gmoL20?ooo`80YJFU0P1NGUh206YZ
JP80FUYJ101/K6`208>3P`80UYJF0P2YZJT20;Vi^@80a/K60P33`l<40<o?c`80emOG103De=@40=OG
e`H0gMgM0P3GemL60=gMg@80emOG0`3MgMd20=GEe@80emOG0P3Fe]H60=OGe`80e=CD203?cll20<k>
cP80clo?103>c/h20<?3``H0`L71102h^;P20;2`/080ZJVY0P2`/;0209FEU@80Q8B40P1fMWH206i^
KP80IVIV101SHf<503/k>`80<c<c0P0Q8B4201HF5P80Shn?0P22PX8207IfMP80KVi^0P2FUYH20;fm
_@80jNWY0P3gmoL40?;blTD0moOg3`3oool000d0oooo9`3gmoL20?ooo`80d=3@0P15ADD206=SH`80
Ph>30P1QHF4408>3P`80UYJF0P2UYJD20;Rh^080aLG50P3=cLd20<o?c`80c/k>0P3?cll40=OGe`80
gMgM0P3GemL20=KFeP80gMgM0P3GemL:0=gMg@D0emOG0P3MgMd20=OGe`80clo?0P3GemL20<o?c`80
emOG103?cll20<k>cP@0clo?103>c/h20<G5a@80b<S81030`<020;Vi^@80^;Rh0P2d];@209fMW@80
ZJVY0P2PX:0208n?S`80Q8B40P1kNg/207IfMP80Hf=S0P1CDe<205YJFP<0M7Ad0P0Y:BT2024Q8@80
9bLW0P1QHF4205iNGP80Ph>30P1fMWH20820P080WYjN0P36a/H20?;blP80moOg0P3bl_820?ooodD0
moOg3`3oool000d0oooo9`3gmoL20?ooo`80d=3@0P15ADD206=SH`80Ph>30P1QHF4408>3P`80UYJF
0P2UYJD20;Rh^080aLG50P3=cLd20<o?c`80c/k>0P3?cll40=OGe`80gMgM0P3GemL20=KFeP80gMgM
0P3GemL:0=gMg@D0emOG0P3MgMd20=OGe`80clo?0P3GemL20<o?c`80emOG103?cll20<k>cP@0clo?
103>c/h20<G5a@80b<S81030`<020;Vi^@80^;Rh0P2d];@209fMW@80ZJVY0P2PX:0208n?S`80Q8B4
0P1kNg/207IfMP80Hf=S0P1CDe<205YJFP<0M7Ad0P0Y:BT2024Q8@809bLW0P1QHF4205iNGP80Ph>3
0P1fMWH20820P080WYjN0P36a/H20?;blP80moOg0P3bl_820?ooodD0moOg3`3oool000d0oooo9`3g
moL20?ooo`80^[Zj0P1kNg/405iNGP80JVYZ0P24Q8@208>3P`80UYJF0P2YZJT20;Rh^080^KVi0P36
a/H20<o?c`80c/k>0P3?cll20=;BdP80clo?0P3MgMd20=CDe0h0emOG0P3MgMd50=;BdPH0clo?0P33
`l<20<o?c`X0c/k>0P3?cll40<k>cP@0`<300P31`L460;Rh^080/;2`102MWId208n?S`80P8200P1k
Ng/206i^KP@0Hf=S101NGUh30451@@80De=C0P11@D4205=CD`80CDe=0P24Q8@207]kN`80Shn?0P2F
UYH20;Fe]@80`/;20P3gmoL20?ooodT0moOg3`3oool000d0oooo9`3gmoL20?ooo`80^[Zj0P1kNg/4
05iNGP80JVYZ0P24Q8@208>3P`80UYJF0P2YZJT20;Rh^080^KVi0P36a/H20<o?c`80c/k>0P3?cll2
0=;BdP80clo?0P3MgMd20=CDe0h0emOG0P3MgMd50=;BdPH0clo?0P33`l<20<o?c`X0c/k>0P3?cll4
0<k>cP@0`<300P31`L460;Rh^080/;2`102MWId208n?S`80P8200P1kNg/206i^KP@0Hf=S101NGUh3
0451@@80De=C0P11@D4205=CD`80CDe=0P24Q8@207]kN`80Shn?0P2FUYH20;Fe]@80`/;20P3gmoL2
0?ooodT0moOg3`3oool000d0oooo9`3gmoL20?ooo`80[Jf]0P2UYJD204e=C@80GEeM0P1QHF4206IV
IP80Ng]k0P2?Shl209fMW@80YJFU0P2m_Kd20<71`@80a/K60P3>c/h20<?3``@0d];B103EeMD20=3@
d080clo?0P3Bd]840=OGe`80gMgM0P3@d=020=GEe@D0clo?0P3>c/h20<?3``@0`L710P32`/840<k>
cP80b<S80P33`l<20<S8b080`/;21031`L420;Rh^080^k^k0P2h^;P40;2`/080ZJVY102MWId209FE
U@80Shn?0P20P80208>3P`80MWIf101JFUX405=CD`<0B4Q80P1=CDd203/k>`80Rh^;0P1dM7@207]k
N`80MWIf0P2YZJT209jNWP80aLG51P3gmoL20?;blP@0moOg0P3ooolS0?Ogm`80oooo703gmoL?0?oo
o`003@3ooolW0?Ogm`80oooo0P2][Jd20:FUY@80CDe=0P1MGEd2065QH@80IVIV0P1kNg/208n?S`80
WIfM0P2UYJD20;fm_@80`L710P36a/H20<k>cP80`l?3103Bd]840=GEe@80d=3@0P3?cll20=;BdP@0
emOG0P3MgMd20=3@d080eMGE1@3?cll20<k>cP80`l?31031`L420<;2`P@0c/k>0P38b<P20<?3``80
b<S80P32`/840<71`@80^;Rh0P2k^k/20;Rh^0@0/;2`0P2YZJT409fMW@80UIFE0P2?Shl20820P080
Ph>30P1fMWH405YJFP@0De=C0`18B4P204e=C@80>c/k0P2;Rh/207AdM080Ng]k0P1fMWH20:VYZ@80
WYjN0P35aLD60?Ogm`80l_;b103gmoL20?ooob<0moOg0P3ooolL0?Ogm`l0oooo000=0?ooobT0moOg
0P3Ph>020<g=c@80>c/k0P1=CDd207IfMP80GUiN0P1kNg/208^;R`80UIFE0P2`/;020;Rh^080^KVi
0P31`L440<?3``80c/k>0P3?cll20<g=c@80clo?0P3EeMD60<o?c`80d=3@0P3?cll20<k>cPD0clo?
0P38b<P20<71`@80^[Zj102k^k/20<30`080`/;2202j^[X20;:b/P80^;Rh0P2k^k/20;2`/080^;Rh
102`/;020:FUY@80Z:RX0P2MWId608n?S`80Ph>30P1kNg/206IVIP80Hf=S0P1QHF4205YJFP80LW9b
0`1QHF4205=CD`80LW9b0P2?Shl207YjNP80Q8B40P2FUYH20;2`/080aLG50P32`/820?;blPH0moOg
0P3ooolJ0?Ogm`80l_;b:@3gmoL?0?ooo`003@3ooolY0?Ogm`80h>3P0P3=cLd203/k>`80CDe=0P1f
MWH205iNGP80Ng]k0P2;Rh/209FEU@80/;2`0P2h^;P20;Vi^@80`L711033`l<20<k>cP80clo?0P3=
cLd20<o?c`80eMGE1P3?cll20=3@d080clo?0P3>c/h50<o?c`80b<S80P31`L420;Zj^P@0^k^k0P30
`<020<;2`PP0^[Zj0P2b/[820;Rh^080^k^k0P2`/;020;Rh^0@0/;2`0P2UYJD20:RXZ080WIfM1P2?
Shl208>3P`80Ng]k0P1VIVH206=SH`80HF5Q0P1JFUX2079bLP<0HF5Q0P1CDe<2079bLP80Shn?0P1j
NWX208B4Q080UYJF0P2`/;020<G5a@80`/;20P3bl_860?Ogm`80oooo6P3gmoL20?;blRT0moOg3`3o
ool000d0oooo:`3gmoL20:f][@80Ph>30P1QHF4206=SH`80M7Ad0P1/K6`207]kN`80Q8B40P2MWId2
0;2`/080aLG50P2i^KT20;fm_@@0`L71203?cll20<g=c@P0a/K60P31`L420;Vi^@L0^;Rh102`/;06
0:VYZ@80Z:RX0P2/[:`20:VYZ@@0Z:RX0P2MWId80:2PX0@0UIFE0P2MWId209FEU@80Shn?0P28R8P2
07IfMP80K6a/0P1jNWX207AdM080GemO101dM7@205=CD`<0K6a/101fMWH207]kN`80MWIf0P2FUYH2
08n?S`80^;Rh0P35aLD20?3`l4l0moOg3`3oool000d0oooo:`3gmoL20:f][@80Ph>30P1QHF4206=S
H`80M7Ad0P1/K6`207]kN`80Q8B40P2MWId20;2`/080aLG50P2i^KT20;fm_@@0`L71203?cll20<g=
c@P0a/K60P31`L420;Vi^@L0^;Rh102`/;060:VYZ@80Z:RX0P2/[:`20:VYZ@@0Z:RX0P2MWId80:2P
X0@0UIFE0P2MWId209FEU@80Shn?0P28R8P207IfMP80K6a/0P1jNWX207AdM080GemO101dM7@205=C
D`<0K6a/101fMWH207]kN`80MWIf0P2FUYH208n?S`80^;Rh0P35aLD20?3`l4l0moOg3`3oool000d0
oooo;@3gmoL20;6a/@80NWYj0P1SHf<206a/K080M7Ad0P23Ph<208n?S`80QHF50P2EUID209fMW@80
^;Rh0P2m_Kd20<K6aP80c/k>0P3=cLd60<K6aP80aLG5102h^;P20;2`/080^;Rh0P35aLD20;2`/0<0
/[:b102`/;0209fMW@80YJFU0P2EUID20:2PX080UYJF0P2YZJT208b<S080X:2P0P28R8P209FEU@@0
R8R80P2FUYH808n?S`80Q8B40P2EUID209fMW@80Rh^;0P2@T90208>3P`80Q8B4101/K6`207YjNP80
Q8B40P1SHf<304E5A@80GUiN0P28R8P208n?S`80R8R80P2FUYH20;Bd]080_Kfm0P32`/8>0?Ogm`80
l_;b8`3gmoL20?oooa`0moOg3`3oool000d0oooo;@3gmoL20;6a/@80NWYj0P1SHf<206a/K080M7Ad
0P23Ph<208n?S`80QHF50P2EUID209fMW@80^;Rh0P2m_Kd20<K6aP80c/k>0P3=cLd60<K6aP80aLG5
102h^;P20;2`/080^;Rh0P35aLD20;2`/0<0/[:b102`/;0209fMW@80YJFU0P2EUID20:2PX080UYJF
0P2YZJT208b<S080X:2P0P28R8P209FEU@@0R8R80P2FUYH808n?S`80Q8B40P2EUID209fMW@80Rh^;
0P2@T90208>3P`80Q8B4101/K6`207YjNP80Q8B40P1SHf<304E5A@80GUiN0P28R8P208n?S`80R8R8
0P2FUYH20;Bd]080_Kfm0P32`/8>0?Ogm`80l_;b8`3gmoL20?oooa`0moOg3`3oool000d0oooo;`3g
moL20>WYj@80TI6A0P1jNWX2065QH@80Ng]k0P23Ph<206a/K080UIFE0P2UYJD20<;2`PH0c/k>1036
a/H20;fm_@80^KVi0P2`/;020;Bd]0d0/;2`102NWYh409FEU@80Shn?0P2EUID208n?S`80P820102?
Shl207]kN`80MWIf0P2?Shl207]kN`80Shn?0P1kNg/20820P080Q8B40P23Ph<208B4Q080K6a/0P1d
M7@207YjNP80P8200P1jNWX207]kN`80NWYj0P1kNg/205iNGP80Hf=S0P1bLW8307IfMP80Ng]k1023
Ph<209jNWP@0_Kfm0P2UYJD80?Ogm`80l_;b8P3gmoL20?;blRD0moOg3`3oool000d0oooo;`3gmoL2
0>WYj@80TI6A0P1jNWX2065QH@80Ng]k0P23Ph<206a/K080UIFE0P2UYJD20<;2`PH0c/k>1036a/H2
0;fm_@80^KVi0P2`/;020;Bd]0d0/;2`102NWYh409FEU@80Shn?0P2EUID208n?S`80P820102?Shl2
07]kN`80MWIf0P2?Shl207]kN`80Shn?0P1kNg/20820P080Q8B40P23Ph<208B4Q080K6a/0P1dM7@2
07YjNP80P8200P1jNWX207]kN`80NWYj0P1kNg/205iNGP80Hf=S0P1bLW8307IfMP80Ng]k1023Ph<2
09jNWP@0_Kfm0P2UYJD80?Ogm`80l_;b8P3gmoL20?;blRD0moOg3`3oool000d0oooo3P3gmoL20?;b
lP80moOg0P3bl_8M0?Ogm`80TI6A0P25QHD208B4Q080OGem0P2@T9020:f][@80[jn_0P2TY:@20;Vi
^@80[jn_0P2i^KT40<;2`P80^KVi0P2h^;P60;2`/080WIfM0P2UYJD20;2`/080YJFU0P2NWYh30:FU
Y@80WIfM0P2EUID408n?S`80Ng]k0P2MWId208B4Q080WIfM0P2?Shl208B4Q080UYJF0P23Ph<207If
MP80WIfM0P23Ph<208n?S`80Q8B40P23Ph<208^;R`80T92@0P1ZJVX207AdM080Ph>30P22PX82079b
LP80NWYj0P24Q8@206i^KP80MWIf0P1^KVh207IfMP<0KVi^0P1kNg/208n?S`80];Bd0P2j^[X20;Bd
]080]KFe0P3De=@80?Ogm`80ooooB@3gmoL?0?ooo`003@3oool>0?Ogm`80l_;b0P3gmoL20?;blQd0
moOg0P2ATI4208F5Q@80Q8B40P1mOGd2092@T080[Jf]0P2_[jl20:BTY080^KVi0P2_[jl20;Vi^@@0
`/;20P2i^KT20;Rh^0H0/;2`0P2MWId20:FUY@80/;2`0P2UYJD209jNWP<0YJFU0P2MWId209FEU@@0
Shn?0P1kNg/209fMW@80Q8B40P2MWId208n?S`80Q8B40P2FUYH208>3P`80MWIf0P2MWId208>3P`80
Shn?0P24Q8@208>3P`80Rh^;0P2@T90206YZJP80M7Ad0P23Ph<208:2PP80LW9b0P1jNWX208B4Q080
KVi^0P1fMWH206i^KP80MWIf0`1^KVh207]kN`80Shn?0P2d];@20;Zj^P80];Bd0P2e]KD20=CDe0P0
moOg0P3ooom90?Ogm`l0oooo000=0?ooo`@0moOg0P3bl_8[0?Ogm`80oooo0P1jNWX208b<S080OGem
0P1dM7@208^;R`@0UIFE0P2TY:@20;Vi^@80_Kfm0P2h^;P20;Bd]080/;2`0P2e]KD60:FUY@80UIFE
0P2MWId209FEU@80WIfM0P2EUID309fMW@80Shn?0P2MWId208>3P`80Ng]k0P25QHD206i^KP80Rh^;
0P23Ph<209FEU@80Ng]k0P24Q8@208>3P`80Q8B40P2NWYh206a/K0@0Ng]k0P2?Shl208>3P`@0M7Ad
0P1SHf<2065QH@80De=C0P1JFUX206a/K0@0GUiN101QHF4206i^KP<0PX:20P2NWYh20;Bd]080cLg=
0P2TY:@20;Fe]@80Shn?E@3gmoL?0?ooo`003@3oool40?Ogm`80l_;b:`3gmoL20?ooo`80NWYj0P2<
S8`207emO@80M7Ad0P2;Rh/409FEU@80Y:BT0P2i^KT20;fm_@80^;Rh0P2d];@20;2`/080]KFe1P2U
YJD209FEU@80WIfM0P2EUID209fMW@80UIFE0`2MWId208n?S`80WIfM0P23Ph<207]kN`80QHF50P1^
KVh208^;R`80Ph>30P2EUID207]kN`80Q8B40P23Ph<208B4Q080WYjN0P1/K6`407]kN`80Shn?0P23
Ph<407AdM080Hf=S0P1QHF4205=CD`80FUYJ0P1/K6`405iNGP@0HF5Q0P1^KVh308:2PP80WYjN0P2d
];@20<g=c@80Y:BT0P2e]KD208n?SeD0moOg3`3oool000d0oooo<`3gmoL20?ooo`80Vi^K0P25QHD2
08B4Q0@0YJFU0P2][Jd80;fm_@P0YJFU0P2MWId20:FUY@@0WIfM102?Shl209fMW@<0Shn?0P23Ph<2
08B4Q080KVi^102;Rh/206a/K080De=C0P24Q8@206=SH`80Shn?0P23Ph<408B4Q080IVIV0P1fMWH2
08>3P`80CDe=0P1CDe<206m_K`80IVIV0P1SHf<206IVIP80Kfm_0P1^KVh207IfMP@0KVi^0P1NGUh2
06m_K`80MWIf0P2d];@309fMW@80]KFe0P32`/8206a/K080Y:BT0P2;Rh/20=;BdP80oooo3P3gmoL2
0?;blT<0moOg3`3oool000d0oooo<`3gmoL20?ooo`80Vi^K0P25QHD208B4Q0@0YJFU0P2][Jd80;fm
_@P0YJFU0P2MWId20:FUY@@0WIfM102?Shl209fMW@<0Shn?0P23Ph<208B4Q080KVi^102;Rh/206a/
K080De=C0P24Q8@206=SH`80Shn?0P23Ph<408B4Q080IVIV0P1fMWH208>3P`80CDe=0P1CDe<206m_
K`80IVIV0P1SHf<206IVIP80Kfm_0P1^KVh207IfMP@0KVi^0P1NGUh206m_K`80MWIf0P2d];@309fM
W@80]KFe0P32`/8206a/K080Y:BT0P2;Rh/20=;BdP80oooo3P3gmoL20?;blT<0moOg3`3oool000d0
oooo=@3gmoL20:f][@80S8b<0P1ZJVX207emO@80MWIf0P2;Rh/20:f][@80^[Zj0P2i^KT20;fm_@80
[Jf]102MWId209FEU@@0WIfM0P2EUID208^;R`80T92@0P2EUID208B4Q0D0Shn?0P1/K6`209jNWP80
Ph>30P1/K6`209fMW@80K6a/0P1SHf<208B4Q0@0K6a/0P1dM7@206=SH`80IVIV0P1MGEd204e=C@@0
GUiN0P1_Kfl205iNGP80HF5Q0P1^KVh206IVIP80GUiN0P1HF5P206IVIP80Ng]k102?Shl20:FUY@80
WIfM0`35aLD20;fm_@80Rh^;0P23Ph<20:BTY080Rh^;2P3gmoL20?;blP@0moOg0P3bl_8L0?Ogm`80
l_;b103gmoL30?ooob00moOg3`3oool000d0oooo=@3gmoL20:f][@80S8b<0P1ZJVX207emO@80MWIf
0P2;Rh/20:f][@80^[Zj0P2i^KT20;fm_@80[Jf]102MWId209FEU@@0WIfM0P2EUID208^;R`80T92@
0P2EUID208B4Q0D0Shn?0P1/K6`209jNWP80Ph>30P1/K6`209fMW@80K6a/0P1SHf<208B4Q0@0K6a/
0P1dM7@206=SH`80IVIV0P1MGEd204e=C@@0GUiN0P1_Kfl205iNGP80HF5Q0P1^KVh206IVIP80GUiN
0P1HF5P206IVIP80Ng]k102?Shl20:FUY@80WIfM0`35aLD20;fm_@80Rh^;0P23Ph<20:BTY080Rh^;
2P3gmoL20?;blP@0moOg0P3bl_8L0?Ogm`80l_;b103gmoL30?ooob00moOg3`3oool000d0oooo=@3g
moL20?ooo`80GemO0P23Ph<20:BTY080QHF50P2;Rh/209^KV`80/[:b0P2j^[X20;2`/080[Jf]0P24
Q8@208n?S`80Rh^;102MWId208n?S`80OGem102?Shl208B4Q0<0UIFE0P24Q8@208n?S`80Hf=S0P1k
Ng/207YjNP80K6a/0P23Ph<206=SH`80K6a/0P1^KVh206=SH`80JVYZ0P1SHf<205YJFPH0GUiN0P1C
De<204e=C@80GUiN0P1QHF4205iNGP@0GEeM0P1/K6`808>3P`80YJFU0P2j^[X508:2PP80Rh^;0P2]
[Jd209fMW@80jNWY103bl_840?Ogm`80l_;b103gmoL20?;blP@0moOg0P3oool80?Ogm`80oooo=`3g
moL?0?ooo`003@3ooole0?Ogm`80oooo0P1OGel208>3P`80Y:BT0P25QHD208^;R`80Vi^K0P2b/[82
0;Zj^P80/;2`0P2][Jd208B4Q080Shn?0P2;Rh/409fMW@80Shn?0P1mOGd408n?S`80Q8B40`2EUID2
08B4Q080Shn?0P1SHf<207]kN`80NWYj0P1/K6`208>3P`80Hf=S0P1/K6`206i^KP80Hf=S0P1ZJVX2
06=SH`80FUYJ1P1NGUh205=CD`80CDe=0P1NGUh2065QH@80GUiN101MGEd206a/K0P0Ph>30P2UYJD2
0;Zj^PD0PX:20P2;Rh/20:f][@80WIfM0P3YjNT40?;blP@0moOg0P3bl_840?Ogm`80l_;b103gmoL2
0?ooo`P0moOg0P3ooolg0?Ogm`l0oooo000=0?ooocT0moOg0P23Ph<205=CD`80Vi^K0P2QXJ420:BT
Y080Vi^K102m_Kd20;:b/P80Ph>30P2EUID408B4Q080Shn?0P23Ph<207YjNP@0Rh^;0P1jNWX308B4
Q080NWYj0P24Q8@206=SH`80Ph>30P1fMWH207AdM080FUYJ0P1CDe<208>3P`80FUYJ0P1QHF4206=S
H`80HF5Q0P1MGEd405=CD`80ADE50P11@D4604e=C@80GEeM0P1fMWH206=SH`80K6a/0P2;Rh/20:FU
Y@80WIfM0P36a/H20;Zj^P80Y:BT0`2@T90207AdM080YJFU0P1dM7@20>WYj@@0oooo0P3bl_9C0?Og
m`l0oooo000=0?ooocT0moOg0P23Ph<205=CD`80Vi^K0P2QXJ420:BTY080Vi^K102m_Kd20;:b/P80
Ph>30P2EUID408B4Q080Shn?0P23Ph<207YjNP@0Rh^;0P1jNWX308B4Q080NWYj0P24Q8@206=SH`80
Ph>30P1fMWH207AdM080FUYJ0P1CDe<208>3P`80FUYJ0P1QHF4206=SH`80HF5Q0P1MGEd405=CD`80
ADE50P11@D4604e=C@80GEeM0P1fMWH206=SH`80K6a/0P2;Rh/20:FUY@80WIfM0P36a/H20;Zj^P80
Y:BT0`2@T90207AdM080YJFU0P1dM7@20>WYj@@0oooo0P3bl_9C0?Ogm`l0oooo000=0?ooocD0moOg
0P3bl_820?Ogm`80oooo0P25QHD204e=C@80Ng]k0P2<S8`209^KV`80^[Zj0P32`/820;:b/P80Ph>3
0P1dM7@209^KV`80Q8B40P2EUID209^KV`80Shn?0P1dM7@208^;R`80Ph>30`1/K6`408B4Q080K6a/
0P1kNg/208>3P`80NWYj0P1bLW8203/k>`80De=C0P1QHF4208>3P`@0GUiN0P15ADD205iNGP80CDe=
0P15ADD203/k>`80@D51100k>c/205=CD`80IVIV0P2;Rh/209fMW@80Shn?0P2MWId20;Zj^P80Vi^K
0P1ZJVX20820P0<0Shn?0P2;Rh/207IfMP80[Jf]303gmoL20?;blP80moOg0P3ooolF0?Ogm`80l_;b
4`3gmoL20?oooa`0moOg3`3oool000d0oooo=@3gmoL20?;blP80moOg0P3oool208F5Q@80CDe=0P1k
Ng/208b<S080Vi^K0P2j^[X20<;2`P80/[:b0P23Ph<207AdM080Vi^K0P24Q8@209FEU@80Vi^K0P2?
Shl207AdM080Rh^;0P23Ph<306a/K0@0Q8B40P1/K6`207]kN`80Ph>30P1jNWX2079bLP80>c/k0P1C
De<2065QH@80Ph>3101NGUh204E5A@80GUiN0P1=CDd204E5A@80>c/k0P11@D4403/k>`80De=C0P1V
IVH208^;R`80WIfM0P2?Shl209fMW@80^[Zj0P2KVi/206YZJP80P8200`2?Shl208^;R`80MWIf0P2]
[Jd<0?Ogm`80l_;b0P3gmoL20?oooaH0moOg0P3bl_8C0?Ogm`80oooo703gmoL?0?ooo`003@3oool:
0?Ogm`80l_;b;`3gmoL20=;BdP80KFe]0P1QHF4206YZJP80T92@0P2TY:@20;:b/P80_Kfm0P2;Rh/2
07AdM080Ph>30P2EUID407YjNP80Q8B40P1bLW8206a/K080OGem0`1jNWX2079bLP80M7Ad0P24Q8@2
07YjNP80K6a/0P23Ph<207]kN`80LW9b0P1/K6`405=CD`80JVYZ101NGUh206IVIP80GEeM0P1fMWH4
05eMG@80IVIV0P1fMWH20820P080Q8B40P2FUYH20:FUY@80bl_;0P2KVi/20:BTY080Ph>30P1CDe<2
07YjNP<0Rh^;102KVi/<0?Ogm`80oooo0P3gmoL20?;blPX0moOg0P3oool@0?Ogm`80oooo;@3gmoL?
0?ooo`003@3oool:0?Ogm`80l_;b;`3gmoL20=;BdP80KFe]0P1QHF4206YZJP80T92@0P2TY:@20;:b
/P80_Kfm0P2;Rh/207AdM080Ph>30P2EUID407YjNP80Q8B40P1bLW8206a/K080OGem0`1jNWX2079b
LP80M7Ad0P24Q8@207YjNP80K6a/0P23Ph<207]kN`80LW9b0P1/K6`405=CD`80JVYZ101NGUh206IV
IP80GEeM0P1fMWH405eMG@80IVIV0P1fMWH20820P080Q8B40P2FUYH20:FUY@80bl_;0P2KVi/20:BT
Y080Ph>30P1CDe<207YjNP<0Rh^;102KVi/<0?Ogm`80oooo0P3gmoL20?;blPX0moOg0P3oool@0?Og
m`80oooo;@3gmoL?0?ooo`003@3ooolm0?Ogm`80`l?30P20P80207MgM`80Jf][0P1ZJVX208b<S080
TY:B0P2m_Kd206a/K080LW9b0P22PX8208n?S`80NWYj0P1dM7@206=SH`@0HF5Q1@1/K6`207AdM080
NWYj101/K6`208>3P`80Rh^;0P1kNg/207YjNP80HF5Q0P23Ph<205iNGP80GEeM0P1jNWX207AdM080
K6a/0P1^KVh207IfMP80Ph>30P2?Shl20:FUY@80UIFE0P2MWId20;fm_@80Y:BT0P2QXJ44092@T080
HF5Q0P1mOGd2092@T0<0Rh^;0P25QHD20?ooo`80moOg103oool20?Ogm`80l_;b0P3oool20?;blP80
oooo0P3gmoL20?;blP80moOg0P3ooolP0?Ogm`80oooo8`3gmoL?0?ooo`003@3ooolm0?Ogm`80`l?3
0P20P80207MgM`80Jf][0P1ZJVX208b<S080TY:B0P2m_Kd206a/K080LW9b0P22PX8208n?S`80NWYj
0P1dM7@206=SH`@0HF5Q1@1/K6`207AdM080NWYj101/K6`208>3P`80Rh^;0P1kNg/207YjNP80HF5Q
0P23Ph<205iNGP80GEeM0P1jNWX207AdM080K6a/0P1^KVh207IfMP80Ph>30P2?Shl20:FUY@80UIFE
0P2MWId20;fm_@80Y:BT0P2QXJ44092@T080HF5Q0P1mOGd2092@T0<0Rh^;0P25QHD20?ooo`80moOg
103oool20?Ogm`80l_;b0P3oool20?;blP80oooo0P3gmoL20?;blP80moOg0P3ooolP0?Ogm`80oooo
8`3gmoL?0?ooo`003@3ooole0?Ogm`80oooo203gmoL20;6a/@80NWYj0P1kNg/207emO@80Rh^;0P2A
TI420:FUY@80[Jf]101bLW8408^;R`80M7Ad0P2;Rh/205iNGPD0Hf=S0P1fMWH207AdM080Ng]k0P1N
GUh208F5Q@80Ng]k0P2EUID208B4Q080Shn?0P2KVi/207AdM0@0IVIV101kNg/408n?S`@0UYJF102`
/;020:f][@80Q8B41023Ph<206IVIP80CDe=0P1NGUh208B4Q080Rh^;0P22PX8309fMW@80oooo1P3g
moL40?ooo`@0moOg0P3ooom?0?Ogm`l0oooo000=0?ooocD0moOg0P3oool80?Ogm`80/K6a0P1jNWX2
07]kN`80OGem0P2;Rh/2096AT@80YJFU0P2][Jd4079bLP@0Rh^;0P1dM7@208^;R`80GUiN1@1SHf<2
07IfMP80M7Ad0P1kNg/205iNGP80QHF50P1kNg/209FEU@80Q8B40P2?Shl209^KV`80M7Ad101VIVH4
07]kN`@0Shn?102FUYH40;2`/080[Jf]0P24Q8@408>3P`80IVIV0P1=CDd205iNGP80Q8B40P2;Rh/2
08:2PP<0WIfM0P3oool60?Ogm`@0oooo103gmoL20?ooodl0moOg3`3oool000d0oooo=@3gmoL20?;b
lP@0moOg0P3bl_840?Ogm`80_;bl0P1[Jf/207]kN`80T92@0P2KVi/20:BTY080[Jf]0P2b/[8207Yj
NP80Rh^;0P1/K6`208b<S080NWYj0P24Q8@207AdM0<0GUiN0P1LG5`205=CD`80K6a/0P1QHF4207em
O@80Ng]k0P2MWId209FEU@80bl_;0P3>c/h20;fm_@80YJFU0P2i^KT60;2`/0@0cLg=0P2h^;P20;Zj
^P80T92@0P1bLW8208:2PP80M7Ad0P1SHf<2065QH@80K6a/0P2?Shl209^KV`80Q8B40P25QHD30?oo
o`@0moOg0P3oool>0?Ogm`80l_;b103gmoL40?oood<0moOg3`3oool000d0oooo=@3gmoL20?;blP@0
moOg0P3bl_840?Ogm`80_;bl0P1[Jf/207]kN`80T92@0P2KVi/20:BTY080[Jf]0P2b/[8207YjNP80
Rh^;0P1/K6`208b<S080NWYj0P24Q8@207AdM0<0GUiN0P1LG5`205=CD`80K6a/0P1QHF4207emO@80
Ng]k0P2MWId209FEU@80bl_;0P3>c/h20;fm_@80YJFU0P2i^KT60;2`/0@0cLg=0P2h^;P20;Zj^P80
T92@0P1bLW8208:2PP80M7Ad0P1SHf<2065QH@80K6a/0P2?Shl209^KV`80Q8B40P25QHD30?ooo`@0
moOg0P3oool>0?Ogm`80l_;b103gmoL40?oood<0moOg3`3oool000d0oooo?@3gmoL20?ooo`@0moOg
0P3_knl208Z:RP80Ng]k0P1UIFD2092@T0@0^[Zj0P2d];@208b<S080UIFE0P2<S8`2096AT@80QHF5
0P2MWId30:f][@80Ph>30P1LG5`2079bLP80G5aL0P1jNWX209^KV`80[Jf]0P2TY:@2096AT@80`/;2
0P33`l<20<;2`P80bl_;0P3IfMT20=CDe080`/;20P2UYJD409^KV`80S8b<0P1kNg/207YjNP80M7Ad
0P1JFUX205iNGP80NWYj0P22PX8209fMW@80Q8B40P2KVi/70?Ogm`80l_;b103gmoL40?;blPH0moOg
0P3bl_8<0?Ogm`80l_;b?`3gmoL?0?ooo`003@3ooolm0?Ogm`80oooo103gmoL20>o_k`80RXZ:0P1k
Ng/206EUI@80T92@102j^[X20;Bd]080S8b<0P2EUID208b<S080TI6A0P25QHD209fMW@<0[Jf]0P23
Ph<205aLG080LW9b0P1LG5`207YjNP80Vi^K0P2][Jd20:BTY080TI6A0P32`/820<?3``80`/;20P3;
bl/20=WIf@80e=CD0P32`/820:FUY@@0Vi^K0P2<S8`207]kN`80NWYj0P1dM7@205YJFP80GUiN0P1j
NWX208:2PP80WIfM0P24Q8@209^KV`L0moOg0P3bl_840?Ogm`@0l_;b1P3gmoL20?;blP`0moOg0P3b
l_8o0?Ogm`l0oooo000=0?ooocd0moOg0P3oool60?Ogm`80oooo0P23Ph<206][J`80RHV90P2ATI42
0;:b/P80cLg=102b/[820<?3``80/K6a0P3@d=020<?3``<0[Jf]0P3De=@20=_Kf`80l?3`0P3Xj>P2
0=_Kf`80e=CD0P3Cdm<20<;2`P80d=3@1P3;bl/20=?Cd`80^[Zj0P2@T9020:f][@80T92@0P22PX84
08>3P`80K6a/0P1bLW8205mOG`80Q8B40P2@T90408^;R`80Q8B40P3oool40?Ogm`<0oooo0P3bl_88
0?Ogm`80l_;b203gmoL20?;blP@0moOg0P3oool40?Ogm`80l_;b103gmoL20?;blP80moOg0P3ooole
0?Ogm`l0oooo000=0?ooocd0moOg0P3oool60?Ogm`80oooo0P23Ph<206][J`80RHV90P2ATI420;:b
/P80cLg=102b/[820<?3``80/K6a0P3@d=020<?3``<0[Jf]0P3De=@20=_Kf`80l?3`0P3Xj>P20=_K
f`80e=CD0P3Cdm<20<;2`P80d=3@1P3;bl/20=?Cd`80^[Zj0P2@T9020:f][@80T92@0P22PX8408>3
P`80K6a/0P1bLW8205mOG`80Q8B40P2@T90408^;R`80Q8B40P3oool40?Ogm`<0oooo0P3bl_880?Og
m`80l_;b203gmoL20?;blP@0moOg0P3oool40?Ogm`80l_;b103gmoL20?;blP80moOg0P3ooole0?Og
m`l0oooo000=0?ooobT0moOg0P3ooolB0?Ogm`80oooo2P3gmoL20>3Ph080Jf][0P1hN7P209^KV`80
Zj^[0P33`l<20=3@d080f][J0P3AdM470=3@d080f][J0P3;bl/20<k>cP80dm?C0P3>c/h20=_Kf`80
hN7Q0P3Jf]X20=3@d080e=CD0P2j^[X20:FUY@80`/;20P2TY:@20:6QX@80YJFU0P1gMgL208>3P`80
K6a/0P1bLW8208>3P`80S8b<0P2TY:@20:FUY@80UIFE0P2;Rh/20:f][@@0moOg0P3bl_820?Ogm`<0
l_;b3P3gmoL20?;blR`0moOg0P3oool50?Ogm`80oooo0P3gmoL20?;blQP0moOg3`3oool000d0oooo
:@3gmoL20?oooa80moOg0P3oool:0?Ogm`80h>3P0P1[Jf/207QhN080Vi^K0P2[Zj/20<?3``80d=3@
0P3Jf]X20=7Ad@L0d=3@0P3Jf]X20<_;b`80c/k>0P3Cdm<20<k>cP80fm_K0P3QhN420=[JfP80d=3@
0P3De=@20;Zj^P80YJFU0P32`/820:BTY080XJ6Q0P2UYJD207MgM`80Ph>30P1/K6`2079bLP80Ph>3
0P2<S8`20:BTY080YJFU0P2EUID208^;R`80[Jf]103gmoL20?;blP80moOg0`3bl_8>0?Ogm`80l_;b
;03gmoL20?ooo`D0moOg0P3oool20?Ogm`80l_;b603gmoL?0?ooo`003@3ooolY0?Ogm`80oooo4P3g
moL20?ooo`X0moOg0P3Ph>0206][J`80N7Qh0P2KVi/20:^[Z`80`l?30P3@d=020=[JfP80dM7A1`3@
d=020=[JfP80bl_;0P3>c/h20=?Cd`80c/k>0P3Kfm/20>7Qh@80f][J0P3@d=020=CDe080^[Zj0P2U
YJD20<;2`P80Y:BT0P2QXJ420:FUY@80MgMg0P23Ph<206a/K080LW9b0P23Ph<208b<S080Y:BT0P2U
YJD209FEU@80Rh^;0P2][Jd40?Ogm`80l_;b0P3gmoL30?;blPh0moOg0P3bl_8/0?Ogm`80oooo1@3g
moL20?ooo`80moOg0P3bl_8H0?Ogm`l0oooo000=0?ooocT0moOg0P3oool20?Ogm`@0oooo0P3gmoL2
0?ooo`@0moOg0P3oool20>WYj@80S8b<0P29RHT209:BTP@0^[Zj0P33`l<20<S8b080d=3@2@3Jf]X2
0>SXj080gmoO0P3Kfm/20=[JfP80hN7Q0P3De=@20=3@d080`l?30P37alL20:6QX@80TY:B0P2UYJD2
08:2PP80Ph>30P1jNWX2092@T080Jf][0P2ATI420:BTY080YJFU0P2QXJ42096AT@80YJFU0P3Ph>06
0?Ogm`80l_;b1`3gmoL20?ooo`80moOg0P3oool40?Ogm`80l_;b4P3gmoL20?ooo`h0moOg0P3oool8
0?Ogm`80oooo2@3gmoL20?oooaX0moOg3`3oool000d0oooo>@3gmoL20?ooo`80moOg103oool20?Og
m`80oooo103gmoL20?ooo`80jNWY0P2<S8`208V9R@80TY:B102j^[X20<?3``80b<S80P3@d=090=[J
fP80j>SX0P3Ogml20=_Kf`80f][J0P3QhN420=CDe080d=3@0P33`l<20<O7a`80XJ6Q0P2BTY820:FU
Y@80PX:20P23Ph<207YjNP80T92@0P1[Jf/2096AT@80Y:BT0P2UYJD20:6QX@80TI6A0P2UYJD20>3P
h0H0moOg0P3bl_870?Ogm`80oooo0P3gmoL20?ooo`@0moOg0P3bl_8B0?Ogm`80oooo3P3gmoL20?oo
o`P0moOg0P3oool90?Ogm`80oooo6P3gmoL?0?ooo`003@3ooom70?Ogm`80l_;b0P3gmoL20?ooo`@0
moOg0P2MWId208>3P`80S8b<0P2l_;`20<g=c@@0f][J0`3IfMT20=CDe080cLg=0P3Kfm/20=7Ad@80
cLg=0P33`l<20;:b/P80Y:BT0P2KVi/20:f][@80/[:b0P2QXJ42096AT@80Kfm_0P25QHD20:6QX@80
TI6A102b/[820;Zj^P80/[:b0P2BTY820;:b/P80l_;b303gmoL20?ooo`T0moOg0P3bl_840?Ogm`80
oooo0P3gmoL20?ooo`H0moOg0P3bl_820?Ogm`80oooo2P3gmoL20?oooaL0moOg1P3oool20?;blP`0
moOg0P3oool:0?Ogm`l0oooo000=0?ooodL0moOg0P3bl_820?Ogm`80oooo103gmoL209fMW@80Ph>3
0P2<S8`20;bl_080cLg=103Jf]X30=WIf@80e=CD0P3=cLd20=_Kf`80dM7A0P3=cLd20<?3``80/[:b
0P2TY:@209^KV`80[Jf]0P2b/[820:6QX@80TI6A0P1_Kfl208F5Q@80XJ6Q0P2ATI440;:b/P80^[Zj
0P2b/[8209:BTP80/[:b0P3bl_8<0?Ogm`80oooo2@3gmoL20?;blP@0moOg0P3oool20?Ogm`80oooo
1P3gmoL20?;blP80moOg0P3oool:0?Ogm`80oooo5`3gmoL60?ooo`80l_;b303gmoL20?ooo`X0moOg
3`3oool000d0oooo9`3gmoL20?oooaX0moOg0P3bl_820?ooo`@0moOg0P3oool:0?Ogm`80YJFU0P2M
WId20;Zj^P80_;bl0`33`l<40=_Kf`80f][J103Kfm/20=[JfP@0`l?30P2][Jd20:^[Z`80WIfM0P2j
^[X20=3@d080YJFU0P33`l<20<g=c@80`l?30P2UYJD209^KV`80`/;20P3YjNT60?ooo`H0moOg0P3o
ool;0?Ogm`80oooo303gmoL20?;blPh0moOg0P3oool20?Ogm`X0oooo2P3gmoL20?ooo`L0moOg103o
ool20?Ogm`80oooo603gmoL?0?ooo`003@3ooolW0?Ogm`80oooo6P3gmoL20?;blP80oooo103gmoL2
0?ooo`X0moOg0P2UYJD209fMW@80^[Zj0P2l_;`30<?3``@0fm_K0P3Jf]X40=_Kf`80f][J1033`l<2
0:f][@80Zj^[0P2MWId20;Zj^P80d=3@0P2UYJD20<?3``80cLg=0P33`l<20:FUY@80Vi^K0P32`/82
0>WYj@H0oooo1P3gmoL20?ooo`/0moOg0P3oool<0?Ogm`80l_;b3P3gmoL20?ooo`80moOg2P3oool:
0?Ogm`80oooo1`3gmoL40?ooo`80moOg0P3ooolH0?Ogm`l0oooo000=0?ooobD0moOg0P3bl_8Z0?Og
m`80oooo0P3gmoL20?ooo`@0moOg0P2a/K420:^[Z`<0`l?30P2][Jd20<;2`P@0dM7A0P3Ogml20=_K
f`80j>SX0P3`l?020>SXj080f][J0P3@d=020=[JfP80dM7A0P3@d=020:f][@80Y:BT0P2j^[X20=3@
d080jNWY103gmoL40?ooo`80l_;b3P3gmoL30?;blP@0moOg0P3bl_860?Ogm`80l_;b3P3gmoL20?;b
lPh0moOg0P3bl_820?Ogm`80oooo0P3bl_8:0?Ogm`<0l_;b203gmoL20?;blQH0moOg3`3oool000d0
oooo9@3gmoL20?;blRX0moOg0P3oool20?Ogm`80oooo103gmoL20;6a/@80Zj^[0`33`l<20:f][@80
`/;2103AdM420=oOg`80fm_K0P3Xj>P20?3`l080j>SX0P3Jf]X20=3@d080f][J0P3AdM420=3@d080
[Jf]0P2TY:@20;Zj^P80d=3@0P3YjNT40?Ogm`@0oooo0P3bl_8>0?Ogm`<0l_;b103gmoL20?;blPH0
moOg0P3bl_8>0?Ogm`80l_;b3P3gmoL20?;blP80moOg0P3oool20?;blPX0moOg0`3bl_880?Ogm`80
l_;b5P3gmoL?0?ooo`003@3ooolW0?Ogm`80oooo8P3gmoL20?;blP@0moOg0P3oool40?;blPH0moOg
1`3bl_840>WYj@80h>3P0P3`l?020>SXj080d=3@1033`l<20=3@d080dM7A103=cLd20=;BdP80jNWY
0P3bl_8:0?Ogm`@0oooo0P3gmoL60?ooo`/0moOg103bl_8<0?Ogm`80l_;b0P3gmoL20?ooo`80l_;b
1P3gmoL20?oooa80moOg0P3oool20?Ogm`80oooo4@3gmoL20?ooo`h0moOg0P3oool60?Ogm`l0oooo
000=0?ooobL0moOg0P3ooolR0?Ogm`80l_;b103gmoL20?ooo`@0l_;b1P3gmoL70?;blP@0jNWY0P3P
h>020?3`l080j>SX0P3@d=040<?3``80d=3@0P3AdM440<g=c@80d];B0P3YjNT20?;blPX0moOg103o
ool20?Ogm`H0oooo2`3gmoL40?;blP`0moOg0P3bl_820?Ogm`80oooo0P3bl_860?Ogm`80oooo4P3g
moL20?ooo`80moOg0P3ooolA0?Ogm`80oooo3P3gmoL20?ooo`H0moOg3`3oool000d0oooo:@3gmoL2
0?;blQH0moOg0P3oool20?;blPP0moOg0P3bl_8C0?Ogm`80oooo2P3gmoL80?;blP80oooo303gmoL4
0?ooo`H0moOg0P3oool80?Ogm`80l_;b0P3gmoL20?ooo`D0moOg0P3oool60?Ogm`80oooo0P3gmoL2
0?ooo`80moOg0P3oool20?Ogm`80l_;b103gmoL20?;blQH0moOg0P3bl_840?Ogm`80oooo2@3gmoL2
0?oooa`0moOg3`3oool000d0oooo:@3gmoL20?;blQH0moOg0P3oool20?;blPP0moOg0P3bl_8C0?Og
m`80oooo2P3gmoL80?;blP80oooo303gmoL40?ooo`H0moOg0P3oool80?Ogm`80l_;b0P3gmoL20?oo
o`D0moOg0P3oool60?Ogm`80oooo0P3gmoL20?ooo`80moOg0P3oool20?Ogm`80l_;b103gmoL20?;b
lQH0moOg0P3bl_840?Ogm`80oooo2@3gmoL20?oooa`0moOg3`3oool000d0ooooB`3gmoL20?;blP@0
moOg0P3bl_820?ooo`H0moOg0P3bl_820?Ogm`<0l_;b103gmoL20?ooo`80l_;b303gmoL20?ooo`@0
moOg0P3bl_8<0?Ogm`80oooo0P3gmoL20?ooo`H0moOg0P3bl_820?ooo`80moOg103ooolC0?Ogm`80
oooo103bl_820?Ogm`80l_;b403gmoL20?ooo``0moOg0P3oool70?Ogm`80l_;b0P3gmoL40?oooa00
moOg0P3oool20?Ogm`80l_;b0P3gmoL?0?ooo`003@3ooom;0?Ogm`80l_;b103gmoL20?;blP80oooo
1P3gmoL20?;blP80moOg0`3bl_840?Ogm`80oooo0P3bl_8<0?Ogm`80oooo103gmoL20?;blP`0moOg
0P3oool20?Ogm`80oooo1P3gmoL20?;blP80oooo0P3gmoL40?oooa<0moOg0P3oool40?;blP80moOg
0P3bl_8@0?Ogm`80oooo303gmoL20?ooo`L0moOg0P3bl_820?Ogm`@0oooo403gmoL20?ooo`80moOg
0P3bl_820?Ogm`l0oooo000=0?ooob/0moOg0P3ooolR0?Ogm`@0oooo1P3gmoL20?;blP@0moOg0`3o
ool60?Ogm`80oooo103gmoL20?ooo`H0moOg0P3bl_8<0?Ogm`80l_;b0P3gmoL20?ooo`@0moOg103o
ool60?Ogm`80l_;b103gmoL20?;blP<0moOg0P3oool80?Ogm`80oooo4P3gmoL20?ooo`80l_;b203g
moL20?ooo`@0moOg0P3oool40?Ogm`80l_;b3@3gmoL20?;blP80oooo503gmoL20?ooo`80moOg3`3o
ool000d0oooo:`3gmoL20?ooob80moOg103oool60?Ogm`80l_;b103gmoL30?ooo`H0moOg0P3oool4
0?Ogm`80oooo1P3gmoL20?;blP`0moOg0P3bl_820?Ogm`80oooo103gmoL40?ooo`H0moOg0P3bl_84
0?Ogm`80l_;b0`3gmoL20?ooo`P0moOg0P3ooolB0?Ogm`80oooo0P3bl_880?Ogm`80oooo103gmoL2
0?ooo`@0moOg0P3bl_8=0?Ogm`80l_;b0P3ooolD0?Ogm`80oooo0P3gmoL?0?ooo`003@3ooolS0?Og
m`80oooo103gmoL20?;blP@0moOg0P3bl_8F0?Ogm`80l_;b0P3oool60?Ogm`80l_;b203gmoL20?;b
lP80oooo0`3bl_860?Ogm`80oooo1P3gmoL20?ooo`80moOg0P3bl_840?Ogm`80l_;b503gmoL20?oo
o`@0moOg0P3bl_820?Ogm`80oooo1`3gmoL20?;blP@0oooo103gmoL20?;blP80oooo203gmoL20?oo
o`H0moOg0P3oool60?Ogm`80oooo103gmoL20?ooo`@0moOg103oool40?Ogm`80oooo1`3gmoL20?;b
lQ00moOg0P3oool:0?Ogm`l0oooo000=0?ooob<0moOg0P3oool40?Ogm`80l_;b103gmoL20?;blQH0
moOg0P3bl_820?ooo`H0moOg0P3bl_880?Ogm`80l_;b0P3oool30?;blPH0moOg0P3oool60?Ogm`80
oooo0P3gmoL20?;blP@0moOg0P3bl_8D0?Ogm`80oooo103gmoL20?;blP80moOg0P3oool70?Ogm`80
l_;b103oool40?Ogm`80l_;b0P3oool80?Ogm`80oooo1P3gmoL20?ooo`H0moOg0P3oool40?Ogm`80
oooo103gmoL40?ooo`@0moOg0P3oool70?Ogm`80l_;b403gmoL20?ooo`X0moOg3`3oool000d0oooo
;@3gmoL20?ooob`0moOg0P3bl_870?Ogm`80oooo0P3bl_820?Ogm`80oooo203gmoL20?ooo`80moOg
0P3oool<0?Ogm`80l_;b0P3gmoL20?oooa/0moOg0P3bl_8<0?Ogm`80l_;b0P3oool20?;blP80oooo
103gmoL20?ooo`@0moOg0P3bl_8H0?Ogm`<0l_;b4P3gmoL20?;blP80oooo2P3gmoL?0?ooo`003@3o
ool]0?Ogm`80oooo;03gmoL20?;blPL0moOg0P3oool20?;blP80moOg0P3oool80?Ogm`80oooo0P3g
moL20?ooo``0moOg0P3bl_820?Ogm`80oooo6`3gmoL20?;blP`0moOg0P3bl_820?ooo`80l_;b0P3o
ool40?Ogm`80oooo103gmoL20?;blQP0moOg0`3bl_8B0?Ogm`80l_;b0P3oool:0?Ogm`l0oooo000=
0?ooobT0moOg0P3ooolJ0?Ogm`80l_;b503gmoL40?;blPT0moOg0P3bl_840?ooo`@0moOg0P3oool2
0?;blPX0moOg0P3oool20?Ogm`@0l_;b103gmoL20?ooo`80l_;b0P3gmoL20?ooo`80moOg0P3oool4
0?Ogm`80oooo0P3gmoL30?ooo`X0moOg0P3oool:0?Ogm`80l_;b0P3gmoL20?ooo`H0moOg0P3oool6
0?Ogm`80oooo0P3gmoL20?ooo`@0moOg0P3oool20?;blP/0moOg0P3oool40?Ogm`80oooo4P3gmoL4
0?;blPl0oooo000=0?ooobT0moOg0P3ooolJ0?Ogm`80l_;b503gmoL40?;blPT0moOg0P3bl_840?oo
o`@0moOg0P3oool20?;blPX0moOg0P3oool20?Ogm`@0l_;b103gmoL20?ooo`80l_;b0P3gmoL20?oo
o`80moOg0P3oool40?Ogm`80oooo0P3gmoL30?ooo`X0moOg0P3oool:0?Ogm`80l_;b0P3gmoL20?oo
o`H0moOg0P3oool60?Ogm`80oooo0P3gmoL20?ooo`@0moOg0P3oool20?;blP/0moOg0P3oool40?Og
m`80oooo4P3gmoL40?;blPl0oooo000=0?ooobd0moOg0P3ooolH0?Ogm`80oooo103gmoL20?;blP80
moOg0P3bl_8<0?Ogm`<0oooo3P3gmoL20?;blP80oooo5P3gmoL20?;blP80moOg0P3oool20?Ogm`80
oooo1P3gmoL20?;blP80oooo0P3bl_830?ooo`H0moOg0P3bl_8@0?Ogm`80oooo103bl_860?Ogm`80
l_;b203gmoL20?ooo`h0moOg0`3ooolH0?Ogm`80l_;b0P3gmoL20?ooo`80moOg3`3oool000d0oooo
;@3gmoL20?oooaP0moOg0P3oool40?Ogm`80l_;b0P3gmoL20?;blP`0moOg0`3oool>0?Ogm`80l_;b
0P3ooolF0?Ogm`80l_;b0P3gmoL20?ooo`80moOg0P3oool60?Ogm`80l_;b0P3oool20?;blP<0oooo
1P3gmoL20?;blQ00moOg0P3oool40?;blPH0moOg0P3bl_880?Ogm`80oooo3P3gmoL30?oooaP0moOg
0P3bl_820?Ogm`80oooo0P3gmoL?0?ooo`003@3oool_0?Ogm`80l_;b403gmoL20?;blP80oooo103g
moL20?;blP@0moOg103bl_860?Ogm`@0oooo1`3gmoL20?;blPP0moOg0P3bl_840?Ogm`80oooo0P3g
moL20?;blP80oooo2P3gmoL20?ooo`80moOg0P3oool20?Ogm`80l_;b0P3oool20?Ogm`80l_;b0P3g
moL20?;blP@0moOg0P3oool50?Ogm`80l_;b103gmoL20?ooo`80l_;b0P3oool20?Ogm`80l_;b0P3g
moL20?;blP80oooo0P3gmoL20?ooo`H0moOg0P3bl_8O0?Ogm`80l_;b703gmoL?0?ooo`003@3oool_
0?Ogm`80l_;b403gmoL20?;blP80oooo103gmoL20?;blP@0moOg103bl_860?Ogm`@0oooo1`3gmoL2
0?;blPP0moOg0P3bl_840?Ogm`80oooo0P3gmoL20?;blP80oooo2P3gmoL20?ooo`80moOg0P3oool2
0?Ogm`80l_;b0P3oool20?Ogm`80l_;b0P3gmoL20?;blP@0moOg0P3oool50?Ogm`80l_;b103gmoL2
0?ooo`80l_;b0P3oool20?Ogm`80l_;b0P3gmoL20?;blP80oooo0P3gmoL20?ooo`H0moOg0P3bl_8O
0?Ogm`80l_;b703gmoL?0?ooo`003@3ooom90?Ogm`80oooo0P3gmoL20?ooo`80moOg0P3bl_840?oo
o`80moOg0P3bl_820?oooa40moOg103oool80?Ogm`80oooo303gmoL20?ooo`X0moOg203oool90?Og
m`80l_;b0P3gmoL20?ooo`H0moOg203oool<0?Ogm`@0oooo203gmoL20?;blP`0moOg0P3oool90?Og
m`80oooo203gmoL20?ooo`80moOg0P3oool40?Ogm`80oooo103gmoL?0?ooo`003@3ooom90?Ogm`80
oooo0P3gmoL20?ooo`80moOg0P3bl_840?ooo`80moOg0P3bl_820?oooa40moOg103oool80?Ogm`80
oooo303gmoL20?ooo`X0moOg203oool90?Ogm`80l_;b0P3gmoL20?ooo`H0moOg203oool<0?Ogm`@0
oooo203gmoL20?;blP`0moOg0P3oool90?Ogm`80oooo203gmoL20?ooo`80moOg0P3oool40?Ogm`80
oooo103gmoL?0?ooo`003@3ooolU0?Ogm`80oooo0P3gmoL20?ooo`@0moOg0P3bl_820?Ogm`80l_;b
2P3gmoL20?ooo``0moOg0P3bl_820?Ogm`80l_;b0P3gmoL20?;blPl0moOg0P3bl_8<0?Ogm`80oooo
203gmoL20?ooo`80l_;b0P3gmoL40?oooaH0moOg0P3oool;0?Ogm`80l_;b303gmoL20?ooo`80moOg
0P3oool40?Ogm`80l_;b0P3gmoL20?ooo`H0moOg0P3oool@0?Ogm`<0l_;b0P3gmoL20?;blQ`0moOg
3`3oool000d0oooo9@3gmoL20?ooo`80moOg0P3oool40?Ogm`80l_;b0P3gmoL20?;blPX0moOg0P3o
ool<0?Ogm`80l_;b0P3gmoL20?;blP80moOg0P3bl_8?0?Ogm`80l_;b303gmoL20?ooo`P0moOg0P3o
ool20?;blP80moOg103ooolF0?Ogm`80oooo2`3gmoL20?;blP`0moOg0P3oool20?Ogm`80oooo103g
moL20?;blP80moOg0P3oool60?Ogm`80oooo403gmoL30?;blP80moOg0P3bl_8L0?Ogm`l0oooo000=
0?ooobD0moOg0P3oool40?Ogm`80oooo703gmoL20?;blP`0moOg0P3oool20?Ogm`80oooo5@3gmoL4
0?ooo`H0moOg0P3bl_840?Ogm`@0oooo5P3gmoL70?oooaH0moOg1P3ooolN0?Ogm`80oooo0P3gmoL3
0?;blP80moOg0P3bl_840?Ogm`80oooo103gmoL20?ooo`80l_;b3P3gmoL?0?ooo`003@3ooolU0?Og
m`80oooo103gmoL20?oooa`0moOg0P3bl_8<0?Ogm`80oooo0P3gmoL20?oooaD0moOg103oool60?Og
m`80l_;b103gmoL40?oooaH0moOg1`3ooolF0?Ogm`H0oooo7P3gmoL20?ooo`80moOg0`3bl_820?Og
m`80l_;b103gmoL20?ooo`@0moOg0P3oool20?;blPh0moOg3`3oool00?l0oooo8@3oool00?l0oooo
8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo
8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool006P0oooo
0T00002f0?ooo`00JP3oool00d000000oooo0?ooo`2c0?ooo`00G03oool3@00000<0oooo0d000003
0?ooo`=000001@3oool014000000oooo0?ooo`3oool3@00000D0oooo00=000000?ooo`3oool01`3o
ool2@00000030?oood00001000000080oooo0T0000000`3ooom00000@00000020?ooo`03@000003o
ool0oooo009000000P3oool3@00000070?oood0000100000@000003ooom000000?ooo`03@00000<0
oooo0T0000001P3ooom000000?oood000000oooo@0000080oooo0T00001Y0?ooo`00G@3oool00d00
0000oooo0?ooo`030?ooo`05@000003oool0oooo0?oood0000000P3oool00d000000oooo0?ooo`07
0?ooo`03@000003oool0oooo00l0oooo00M000000?ooo`3oool0oooo@000003ooom000000080oooo
00=000000?oood0000000P3oool00d000000oooo@00000020?ooo`03@000003ooom0000000@0oooo
00A000000?ooo`3ooom000000P3oool01D000000oooo0?ooo`3ooom000000080oooo0T0000001P3o
oom000000?oood000000oooo@00006/0oooo001M0?ooo`03@000003oool0oooo00<0oooo00E00000
0?ooo`3oool0oooo@00000020?ooo`03@000003oool0oooo00P0oooo00=000000?ooo`3oool03P3o
ool01d000000oooo@000003ooom000000?oood0000000P3oool00d000000oooo@00000020?ooo`03
@000003ooom000000080oooo00=000000?oood000000103oool014000000oooo0?oood0000020?oo
o`05@000003oool0oooo0?oood0000000P3oool2@00000050?oood000000oooo@000003oool00d00
001Y0?ooo`00G@3oool2@00000<0oooo0T0000040?ooo`=000002P3oool00d000000oooo0?ooo`0>
0?ooo`90000000<0oooo@000040000000P3oool2@00000030?oood0000100000009000000`3oool2
@0000080oooo0d0000020?ooo`=000000P3oool4@0000080oooo0T0000001@3ooom00000@000003o
oom000000080oooo0d00001Y0?ooo`00G@3oool014000000oooo0?oood00000C0?ooo`03@000003o
oom0000000l0oooo0T0000000`3ooom00000@000000E0?ooo`03@000003oool0oooo07d0oooo001L
0?ooo`E000000P3oool00d000000oooo0?ooo`0?0?ooo`03@000003oool0oooo00h0oooo0T000000
0`3ooom00000@000000D0?ooo`900000O`3oool00?l0oooo8@3oool00?l0oooo8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-6.47761, -2.56068, 0.491133, 
  0.491133}}]
}, Open  ]],

Cell[TextData[{
  StyleBox["\t",
    FontFamily->"Times New Roman",
    FontSize->10.5],
  StyleBox["Thus, we can handle the monochrome image data by installing the \
command \[OpenCurlyDoubleQuote]RGBsplit.exe\[CloseCurlyDoubleQuote]. However, \
it must be noted here that the monochrome image format will greatly depend on \
a processing tool. In this textbook, we worked out a sample monochrome image \
\[OpenCurlyDoubleQuote]BF001M.bmp\[CloseCurlyDoubleQuote] form the color \
image data \[OpenCurlyDoubleQuote]BF001.bmp\[CloseCurlyDoubleQuote] by a \
popular commercial/shareware base image drawing software \
\[OpenCurlyDoubleQuote]PaintShopPro\[CloseCurlyDoubleQuote] for the Widows \
95, 98 and NT versions.\n\tThe other way to obtain a monochrome image is to \
compose the monochrome images from the red, green and blue color components \
shown in Fig.1. We take up here the two types of monochrome images. One is \
the y component intensity of the yjk style, and the other is the NTSC style \
used in the televisions. Figure 3 shows both of the synthesized yjk and NTSC \
types monochrome images from the color components shown in Fig.1.",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell[CellGroupData[{

Cell[BoxData[
    \(yjk = \((\  .5*\ red +  .25*green +  .125*blue)\); \n
    tvM = \(( .3\ *\ red +  .59*green +  .11*blue)\); \n
    yjkG = ListDensityPlot[yjk, Mesh -> False, \ Frame -> False, \n\t\t\t
        PlotLabel -> "\<Intensity y of yjk style\>", \n\t\t\t
        DisplayFunction -> Identity]; \n
    tvMG = ListDensityPlot[tvM, Mesh -> False, \ Frame -> False, \n\t\t
        PlotLabel -> "\<NTSC style\>", \n\t\tDisplayFunction -> Identity]; \n
    Show[GraphicsArray[{yjkG, tvMG}], \n\t\t
      PlotLabel -> "\<Fig.3. Two types of monochrome images\>", \n\t\t
      ImageSize -> {300, 150}]; \)], "Input",
  CellLabel->"In[28]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .47619 
%%ImageSize: 300 150 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0113379 0.47619 [
[.5 .48869 -113 0 ]
[.5 .48869 113 12.5625 ]
[ 0 0 0 0 ]
[ 1 .47619 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .48869 -174 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Fig) show
81.000000 12.812500 moveto
(.3) show
93.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(.) show
105.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Two) show
129.000000 12.812500 moveto
(types) show
165.000000 12.812500 moveto
(of) show
183.000000 12.812500 moveto
(monochrome) show
249.000000 12.812500 moveto
(images) show
285.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
0 0 m
1 0 L
1 .47619 L
0 .47619 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0113379 0.477324 0.464853 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00751202 0.0192308 0.00751202 [
[.5 1.0125 -74 0 ]
[.5 1.0125 74 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -135 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Intensity) show
123.000000 12.812500 moveto
(y) show
135.000000 12.812500 moveto
(of) show
153.000000 12.812500 moveto
(yjk) show
177.000000 12.812500 moveto
(style) show
207.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
128 string
128 128 8 [128 0 0 128 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
F1F3F7F7F1F3EEEEF7EEF3DEDEDEDFE2DFDFDFDFDFF3EFA6
D6DFD6D6D2D9D9D1D9DAD9DAD2D2D9D9DDDDDADAD9D9D9DA
D3DADADAE2E2E2E2E2E2E2DDE2DADAE0E2DADADADADAD9D9
D9D9DADAD6DADAD9DADAD9EAF3EAAFD2D2D9D9D2D2D2D6D6
D6D6D6D6DEDDDBDDE6E2E6E6E6DFE6DED7D6C9C9D2D2D1C9
E6E4C5DAECF5F7F1
F1F5F5EEF3F7F7F1F1F7F3EEDFDFDFDFDFDFDFDEDEDEEFBE
DADED7D6D6D2D2D2D5D9DAD9DAD9D5DADEDADAD9D9D3D5D9
D9D2D9DAD9DADDE0DADAE2DADAE2DADADADADAE0DADAD9D9
DADADADADAD6D2DADAD9DAD9EAF3BFB5D9D9D9D2D2D2D2D2
D9DADADADDDADEDADEDEDFDFDFE6DFDFD6D7D6D6D2D2D6EB
ECD1CFD2ECF5F1F3
EEEEEEF3F1F1F1F3F1F1F7F7F5DFDEDEDEE0DEDEDBDEECEF
9FD6DBD7D2CED2D9D9D9DAD9DAD9D2D3DDDDDAD9D5D5D1D1
CECECED5D9DADADDDADADADAD9DADADEE2E2DDE0E2DADADA
DADADADADAD9DADADADADADAD9DFF3EAA5D2D2D2D9D6D2D2
D9D2D2DADEDDDEDDDEDEDFE2E6E2DFDADBD6DAD6D6DADFDE
EBDED1D2E2EEF7F3
F3F1F5F7F1F7F7EEF7F7F3F1F3EEEEE6DBDEDADADADADAEF
E2C7D6D7D7D2D2D2D2D2D9DADAD9D2D2D9DADADAD5D9D1CE
D1D1CECDD2D9D9DADAD9DAD9D9D9DDE6E2E2E2E6E2E2DDE2
E2DADADBDBDBDADBDBDADADADADADFF3EAB5DADADADADADD
DADADBDADDDADEDBDEDFE6E2E2DFE2DBDBD7DED7ECDFDEEB
D1E2D6D1ECECECF3
F1F5F1F5F7F5F5F1F7F7F7F7F3F7F1F3E6DEE2DADDDAE2EF
EFC7DADBDAD2D2D2D9D2D2D9D9DAD9D9DAD9D5D5D5D9D9D9
D9D9D5CED1D2D9D3D3D3D9DADADADADAE2DADAE6E6DBE2E0
E2E0DADEDEDBDBDEDEDEDADEDADADADFF3C5CCDADDDDDDDA
DADADDDEDDDEE2DEDEE2E6E2E2E2DFDFDFD7E2EEECEBEBEE
DAECD1D1ECF7F3EE
F1F5EEF5F1F3F5F7EEF5F5EEF7F7F5F7F5E6DEE2DEDEDEDF
EFEBDADEDED7D6D2D2D9D6DADAD2D2D9D2CED5D5D1D9D9D9
DAD9DADAD3CECED5CED9D2D9DADADADADAE0E2E2DADFDEDE
DEE2DEE2DEDFDEDBDEDBDBDBDADDDADADFF3D2CCDADEDEDD
DBDDDDE2E2E2E2DEE2DFDFE2E2E2DFD7D2D1DFEBF3D6DFD6
DFECD2DFF5F5F5EE
F1F7F7F7EEF7EEF5F5F7EEF7F7F1F7F7F7F7F3E2E2E6E2E6
E6F3E0DBDFDFDAD7D6D2D2D1D1D2CDC6CDCDCDD1CDD9DADD
DDDDDDE2D9D9CED5D1D5CED1D2D3D9D9DADADDDADADADADA
DBDADADEDEDBDBDBDADADADADAD6DADAD6E2F3EAD6DADADA
D9DDE0E2E2DEE2DEE6DFE2E2E2D7D6C7BDD2ECE2EED7DADE
DADACFECF5F3F7F1
F1F3F5F5F5F7F5F7F1F1EEF1F1F7F5F7F7F7F5F1ECEAEAEA
E6E6F3E2A8DFDBDAD2D2D2D2D1C6C6CDCDCDCDCDCDD2D9DA
DDDDDDE2DADAD3CECDCDCED2CECDCDCED2D2D2D9D2D2D5D2
D9D2D9D6D2D6D9D9D2D2D2D2D2D2D2D9D2D2E0EFD7D6D9DA
DADADADEE2DEDEE6E6DFDFDFD6D2B9BFBDD6DFD6C5D2D9CF
DFD7D1EBF5EEF3F1
F1F7F1F7F7F7F1F3F5F5F7F5F1EEF7F5F7F7F1F7F1F7F5F5
F7F7F5F5F3C9D6DAD6D2D2D2CED1C6D1D1D5D9D9D5CDD5D9
DDDDDDDDE2DDD9D2D5D9D3D5D5D2D2CDCDC5C6C5C1C6C5C5
C5C1C5C5C6C6C6C6C6C6C6D1CED1D1D1CECDD1C6DCDCC0B5
C6D2D2DADADADEDFDFE2DFD7AEB8C5C1C5C5D7D6D2CFD1E2
DAD1E0EBF1F5EEEE
F7F5F7F3F7F7F7F5F5EEF3F1F1F3F7F1EEF7F1F7F5F7F5F1
F7F5F5F3F7F1D1B9DED2C7D2D2D1C6C6C6CDD1D5D5CDD1D9
D9E2DDE2DDDADAD5D5D5D5D9D5D9D9D9D5D9D5D5D1CED1CE
CECED1CECED5D1D5D2D2D9D9CED9D9D9D2D9D2D2D5DBDADC
D275CEC7D2D6D6D7C0A49F9FABC5CFD2C5CFD1D2DAD6C5E2
DEC5E6E2F3F5F7F1
EEF1F7F1F5EEF1F5F5F7EEF5F7F7F5F5F5F7F5F7F5F7F1F5
F5F1F7F1F5F5D1B8C6BDC7D1D1D1D1D2C6CDD1D5D5CDCFD9
DAD9DADDDDDDDDD9D5D5D9D9D9D9D9D9D9D5D3D9D9D9D9D2
D1D5D5D9D9D5D5D5D2D9D9D9D9D9D5D9D5D9D9DAD9D2DAD9
DAD5E0C0A8A8BDA29FAB9FA4B8B8CFC6BFEBCFCFD2C0DFE6
D1E2D7EEECEEEEF7
F7F1F3F7F1F7F7EEF3F3F7F5F7F1F7F1F5F5F7F1F7F7F7F7
F1F1EEEEF5EED7D6AEBFBFAFD1D2CED1C7CFD1CDD5CFCFD9
D9D9DADADDD9DDD9D9D5D5D9D9D9D9D9D9D9D9D3D5D5D9D9
D9D1D5D2D3D5D9D9D3D9D9D9D9D5D5D9D2D9D1D9D9D9D9D2
D2D2DADCDCC9868AA49FA4AEAEAFAEBDC6E2B8C3D6C0D7DE
CFEEEBEEEEF1F1F7
F1F7F7F1F1F7F3F7F7F7F1F7F7F5F3F7F7F7F7F3F5F7F7F5
F1F1F5F1F1F1DCD7C0AEBF9E8AC7D1CECED1CED1D2CDD1D9
D9D9D9D9DDD9D9D9D9D9D9D9D9D9DAD9D9D9D9D5D5D5D9D5
D5D9D1D3D5D5D5D1D2D9DAD9D9D3D9D9D5D5D5D9D9D2D2D2
D1C6BDB99F8F9F9E989EAEABAEAFC3C3C5D6C0C3CFC3DED6
DAEBEEF5EBF7F7F5
F7F5F1F5F3F7F1F7EEF7F1F7F3F7F1F7F7F7F1F5F7F7F1F7
F3EEF1F7F3F1E6EBDEABAE9E8E72CEC7D1C6C7CED1CFD1D9
D9D9D9D9DAD9D9D9D9D9D5D5D5D5D9D5D9D9D9D5D5D5D5D5
D1D1D1D5D5D5D5D1D5D5D9D1D5D5D9D9D5D1D5D5D5CDD1C6
C5B9AE938F9FABABABA49EAEAEBFC5C3D1C5B8C3C3D6D6D6
DEF5EEF3F3F5F5EE
F1F5F7F5EEF7F7F7F3F7F5F1F7F1F7F7F3F1F5F1F7EEF7F5
F3F7F5F5EEF3DFF3D6AB9F9E8B725AC1C5C6D1CED1CDCFD2
D9D9D9D9D5D9D9D9D9D9D9D9D5D9D5D5D5D9D9D9D9D2D2D5
D5D5D5D3D5D1D2CFD1D3D9D5D9D5D1D9D9D5D5D1CDCDC5C3
B8B89F8AA4AB9FABB9ABA4ABBFAEBFB8BDC0CFCFCFE6C5D7
EEEEF5EFF1EEF7F5
F3F1F1F3F1F7EEF3EEF7F7F7F3F7F3F3F7F1F7F5F1F7F1F3
F7F3F7F5F3EEE6EBD7C99EA48E725A5AC6C6CDC6D1CFCDD9
D9D9D9D9D9D5D5D9D9D5D5D5D5D2D1D5D9D9D9D5D5D5D1D2
CFCDD5D5D5D2D1CAD1CFD5D5D5D5D5D5CFC3C3C0B8B8B8B8
A47E729FB8AE8BABAFBFBFBFABABAEB8C5C0CFCFEBD1D6E2
ECEBECF3F3F1F7F5
EEF7F5F1F7F1F1F5F7F5F5F7F5F7F5F7F7F5F7F5F3F3F7F5
F1EEF5F3F5EEF3E2E2BFA49F8672675A4EC5CEBDCFCDCFD5
D9D5D5D5D5D9D5D5D9D5D5D9D5D5D2CFD5D5D1D9D5D2CDD2
CDCDCDCDCFCDCDCACACAD2D5CAD5C3CFCDCAC0C0B8AFA493
728486A4AEAEA7B8B8BFB8B8BFABAEC0C0C3CFD2D1D6DEEB
ECE2ECF5F5F1F7F7
F3EEF7F7F7EEF7F7F7F3F1F7F3F5EEF5F1F1F7F7F7F5F5F7
F1F1F3F5F3ECEBDAE6ABA49E847272674E32BDC7C6CDCDD2
D1D5D5D5D5D9D5D9D5D5D5D5D1D5D5D2D2CFD2D5D5D1CFD2
CDD2CAC3CAD2CACAD2CACFCDCAC3CDC5C5C3C0B9AC938A86
7E8BA2AFABA7AEB8AEA4A4AEABBFC0C0BFCFD2D2D6EBEBE6
ECF5F3F7F7F7F7F7
EEF7F5F7F7F7F3F5F7F7F5F1EEF5F7F7F7F7F5F1F5F5F5F7
F5F5F5F1F3F5ECDEE2AEA49F86727267464632C6C6D1CED1
D1D5D5D5D5D5D9D9D5D5D5D5D5D5D5CFCFD5D2D1D2D3CDCD
CDCDCACACACAC3C0C3CAC3D1C0C5C3C3B9C1B89F848A638B
939FAEABA7ABA7BFB8B8B8BFBFC0C3BFCFD1D2D2DFE2E6EB
EEF3F7F5F7F5F1F7
F7F7EEF7F5F7F7F7F5F5EEF5F7F1EEF5F5F7F7F3F5F7F1F1
F5F7F5F1F3EEEBE2DCAEA48F867E725A463A4EC6C6CDD1D1
D2D1D9D5D9D5D5D5D5D5D2D5D5CFD5D2D1D2CDCDCACDCDCD
CDCACAC3C1C0C0C0C3D1C3B9B8B9BCBCACAC9E9F6C847E8A
7E9FABA4A4A7B8B8BFC5B8BFCFBFC3CFCFD2D1DFE2E2F3F3
F7F7F5F5F7F1F7F7
F7F5F3F3F5F1F7F3F7F3F1F7F7F5F7F3F7F5F5F5F7F1F1F7
F7F5F7F3F5EEEFDEBFAEA493848E726B4E4E5E61C7CFD1D9
D1D1D9D5D5D5D5D5D5D1D5D1CDD3D5CFD2D2CFCACFC3CDCF
CDCACAC1C1AFB8C5D1C5ACAFB8AFB8AF9F9E8B869F8B9F9F
A2AEAFA7ABA7B8ABAFB8B8C0B8B8CFCFCFD1DAE2EBEBF5F7
F1EEF7F7F5F5F7F5
F7F7F1F7F1F5F5F7F7F3F7F7F7F7F1F5F7F1F5EEF1F7F1F5
F7F3F5F3EEEBECD5BFA4A48F938A6B6B5A636746C6D1D2D9
D1D1D5D2CFD5D2CFD5D5CFD2CFD2D2D5CDCDCDCFC3D2C3CA
C5C3C1BDAFB8B8CFD1ACAFB8B8AC98927E9E8E868A9E9F8F
A4AEAEABA493BFAEBFAFCFB8C0CFCFCFCFD6D7EBECECF5F7
EEF7F7F7F1F7F7F7
F7F1F7F3F7F7F7F7F7F5F7F7F7F7F5F3F7F7F5F5EEF7F5F7
F1F1F7F7F3EBEBC6BFA4938B7E7E676B72725A32D1CDD2D1
D5D1D5D2D2D5D2D2D2D2D2D2CFCFD2CDCFCDCDC3C3C3CAC3
C5C5BDB8ACACC3C6ACA5A5A7A5988F738B9E8E8E8E8F8B8F
A4AEAFA2A2AEB9AFB8AFAFBFBFC0D1D1D2E2F3EBECEEF7F7
F5F7F7F1F5F1F7F7
F7F7F7F1F7F7F5F7F5F7F5F7F7F7F7F5F5F5F5F5F7F7F5F7
F1F7F7F7F1EBDFBFB8A2988F8B6B6372756B524ED2CED9D2
CDD5D1D1D5D2D3CFD2CAD2D2CACACACAD2C3CAC5C3CAC0C1
C0B9B8A6ACAEB8AFA4A5A4A4987E82828AAB9F9E8E8AA29F
A4A2ABABBFB8B8ABAFAFAFB8CFD2D9D2E2E6EBEEEBEEF3EE
F7F7F5F7F7F7F7F7
F7F5F7F7F7F5F5F7F7F5F7F7F7F7F5F7F5F5F7F7F5F7F5F5
F5F5F5F3F1EBDEC0AFA4938B8A75728A724E4E46D2CED1C6
D1D5D5CACAD2CDCACACAC3CACAC3C3CAC1CAC1C1C1C1C0C0
B8B8AFABA5B9A798929F93987A93868A8B9FABA4939F989F
A293A7ABBFBFBFAEAFBFAEB8CFD1D6E2EBF3EBEEEBF3F3F7
F7F7F5F1F5F1F5F7
F7F7F7F5F7F7F5F7F7F7F5F7F7F7F7F7F7F7F7F7F5F7F5F5
F7F3F1F7F7EBD2B8B8A2938B8B6B7E7263465246D1D1D1D1
D1CDD5CFCAD2CAC3CAC3C1C3C1C3C1C1C1C5C3C0BDB9C0B9
B9B8AFA4AFAC9892938B8B758282727E8FABABABAF9F9F93
93A2ABA4BDBFB9ABBFC5B8C3CFCFE2EAEBE2EBEEF5F5F5F7
F5F7F7F7F5F5F7F5
F7F7F7F7F5F5F7F5F1F7F7F7F7F5F7F7F7F7F7F5F7F7F5EE
F5EEF7F5F3F3BDB8A7A47E8275757E755E525E4ED2C7D1CD
D1CDCACFCACACAC3C1C1C1BCBDC0BDBDC1C0C0B8BCB8B8B8
B8ACACA4AFA4938B89897A8B8275757E8E9EABA4ABA4A293
938FA4B8B9B8C0C0BFAFB8C3D1D7E6E2EBF3EEEBF5F7F5F7
F7F7F7F7F5F7F7F5
F7F5F5F7F5F5F7F7F7F5F1F7F7F5F7F7F5F5F3F1F7F5F5F7
F7F5F7EEF3DEC0B8A4988B93727E7E7546464E52D1C6CEC6
CDCDCACACAC1C3C0BDC0BDBDBCAFAFAFB8B8BDB8B8AFAFAF
ACACA5A2938B8A7E898B8B7E7E7E868E8F9EABBFB8C3A78A
8A93A7A4B8BFBFBFAEAEAECFD6D7E2EBE6EEEBF7F5F7F7F7
F7F5F7F7F7F1F7F5
F5F7F7F5F5F3F1F1F5F7F7F7F1F7F5F7F5F7F3F7F7F7F7F7
F5F1F5F3F3D2BFABA2937E82758A6B633E3E4E4ED1C6CDCE
CDCACAC1C0C0C0C0BCB9B8BCB8B8AFAFAFAFB8B8AFAFAFA5
A5A498A48F7E758B7E8B8B5E5E6B8B9E9E9EA4AEB8AFBFA2
93A4A4AFA4C0C0AFAEAFAECFD6EBE2EBEBECF1F7EEF3F7F7
F5F7F7F7F5F7F7F7
F7F7F7F7F5F7F7F7F7F7F7F7F7F3F5F7F3F7F5F7F5F7F5F3
F5F7EEF5E2C6BFA2988B8275757E6B5A4E52525AC6C6C5C5
CAC5C1C5C1C1B9BCBCAFAFAFA6ACACA6AFAFA6AFAFAFA5A4
A5A493AB8B6B82827E75635E46869E8B9E8F9FAEBFB9C3A2
A2AEA2AFABBFAFAFA4ABC3D6E2E6E6E2EEF3F3F7F5F5F7F7
F7F1F7F5F7F5F7F7
F7F7F5F7F5F5F1F5F5F7F5F7F7F7F7F7F1F3F5F1F7F7F5F7
F7F1F5EED7C0B1989882897E757552524E525252C6C5C6D2
CBCBC9CBC9C9C5C1C1B9ACA4ACA1A4A4A4A4ACACA4A4A498
989293A47E617E8B6B5E5A6172849E9E939E8AAEB8BFAFAB
A4A7A7A2BFBFAEB8AEBFBFD2F3E2E2EEECF7F7F7F7F5F7F7
F7F7F7F7F7F5F7F5
F5F7F7EEEEF7F5F7F7F5F5F7F7F1F7F5F7F3F5F3F7F7F5F5
F1F1F1EBD2BFAB98938B7E9375753A5A52524E6AC6D6DADA
DAD9D9D3D3D3CCCBCBC5C1B9A1A19FA1A1989898A4A1989F
938B8B9F6B6C7E73634E5286637E9F9E938A93ABB9C3C5BF
ABAB988FBFBFABAFBFBFD1EEEBEBEBEEF3F5F7F5F7F7F7F7
F5F7F7F7F7F7F5F1
F7F5F5F7F7F7F5F7F7F7F7F7F7F5F7F7F5F7F7EEF7F5F7F3
F1F5F5DAC6B8A7988F757E757E63465E5A524E9BDADBE6E0
E0DADAE0DADAD3D3CECBC5C1BDAF9F93989F9FA192989F98
938B7A93757E93635A4E5E8E677E8F9F8E8A93A4ABC3C5BF
B8AB93A2B8B8B8B8CFB8D1EEE6DEEFECF7F5F7F1F5F1F5F5
F7F7F5F7F7F7F7F7
F5F7F3F7F5F3F7F1F7F7F7F7F5F3F7F5F5F7F5F5F7F5F1F1
F3F5F5DABDABA28F8B8B7E757E4652615252A0DBE2E6E2E6
E0E6E0E2E0DAD9DAD3D3CBCAC1C0B8AF939393939F939893
89826B639375A45A4E3A468A8F728FAB8AA293A4B8C3CFD2
C08FA2A2AFA7B8C0BFC0ECE6DFEBF3F5F7F7F3F7F7F7F7F5
F5F7F7F7F7F5F7F7
F7F5F7F7F7F7F7F1F5F3F7F7F7F3F5F7F5F5F5F5F7F7F7F7
F1ECDED6B1AB9882757E7E756646616152D7E2DDE2E6E6E2
E6E2E0E0E0E2DAD9D9D9D1C6C5CAC1B9AF928B8B938B928B
897E635EA463AC7E525E3A639F678F9F8EA4A4A4AEB8D1D2
BFA798A2ABABBFC0BFCFE2DFE2EEEEF7F3F7F5F7F7F5F5F7
F5F5F7F7F7F7F7F7
F7F7F7F7F1F7F7F7F7F7F7F7F1F5F3F7F7F5F7F7F7F7F7F5
EEECD5C9A8A2988B7A7E7575524E5E5293DEE2DAE2E2E6E6
E6E6E2E6E0E0DADADAD2CED1CDCAC6C1B9A6AF89898B8289
7A75675A9F8F98934E3A5E7E9FA49F9FA48BA7A2ABB8BFD1
CFA293A29FABC6CFC1C0D6EBF3F3F5F7F5F7F5F7F5F5F7F7
F7F7F5F7F7F7F5F7
F1F7F5F7F7F7F3F7F5F5F7F5F5F5F3F7F5F5F3F7F7EEF7F1
EEE2D5BDA8A293826B756B753E525A73DADBE2E2E2E2E6E0
E6E0E0E6E0E0DAD9DADAD9CECECDC6C5C1B9AFA67E898978
7E66614682B96BAF7A8B4E866CA2869E9FA29BAB98BFAED2
DEA293A2A7B1B8BFC0CFE2EBECF3EEF5F7F5F7F7F5F5F7F5
F5F7F5F5F7F5F7F7
F5F7F5F7F7F7F5F5F7F7F7F7F5F5F7F5F7F7F7F7F7F7F5EC
ECDAD5B1A78F937A75756A524E666FDBDADDE2E2E2E0DDDA
DADADADAD9D3D3D2D9D1D5CECEC5CAC6C5C1B8AFAC7E757E
6C6B52526BA29882B1679875898F9F8A9FA27EA2A2B8B8BD
C5CFA28FA2B1ABBFCFDFEEE2EEF3EEF7F5F5F7F5F7F7F5F7
F5F7F7F7F5F7F7F7
F7F7F5F7F7F7F5F7F5F5F5F5F7F7F5F7F5F3F1F5F5F7F7EC
DFDAC1A8988F7A75757546524E4EDBDBE2DDDADAE0DAD5CE
CBCBC5C5C5C1C5C5C5C5CDCDCDCECDC5C5C1BDB9B8AC9275
6A675A525E7AAFA28EB89F98638AA49E9F8A9898B9ABB8BF
D2D7A2ABB9ABA7BDD1F3E2F5EEF3EEF7F7F5F7F1F5F7F5F5
F7F7F7F7F7F7F7F5
F7F5F7F7F7F5F7F7F7F7F5F7F7F7F7F7F5F5F5F7F7F5F5EC
DED5C0AB9393896C756A4E5266D7DEDEE2DDDADAD9D2CBCA
C1BDBEBEBEBEBEC1BDC1C5C1CDCDCEC6C5C1BDB9AFAFA573
6461523E5277AF8F75BD9FAE987E8BAB9F93A298B8ABBFB8
BFD6BFB8B1B1B8C0D2EBEBF3EEF5F7F5F7F7F1F7F7F7F5F7
F7F5F7F7F7F7F7F7
F7F5F7F7F5F7F7F7F7F7F5F7F7F7F7F7F7F5F3F3F7F5EEDF
DAD6B1988F7E896B6652525A61DBDBDADADADAD9D3AEA1B1
B1B5B5B5B5B5A1A1A1A1B9C5C5CDCDCDC6C5C1B9B9AFA6A4
61524E3A4E6B8FB99BA6BFAEB8AB9F93A4A28A93A2B8A2C3
C0CFD2B1BFABB8CFD5DFECEEECEEF3F7F1F5F7F5F7F7F7F5
F7F7F5F7F7F5F7F7
F7F5F7F5F7F5F7F7F7F7F5F7F7F5F3F7F7F5F7F7F3F7ECE2
DEC0AB8E827E75616B5A5261DFDBDADAD9DDDABEB5B5B5DB
D3BEBEC9D3B5B5B1A6A5A1B9C5C6CDCEC6C5C5BDB9AFB5A5
985E3E3E3A6B3EBDC57EC098C0BFA2A4AE86A498A2ABAFB9
C0D2D7A89BABB8BDEBEBEEEEEBF7F7F1F5F5F7F5F7F5F5F7
F7F5F7F7F5F5F7F5
F5F7F5F7F5F7F5F7F5F5F7F5F5F5F5F5F5F3F7F7F1F7E0D5
BDAB9B8E6B756C7546525293DEDEDEDAD9D9D9B1B5B5B1AE
AEAEB5A1A1969898BEA5A596BECBCDCDCDCDC5BDB9B9AFAF
A48F5252294E739BAB98A2BFA4C3DDA293A4A48B98AEABB8
B8D2D2B1ABB1A8BDEBECF3ECECF7F7F7F7F7F7F7F5F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F5F5F7F5F5F5F7F5F5F5F7F7F5F5F7F5F5F5DFCD
B8AB8F7A6C75664E5E4E75DFDFDEDADAD9BEB58F757F8D8F
8D8D9687756C727F637D726478B5CDCDCDC5C5C5B9B9B8B9
A598733229525E6FA2BD75BD98B9D1DDAFAF8EA498A2A798
BFCFD2C9B8BFB1C6E2EEEBEEF5EEF7F7F5F7F5F7F7F7F7F7
F7F7F7F5F7F5F7F7
F5F5F5F7F7F5F5F7F5F7F5F7F5F7F5F5F5F5F5F3F5ECDFC9
A8987A6C736B61616164DFDFDBDEE2DAD9D3D9BEA5A198A1
98A1B1989898989898B8BDBEC5C5CDCDCACAC5CAC1B9B9B8
AFA586492929496F86B9AB82B898D1D1DE8FA4A498A2A298
BFBFD2D6ABBFB8DEECECEBEBF5F5F5F5F7F7F7F7F5F7F7F5
F7F7F5F7F7F5F7F7
F7F5F5F7F5F7F7F7F5F7F5F7F7F7F7F7F3F7F5EEF3EBD6C0
9B8282736B665A61636ADEDADEDDDADDD9DDE2E2E6E2DBDA
E6DAD9E2E6DBDAD2CED2CECDCDCECDCECDCBC5C5C1C1B9B8
AFAF986A391D6F5E6F86A27EA48BA4D1D1B8AFA29393A2AF
B8AFD2D6B1B1A7E2EBEBECEBF7F7F7F5F7F7F7F7F7F7F5F7
F5F7F7F7F5F7F7F7
F5F7F7F7F7F7F5F7F7F7F5F7F5F5F7F7F5F3F5F5ECD2D1B1
8F7A6A6A674E61615EC6DEDEDEE0E2DAE2DAE2E2E6E2E6E2
E6D9DADADACECECECED1CED1D9CECDD1CECBCBC5C1C1B9B5
AFAF98783A325E6A9386B17E75A7A2C6D1D9BFA4A4A79398
98AFD2D6B8C0ABEBECE2EBF3F7F7F7F5F7F7F5F5F5F7F7F7
F7F7F7F7F7F7F7F5
F5F7F5F5F5F5F7F3F7F7F7F7F5F7F5F7F5F5F3F5F5D6B198
7E8266675261616161DEDEDBDEE2E0E0E2DEE2E2E2E2E2E2
DEDAD9D9D9CED1D5CED2CED9CED9CECECBCBCDC5C1BDC1B8
AFAFA5825A4929626B7A7E8F7E988EAFCFCFAFB8A4A293A2
93B8BFD2BDABB9DFEBEBDEF7F5F7F7F5F7F5F7F7F7F7F5F7
F7F7F5F5F7F7F7F7
F7F5F7F5F5F7F7F7F5F7F7F7F7F7F7F7F7F5F5F3D6CDA893
82667352614E616652DEDBDBDEE2E2E2E0E2E2E2E2DEE2E2
D9D9CED9CECACDD1CED3D5D9D3D3DAD9CECECBCAC1C1B9B8
B5A6A5935E3A3E5E777F869B82737AA8A7BFD9BF9FA782AB
A2B9B8D2BDA2D7DEECECECF5F7F7F7F7F7F7F5F7F7F7F5F7
F5F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F5F7F7F7F7F5F5F5F7F7ECD2B6A882
7E7A6461615E61529BD7DBDBE2E2E2E2E6E2DEE2E2E2DADA
CEC5C1CBC6C1C5CBCDCED5D2D9DADAD3D3CECBC5C1C1B9B9
B8AFA1927349524E6F6B867A936A7E6BC0CFB8C0A7AB8E98
A2B1B8D1C6ABE2D2F5ECF7F7F7F7F7F7F5F7F7F7F7F7F7F5
F5F7F7F5F7F7F7F7
F5F7F7F7F7F7F5F7F5F5F7F7F5F7F7F7F3F7F5F5D1A88F7A
6C6C61525261614ED7DBDBE0E2E2E2E2E2E2DDE2E2E2DAD3
CCCDBDC1C1B9BDC5C5CDCED5D3D9D9D9D3D9D2CBC5C1B9B9
B8A6A59878491D365E6A826B937E7E61BDA4B8DDABA7A798
A0A4ABD1C9C9D5DFDFDCF7F7F7F7F7F7F5F7F7F7F7F7F7F7
F7F7F7F5F7F7F7F7
F7F7F7F7F7F7F7F5F7F7F7F5F7F7F7F7F7F7F7ECC09B7A6A
6C52615A61644E46DBD6DADAE2E0E6E6E2E2E2E0E2BDB1DA
DAD3C98D8DA6BD98B8C5CED9D9DADADAD9D3CECBCAC1C1B9
B8AFA592895A2936465E6B6F82826A8273A2C3B8C3A4A27E
9898B8CFC9ECBDECC6F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F5F7
F5F5F7F5F5F7F7F7F7F5F5F7F5F7F7F7F7F7F5E4AB8F7A7E
6161525E6152466BDBDADEE2E6E2E0E6E0E2DDE2E6DEDBE0
E0DACDC5C6CACDC1ACB9CEDADADADADAD3D9D9D2CAC5C1B9
AFAFA5A186731D29364E62736B866A753EBFACAED198A282
8FA2ABBDD2D2B9C6F7F7F5F7F7F7F7F7F5F7F7F7F7F5F7F7
F7F7F7F5F5F7F7F7
F7F7F7F7F7F7F5F7F7F5F5F7F7F7F7F3F7F7F7DFA27A7852
5E675A6167464690D6E0E0E0E2E6E6E6E2E2E2E0E6DBE2E2
E2E0D9CDCCCCC6C5C1C1D3DADAE0DADADAD3D3D3CDCAC5BD
B5B5A5988B7A1D32295E6B7A5A826A7546ABA2BFD198A28F
989BA8C0D2D2C9D5F7F7F5F7F7F7F7F7F7F7F5F7F7F7F7F7
F7F7F7F7F5F7F7F7
F7F7F7F5F7F5F7F7F5F7F5F7F7F3F7F5F5F7F5DC8F73756A
6161666C5E3E49D7DBE2E2E6E6E6E2E6E2E6E0DAE6E6E2EC
E2E0DAD2CBC9C6C5C1CBD3DADADDDAE0DAD9D9D3D3CBCAC1
BDAFA6988B753E11325A3E7E6A825E6A738FA7C0C0B898A2
8F9898BDD6C6DCF5F7F7F7F7F7F7F7F5F5F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F5F5F7F5F5F7F7F5F7F7F7F3AB7A7A525A
5A616761324632DAE0DFE0E6E6E2E6E6E6E6E6E2E2E0E2E2
E2E2DACBBEC1C5BEC6CEDADBDBDEE2DADAD9DAD9D3CBCAC5
C1B8A6988F895E182949696B737A616A5E86A4AFC5D29398
8698ABD1D6B1D5F7F5F7F5F5F5F7F7F7F5F7F7F7F7F7F7F7
F7F7F5F7F7F7F7F7
F5F5F7F7F7F5F7F7F7F7F7F7F5F7F5F7F7F7F19D7A66526B
676761293E3A49DAE2E6E2E2E2E2E2E2E2E2E6E6E0DFE0E6
E0DBD3CEBEC5C6C6CEDADADADBE0E2DBE0DAD9DAD3D3CBCA
BDC1AFA58F826C1D393E5A5E6A6A7E6A6A8EA2AEC5DD9893
828E9BBDD2D5F5F7F7F7F7F7F7F7F7F7F7F7F7F7F7F5F7F7
F7F7F5F5F7F7F7F7
F7F7F7F7F5F7F7F7F7F7F7F5F7F5F7F5F5F5F59D7561616B
5E61673E323EBDDEDEE6E2E2E2E2EAEAEAE2E6E6E6E2DBE6
E6DAD3C6C6C5CDCED2DADEDBE0E0E6DFE0DBDADAD3CECEC6
C1B9B8A592827A3218463E6B7361757E6A86B1B8C3DD8FA7
739B8FCFDAD5F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F5F7
F5F5F5F7F7F7F7F7F7F7F5F5F5F7F7F5F5F7D486735A6A6A
67613E3229D3DFE0E6EAE2E2EAE2E2E2E2E2E2E2E2E6E2E6
E6E0DACEC6CDCDCED2DBDBE2E6E0E2E0E6DFDFDBDAD6D3CD
C5BDB9B898827E5A46525E5E7A6A7E736C86BDB8BFD2A293
6A8E98C5DEEEF7F7F7F7F7F7F7F7F7F5F7F7F5F5F7F7F5F7
F5F7F7F7F7F7F7F7
F5F7F5F7F7F7F7F7F7F5F7F7F5F7F7F7F7F786756A46695E
5E673E5249DADBE2E6E2E2EAEAE2E2E6EAE2E2E2E2E6DFE6
E6E6E0CEC6CED1D2D2D6DEE6DFE6E2E6E0DFDFDFDBDAD2CE
C6C5B9B8A192785E5252526B6A7E7A73829DB9B8B8BFA78A
668EA8C0E2F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F5
F7F7F7F5F7F7F7F7
F5F7F7F7F7F7F7F7F7F7F7F7F5F7F7F7F5F78F7E5E52736B
615A523E95E0DFE2E2E2EAEAE2E6E2E6E6E2EAEAE2E2E6E6
E2E0E0CEC6C6D1D2DADADFDFDFE2E2E0E0E6E2DEDBDADAD2
C6C5BDB8A592786C4646525E677A7E7A75B8B8B8B8BDBF8B
8B8F9BC3EEF7F7F7F7F7F7F7F7F7F7F7F7F7F5F7F5F7F7F7
F7F7F7F7F7F7F7F7
F7F7F5F7F5F7F7F7F5F7F7F7F7F7F7F7F7F586866B5E5A6B
67465A6BDBE2DFE2E2E2E2E2E2E2E6E2DFE2E2E2E2E6E6DB
E2E2E6D2CBC6CED2D2D6DBDFDFDFE2DFE6DFDBDBDADBD6D2
D2C6BDB9AF98826B5A4E52526B75776B66C0B8ABB9B1C575
8F8F93BFF3F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F5F7
F7F7F7F7F7F7F7F7
F5F7F7F7F5F7F5F7F5F7F7F7F7F7F7F5F7B675776A736A6C
52495AD6E6DBE6E2E2E2E2EAE2E2E6DFDBDBDFDFE6E6E0E2
E2E2E6DACBC5C6C7D1C7D7DADBE2DFDFDFDBD7DBDADADAD2
D2C7C5BDB5A582755E3E52525E82737373B1ABB8B882CF63
82A2ABBDF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F5F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F5F7F7F5F7F7F7F7F7F7F7F7F5F791A0825E825E6C
465E61D6E0D6E2E2EAE2E2E6E2DFDFD3D6DADADBDFE6DEE2
E6E2E6DAC9C5BEC6C6D2D7DBDFD6D6D2D6D6D6D6DADBD6D6
C6D1C5BDB8A58F75673E3A525E737E7373B1AFAFB867C378
739DBDD6F7F7F7F5F7F7F7F7F7F7F7F7F7F7F7F7F5F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F5F7F7F7F5F7F7F7F5F5F5F5F7F76BA3737F6F735E
3E7ECADACBDBE6E2E2E2E2DFDADBDBDAC7C6D2D6DBDFD6DB
E2E2E6D3C6BDC0BEBDC6D6D7D2D2C6CCC5C5BEC7C7D2D2D2
D1D1C6BDAFA692826B5A2946527373826BA8B998A266CF82
6CABBFDEF7F7F7F7F7F7F7F7F5F7F7F7F7F7F7F7F7F7F7F7
F5F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F5F7F5F7F7F7F7FF82906B736B783A
6A67E0AFC1DEE6E2E2E2DFD7C7A8A0BEBAA8C7C7DFDFDBDB
E6E6E6DAC6B9B1B9D1C7D7CCC7B7AD9DA0B1B1B1BAD1D2C7
C7C7C5BDB1A698786B5E5246466B6A77739DA2989875CF75
6CB1B8DFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F5F7F7F7F7F5F7F5F7F7F7F7F7F7F7F7AE8E865E6B5E7846
75D2D3BEBEDEDFE2E2DBCC9BA2C7B66E7295B1B5B5DBDBD6
E6E6E6D9CEB9BDA8BD7596A6BED4886691908E909DBEC6C6
C7C7BEBEAFA69282735E6B3E3E6B6B73829BA8939872D17E
86BFBFECF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F5F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F5F7F7F7F79DAD8677466B784E
3EE0CAC9C6DFE6DFD6CC9DA6CADF786E5E7F91B1A8CCC6D9
E6E6DEDACEC1A89DA6B17DD4EC7F82728F66AE867A9DBDBD
C6C5BEB9B89D8F826A5E461D326B735A829D9B828E89C566
A8C0C0F7F7F7F7F7F7F7F7F7F7F7F7F7F5F7F7F7F5F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F5F7F7F7F7F7F7FFF5936A61466B6B6B
78E0C1BEC6D7DEDAC7A88249A6BF87B61D7C52829DA8CEDD
E6E6E2DAD1CDA8A086A0A882CA5EBB1D725EAE396290A0A8
BDBEBDA8ABA58F786B673229323E6B5E8F868E8E9889BF66
A2B9D2F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7A3CF9782675E6B6B78
A5D3BEB9C5DBDECEBAA65E73734E36496B7A7390A8CBD5E2
E2E6E2DAD5CEC1A8A68F829999493E49495E4E6667909B9D
AFB9B9A89D987873735E52324952525E828F827E988FBF7A
A2B8EBF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F5F7F7F7F7F7F7F7
F7F7F7F7F5F7F7F7F5F7F7F7F7F7F78FAEA8735E776B5E6C
A5C9B9B9C5DBD7D6D2C6A892776767676B82A6BDCEDADAE2
E6E6E2DADAD9CDC1B9A89D7290958C73574E5E86A2A0A6AF
B9B9A8AFA29278736B6B5A3E4946465A8698867E98A2BF82
A2BDEEF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F5F7F7EB987F5E5A5E5E5282
A5AFB1A8BED7DEDEE6DFDADBD2CECCCED2CEB9C1CBD9E6E2
E2E2E6E2DDDACDB8BDA8BDBEBDA8A8A8AFB9BDBDC5CAC6BE
BDB9AFA6A29878776B52523E495E5A5282A2827EA4A8C686
A8E6FFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F5F7
F7F7F5F7F7F5F7F7F7F7F7F5F7F7FFFF5A734652527A4675
92B5AFA0BDDED2E2E6E6E2E6E6E2C9A6908692CED9E6E6E6
EAE2E6E2E2E6D5CBA6898692A0D2D6DAD6D2D2CECECEC6BD
AB9BAFA2988F82736A6B463E3E493A5E738F827AA7ABD18E
B1ECF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7ECFF526146525E6B5E7E
8D98A2A6B1DAD2D1DBE6E2E2E09D908292BDD9E2E2E6EAE6
EAE2E6E6E6E2E2D9CBA2786B7892C1CCD6DADAD3D2C6C1A8
8EAFA09D8F82827352523E463E3A626F7F8E8675A2A2C0A8
B1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F5F7FFB6FF6A5A5E5E466B6175
7878909DB1D7DFA8B1BDB9B5928FB9E2E6E6EAEAEAEAEAEA
E2E2E2E2E6E2E2E2E2DDCEBDA082738689A1A0A69B908E9D
A8A8B5A28F82826B82325A5A523E3672828F827AA2B89D8B
D5F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F5F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F5F7F7B6865E5E726B5E5E5E6B
7577868EBDD7DEDEDABDADB5C7E2EAEAEAEAEAEAEAEAEAEC
E2E2EAEAEAE6E6E2E6E2E0DADADAD6D6B1908F9090A8B1A8
AFB8AFA28F868F6B525E52462929327782738E89ABB182A2
ECF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F5F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F5F7F7F7F5F7F7F7F7F7CF82695E8C7A696B5E73
73778F8FB9DADBDEDEE6E6E2E2E2EAEAEAEAEAEAEAECEAEA
E2EAEAEAE2E2E2E2E2E6DEDEE2DADADAD2D6D6CEC6C5BEB9
BDA8A0988F8E8F825E523A29292932A07773B88298BF82B1
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F5F7F7F7F7F5F7F7F7F7F7F7C166626F977F6B6F696F
6F738E86B9D6DEDEDFE6E6E2EAEAE2E6EAEAEAE6EAEAEAEA
E6E2EAE2E2EAE2E6E6E6E6E0E2DBDAD6D2DACECEC6BDBDB9
B9A8ABA2928F8F73825A3E3E32463AA88E73A88F82C082C9
FFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7D66B7A7786777A776F6B
6A6A8286A6D1DBDEDEDFE6E6E2EAEAE6EAEAEAEAEAEAEAEA
EAEAEAEAEAE2E2E2E2E2E2E2E2DAD9D6DAD2D1CDC6C5BEBD
B9B8AF988F9886825E465246292932AB9082B89377A882F5
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F5F7F7F7F7F7F7F7F7F5776B6B6B72776B6F6B
6F6B8E98ABCED2DDDFE2E6E6E2E2EAEAEAEAEAE6E6EAEAEA
EAEAE2E2E2E2E2E0E2E2E2DDDADADAD3D2D1D2CEC5C6C1BD
A8AFA6A2988F826B5E495A3229294686B89BB998867ABDF7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F5F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7FF677A6B777A7F776F6F
6B7786A2A8C5D2DEDFE6E6E6E6EAEAE6E6EAEAE6EAEAE2EA
EAEAE2E2E2E6E6E6E6E2E2DDDADADAD3CECECECECBC5BEBD
B9AFA09B9B908273525E3A3232293682A886ABA2937ADCF7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7FF8C62737F7F6F776B69
7F77869DABBED2DAE2E2E2E6E6E6EAEAE2E6EAEAE2E6EAE6
E2E2E6E2E6E6E6E2E6E2E2DAE2DAD9D9D2D1D2CDC6C5BEBD
A8AFA69B9B8282735E523A291D1D67778E8FB1ABC0ABF7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7FF6B908E737772736F7E
5A7790A2A0BDD1DADEE2E6E6E6EAEAE2EAEAEAE6EAE6E2EA
E6E2E2E6E2E2E6E6E6E6DAE0DDDADAD3D9CECEC6C6C5BEBD
A8B8A09D867F6F5E6B46291D361D727F827AABABB1E2F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F5F7F5F7F7F7F7F7F7F7F7F7F7E49069696B6B6A6F6B
77778EA0B1BED1DADEE6E6E2E6EAEAE6EAE6EAE6E2E6EAE6
E2E2E6E6E6E6E2E6E6E0E2E2DADADAD3D9CECEC6C5C5C5BD
B1B99D90868682695246292936297F7F867EABB1BEF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FF77696B5E6A625E69
77829BA0B9C0D1DAE2E0E6E2E6E6E6E6E2EAEAEAEAE2E2EA
E6E6E6E6E6E6E6E6E0E2E2E2DAE2DAD9D9D5CEC6C5BEC5BD
BDA89D9D907773524632321D2D298A7F7E7AB1C1D6F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7C4726B6B6A6B6B62
6B8290A0B1C7D2DAE2E2E6E2E2EAE2EAEAEAEAEAE2EAE6E2
EAE2E6E2E6E6E6E6E2E6E2E0DDDADAD9D9CECEC7C5C5BDBE
AFAFA2908E867349463236263232909D738FABD1F7F7F5F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F5F7F7F7F7F7F7F7F7F7F7F7F7F7F7F57A5E5E62626B69
627F9BA8BDC6D9DADBDEE2E6E6E6E6E6EAE6EAE2E6E6E2E6
E2E2E6E6E6E2E6E6E2E2DDE2E0DADADAD2D2D1CDC5C5BEB9
B9A0A29086776B494636323E3E29829B82A4BDD7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7907A626F696269
6F7F86ABC0D2D2DAE2E2E6E6E6E2E2EAEAE2E6E6E2E2E2E2
E6E6E2E6E6E6E6E2E2E2DDDDDAD9D9DAD2D1CDCBC5C5C1C1
AFA09D8F82735E49493E323E291D7F8682A2C5EEF7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFC4907F7F7F69
697F93A0B9CED9DADAE2DEE2E2E2E2E2E6E6E2EAE6E2E6E6
E6E6E2E6E2E2E2E2E6E0E2D9D9D9D9D3D2D1CDC6CDBDBDBD
A0A0908E776B5A5E4646322918499D8693AFBDF7F5F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F5F7F7F7F7F7F7F7F7F7F5F7F7F7F7F7FFFFEC827F6F77
72778FA8B1C6D9DADAE2E2E6E6E2E2E2E6E6E6E6E6E6E2E6
E6E6E6E6E2E2E2E6E2DADADADAD9DAD5CECECECDC5B9BEA8
A8A28F786B6F5A4949363E1D188E907A98A7DAF7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFAE6B7262
77778EA2B9C7D2D3DADAE2DDDDE2E2E6E6E6E2E6E6E6E2E6
DEE2DFE2E2E2DDDADADADAD9DAD9D9D3CECECEC6C6BEB9BD
A090827A736F6F46463E291D9D8A827AA2C6ECF7F5F5F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFD5526F8E
698E8EA2B1C6D1D6DAD9DAE2E2E6E2DFE6E2E6E6E6E6E6E2
E2E6E2DAE2DAE2DADAD9DADAD9D9D1D5CDCDC7C5BDA8B9AF
9D9086826F5E627F32292D696B8E828FABD2F5F7F5FFF7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFC1866B6B
72908EA2B9C6C7D2DAD9DAE0DAE6DDE2E2E2E2E2E2E2E6E0
E0DADADAD3DAD9D9D9D9D9DAD9D9CDCDCEC6C6C5BDA8A89D
8F867A6F6F6B6B495E495E5A90869BA2C0C9F7FFF7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFB6B15A6A
6973869BA8B1C6CED2D9D3E0E0DEDEDBDAE0E2E2E6DBDEDA
DAD9D3CECED2D9D9D5D3D5D2CECEC5CBC6BEBEB9A8A8A09D
8F8E8262625E5E4E5A46937F8682B9ABD1F7F7F7F5F7F7FF
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFF7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E4D4465A
826B8693A0BEC6C7CED3D3D9DAD6DADEDADADADBDAD9DADA
D5CECACBCBCDD2CACACACAC1C5CBBDC5BDBDB1B8A89D9B9B
8E86736F69627A695E7A9D8290A2BDD1C9F5F7F7F7FFF7F7
F7F7F7F7F7F7F7F7F7F7F7F5F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7B68C69
6F7F778690A8BED1C7C6CECEDADADADAD6D2D2D2D2CEC7C5
C6C6BDBDB9B9B9B8BDB9B8B8A8AFAFAFAFA6A0A8A09D9882
77827F667F7F5E7782828682A29BC6D1F3F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7B682
6F777F8E9D91A0A8C6C6D2D9D6D2D2D2D1C6C6BDC6D1BEC1
BDBEA8B1A6AFA2B9A5AF98A09898A29B9B9D9D90A0A89397
8E90777782906F526B989B98A2BDC6C9F7F7F7F7F7F7F7F5
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFF7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EC
988269868E77A0B1C9D7D7D7D2D2C6C7BDBDBEBEBDBEBDBD
ABABA0A09DA09D8F9D9B86829D869B868F908E90777F828F
828682866B6F7A82868E8EABC6C6B1F7F7F7F7F5F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F5F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F5F7F5F7F7F7F7F7F7F7F7F7F7F7F7F7F7
9891908897B6BAADC7BAC7C9C9C7C6BEBDBEA8B1BDB1ABB1
A8A69B9D86A890A89B90A28E82A88E9D908E9397727F8E8A
7A82907A827A827A869BBFC1BDC0DCF7F7F7F7FFF7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F5F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
FF8295887F93A0A0ADC7C6C6BDBEC0B1B1B1A0A8A0A8A0A8
9DA88E86917A938EA086908E90AB7786869D8E7F7F6F695E
62776B6B69697A93ABBFD6ADC09BF7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7FFA39190AEB1B6C6C6C6C6B1B1B1B1A8B1A8A89D9DA89B
8E907A9393775E906F9B8E909073828E5A5E7E736F737E7A
827A7A6B7E82BDA8C0C977AD93D7FFF7F7F7F7F7F7F7F5F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7B79572888293B7C1C7C6B6A8A8A0A8A8A09397A0909B
9B77AB8E77A8776F9077777F6F736A5A6B6B7E6B697A736B
6773869B9BB1A8D1C6938EAD93F7F7F7F7F7F5F7F7F5F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F5F7F7FFF7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7FF668CAD9193A3B9C1BEB6909D93A8A89D889D9B90A0
909B6F8682778E6F777A6F726F626B6B6B5E5A6B696B6A6A
778E8E8E8EB1C18A8A93B6A8ECF5F5F7F7F5F7F7F5F7F7FF
F7F7F7F7FFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F78C5EA3A8ADA3C6C6B98EA090909B8E8293938290
82906F8E827F625E8E62696F696A5E5E52495A5A5A6A826F
7793B1A8D2C1AD977FB17FECFFFFF5F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F5F7FF915A8495A3C1C9B98E7FA390A0A39B7F938E77
909077868E827A465E698E6B6B526B5A52464946465E7393
A89DA8C1A372879B9382B7F7F7F7F7F7F7F5F7FFF7F7F7F7
F7F7F7F7F7F7F7F5F7F7F7F7F7F7F7F7F7FFF7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F5F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7D772697297ADB9C6937F8EA08282907A778882
7A7F9082778E867A775E5E726B6B736A826A6A75828F90A2
B1D2A3AD8C5E8293A3A3F7F7F7F7F7F7FFF7F5F7F7F7F7F7
FFF7F7F7F7F7F7F7F7FFF7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7CA877E73729599C6777A8A9B827F6F696977
777F8277778E938682698E6B6A827F777A828E9BB1A0A8C6
ADA897976988979391FFF7FFFFF7F5FFF5FFF7F5F7FFF7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFF7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7FFF7F7F7F7B68284889398B1B67A7A93937F936B6F6F
827F866B9186A0909DA37F737386869B9BA2A2BDBDB6908C
8C735A6B90938AA8FFF7F7F7FFFFF7F7FFF7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F5F7F7F5F7F7C4738497A3ADB6B98293779582907F6B
675E77698886A8A0D2D7C6B1C7BEBEBED6D6C6C1977A8A7F
6F69779BA39091FFF7F7FFF7F7F7F7F7F7F7F5F7F7FFFFF7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7FFF7F7F190846A97C1C1BD95A0959891A8B6
8C677A6782A3B6AD98C9CAC9D2DEDCC9B1A3A39584827F62
6B828AA890A3F7F7F7F5F7F7F5F5F7F7F7F5F7F7F7F7F7F7
F5F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7FFF7F7F7FF8C738F98B9D4B9B9CAB6D5CAB7
DCE2F3EBE2DCDAC9D5D2D2D2DAC197B6978A8C8C777A6690
97939390FFF7F7FFF5F7F7F7F7F5F7F7F7F7F5F7F7FFF7F7
F5F7F7F5F7FFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFF7F7F7
F7F7F7F7F7F7FFF7F7F7F7F7E4737FA3B2CAD5DFD6D5D5D5
DFD2D7DAD7E2E6DFD5DCC1AEC9ADA8AE7E8E777A8C95ADB1
A093B7F7F7F5F7F5F7F7F7F7F7F7F7F5F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFF7F7FFF7F5F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7FFF7FFFFF7FFF7F7FFEC958F99C1C1CACDD5DFDF
DFDFEBE2E0DFE6DCD5CACAA899AE8A8C82977398ADB1A898
B1E4F7F7F7F5F7F7F7FFF7FFF7F7F5F7F7F7F7F7F7F7F7F7
FFF7F7F7F7F7F7F7FFF7F7F7F7FFF7F7F7F7FFF7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F5F7FFF7F7A68C95C4D4DFDFDE
DCD4E0D6D4CAB9ADA3B6B9A8987691A898B9B9C1B999B9F5
F7F7F7F7F7F7FFF7F7F7F7F5F7F7FFF7FFF7F7F7F5F7FFF7
F7F7F7F7FFF7F7F7F7F7F7F7F7F7F7F7FFFFFFF5F7F7F7F7
F7F7FFF7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFF7F7F7F7
F7F7F7F7F7F7F7F7F7F5FFF7F7FFF7F7F7F7F7AEA6BFC4CA
E0E0DFE0E0DFCACAB7B2A6C1D5AECAD4CAAEA3C9ECFFFFFF
F7F7F7FFF7F7F7F7F7FFF7F7F7F7F7F7F5F7F7F7F7F7F7F7
FFF7FFFFFFFFFFF7F7F7F7F7FFF7F7F7FFFFF7FFF7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F5F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFF7FFF7F7B6B2CA
B7C9D6D6E2E0EBF3EBDFD5DFD6D5B7ADC1D5ECF7F7FFFFF5
F7F7F7F7F7F7F7F5F7F7F5F7F7F7F5F7F7F7F7F7F7F7F5F7
F7F7F7F7F7F7F5F7FFF5F7F7F7F7F7F5F7F7F7F7F5F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFF7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F5F7F7FFF5F5F7F7F7F5F5
F5ECECE4F3EBD5CACAD5D6D4D4D7ECF5F7F7F7F7F7FFFFF7
FFFFFFF7F7F7F7F7F5F5F7F7F7F7F7F7F5F7FFF5F7F7F7FF
F7F7F7F7F7F7F7F7F7FFF7FFF7F7F7F7F7F7F7F7FFF7F7F7
F7F7F7F7FFF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F5F7F7F7
F7F7F7F7F7F7F7F7FFF5F7F7F7F7F5F7F7F7F7F7F7F7F7F7
FFF7F7F7F7F7F5F5F5F5FFF7F7F7F7F7F7FFFFF7F7F7FFF7
F7F7F7F5F7FFF7F7FFF7F7F7FFF7FFF7FFF7F5F7F7F5F7F7
F7F7F7F7F7F7F7F7F7F5F7F7FFF7F7F7F7FFF7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F5F7F7F5FFF7F7F7F5F7F5
F7F7FFF5F7F7F7F7F7F7FFF7F7F5F7F7F7F7F7F7FFF7FFF7
F7F7F5FFF7FFFFF7F7F7F7F7F7F7F7F7FFF5F5F7F5F7F7F7
F7F7F7F7F7FFF7F7F7F7F7F7FFF7F7F7F5F7FFFFF7F7F7F7
F7F7F7F7FFF7F5F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFF7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFF7F7F7F5F7F7FF
F7F7F7FFF7F7FFF7F7F7F5F7F7F7F7F7F7F5F7FFF7F7FFFF
F7F7F7F5F7F7F5F7FFF7F7F7F7FFF7F7F7F7F7F7F7F7F7FF
F5F7F7F7F7FFF7F7FFF7F7F5F7F7F7F7F7F7F5FFF7F7F7F7
F7F7F7F7F7F7FFF7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFF7F7F5F7F7F5
F7F7F7F7F7F7F7F7F7F7F7F5FFF7F7F7F5F7F7F7F7F5FFF5
F7F7F7FFF7F7F7FFF7F5F7F7F5F7F7F7F7F7F7F7F7F7F7FF
F7F7F5F7FFF7F7F7F5FFFFF7F7F5FFF7F7F7F7FFF7F7F7FF
F7F7F7FFF7F7FFF7F7FFFFF7F7FFF7F7F7F5F7F7F7F7F7F7
F7F7FFF7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFF7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F5F7F7
F7FFF5F7FFF7F7F7F7FFF7FFF7F7F7F7F7F7F5F7FFF7F7F7
F7F7F7F7F7F7F7F7F7F7F5F7F7F7F7F7F7F5FFF5FFF7F7FF
F7F7F5F7F7F7F7F7F7F7F7F7F7F7F7F5F7F7F7F7F7F7F7F7
F7F5FFF7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFF7F7F7
F7F7F7F7F7F7F7F7F7F7F5F7F7F7F7F7F7F7F7F7F7F5F5F7
F7F7F7F5FFFFF7F7FFF5F7F7F7F7F7FFF7F5F5F7F7FFF5F7
FFF7FFF7F7FFF7FFF7F7F7F7F7FFF7F7F7F7F7F5F7FFF7F7
F7FFF7F7F7FFF7FFF7F7FFF5F7F7F7F7F7FFF7F7FFF7F7F7
F7F7F7F7F7F7F5F5
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFF7
F7F7F7F7F7F7F7F7F7F7F7FFF7F7F5F7F5F7F7F7F7F7F7FF
F7F7F7F7F7F7F7F5FFF7F7F7F7F7F7F7F7F7F7F7F5F7FFF7
FFF7F7F7F5FFF5FFF7F7F7F5F7F7F7F7F7F7F7F7FFF5F5F7
F7F7F5F7F7F7F7FFF7F7F7F7F7F7F7FFF7F7F7F7F7F7F7F7
F7F7F7F7F5F7FFF7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F5
F7F7F7F7F7F7F7F7F5FFF7F7F5F7F7F5F5F7F7F7FFFFF7F7
F7F5F7F7F7F7F5F7F7FFF7F5FFF7F7F7F7F7FFF7FFF7F5FF
F7F5F7F5F7F7FFF7F7F5F7F7FFF5FFF7F5F7F5FFF7FFF7F7
F7F5F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F5F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7FFF7FFF7F5FFFFF7F5FFF7F7
F7F7F7F7F7F7FFFFF7F7F7F7FFF7F7F7F7F7F7FFF7F7F7F7
F7FFFFFFFFF7F7F7F7F5F7FFF7F7F7FFFFFFFFF7F7F7F7F7
F7FFFFF7F7F7F7F5F7F7F7F7F7F7FFF7F7F7F7FFF7F7F7F7
FFF7FFF7F7FFF7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFF7FFF7F7F5
F7F5F7F7F7F7F7FFF7F7F7F7F7F7F5F7F5F7F5F7F7F7F7F7
F7F7F5F7F7F7F7F7F7FFF7F7F7F7FFF5F7FFFFF7F7F7F7F7
F7F7F7F7F7F7FFF7F7F7F7F7F5F7F7F7F7F7F7FFF7FFF7F7
F5F7FFF7F7F7FFF7F7F7F7F7F7F7F7F5F7F5F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFF7F7FFF7F7
F7F7F7F7F7F7F7F7F7F7F7F7F5F7F7F7F7F7F7FFF7FFF7F7
F7F7F7F7F7F7F7F7FFFFF7F7F7F5F7F7FFFFF7F7F7F7F7F7
F7F7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7FFF7F5F7F5F7F7FFF7F7FF
F5F7F7F7F7F7F7F7
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0113379 0.97619 0.464853 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00751202 0.0192308 0.00751202 [
[.5 1.0125 -32 0 ]
[.5 1.0125 32 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -93 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(NTSC) show
93.000000 12.812500 moveto
(style) show
123.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
128 string
128 128 8 [128 0 0 128 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
F0F1F7F7F0F1EFEFF7EFF1D5D5D5D6DCD6D6D6D6D6F1EB95
CDD6CDCDC7CFCFC6CFD0CFD0C7C7CFCFD5D5D0D0CFCFCFD0
C4D0D0D0D8D8D8D8D8D8D8D5D8D0D0D3D8D0D0D0D0D0CFCF
CFCFD0D0CDD0D0CFD0D0CFE4F1E4A1C7C7CFCFC7C7C7CDCD
CDCDCDCDD5D5D1D5DED8DEDEDED6DED5CECDC3C3C7C7C6C3
E2E1B8D4EAF3F7F0
F0F3F3EFF1F7F7F0F0F7F1EFD6D6D6D6D6D6D6D5D5D5EBB1
D0D5CECDCDC7C7C7C9CFD0CFD0CFC9D0D5D0D0CFCFC4C9CF
CFC7CFD0CFD0D5D3D0D0D8D0D0D8D0D0D0D0D0D3D0D0CFCF
D0D0D0D0D0CDC7D0D0CFD0CFE4F1B59DCFCFCFC7C7C7C7C7
CFD0D0D0D5D0D5D0D5D5D6D6D6DED6D6CDCECDCDC7C7CDE9
EAC6C5C7EAF3F0F1
EFEFEFF1F0F0F0F1F0F0F7F7F3D6D5D5D5D3D5D5D1D5E5EB
8CCDD1CEC7C2C7CFCFCFD0CFD0CFC7C4D5D5D0CFC9C9C6C6
C2C2C2C9CFD0D0D5D0D0D0D0CFD0D0D5D8D8D5D3D8D0D0D0
D0D0D0D0D0CFD0D0D0D0D0D0CFD6F1E494C7C7C7CFCDC7C7
CFC7C7D0D5D5D5D5D5D5D6DCDEDCD6D4D1CDD0CDCDD4DBDA
E9DAC6C7E0EFF7F1
F1F0F3F7F0F7F7EFF7F7F1F0F1EFEFDED1D5D0D0D0D0D0EB
DCBACDCECEC7C7C7C7C7CFD0D0CFC7C7CFD0D0D0C9CFC6C2
C6C6C2C1C7CFCFD0D0CFD0CFCFCFD5DED8D8D8DED8D8D5D8
D8D0D0D1D1D1D0D1D1D0D0D0D0D0D6F1E49DD0D0D0D0D0D5
D0D0D1D0D5D0D5D1D5D6DEDCDCD6DCD1D1CED5CEEADBDAE9
C6E0CDC6EAEAEAF1
F0F3F0F3F7F3F3F0F7F7F7F7F1F7F0F1DED5D8D0D5D0D8EB
EBBAD0D1D4C7C7C7CFC7C7CFCFD0CFCFD0CFC9C9C9CFCFCF
CFCFC9C2C6C7CFC4C4C4CFD0D0D0D0D0D8D0D0DEDED1D8D3
D8D3D0D5D5D1D1D5D5D5D0D5D0D0D0D6F1B8BDD0D5D5D5D0
D0D0D5D5D5D5D8D5D5D8DEDCDCDCD6D6D6CEDCEFEAE9E9EF
D4E5C6C6EAF7F1EF
F0F3EFF3F0F1F3F7EFF3F3EFF7F7F3F7F3E2D5D8D5D5D5D6
EBE9D0D5D5CECDC7C7CFCDD0D0C7C7CFC7C2C9C9C6CFCFCF
D0CFD0D0C4C2C2C9C2CFC7CFD0D0D0D0D0D3D8D8D0D6D5D5
D5D8D5D8D5D6D5D1D5D1D1D1D0D5D0D0D6F1C7BDD0D5D5D5
D1D5D5D8D8D8D8D5D8D6D6DCDCDCD6CECCC6DBE9F1CDDBCD
D6EAC7DBF3F3F3EF
F0F7F7F7EFF7EFF3F3F7EFF7F7F0F7F7F7F7F1DCDCDEDCDE
DEF1DBD1D6D6D4CECDC7C7C6C6C7C1B9C1C1C1C6C1CFD0D5
D5D5D5D8CFCFC2C9C6C9C2C6C7C4CFCFD0D0D5D0D0D0D0D0
D1D0D0D5D5D1D1D1D0D0D0D0D0CDD0D0CDDCF1E4CDD0D0D0
CFD5D3D8D8D5D8D5DED6DCDCDCCECDBAB4C7EAE0EFCED4D5
D4D4C5EAF3F1F7F0
F0F1F3F3F3F7F3F7F0F0EFF0F0F7F3F7F7F7F3F0E5E4E4E4
E2E2F1DC9ED6D1D0C7C7C7C7C6B9B9C1C1C1C1C1C1C7CFD0
D5D5D5D8D0D0C4C2C1C1C2C7C2C1C1C2C7C7C7CFC7C7C9C7
CFC7CFCDC7CDCFCFC7C7C7C7C7C7C7CFC7C7DBEBCECDCFD0
D0D0D0D5D8D5D5DEDED6D6D6CDC7AAB5B4CDDBCDB8C7CFC5
DBCEC6E9F3EFF1F0
F0F7F0F7F7F7F0F1F3F3F7F3F0EFF7F3F7F7F0F7F0F7F3F3
F7F7F3F3F1C3CDD0CDC7C7C7C2C6BDC6C6C9CFCFC9C1C9CF
D5D5D5D5D8D5CFC3C9CFC4C9C9C7C7C1C1B8B9B8B3B9B8B8
B8B3B8B8B9B9B9B9B9B9B9C6C2C6C6C6C2C1C6B9D5D5B69D
B9C7C7D0D0D0D5D6D6DCD6CEA0A9B8BBB8B8CECDC7C5C6E0
D4C6DBE9F0F3EFEF
F7F3F7F1F7F7F7F3F3EFF1F0F0F1F7F0EFF7F0F7F3F7F3F0
F7F3F3F1F7F0C6AADAC7BAC7C7C6BDBDB9C1C6C9C9C1C6CF
CFD8D5D8D5D0D0C9C9C9C9CFC9CFCFCFC9CFC9C9C6C2C6C2
C2C2C6C2C2C9C6C9C7C7CFCFC2CFCFCFC7CFC7C7C9D1D4D5
C767C2BAC7CDCDCEB6938C8C9AB8C5C7B8C5C6C7D4CDB8DC
DAB8E2E0F1F3F7F0
EFF0F7F0F3EFF0F3F3F7EFF3F7F7F3F3F3F7F3F7F3F7F0F3
F3F0F7F0F3F3C6A9B9B4BAC6C6C6C6C7BDC1C6C9C9C1C5CF
D0CFD0D5D5D5D5CFC9C9CFCFCFCFCFCFCFC9C4CFCFCFCFC7
C6C9C9CFCFC9C9C9C7CFCFCFCFCFC9CFC9CFCFD0CFC7D0CF
D4D1DBB69E9EB0968C9A8C93A9A9C5B9B5E9C5C5CCB2D6E2
C6E0CEEFEAEFEFF7
F7F0F1F7F0F7F7EFF1F1F7F3F7F0F7F0F3F3F7F0F7F7F7F7
F0F0EFEFF3EFCECDA0B5B5A1C6C7C2C6BAC5C6C1C9C5C5CF
CFCFD0D0D5CFD5CFCFC9C9CFCFCFCFCFCFCFCFC4C9C9CFCF
CFC6C9C7C4C9CFCFC4CFCFCFCFC9C9CFC7CFC6CFCFCFCFC7
C7C7D4D5D5C37479938C93A0A0A1A0B4BDE0A9B7CDB2CEDA
C5EFE9EFEFF0F0F7
F0F7F7F0F0F7F1F7F7F7F0F7F7F3F1F7F7F7F7F1F3F7F7F3
F0F0F3F0F0F0D5CEB6A0B58B79BAC6C2C2C6C2C6C3C1C6CF
CFCFCFCFD5CFCFCFCFCFCFCFCFCFD0CFCFCFCFC9C9C9CFC9
C9CFC6C4C9C9C9C6C7CFD0CFCFC4CFCFC9C9C9CFCFC7C7C7
C6B9B0AA8C7D8C8B898BA09AA0A1B7B7B8CDB2B7C5B7DACD
D4E9EFF3E9F7F7F3
F7F3F0F3F1F7F0F7EFF7F0F7F1F7F0F7F7F7F0F3F7F7F0F7
F1EFF0F7F1F0E2E9DA9AA08B7C61C2BAC6B9BAC2C6C5C6CF
CFCFCFCFD0CFCFCFCFCFC9C9C9C9CFC9CFCFCFC9C9C9C9C9
C6C6C6C9C9C9C9C6C9C9CFC6C9C9CFCFC9C6C9C9C9C1C6B9
B8AAA0827D8C9A9A9F938BA0A0B1B8B7C6B8A9B7B7CDCDCD
DAF3EFF1F1F3F3EF
F0F3F7F3EFF7F7F7F1F7F3F0F7F0F7F7F1F0F3F0F7EFF7F3
F1F7F3F3EFF1DBF1CD9A8C8B766149B3B8B9C6C2C6C1C5C7
CFCFCFCFC9CFCFCFCFCFCFCFC9CFC9C9C9CFCFCFCFC3C3C9
C9C9C9C4C9C6C3C5C6C4CFC9CFC9C6CFCFC9C9C6C1C1B8B7
A9A98C79939A8C9AAA9A939AB1A0B5A9B4B2C5C5C5E2B8CE
EFEFF3EBF0EFF7F3
F1F0F0F1F0F7EFF1EFF7F7F7F1F7F1F1F7F0F7F3F0F7F0F1
F7F1F7F3F1EFE2E9CEC38B937C614949B9B9C1B9C6C5C1CF
CFCFCFCFCFC9C9CFCFC9C9C9C9C3C6C9CFCFCFC9C9C9C6C3
C5C1C9C9C9C3C6BBC6C5C9C9C9C9C9C9C5B7B7B2A9A9A9A9
936F618CA9A07A9AA1B5B1B19A9AA0A9B8B2C5C5E9C6CDDC
EAE9EAF1F1F0F7F3
EFF7F3F0F7F0F0F3F7F3F3F7F3F7F3F7F7F3F7F3F1F1F7F3
F0EFF3F1F3EFF1E0E0B5938C746154493FB8C2B4C5C1C5C9
CFC9C9C9C9CFC9C9CFC9C9CFC9C9C3C5C9C9C6CFC9C3C1C3
C1C1C1C1C5C1C1BBBBBBC3C9BBC9B7C5C1BBB2B2A9A19382
616E7493A0A099A9A9B1A9A9B19AA0B2B2B7C5C7C6CDDAE9
EAE0EAF3F3F0F7F7
F1EFF7F7F7EFF7F7F7F1F0F7F1F3EFF3F0F0F7F7F7F3F3F7
F0F0F1F3F1EAE9D4E29A938B6E6161543F25B0BAB9C1C1C7
C6C9C9C9C9CFC9CFC9C9C9C9C6C9C9C3C3C5C3C9C9C6C5C3
C1C3BBB7BBC3BBBBC3BBC5C1BBB7C1B8B8B7B2AA9B827974
6F7A96A19A99A0A9A09393A09AB1B2B2B1C5C7C7CDE9E9E2
EAF3F1F7F7F7F7F7
EFF7F3F7F7F7F1F3F7F7F3F0EFF3F7F7F7F7F3F0F3F3F3F7
F3F3F3F0F1F3EADAE0A0938C74616154373725B9B9C6C2C6
C6C9C9C9C9C9CFCFC9C9C9C9C9C9C9C5C5C9C3C6C3C4C1C1
C1C1BBBBBBBBB7B2B7BBB7C6B2B8B7B7AAB3A98C6E79527A
828CA09A999F99B1A9A9A9B1B1B2B7B5C5C6C7C7D6DCE2E9
EFF1F7F3F7F3F0F7
F7F7EFF7F3F7F7F7F3F3EFF3F7F0EFF3F3F7F7F1F3F7F0F0
F3F7F3F0F1EFE9E0D5A0937D746F6149372E3FB9B9C1C6C6
C7C6CFC9CFC9C9C9C9C9C3C9C9C5C9C3C6C3C1C1BBC1C1C1
C1BBBBB7B3B2B2B2B7C6B7AAA9AAABAB9B9B8B8C5B6E6F79
6F8C9A939399A9A9B5B8A9B1C5B5B7C5C5C7C6D6DCDCF1F1
F7F7F3F3F7F0F7F7
F7F3F1F1F3F0F7F1F7F1F0F7F7F3F7F1F7F3F3F3F7F0F0F7
F7F3F7F1F3EFEBDAB5A093826E7C615A3F3F4F55BAC5C6CF
C6C6CFC9C9C9C9C9C9C6C9C6C1C4C9C5C3C3C5BBC5B7C1C5
C1BBBBB3B3A1A9B8C6B89BA1A9A1A9A18C8B76748C7A8C8C
96A0A1999A99A99AA1A9A9B2A9A9C5C5C5C6D4DCE9E9F3F7
F0EFF7F7F3F3F7F3
F7F7F0F7F0F3F3F7F7F1F7F7F7F7F0F3F7F0F3EFF0F7F0F3
F7F1F3F1EFE9EAD1B593937D82795A5A49525437B9C6C7CF
C6C6C9C3C5C9C3C5C9C9C5C3C5C3C3C9C1C1C1C5B7C3B7BB
B8B7B3ACA1A9A9C5C69BA1A9A99B897E6F8B7C74798B8C7D
93A0A09A9382B5A0B5A1C5A9B2C5C5C5C5CDCEE9EAEAF3F7
EFF7F7F7F0F7F7F7
F7F0F7F1F7F7F7F7F7F3F7F7F7F7F3F1F7F7F3F3EFF7F3F7
F0F0F7F7F1E9E9B9B593827A6F6F545A61614925C6C1C7C6
C9C6C9C3C3C9C3C3C3C3C3C3C5C5C3C1C5C1C1B7B7B7BBB7
B8B8ACA99B9BB7B99B949499948981667A8B7C7C7C7D7A7D
93A0A19696A0AAA1A9A1A1B1B1B2C6C6C7DCF1E9EAEFF7F7
F3F7F7F0F3F0F7F7
F7F7F7F0F7F7F3F7F3F7F3F7F7F7F7F3F3F3F3F3F7F7F3F7
F0F7F7F7F0E9DBB5A996897D7A5A5261675A453FC7C2CFC7
C1C9C6C6C9C3C4C5C3BBC3C3BBBBBBBBC3B7BBB8B7BBB2B3
B2AAA9959BA0A9A193949393896F7676799A8C8B7C79968C
93969A9FB5A9A99FA1A1A1A9C5C7CFC7DCE2E9EFE9EFF1EF
F7F7F3F7F7F7F7F7
F7F3F7F7F7F3F3F7F7F3F7F7F7F7F3F7F3F3F7F7F3F7F3F3
F3F3F3F1F0E9DAB6A193827A79676179613F3F37C7C2C6B9
C6C9C9BBBBC3C1BBBBBBB7BBBBB7B7BBB3BBB3B3B3B3B2B2
A9A9A19A94AA99897E8C82896E827C797A8C9A93828C898C
9682999FB5B5B5A0A1B5A0A9C5C6CDDCE9F1E9EFE9F1F1F7
F7F7F3F0F3F0F3F7
F7F7F7F3F7F7F3F7F7F7F3F7F7F7F7F7F7F7F7F7F3F7F3F3
F7F1F0F7F7E9C7A9A996827A7A5A6F6152374537C6C6C6C6
C6C1C9C5BBC3BBB7BBB7B3B7B3B7B3B3B3B8B7B2ACAAB2AA
AAA9A193A19B897E827A7A677676616F7D9A9A9AA18C8C82
82969F93B0B5AA9FB5B8A9B7C5C5DCE4E9E0E9EFF3F3F3F7
F3F7F7F7F3F3F7F3
F7F7F7F7F3F3F7F3F0F7F7F7F7F3F7F7F7F7F7F3F7F7F3EF
F3EFF7F3F1F1B4A999936F7667606F604F454F3FC7BAC6C1
C6C1BBC5BBBBBBB7B3B3B3ABACB2ACACB3B2B2A9ABA9A9A9
A99B9B93A193827A76766E7A7667676F7C8B9A939A939682
827D93A9AAA9B6B6B5A1A9B7C6CEE2E0E9F1EFE9F3F7F3F7
F7F7F7F7F3F7F7F3
F7F3F3F7F3F3F7F7F7F3F0F7F7F3F7F7F3F3F1F0F7F3F3F7
F7F3F7EFF1DAB6A993897A82616F6F673B373F45C6B9C2B9
C1C1BBBBBBB3B7B2ACB2ACACABA1A1A1A9A9ACA9A9A1A1A1
9B9B9496827A796F767A7A6F6F6F747C7D8B9AB1A9B79979
79829993A9B5B5B5A0A0A0C5CDCEE0E9E2EFE9F7F3F7F7F7
F7F3F7F7F7F0F7F3
F3F7F7F3F3F1F0F0F3F7F7F7F0F7F3F7F3F7F1F7F7F7F7F7
F3F0F3F1F1C7B59F96826F7667795A5233333F3FC6B9C1C2
C1BBBBB3B2B2B2B2ABAAA9ABA9A9A1A1A1A1A9A9A1A1A194
949389937D6F677A6F7A7A4F4F5A768B8B8B93A0A9A1B596
829393A193B6B6A1A0A1A0C5CDE9E0E9E9EAF0F7EFF1F7F7
F3F7F7F7F3F7F7F7
F7F7F7F7F3F7F7F7F7F7F7F7F7F1F3F7F1F7F3F7F3F7F3F1
F3F7EFF3E0BDB596897A7667676F5A493F454549B9B9B8B8
BBB8B3B8B3B3AAABABA1A1A1959B9B95A1A195A1A1A19493
9493829A7A5A76766F67524F37748B768B7D8CA0B1AAB796
96A096A19FB5A1A1939AB7CDDCE2E2E0EFF1F1F7F3F3F7F7
F7F0F7F3F7F3F7F7
F7F7F3F7F3F3F0F3F3F7F3F7F7F7F7F7F0F1F3F0F7F7F3F7
F7F0F3EFCEB6A6898976766F676745453F454545B9B8B9C7
BCBCB7BCB7B7B8B3B3AA9B939B8E939393939B9B93939389
897E82936F556F7A5A4F4955616E8B8B828B79A0A9B5A19F
93999996B5B5A0A9A0B5B5CCF1DCE0EFEAF7F7F7F7F3F7F7
F7F7F7F7F7F3F7F3
F3F7F7EFEFF7F3F7F7F3F3F7F7F0F7F3F7F1F3F1F7F7F3F3
F0F0F0E9CCB59F89827A6F8260672E4E45453F5DB9CDD0D0
D0CFCFC4C4C4BDBCBCB8B3AA8E8E8C8E8E898989938E898C
827A7A8C5A5B6F66523F4574526F8C8B8279829AAAB7B8B5
9F9F897DB5B59FA1B5B5C6EFE9E9E9EFF1F3F7F3F7F7F7F7
F3F7F7F7F7F7F3F0
F7F3F3F7F7F7F3F7F7F7F7F7F7F3F7F7F3F7F7EFF7F3F7F1
F0F3F3D4BDA9998981676F676F52374F4E453F8FD0D1DED3
D3D0D0D3D0D0C4C4C2BCB8B3ACA18C82898C8C8E7E898C89
827A6E82676F8252493F537C546F7D8C7C7982939AB7B8B5
A99F8296A9A9A9A9C5A9C6EFE2DAEBEAF7F3F7F0F3F0F3F3
F7F7F3F7F7F7F7F7
F3F7F1F7F3F1F7F0F7F7F7F7F3F1F7F3F3F7F3F3F7F3F0F0
F1F3F3D4B49F96817A7A6F676F374555454596D1D8DED8DE
D3DED3D8D3D0CFD0C4C4BCBBB3B2A9A1828282828C828982
76765E52826793493F2E37797D617D9A79968293A9B7C5C7
B67D9696A199A9B6B5B2EAE2D6E9F1F3F7F7F1F7F7F7F7F3
F3F7F7F7F7F3F7F7
F7F3F7F7F7F7F7F0F3F1F7F7F7F1F3F7F3F3F3F3F7F7F7F7
F0EADACDA69F8976676F6F675837555545CED8D5D8DEDEDC
DEDCD3D3D3D8D0CFCFCFC6B9B8BBB3AAA17E7A7A827A7E7A
766F524F93529B6F45532E528C547D8C7C939393A0A9C6C7
B59989969F9FB5B6B5C5E0DBE0EFEFF7F1F7F3F7F7F3F3F7
F3F3F7F7F7F7F7F7
F7F7F7F7F0F7F7F7F7F7F7F7F0F3F1F7F7F3F7F7F7F7F7F3
EFEAD1C39E96897A6E6F6767453F4F458BD5D8D0D8D8DEDE
DEDEDCDED3D3D0D0D0C7C2C6C1BBB9B3AA95A176767A7676
6E60584E8C8189823F2E4F6F8C938C8C937A99969FA9B5C6
C59682968C9FBDC5BBB6CDE9F1F1F3F7F3F7F3F7F3F3F7F7
F7F7F3F7F7F7F3F7
F0F7F3F7F7F7F1F7F3F3F7F3F3F3F1F7F3F3F1F7F7EFF7F0
EFE0D1B49E9682765E675A6733454E66D0D1D8D8D8D8DED3
DED3D3DED3D3D0CFD0D0CFC2C2C1B9B8B3AAA1956F767669
6F58553776AA5AA16E7A3F745B96748B8C968F9F89B5A0C7
D596829699A6A9B5B6C5E0E9EAF1EFF3F7F3F7F7F3F3F7F3
F3F7F3F3F7F3F7F7
F3F7F3F7F7F7F3F3F7F7F7F7F3F3F7F3F7F7F7F7F7F7F3EA
EAD4D1A69981826E67675D453F5864D1D0D5D8D8D8D3D5D0
D0D0D0D0CFC4C4C7CFC6C9C2C2B8BBB9B8B3A9A19B6F606F
5B5A45455E968976A6548967767D8C798C966F9696A9A9B4
B8C5967D96A69FB5C5DBEFE0EFF1EFF7F3F3F7F3F7F7F3F7
F3F7F7F7F3F7F7F7
F7F7F3F7F7F7F3F7F3F3F3F3F7F7F3F7F3F1F0F3F3F7F7EA
DBD4BB9E89816E6767673B453F3FD1D1D8D5D0D0D3D0C9C2
BCBCB8B8B8B3B8B8B8B8C1C1C1C2C1B8B8B3ACAAA99B7E67
5D584E45536EA19684A98C895279938B8C798989AA9FA9B5
C7CE969FAA9F99B4C6F1E0F3EFF1EFF7F7F3F7F0F3F7F3F3
F7F7F7F7F7F7F7F3
F7F3F7F7F7F3F7F7F7F7F3F7F7F7F7F7F3F3F3F7F7F3F3EA
DAD1B69F8282765B675D3F4558CED5D5D8D5D0D0CFC7BCBB
B3ACA6A6A6A6A6B3ACB3B8B3C1C1C2B9B8B3B0AAA1A19466
53554533456CA18167B08CA0896F7A9A8C829689A99FB5A9
B5CDB5A9A6A6A9B6C7E9E9F1EFF3F7F3F7F7F0F7F7F7F3F7
F7F3F7F7F7F7F7F7
F7F3F7F7F3F7F7F7F7F7F3F7F7F7F7F7F7F3F1F1F7F3EFDB
D4D2A689816F765E5845454955D1D1D0D0D0D0CFC4918797
979D9D9D9D9D87878787AAB8B8C1C1C1B9B8B3AAAAA19593
55453F2E3F5E81AA8F95B5A0A99F8C829396798296A996B7
B6C5C7A6B59FA9C5D1DBEAEFEAEFF1F7F0F3F7F3F7F7F7F3
F7F7F3F7F7F3F7F7
F7F3F7F3F7F3F7F7F7F7F3F7F7F3F1F7F7F3F7F7F1F7EAE0
DAB69F84766F67555E4E4555D6D1D0D0CFD5D0A69D9D9DD1
C4A6A6B7C49D9D97958D87AAB8B9C1C2B9B8B8B0AAA19D94
895333332E5E33B0B86FB689B2B59693A0749389969FA1AA
B6C7CE9E8F9FA9B4E9E9EFEFE9F7F7F0F3F3F7F3F7F3F3F7
F7F3F7F7F3F3F7F3
F3F7F3F7F3F7F3F7F3F3F7F3F3F3F3F3F3F1F7F7F0F7DBD1
B49F8F845E675B673745458BD5D5D5D0CFCFCF979D9D9791
91919D8787797E7EA68D8D79B1BCC1C1C1C1B8B0AAAAA1A1
93814545213F668F9F8996B593B7D5968293937A89A09FA9
A9C7C7A69FA69EB4E9EAF1EAEAF7F7F7F7F7F7F7F3F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F3F3F7F3F3F3F7F3F3F3F7F7F3F3F7F3F3F3DBC9
A99F816E5B67583F4F3F67D6D6D5D0D0CFA69D8160657081
7070796D604F5A654A605A53699DC1C1C1B8B8B8AAAAA9AA
948966252145536496B067B089AAC6D5A1A17C9389969989
B5C5C7C3A9B5A6BDE0EFE9EFF3EFF7F7F3F7F3F7F7F7F7F7
F7F7F7F3F7F3F7F7
F3F3F3F7F7F3F3F7F3F7F3F7F3F7F3F3F3F3F3F1F3EADBC3
9E896E5B665A55555553D6D6D1D5D8D0CFC4CFA68D877E87
7E87977E7E7E7E7E7EA9B0B1B8B8C1C1BBBBB8BBB3AAAAA9
A1947C41212141647CAA9F76A989C6C6D581939389969689
B5B5C7CD9FB5A9DAEAEAE9E9F3F3F3F3F7F7F7F7F3F7F7F3
F7F7F3F7F7F3F7F7
F7F3F3F7F3F7F7F7F3F7F3F7F7F7F7F7F1F7F3EFF1E9D2B6
8F7676665A584E55525DD5D0D5D5D0D5CFD5D8D8DEDCD1D0
DED0CFD8DED1D0C7C2C7C2C1C1C2C1C2C1BCB8B8B3B3AAA9
A1A1895D35166453647C966F937A93C6C6A9A196828296A1
A9A1C7CDA6A699E0E9E9EAE9F7F7F7F3F7F7F7F7F7F7F3F7
F3F7F7F7F3F7F7F7
F3F7F7F7F7F7F3F7F7F7F3F7F3F3F7F7F3F1F3F3EACCC6A6
816E5D5D583F55554FBDD5D5D5D3D8D0D8D0D8D8DED8DED8
DECFD0D0D0C2C2C2C2C6C2C6CFC2C1C6C2BCBCB8B3B3AA9D
A1A189692E2A535D8B7CA66F679996B9C6CFB59393998289
89A1C7CDA9B69FE9EAE0E9F1F7F7F7F3F7F7F3F3F3F7F7F7
F7F7F7F7F7F7F7F3
F3F7F3F3F3F3F7F1F7F7F7F7F3F7F3F7F3F3F1F3F3D2A689
6F7658584555555555D5D5D1D5D8D3D3D8D5D8D8D8D8D8D8
D5D0CFCFCFC2C6C9C2C7C2CFC2CFC2C2BCBCC1B8B3ACB3A9
A1A194764E41215A5E6E6F816F8984A1C5C5A1A993968296
82A9B5C7B49FAADBE9E9DAF7F3F7F7F3F7F3F7F7F7F7F3F7
F7F7F3F3F7F7F7F7
F7F3F7F3F3F7F7F7F3F7F7F7F7F7F7F7F7F3F3F1D2C99E82
76586645553F555845D5D1D1D5D8D8D8D3D8D8D8D8D5D8D8
CFCFC2CFC2BBC1C6C2C4C9CFC4C4D0CFC2C2BCBBB3B3AAA9
9D959482532E33536C757C8F76666E9E99B1CFB58C99769F
96AAA9C7B496CEDAEAEAEAF3F7F7F7F7F7F7F3F7F7F7F3F7
F3F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F3F7F7F7F7F3F3F3F7F7EACCAD9E76
6F6E5355555355458FCED1D1D8D8D8D8DED8D5D8D8D8D0D0
C2B8B3BCB9B3B8BCC1C2C9C7CFD0D0C4C4C2BCB8B3B3AAAA
A9A18E7E66414548645E7C6E825D6F5EB6C5A9B2999F8489
96A6A9C6BD9FE0C7F3EAF7F7F7F7F7F7F3F7F7F7F7F7F7F3
F3F7F7F3F7F7F7F7
F3F7F7F7F7F7F3F7F3F3F7F7F3F7F7F7F1F7F3F3C69E816E
5B5B55454555553FCED1D1D3D8D8D8D8D8D8D5D8D8D8D0C4
BDC1ACB3B3AAB0B8B8C1C2C9C4CFCFCFC4CFC3BCB8B3AAAA
A99594896941162F535D765E826F6F55B093A9D59F999989
96939FC6C3C3D1DBDBD5F7F7F7F7F7F7F3F7F7F7F7F7F7F7
F7F7F7F3F7F7F7F7
F7F7F7F7F7F7F7F3F7F7F7F3F7F7F7F7F7F7F7EAB68F6E5D
5B45554E55533F3BD1CDD0D0D8D3DEDED8D8D8D3DCAC97D0
D0C4B7787895AC89A9B8C2CFCFD0D0D0CFC4C2BCBBB3B3AA
A9A1947E764E212F3B535E6476765D766696B7A9B793966F
8989A9C5C3EAB4EABDF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F3F7
F3F3F7F3F3F7F7F7F7F3F3F7F3F7F7F7F7F7F3E19F816E6F
5555454F55453B5ED1D0D5D8DED8D3DED3D8D5D8DED5D1D3
D3D0C1B8B9BBC1B39BAAC2D0D0D0D0D0C4CFCFC3BBB8B3AA
A1A1948E7C6616212F485A665E7C5D6733B59BA0C6899676
81969FB4CCCCB3BDF7F7F3F7F7F7F7F7F3F7F7F7F7F3F7F7
F7F7F7F3F3F7F7F7
F7F7F7F7F7F7F3F7F7F3F3F7F7F7F7F1F7F7F7DB966E6945
53584E5558373785CDD3D3D3DCDEDEDEDCD8D8D3DED1DCDC
DCD3CFC1BDBDB9B8B3B3C4D0D0D3D0D0D0C4C4C4C1BBB8AC
9D9D94897A6E162A21535E6E4E765D673B9F96B5C6899681
898F9EB6CCCCC3D1F7F7F3F7F7F7F7F7F7F7F3F7F7F7F7F7
F7F7F7F7F3F7F7F7
F7F7F7F3F7F3F7F7F3F7F3F7F7F1F7F3F3F7F3D58166675D
5555585B4F3341CED1D8D8DEDEDEDCDEDCDED3D0DEDEDCE5
DCD3D0C7BCB7B9B8B3BCC4D0D0D5D0D3D0CFCFC4C4BCBBB3
ACA195897A67330C2A4E336F5D764F5D668199B2B2A98996
818989B4CDBDD5F3F7F7F7F7F7F7F7F3F3F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F3F3F7F3F3F7F7F3F7F7F7F19F6E6E454E
4E5558552A372AD0D3D6D3DEDEDCDEDEDEDEDED8D8D3DCDC
DCD8D0BCB1B3B8B1B9C2D0D1D1D5D8D0D0CFD0CFC4BCBBB8
B3A99589817653142141615E666E555D537C93A1B8C78289
7C899FC6CDA6D1F7F3F7F3F3F3F7F7F7F3F7F7F7F7F7F7F7
F7F7F3F7F7F7F7F7
F3F3F7F7F7F3F7F7F7F7F7F7F3F7F3F7F7F7F0906E58455E
58585521332E41D0D8DEDCDCDCDCDCDCDCDCDEDED3D6D3DE
D3D1C4C2B1B8B9B9C2D0D0D0D1D3D8D1D3D0CFD0C4C4BCBB
B0B3A19481765B1635334E535D5D6F5D5D8496A0B8D58982
76848FB4CCD1F3F7F7F7F7F7F7F7F7F7F7F7F7F7F7F3F7F7
F7F7F3F3F7F7F7F7
F7F7F7F7F3F7F7F7F7F7F7F3F7F3F7F3F3F3F3906755555E
535558332A33B4D5D5DEDCDCDCDCE4E4E4DCDEDEDED8D1DE
DED0C4B9B9B8C1C2C7D0D5D1D3D3DED6D3D1D0D0C4C2C2B9
B3AAA9947E766E2A143B335E6655676F5D7CA6A9B7D58199
668F81C5D4D1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F3F7
F3F3F3F7F7F7F7F7F7F7F3F3F3F7F7F3F3F7CE7C664E5D5D
5855332A21C4D6D3DEE4DCDCE4DCDCDCDCDCDCDCDCDED8DE
DED3D0C2B9C1C1C2C7D1D1DCDED3DCD3DED6D6D1D0CDC4C1
B8B0AAA989766F4E374553536E5D6F665B7CB0A9B5C79682
5D8489B8DAEFF7F7F7F7F7F7F7F7F7F3F7F7F3F3F7F7F3F7
F3F7F7F7F7F7F7F7
F3F7F3F7F7F7F7F7F7F3F7F7F3F7F7F7F7F77C675D3B6153
5358334541D0D1DCDEDCDCE4E4DCDCDEE4DCDCDCDCDED6DE
DEDED3C2B9C2C6C7C7CDD5DED6DEDCDED3D6D6D6D1D0C7C2
B9B8AAA98E7E69534545455E5D6F6E667A90AAA9A9B59979
58849EB6E0F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F3
F7F7F7F3F7F7F7F7
F3F7F7F7F7F7F7F7F7F7F7F7F3F7F7F7F3F7816F5345665E
554E45338CD3D6DCDCDCE4E4DCDEDCDEDEDCE4E4DCDCDEDE
DCD3D3C2B9B9C6C7D0D0D6D6D6DCDCD3D3DED8D5D1D0D0C7
B9B8B0A9947E695B3B3B4553586E6F6E67A9A9A9A9B0B57A
7A818FB7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F3F7F3F7F7F7
F7F7F7F7F7F7F7F7
F7F7F3F7F3F7F7F7F3F7F7F7F7F7F7F7F7F37C7C5E534E5E
583B4E5ED1D8D6DCDCDCDCDCDCDCDEDCD6DCDCDCDCDEDED1
DCDCDEC7BCB9C2C7C7CDD1D6D6D6DCD6DED6D1D1D0D1CDC7
C7B9B0AAA189765E4E3F45455E676C5E58B6A99FAAA6B867
81818BB5F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F3F7
F7F7F7F7F7F7F7F7
F3F7F7F7F3F7F3F7F3F7F7F7F7F7F7F3F7B2676C5D665D5B
45414ECDDED1DEDCDCDCDCE4DCDCDED6D1D1D6D6DEDED3D8
DCDCDED0BCB8B9BAC6BACED4D1DCD6D6D6D1CED1D0D0D0C7
C7BAB8B09D947667533345455376666666A69FA9A976C552
76969FB4F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F3F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F3F7F7F3F7F7F7F7F7F7F7F7F3F78696765376535B
3B5355CDD3CDDCDCE4DCDCDEDCD6D6C4CDD0D0D1D6DED5D8
DEDCDED0B7B8B1B9B9C7CED1D6CDCDC7CDCDCDCDD0D1CDCD
BDC6B8B0A994816758332E4553666F6666A6A1A1A958B769
6690B0CDF7F7F7F3F7F7F7F7F7F7F7F7F7F7F7F7F3F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F3F7F7F7F3F7F7F7F3F3F3F3F7F75A9B6675646653
336FBBD0BCD1DEDCDCDCDCD6D4D1D1D0BAB9C7CDD1D6CDD1
DCDCDEC4B9ACB6B1B4BDCDCEC7C7BDBDB8B8B1BABAC7C7C7
C6C6B9B0A1957E765E4E2137456666765E9EAA899658C576
5B9FB5DAF7F7F7F7F7F7F7F7F3F7F7F7F7F7F7F7F7F7F7F7
F3F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F3F7F3F7F7F7F7FF76855E665E692E
5D58D3A1B3D5DEDCDCDCD6CEBA9E96B1B09EBABAD6D6D1D1
DEDEDED0B9AAA6AAC6BACEBDBAAEA49096A6A6A6B0C6C7BA
BABAB8B0A69589695E53453B3B5E5D6C669096898967C567
5BA6A9DBFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F3F7F7F7F7F3F7F3F7F7F7F7F7F7F7F7A5847C535E53693B
67C3C4A6B1D5D6DCDCD1BD8F96BAB26C728CA69D9DD1D1CD
DEDEDECFC2AAB09EB0607995B1CE82608685848590B1B9B9
BABAB1B1A1957E7666535E33335E5E66768F9E828961C66F
7CB5B5EAF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F3F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F3F7F7F7F790A47C6C3B5E693F
33D3BBB7B9D6DED6CDBD9095C4DB756C5C7D86A69EBDB9CF
DEDED5D0C2B39E9095A660CEEA797A6E8E64A57C7290B0B0
B9B8B1AAA99081765D533B162A5E664E76908F768476B858
9EB6B6F7F7F7F7F7F7F7F7F7F7F7F7F7F3F7F7F7F3F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F3F7F7F7F7F7F7FFF38B5D553B5E5E5E
69D3B3A6B9CED5D0BA9E7A419DBA81B61A774E7A909EC2D5
DEDED8D0C6C19E967C969E76C85CBD1A725CA5355A85969E
B0B1B09E9F9481695E582A212A335E53817C84848976B558
96AACCF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F79BCB917A5C535E5E69
8DC4A6AAB8D1D5C2B095536B6B482F415E726B859EBCC9D8
D8DED8D0C9C2B39E95817A9393413341415348605C858F90
A1AAAA9E908969666653452A414545537681766F8981B56E
96A9E9F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F3F7F7F7F7F7F7F7
F7F7F7F7F3F7F7F7F3F7F7F7F7F7F781A5A266536C5E535B
94B7AAAAB8D1CECDC7B99E7E6C5C5C5C5E7A95B0C2D0D0D8
DEDED8D0D0CFC1B3AA9E906A858C836B5048537C969695A1
AAAA9EA1967E69665E5E4E33413B3B4E7C897C6F8996B576
96B0EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F3F7F7E99275534E53534576
94A1A69EB1CED5D5DED6D0D1C7C2BDC2C7C2AAB3BCCFDED8
DCDCDED8D5D0C1A9AC9EB0B1B09E9E9EA1AAB0B0B8BBB9B1
B0AAA1959689696C5E45453341534E457696766F939EB97C
9EE2FFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F3F7
F7F7F3F7F7F3F7F7F7F7F7F3F7F7FFFF4E663B45456E3B60
7E9DA196B0D5C7D8DEDEDCDEDEDCB795857C7EC2CFDEDEDE
E4DCDEDCD8DEC9BC95767C7E96C7CDD0CDC7C7C2C2C2B9B0
9F8FA196898176665D5E373333412E536681766E999FC684
A6EAF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7EAFF45553B45535E536F
78899695A6D0CCC6D1DEDCDCD390857A7EB0CFD8D8DEE4DE
E4DCDEDEDED8D8CFBC96695E697EB3BDCDD0D0C4C7B9B39E
84A19690817676664545333B332E5A6475847C679696B69E
A6F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F3F7FFB2FF5D4E53533B5E5567
69698590A6CED69EA6B0AA9D7E81AAD8DEDEE4E4E4E4E4E4
DCDCDCDCDEDCD8D8D8D5C2B0967A667C768796958F858490
9E9E9D968176765E762A4E4E45332F6A7681766E96A9907A
D1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F3F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F3F7F7AD7C53536A5E5353535E
676C7C84B0CED5D5D0B0A49DBADCE4E4E4E4E4E4E4E4E4E5
DCDCE4E4E4DEDEDCDED8D3D0D0D0CDCDA6858185859EA69E
A1A9A196817C815E4553453B21212A6C7A6684769FA67696
EAF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F3F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F3F7F7F7F3F7F7F7F7F7CB7661538372615E5366
666C8181AAD0D1D5D5DEDEDCDCDCE4E4E4E4E4E4E4E5E4E4
DCE4E4E4DCDCDCDCDCDED5D5D8D0D0D0C7CDCDC2B9B8B1AA
B09E96898184817653452E2121212A966C66A97689B576A6
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F3F7F7F7F7F3F7F7F7F7F7F7BB585A6491755E646164
6466847CAACDD5D5D6DEDEDCE4E4DCDEE4E4E4DEE4E4E4E4
DEDCE4DCDCE4DCDEDEDEDED3D8D1D0CDC7D0C2C2B9B0B0AA
AA9E9F967E818166764E33332A3B2E9E84669E8176B676C3
FFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7D25E726C7C6C726C645E
5D5D767C95C6D1D5D5D6DEDEDCE4E4DEE4E4E4E4E4E4E4E4
E4E4E4E4E4DCDCDCD8D8D8D8D8D0CFCDD0C7C6C1B9B8B1B0
AAA9A18981897C76533B453B21212A9F8576A9826C9E76F3
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F3F7F7F7F7F7F7F7F7F36C5E5E5E6A6C5E645E
645E84899FC2C7D5D6D8DEDEDCDCE4E4E4E4E4DEDEE4E4E4
E4E4DCDCDCDCDCD3D8D8D8D5D0D0D0C4C7C6C7C2B8B9B3B0
9EA195968981765E53414E2A21213B7CA98FAA897C6EB4F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F3F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7FF5C725E6C72756C6464
5E6C7C969EB8C7D5D6DEDEDEDEE4E4DEDEE4E4DEE4E4DCE4
E4E4DCDCDCDEDEDEDED8D8D5D0D0D0C4C2C2C2C2BCB8B1B0
AAA1968F8F85766645532E2A2A212F7A9E7C9F968B6ED5F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7FF835A667575646C5E61
756C7C909FB1C7D0D8D8D8DEDEDEE4E4DCDEE4E4DCDEE4DE
DCDCDEDCDEDEDED8DED8D8D0D8D0CFCFC7C6C7C1B9B8B1B0
9EA1958F8F76766653452E2116165C6C8481A69FB69FF7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7FF5E8584666C6A66646F
4E6C859696B0C6D0D5D8DEDEDEE4E4DCE4E4E4DEE4DEDCE4
DEDCDCDEDCDCDEDEDEDED0D3D5D0D0C4CFC2C2B9B9B8B1B0
9EA996907C7564535E3B21162F166A75766E9F9FA6E0F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F3F7F3F7F7F7F7F7F7F7F7F7F7E18561615E5E5D645E
6C6C8496A6B1C6D0D5DEDEDCDEE4E4DEE4DEE4DEDCDEE4DE
DCDCDEDEDEDEDCDEDED3D8D8D0D0D0C4CFC2C2B9B8B8B8B0
A6AA90857C7C7661453B21212F2175757C6F9FA6B1F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FF6C615E535D5A5361
6C768F96AAB6C6D0D8D3DEDCDEDEDEDEDCE4E4E4E4DCDCE4
DEDEDEDEDEDEDEDED3D8D8D8D0D8D0CFCFC9C2B9B8B1B8B0
B09E9090856C66453B2A2A16272182756F6EA6BBD2F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7BD6A5E5E5D5E5E5A
5E768596A6BAC7D0D8D8DEDCDCE4DCE4E4E4E4E4DCE4DEDC
E4DCDEDCDEDEDEDED8DED8D3D5D0D0CFCFC2C2BAB8B8B0B1
A1A19685847C66413B2A2F1F2A2A859066819FC6F7F7F3F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F3F7F7F7F7F7F7F7F7F7F7F7F7F7F7F37253535A5A5E61
5A758F9EB0B9CFD0D1D5D8DEDEDEDEDEE4DEE4DCDEDEDCDE
DCDCDEDEDEDCDEDED8D8D5D8D3D0D0D0C7C7C6C1B8B8B1AA
AA9696857C6C5E413B2F2A333321768F7693B0D3F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F785725A64615A61
64757C9FB6C7C7D0D8D8DEDEDEDCDCE4E4DCDEDEDCDCDCDC
DEDEDCDEDEDEDED8D8D8D5D5D0CFCFD0C7C6C1BCB8B8B3B3
A19690817666534141332A332116757C7696B8EFF7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFBD8575757561
61758B96AAC2CFD0D0D8D5D8DCDCDCDCDEDEDCE4DEDCDEDE
DEDED8DED8D8D8D8DED3D8CFCFCFCFC4C7C6C1B9C1B0B0B0
969685846C5E4E533B3B2A211441907C82A1B4F7F3F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F3F7F7F7F7F7F7F7F7F7F3F7F7F7F7F7FFFFEA7A75646C
6A6C819EA6B9CFD0D0D8D8DEDED8DCDCDEDEDEDEDEDEDCDE
DEDEDEDED8D8D8DED8D0D0D0D0CFD0C9C2C2C2C1B8AAB19E
9E9681695E644E41412F331A1484856E8999D4F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFA55E6A5A
6C6C8496AABAC7C4D0D0D8D5D5D8D8DEDEDED8DEDEDED8DE
D5D8D6D8D8D8D5D0D0D0D0CFD0CFCFC4C2C2C2B9B9B1AAB0
9685766E6664643B3B3321169082766E96BDEAF7F3F3F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFD1456484
61848496A6B9C6CDD0CFD0D8D8DED8D6DED8DEDEDEDEDED8
D8DED8D0D8D0D8D0D0CFD0D0CFCFC6C9C1C1BAB8B49EAAA1
90857C7664535A752A2127615E8476819FC7F3F7F3FFF7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFBB7C5E5E
6A858496AAB9BAC7D0CFD0D3D0DED5D8D8D8D8D8D8D8DED3
D3D0D0D0C4D0CFCFCFCFCFD0CFCFC1C1C2B9B9B8B09E9E90
817C6E64645E5E415341534E857C8F96B6C3F7FFF7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFADA64E5D
61667C8F9EA6BDC2C7CFC4D3D3D5D5D1D0D3D8D8DED1D5D0
D0CFC4C2C2C3CFCFC9C4C9C3C2C2B8BCB9B1B1AA9E9E9690
8184765A5A5353484E3B8B757C76AA9FC6F7F7F7F3F7F7FF
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFF7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E1CE3B4E
765E7C8B96B1B9BAC2C4C4CFD0CDD0D5D0D0D0D1D0CFD0D0
C9C2BBBCBCC1C3BBBBBBBBB3B8BCB0B8B0B0A6A99E908F8F
847C6664615A72615372907A8596B0C6C3F3F7F7F7FFF7F7
F7F7F7F7F7F7F7F7F7F7F7F3F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7AD8361
64756C7C859EB1C6BABDC2C2D0D0D0D0CDC7C7C7C7C2BAB8
B9B9B0B0AAAAAAA9ACAAA9A99EA1A1A1A195969E96908976
6C7A75607575536C76767C76968FB9C6F1F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7B27A
646C75849086969EB9BDC7CFCDC7C7C7C6B9B9B0B9C6B1B3
B0B19EA695A196AA8DA189968989968F8F909085969E8B91
84856C6C7A8564455E898F8996B4BDC3F7F7F7F7F7F7F7F3
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFF7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EA
927A617C846C96A6C3CECECEC7C7BDBAB0B4B1B1B0B1B0B0
9F9F969690969081908F7C76907C8F7C818584856C757A81
7A7C7A7C5E6472767C84849FBDBDA6F7F7F7F7F3F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F3F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F3F7F3F7F7F7F7F7F7F7F7F7F7F7F7F7F7
9286857E91ADB0A4BAB0BAC3C3BAB9B1B0B19EA6B0A69FA6
9E958F907C9E859E8F859684769E849085848B916A758482
727A856E766E766E7C8FB5BBB4B6D5F7F7F7F7FFF7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F3F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
FF7A8C7E758B9696A4BABDB9B4B1B6A6A6A6969E969E969E
909E847C866E8B84967C8584859F6C7C7C90847575646153
5A6C5E5E61616E829FB5CDA4B68FF7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7FF9B8685A5A6ADBDBDBDBDA6A6A6A69EA69E9E90909E8F
84856E8B8B6C5385648F8485856676844E536F6664666F6E
766E6E5E6F76B49EB6C36CA48BD3FFF7F7F7F7F7F7F7F3F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7AE8C6A7E768BAEBBBABDAD9E9E969E9E968B9196858F
8F6C9F846C9E6C64856C6C7564665D4E5E5E6F5E616E665E
58667C8F8FA69EC6BD8B84A48BF7F7F7F7F7F3F7F7F3F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F3F7F7FFF7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7FF6083A4868B9BB3BBB1AD85908B9E9E907E908F8596
858F647C7A6C84646C6E646A645A5E5E5E534E5E615E5D5D
6C84848484A6BB82828BAD9EEAF3F3F7F7F3F7F7F3F7F7FF
F7F7F7F7FFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F783539BA2A49BBDBDB3849685858F847A8B8B7A85
7A85648476755A53845A6164615D535345414E4E4E5D7664
6C8BA69EC7BBA49175A675EAFFFFF3F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F3F7FF864E7B8C9BBBC3B384759B85969B8F758B846C
85856C7C847A723B5361845E5E455E4E453B413B3B53668B
9E909EBB9B6A818F8B76AEF7F7F7F7F7F7F3F7FFF7F7F7F7
F7F7F7F7F7F7F7F3F7F7F7F7F7F7F7F7F7FFF7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F3F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7D36E616A91A4B3BD8B7584967A7A85726C7E7A
7275857A6C847C726C53536A5E5E665D765D5D6776818596
A6CC9BA483537A8B9B9BF7F7F7F7F7F7FFF7F3F7F7F7F7F7
FFF7F7F7F7F7F7F7F7FFF7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7C481786B6A8C93BD6C72828F7A756461616C
6C757A6C6C848B7C7A61845E5D7A756C6E76848FA6969EBD
A4A29191617E918B86FFF7FFFFF7F3FFF3FFF7F3F7FFF7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFF7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7FFF7F7F7F7B27A7B7E8B92A6AD72728B8B758B5E6464
76757C5E867C9685909B7566667C7C8F8F9696B0B0AD8583
83664E5E858B829EFFF7F7F7FFFFF7F7FFF7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F3F7F7F3F7F7BD6B7B919BA4ADB37A8B6C8C7A85755E
5C536C617E7C9E96CCCEBDA6BAB1B1B1CDCDB9BB91728275
64616C8F9B8586FFF7F7FFF7F7F7F7F7F7F7F3F7F7FFFFF7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7FFF7F7F08A7B6691BBBBB48C968C92869EAD
835C725C7A9BADA492C3C4C3CCDAD5C3A69B9B8C7B7A755A
5E7A829E859BF7F7F7F3F7F7F3F3F7F7F7F3F7F7F7F7F7F7
F3F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7FFF7F7F7FF836B8992B3CEB3B3C4B2D1C4AE
D5DCF1E9DCD5D4C3D1CCCCCCD4BB91AD918283836C726085
918B8B85FFF7F7FFF3F7F7F7F7F3F7F7F7F7F3F7F7FFF7F7
F3F7F7F3F7FFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFF7F7F7
F7F7F7F7F7F7FFF7F7F7F7F7E16B799BABC4D1DBD2D1D1D1
DBCCCED4CEDCE2DBD1D5BBA5C3A4A2A578846C72838CA4A6
968BAEF7F7F3F7F3F7F7F7F7F7F7F7F3F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFF7F7FFF7F3F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7FFF7FFFFF7FFF7F7FFEA8C8993BBBBC4C9D1DBDB
DBDBE9E0DBDBE2D5D1C4C8A293A582837A916B92A4A6A292
A6E1F7F7F7F3F7F7F7FFF7FFF7F7F3F7F7F7F7F7F7F7F7F7
FFF7F7F7F7F7F7F7FFF7F7F7F7FFF7F7F7F7FFF7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F3F7FFF7F79D838CBDCEDBDBDA
D5CEDBD2CEC4B3A49BADB3A2927086A292B3B3BBB393B3F3
F7F7F7F7F7F7FFF7F7F7F7F3F7F7FFF7FFF7F7F7F3F7FFF7
F7F7F7F7FFF7F7F7F7F7F7F7F7F7F7F7FFFFFFF3F7F7F7F7
F7F7FFF7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFF7F7F7F7
F7F7F7F7F7F7F7F7F7F3FFF7F7FFF7F7F7F7F7A59DBABDC4
DBDBDBDBDBDBC4C4AEAB9DBBD1A5C4CEC4A59BC3EAFFFFFF
F7F7F7FFF7F7F7F7F7FFF7F7F7F7F7F7F3F7F7F7F7F7F7F7
FFF7FFFFFFFFFFF7F7F7F7F7FFF7F7F7FFFFF7FFF7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F3F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFF7FFF7F7B2ABC4
AEC3D2D2E0DBE9F1E9DBD1DBD2D1AEA4BBD1EAF7F7FFFFF3
F7F7F7F7F7F7F7F3F7F7F3F7F7F7F3F7F7F7F7F7F7F7F3F7
F7F7F7F7F7F7F3F7FFF3F7F7F7F7F7F3F7F7F7F7F3F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFF7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F3F7F7FFF3F3F7F7F7F3F3
F3EAEAE1F1E9D1C4C4D1D2CECED3EAF3F7F7F7F7F7FFFFF7
FFFFFFF7F7F7F7F7F3F3F7F7F7F7F7F7F3F7FFF3F7F7F7FF
F7F7F7F7F7F7F7F7F7FFF7FFF7F7F7F7F7F7F7F7FFF7F7F7
F7F7F7F7FFF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F3F7F7F7
F7F7F7F7F7F7F7F7FFF3F7F7F7F7F3F7F7F7F7F7F7F7F7F7
FFF7F7F7F7F7F3F3F3F3FFF7F7F7F7F7F7FFFFF7F7F7FFF7
F7F7F7F3F7FFF7F7FFF7F7F7FFF7FFF7FFF7F3F7F7F3F7F7
F7F7F7F7F7F7F7F7F7F3F7F7FFF7F7F7F7FFF7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F3F7F7F3FFF7F7F7F3F7F3
F7F7FFF3F7F7F7F7F7F7FFF7F7F3F7F7F7F7F7F7FFF7FFF7
F7F7F3FFF7FFFFF7F7F7F7F7F7F7F7F7FFF3F3F7F3F7F7F7
F7F7F7F7F7FFF7F7F7F7F7F7FFF7F7F7F3F7FFFFF7F7F7F7
F7F7F7F7FFF7F3F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFF7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFF7F7F7F3F7F7FF
F7F7F7FFF7F7FFF7F7F7F3F7F7F7F7F7F7F3F7FFF7F7FFFF
F7F7F7F3F7F7F3F7FFF7F7F7F7FFF7F7F7F7F7F7F7F7F7FF
F3F7F7F7F7FFF7F7FFF7F7F3F7F7F7F7F7F7F3FFF7F7F7F7
F7F7F7F7F7F7FFF7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFF7F7F3F7F7F3
F7F7F7F7F7F7F7F7F7F7F7F3FFF7F7F7F3F7F7F7F7F3FFF3
F7F7F7FFF7F7F7FFF7F3F7F7F3F7F7F7F7F7F7F7F7F7F7FF
F7F7F3F7FFF7F7F7F3FFFFF7F7F3FFF7F7F7F7FFF7F7F7FF
F7F7F7FFF7F7FFF7F7FFFFF7F7FFF7F7F7F3F7F7F7F7F7F7
F7F7FFF7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFF7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F3F7F7
F7FFF3F7FFF7F7F7F7FFF7FFF7F7F7F7F7F7F3F7FFF7F7F7
F7F7F7F7F7F7F7F7F7F7F3F7F7F7F7F7F7F3FFF3FFF7F7FF
F7F7F3F7F7F7F7F7F7F7F7F7F7F7F7F3F7F7F7F7F7F7F7F7
F7F3FFF7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFF7F7F7
F7F7F7F7F7F7F7F7F7F7F3F7F7F7F7F7F7F7F7F7F7F3F3F7
F7F7F7F3FFFFF7F7FFF3F7F7F7F7F7FFF7F3F3F7F7FFF3F7
FFF7FFF7F7FFF7FFF7F7F7F7F7FFF7F7F7F7F7F3F7FFF7F7
F7FFF7F7F7FFF7FFF7F7FFF3F7F7F7F7F7FFF7F7FFF7F7F7
F7F7F7F7F7F7F3F3
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFF7
F7F7F7F7F7F7F7F7F7F7F7FFF7F7F3F7F3F7F7F7F7F7F7FF
F7F7F7F7F7F7F7F3FFF7F7F7F7F7F7F7F7F7F7F7F3F7FFF7
FFF7F7F7F3FFF3FFF7F7F7F3F7F7F7F7F7F7F7F7FFF3F3F7
F7F7F3F7F7F7F7FFF7F7F7F7F7F7F7FFF7F7F7F7F7F7F7F7
F7F7F7F7F3F7FFF7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F3
F7F7F7F7F7F7F7F7F3FFF7F7F3F7F7F3F3F7F7F7FFFFF7F7
F7F3F7F7F7F7F3F7F7FFF7F3FFF7F7F7F7F7FFF7FFF7F3FF
F7F3F7F3F7F7FFF7F7F3F7F7FFF3FFF7F3F7F3FFF7FFF7F7
F7F3F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F3F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7FFF7FFF7F3FFFFF7F3FFF7F7
F7F7F7F7F7F7FFFFF7F7F7F7FFF7F7F7F7F7F7FFF7F7F7F7
F7FFFFFFFFF7F7F7F7F3F7FFF7F7F7FFFFFFFFF7F7F7F7F7
F7FFFFF7F7F7F7F3F7F7F7F7F7F7FFF7F7F7F7FFF7F7F7F7
FFF7FFF7F7FFF7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFF7FFF7F7F3
F7F3F7F7F7F7F7FFF7F7F7F7F7F7F3F7F3F7F3F7F7F7F7F7
F7F7F3F7F7F7F7F7F7FFF7F7F7F7FFF3F7FFFFF7F7F7F7F7
F7F7F7F7F7F7FFF7F7F7F7F7F3F7F7F7F7F7F7FFF7FFF7F7
F3F7FFF7F7F7FFF7F7F7F7F7F7F7F7F3F7F3F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFF7F7FFF7F7
F7F7F7F7F7F7F7F7F7F7F7F7F3F7F7F7F7F7F7FFF7FFF7F7
F7F7F7F7F7F7F7F7FFFFF7F7F7F3F7F7FFFFF7F7F7F7F7F7
F7F7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7FFF7F3F7F3F7F7FFF7F7FF
F3F7F7F7F7F7F7F7
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[28]:=",
  ImageSize->{300, 150},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004/0000UR000`400?l00000o`00003oo`3oool]
0?ooo`00o`3oool]0?ooo`00o`3oool]0?ooo`00o`3oool]0?ooo`00o`3oool]0?ooo`00o`3oool]
0?ooo`00o`3oool]0?ooo`006@3oool01@3alO40lo?c0?Ogm`3alO40lo?c0080k^k^00<0moOg0??c
l`3Ng]h00P3Ng]h00`3Ogml0h^;R0=oOg`030=oOg`040??cl`3_knl0e]KF0=oOg`80e]KF00P0d];B
0=WIf@3AdM40fMWI0=[JfP3IfMT0f][J0=;BdP80fMWI0P3MgMd01P3Jf]X0fMWI0=WIf@3IfMT0f][J
0=?Cd`80f][J1P3Rh^801@3MgMd0h^;R0=[JfP3Jf]X0h^;R00D0f][J0`3IfMT40=[JfP070=WIf@3J
f]X0f][J0=WIf@3clo<0j^[Z0:n_[`020=;BdP040=WIf@3Bd]80d];B0=;BdPD0e]KF00D0g]kN0=gM
g@3Kfm/0i^KV0>;RhP030>KViP040=oOg`3Ng]h0emOG0=KFeP80bLW900X0d];B0=7Ad@39bLT0i^KV
0>CTi035aLD0f][J0?Gem@3gmoL0lO7a7P3oool01@3`l?00lO7a0?Ogm`3`l?00lO7a0080kno_00<0
moOg0?7al@3EeMD00P3EeMD00`3Fe]H0g=cL0=KFeP030=KFeP040?7al@3[jn/0cLg=0=KFeP80cLg=
00P0alO70<o?c`36a/H0clo?0=3@d03?cll0d=3@0<O7a`80clo?0P3EeMD01P3@d=00clo?0<o?c`3?
cll0d=3@0<C4a080d=3@1P3Hf=P01@3EeMD0f=SH0=3@d03@d=00f=SH00D0d=3@0`3?cll40=3@d007
0<o?c`3@d=00d=3@0<o?c`3alO40i>CT0:6QX@020<O7a`040<o?c`37alL0alO70<O7a`D0cLg=0P3E
eMD00`3AdM40g]kN0=SHf0030=kNgP040=KFeP3EeMD0c/k>0<g=c@80`l?300X0alO70<K6aP33`l<0
h^;R0>7Qh@2h^;P0e=CD0??cl`3gmoL0l?3`6`3oool001T0oooo00@0lO7a0?Gem@3^k^h0lo?c0P3g
moL20?7al@030??cl`3^k^h0gmoO00D0gmoO0`3Ng]h0103_knl0f][J0=kNgP3GemL20=KFeP80d];B
00<0eMGE0=WIf@3Jf]X00P3IfMT00`3EeMD0f][J0=kNgP020=[JfP030=WIf@3Cdm<0eMGE00<0fMWI
00L0f][J0=WIf@3Jf]X0gMgM0>3Ph03Jf]X0h^;R0080f][J00<0h^;R0=[JfP3Jf]X00P3Jf]X0103P
h>00f][J0=[JfP3IfMT40=[JfP0:0=KFeP3Bd]80f][J0=[JfP3IfMT0f][J0>[ZjP3clo<0_kno0;Fe
]@80fMWI1@3Bd]801@3IfMT0f][J0=[JfP3MgMd0f][J00<0g]kN0`3Ogml0103Vi^H0gmoO0=KFeP3G
emL20=KFeP0:0=;BdP3Fe]H0jn_[0>c/k03AdM40clo?0=;BdP3emOD0lO7a0??clah0oooo00@0l?3`
0??cl`3_knl0lO7a0P3gmoL20?3`l0030?7al@3_knl0e]KF00D0e]KF0`3EeMD0103[jn/0d=3@0=GE
e@3>c/h20<g=c@80alO700<0bLW90<o?c`3@d=000P3?cll00`39bLT0d=3@0=GEe@020=3@d0030<o?
c`34a<@0bLW900<0clo?00L0d=3@0<o?c`3@d=00eMGE0=?Cd`3@d=00f=SH0080d=3@00<0f=SH0=3@
d03@d=000P3@d=00103Cdm<0d=3@0=3@d03?cll40=3@d00:0<g=c@37alL0d=3@0=3@d03?cll0d=3@
0>CTi03alO40]KFe09fMW@80clo?1@37alL01@3?cll0d=3@0=3@d03EeMD0d=3@00<0eMGE0`3Fe]H0
103Ng]h0e]KF0<g=c@3>c/h20<g=c@0:0<O7a`3=cLd0jNWY0>[ZjP36a/H0aLG50<O7a`3clo<0l?3`
0?7alA/0oooo000I0?ooo`80k^k^00H0lo?c0?7al@3alO40lO7a0??cl`3alO420?Ogm`050?Gem@3O
gml0g]kN0=kNgP3Ph>000P3Ng]h01`3Kfm/0g]kN0>c/k02OWil0e]KF0=_Kf`3GemL00P3Bd]830=WI
f@050=[JfP3IfMT0fMWI0=;BdP3Cdm<00P3MgMd00`3Jf]X0eMGE0=GEe@020=7Ad@80c/k>00D0eMGE
0=WIf@3Jf]X0f][J0=gMg@030=[JfP030=WIf@3Jf]X0f][J0080h^;R00<0gMgM0>3Ph03Rh^801P3J
f]X00`3IfMT0f][J0=[JfP030=[JfP050=WIf@3Ogml0lo?c0>[ZjP2UYJD00P3Bd]802@3IfMT0e]KF
0=;BdP3Bd]80fMWI0=;BdP3Jf]X0g]kN0=gMg@030=kNgP080=oOg`3Rh^80i^KV0>;RhP3Jf]X0fm_K
0=KFeP3Jf]X20=KFeP090=oOg`3Ng]h0jn_[0=kNgP3AdM40d];B0>k^kP3gmoL0lo?c01h0oooo0P3_
knl01P3alO40l?3`0?3`l03`l?00lO7a0?3`l080moOg00D0lo?c0=KFeP3EeMD0eMGE0=?Cd`020=GE
e@070=7Ad@3EeMD0iNGU08b<S03=cLd0dM7A0<k>cP020<O7a`<0clo?00D0d=3@0<o?c`3?cll0alO7
0<C4a0020=GEe@030=3@d039bLT0bLW90080a/K60P32`/801@39bLT0clo?0=3@d03@d=00eMGE00<0
d=3@00<0clo?0=3@d03@d=000P3Hf=P00`3EeMD0dm?C0=SHf0060=3@d0030<o?c`3@d=00d=3@00<0
d=3@00D0clo?0=KFeP3alO40i>CT09BDU0020<O7a`070<o?c`3=cLd0alO70<O7a`3?cll0alO70=3@
d0050=GEe@080=KFeP3Lg=`0g]kN0=cLg03De=@0dM7A0<g=c@3@d=020<g=c@090=_Kf`3Jf]X0jNWY
0=[JfP36a/H0alO70>o_k`3gmoL0lO7a01/0oooo000I0?ooo`040?7al@3emOD0mOGe0?Ogm`80mOGe
01<0lO7a0?Ogm`3gmoL0moOg0??cl`3gmoL0lO7a0??cl`3Ng]h0h^;R0=[JfP3MgMd0f][J0>;RhP3_
knl0alO70=[JfP3Kfm/0f][J0080d];B00D0fMWI0=;BdP3Bd]80fMWI0=[JfP020=WIf@040=[JfP3I
fMT0eMGE0=GEe@@0fMWI00D0eMGE0<k>cP3AdM40d];B0=WIf@020=?Cd`030=WIf@3Jf]X0f][J0080
f][J00<0h^;R0=[JfP3Jf]X00P3Vi^H01P3Kfm/0h>3P0>;RhP3Ph>00f][J0=kNgP80fm_K0`3Ng]h4
0=[JfP040=oOg`3clo<0aLG50=[JfP<0gMgM0P3Jf]X0203MgMd0g]kN0=gMg@3Ng]h0h^;R0=kNgP3R
h^80i^KV0`3Rh^820=oOg`080=OGe`3Rh^80k^k^0>c/k03[jn/0k^k^0=[JfP3/k>`20=7Ad@030?Og
m`3clo<0k^k^01h0oooo00@0l?3`0??cl`3clo<0moOg0P3clo<04`3`l?00moOg0?Ogm`3gmoL0lO7a
0?Ogm`3`l?00lO7a0=GEe@3Hf=P0d=3@0=GEe@3@d=00f=SH0>_[j`2j^[X0d=3@0=7Ad@3De=@00P37
alL01@3?cll0alO70<O7a`3?cll0d=3@0080clo?00@0d=3@0<o?c`39bLT0bLW9103?cll01@39bLT0
`/;20<K6aP37alL0clo?0080a<C400<0clo?0=3@d03@d=000P3@d=000`3Hf=P0d=3@0=3@d0020=kN
gP060=7Ad@3Cdm<0f=SH0=?Cd`3@d=00eMGE0P3AdM430=GEe@@0d=3@00@0e]KF0?7al@2h^;P0d=3@
0`3EeMD20=3@d0@0eMGE00@0f=SH0=GEe@3Hf=P0g]kN0`3Lg=`20=KFeP080<k>cP3Lg=`0kno_0>[Z
jP3YjNT0kno_0=CDe03UiND20<K6aP030?Ogm`3alO40kno_01/0oooo000I0?ooo`0:0?7al@3emOD0
mOGe0?7al@3clo<0mOGe0?Ogm`3^k^h0mOGe0>k^kP80moOg00D0mOGe0?Ogm`3Vi^H0g]kN0>;RhP03
0=kNgP030>o_k`3[jn/0f][J0080g]kN00H0e]KF0=;BdP3Bd]80fMWI0=KFeP3Jf]X20=;BdP050=WI
f@3Bd]80c/k>0=GEe@3AdM400`3IfMT30=[JfP070=?Cd`3>c/h0c/k>0=GEe@3IfMT0d];B0=WIf@04
0=[JfP050>3Ph03Rh^80h^;R0=[JfP3Ogml00P3Ng]h01`3Rh^80g]kN0>;RhP3Ogml0g]kN0=_Kf`3N
g]h00P3Kfm/0203Jf]X0gMgM0=[JfP3Jf]X0gmoO0??cl`3<c<`0f][J0P3Ng]h00`3MgMd0fm_K0=gM
g@050>;RhP80gmoO0`3Rh^80303GemL0d];B0=7Ad@3Ogml0jn_[0??cl`3Ogml0e]KF0=oOg`3/k>`0
d];B0=oOg`80mOGe00<0k^k^0?ooo`3oool0703oool02P3`l?00lo?c0??cl`3`l?00lO7a0??cl`3g
moL0kno_0??cl`3_knl20?Ogm`050??cl`3gmoL0h^;R0=GEe@3Hf=P00`3EeMD00`3[jn/0jNWY0=3@
d0020=GEe@060<g=c@37alL0alO70<o?c`3=cLd0d=3@0P37alL01@3?cll0alO70<;2`P39bLT0a/K6
00<0clo?0`3@d=001`34a<@0`/;20<;2`P39bLT0clo?0<O7a`3?cll0103@d=001@3Cdm<0f=SH0=SH
f03@d=00e]KF0080eMGE00L0f=SH0=GEe@3Hf=P0e]KF0=GEe@3AdM40eMGE0080dM7A00P0d=3@0=GE
e@3@d=00d=3@0=KFeP3alO40_Kfm0=3@d0<0eMGE00<0dM7A0=GEe@3Hf=P0103Hf=P20=KFeP<0g=cL
00`0c/k>0<c<c036a/H0fm_K0>WYj@3alO40fm_K0<g=c@3Fe]H0j^[Z0<O7a`3Kfm/20??cl`030>o_
k`3oool0oooo01T0oooo000I0?ooo`060?7al@3gmoL0moOg0>k^kP3gmoL0k^k^0P3emOD0103^k^h0
moOg0?Ogm`3alO430?Ogm`0=0??cl`3Rh^80h^;R0>KViP3Rh^80i^KV0??cl`3Ph>00fm_K0=oOg`3J
f]X0emOG0=KFeP020=;BdP040=7Ad@3Bd]80cLg=0<K6aP@0cLg=00<0fMWI0=[JfP3MgMd00P3MgMd0
103Rh^80fMWI0=WIf@3>c/h20=GEe@050<k>cP3AdM40d];B0=?Cd`3IfMT00P3Jf]X00`3MgMd0f][J
0=[JfP020=[JfP040=_Kf`3Jf]X0f][J0=kNgP<0fm_K103Jf]X01`3Fe]H0f][J0=[JfP3Fe]H0h^;R
0>[ZjP3Fe]H00`3Jf]X0203IfMT0h>3P0>;RhP3Rh^80g]kN0>;RhP3Vi^H0gmoO0`3Rh^802@3GemL0
alO70;fm_@3Bd]80k>c/0>;RhP3^k^h0f][J0=kNgP020=[JfP050<o?c`3/k>`0lo?c0?Ogm`3alO40
7P3oool01P3`l?00moOg0?Ogm`3_knl0moOg0>o_k`80lo?c00@0kno_0?Ogm`3gmoL0l?3`0`3gmoL0
3@3alO40g=cL0=cLg03Ng]h0g=cL0=kNgP3alO40fm_K0=7Ad@3Fe]H0e=CD0<k>cP3=cLd00P37alL0
1036a/H0alO70<71`@2i^KT40<71`@030<o?c`3@d=00eMGE0080eMGE00@0f=SH0<o?c`3?cll0`/;2
0P39bLT01@32`/80a/K60<O7a`34a<@0clo?0080d=3@00<0eMGE0=3@d03@d=000P3@d=00103AdM40
d=3@0=3@d03EeMD30=7Ad@@0d=3@00L0cLg=0=3@d03@d=00cLg=0=cLg03Ti>@0cLg=00<0d=3@00P0
clo?0=?Cd`3Hf=P0f=SH0=GEe@3Hf=P0g]kN0=KFeP<0g=cL00T0c/k>0;Zj^P2d];@0alO70>[ZjP3P
h>00kno_0=CDe03EeMD00P3De=@01@35aLD0j^[Z0?7al@3gmoL0l?3`01/0oooo000I0?ooo`090?7a
l@3clo<0mOGe0?Gem@3gmoL0mOGe0?Ogm`3alO40k^k^0080lO7a00L0moOg0?Gem@3gmoL0moOg0?Ge
m@3alO40k>c/0080j^[Z0P3Vi^H01@3clo<0h^;R0:RXZ03Kfm/0f][J00@0d];B0P36a/H50<g=c@03
0=;BdP3IfMT0f][J0080gMgM00T0h^;R0=[JfP3Jf]X0dm?C0<k>cP3=cLd0c/k>0=;BdP3>c/h00P3=
cLd30=;BdP070=WIf@3Bd]80d];B0=;BdP3IfMT0d];B0=WIf@020=KFeP80fMWI1P3Bd]801`3IfMT0
d];B0=;BdP3_knl0emOG0=KFeP3IfMT00`3Jf]X01@3Ng]h0h^;R0=kNgP3Ng]h0i^KV00<0gmoO0140
e]KF0=;BdP2o_kl0_Kfm0=KFeP3Ogml0e]KF0<G5a@3IfMT0clo?0=oOg`3GemL0dM7A0>_[j`3^k^h0
lo?c0?7al@0N0?ooo`090?3`l03alO40lo?c0??cl`3gmoL0lo?c0?Ogm`3`l?00kno_0080l?3`00L0
moOg0??cl`3gmoL0moOg0??cl`3`l?00iNGU0080i>CT0P3Rh^801@3alO40g=cL09jNWP3AdM40d=3@
00@0alO70P2i^KT50<71`@030<O7a`3?cll0d=3@0080eMGE00T0f=SH0=3@d03@d=00a<C40<;2`P31
`L40`/;20<O7a`32`/800P31`L430<O7a`070<o?c`37alL0alO70<O7a`3?cll0alO70<o?c`020<g=
c@80clo?1P37alL01`3?cll0alO70<O7a`3[jn/0c/k>0<g=c@3?cll00`3@d=001@3EeMD0f=SH0=GE
e@3EeMD0g]kN00<0e]KF0140cLg=0<O7a`2e]KD0];Bd0<g=c@3Kfm/0cLg=0;Rh^03?cll0aLG50=_K
f`3>c/h0a/K60>WYj@3_knl0lO7a0?3`l00K0?ooo`006@3oool00`3alO40moOg0?Ogm`020?Ogm`0?
0?7al@3clo<0mOGe0?Ogm`3emOD0lO7a0>k^kP3gmoL0mOGe0?Ogm`3alO40moOg0?7al@3gmoL0mOGe
0080moOg0P3emOD0103clo<0e]KF0=[JfP3Fe]H30=;BdP0:0=7Ad@36a/H0dM7A0=7Ad@3EeMD0fMWI
0=GEe@3=cLd0eMGE0=WIf@<0gMgM00H0h^;R0=gMg@3IfMT0d];B0=WIf@3Cdm<20=GEe@80d];B00H0
cLg=0<G5a@36a/H0aLG50<71`@36a/H20<G5a@030<71`@35aLD0aLG500H0a/K600L0c/k>0=7Ad@3A
dM40dM7A0<k>cP3=cLd0a/K60080g=cL00@0`<300;Fe]@36a/H0d];B0`3Jf]X0203Ng]h0gmoO0>;R
hP3Ogml0emOG0:j^[P2h^;P0`L710P35aLD02P3GemL0e]KF0=;BdP3AdM40h^;R0=[JfP3AdM40h>3P
0>_[j`3emOD20>k^kQh0oooo00<0l?3`0?Ogm`3gmoL00P3gmoL03`3`l?00lO7a0??cl`3gmoL0lo?c
0?3`l03_knl0moOg0??cl`3gmoL0l?3`0?Ogm`3`l?00moOg0??cl`020?Ogm`80lo?c00@0lO7a0<g=
c@3@d=00cLg=0`37alL02P36a/H0_Kfm0<K6aP36a/H0bLW90<o?c`39bLT0`L710<W9b@3?cll30=GE
e@060=SHf03EeMD0clo?0<?3``3?cll0a<C40P39bLT20<O7a`060<71`@2h^;P0^KVi0;Rh^02c/k<0
^KVi0P2h^;P00`2c/k<0^;Rh0;Rh^0060;Vi^@070<;2`P36a/H0a/K60<K6aP32`/80`L710;Vi^@02
0=GEe@040;Jf]P2MWId0^KVi0<O7a`<0d=3@00P0eMGE0=KFeP3Lg=`0e]KF0<k>cP2PX:00ZJVY0;^k
^`80^;Rh00X0c/k>0<g=c@37alL0a/K60>3Ph03De=@0a/K60=_Kf`3YjNT0lo?c0P3_knlK0?ooo`00
6@3oool00`3gmoL0mOGe0??cl`030?Ogm`80mOGe00d0lo?c0?7al@3alO40lo?c0?Ogm`3alO40moOg
0?7al@3gmoL0mOGe0?Ogm`3emOD0moOg0080mOGe00T0lo?c0?Ogm`3AdM40^KVi0=kNgP3Bd]80alO7
0=;BdP3AdM400`36a/H01@3=cLd0dM7A0=GEe@3=cLd0dM7A0080fMWI00<0gMgM0>;RhP3MgMd00P3J
f]X30=GEe@060=WIf@3EeMD0fMWI0=WIf@3EeMD0fMWI0P3EeMD00`3AdM40c/k>0<k>cP020<k>cP05
0=7Ad@3>c/h0eMGE0=7Ad@3EeMD00P3Bd]800`3IfMT0c/k>0=WIf@020=WIf@0;0=;BdP3IfMT0d];B
0=GEe@3Kfm/0f][J0=cLg03Bd]80c/k>0<O7a`3Bd]800P3Fe]H05@30`<00Y:BT09nOW`2OWil0Zj^[
0<G5a@3Bd]80aLG50<o?c`3AdM40d];B0=[JfP35aLD0h^;R0=kNgP35aLD0i^KV0>;RhP3emOD0moOg
0?7al@0N0?ooo`030?Ogm`3clo<0lO7a00<0moOg0P3clo<03@3alO40l?3`0?3`l03alO40moOg0?3`
l03gmoL0l?3`0?Ogm`3clo<0moOg0??cl`3gmoL00P3clo<02@3alO40moOg0<K6aP2ZZZX0f][J0<O7
a`2j^[X0alO70<K6aP020;fm_@060;Vi^@31`L40a/K60<W9b@31`L40a/K60P3?cll00`3EeMD0f=SH
0=GEe@020=3@d0<0bLW900H0clo?0<W9b@3?cll0clo?0<W9b@3?cll20<W9b@030<K6aP32`/80`/;2
0080`/;200D0a/K60<;2`P39bLT0a/K60<W9b@020<O7a`030<o?c`32`/80clo?0080clo?00/0alO7
0<o?c`37alL0bLW90=7Ad@3De=@0eMGE0<O7a`32`/80^[Zj0<O7a`020<g=c@0E0;Jf]P2CTi<0S8b<
08b<S02JVYX0^;Rh0<O7a`2h^;P0aLG50<K6aP37alL0e=CD0;Rh^03Lg=`0f][J0;Rh^03Rh^80h>3P
0??cl`3gmoL0l?3`01/0oooo000I0?ooo`040?Ogm`3alO40moOg0?7al@80moOg00/0k^k^0??cl`3g
moL0mOGe0?Ogm`3alO40moOg0?7al@3emOD0moOg0?7al@030?Ogm`80lO7a0P3^k^h0103emOD0emOG
0=KFeP2^[Zh20;no_`080:n_[`3Bd]80c/k>0=7Ad@37alL0clo?0=7Ad@3EeMD20<o?c`80fMWI0P3J
f]X0103MgMd0fMWI0=gMg@3IfMT20=GEe@L0fMWI00<0dm?C0=GEe@3EeMD00P3IfMT0103AdM40eMGE
0=;BdP3EeMD20=WIf@040=?Cd`3IfMT0fMWI0=WIf@80eMGE00<0fMWI0=;BdP3IfMT0103IfMT20=;B
dP080=[JfP3Lg=`0g=cL0<W9b@26QXH0Y:BT09nOW`2TY:@20:j^[P0=0:n_[`2m_Kd0a/K60>;RhP2h
^;P0`l?30=KFeP3GemL0g]kN0<o?c`3^k^h0jn_[0>k^kP020?7al@030?Ogm`3oool0oooo01`0oooo
00@0moOg0?3`l03gmoL0l?3`0P3gmoL02`3_knl0lO7a0?Ogm`3clo<0moOg0?3`l03gmoL0l?3`0??c
l`3gmoL0l?3`00<0moOg0P3`l?020>o_k`040??cl`3>c/h0cLg=0:2PX080]KFe00P0XJ6Q0<O7a`32
`/80a/K60;Zj^P35aLD0a/K60<W9b@80aLG50P3?cll20=3@d0040=GEe@3?cll0eMGE0<o?c`80bLW9
1`3?cll00`34a<@0bLW90<W9b@020<o?c`040<K6aP39bLT0alO70<W9b@80clo?00@0a<C40<o?c`3?
cll0clo?0P39bLT00`3?cll0alO70<o?c`040<o?c`80alO700P0e=CD0=GEe@3EeMD0`l?307AdM02C
Ti<0S8b<09>CT`80X:2P00d0XJ6Q0;Bd]02m_Kd0h>3P0:VYZ@2g]kL0cLg=0<k>cP3Jf]X0aLG50>o_
k`3YjNT0kno_0080l?3`00<0moOg0?ooo`3oool06@3oool001T0oooo00H0lO7a0?Ogm`3alO40lO7a
0?Ogm`3clo<20?Ogm`050?7al@3gmoL0moOg0?Gem@3clo<00`3gmoL0103clo<0mOGe0?Ogm`3gmoL2
0?7al@0;0?Gem@3alO40lO7a0=cLg03GemL0`<300:j^[P2o_kl0WYjN0<O7a`3AdM400P3>c/h01@3A
dM40c/k>0=;BdP3=cLd0dM7A00@0fMWI00<0gMgM0=WIf@3IfMT01P3IfMT0103Jf]X0fMWI0=WIf@3I
fMT50=GEe@030=WIf@3AdM40dm?C0080eMGE00H0dM7A0=;BdP3IfMT0f][J0=WIf@3Cdm<20=WIf@80
eMGE0P3IfMT30=;BdP0H0=7Ad@2m_Kd0^KVi09nOW`2?Shl0WinO09RHV02NWYh0[Zj^0:^[Z`2^[Zh0
[jn_0<?3``35aLD0e]KF0<30`033`l<0clo?0=kNgP3Fe]H0f][J0>_[j`3^k^h0mOGe0P3gmoL00`3e
mOD0oooo0?ooo`0L0?ooo`060?3`l03gmoL0l?3`0?3`l03gmoL0lO7a0P3gmoL01@3`l?00moOg0?Og
m`3clo<0lO7a00<0moOg00@0lO7a0??cl`3gmoL0moOg0P3`l?002`3clo<0l?3`0?3`l03EeMD0c/k>
0;Jf]P2PX:00]KFe08^;R`2j^[X0a/K60080`/;200D0a/K60<;2`P33`l<0`L710<K6aP040<o?c`03
0=GEe@3?cll0clo?00H0clo?00@0d=3@0<o?c`3?cll0clo?1@39bLT00`3?cll0a/K60<C4a0020<W9
b@060<K6aP37alL0clo?0=3@d03?cll0a<C40P3?cll20<W9b@80clo?0`37alL06036a/H0/;2`0:ZZ
ZP2<S8`0OGem08b<S029RHT0Rh^;0:2PX02JVYX0X:2P0:6QX@2g]kL0^;Rh0<g=c@2b/[80]kNg0<G5
a@3Jf]X0cLg=0=CDe03YjNT0kno_0??cl`80moOg00<0lo?c0?ooo`3oool06@3oool001T0oooo00d0
moOg0?Gem@3emOD0lo?c0?Ogm`3alO40moOg0>k^kP3alO40moOg0??cl`3gmoL0lO7a0080moOg01T0
lO7a0?Gem@3gmoL0moOg0?7al@3clo<0k^k^0?7al@3gmoL0lo?c0>KViP3[jn/0g]kN0:^[Z`2^[Zh0
WYjN079bLP3>c/h0alO70=7Ad@36a/H0alO70=7Ad@3?cll0dM7A00@0fMWI00<0f][J0=WIf@3IfMT0
0P3IfMT40=GEe@@0fMWI103EeMD30=7Ad@<0eMGE00@0dM7A0=GEe@3EeMD0fMWI0P3EeMD20=WIf@0<
0=GEe@3AdM40eMGE0=GEe@3=cLd0dM7A0<K6aP35aLD0[Zj^09>CT`2?Shl0WinO0P2[Zj/02@2TY:@0
WYjN0:j^[P2^[Zh0_kno0<?3``3AdM40aLG50;Rh^0020<?3``80e]KF00@0g]kN0?Gem@3^k^h0lo?c
0P3emOD00`3^k^h0oooo0?ooo`0L0?ooo`0=0?Ogm`3clo<0lo?c0?7al@3gmoL0l?3`0?Ogm`3_knl0
l?3`0?Ogm`3alO40moOg0?3`l0020?Ogm`0I0?3`l03clo<0moOg0?Ogm`3`l?00lO7a0>o_k`3`l?00
moOg0?7al@3Rh^80jNWY0=[JfP2JVYX0X:2P08^;R`1QHF40`/;20;Zj^P36a/H0^KVi0;Zj^P36a/H0
aLG50<K6aP040<o?c`030=3@d03?cll0clo?0080clo?1039bLT40<o?c`@0bLW90`36a/H30<W9b@04
0<K6aP39bLT0bLW90<o?c`80bLW90P3?cll04039bLT0a/K60<W9b@39bLT0`L710<K6aP2i^KT0^;Rh
0:2PX022PX80OGem08b<S02JVYX0WinO09>CT`2;Rh/20:2PX0050;6a/@2g]kL0a/K60;Rh^02YZJT0
0P2g]kL20<g=c@040=[JfP3clo<0kno_0?7al@80lo?c00<0kno_0?ooo`3oool06@3oool001T0oooo
00@0lO7a0?Gem@3emOD0k^k^0`3gmoL01@3clo<0mOGe0?7al@3gmoL0lO7a0080moOg00P0lO7a0?Ge
m@3alO40moOg0>k^kP3gmoL0lo?c0?Ogm`80mOGe00`0k^k^0=oOg`3clo<0e]KF0:^[Z`2OWil0WYjN
079bLP1JFUX0`L710<G5a@36a/H20=7Ad@030<g=c@3?cll0d];B00<0fMWI00<0eMGE0=WIf@3IfMT0
103IfMT0103EeMD0fMWI0=GEe@3EeMD40=WIf@030=;BdP3EeMD0eMGE0080eMGE00H0dm?C0=7Ad@3B
d]80clo?0=7Ad@3Cdm<20=WIf@060=GEe@3AdM40fMWI0=WIf@3EeMD0dM7A0P3=cLd04@35aLD0`l?3
0;Rh^02OWil0RXZ:0:BTY02[Zj/0WinO0;Vi^@2[Zj/0Y:BT0:^[Z`2o_kl0[Zj^0;Rh^02m_Kd0`<30
00<0clo?00T0aLG50=OGe`3^k^h0k^k^0?Gem@3_knl0k^k^0?Ogm`3emOD07P3oool0103`l?00lo?c
0??cl`3_knl30?Ogm`050?7al@3clo<0l?3`0?Ogm`3`l?000P3gmoL0203`l?00lo?c0?3`l03gmoL0
kno_0?Ogm`3alO40moOg0P3clo<0303_knl0fm_K0?7al@3=cLd0VYZJ08b<S02;Rh/0HF5Q04U9B@2c
/k<0^;Rh0;Vi^@80a/K600<0`L710<G5a@37alL00`3?cll00`39bLT0clo?0<o?c`040<o?c`040<W9
b@3?cll0bLW90<W9b@@0clo?00<0`l?30<W9b@39bLT00P39bLT01P34a<@0a/K60<?3``35aLD0a/K6
0<C4a080clo?00H0bLW90<K6aP3?cll0clo?0<W9b@36a/H20<71`@0A0;Rh^02g]kL0ZJVY08b<S01i
NGT0Ti>C09ZJVP2<S8`0ZZZZ09ZJVP2CTi<0VYZJ0;6a/@2PX:00ZJVY0;Bd]02b/[800`35aLD02@2h
^;P0c/k>0>o_k`3_knl0lo?c0>_[j`3_knl0moOg0??cl`0K0?ooo`006@3oool0203clo<0lO7a0??c
l`3alO40moOg0>k^kP3clo<0k^k^0P3gmoL05P3clo<0moOg0??cl`3clo<0lO7a0?Ogm`3emOD0lO7a
0?Ogm`3alO40moOg0??cl`3gmoL0mOGe0??cl`3Vi^H0jn_[0=OGe`39bLT0WYjN0:BTY01bLW8205YJ
FP80a/K600@0cLg=0=7Ad@3?cll0cLg=1@3IfMT20=GEe@030=WIf@3EeMD0eMGE0080eMGE00<0d];B
0=7Ad@3IfMT00P3IfMT30=GEe@030=;BdP3?cll0cLg=0080eMGE00D0d];B0=7Ad@3:b/X0dM7A0<o?
c`050=GEe@030<o?c`33`l<0`<3000@0^;Rh00L0Y:BT079bLP2OWil0^;Rh0:j^[P2;Rh/0[jn_00<0
_kno0P2[Zj/00`2h^;P0aLG50<30`0020<o?c`0:0>_[j`3Fe]H0h^;R0>c/k03[jn/0k>c/0??cl`3a
lO40moOg0?GemAh0oooo00P0lO7a0?3`l03alO40l?3`0?Ogm`3_knl0lO7a0>o_k`80moOg01H0lO7a
0?Ogm`3alO40lO7a0?3`l03gmoL0lo?c0?3`l03gmoL0l?3`0?Ogm`3alO40moOg0??cl`3alO40h^;R
0>WYj@3>c/h0`l?308^;R`2CTi<0HF5Q0P19BDT20;Vi^@040<71`@36a/H0aLG50<71`@D0clo?0P39
bLT00`3?cll0bLW90<W9b@020<W9b@030<?3``36a/H0clo?0080clo?0`39bLT00`33`l<0aLG50<71
`@020<W9b@050<?3``36a/H0^k^k0<K6aP35aLD01@39bLT00`35aLD0]kNg0;:b/P040:VYZ@0809>C
T`1QHF40S8b<0:VYZ@2PX:00NWYj0:6QX@2e]KD20;6a/@80VYZJ00<0ZJVY0;Rh^02b/[800P35aLD0
2P3YjNT0cLg=0=cLg03Zj^X0jNWY0>[ZjP3alO40l?3`0?Ogm`3clo<K0?ooo`006@3oool01@3clo<0
k^k^0?Ogm`3gmoL0k^k^00<0moOg00L0lO7a0?Ogm`3clo<0mOGe0>k^kP3emOD0lO7a00<0moOg0P3e
mOD20?7al@090??cl`3emOD0lo?c0>_[j`3Jf]X0i^KV0:^[Z`2TY:@0WYjN0080LW9b00D0IfMW04i>
CP0b<S80_Kfm0<K6aP020<g=c@030=;BdP3AdM40eMGE0080eMGE00<0fMWI0=GEe@3IfMT00`3EeMD0
1P3AdM40eMGE0=GEe@3Bd]80clo?0=;BdP80eMGE00L0dM7A0=;BdP3=cLd0d];B0<[:bP33`l<0d];B
0080b/[:00H0d];B0<[:bP3?cll0b/[:0<?3``3=cLd20<G5a@0;0<?3``2i^KT0[:b/09>CT`2:RXX0
QXJ607inOP2RXZ80[jn_0:^[Z`2WYjL00P2^[Zh20:BTY0060:j^[P2[Zj/0_kno0<30`02o_kl0clo?
0P3Bd]801P3Fe]H0jn_[0>KViP3/k>`0mOGe0??cl`@0moOg7P3oool01@3alO40kno_0?Ogm`3gmoL0
kno_00<0moOg00L0l?3`0?Ogm`3alO40lo?c0>o_k`3clo<0l?3`00<0moOg0P3clo<20?3`l0090?7a
l@3clo<0lO7a0>WYj@3De=@0h^;R09ZJVP2CTi<0Rh^;0080HF5Q00D0E5AD03lo?`0U9BD0/;2`0;Vi
^@020<71`@030<O7a`36a/H0bLW90080bLW900<0clo?0<W9b@3?cll00`39bLT01P36a/H0bLW90<W9
b@33`l<0aLG50<?3``80bLW900L0a/K60<?3``31`L40`l?30;^k^`2g]kL0`l?30080^k^k00H0`l?3
0;^k^`35aLD0^k^k0;Ng]`31`L420;Rh^00;0;Ng]`2ZZZX0Vi^K08:2PP1iNGT0M7Ad06m_K`2FUYH0
XJ6Q09ZJVP2IVIT00P2PX:0209>CT`060:2PX02JVYX0/K6a0;:b/P2a/K40aLG50P37alL01P3=cLd0
jNWY0>;RhP3Zj^X0lo?c0?7al@@0moOg6`3oool001T0oooo00<0k^k^0?Ogm`3gmoL00P3gmoL01`3c
lo<0mOGe0?Ogm`3emOD0lO7a0>k^kP3emOD00`3gmoL00`3emOD0lO7a0?Gem@050?Gem@080?7al@3c
lo<0k>c/0=kNgP3Rh^80[Zj^0:BTY02OWil2079bLP0706MWI`16ATH0ATI6038b<P36a/H0dM7A0<k>
cP020=7Ad@@0eMGE0P3IfMT60=GEe@060<o?c`3EeMD0d];B0=7Ad@3Bd]80dm?C0`3=cLd30<[:bP07
0<?3``30`<00`l?30<[:bP33`l<0`<300<G5a@020<?3``0=0;Vi^@31`L40WinO08B4Q02:RXX0Hf=S
08^;R`2CTi<0[Zj^0:^[Z`2WYjL0Zj^[0:NWY`030;Rh^080_kno00@0`<300;no_`3?cll0dM7A0P3B
d]801P3Ogml0i^KV0>_[j`3^k^h0lo?c0?Ogm`80mOGe00<0lO7a0?Ogm`3oool07@3oool00`3_knl0
moOg0?Ogm`020?Ogm`070?7al@3clo<0moOg0??cl`3`l?00kno_0??cl`030?Ogm`030??cl`3`l?00
lo?c00D0lo?c00P0l?3`0?7al@3Zj^X0f][J0>3Ph02PX:00Ti>C08b<S080HF5Q00L0E5AD03Lg=`0g
=cL09BDU0;Vi^@36a/H0`/;20080a/K61039bLT20<o?c`H0bLW900H0aLG50<W9b@33`l<0a/K60<?3
``34a<@30<71`@<0^k^k00L0]kNg0;:b/P2g]kL0^k^k0;Ng]`2b/[80^;Rh0080]kNg00d0ZZZZ0;>c
/`2<S8`0KVi^07UiN@1BDU80NWYj08:2PP2PX:00VYZJ09VIV@2OWil0VIVI00<0ZJVY0P2a/K40102b
/[80]KFe0<G5a@36a/H20<O7a`060=KFeP3Rh^80jNWY0>o_k`3alO40moOg0P3clo<00`3`l?00moOg
0?ooo`0J0?ooo`006@3oool30?Ogm`0;0?Gem@3gmoL0moOg0?Ogm`3emOD0k^k^0?Gem@3gmoL0lO7a
0>k^kP3emOD00P3gmoL05`3clo<0mOGe0?Ogm`3alO40mOGe0?Ogm`3emOD0lO7a0??cl`3[jn/0h^;R
0=cLg02^[Zh0Y:BT08n?S`1nOWh0LW9b05YJFP16ATH0>SXj04i>CP36a/H0cLg=0080dM7A00@0d];B
0=WIf@3EeMD0fMWI103EeMD01`3Bd]80eMGE0=GEe@3?cll0eMGE0=7Ad@3Bd]800P3=cLd0103:b/X0
cLg=0<g=c@3=cLd20<[:bP090<?3``30`<00`<300<30`033`l<0dM7A0<?3``2h^;P0^KVi0080_;bl
0P2/[:`01`2OWil0K6a/08B4Q01nOWh0RXZ:07inOP2[Zj/00P2TY:@0202WYjL0^;Rh0;no_`35aLD0
^;Rh0;no_`3?cll0_kno0P3?cll0103Bd]80dM7A0=oOg`3Rh^820??cl`80moOg0P3emOD00`3alO40
moOg0?Ogm`0N0?ooo`<0moOg00/0lo?c0?Ogm`3gmoL0moOg0??cl`3_knl0lo?c0?Ogm`3`l?00kno_
0??cl`020?Ogm`0G0?7al@3clo<0moOg0?3`l03clo<0moOg0??cl`3`l?00lO7a0>WYj@3Ph>00eMGE
0:2PX02CTi<0OGem06m_K`1QHF40BDU903Lg=`0^;Rh0?clo0;Vi^@31`L400P36a/H01037alL0clo?
0<W9b@3?cll40<W9b@070<?3``39bLT0bLW90<G5a@39bLT0a/K60<?3``020<71`@040;^k^`31`L40
`L710<71`@80^k^k00T0]kNg0;:b/P2b/[80/[:b0;Ng]`36a/H0]kNg0:VYZ@2ZZZX00P2[Zj/209^K
V`0708b<S01KFe/0KVi^06m_K`1iNGT0Kfm_09ZJVP0209>CT`0809VIV@2YZJT0]KFe0;Rh^02YZJT0
/K6a0<G5a@2e]KD20<G5a@040<O7a`36a/H0e]KF0=cLg080lO7a0P3gmoL20??cl`030?3`l03gmoL0
moOg01/0oooo000I0?ooo`090?Ogm`3emOD0lo?c0?Gem@3alO40moOg0??cl`3gmoL0lO7a0080moOg
00<0mOGe0?Ogm`3clo<00`3emOD04@3gmoL0lO7a0?7al@3gmoL0mOGe0?Ogm`3clo<0mOGe0>o_k`3N
g]h0_kno0:j^[P2TY:@0Ti>C08j>SP1bLW80Jf][0080CTi>00L0GUiN0<O7a`3?cll0dM7A0=WIf@3A
dM40fMWI00D0eMGE00H0dM7A0=GEe@3AdM40cLg=0=?Cd`3EeMD20=;BdP060<o?c`3:b/X0clo?0<?3
``3?cll0cLg=0P3:b/X04031`L40[jn_0;Rh^035aLD0dM7A0<G5a@2/[:`0^;Rh0:n_[`2h^;P0[jn_
09nOW`2NWYh0QXJ609nOW`2;Rh/209nOW`070::RXP2_[jl0YjNW0:^[Z`2WYjL0^;Rh0:n_[`020;Rh
^0030<30`02h^;P0^;Rh0080clo?00P0dM7A0=[JfP3Rh^80jn_[0?Gem@3gmoL0lO7a0>k^kP80moOg
00<0mOGe0?Ogm`3emOD07P3oool02@3gmoL0lo?c0?7al@3clo<0l?3`0?Ogm`3alO40moOg0?3`l002
0?Ogm`030??cl`3gmoL0lO7a00<0lo?c0140moOg0?3`l03`l?00moOg0??cl`3gmoL0lO7a0??cl`3[
jn/0f][J0;Fe]@2PX:00Ti>C08:2PP1lO7`0HF5Q05YJFP0203lo?`0704m?C`2j^[X0aLG50<K6aP3?
cll0a/K60<o?c`050<W9b@060<K6aP39bLT0a/K60<71`@34a<@0bLW90P33`l<01P35aLD0^k^k0<G5
a@2g]kL0aLG50<71`@80^k^k0100/k>c0:6QX@2YZJT0^;Rh0<K6aP2h^;P0Vi^K0:VYZ@2QXJ40ZJVY
0:6QX@2<S8`0Rh^;07AdM02<S8`0NWYj0P2<S8`01`2FUYH0XJ6Q09VIV@2JVYX0VIVI0:VYZ@2QXJ40
0P2YZJT00`2b/[80ZJVY0:VYZ@020<G5a@080<K6aP3De=@0g=cL0>WYj@3clo<0moOg0?3`l03_knl2
0?Ogm`030??cl`3gmoL0lo?c01/0oooo000I0?ooo`<0moOg00<0lO7a0?Gem@3emOD01P3gmoL0403a
lO40mOGe0?7al@3emOD0k^k^0?7al@3gmoL0lO7a0?Ogm`3clo<0mOGe0??cl`3^k^h0k>c/0=GEe@2o
_kl20:BTY00F08n?S`2:RXX0Jf][06][J`1JFUX0Hf=S06MWI`36a/H0dM7A0=;BdP3IfMT0dM7A0=GE
e@3Bd]80clo?0=GEe@3Bd]80clo?0=GEe@3?cll0d];B0<o?c`80d];B0`3=cLd0203?cll0`l?30=;B
dP3:b/X0aLG50<?3``31`L40_Kfm0P2h^;P0503?cll0dM7A0:b/[02_[jl0^;Rh0:b/[02HV9P0TY:B
07inOP2NWYh0QXJ608Z:RP2NWYh0WinO08n?S`2TY:@0[Zj^0:^[Z`2TY:@0Ti>C0P2o_kl0102_[jl0
clo?0;Rh^030`<030<o?c`070=KFeP3GemL0jn_[0>c/k03emOD0moOg0>k^kP060?Ogmah0oooo0`3g
moL00`3`l?00lo?c0??cl`060?Ogm`0@0?3`l03clo<0l?3`0??cl`3_knl0l?3`0?Ogm`3`l?00moOg
0?7al@3clo<0lO7a0>o_k`3Zj^X0dM7A0;Fe]@80Ti>C01H0OGem07UiN@1JFUX0FUYJ04U9B@1BDU80
E5AD0;Vi^@36a/H0alO70<o?c`36a/H0bLW90<?3``35aLD0bLW90<?3``35aLD0bLW90<G5a@33`l<0
aLG50P33`l<30<71`@080<G5a@2g]kL0`l?30;^k^`2h^;P0]kNg0;>c/`2/[:`20:VYZ@0D0<G5a@36
a/H0Vi^K0:6QX@2YZJT0Vi^K08V9R@1nOWh0Kfm_08^;R`1dM7@0NGUi08^;R`2<S8`0OGem09>CT`2P
X:00VYZJ09>CT`22PX820;Fe]@040:6QX@35aLD0ZJVY0;:b/P<0aLG500L0cLg=0<k>cP3YjNT0j^[Z
0??cl`3gmoL0kno_00H0moOg6`3oool001T0oooo0P3gmoL01@3alO40moOg0?Ogm`3emOD0moOg0080
mOGe103gmoL40?Gem@80moOg00<0mOGe0?7al@3gmoL00P3gmoL04P3alO40gmoO0;no_`2h^;P0XZ:R
09RHV02?Shl0Jf][06=SH`1bLW80MGEe06][J`1BDU80d];B0<k>cP3IfMT0d];B0<g=c@80dM7A00D0
eMGE0=;BdP3Cdm<0clo?0<[:bP020=;BdP<0b/[:01<0d];B0<?3``3:b/X0aLG50<?3``3:b/X0`L71
0<30`02i^KT0^;Rh0:JVYP2^[Zh0^;Rh0:n_[`2TY:@0YJFU0:BTY02HV9P0OWin0080PX:200P0RXZ:
0:^[Z`2NWYh0SXj>08Z:RP2RXZ80WinO0:BTY080Zj^[00<0_kno0;Rh^02h^;P00`2_[jl02`2h^;P0
clo?0=;BdP3Bd]80h^;R0>KViP3[jn/0k^k^0>_[j`3clo<0k^k^0080moOg00<0mOGe0?Ogm`3gmoL0
0P3gmoLN0?ooo`80moOg00D0l?3`0?Ogm`3gmoL0lo?c0?Ogm`020??cl`@0moOg103clo<20?Ogm`03
0??cl`3`l?00moOg0080moOg0180l?3`0=_Kf`2e]KD0ZJVY09JFUP29RHT0OGem05YJFP1BDU80HF5Q
06MWI`1JFUX0ADE50<O7a`32`/80clo?0<O7a`31`L420<K6aP050<W9b@33`l<0a<C40<G5a@2k^k/0
0P33`l<30;^k^`0C0<?3``2g]kL0^k^k0;Rh^02g]kL0^k^k0;>c/`2b/[80ZZZZ0:VYZ@2EUID0X:2P
0:VYZ@2QXJ40Ti>C09BDU02CTi<0RHV906m_K`0207IfMP0;07UiN@2JVYX0Rh^;07alO01iNGT0UYJF
08b<S02CTi<0VYZJ09nOW`2e]KD00P2YZJT30:6QX@0;0:VYZ@35aLD0alO70<O7a`3Lg=`0h^;R0>WY
j@3_knl0jNWY0?7al@3_knl00P3gmoL00`3clo<0moOg0?Ogm`020?Ogma/0oooo000I0?ooo`040?Og
m`3emOD0moOg0?Ogm`80mOGe1P3gmoL00`3emOD0moOg0?Gem@020?Ogm`030?Gem@3gmoL0mOGe00<0
mOGe00`0lo?c0?7al@3Ng]h0`<300:n_[`2TY:@0Ti>C08^;R`1eMGD0LW9b08Z:RP1bLW8204i>CP06
0=;BdP3>c/h0dM7A0<K6aP3AdM40eMGE0P3:b/X01@3Bd]80cLg=0<[:bP3:b/X0`l?30080b/[:0P33
`l<00`31`L40b/[:0<71`@030<71`@0I0<30`02h^;P0^;Rh0:n_[`2[Zj/0^KVi0:NWY`2HV9P0TY:B
09nOW`2CTi<0NWYj09>CT`26QXH0RXZ:08^;R`2OWil0Y:BT09>CT`2OWil0V9RH09nOW`2RXZ80YjNW
0:^[Z`030;no_`0=0:n_[`2o_kl0[Zj^0;Rh^03?cll0dM7A0>;RhP3[jn/0lo?c0>_[j`3^k^h0jn_[
0??cl`030?Ogm`050?Gem@3alO40lO7a0?Gem@3gmoL07P3oool0103gmoL0lo?c0?Ogm`3gmoL20??c
l`H0moOg00<0lo?c0?Ogm`3clo<00P3gmoL00`3clo<0moOg0??cl`030??cl`0<0?7al@3`l?00f][J
0;Jf]P2QXJ40Ti>C08:2PP1jNWX0IfMW065QH@1iNGT0HF5Q0P0o?cl01P37alL0`/;20<K6aP2i^KT0
a/K60<W9b@80^k^k00D0`l?30<71`@2k^k/0^k^k0;Ng]`020;^k^`80]kNg00<0/k>c0;^k^`2c/k<0
0`2c/k<06@2b/[80ZJVY0:VYZ@2QXJ40VYZJ0:ZZZP2IVIT0RHV907inOP2<S8`0PX:206i^KP22PX80
O7al07UiN@1jNWX0S8b<09>CT`22PX80S8b<08V9R@2<S8`0UYJF09VIV@2OWil00`2e]KD03@2QXJ40
]KFe0:2PX02YZJT0aLG50<K6aP3Lg=`0jNWY0?7al@3YjNT0kno_0>WYj@3alO400`3gmoL01@3clo<0
l?3`0?3`l03clo<0moOg01/0oooo000I0?ooo`80moOg00@0mOGe0?Ogm`3gmoL0mOGe0P3gmoL00`3e
mOD0moOg0?Ogm`060?Ogm`060?Gem@3gmoL0mOGe0?Ogm`3clo<0lO7a0P3gmoL0303Bd]80^;Rh0;Rh
^02RXZ80Ti>C08^;R`1[Jf/0OWin079bLP1SHf<0ATI6059BDPD0dM7A00D0eMGE0<o?c`3:b/X0d];B
0<[:bP020<?3``040<71`@33`l<0`L710<?3``80`L7100@0aLG50<?3``30`<00_Kfm0`2i^KT01`2h
^;P0[jn_0:BTY02/[:`0V9RH09:BTP2CTi<00P2;Rh/208:2PP03079bLP1nOWh0Shn?0080Zj^[00<0
[jn_09nOW`2OWil00P2CTi<02@2[Zj/0Y:BT0;fm_@2o_kl0^KVi0;no_`35aLD0^;Rh0<?3``020<o?
c`050>[ZjP3[jn/0h^;R0>_[j`3^k^h00P3emOD00`3gmoL0mOGe0?Ogm`020?Ogm`030?Gem@3gmoL0
mOGe01h0oooo0P3gmoL0103clo<0moOg0?Ogm`3clo<20?Ogm`030??cl`3gmoL0moOg00H0moOg00H0
lo?c0?Ogm`3clo<0moOg0?7al@3`l?020?Ogm`0<0<O7a`2YZJT0ZJVY09JFUP22PX80NWYj05YJFP1_
Kfl0HF5Q059BDP0g=cL0ADE51@36a/H01@39bLT0aLG50;^k^`33`l<0^k^k0080]kNg00@0/k>c0;Ng
]`2c/k<0]kNg0P2c/k<0102h^;P0]kNg0;:b/P2/[:`30:ZZZP070:VYZ@2QXJ40Ti>C09^KV`29RHT0
OWin08:2PP0207YjNP80MWIf00<0HF5Q06m_K`1mOGd00P2JVYX00`2QXJ40S8b<08b<S00208:2PP09
09nOW`2CTi<0/;2`0;Fe]@2ZZZX0]KFe0;Rh^02YZJT0]kNg0080aLG500D0i>CT0>WYj@3Ph>00jNWY
0>o_k`020??cl`030?Ogm`3clo<0moOg0080moOg00<0lo?c0?Ogm`3clo<06`3oool001T0oooo0`3g
moL20?Gem@030?Ogm`3emOD0lO7a00<0moOg00<0mOGe0?Ogm`3gmoL00P3gmoL00`3emOD0moOg0?Og
m`020?Gem@0G0>k^kP3gmoL0mOGe0??cl`2m_Kd0^;Rh0:NWY`2TY:@0OWin08:2PP1eMGD0OWin07Ee
M@1NGUh0DU9B05iNGP3Bd]80alO70=7Ad@3=cLd0dM7A0<[:bP3?cll00`3:b/X02033`l<0`L710<71
`@2l_;`0_Kfm0<30`02m_Kd0`L710P30`<000`2h^;P0_;bl0;Rh^0020;Rh^080[:b/0P2TY:@01P2C
Ti<0Rh^;08V9R@29RHT0NWYj08:2PP80MGEe00L0OWin08j>SP2NWYh0Y:BT0:^[Z`2TY:@0XZ:R0080
Ti>C0100Y:BT0;Rh^02i^KT0^;Rh0<30`02o_kl0[jn_0;Rh^033`l<0dM7A0=OGe`3Rh^80jn_[0??c
l`3^k^h0jn_[0P3emOD70?Ogm`030?Gem@3oool0oooo01`0oooo0`3gmoL20??cl`030?Ogm`3clo<0
l?3`00<0moOg00<0lo?c0?Ogm`3gmoL00P3gmoL00`3clo<0moOg0?Ogm`020??cl`0G0>o_k`3gmoL0
lo?c0?7al@2d];@0ZJVY09VIV@2CTi<0Kfm_07IfMP1PH600Kfm_061PH01?Cdl0ADE504m?C`37alL0
^[Zj0<K6aP31`L40a/K60;^k^`35aLD00`2k^k/0202g]kL0/k>c0;>c/`2[Zj/0[:b/0;:b/P2/[:`0
/k>c0P2b/[800`2YZJT0Zj^[0:VYZ@020:VYZ@80Vi^K0P2CTi<01P22PX80NWYj07IfMP1fMWH0KVi^
07IfMP80IfMW00L0Kfm_07alO02;Rh/0Ti>C09ZJVP2CTi<0UYJF0080PX:20100Ti>C0:VYZ@2ZZZX0
ZJVY0;Jf]P2e]KD0XJ6Q0:VYZ@2g]kL0a/K60<k>cP3Ph>00jNWY0?7al@3_knl0jNWY0P3clo<70?Og
m`030??cl`3oool0oooo01T0oooo000I0?ooo`030?Ogm`3emOD0moOg0080mOGe0`3gmoL0103alO40
moOg0?Ogm`3emOD20?Ogm`040?Gem@3clo<0lO7a0?Ogm`80mOGe00/0moOg0?Gem@3gmoL0k^k^0??c
l`30`<00^;Rh0:BTY02HV9P0Rh^;09>CT`0207inOP0907EeM@16ATH0ATI604i>CP3AdM40a/K60<k>
cP36a/H0cLg=00<0b/[:00@0`L710<?3``30`<00`<300P2m_Kd00`2l_;`0[jn_0:n_[`020;Rh^003
0;fm_@2h^;P0^;Rh0080[jn_0P2/[:`01P2UYJD0XZ:R08^;R`2:RXX0OWin08V9R@80Rh^;0P1nOWh0
2026QXH0SXj>08n?S`2NWYh0_kno0;Rh^033`l<0YjNW0P2:RXX00`2WYjL0Y:BT0;Rh^0020;no_`<0
[Zj^00T0clo?0=KFeP3GemL0jn_[0>KViP3^k^h0jn_[0?Ogm`3emOD00`3gmoL01P3emOD0moOg0?Og
m`3alO40moOg0?GemAh0oooo00<0moOg0??cl`3gmoL00P3clo<30?Ogm`040?3`l03gmoL0moOg0??c
l`80moOg00@0lo?c0?7al@3`l?00moOg0P3clo<02`3gmoL0lo?c0?Ogm`3_knl0lO7a0;Jf]P2YZJT0
Ti>C08V9R@1jNWX0PX:20080Kfm_00T0IfMW03/k>`0g=cL0?clo0<K6aP2i^KT0`/;20;Vi^@31`L40
0`2k^k/0102c/k<0]kNg0;:b/P2b/[820:b/[0030:^[Z`2QXJ40XJ6Q0080ZJVY00<0[:b/0:VYZ@2Y
ZJT00P2QXJ4209^KV`0609BDU02FUYH0NWYj07UiN@1_Kfl0MWIf0P1jNWX206m_K`0807AdM01lO7`0
OGem08^;R`2a/K40ZJVY0;Ng]`2IVIT207UiN@0309VIV@2CTi<0ZJVY0080]KFe0`2PX:002@35aLD0
cLg=0<k>cP3YjNT0h^;R0>o_k`3YjNT0moOg0??cl`030?Ogm`060??cl`3gmoL0moOg0?3`l03gmoL0
lo?c6`3oool001T0oooo00D0mOGe0?Ogm`3emOD0mOGe0??cl`020?7al@060?Gem@3gmoL0moOg0?7a
l@3gmoL0mOGe0P3gmoL00`3clo<0moOg0?Ogm`020?Ogm`030?Gem@3alO40mOGe0080lo?c00T0_kno
0:^[Z`2RXZ80Ti>C07inOP22PX80RXZ:06][J`1SHf<00P0n?Sh0201>CTh0dM7A0<K6aP3=cLd0c/k>
0<g=c@3:b/X0`L711030`<000`2i^KT0^;Rh0;bl_0020;Rh^0<0[jn_0P2h^;P20:n_[`80YJFU00L0
Y:BT09RHV02TY:@0OWin07EeM@2;Rh/0OWin0080Rh^;00<0GUiN06][J`2;Rh/00`2NWYh02@2^[Zh0
^;Rh0:n_[`2o_kl0XZ:R09>CT`2TY:@0[jn_0:BTY0020<30`0050:j^[P2_[jl0[Zj^0<o?c`3Fe]H0
0`3[jn/0103/k>`0lO7a0?Ogm`3^k^h20?Ogm`030?Gem@3gmoL0moOg00@0moOg7P3oool01@3clo<0
moOg0??cl`3clo<0lO7a0080l?3`00H0lo?c0?Ogm`3gmoL0l?3`0?Ogm`3clo<20?Ogm`030?7al@3g
moL0moOg0080moOg00<0lo?c0?3`l03clo<00P3alO402@2e]KD0WinO09JFUP22PX80Kfm_07IfMP1i
NGT0FUYJ059BDP0203<c<`0803lo?`36a/H0^KVi0<71`@32`/80`L710;^k^`2c/k<40;:b/P030:ZZ
ZP2YZJT0Zj^[0080ZJVY0`2QXJ420:VYZ@80XJ6Q0P2DU9@01`2CTi<0RHV909>CT`1_Kfl0IfMW07Yj
NP1_Kfl00P1jNWX00`1?Cdl0FUYJ07IfMP0308^;R`090:2PX02YZJT0XJ6Q0;Fe]@2FUYH0PX:209>C
T`2QXJ40Ti>C0080][Jf00D0X:2P0:6QX@2PX:00aLG50<g=c@030>WYj@040>[ZjP3`l?00moOg0>o_
k`80moOg00<0lo?c0?Ogm`3gmoL0103gmoLK0?ooo`006@3oool30?Ogm`80mOGe00@0lO7a0?Gem@3e
mOD0mOGe1@3gmoL00`3clo<0mOGe0?7al@020?Ogm`070?Gem@3gmoL0lO7a0?Gem@3^k^h0emOG0;6a
/@0209RHV00408:2PP29RHT0OWin07EeM@80DU9B00X0CTi>059BDP1BDU80a/K60<G5a@36a/H0d];B
0<_;b`39bLT0bl_;0P39bLT01`35aLD0`L710;Vi^@2/[:`0Y:BT0:b/[02QXJ400`2TY:@20:b/[080
Y:BT0P2HV9P02`2BTY80Ti>C0:BTY01QHF40OWin08^;R`1[Jf/0GUiN05YJFP1bLW80Q8B40080WYjN
00X0Ti>C09jNWP2^[Zh0^;Rh0;no_`2_[jl0Zj^[0:BTY02WYjL0XZ:R0P2o_kl20:j^[P80_kno00D0
d];B0??cl`3Rh^80k^k^0>c/k00:0?Ogm`030?Gem@3gmoL0mOGe01h0oooo0`3gmoL20??cl`040?3`
l03clo<0lo?c0??cl`D0moOg00<0lO7a0??cl`3`l?000P3gmoL01`3clo<0moOg0?3`l03clo<0kno_
0<k>cP2VYZH00P29RHT207IfMP0506m_K`1WIfL0ADE504E5A@0o?cl00P15ADD01`2i^KT0^;Rh0;Vi
^@37alL0_;bl0;Ng]`2l_;`00P2g]kL01`2h^;P0/k>c0:ZZZP2KVi/0Ti>C09^KV`2>SXh00`2CTi<2
09^KV`80Ti>C0P29RHT02`1nOWh0PX:209>CT`1EEED0Kfm_07YjNP1JFUX0Cdm?04U9B@1QHF40KVi^
0080Rh^;00X0PX:208^;R`2PX:00ZJVY0;Fe]@2QXJ40WinO09>CT`2IVIT0UYJF0P2e]KD20:2PX080
]KFe00D0c<c<0?7al@3Lg=`0kno_0>[ZjP0:0?Ogm`030??cl`3gmoL0lo?c01/0oooo000I0?ooo`06
0?Gem@3gmoL0k^k^0>k^kP3gmoL0mOGe0P3gmoL02@3emOD0moOg0?Ogm`3alO40moOg0?Gem@3clo<0
mOGe0??cl`020?Ogm`0?0?Gem@3alO40lO7a0?7al@3[jn/0d];B0:^[Z`2HV9P0Ti>C08^;R`1nOWh0
Ti>C07EeM@0j>SX0FUYJ0080DU9B00<0CTi>0<K6aP3Fe]H00`3Jf]X02@3IfMT0dm?C0=?Cd`3Cdm<0
c<c<0<_;b`35aLD0`L710;Vi^@020:6QX@0309nOW`2QXJ40V9RH0080V9RH00@0Y:BT0:6QX@2OWil0
Ti>C0P2;Rh/05@2OWil0K6a/07inOP1cLg<0Hf=S04i>CP1BDU80Hf=S07inOP2OWil0WYjN09>CT`2:
RXX0Zj^[0;Vi^@33`l<0aLG50;no_`2[Zj/0V9RH08n?S`020;no_`050:^[Z`2o_kl0_kno0=7Ad@3^
k^h00P3[jn/01@3^k^h0lo?c0?Gem@3gmoL0mOGe00<0moOg00<0mOGe0?Ogm`3gmoL00P3gmoL00`3e
mOD0lO7a0?ooo`0M0?ooo`060??cl`3gmoL0kno_0>o_k`3gmoL0lo?c0P3gmoL02@3clo<0moOg0?Og
m`3`l?00moOg0??cl`3alO40lo?c0?7al@020?Ogm`0?0??cl`3`l?00l?3`0?3`l03YjNT0c<c<09nO
W`29RHT0PX:207YjNP1_Kfl0PX:206MWI`0^;Rh0CTi>0080ADE500<0?clo0;Vi^@3=cLd00`3@d=00
2@3?cll0a<C40<C4a034a<@0_Kfm0;bl_02h^;P0/k>c0:ZZZP0208j>SP0308b<S02>SXh0RHV90080
RHV900@0Ti>C08j>SP2<S8`0PX:20P1jNWX05@2<S8`0Fe]K06m_K`1VIVH0DU9B03lo?`15ADD0DU9B
06m_K`2<S8`0Rh^;08:2PP1iNGT0VYZJ0:ZZZP2g]kL0^;Rh0;Fe]@2OWil0RHV907emO@020;Fe]@05
09nOW`2e]KD0]KFe0<K6aP3_knl00P3YjNT01@3_knl0lO7a0??cl`3gmoL0lo?c00<0moOg00<0lo?c
0?Ogm`3gmoL00P3gmoL00`3clo<0l?3`0?ooo`0J0?ooo`006@3oool00`3gmoL0mOGe0?Ogm`020?Og
m`030?Gem@3gmoL0moOg00<0moOg00<0mOGe0?Ogm`3gmoL00P3gmoL01@3^k^h0moOg0?Gem@3gmoL0
lO7a0080mOGe0140f][J0<K6aP2WYjL0V9RH08n?S`1eMGD0OWin07EeM@1SHf<0ATI605iNGP1JFUX0
DU9B04i>CP3Jf]X0fm_K0>KViP020>3Ph0040=[JfP3Ph>00f][J0=[JfP80dm?C00L0bl_;0<G5a@31
`L40_Kfm0:n_[`2OWil0V9RH0080WinO01`0XJ6Q09:BTP2HV9P0V9RH09>CT`2;Rh/0NWYj09>CT`1n
OWh0Ti>C06=SH`1JFUX0CTi>05iNGP1WIfL0OWin08n?S`2OWil0SXj>08Z:RP2TY:@0Zj^[0<?3``35
aLD0_kno0;Rh^02CTi<0XZ:R0`2h^;P02`3?cll0^;Rh0=7Ad@3^k^h0i^KV0=kNgP3/k>`0moOg0?Ge
m@3gmoL0lO7a00<0mOGe0P3gmoL00`3emOD0moOg0?Ogm`020?Ogmah0oooo00<0moOg0??cl`3gmoL0
0P3gmoL00`3clo<0moOg0?Ogm`030?Ogm`030??cl`3gmoL0moOg0080moOg00D0kno_0?Ogm`3clo<0
moOg0?3`l0020??cl`0A0=CDe02m_Kd0VIVI08V9R@21PH40IfMW06m_K`1WIfL0DU9B03Lg=`1?Cdl0
CTi>04E5A@0o?cl0d=3@0=7Ad@3Ng]h00P3Cdm<0103@d=00dm?C0=3@d03@d=020<C4a0070;bl_02h
^;P0/k>c0:b/[02QXJ40S8b<08V9R@0208b<S00L08j>SP1nOWh0RHV908V9R@22PX80NWYj06i^KP22
PX80Kfm_08:2PP1BDU80BDU903lo?`1CDe<0E5AD06m_K`1mOGd0S8b<07alO01iNGT0Ti>C09ZJVP2g
]kL0^;Rh0;Fe]@2YZJT0PX:209JFUP<0ZJVY00/0aLG50:VYZ@36a/H0kno_0>;RhP3Jf]X0j^[Z0?Og
m`3clo<0moOg0?3`l0030??cl`80moOg00<0lo?c0?Ogm`3gmoL00P3gmoLK0?ooo`006@3oool01`3e
mOD0moOg0?Ogm`3emOD0lo?c0?Ogm`3alO400`3gmoL01@3emOD0lo?c0?Ogm`3emOD0moOg0080mOGe
00@0moOg0?Gem@3alO40lo?c0P3emOD0103Jf]X0_Kfm0::RXP2?Shl208^;R`0507inOP1eMGD0ATI6
059BDP1QHF400P1BDU801@2PX:00h^;R0>KViP3Rh^80i^KV0080h>3P00/0h^;R0>3Ph03Jf]X0fMWI
0=[JfP3Cdm<0bl_;0<[:bP31`L40`<300;Rh^00409>CT`0I09nOW`2CTi<0Ti>C08V9R@22PX80Jf][
06=SH`1eMGD0Y:BT05YJFP1>CTh0>SXj04I6AP2?Shl0LW9b08n?S`2[Zj/0RXZ:0::RXP2TY:@0^;Rh
0<?3``3?cll0d];B0<30`0020::RXP0:0:n_[`2WYjL0^;Rh0;no_`30`<00k>c/0>KViP3Ogml0jn_[
0?Gem@80moOg00@0lo?c0?Ogm`3gmoL0moOg0P3emOD30?Ogm`030?Gem@3gmoL0moOg01h0oooo00L0
lo?c0?Ogm`3gmoL0lo?c0?7al@3gmoL0l?3`00<0moOg00D0lo?c0?7al@3gmoL0lo?c0?Ogm`020??c
l`040?Ogm`3clo<0l?3`0?7al@80lo?c00@0e=CD0;Bd]02FUYH0PH610P1jNWX01@1_Kfl0IfMW03Lg
=`15ADD0EEEE0080ADE500D0UYJF0=SHf03Ng]h0f=SH0=kNgP020=?Cd`0;0=SHf03Cdm<0d=3@0<o?
c`3@d=00a<C40;bl_02k^k/0/k>c0;:b/P2YZJT01022PX800`2<S8`0PX:208:2PP0207IfMP0D05iN
GP1BDU80IfMW09>CT`19BDT0?clo02h^;P0g=cL0OGem065QH@1mOGd0VYZJ07UiN@2FUYH0Ti>C0:VY
Z@2g]kL0aLG50<O7a`2f][H209JFUP0:0:6QX@2IVIT0ZJVY0;Fe]@2b/[80j^[Z0>;RhP3Fe]H0jNWY
0??cl`80moOg00@0lO7a0?Ogm`3gmoL0moOg0P3clo<30?Ogm`030??cl`3gmoL0moOg01/0oooo000I
0?ooo`030?Ogm`3emOD0moOg00<0moOg00<0lO7a0?Gem@3gmoL00P3gmoL00`3clo<0mOGe0?Ogm`03
0?Gem@<0moOg00P0lO7a0>c/k03Ng]h0e]KF0;6a/@2HV9P0PX:207EeM@80OWin00H0MGEe04I6AP1Q
HF40HF5Q059BDP3GemL20>;RhP80i^KV00<0h^;R0>KViP3Ph>000P3Ph>002`3Rh^80f][J0=WIf@3I
fMT0dM7A0<K6aP35aLD0b/[:0<71`@2_[jl0TY:B0080Rh^;0180Ti>C08^;R`2;Rh/0RHV907inOP1S
Hf<0GUiN06=SH`2/[:`0OWin059BDP1NGUh0>SXj09nOW`1WIfL0Shn?09nOW`2>SXh20:BTY0070:j^
[P2h^;P0dM7A0=;BdP2o_kl0V9RH0::RXP020:^[Z`80_kno00T0clo?0>;RhP3Ogml0h^;R0>k^kP3g
moL0lo?c0?Ogm`3emOD00P3gmoL0103emOD0moOg0?Gem@3emOD50?Ogmah0oooo00<0moOg0??cl`3g
moL00`3gmoL00`3`l?00lo?c0?Ogm`020?Ogm`030?7al@3clo<0moOg00<0lo?c0`3gmoL0203`l?00
j^[Z0=[JfP3=cLd0YZJV08V9R@1fMWH0IfMW0P1_Kfl01P1WIfL0=cLg05EEE@1EEED0ADE50<k>cP80
f=SH0P3Ng]h00`3Lg=`0g]kN0=?Cd`020=?Cd`0;0=SHf03@d=00clo?0<o?c`36a/H0^KVi0;Rh^02k
^k/0/k>c0:6QX@1nOWh00P1jNWX04P22PX80NWYj07YjNP1fMWH0Kfm_059BDP1?Cdl0DU9B09^KV`1_
Kfl0ADE505=CD`0^;Rh0S8b<05ADE01mOGd0S8b<07alO080Ti>C00L0X:2P0:VYZ@36a/H0alO70;Fe
]@29RHT0UYJF0080WinO0P2e]KD02@35aLD0h>3P0=_Kf`3Ph>00kno_0?Ogm`3alO40moOg0??cl`02
0?Ogm`040??cl`3gmoL0lo?c0??cl`D0moOg6`3oool001T0oooo00<0lO7a0?Ogm`3gmoL00P3gmoL0
103clo<0moOg0?Gem@3gmoL30?Gem@040??cl`3gmoL0mOGe0??cl`80moOg0180k^k^0?Ogm`3^k^h0
h^;R0=GEe@2m_Kd0Z:RX09>CT`22PX80Jf][07EeM@1[Jf/0MGEe059BDP1JFUX0Lg=c0=[JfP3Kfm/3
0>;RhP050>KViP3Ph>00i^KV0>3Ph03Vi^H00P3Ph>00103Jf]X0fMWI0=[JfP3IfMT20<k>cP0]0<g=
c@36a/H0`L710;Vi^@2_[jl0YZJV07inOP29RHT0N7Qh07inOP1VIVH0HF5Q04I6AP2i^KT0Jf][0:n_
[`1jNWX0Rh^;04i>CP1/K6`0XZ:R08J6QP2NWYh0WinO0::RXP2[Zj/0V9RH0;no_`2^[Zh0d];B0=kN
gP2CTi<0XZ:R0:NWY`2a/K40^;Rh0<30`03?cll0h^;R0>_[j`3/k>`0lo?c0?Gem@3gmoL0mOGe0080
moOg00D0mOGe0?Ogm`3emOD0mOGe0?Ogm`030?Gem@80moOg7P3oool00`3`l?00moOg0?Ogm`020?Og
m`040?7al@3gmoL0lo?c0?Ogm`<0lo?c00@0lO7a0?Ogm`3clo<0lO7a0P3gmoL04P3_knl0moOg0>o_
k`3Ph>00dM7A0;Bd]02NWYh0PX:207IfMP1NGUh0IfMW05YJFP1WIfL0ADE504i>CP1VIVH0d=3@0=7A
d@<0f=SH00D0g]kN0=?Cd`3Ng]h0dm?C0=kNgP020=?Cd`040=3@d03?cll0d=3@0<o?c`80`/;202d0
`L710;Vi^@2c/k<0ZZZZ0:6QX@2EUID0Kfm_07IfMP1YJFT0Kfm_05QHF01EEED0=cLg0:ZZZP1JFUX0
XJ6Q06i^KP1jNWX0?clo05]KF`2FUYH0M7Ad08^;R`2<S8`0UYJF09nOW`29RHT0]KFe0:2PX037alL0
eMGE08:2PP2FUYH0VIVI0:JVYP2YZJT0][Jf0<G5a@3Ph>00jNWY0>[ZjP3alO40lo?c0?Ogm`3clo<0
0P3gmoL01@3clo<0moOg0??cl`3clo<0moOg00<0lo?c0P3gmoLK0?ooo`006@3oool00`3emOD0moOg
0?Ogm`020?Ogm`80mOGe0`3gmoL20?Gem@030?Ogm`3emOD0moOg00@0moOg00P0mOGe0>c/k03Jf]X0
eMGE0;6a/@2WYjL0Ti>C07YjNP80MGEe00L0JVYZ059BDP1VIVH0Kfm_0=_Kf`3Jf]X0gMgM0080h^;R
00<0h>3P0=gMg@3Jf]X00`3Jf]X01P3IfMT0dm?C0=?Cd`3Bd]80dM7A0=GEe@80c/k>00L0aLG50<[:
bP35aLD0`L710;Rh^02_[jl0[:b/0080OWin00l0K6a/06][J`1BDU80DU9B0::RXP2HV9P0PX:20;6a
/@1WIfL0V9RH08V9R@2?Shl0WinO08Z:RP2OWil00`2RXZ820;Rh^00>0;fm_@35aLD0XZ:R08n?S`2R
XZ80/K6a0:^[Z`3?cll0gmoO0>k^kP3Rh^80k^k^0??cl`3gmoL20?Gem@060?Ogm`3emOD0moOg0?Ge
m@3gmoL0mOGe1P3gmoLN0?ooo`030??cl`3gmoL0moOg0080moOg0P3clo<30?Ogm`80lo?c00<0moOg
0??cl`3gmoL0103gmoL0203clo<0j^[Z0=CDe03AdM40YZJV09VIV@22PX80KVi^0P1WIfL01`1MGEd0
ADE505QHF01TI6@0dM7A0=3@d03EeMD00P3Hf=P00`3Cdm<0eMGE0=3@d0030=3@d0060<o?c`34a<@0
a<C40<O7a`36a/H0bLW90P32`/801`2h^;P0^k^k0;Rh^02c/k<0ZJVY0:6QX@2KVi/00P1_Kfl03`1K
Fe/0FUYJ04E5A@15ADD0UYJF08V9R@1fMWH0YZJV05ADE029RHT0MWIf07emO@2<S8`0NGUi08b<S003
09JFUP80ZJVY00h0];Bd0;Rh^02FUYH0OGem09JFUP2VYZH0WinO0<G5a@3Kfm/0kno_0>3Ph03_knl0
lO7a0?Ogm`80lo?c00H0moOg0??cl`3gmoL0lo?c0?Ogm`3clo<60?Ogma/0oooo000I0?ooo`D0moOg
00<0mOGe0?Ogm`3emOD00P3emOD20?Ogm`040?Gem@3gmoL0lo?c0?7al@80mOGe0P3gmoL01P3Ogml0
f][J0<71`@2XZ:P0V9RH07YjNP<0MGEe00<0ATI6059BDP1>CTh00P3Kfm/0203Rh^80gMgM0=[JfP3P
h>00f][J0=GEe@3>c/h0bl_;0`35aLD01031`L40aLG50<G5a@35aLD30<g=c@0Z0<k>cP3=cLd0aLG5
0<71`@2m_Kd0^KVi0;Rh^02/[:`0MGEe06YZJP1WIfL0FUYJ059BDP1jNWX0[jn_0::RXP2>SXh0^;Rh
09nOW`1SHf<0RXZ:0:BTY02NWYh0WinO08Z:RP2HV9P0^KVi0:^[Z`2h^;P0_kno0=;BdP2RXZ80Zj^[
0;Vi^@2[Zj/0YjNW0=7Ad@3clo<0h^;R0?Gem@3^k^h0lo?c0P3gmoL00`3emOD0moOg0?7al@030?Ge
m@H0moOg00<0mOGe0?ooo`3oool0703oool50?Ogm`030??cl`3gmoL0lo?c0080lo?c0P3gmoL0103c
lo<0moOg0?7al@3`l?020??cl`80moOg00H0fm_K0=CDe02k^k/0WYjN08V9R@1^KVh306MWI`0303/k
>`15ADD0?clo0080dM7A00P0f=SH0=GEe@3@d=00dm?C0=3@d039bLT0`/;20;bl_0<0^;Rh00@0/k>c
0;Rh^02h^;P0^;Rh0`31`L40:P32`/80`L710;Rh^02c/k<0[:b/0:ZZZP2YZJT0Vi^K06MWI`1MGEd0
F5QH04i>CP15ADD0KVi^0:6QX@2FUYH0Q8B40:VYZ@2<S8`0DU9B07UiN@2CTi<0Rh^;08b<S01iNGT0
RHV90:ZZZP2OWil0ZJVY0;Fe]@37alL0UYJF09nOW`2ZZZX0WinO09VIV@36a/H0lO7a0>3Ph03clo<0
kno_0?7al@80moOg00<0lo?c0?Ogm`3`l?000`3clo<60?Ogm`030??cl`3oool0oooo01T0oooo000I
0?ooo`050?Ogm`3emOD0moOg0?Ogm`3emOD00`3gmoL00`3emOD0moOg0?Ogm`030?Ogm`80mOGe0P3g
moL20?Gem@0<0=kNgP3EeMD0`<300:^[Z`2CTi<0RHV906a/K01eMGD0JVYZ04i>CP1BDU80emOG0P3N
g]h0203Rh^80gMgM0=[JfP3IfMT0d];B0<_;b`3:b/X0`L711@2n_[h20<71`@090<G5a@31`L40cLg=
0<g=c@3>c/h0aLG50<71`@2m_Kd0^KVi0080[jn_01H0Lg=c06ATI01QHF40DU9B03hn?P1gMgL0[jn_
08n?S`1eMGD0_Kfm09nOW`2HV9P0OWin08^;R`2[Zj/0WinO09>CT`2HV9P0^;Rh0:^[Z`2o_kl0^;Rh
0P2o_kl01@2h^;P0/K6a0;6a/@2h^;P0d];B0080jn_[00@0lo?c0>k^kP3emOD0mOGe0P3gmoL0103a
lO40moOg0?Ogm`3emOD20?Ogm`030?Gem@3gmoL0moOg00<0moOg7P3oool01@3gmoL0lo?c0?Ogm`3g
moL0lo?c00<0moOg00<0lo?c0?Ogm`3gmoL00`3gmoL20??cl`80moOg0P3clo<0303Jf]X0dM7A0;Jf
]P2OWil0PX:207IfMP1KFe/0IfMW05eMG@0o?cl0ADE50<k>cP80eMGE00P0f=SH0=GEe@3@d=00clo?
0<O7a`2l_;`0^k^k0;>c/`D0YZJV0P2c/k<02@2h^;P0/k>c0<71`@31`L40`/;20;Rh^02c/k<0/;2`
0:ZZZP020:6QX@0F06IVIP1CDe<0EEEE04E5A@0c<c<0K6a/0:6QX@21PH40IfMW0;2`/02<S8`0RHV9
06m_K`1jNWX0VYZJ08b<S022PX80RHV90:VYZ@2OWil0]KFe0:VYZ@80]KFe00D0ZJVY0:JVYP2VYZH0
ZJVY0<O7a`020>WYj@040?7al@3_knl0lo?c0??cl`80moOg00@0l?3`0?Ogm`3gmoL0lo?c0P3gmoL0
0`3clo<0moOg0?Ogm`030?Ogma/0oooo000I0?ooo`040?Ogm`3emOD0moOg0?Gem@@0moOg00<0mOGe
0?Ogm`3gmoL00`3gmoL03P3emOD0lo?c0??cl`3gmoL0mOGe0>k^kP3Jf]X0e]KF0;6a/@2HV9P0Shn?
08V9R@1[Jf/0IVIV0P1BDU800`1JFUX0fm_K0=_Kf`040=[JfP030=?Cd`2^[Zh0XJ6Q0080/K6a102e
]KD30:6QX@030;Vi^@35aLD0aLG50080cLg=00<0a/K60<G5a@31`L400P2i^KT0:02_[jl0Y:BT065Q
H@1BDU80CTi>03Xj>P1[Jf/0Shn?0;Vi^@2KVi/0YZJV0;no_`2h^;P0Zj^[09nOW`2CTi<0Y:BT0::R
XP2CTi<0XZ:R0;Rh^02RXZ80`l?30<30`03Bd]80/K6a0;no_`2[Zj/0^;Rh0=GEe@3Ogml0k>c/0>k^
kP3/k>`0k^k^0?Ogm`3alO40mOGe0?Ogm`3emOD20?Ogm`060?Gem@3gmoL0moOg0?Gem@3gmoL0mOGe
0P3gmoLN0?ooo`040?Ogm`3clo<0moOg0??cl`@0moOg00<0lo?c0?Ogm`3gmoL00`3gmoL03P3clo<0
lO7a0?7al@3gmoL0lo?c0>o_k`3De=@0d];B0:JVYP29RHT0PH6107IfMP1NGUh0F5QH0P15ADD00`19
BDT0dM7A0=7Ad@040=3@d0030<C4a02ATI40QhN70080UiNG102MWId308N7Q`030:ZZZP2h^;P0^;Rh
0080`L7100<0^KVi0;Rh^02c/k<00P2ZZZX0:02QXJ40Ti>C05EEE@15ADD0?clo02h^;P1NGUh0PH61
0:ZZZP2?Shl0UIFE0;Fe]@2YZJT0WinO08b<S022PX80Ti>C09JFUP22PX80UYJF0:VYZ@2FUYH0]kNg
0;Jf]P37alL0YZJV0;Fe]@2OWil0ZJVY0=7Ad@3Kfm/0j^[Z0>o_k`3Zj^X0kno_0?Ogm`3`l?00lo?c
0?Ogm`3clo<20?Ogm`060??cl`3gmoL0moOg0??cl`3gmoL0lo?c0P3gmoLK0?ooo`006@3oool01@3g
moL0mOGe0?Gem@3gmoL0mOGe00<0moOg00L0mOGe0?Ogm`3gmoL0mOGe0??cl`3gmoL0mOGe0080moOg
00l0lo?c0?Ogm`3/k>`0g]kN0<30`02[Zj/0SXj>08:2PP1eMGD0HF5Q06][J`1JFUX0DU9B065QH@3K
fm/00P3Jf]X00`3IfMT0gMgM0=[JfP030;Fe]@050=_Kf`3Cdm<0_[jn0<W9b@3Cdm<00P2e]KD0202a
/K40YJFU0:6QX@2i^KT0aLG50<K6aP3=cLd0a/K60P35aLD01P2m_Kd0^KVi0:n_[`2UYJD0V9RH05iN
GP80?Shn00D0Jf][03hn?P2m_Kd0aLG507inOP020<30`00@0;no_`2RXZ80Y:BT0:j^[P26QXH0V9RH
0::RXP2[Zj/0[jn_0;Vi^@30`<00emOG0:RXZ02KVi/0Zj^[0;Rh^080jn_[0P3^k^h00`3[jn/0moOg
0?7al@020?Gem@040?Ogm`3emOD0moOg0?Gem@80moOg00H0mOGe0?Ogm`3gmoL0mOGe0?Ogm`3emODN
0?ooo`050?Ogm`3clo<0lo?c0?Ogm`3clo<00`3gmoL01`3clo<0moOg0?Ogm`3clo<0lO7a0?Ogm`3c
lo<00P3gmoL03`3alO40moOg0>[ZjP3Jf]X0][Jf09nOW`24Q8@0MWIf06MWI`1EEED0GUiN04i>CP15
ADD0EEEE0=7Ad@020=3@d0030<o?c`3EeMD0d=3@00<0WIfM00D0dM7A0<C4a02VYZH0]kNg0<C4a002
09fMW@0809NGU`2=SHd0QhN70:ZZZP2h^;P0^KVi0<71`@2i^KT20;Rh^0060;2`/02ZZZX0XJ6Q09BD
U029RHT0De=C0P0c<c<05`1NGUh0<c<c0;2`/02h^;P0Kfm_0;Jf]P2b/[80]KFe09JFUP2CTi<0X:2P
07AdM029RHT0UYJF09nOW`2QXJ40ZZZZ0;Jf]P3>c/h0WYjN08n?S`2OWil0ZJVY0080jNWY0P3_knl0
0`3YjNT0moOg0?3`l0020??cl`040?Ogm`3clo<0moOg0??cl`80moOg00H0lo?c0?Ogm`3gmoL0lo?c
0?Ogm`3clo<K0?ooo`006@3oool30?Ogm`80mOGe00@0moOg0?Gem@3emOD0moOg0`3emOD20?Ogm`03
0?Gem@3gmoL0mOGe0080mOGe00d0gmoO0;Rh^02[Zj/0Shn?07YjNP1/K6`0IVIV04i>CP1NGUh0CTi>
07EeM@3Ogml0g]kN0080f][J01<0fMWI0;jn_P2e]KD0MGEe07moO`2=SHd0Shn?08f=S@2FUYH0QhN7
07EeM@1/K6`0LW9b07moO`1mOGd0LW9b06ATI01hN7P0]KFe0080cLg=0`35aLD30;Vi^@0>0:FUY@2H
V9P0Lg=c038b<P1BDU80GUiN06m_K`2RXZ80_Kfm07EeM@2HV9P0^KVi0=7Ad@3MgMd20:n_[`0E0:BT
Y02HV9P0XZ:R0:NWY`2HV9P0_kno0=;BdP39bLT0^;Rh0;no_`2a/K40h^;R0>k^kP3[jn/0k^k^0?Ge
m@3^k^h0moOg0?Gem@3gmoL0mOGe00L0moOg0P3emOD20?Ogmah0oooo0`3gmoL20??cl`040?Ogm`3c
lo<0lo?c0?Ogm`<0lo?c0P3gmoL00`3clo<0moOg0??cl`020??cl`0=0=_Kf`2YZJT0WinO0861P@1^
KVh0Fe]K05QHF00o?cl0Cdm?03lo?`1WIfL0e]KF0=GEe@020=3@d00C0<o?c`2VYZH0WIfM061PH01U
IFD0L71`0861P@1`L700NGUi06e]K@1PH600Cdm?05YJFP1UIFD0H61P05YJFP1CDe<0JFUY09fMW@02
0<71`@<0^;Rh0`2ZZZX03P2DU9@0RHV906IVIP0U9BD0ADE505=CD`1TI6@0UYJF0;2`/01WIfL0RHV9
0:ZZZP36a/H0eMGE0P2QXJ405@2CTi<0RHV909JFUP2IVIT0RHV90;Fe]@37alL0`l?30:VYZ@2e]KD0
YZJV0>3Ph03_knl0jNWY0>o_k`3clo<0kno_0?Ogm`3clo<0moOg0??cl`070?Ogm`80lo?c0P3gmoLK
0?ooo`006@3oool20?Gem@80moOg0P3emOD01P3gmoL0mOGe0?Gem@3gmoL0mOGe0?Ogm`@0mOGe00T0
lo?c0?Gem@3/k>`0gmoO0:RXZ02HV9P0NWYj06a/K01cLg<00`1QHF403`1TI6@0gmoO0=oOg`3Ng]h0
h^;R0=[JfP3IfMT0dm?C0=WIf@2UYJD0XJ6Q09RHV02QXJ40V9RH0;6a/@0509RHV0030;Rh^02m_Kd0
_[jn0080aLG501@0cLg=0<[:bP3:b/X0aLG50<[:bP31`L40^KVi0;Rh^02_[jl0YJFU08J6QP19BDT0
:BTY04U9B@1_Kfl0QXJ60;Vi^@2[Zj/0^;Rh09RHV080dM7A00@0g]kN08n?S`2TY:@0V9RH0P2RXZ80
1`2HV9P0_kno0=;BdP3Fe]H0Zj^[0;no_`2h^;P00P3/k>`20>_[j`<0mOGe103gmoL00`3emOD0moOg
0?Gem@020?Ogm`030?Gem@3gmoL0mOGe0080moOg7P3oool20??cl`80moOg0P3clo<01P3gmoL0lo?c
0??cl`3gmoL0lo?c0?Ogm`@0lo?c00T0lO7a0??cl`3Zj^X0fm_K09jNWP29RHT0KVi^05]KF`1VIVH0
0`1EEED03`1CDe<0e]KF0=KFeP3EeMD0f=SH0=3@d03?cll0a<C40<o?c`2=SHd0QhN707inOP27QhL0
OWin09NGU`0507inOP030:VYZ@2`/;00/K6a0080^;Rh01@0`L710;^k^`2k^k/0^;Rh0;^k^`2c/k<0
ZZZZ0:VYZ@2QXJ40U9BD07alO011@D408B4Q0451@@1TI6@0O7al0:ZZZP2OWil0ZJVY08V9R@80a/K6
00@0eMGE0861P@2CTi<0RHV90P2FUYH01`29RHT0]KFe0<O7a`3=cLd0WinO0;Fe]@2YZJT00P3Zj^X2
0>WYj@<0lo?c103gmoL00`3clo<0moOg0??cl`020?Ogm`030??cl`3gmoL0lo?c0080moOg6`3oool0
01T0oooo00@0moOg0?Gem@3gmoL0mOGe0`3gmoL20?Gem@H0moOg00H0mOGe0>k^kP3clo<0jn_[0=KF
eP2KVi/208:2PP0H07=cL`1[Jf/0FUYJ065QH@1SHf<0JVYZ0=kNgP3Jf]X0gMgM0=[JfP3MgMd0fMWI
0=gMg@3Rh^80i^KV0>;RhP3Kfm/0f][J0>KViP3IfMT0h^;R0>KViP3Kfm/0f][J0P3Bd]80103>c/h0
cLg=0<g=c@3>c/h20<g=c@030<_;b`35aLD0aLG50080`L7100h0^;Rh0:n_[`2_[jl0V9RH06YZJP0M
7Ad0Kfm_05iNGP1_Kfl0QXJ60::RXP2TY:@0Rh^;0:BTY080dM7A00T0^;Rh0::RXP2CTi<0Ti>C0::R
XP2_[jl0^;Rh0=;BdP3Fe]H00P2a/K401@2WYjL0jn_[0>_[j`3/k>`0jn_[0080moOg00<0mOGe0?Og
m`3gmoL00`3gmoL00`3emOD0moOg0?Gem@060?Ogmah0oooo00@0moOg0??cl`3gmoL0lo?c0`3gmoL2
0??cl`H0moOg00H0lo?c0>o_k`3alO40jNWY0=;BdP2?Shl207IfMP0H06IVIP1JFUX0CTi>05EEE@1B
DU80GEeM0=GEe@3@d=00eMGE0=3@d03EeMD0clo?0=GEe@3Hf=P0g]kN0=cLg03AdM40d=3@0=kNgP3?
cll0f=SH0=kNgP3AdM40d=3@0P37alL01032`/80`L710<71`@32`/820<71`@030;bl_02h^;P0^;Rh
0080/k>c00h0ZJVY0:6QX@2QXJ40RHV905eMG@0F5QH0I6AT05=CD`1TI6@0O7al09JFUP2CTi<0NWYj
09>CT`80a/K600T0ZJVY09JFUP22PX80PX:209JFUP2QXJ40ZJVY0<O7a`3=cLd00P2VYZH01@2IVIT0
jNWY0>WYj@3Zj^X0jNWY0080moOg00<0lo?c0?Ogm`3gmoL00`3gmoL00`3clo<0moOg0??cl`060?Og
ma/0oooo000I0?ooo`030?Gem@3gmoL0moOg0080moOg00D0mOGe0?Ogm`3gmoL0mOGe0?Ogm`020?Ge
m@80moOg00P0lo?c0?Gem@3emOD0k>c/0=;BdP3AdM40Shn?07YjNP80JVYZ00D0IfMW065QH@1QHF40
GUiN0<K6aP020=kNgP0;0>3Ph03Rh^80f][J0>;RhP3Jf]X0h^;R0>KViP3Rh^80i^KV0>;RhP3Vi^H0
0`3Jf]X30<k>cP070=7Ad@3>c/h0dM7A0=WIf@3>c/h0cLg=0<k>cP020<_;b`040<G5a@31`L40`L71
0;Fe]@80[jn_00h0V9RH07QhN00b<S80GUiN06YZJP2CTi<0QXJ60;6a/@1eMGD0YjNW0::RXP36a/H0
dM7A0=WIf@80Y:BT00d0YjNW09>CT`2HV9P0V9RH0=;BdP3Fe]H0^;Rh0<30`02[Zj/0k>c/0>;RhP3[
jn/0lo?c0080moOg00<0mOGe0?Ogm`3gmoL00`3emOD80?Ogm`030?Gem@3oool0oooo01`0oooo00<0
lo?c0?Ogm`3gmoL00P3gmoL01@3clo<0moOg0?Ogm`3clo<0moOg0080lo?c0P3gmoL0203alO40lo?c
0??cl`3Zj^X0c<c<0<K6aP21PH40KVi^0P1MGEd01@1HF5P0EEEE05EEE@1?Cdl0_Kfm0080eMGE00/0
dm?C0=SHf03@d=00f=SH0=3@d03Hf=P0g]kN0=SHf03Ng]h0f=SH0=kNgP030=3@d0<0`/;200L0a/K6
0<;2`P36a/H0clo?0<;2`P31`L40`/;20080_;bl00@0^;Rh0;>c/`2c/k<0WIfM0P2QXJ403P29RHT0
JFUY02XZ:P1CDe<0GEeM08^;R`1lO7`0YZJV06MWI`2IVIT0UYJF0;Vi^@36a/H0clo?0P2CTi<03@2I
VIT0PX:208V9R@29RHT0alO70<g=c@2YZJT0][Jf09nOW`3Zj^X0h>3P0>WYj@3alO400P3gmoL00`3c
lo<0moOg0?Ogm`030??cl`P0moOg00<0lo?c0?ooo`3oool06@3oool001T0oooo00<0mOGe0?Ogm`3e
mOD00P3emOD00`3gmoL0lo?c0?Ogm`020?Ogm`060?Gem@3gmoL0mOGe0?Ogm`3emOD0lo?c0P3emOD0
1`3Fe]H0/K6a07inOP22PX80IVIV06MWI`1BDU800`1QHF420=kNgP060=_Kf`3Rh^80h>3P0>3Ph03R
h^80g]kN1@3Rh^803@3Ng]h0fMWI0=WIf@3IfMT0c/k>0=7Ad@3EeMD0d];B0<k>cP3IfMT0c/k>0=WI
f@3>c/h00P3;bl/01@3=cLd0aLG50<71`@2m_Kd0^;Rh0080[jn_00L0YJFU08:2PP19BDT0:BTY069R
HP1[Jf/0NWYj0080OWin00<0V9RH08j>SP2_[jl00P3?cll02`2h^;P0Y:BT0::RXP2CTi<0XZ:R09>C
T`2o_kl0d];B0;fm_@2[Zj/0^KVi0080jn_[00L0g]kN0?Ogm`3emOD0moOg0?Gem@3gmoL0mOGe00<0
moOg00@0mOGe0?Ogm`3gmoL0moOg0P3emOD30?Ogmah0oooo00<0lo?c0?Ogm`3clo<00P3clo<00`3g
moL0lO7a0?Ogm`020?Ogm`060??cl`3gmoL0lo?c0?Ogm`3clo<0lO7a0P3clo<0103Bd]80YZJV06m_
K`1fMWH205QHF00404E5A@1EEED0EEEE05EEE@80eMGE00H0dM7A0=SHf03Cdm<0dm?C0=SHf03EeMD5
0=SHf00=0=GEe@3?cll0clo?0<o?c`32`/80a/K60<W9b@37alL0`/;20<o?c`32`/80clo?0<;2`P02
0;bl_0050<71`@2h^;P0/k>c0:b/[02YZJT00P2QXJ401`2DU9@0MWIf0451@@0Q8B40FUYJ05iNGP1^
KVh00P1_Kfl00`29RHT0Q8B40:6QX@020<G5a@0;0:VYZ@2CTi<0UYJF08:2PP2FUYH0PX:20;Fe]@37
alL0];Bd09nOW`2ZZZX00P3YjNT01`3Jf]X0moOg0??cl`3gmoL0lo?c0?Ogm`3clo<00`3gmoL0103c
lo<0moOg0?Ogm`3gmoL20??cl`<0moOg6`3oool001T0oooo303gmoL20?Gem@80moOg00L0k>c/0=;B
dP2f][H0Z:RX07inOP1jNWX0I6AT00<0HF5Q00<0DU9B09^KV`3GemL00P3Kfm/30>;RhP030>KViP3R
h^80g]kN0080h^;R0P3Jf]X02`3>c/h0`L710<_;b`36a/H0`L710<G5a@3;bl/0c/k>0=GEe@3Bd]80
fMWI0080f][J00@0dm?C0<k>cP3;bl/0aLG50P31`L407P2i^KT0^;Rh0:n_[`2QXJ40TY:B04U9B@1B
DU80CTi>06m_K`1[Jf/0QXJ609>CT`1ZJVX0OWin06][J`30`<00clo?0<30`02WYjL0Zj^[08j>SP2H
V9P0XZ:R0;Rh^03AdM40a/K60:^[Z`3Rh^80mOGe0>c/k0D0moOg00<0mOGe0?Ogm`3gmoL00`3gmoL2
0?Gem@80moOg00@0mOGe0?Ogm`3gmoL0moOg7P3oool<0?Ogm`80lo?c0P3gmoL01`3Zj^X0c<c<0:f]
[@2NWYh0Kfm_06i^KP1CDe<00`1EEED00`15ADD0Shn?0<k>cP020=7Ad@<0f=SH00<0g]kN0=SHf03E
eMD00P3Hf=P20=3@d00;0<;2`P2c/k<0_;bl0;Vi^@2c/k<0^;Rh0;bl_032`/80bLW90<O7a`3?cll0
0P3@d=001034a<@0`/;20;bl_02h^;P20;>c/`0N0:ZZZP2YZJT0XJ6Q08j>SP1nOWh0@D5104E5A@18
B4P0I6AT05iNGP1lO7`0PX:205eMG@1_Kfl0GUiN0;Jf]P35aLD0/[:b09VIV@2OWil0Q8B408V9R@2F
UYH0ZJVY0<K6aP2m_Kd0WinO0>3Ph03clo<0j^[Z1@3gmoL00`3clo<0moOg0?Ogm`030?Ogm`80lo?c
0P3gmoL0103clo<0moOg0?Ogm`3gmoLK0?ooo`006@3oool00`3emOD0moOg0?Ogm`020?Ogm`030?Ge
m@3gmoL0mOGe0080moOg00<0mOGe0?Ogm`3gmoL00P3gmoL20?Gem@030=7Ad@2XZ:P0Shn?0080K6a/
00H0HF5Q059BDP1BDU80HF5Q04i>CP3GemL20=_Kf`030>3Ph03Rh^80h^;R00<0h^;R00L0gMgM0>;R
hP3Rh^80f][J0=?Cd`3<c<`0_Kfm0080`L7100L0^KVi0;fm_@35aLD0cLg=0<k>cP3EeMD0dm?C0080
fMWI0180dm?C0=WIf@3Bd]80bl_;0<G5a@31`L40^KVi0;Rh^02VYZH0YJFU09RHV019BDT07AdM03Hf
=P1NGUh0JVYZ08:2PP2CTi<207inOP05065QH@2m_Kd0Y:BT0=gMg@2[Zj/00P2WYjL0102HV9P0X:2P
0:^[Z`3AdM420<W9b@030=GEe@3Ogml0g=cL00D0moOg00<0mOGe0?Ogm`3gmoL01`3gmoL0103emOD0
moOg0?Ogm`3gmoLN0?ooo`030??cl`3gmoL0moOg0080moOg00<0lo?c0?Ogm`3clo<00P3gmoL00`3c
lo<0moOg0?Ogm`020?Ogm`80lo?c00<0a/K609jNWP21PH400P1KFe/01P1EEED0ADE504E5A@1EEED0
?clo0<k>cP80dM7A00<0dm?C0=SHf03Hf=P00`3Hf=P01`3EeMD0f=SH0=SHf03@d=00a<C40;fm_@2/
[:`00P2c/k<01`2ZZZX0/;2`0;Rh^031`L40`/;20<W9b@34a<@00P3?cll04P34a<@0clo?0<?3``2l
_;`0^;Rh0;>c/`2ZZZX0ZJVY09FEU@2DU9@0RHV90451@@0F5QH0;bl_05=CD`1MGEd0MWIf08:2PP80
Kfm_00D0EEEE0;2`/02CTi<0eMGE09nOW`0209VIV@0408V9R@2FUYH0WinO0<K6aP80`l?300<0dM7A
0=_Kf`3EeMD01@3gmoL00`3clo<0moOg0?Ogm`070?Ogm`040??cl`3gmoL0moOg0?Ogma/0oooo000I
0?ooo`H0moOg00@0mOGe0?Ogm`3gmoL0mOGe1P3gmoL03@3/k>`0`<3009^KV`1jNWX0K6a/059BDP1Q
HF40FUYJ065QH@1>CTh0ATI60=_Kf`3Fe]H00P3Jf]X00`3Ph>00i^KV0>KViP040>;RhP050;fm_@2a
/K40f][J0=[JfP39bLT00P2=SHd01@2VYZH0_Kfm09RHV035aLD0c/k>0080fMWI0P3Jf]X04@3IfMT0
dm?C0<k>cP3;bl/0b/[:0<71`@2i^KT0^;Rh0:n_[`2UYJD0TY:B05YJFP0Y:BT0=SHf04I6AP1NGUh0
Jf][0080PX:20100JVYZ08:2PP1cLg<0XZ:R0;Rh^033`l<0Y:BT0::RXP1nOWh0V9RH0;Rh^03?cll0
bLW90>c/k02m_Kd0a/K64P3gmoL00`3emOD0moOg0?ooo`0M0?ooo`H0moOg00@0lo?c0?Ogm`3gmoL0
lo?c1P3gmoL03@3Zj^X0][Jf08n?S`1^KVh0Fe]K04E5A@1EEED0CTi>05EEE@0o?cl0>c/k0=7Ad@3=
cLd00P3@d=000`3Cdm<0g]kN0=kNgP030=SHf0030=cLg02/[:`0UiNG0080d=3@00P0]kNg07QhN01h
N7P0UIFE0:b/[029RHT0^;Rh0<;2`P80clo?0P3@d=004@3?cll0a<C40<;2`P2l_;`0^k^k0;>c/`2Z
ZZX0ZJVY0:6QX@2DU9@0OWin04i>CP0Q8B40;bl_03/k>`1CDe<0GUiN0080MWIf0100GEeM07IfMP1V
IVH0UYJF0:VYZ@2g]kL0Ti>C09JFUP1_Kfl0RHV90:VYZ@35aLD0`l?30>[ZjP2d];@0_Kfm4P3gmoL0
0`3clo<0moOg0?ooo`0J0?ooo`006@3oool40?Gem@@0moOg00<0mOGe0?Ogm`3emOD0103gmoL01@3e
mOD0i>CT0:^[Z`2?Shl0NWYj0080HF5Q00P0DU9B05iNGP1QHF40ATI606][J`3Kfm/0f][J0=kNgP80
h^;R00P0h>3P0>KViP3Ph>00h^;R0=gMg@3Vi^H0g]kN0=_Kf`80h>3P00P0cLg=0<G5a@36a/H0b/[:
0<g=c@31`L40^KVi0<k>cP@0f][J00L0dm?C0=WIf@3IfMT0d];B0<[:bP35aLD0^KVi0080[jn_01H0
YJFU0:6QX@1cLg<07AdM02TY:@0f=SH0CTi>069RHP1[Jf/0QXJ606YZJP1eMGD0?Shn0;no_`2^[Zh0
dM7A09RHV02RXZ80PX:208n?S`2[Zj/0_Kfm0P3Bd]80102i^KT0moOg0?Ogm`3emOD40?Ogm`030?Ge
m@3gmoL0moOg00L0moOg00@0mOGe0?Ogm`3gmoL0moOg7P3oool40??cl`@0moOg00<0lo?c0?Ogm`3c
lo<0103gmoL01@3clo<0hN7Q09nOW`21PH40KVi^0080EEEE00P0ADE504m?C`1EEED0>c/k05iNGP3A
dM40d=3@0=GEe@80f=SH00P0dm?C0=kNgP3Cdm<0f=SH0=GEe@3Ng]h0eMGE0=7Ad@80dm?C00P0`L71
0;Rh^02i^KT0^k^k0<71`@2c/k<0ZZZZ0<;2`P@0d=3@00L0a<C40<o?c`3?cll0`l?30;^k^`2h^;P0
ZZZZ0080XJ6Q01H0U9BD08j>SP1VIVH05QHF024Q8@0_;bl0B4Q805YJFP1NGUh0O7al05eMG@1WIfL0
<c<c0;Fe]@2PX:00a/K608V9R@2FUYH0MWIf0861P@2OWil0];Bd0P3<c<`0102c/k<0moOg0?Ogm`3c
lo<40?Ogm`030??cl`3gmoL0moOg00L0moOg00@0lo?c0?Ogm`3gmoL0moOg6`3oool001T0oooo1@3g
moL0103emOD0moOg0?Ogm`3emOD40?Ogm`0?0??cl`3gmoL0moOg0=oOg`2RXZ80NWYj07QhN01NGUh0
IfMW05YJFP1QHF40IfMW04I6AP2@T900e]KF00<0h>3P0`3Vi^H30>;RhP030>KViP3Kfm/0h^;R0080
h^;R00P0fMWI0<g=c@3<c<`0c<c<0<K6aP35aLD0`L710=?Cd`80f][J00<0h>3P0=[JfP3Jf]X00`3C
dm<00`3=cLd0b/[:0;fm_@020;Fe]@0F0:FUY@2HV9P0NWYj01dM7@0b<S80:BTY05iNGP1[Jf/0FUYJ
08:2PP1ZJVX0MGEe04I6AP2[Zj/0_kno0=7Ad@2HV9P0XZ:R08n?S`2HV9P0Z:RX0<30`080d];B00@0
bLW90?Ogm`3gmoL0mOGe1P3gmoL00`3emOD0moOg0?Ogm`090?Ogmah0oooo1@3gmoL0103clo<0moOg
0?Ogm`3clo<40?Ogm`0?0?7al@3gmoL0moOg0=_Kf`2FUYH0KVi^06UYJ@1CDe<0F5QH04i>CP1EEED0
F5QH03Lg=`25QHD0cLg=00<0dm?C0`3Ng]h01@3Lg=`0f=SH0=SHf03Ng]h0dM7A00<0g=cL00P0clo?
0<71`@2m_Kd0_Kfm0;Vi^@2h^;P0/k>c0<C4a080d=3@00<0dm?C0=3@d03@d=000`34a<@00`31`L40
^k^k0:b/[00209fMW@0F09BDU029RHT0KVi^01HF5P0Z:RX08B4Q05=CD`1NGUh0CTi>07IfMP1MGEd0
IfMW03/k>`2OWil0]KFe0<K6aP29RHT0UYJF0861P@29RHT0WYjN0;Jf]P80c<c<00@0`l?30?Ogm`3g
moL0lo?c1P3gmoL00`3clo<0moOg0?Ogm`090?Ogma/0oooo000I0?ooo`H0moOg103emOD20?Ogm`05
0?Gem@3gmoL0moOg0??cl`2[Zj/00P1jNWX01@1BDU80FUYJ065QH@1WIfL0HF5Q0080<S8b00H0f][J
0>3Ph03Ogml0h>3P0>KViP3Rh^850>KViP030>;RhP3Ph>00h^;R0080h^;R00P0f][J0<_;b`2n_[h0
`L710<G5a@2n_[h0c/k>0=[JfP80fm_K02H0g]kN0>;RhP3Jf]X0fMWI0=[JfP3IfMT0dm?C0<_;b`35
aLD0`L710;Rh^02VYZH0V9RH08V9R@1NGUh061PH02TY:@19BDT0JFUY07=cL`1jNWX0HF5Q06YZJP1N
GUh0QXJ60:n_[`35aLD0d];B09>CT`2HV9P0QXJ60:^[Z`3AdM40e]KF0;6a/@3EeMD0mOGe0?Ogm`<0
mOGe0P3gmoL00`3emOD0moOg0?Ogm`060?Ogm`030?Gem@3gmoL0moOg0080moOg7P3oool60?Ogm`@0
lo?c0P3gmoL01@3clo<0moOg0?Ogm`3alO40WinO0080KVi^00D0ADE504i>CP1EEED0F5QH05EEE@02
02XZ:P060=3@d03Cdm<0e]KF0=?Cd`3Ng]h0g=cL1@3Ng]h00`3Hf=P0dm?C0=cLg0020=cLg0080=3@
d02l_;`0/K6a0;>c/`2h^;P0/K6a0<;2`P3@d=020=7Ad@0V0=GEe@3Hf=P0d=3@0<o?c`3@d=00clo?
0<C4a02l_;`0^;Rh0;>c/`2YZJT0UIFE08V9R@1fMWH0De=C01@D500Q8B40@D51065QH@1VIVH0KVi^
05EEE@1MGEd0De=C07alO02QXJ40^;Rh0<O7a`22PX80RHV907alO02OWil0a/K60<g=c@2VYZH0dM7A
0??cl`3gmoL30??cl`80moOg00<0lo?c0?Ogm`3gmoL01P3gmoL00`3clo<0moOg0?Ogm`020?Ogma/0
oooo000I0?ooo`80mOGe0P3gmoL00`3emOD0moOg0?Ogm`030?Ogm`030?Gem@3gmoL0mOGe0080moOg
00D0lO7a09fMW@1jNWX0IVIV059BDP0206MWI`07065QH@0Y:BT0?Shn04U9B@3Jf]X0h^;R0>KViP07
0>;RhP0:0>KViP3Ph>00gmoO0>3Ph03Vi^H0h>3P0=?Cd`3>c/h0_[jn0<G5a@80a/K60`3Jf]X01`3K
fm/0h>3P0>;RhP3Ph>00f][J0=WIf@3Jf]X00P3Cdm<02`3:b/X0_Kfm0<71`@2_[jl0YJFU08:2PP1/
K6`07AdM03Ti>@0n?Sh0FUYJ0080JVYZ00l0OWin06YZJP1ZJVX0SXj>0:j^[P35aLD0gMgM09RHV02C
Ti<0PX:209^KV`2m_Kd0d];B0=GEe@3emOD0403gmoL20?Gem@<0moOg7P3oool20??cl`80moOg00<0
lo?c0?Ogm`3gmoL00`3gmoL00`3clo<0moOg0??cl`020?Ogm`050?3`l02@T900KVi^05QHF015ADD0
0P1HF5P01`1EEED08B4Q03<c<`11@D40d=3@0=SHf03Ng]h01`3Lg=`02P3Ng]h0dm?C0=KFeP3Cdm<0
g]kN0=?Cd`34a<@0`/;20;6a/@2h^;P20;Vi^@<0d=3@00L0dM7A0=?Cd`3Hf=P0dm?C0=3@d03?cll0
d=3@0080a<C400/0^k^k0;2`/02c/k<0XJ6Q09BDU01fMWH0Fe]K01HF5P0e=CD0<c<c04i>CP0205eM
G@0?06m_K`1MGEd0GEeM08B4Q02PX:00^;Rh0=GEe@29RHT0PX:207IfMP2?Shl0];Bd0<c<c03AdM40
lo?c0100moOg0P3clo<30?Ogma/0oooo000I0?ooo`<0moOg00<0mOGe0?Ogm`3gmoL00`3gmoL0103e
mOD0moOg0?Gem@3gmoL30?Gem@0:09fMW@1eMGD0HF5Q065QH@1NGUh0HF5Q06MWI`0n?Sh0<S8b0;fm
_@80g]kN00@0i^KV0>;RhP3Rh^80h^;R0`3Zj^X01@3Rh^80i^KV0>KViP3Rh^80fm_K0080i^KV00T0
dm?C0<K6aP36a/H0aLG50<g=c@3>c/h0f][J0=kNgP3Kfm/00P3Ph>000`3Vi^H0h>3P0=_Kf`020=[J
fP0M0=?Cd`3>c/h0a/K60<71`@2i^KT0^;Rh0:FUY@22PX80NWYj038b<P0H61P0ATI603hn?P1cLg<0
HF5Q07EeM@1nOWh0JVYZ08J6QP2h^;P0`l?30=gMg@2?Shl0YjNW07=cL`2?Shl0clo?0=[JfP3EeMD0
503gmoL00`3emOD0moOg0?ooo`0M0?ooo`<0moOg00<0lo?c0?Ogm`3gmoL00`3gmoL0103clo<0moOg
0??cl`3gmoL30??cl`0:092@T01WIfL0EEEE05EEE@1CDe<0EEEE05QHF00c<c<0:RXZ0;Bd]080eMGE
00@0g]kN0=cLg03Lg=`0g=cL0`3Ti>@01@3Lg=`0g]kN0=kNgP3Hf=P0dM7A0080g]kN00T0a<C40;Vi
^@2i^KT0^;Rh0<71`@32`/80d=3@0=GEe@3AdM400P3Cdm<00`3Ng]h0dm?C0=7Ad@020=3@d00M0<C4
a032`/80^KVi0;>c/`2ZZZX0ZJVY09BDU01fMWH0KVi^02XZ:P0D51@0>c/k03<c<`1VIVH0EEEE06MW
I`1_Kfl0GEeM07alO02YZJT0]kNg0=GEe@21PH40VIVI06IVIP21PH40aLG50=CDe03AdM40503gmoL0
0`3clo<0moOg0?ooo`0J0?ooo`006@3oool20?Gem@H0moOg0`3emOD20?Ogm`0@0?Gem@3gmoL0e=CD
08J6QP1cLg<0FUYJ06YZJP1WIfL0HF5Q03hn?P0b<S80:BTY0=oOg`3Ph>00i^KV0>[ZjPT0h^;R00L0
i^KV0>;RhP3Vi^H0i^KV0=[JfP3>c/h0a/K60080cLg=00P0c/k>0=_Kf`3Kfm/0h^;R0>KViP3Ph>00
h^;R0>KViP80gmoO01h0fm_K0=[JfP3Fe]H0cLg=0<G5a@2m_Kd0^KVi0;Rh^022PX80OWin05YJFP16
ATH0DU9B05iNGP1jNWX0JVYZ07inOP1cLg<0K6a/08J6QP2h^;P0_kno0=;BdP2RXZ80Ti>C06YZJP2H
V9P0aLG50=kNgP3^k^h70?Ogm`030?Gem@3gmoL0moOg0080mOGe00@0moOg0?Gem@3gmoL0mOGe1P3g
moLN0?ooo`80lo?c1P3gmoL30??cl`80moOg0100lo?c0?Ogm`3>c/h0O7al06IVIP1>CTh0GEeM05QH
F01EEED0<c<c02XZ:P0Q8B40e]KF0=?Cd`3Ng]h0i>CT2@3Lg=`01`3Ng]h0f=SH0=kNgP3Ng]h0d=3@
0<;2`P2i^KT00P31`L402032`/80dM7A0=7Ad@3Lg=`0g]kN0=?Cd`3Lg=`0g]kN0P3Fe]H07P3AdM40
d=3@0<g=c@31`L40^;Rh0;2`/02ZZZX0ZJVY07IfMP1_Kfl0CTi>03Lg=`15ADD0De=C06i^KP1MGEd0
Kfm_06IVIP1KFe/0O7al0:VYZ@2e]KD0alO709JFUP22PX80GEeM08V9R@2h^;P0f][J0>o_k`L0moOg
00<0lo?c0?Ogm`3gmoL00P3clo<0103gmoL0lo?c0?Ogm`3clo<60?Ogma/0oooo000I0?ooo`030?Ge
m@3gmoL0moOg00L0moOg00<0mOGe0?Ogm`3gmoL00P3gmoL03@26QXH0MGEe06YZJP16ATH0JFUY05iN
GP1WIfL0?Shn059BDP19BDT0fm_K0>;RhP3Vi^H00P3Rh^801@3Zj^X0h^;R0>;RhP3Vi^H0j^[Z00<0
h^;R0140i^KV0=oOg`3Vi^H0i^KV0>3Ph03>c/h0a/K60<k>cP3AdM40d];B0=KFeP3Ng]h0i^KV0=oO
g`3Vi^H0h^;R0>3Ph0030=oOg`0:0=_Kf`3Jf]X0c/k>0<K6aP35aLD0^KVi0;Rh^02BTY80N7Qh05iN
GP<0DU9B00H0JVYZ07inOP1jNWX0Lg=c08:2PP2MWId20;Rh^0070;no_`2WYjL0RXZ:06IVIP2XZ:P0
`<300>;RhP0?0?Ogm`050?Gem@3gmoL0moOg0?Ogm`3emOD00`3gmoLN0?ooo`030??cl`3gmoL0moOg
00L0moOg00<0lo?c0?Ogm`3gmoL00P3gmoL03@1lO7`0IfMW05eMG@0k>c/0HF5Q05=CD`1HF5P0<c<c
04E5A@11@D40dM7A0=cLg03Ng]h00P3Lg=`01@3Ti>@0g=cL0=cLg03Ng]h0i>CT00<0g=cL0140g]kN
0=KFeP3Ng]h0g]kN0=?Cd`32`/80^KVi0<;2`P36a/H0alO70<g=c@3EeMD0g]kN0=KFeP3Ng]h0g=cL
0=?Cd`030=KFeP0:0=7Ad@3@d=00`/;20;Vi^@2h^;P0ZZZZ0:VYZ@1nOWh0JFUY05=CD`<0ADE500H0
GEeM06m_K`1^KVh0IVIV07YjNP2@T9020:VYZ@070;Fe]@2IVIT0NGUi05QHF02NWYh0][Jf0>3Ph00?
0?Ogm`050??cl`3gmoL0moOg0?Ogm`3clo<00`3gmoLK0?ooo`006@3oool00`3emOD0moOg0?Ogm`07
0?Ogm`030?Gem@3gmoL0moOg0080moOg00/0Shn?07inOP1NGUh0DU9B07=cL`1QHF40FUYJ059BDP0n
?Sh0UIFE0=oOg`030>;RhP80j^[Z00H0i^KV0>;RhP3Vi^H0i^KV0>;RhP3Zj^X20>;RhP80i^KV00<0
h^;R0>3Ph03>c/h00P36a/H00`3AdM40d];B0=[JfP030=oOg`80h^;R00h0h>3P0>KViP3Rh^80g]kN
0=_Kf`3Jf]X0d];B0<K6aP35aLD0_Kfm0;Rh^02BTY80N7Qh06a/K080ATI600H0DU9B06MWI`1jNWX0
OWin07YjNP1eMGD30;Rh^0070;fm_@2o_kl0Rh^;08^;R`2KVi/0`l?30>k^kP0;0?Ogm`030?Gem@3g
moL0mOGe00T0moOg7P3oool00`3clo<0moOg0?Ogm`070?Ogm`030??cl`3gmoL0moOg0080moOg00/0
PH6106m_K`1CDe<0ADE506IVIP1EEED0CTi>04E5A@0c<c<0S8b<0=KFeP030=cLg080i>CT00H0g]kN
0=cLg03Ng]h0g]kN0=cLg03Ti>@20=cLg080g]kN00<0g=cL0=?Cd`32`/800P2i^KT00`36a/H0alO7
0=3@d0030=KFeP80g=cL00h0dm?C0=kNgP3Hf=P0eMGE0=7Ad@3@d=00alO70;Vi^@2h^;P0/;2`0:VY
Z@1nOWh0JFUY05]KF`80>c/k00H0ADE505QHF01^KVh0Kfm_06i^KP1WIfL30:VYZ@070;2`/02e]KD0
NWYj07YjNP2?Shl0]kNg0>o_k`0;0?Ogm`030??cl`3gmoL0lo?c00T0moOg6`3oool001T0oooo00P0
mOGe0?Ogm`3gmoL0mOGe0?Ogm`3emOD0moOg0?Gem@D0moOg00/0mOGe0;Jf]P1eMGD0MgMg06YZJP1c
Lg<0JVYZ059BDP19BDT0FUYJ0=KFeP020>KViP@0h^;R00@0j^[Z0>;RhP3Vi^H0gmoO0P3Kfm/0103O
gml0i^KV0>KViP3Ph>020>;RhP050>KViP3Jf]X0bl_;0<G5a@36a/H00P37alL0103GemL0f][J0=_K
f`3Rh^820=oOg`030=_Kf`3GemL0fm_K0080f][J0P3Bd]802`37alL0aLG50;fm_@2UYJD0PX:207Ee
M@1NGUh0?Shn059BDP1NGUh0PX:200<0Lg=c00T0/K6a0;Rh^02h^;P0PX:20<o?c`1SHf<0PX:20:^[
Z`2m_Kd03P3gmoL00`3emOD0moOg0?Ogm`070?Ogmah0oooo00P0lo?c0?Ogm`3gmoL0lo?c0?Ogm`3c
lo<0moOg0??cl`D0moOg00/0lo?c0;:b/P1WIfL0K6a/05eMG@1VIVH0GEeM04E5A@11@D40CTi>0<g=
c@020=kNgP@0g=cL00@0i>CT0=cLg03Ng]h0e]KF0P3AdM402`3Fe]H0g]kN0=kNgP3Cdm<0f=SH0=cL
g03Ng]h0d=3@0;bl_02h^;P0^KVi0080^[Zj00@0c/k>0=CDe03AdM40g=cL0P3Fe]H00`3AdM40c/k>
0=7Ad@020=3@d080alO700/0^[Zj0;Rh^02`/;00U9BD07IfMP1WIfL0De=C03<c<`15ADD0De=C07If
MP0306IVIP090:JVYP2YZJT0ZJVY07IfMP35aLD0DU9B07IfMP2OWil0];Bd00h0moOg00<0lo?c0?Og
m`3gmoL01`3gmoLK0?ooo`006@3oool20?Ogm`040?Gem@3gmoL0moOg0?Gem@L0moOg00`0mOGe096A
T@2PX:00PX:205iNGP22PX80GUiN04I6AP1NGUh0HF5Q0=KFeP3Ph>020>;RhP040>[ZjP3Rh^80h^;R
0>KViP80gmoO00P0dm?C0=KFeP3Jf]X0f][J0=oOg`3Vi^H0g]kN0>;RhP80i^KV00T0f][J0<W9b@35
aLD0_[jn0<K6aP3Bd]80emOG0=_Kf`3Ogml01P3Fe]H0403Jf]X0fm_K0=KFeP36a/H0dM7A0<G5a@2m
_Kd0YJFU08n?S`1eMGD0IfMW03hn?P0j>SX0GUiN07=cL`1nOWh207=cL`090;6a/@2_[jl0^;Rh06MW
I`33`l<0N7Qh07=cL`2m_Kd0e]KF00h0moOg00<0mOGe0?Ogm`3gmoL01`3gmoLN0?ooo`80moOg00@0
lo?c0?Ogm`3gmoL0lo?c1`3gmoL0303clo<0QXJ609JFUP1fMWH0De=C07IfMP1CDe<0>c/k05=CD`1E
EED0cLg=0=?Cd`80g=cL00@0i>CT0=cLg03Lg=`0g]kN0P3Fe]H02034a<@0cLg=0=3@d03@d=00e]KF
0=kNgP3EeMD0f=SH0P3Ng]h02@3@d=00]kNg0;Rh^02a/K40^KVi0<O7a`3>c/h0dM7A0=KFeP060<g=
c@0@0=3@d03AdM40cLg=0;fm_@36a/H0^;Rh0;2`/02DU9@0PH6106MWI`1HF5P0<c<c02h^;P1CDe<0
IVIV06m_K`80IVIV00T0YZJV0:6QX@2YZJT0F5QH0;Ng]`1YJFT0IVIV0;2`/03=cLd03P3gmoL00`3c
lo<0moOg0?Ogm`070?Ogma/0oooo000I0?ooo`80moOg00D0mOGe0?Ogm`3gmoL0moOg0?Gem@020?Og
m`@0mOGe00d0moOg06][J`2SXj<0Lg=c07moO`1_Kfl0Lg=c03hn?P1nOWh0b/[:0=[JfP3;bl/0i^KV
00@0h^;R01D0gmoO0=_Kf`3Kfm/0f][J0<O7a`36a/H0d];B0=_Kf`3Ogml0e]KF0=_Kf`3Rh^80i^KV
0=?Cd`36a/H0_Kfm0<30`02n_[h0a/K60=KFeP3GemL00P3Bd]801036a/H0aLG50<G5a@2n_[h20<O7
a`80d];B0P3AdM402@36a/H0_Kfm0:JVYP2BTY80PX:206][J`1JFUX0:BTY059BDP0207=cL`0;08:2
PP1[Jf/0Z:RX09RHV02RXZ80IVIV0<o?c`22PX80K6a/0;no_`3Ng]h01`3gmoL00`3emOD0moOg0?Og
m`070?Ogm`030?Gem@3gmoL0moOg00@0moOg7P3oool20?Ogm`050??cl`3gmoL0moOg0?Ogm`3clo<0
0P3gmoL40??cl`0=0?Ogm`1JFUX0Vi^K06IVIP1eMGD0I6AT06IVIP0c<c<0Kfm_0;^k^`3@d=00_;bl
0=kNgP040=cLg00E0=KFeP3AdM40dM7A0=3@d02j^[X0^KVi0<O7a`3AdM40e]KF0<g=c@3AdM40g=cL
0=kNgP34a<@0^KVi0:b/[02f][H0/K6a0;fm_@3=cLd0c/k>0080alO700@0_Kfm0;Rh^02h^;P0/K6a
0P2j^[X20<O7a`80a/K600T0^KVi0;2`/02EUID0OWin07IfMP1NGUh0CTi>024Q8@15ADD00P1VIVH0
2`1fMWH0GUiN09jNWP29RHT0UYJF05QHF035aLD0MWIf05]KF`2e]KD0f][J00L0moOg00<0lo?c0?Og
m`3gmoL01`3gmoL00`3clo<0moOg0?Ogm`040?Ogma/0oooo000I0?ooo`T0moOg00<0mOGe0?Ogm`3g
moL00P3gmoL03022PX80T92@06][J`1cLg<0Jf][07QhN01ZJVX0IfMW0>3Ph02_[jl0`L710>KViP<0
h^;R00P0gmoO0=OGe`2XZ:P0X:2P0;jn_P2j^[X0Z:RX0<O7a`80gmoO0P3Kfm/20>KViP0<0=[JfP36
a/H0^KVi0;6a/@2i^KT0alO70=OGe`3<c<`0alO70;Ng]`2][Jd0X:2P0`2a/K400`2j^[X0dM7A0<O7
a`020<O7a`0>0<G5a@2m_Kd0YZJV09RHV01hN7P0Jf][05iNGP1BDU80ATI606][J`1ZJVX0MgMg07=c
L`2MWId209RHV00707EeM@3?cll0MGEe06a/K02h^;P0gmoO0?ooo`0G0?Ogmah0oooo2@3gmoL00`3c
lo<0moOg0?Ogm`020?Ogm`0<07IfMP25QHD0GUiN06IVIP1NGUh0JFUY05eMG@1HF5P0dm?C0:6QX@2c
/k<0g]kN0`3Lg=`0203Fe]H0c/k>09jNWP2FUYH0/K6a0;2`/02NWYh0^[Zj0P3Fe]H20=7Ad@80g]kN
00`0d=3@0;Vi^@2ZZZX0YZJV0:ZZZP2j^[X0c/k>0;fm_@2j^[X0[Zj^0:BTY02FUYH30:JVYP030;2`
/036a/H0^[Zj0080^[Zj00h0^;Rh0;2`/02EUID0RHV906UYJ@1NGUh0De=C04E5A@0k>c/0GUiN05eM
G@1/K6`0IVIV092@T080RHV900L0IfMW0<G5a@1WIfL0Fe]K0:VYZ@3Kfm/0oooo01L0moOg6`3oool0
01T0oooo00L0mOGe0?Ogm`3gmoL0moOg0?Gem@3gmoL0mOGe00L0moOg00T0SXj>08J6QP1NGUh0Jf][
05iNGP1hN7P0MGEe0=;BdP3Cdm<00P2n_[h03@3Ogml0h^;R0>;RhP3Kfm/0c<c<09^KV`37alL0][Jf
06i^KP1bLW80UIFE0;6a/@2e]KD00P3Kfm/05@3Fe]H0i^KV0>KViP3IfMT0c/k>0;Vi^@2m_Kd0Z:RX
07EeM@2FUYH0YZJV0;jn_P3De=@0R8R8096AT@2@T900SXj>092@T02MWId0_[jn0<K6aP020<O7a`80
_[jn00L0YZJV09:BTP22PX80Lg=c05iNGP1[Jf/0?Shn0080Jf][00/0Lg=c08:2PP2KVi/0Ti>C09RH
V01bLW80dM7A07inOP26QXH0_kno0>c/k00=0?Ogm`030?Gem@3gmoL0moOg00P0moOg7P3oool01`3c
lo<0moOg0?Ogm`3gmoL0lo?c0?Ogm`3clo<01`3gmoL03024Q8@0O7al05=CD`1NGUh0De=C06UYJ@1W
IfL0`l?30<C4a02VYZH0/K6a0=KFeP80g=cL00X0dM7A0;fm_@2?Shl0^[Zj0;:b/P1/K6`0LW9b08b<
S02VYZH0WIfM0P3AdM405@3=cLd0g]kN0=kNgP3?cll0`/;20:ZZZP2`/;00WYjN061PH01iNGT0UIFE
0;6a/@3>c/h0PX:208J6QP25QHD0Q8B408F5Q@2@T900/K6a0;Vi^@020;Zj^P80/K6a00L0UIFE07in
OP1fMWH0IVIV05=CD`1NGUh0<c<c0080GUiN00/0IVIV07IfMP2?Shl0PX:208V9R@1QHF40a/K606m_
K`1lO7`0]KFe0>[ZjP0=0?Ogm`030??cl`3gmoL0moOg00P0moOg6`3oool001T0oooo1`3gmoL00`3e
mOD0moOg0?Ogm`030?Ogm`050?ooo`2CTi<0JVYZ065QH@16ATH00P1[Jf/06`1hN7P0h>3P0<71`@2n
_[h0a/K60=kNgP3Jf]X0alO70:RXZ022PX80BDU90;no_`27QhL0][Jf01dM7@1lO7`0DU9B09fMW@2X
Z:P0c/k>0=gMg@3Vi^H0h^;R0=[JfP3AdM40cLg=0:RXZ0020:2PX00E0:RXZ022PX80b/[:05iNGP2k
^k/0LW9b05iNGP2^[Zh0>CTi069RHP2@T900Z:RX0;fm_@2n_[h0_Kfm0:RXZ02UYJD0Shn?07QhN01[
Jf/0IfMW0080<S8b00`0?Shn06][J`1NGUh0Shn?08J6QP2>SXh0V9RH08V9R@2o_kl0IVIV0::RXP3B
d]8I0?Ogmah0oooo1`3gmoL00`3clo<0moOg0?Ogm`030?Ogm`050?ooo`2;Rh/0GEeM05EEE@0k>c/0
0P1NGUh06`1YJFT0dm?C0;>c/`2VYZH0^KVi0=GEe@3@d=00^[Zj09jNWP1jNWX0@D510;Zj^P21PH40
][Jf01XJ6P1gMgL0CTi>092@T02NWYh0`/;20=GEe@3Ng]h0f=SH0=3@d036a/H0`L7109jNWP0209JF
UP0E09jNWP1fMWH0b<S805aLG02m_Kd0LW9b05aLG02UYJD0=CDe05YJFP25QHD0WYjN0;2`/02a/K40
/;2`09jNWP2DU9@0PH6106UYJ@1NGUh0F5QH0080:RXZ00`0<c<c05iNGP1CDe<0PH6107alO024Q8@0
RHV907IfMP2e]KD0F5QH09JFUP3<c<`I0?Ogma/0oooo000I0?ooo`d0moOg00D0Xj>S09NGU`22PX80
IfMW05iNGP0206][J`0D0:FUY@3Cdm<0_[jn0;Vi^@35aLD0g]kN0<k>cP2j^[X0YZJV05iNGP1cLg<0
CTi>03Hf=P19BDT0Jf][07YjNP1cLg<0Z:RX0<_;b`3EeMD30>;RhP070=[JfP3EeMD0c/k>0<71`@2X
Z:P0Shn?08:2PP0209VIV@0:04U9B@0n?Sh0BDU905iNGP1>CTh0IVIV06MWI`2@T900WIfM0:n_[`80
^KVi00<0Z:RX09RHV01hN7P00P1cLg<00`1NGUh0DU9B04U9B@02059BDP0:05iNGP22PX80Shn?07in
OP2HV9P0Shn?0;no_`1jNWX0XZ:R0>_[ja80moOg00<0mOGe0?Ogm`3gmoL0103gmoLN0?ooo`d0moOg
00D0Vi^K096AT@1jNWX0G5aL05=CD`0205iNGP0D08f=S@34a<@0YZJV0:ZZZP2h^;P0eMGE0<;2`P2`
/;00UIFE05=CD`1[Jf/0B4Q802l_;`11@D40GUiN079bLP1[Jf/0WYjN0;bl_039bLT30=SHf0070=3@
d039bLT0`/;20;>c/`2NWYh0PH6107YjNP0209>CT`0:0451@@0c<c<0@D5105=CD`18B4P0H61P05aL
G025QHD0T92@0:6QX@80ZZZZ00<0WYjN08V9R@1YJFT00P1VIVH00`1CDe<0ADE50451@@0204E5A@0:
05=CD`1fMWH0PH6106m_K`29RHT0PH610;Fe]@1^KVh0UYJF0>WYjA80moOg00<0lo?c0?Ogm`3gmoL0
103gmoLK0?ooo`006@3oool30?Ogm`050?Gem@3gmoL0moOg0?Ogm`3emOD01@3gmoL02@2?Shl0Z:RX
07=cL`1NGUh0MgMg06][J`1NGUh0YJFU0<W9b@020;Vi^@070<G5a@3GemL0e]KF0=;BdP36a/H0Z:RX
09:BTP0306MWI`0406][J`22PX80YZJV0<k>cP80f][J00<0h^;R0>KViP3Rh^800P3Jf]X0403IfMT0
cLg=0<71`@2XZ:P0WIfM079bLP2@T900UIFE08b<S01GEeL0CTi>05iNGP26QXH0XZ:R0:2PX02_[jl2
0;Vi^@050:RXZ02_[jl0TY:B07QhN01cLg<00P1[Jf/03P1JFUX0BDU904I6AP16ATH0FUYJ08J6QP2H
V9P0OWin09RHV02RXZ80_kno08:2PP2RXZ80k^k^6@3gmoLN0?ooo`<0moOg00D0lo?c0?Ogm`3gmoL0
moOg0??cl`050?Ogm`090861P@2RXZ80IVIV05=CD`1/K6`0GUiN05=CD`2DU9@0]kNg0080ZZZZ00L0
^;Rh0<k>cP3=cLd0alO70;Vi^@2NWYh0OWin00<0G5aL00@0GUiN07YjNP2EUID0`/;20P3@d=000`3H
f=P0g]kN0=SHf0020=3@d00=0<o?c`31`L40/k>c09jNWP2@T900JVYZ08F5Q@2<S8`0Ph>3051@D018
B4P0De=C07alO00209JFUP080:6QX@2ZZZX0ZZZZ09jNWP2QXJ40OWin06UYJ@1VIVH205iNGP0>04i>
CP11@D40>c/k03/k>`1>CTh0O7al08V9R@1_Kfl0RHV909JFUP2e]KD0MWIf09JFUP3_knlI0?Ogma/0
oooo000I0?ooo`X0moOg00L0mOGe0?Ogm`3gmoL0jn_[07moO`1NGUh0FUYJ0080GUiN00H0DU9B0:FU
Y@2_[jl0/K6a0:RXZ02n_[h20=kNgP0=0>KViP3Ogml0f][J0=_Kf`3>c/h0c<c<0<k>cP3Bd]80c/k>
0;Vi^@3;bl/0fMWI0>KViP020>;RhP0:0>KViP3Rh^80gMgM0=[JfP3=cLd0^;Rh0:RXZ02m_Kd0_[jn
0;fm_@80Z:RX00l0[jn_0;Vi^@2m_Kd0_Kfm0<G5a@3:b/X0_[jn0;fm_@2i^KT0[jn_0:JVYP2HV9P0
N7Qh07MgM`1[Jf/00P1BDU803@19BDT0GUiN05YJFP1BDU80PX:20::RXP1nOWh0Y:BT0:RXZ036a/H0
QXJ60:RXZ03oool05`3gmoL00`3emOD0moOg0?ooo`0M0?ooo`X0moOg00L0lo?c0?Ogm`3gmoL0jNWY
07EeM@1CDe<0CTi>0080De=C00H0ADE509BDU02QXJ40YZJV09jNWP2a/K420=GEe@0I0=kNgP3Fe]H0
d=3@0=7Ad@32`/80_Kfm0<;2`P37alL0`/;20:ZZZP2l_;`0clo?0=kNgP3Hf=P0g=cL0=kNgP3Hf=P0
eMGE0=3@d031`L40ZJVY09jNWP2`/;00/K6a0;2`/00209jNWP0?0:6QX@2ZZZX0/;2`0;2`/02h^;P0
^k^k0;6a/@2`/;00ZZZZ0:6QX@2EUID0RHV906UYJ@1/K6`0GUiN0080ADE500d0@D5105=CD`1>CTh0
ADE507IfMP2FUYH0Kfm_09>CT`2NWYh0^KVi07alO02NWYh0oooo01L0moOg00<0lo?c0?Ogm`3oool0
6P3oool001T0oooo103gmoL00`3emOD0moOg0?Ogm`020?Ogm`030?Gem@3gmoL0moOg0080oooo00d0
Lg=c04I6AP1BDU80DU9B07YjNP16ATH0TY:B0;Fe]@2_[jl0X:2P0;fm_@3Bd]80h^;R0080i^KV00T0
h^;R0>KViP3Rh^80bLW90:JVYP2@T900QXJ609:BTP3IfMT00`3Vi^H0303Zj^X0i^KV0>;RhP3Rh^80
i^KV0=GEe@3;bl/0RHV908J6QP2BTY80X:2P0=;BdP80e]KF0P3Bd]830<k>cP0G0;fm_@2[Zj/0Vi^K
0:n_[`2RXZ80Shn?08:2PP1cLg<0JVYZ06][J`16ATH0?Shn04U9B@0j>SX0GUiN07=cL`2?Shl0NWYj
0:NWY`2[Zj/0dM7A08j>SP2a/K406P3gmoLN0?ooo`@0moOg00<0lo?c0?Ogm`3gmoL00P3gmoL00`3c
lo<0moOg0?Ogm`020?ooo`0=06IVIP0k>c/0ADE504E5A@1^KVh0>c/k07inOP2MWId0XJ6Q09JFUP2`
/;00alO70=SHf0020=kNgP090=cLg03Ng]h0g=cL0;Ng]`2EUID0QHF507alO01nOWh0clo?00<0g]kN
00`0i>CT0=kNgP3Lg=`0f=SH0=kNgP39bLT0_;bl07IfMP1lO7`0OWin09JFUP37alL20<g=c@80alO7
0`32`/805`2`/;00WinO08n?S`2QXJ40UYJF0861P@1fMWH0IVIV05eMG@1NGUh0=cLg03<c<`11@D40
;Rh^05=CD`1VIVH0PH6106i^KP2IVIT0WinO0<K6aP24Q8@0YZJV01X0moOg6`3oool001T0oooo303g
moL04@3/k>`0oooo065QH@16ATH0DU9B05iNGP1[Jf/0GUiN08f=S@2HV9P0XZ:R0:JVYP2a/K40d];B
0=7Ad@3Kfm/0i^KV0080h^;R00/0WIfM092@T022PX80TY:B0;fm_@3IfMT0h^;R0>KViP3Zj^X0i^KV
0>[ZjP030>KViP80h^;R00P0fMWI0::RXP1hN7P0Jf][07QhN02BTY80`L710=KFeP80f][J00P0dm?C
0=;BdP36a/H0Z:RX08j>SP2_[jl0X:2P09fMW@80PX:200<0Lg=c059BDP1BDU800P0n?Sh01P0j>SX0
HV9R06m_K`1oOgl0SXj>07EeM@80XZ:R00<0`<300:RXZ02a/K406P3gmoLN0?ooo``0moOg0140j^[Z
0?ooo`1EEED0>c/k04E5A@1CDe<0GUiN05=CD`1hN7P0RHV909JFUP2EUID0YZJV0<c<c036a/H0dM7A
0=kNgP020=cLg00;092@T025QHD0NWYj07inOP2`/;00clo?0=SHf03Ng]h0i>CT0=kNgP3Ti>@00`3N
g]h20=SHf0080<o?c`2FUYH0JFUY05iNGP1YJFT0OWin0;>c/`3=cLd20=3@d0080<C4a037alL0^KVi
09jNWP24Q8@0XJ6Q09JFUP2@T90207IfMP0306IVIP15ADD0ADE50080<c<c00H0;Rh^05YJFP1TI6@0
MGEe08B4Q01WIfL209JFUP030;Jf]P2NWYh0YZJV01X0moOg6`3oool001T0oooo2@3gmoL0203emOD0
moOg0?Ogm`2f][H0QXJ605iNGP1bLW80Jf][0`1NGUh01@1eMGD0MgMg08J6QP2>SXh0_Kfm0080g]kN
00D0f][J0;fm_@2][Jd0]KFe0>;RhP080>[ZjP030>c/k03Rh^80j^[Z0080j^[Z0P3Vi^H20>;RhP08
0>3Ph03Jf]X0f][J0=[JfP3Fe]H0/K6a092@T02?Shl2092@T080Z:RX00X0[jn_0;Rh^02_[jl0XZ:R
08J6QP2?Shl0Jf][059BDP1NGUh0DU9B0P0Y:BT02P0b<S80MgMg08:2PP1cLg<0RHV90:^[Z`2a/K40
PX:20::RXP3/k>`@0?Ogm`030?Gem@3gmoL0moOg00L0moOg7P3oool90?Ogm`080??cl`3gmoL0moOg
0:f][@1lO7`0De=C06YZJP1NGUh305=CD`0506MWI`1/K6`0O7al08B4Q02`/;000P3EeMD01@3@d=00
/;2`0:BTY02MWId0g=cL00P0i>CT00<0iNGU0=cLg03Ti>@00P3Ti>@20=kNgP030=cLg03Hf=P0dm?C
00<0d=3@00@0cLg=0:JVYP25QHD0PH610P25QHD209jNWP0:0:6QX@2YZJT0XJ6Q09JFUP1lO7`0PH61
05iNGP15ADD0De=C04E5A@808B4Q00X0:RXZ06a/K01jNWX0IVIV07IfMP2OWil0YZJV07IfMP2FUYH0
j^[Z403gmoL00`3clo<0moOg0?Ogm`070?Ogma/0oooo000I0?ooo`<0moOg00D0mOGe0?Ogm`3gmoL0
moOg0?Gem@040?Ogm`0:0<o?c`22PX80GUiN08b<S01jNWX0JFUY06][J`1NGUh0Lg=c07MgM`80Shn?
00@0^KVi0=_Kf`3Ng]h0g]kN0P3Vi^H20>;RhPH0j^[Z00@0k>c/0>[ZjP3Zj^X0h^;R0P3Zj^X40>;R
hP040>KViP3Ng]h0g]kN0>;RhP80f][J0140d];B0=KFeP3Fe]H0c/k>0<K6aP35aLD0^KVi0;fm_@2X
Z:P0X:2P09RHV02>SXh0Shn?08:2PP1NGUh0DU9B03Xj>P0202TY:@09038b<P2PX:00MgMg07=cL`22
PX80V9RH0;no_`22PX80/K6a01/0moOg7P3oool30?Ogm`050??cl`3gmoL0moOg0?Ogm`3clo<0103g
moL02P3;bl/0MWIf05=CD`23Ph<0LW9b065QH@1NGUh0De=C06IVIP1/K6`20861P@040:ZZZP3AdM40
eMGE0=GEe@80g]kN0P3Lg=`60>CTi0040>GUi@3Ti>@0i>CT0=cLg080i>CT103Lg=`0103Ng]h0eMGE
0=GEe@3Hf=P20=3@d00A0<O7a`3=cLd0cLg=0<;2`P2i^KT0^;Rh0:ZZZP2`/;00WYjN09JFUP29RHT0
Q8B40861P@1fMWH0De=C04E5A@0^;Rh00P0Q8B402@0Z:RX0UYJF06a/K01VIVH0MWIf08V9R@2e]KD0
MWIf0:JVYP0K0?Ogma/0oooo000I0?ooo`H0moOg00<0mOGe0?Ogm`3gmoL00`3gmoL03@31`L40IVIV
06m_K`2GUiL0Ogmo06][J`1_Kfl0JFUY06m_K`1cLg<0SXj>08J6QP2i^KT00P3Ng]h01`3Ogml0i^KV
0>KViP3Rh^80j^[Z0>;RhP3Vi^H01`3Zj^X01P3Vi^H0j^[Z0>;RhP3Rh^80j^[Z0>;RhP<0i^KV00H0
h>3P0>;RhP3Kfm/0f][J0=;BdP3Jf]X20<k>cP070<K6aP2m_Kd0^KVi0;Vi^@2XZ:P0Zj^[0::RXP02
08n?S`0@07=cL`22PX80FUYJ03hn?P0b<S80ATI603Xj>P2XZ:P0SXj>07=cL`2?Shl0PX:20<30`022
PX80bLW90?oooaX0moOg7P3oool60?Ogm`030??cl`3gmoL0moOg00<0moOg00d0^k^k05QHF01TI6@0
TI6A07EeM@1NGUh0I6AT065QH@1TI6@0IVIV08B4Q01lO7`0ZZZZ0080eMGE00L0e]KF0=kNgP3Ng]h0
g=cL0>CTi03Lg=`0g]kN00L0i>CT00H0g]kN0>CTi03Lg=`0g=cL0>CTi03Lg=`30=kNgP060=?Cd`3H
f=P0dM7A0=3@d037alL0d=3@0P32`/801`2i^KT0/;2`0:ZZZP2ZZZX0WYjN09nOW`2FUYH00P21PH40
401VIVH0MWIf04i>CP0c<c<0:RXZ03/k>`0^;Rh0WYjN08B4Q01VIVH0PH6107IfMP2f][H0MWIf0<?3
``3ooolJ0?Ogma/0oooo000I0?ooo``0moOg00P0e]KF06][J`1gMgL0QXJ607MgM`1jNWX0MgMg06m_
K`80JVYZ00@0PX:208J6QP2VYZH0fm_K0P3Ng]h00`3Ogml0i^KV0>KViP020>[ZjP030>KViP3Zj^X0
j^[Z00T0j^[Z1`3Rh^80303Jf]X0fMWI0=[JfP3Bd]80dM7A0<g=c@36a/H0aLG50;fm_@2i^KT0^;Rh
0:n_[`80V9RH00D0QXJ608:2PP1NGUh0ATI6059BDP0202TY:@09038b<P2[Zj/0T92@08:2PP2CTi<0
MgMg0:RXZ022PX80mOGe01/0moOg7P3oool<0?Ogm`080=;BdP1NGUh0K6a/07alO01/K6`0LW9b06a/
K01TI6@205eMG@0407IfMP1lO7`0UIFE0=7Ad@80eMGE00<0e]KF0=kNgP3Ng]h00P3Ti>@00`3Ng]h0
i>CT0>CTi0090>CTi0<0g=cL103Hf=P0303@d=00clo?0=3@d037alL0a/K60<71`@2i^KT0^;Rh0;2`
/02ZZZX0ZJVY0:6QX@80RHV900D0O7al07IfMP1CDe<0>c/k04E5A@02024Q8@0902XZ:P2OWil0QHF5
07IfMP22PX80K6a/09jNWP1fMWH0lo?c01/0moOg6`3oool001T0oooo103gmoL00`3emOD0moOg0?Og
m`050?Ogm`070?Gem@1gMgL0Jf][06][J`1bLW80MgMg06][J`0206m_K`0806][J`2>SXh0V9RH0:^[
Z`3Bd]80gMgM0=oOg`3Rh^820>KViP030>;RhP3Zj^X0j^[Z00<0j^[Z00<0i^KV0>[ZjP3Zj^X00P3Z
j^X50>;RhP040>3Ph03Rh^80h^;R0=gMg@<0f][J0140d];B0=7Ad@3Bd]80c/k>0<G5a@36a/H0_Kfm
0:RXZ02_[jl0YZJV0::RXP2?Shl0PX:206][J`1NGUh0BDU905YJFP0202TY:@0804I6AP26QXH0^;Rh
09^KV`2HV9P0QXJ607YjNP2m_KdA0?Ogm`030?Gem@3gmoL0moOg00P0moOg7P3oool40?Ogm`030??c
l`3gmoL0moOg00D0moOg00L0lo?c06a/K01NGUh0GUiN06YZJP1/K6`0GUiN0080I6AT00P0GUiN08B4
Q029RHT0WinO0<O7a`3EeMD0e]KF0=SHf080g]kN00<0g=cL0>CTi03Ti>@00`3Ti>@00`3Ng]h0i>CT
0>CTi0020>CTi0D0g=cL00@0dm?C0=SHf03Hf=P0eMGE0`3@d=004@37alL0a/K60<O7a`32`/80^;Rh
0;Vi^@2`/;00WYjN0:6QX@2EUID0UYJF0861P@1fMWH0GUiN05=CD`11@D40CTi>00808B4Q00P0>c/k
07alO02YZJT0Shn?08V9R@1lO7`0KVi^0;Bd]140moOg00<0lo?c0?Ogm`3gmoL0203gmoLK0?ooo`00
6@3oool<0?Ogm`030?ooo`2<S8`0Lg=c0080Ogmo00X0Kfm_07MgM`1[Jf/0Ogmo07MgM`26QXH0WIfM
0:^[Z`3Bd]80f][J0`3Rh^820>KViP80j^[Z00X0h^;R0>KViP3Zj^X0h^;R0>KViP3Zj^X0i^KV0>;R
hP3Vi^H0h^;R0`3Vi^H30>;RhP0?0=[JfP3Rh^80f][J0=WIf@3Bd]80dM7A0=;BdP3=cLd0a/K60<G5
a@2m_Kd0Z:RX0:n_[`2VYZH0Vi^K0080PX:200@0Lg=c05iNGP1BDU80>SXj0P0M7Ad01`1WIfL0MgMg
08j>SP2?Shl0Zj^[0<30`02[Zj/07@3gmoLN0?ooo``0moOg00<0oooo08>3P`1VIVH00P1eMGD02P1T
I6@0K6a/05iNGP1eMGD0K6a/07alO02@T900WinO0<O7a`3@d=030=SHf080g]kN0P3Ti>@02P3Lg=`0
g]kN0>CTi03Lg=`0g]kN0>CTi03Ng]h0g=cL0=kNgP3Lg=`30=kNgP<0f=SH00l0d=3@0=SHf03@d=00
clo?0<O7a`36a/H0alO70<71`@2i^KT0^;Rh0;2`/02NWYh0XJ6Q09FEU@2?Shl00P1fMWH0101VIVH0
De=C04E5A@0^;Rh201HF5P0705aLG01/K6`0Q8B40861P@2OWil0][Jf09nOW`0M0?Ogma/0oooo000I
0?ooo``0moOg0140oooo06][J`2>SXh0Lg=c07MgM`1bLW80Lg=c06m_K`1JFUX0MgMg092@T02RXZ80
X:2P0=7Ad@3Jf]X0g]kN0>;RhP020>KViP80j^[Z00<0h^;R0>[ZjP3Zj^X00P3Zj^X01P3Vi^H0h^;R
0>[ZjP3Vi^H0h^;R0>KViP80h^;R0`3Vi^H00`3Jf]X0h>3P0=gMg@020=[JfP030=WIf@3>c/h0c/k>
0080a/K601D0aLG50;fm_@2XZ:P0^;Rh0:2PX02MWId0Ogmo06m_K`1NGUh0Jf][04I6AP0Y:BT0=SHf
01dM7@1bLW80Ogmo08:2PP1jNWX0Zj^[0;6a/@3Rh^807@3gmoLN0?ooo``0moOg00/0oooo05iNGP24
Q8@0IVIV06a/K01ZJVX0IVIV06ATI01>CTh0K6a/08F5Q@0209JFUP040<K6aP3@d=00eMGE0=SHf080
g]kN0P3Ti>@00`3Lg=`0i>CT0>CTi0020>CTi0060=kNgP3Lg=`0i>CT0=kNgP3Lg=`0g]kN0P3Lg=`3
0=kNgP030=3@d03Cdm<0eMGE0080d=3@00<0clo?0<;2`P32`/800P2i^KT05@2h^;P0/;2`09jNWP2Y
ZJT0UYJF092@T01eMGD0I6AT05=CD`1NGUh0>c/k024Q8@0_;bl05QHF06YZJP1eMGD0MWIf06i^KP2O
Wil0YZJV0>3Ph00M0?Ogma/0oooo000I0?ooo`<0moOg00<0mOGe0?Ogm`3gmoL01`3gmoL00`3Ti>@0
JFUY06UYJ@0206][J`0:06YZJP1_Kfl0MgMg07MgM`2>SXh0X:2P0;6a/@3AdM40f][J0=kNgP80i^KV
00`0h^;R0>[ZjP3Zj^X0i^KV0>[ZjP3Vi^H0j^[Z0>;RhP3Vi^H0j^[Z0>KViP3Rh^840>KViP030>;R
hP3Vi^H0h>3P0080h^;R0`3Jf]X0103IfMT0c/k>0<k>cP36a/H20<G5a@0=0;fm_@2a/K40^KVi09fM
W@2@T900QXJ608:2PP1YJFT0DU9B04I6AP0Y:BT0=SHf02TY:@0207moO`0408J6QP1nOWh0/K6a0;jn
_Qh0moOg7P3oool30?Ogm`030??cl`3gmoL0moOg00L0moOg00<0hN7Q065QH@1QHF400P1NGUh02P1M
GEd0I6AT06a/K01/K6`0Q8B409JFUP2VYZH0a/K60=3@d03EeMD20=kNgP0<0=cLg03Ti>@0i>CT0=kN
gP3Ti>@0g]kN0>CTi03Lg=`0g]kN0>CTi03Ng]h0g=cL103Ng]h00`3Lg=`0g]kN0=?Cd`020=SHf0<0
d=3@00@0clo?0<;2`P32`/80^KVi0P2h^;P03@2`/;00YZJV0:ZZZP2@T900QHF507alO01fMWH0HF5Q
04E5A@0k>c/08B4Q02l_;`0Q8B400P1eMGD0101lO7`0Kfm_0:JVYP2a/K4N0?Ogma/0oooo000I0?oo
o`d0moOg0180oooo06UYJ@1[Jf/0GUiN06YZJP1RHV80GUiN07MgM`22PX80Vi^K0:2PX02i^KT0dM7A
0=[JfP3Rh^80h>3P0>KViP3Rh^830>KViP040>;RhP3Zj^X0j^[Z0>[ZjP80h^;R00<0j^[Z0>KViP3V
i^H01@3Vi^H30>;RhP090=[JfP3Rh^80f][J0=WIf@3EeMD0c/k>0<K6aP35aLD0_[jn0080_Kfm00L0
Z:RX09fMW@2MWId0MgMg07=cL`1BDU80ATI60080<S8b00P0;Bd]02TY:@2:RXX0Ogmo07inOP1jNWX0
`L710=KFeQh0moOg7P3oool=0?Ogm`0B0?ooo`1QHF40GUiN05=CD`1MGEd0FUYJ05=CD`1/K6`0MWIf
08n?S`2FUYH0ZZZZ0<K6aP3@d=00f=SH0=?Cd`3Ng]h0g=cL0`3Ng]h0103Lg=`0i>CT0>CTi03Ti>@2
0=cLg0030>CTi03Ng]h0g]kN00D0g]kN0`3Hf=P02@3@d=00f=SH0=3@d03?cll0bLW90<;2`P2i^KT0
^;Rh0;6a/@020;2`/00709jNWP2@T900T92@06a/K01VIVH0ADE503/k>`0202XZ:P0802LW9`0Q8B40
PX:207EeM@1_Kfl0KVi^0;^k^`3Bd]8N0?Ogma/0oooo000I0?ooo`h0moOg00@0LW9b06][J`1[Jf/0
JVYZ0`1[Jf/01P22PX80T92@0:2PX02a/K40d];B0=[JfP80h^;R00@0i^KV0>;RhP3Zj^X0h^;R103Z
j^X01`3Rh^80j^[Z0>KViP3Rh^80j^[Z0>KViP3Rh^801@3Vi^H00`3Rh^80h>3P0=gMg@020=[JfP04
0=WIf@3>c/h0c/k>0<O7a`80aLG500/0_[jn0:n_[`2_[jl0XZ:R092@T026QXH0Lg=c04U9B@16ATH0
<S8b03Hf=P02038b<P05092@T02MWId0Lg=c08n?S`3AdM400P3gmoL00`3emOD0moOg0?Ogm`0J0?Og
mah0oooo3P3gmoL0101ZJVX0GUiN05iNGP1MGEd305iNGP0607IfMP25QHD0UYJF0:JVYP37alL0d=3@
0P3Hf=P0103Ng]h0g=cL0>CTi03Lg=`40>CTi0070=cLg03Ti>@0g]kN0=cLg03Ti>@0g]kN0=cLg005
0=kNgP030=SHf03Cdm<0eMGE0080d=3@00@0clo?0<;2`P32`/80^[Zj0P2h^;P02`2a/K40XJ6Q0:6Q
X@2FUYH0QHF507alO01VIVH0@D5103/k>`0Z:RX0;bl_0080:RXZ00D0QHF5092@T01VIVH0PH610<K6
aP020?Ogm`030??cl`3gmoL0moOg01X0moOg6`3oool001T0oooo3P3gmoL03@2@T900NWYj069RHP1_
Kfl0JFUY069RHP1_Kfl0Ogmo08J6QP2[Zj/0`<300=;BdP3Jf]X00P3Rh^820>KViP80h^;R0P3Zj^X0
0`3Rh^80i^KV0>;RhP030>;RhP030>KViP3Rh^80i^KV00<0i^KV0P3Rh^820=gMg@070=[JfP3IfMT0
fMWI0=;BdP3AdM40cLg=0<_;b`020<G5a@070<71`@2_[jl0X:2P09fMW@2?Shl0Lg=c05iNGP0204U9
B@0903hn?P0b<S80:BTY01dM7@1oOgl0QXJ608:2PP2RXZ80k^k^01l0moOg7P3oool>0?Ogm`0=08F5
Q@1bLW80FUYJ06ATI01QHF40FUYJ06ATI01eMGD0O7al09nOW`2f][H0alO70=3@d0020=SHf080g]kN
0P3Lg=`20>CTi0030=cLg03Ng]h0g=cL00<0g=cL00<0g]kN0=cLg03Ng]h00`3Ng]h20=SHf080eMGE
00L0d=3@0<o?c`3?cll0alO70<K6aP31`L40_;bl0080^;Rh00L0/k>c0:6QX@2FUYH0T92@0861P@1V
IVH0De=C0080@D5100T0<c<c02XZ:P0Q8B405QHF07EeM@1lO7`0MWIf09JFUP3_knl07`3gmoLK0?oo
o`006@3oool>0?Ogm`030?ooo`34a<@0T92@00<0Ogmo00H0JFUY07moO`2CTi<0X:2P0;Vi^@3IfMT2
0=[JfP030>;RhP3Ng]h0h^;R00<0h^;R0P3Vi^H00`3Rh^80i^KV0>;RhP030>KViP030>;RhP3Vi^H0
h^;R00<0h^;R00<0h>3P0>;RhP3IfMT00`3IfMT01@3Bd]80dM7A0<g=c@36a/H0cLg=0080_Kfm0P2P
X:001@2@T900SXj>06][J`1JFUX0GUiN0080ATI600T0<S8b01PH6019BDT0WIfM08J6QP2CTi<0[jn_
0?Ogm`3emOD07P3gmoLN0?ooo`h0moOg00<0oooo0;fm_@25QHD00`1eMGD01P1QHF40MGEe08^;R`2F
UYH0ZZZZ0<o?c`80d=3@00<0f=SH0=GEe@3Hf=P00`3Lg=`20=kNgP030=cLg03Ng]h0g=cL00<0g]kN
00<0f=SH0=kNgP3Hf=P00`3Hf=P00`3Cdm<0f=SH0<o?c`030<o?c`050<O7a`36a/H0`L710;Vi^@31
`L400P2`/;0209JFUP0508F5Q@24Q8@0GUiN04i>CP1CDe<00P0k>c/02@0Z:RX051@D0451@@2@T900
O7al08:2PP2QXJ40moOg0??cl`0N0?Ogma/0oooo000I0?ooo`030?Ogm`3emOD0moOg00H0moOg00<0
mOGe0?Ogm`3gmoL00P3gmoL20?ooo`0:0>c/k022PX80Ogmo06m_K`1bLW80MgMg08n?S`2XZ:P0/K6a
0=WIf@80f][J0P3Rh^80103Vi^H0h^;R0>;RhP3Rh^850>KViP030>;RhP3Vi^H0i^KV0080i^KV0`3R
h^800`3Vi^H0f][J0=[JfP020=[JfP030=WIf@3Jf]X0c/k>0080c/k>00<0cLg=0<G5a@2i^KT00P2X
Z:P01@2RXZ80Shn?07QhN01_Kfl0FUYJ0080BDU900P0=SHf03hn?P0H61P0SXj>092@T01jNWX0V9RH
0:NWYb00moOg7P3oool00`3gmoL0lo?c0?Ogm`060?Ogm`030??cl`3gmoL0moOg0080moOg0P3oool0
2P3Zj^X0NWYj07EeM@1TI6@0JVYZ06a/K021PH40WYjN0:JVYP3?cll20=3@d080f=SH00@0g]kN0=SH
f03Lg=`0g=cL1@3Ng]h00`3Lg=`0g]kN0=kNgP020=kNgP<0f=SH00<0g]kN0=3@d03@d=000P3@d=00
0`3?cll0d=3@0<;2`P020<;2`P030<71`@2h^;P0ZZZZ0080WYjN00D0UYJF0861P@1YJFT0I6AT04i>
CP020451@@0802l_;`0c<c<051@D08B4Q025QHD0KVi^08V9R@2IVITP0?Ogma/0oooo000I0?oooa00
moOg00@0oooo0:j^[P1[Jf/0LW9b0P1gMgL01@2>SXh0XZ:R0;Vi^@3Bd]80dm?C0080f][J00@0h^;R
0=gMg@3Rh^80h^;R0`3Vi^H01`3Rh^80i^KV0>KViP3Rh^80i^KV0=kNgP3Ogml00`3Rh^801P3MgMd0
f][J0=[JfP3Jf]X0fMWI0=[JfP80fMWI0`3>c/h20<K6aP060;jn_P2m_Kd0X:2P092@T022PX80NWYj
0P1_Kfl204I6AP0903hn?P0Y:BT0WIfM08Z:RP22PX80NWYj0::RXP36a/H0moOg0080mOGe7@3gmoLN
0?oooa00moOg00@0oooo0:FUY@1NGUh0JVYZ0P1/K6`01@24Q8@0UYJF0:ZZZP37alL0a<C40080d=3@
00@0f=SH0=GEe@3Hf=P0f=SH0`3Ng]h01`3Hf=P0g]kN0=kNgP3Hf=P0g]kN0=GEe@3Fe]H00`3Hf=P0
1P3EeMD0d=3@0=3@d03@d=00clo?0=3@d080clo?0`32`/820;Vi^@060;6a/@2`/;00UYJF08F5Q@1f
MWH0KVi^0P1TI6@203/k>`0903<c<`0Q8B40T92@08:2PP1fMWH0KVi^09JFUP2m_Kd0moOg0080lo?c
7@3gmoLK0?ooo`006@3oool@0?Ogm`050?ooo`3EeMD0DU9B06m_K`1YJFT00P2>SXh03@2RXZ80/K6a
0=7Ad@3Fe]H0f][J0=WIf@3Jf]X0h^;R0>KViP3Rh^80gmoO0>KViP3Rh^80103Vi^H30>;RhP060=[J
fP3Rh^80f][J0>;RhP3Jf]X0fMWI0P3Jf]X20=WIf@0K0=7Ad@3=cLd0cLg=0<O7a`35aLD0_Kfm0:RX
Z02_[jl0WIfM092@T026QXH0PX:205iNGP1RHV80Ogmo038b<P0Y:BT0;Bd]06][J`2>SXh0PX:208n?
S`2[Zj/0d];B0?Ogm`3emOD0oooo01d0moOg7P3oool@0?Ogm`050?ooo`3AdM40ADE506ATI01QHF40
0P24Q8@03@2FUYH0YZJV0<K6aP3=cLd0d=3@0<o?c`3@d=00f=SH0=kNgP3Hf=P0e]KF0=kNgP3Hf=P0
103Ng]h30=SHf0060=3@d03Hf=P0d=3@0=SHf03@d=00clo?0P3@d=020<o?c`0K0<K6aP31`L40`L71
0;Zj^P2h^;P0];Bd09jNWP2QXJ40T92@08F5Q@1lO7`0MWIf05=CD`1JFUX0MGEe02XZ:P0Q8B409bLW
05iNGP24Q8@0MWIf0861P@2OWil0alO70?Ogm`3clo<0oooo01d0moOg6`3oool001T0oooo403gmoL0
4@3oool0`L7108J6QP1[Jf/0LW9b092@T02>SXh0XZ:R0;Vi^@37alL0d];B0=[JfP3IfMT0f][J0>3P
h03Vi^H0gMgM00H0h^;R00<0i^KV0>3Ph03Ph>000P3Jf]X00`3Cdm<0f][J0=WIf@030=WIf@050=[J
fP3IfMT0fMWI0<g=c@3>c/h00P36a/H02035aLD0_Kfm0:RXZ02MWId0Shn?08J6QP1jNWX0Kfm_0P1[
Jf/02`19BDT0GUiN04U9B@1NGUh0T92@08J6QP2KVi/0XZ:R0<30`039bLT0oooo01l0moOg7P3oool@
0?Ogm`0A0?ooo`2k^k/0O7al05iNGP1ZJVX0QHF508B4Q02FUYH0ZZZZ0;Zj^P37alL0d=3@0<o?c`3@
d=00dm?C0=kNgP3EeMD01P3Hf=P00`3Ng]h0dm?C0=?Cd`020=3@d0030<C4a03@d=00clo?00<0clo?
00D0d=3@0<o?c`3?cll0`L710<;2`P020;Vi^@080;Rh^02`/;00WYjN092@T021PH40O7al06i^KP1T
I6@205iNGP0;0451@@1CDe<0@D5105=CD`25QHD0O7al08n?S`2FUYH0][Jf0<?3``3oool07`3gmoLK
0?ooo`006@3ooolA0?Ogm`0;0>CTi03De=@0ATI608:2PP1[Jf/0QXJ609>CT`2PX:00a/K60<O7a`3>
c/h00P3Cdm<0103IfMT0e]KF0=[JfP3Ng]h40=[JfP050=WIf@3Jf]X0f][J0=GEe@3:b/X00P3;bl/0
0`3=cLd0d];B0<[:bP020<[:bP030<71`@35aLD0bl_;00<0_Kfm01D0/K6a0;Rh^02XZ:P0WIfM09^K
V`2>SXh0QXJ607=cL`1_Kfl0HV9R07YjNP1YJFT0GUiN07YjNP2MWId0T92@0::RXP2m_Kd0dM7A0<W9
b@3emOD00P3gmoL00`3oool0moOg0?Ogm`090?Ogm`030?Gem@3gmoL0moOg00l0moOg7P3ooolA0?Og
m`0;0>7Qh@3>c/h0>c/k07IfMP1NGUh0O7al08^;R`2FUYH0^KVi0;Zj^P32`/800P34a<@0103?cll0
cLg=0=3@d03EeMD40=3@d0050<o?c`3@d=00d=3@0<W9b@2k^k/00P2l_;`00`31`L40`l?30;^k^`02
0;^k^`030;>c/`2h^;P0_;bl00<0/;2`01D0YZJV0:VYZ@2NWYh0T92@08n?S`24Q8@0O7al06IVIP1T
I6@0FUYJ079bLP1QHF40De=C079bLP2@T900QHF509JFUP2`/;00a/K60<?3``3clo<00P3gmoL00`3o
ool0moOg0?Ogm`090?Ogm`030??cl`3gmoL0moOg00l0moOg6`3oool001T0oooo4P3gmoL02`2f][H0
S8b<06m_K`1oOgl0MgMg08J6QP2@T900_[jn0=7Ad@37alL0a/K60080c/k>0`3Jf]X0203Fe]H0d];B
0=;BdP3Bd]80c/k>0<O7a`35aLD0a/K60P2m_Kd30;Vi^@050;Rh^02i^KT0^;Rh0;Rh^02XZ:P00`2_
[jl03@2VYZH0X:2P0:RXZ02PX:00WIfM08:2PP1gMgL0PX:207moO`1VIVH0Ogmo05iNGP1gMgL00P22
PX801P26QXH0XZ:R09^KV`36a/H0dM7A0??clb40moOg7P3ooolB0?Ogm`0;0:f][@23Ph<0I6AT07Ee
M@1/K6`0O7al08F5Q@2a/K40a/K60;Zj^P2m_Kd00P32`/830=3@d0080<g=c@37alL0alO70<O7a`32
`/80^[Zj0;Rh^02i^KT20;2`/0<0ZZZZ00D0ZJVY0:ZZZP2YZJT0ZJVY09jNWP030:6QX@0=09FEU@2F
UYH0WYjN09JFUP2@T900MWIf06a/K01jNWX0MGEe061PH01eMGD0De=C06a/K00207IfMP0607alO02F
UYH0Shn?0;Vi^@36a/H0lO7a8@3gmoLK0?ooo`006@3ooolC0?Ogm`080;Jf]P1_Kfl0MgMg07moO`2>
SXh0WIfM0:2PX02XZ:P20<K6aP030=;BdP3IfMT0d];B0080d];B0140dM7A0<K6aP36a/H0a/K60=7A
d@2n_[h0`L710;fm_@2XZ:P0/K6a0:JVYP2_[jl0XZ:R0;Vi^@2_[jl0V9RH0:2PX00209RHV00:0::R
XP2KVi/0WIfM09fMW@2@T900X:2P0:RXZ02GUiL0SXj>092@T080MgMg00X0T92@06m_K`1BDU80Jf][
09RHV02KVi/0XZ:R0;fm_@36a/H0bLW91P3gmoL00`3emOD0moOg0?Ogm`0<0?Ogm`030?ooo`3gmoL0
moOg00X0moOg7P3ooolC0?Ogm`0<0;:b/P1TI6@0K6a/07EeM@24Q8@0T92@09JFUP2NWYh0^KVi0;fm
_@37alL0clo?0`37alL04@36a/H0^KVi0;Vi^@2i^KT0a/K60;6a/@2c/k<0/;2`09jNWP2VYZH0UIFE
0:6QX@2FUYH0ZZZZ0:6QX@29RHT0UYJF0080RHV900X0UYJF08n?S`2@T900T92@08F5Q@2FUYH0WYjN
096AT@24Q8@0QHF50P1/K6`02P25QHD0I6AT04E5A@1NGUh0RHV908n?S`2FUYH0];Bd0;fm_@33`l<6
0?Ogm`030??cl`3gmoL0moOg00`0moOg00<0oooo0?Ogm`3gmoL02P3gmoLK0?ooo`006@3ooolD0?Og
m`0809RHV022PX80JFUY08J6QP2>SXh0X:2P0;6a/@39bLT30=OGe`030=;BdP36a/H0alO70080_Kfm
00<0_[jn0;fm_@2n_[h00P2m_Kd0702[Zj/0X:2P0:2PX02MWId0X:2P09fMW@2?Shl0Vi^K08J6QP22
PX80WIfM08J6QP2KVi/0Shn?092@T02>SXh0T92@07MgM`1oOgl0Shn?08:2PP26QXH0PX:208J6QP1_
Kfl0NWYj08:2PP26QXH208j>SP80a/K600D0/K6a0?Ogm`3gmoL0moOg0?Gem@0?0?Ogm`030?Gem@3g
moL0moOg00d0moOg7P3ooolD0?Ogm`0809:BTP1jNWX0HF5Q07alO024Q8@0UYJF0:JVYP33`l<30<k>
cP080<O7a`2m_Kd0^[Zj0;2`/02d];@0/K6a0;2`/02a/K420;2`/00L09nOW`2FUYH0UYJF092@T02F
UYH0T92@0861P@2?Shl0O7al07IfMP2@T900O7al08n?S`21PH40QHF508B4Q025QHD0K6a/07EeM@21
PH40NWYj07alO01jNWX0O7al06ATI01bLW80MWIf07alO080Q8B40P2m_Kd01@2VYZH0moOg0?Ogm`3g
moL0lo?c00l0moOg00<0lo?c0?Ogm`3gmoL03@3gmoLK0?ooo`006@3oool60?Ogm`030?Gem@3gmoL0
moOg00/0moOg02`0V9RH096AT@2@T900R8R809NGU`2j^[X0[Jf]0<O7a`2j^[X0alO70<W9b@37alL0
a/K60;jn_P2m_Kd0_[jn0:RXZ02m_Kd0/K6a0:^[Z`2a/K40Z:RX09^KV`2MWId0QXJ60:RXZ02@T900
Z:RX092@T02RXZ80SXj>08:2PP2XZ:P0SXj>092@T02>SXh0Ti>C09NGU`1bLW80Ogmo08Z:RP1jNWX0
PX:2092@T080NWYj00P0PX:207YjNP26QXH0Vi^K0;no_`2m_Kd0`<300=cLg0<0moOg00<0oooo0?Og
m`3gmoL07@3gmoLN0?ooo`H0moOg00<0lo?c0?Ogm`3gmoL02`3gmoL0;02BTY80QXJ608F5Q@1nOWh0
TI6A0;2`/02TY:@0^[Zj0;2`/02j^[X0`l?30;Zj^P2i^KT0/K6a0;2`/02a/K40WYjN0;2`/02VYZH0
WinO0:JVYP2NWYh0Shn?092@T01lO7`0WYjN08F5Q@2NWYh0QHF509JFUP24Q8@0MWIf09jNWP24Q8@0
QHF508B4Q02;Rh/0TI6A06YZJP1eMGD0PX:2079bLP1jNWX0QHF50P1^KVh0201fMWH0KVi^07alO02?
Shl0]KFe0;Bd]02f][H0eMGE0`3gmoL00`3oool0moOg0?Ogm`0M0?Ogma/0oooo000I0?oooaD0moOg
00H0oooo0:>SX`2ATI40T92@0;6a/@2f][H40<K6aP<0/K6a00<0Z:RX0;6a/@2XZ:P00P2MWId0102X
Z:P0Vi^K08j>SP1jNWX209>CT`0507MgM`1NGUh0T92@09^KV`2>SXh00P2@T9002P1cLg<0PX:205YJ
FP1NGUh0OWin07=cL`1_Kfl0Lg=c07YjNP22PX8207YjNP0:06][J`22PX80_Kfm0:RXZ030`<00bLW9
07MgM`2CTi<0emOG0?ooo`H0moOg00<0mOGe0?Ogm`3gmoL06P3gmoLN0?oooaD0moOg00H0oooo09^K
V`26QXH0QHF50:JVYP2][Jd40;fm_@<0YZJV00<0WYjN0:JVYP2NWYh00P2@T900102NWYh0Shn?08B4
Q01^KVh208^;R`0506a/K01CDe<0QHF508n?S`24Q8@00P25QHD02P1VIVH0MWIf04i>CP1CDe<0Kfm_
06IVIP1TI6@0IVIV06i^KP1fMWH206i^KP0:05iNGP1fMWH0];Bd09jNWP2f][H0`l?306a/K02;Rh/0
dm?C0?ooo`H0moOg00<0lo?c0?Ogm`3gmoL06P3gmoLK0?ooo`006@3ooolF0?Ogm`090;Ng]`2EUID0
LW9b08:2PP2CTi<0]kNg0<71`@37alL0a/K60080Z:RX00L0X:2P0:RXZ02XZ:P0X:2P09NGU`2PX:00
T92@0080Vi^K00H0Zj^[08j>SP1gMgL0Z:RX07MgM`1_Kfl207MgM`0407moO`1_Kfl0Lg=c06YZJP80
Jf][0100OWin06][J`1YJFT0NWYj06][J`1WIfL0Lg=c08J6QP2KVi/0/K6a0:RXZ03AdM40a/K609>C
T`2>SXh0Ti>C1`3gmoL00`3emOD0moOg0?Ogm`0:0?Ogm`030?Gem@3gmoL0oooo00h0moOg7P3ooolF
0?Ogm`090:j^[P2<S8`0JVYZ07IfMP2;Rh/0[Zj^0;^k^`2j^[X0_Kfm0080WYjN00L0UYJF09jNWP2N
WYh0UYJF096AT@2FUYH0QHF50080Shn?00H0WinO08B4Q01/K6`0WYjN06a/K01TI6@206a/K00407Ee
M@1TI6@0IVIV05eMG@80GUiN0100Kfm_05iNGP1QHF40KVi^05iNGP1HF5P0IVIV07alO02?Shl0YZJV
09jNWP36a/H0_Kfm08^;R`24Q8@0Rh^;1`3gmoL00`3clo<0moOg0?Ogm`0:0?Ogm`030??cl`3gmoL0
oooo00h0moOg6`3oool001T0oooo5P3gmoL0303oool0IVIV08b<S02ATI40Ti>C0:>SX`2i^KT0`L71
0;jn_P2@T900WIfM09>CT`80Z:RX0P2MWId03`2KVi/0T92@0:2PX02@T900Kfm_08J6QP22PX80MgMg
08j>SP1_Kfl0NWYj06m_K`1bLW80Kfm_069RHP0206][J`0705iNGP1JFUX0Jf][06UYJ@1[Jf/0JVYZ
07MgM`0308j>SP070;6a/@31`L40RXZ:08Z:RP2CTi<0][Jf0>c/k0020?Gem@80moOg00<0mOGe0?Og
m`3emOD00P3gmoL01@3oool0moOg0?Ogm`3gmoL0oooo01L0moOg7P3ooolF0?Ogm`0<0?ooo`1PH600
Ph>308J6QP2;Rh/0Vi^K0;>c/`2k^k/0/K6a08F5Q@2@T900Rh^;0P2NWYh2092@T00?08n?S`25QHD0
UYJF08F5Q@1TI6@0O7al07YjNP1/K6`0Q8B406ATI01^KVh0I6AT06YZJP1TI6@0FUYJ0080GUiN00L0
De=C04i>CP1NGUh0HF5Q05iNGP1MGEd0K6a/00<0Q8B400L0YZJV0;^k^`22PX80PX:208^;R`2][Jd0
j^[Z0080lo?c0P3gmoL00`3clo<0moOg0??cl`020?Ogm`050?ooo`3gmoL0moOg0?Ogm`3oool05`3g
moLK0?ooo`006@3ooolH0?Ogm`0508b<S02SXj<0Z:RX0:f][@2SXj<00P36a/H01P2>SXh0X:2P092@
T02@T900Vi^K08j>SP80Ti>C0140PX:2092@T022PX80Kfm_08j>SP22PX80Ogmo069RHP1NGUh0HV9R
06UYJ@1_Kfl0JFUY06YZJP1NGUh0DU9B04U9B@0305YJFP0<06YZJP1_Kfl0MgMg09>CT`2a/K40Z:RX
0<71`@2][Jd0UiNG07moO`2a/K40Ogmo0P3oool00`3emOD0moOg0?Ogm`0Q0?Ogmah0oooo603gmoL0
1@23Ph<0Vi^K0::RXP2TY:@0Vi^K0080_Kfm00H0Q8B409JFUP25QHD0QHF508n?S`24Q8@208^;R`0A
07YjNP25QHD0NWYj06ATI024Q8@0MWIf07EeM@1JFUX0De=C05YJFP1QHF40I6AT065QH@1MGEd0De=C
04E5A@11@D400`1>CTh0301MGEd0I6AT06a/K02;Rh/0YZJV09jNWP2k^k/0Y:BT096AT@1eMGD0YZJV
07EeM@80oooo00<0lo?c0?Ogm`3gmoL08@3gmoLK0?ooo`006@3ooolF0?Ogm`0L0?Gem@3gmoL0oooo
05YJFP24Q8@0UIFE0:>SX`31`L40bLW908j>SP1oOgl0Xj>S092@T02PX:00Xj>S07moO`2CTi<0SXj>
07MgM`2@T900MgMg08J6QP2>SXh0PX:207YjNP16ATH0JFUY08j>SP80Jf][00D0DU9B06][J`1BDU80
ATI604U9B@0204I6AP0<05iNGP2CTi<0Z:RX09fMW@2XZ:P0`L71079bLP27QhL0Vi^K09>CT`22PX80
]kNg1@3gmoL00`3emOD0oooo0?Ogm`0A0?Ogm`030?ooo`3gmoL0moOg00X0moOg7P3ooolF0?Ogm`0L
0??cl`3gmoL0oooo04i>CP1kNg/0S8b<09^KV`2k^k/0`l?308B4Q01eMGD0Vi^K08F5Q@2FUYH0Vi^K
07EeM@2;Rh/0Q8B406a/K025QHD0K6a/07alO024Q8@0NWYj079bLP0k>c/0HF5Q08B4Q080GUiN00D0
ADE505iNGP15ADD0>c/k0451@@0203/k>`0<05=CD`2;Rh/0WYjN092@T02NWYh0^k^k06YZJP21PH40
Shn?08^;R`1fMWH0[Zj^1@3gmoL00`3clo<0oooo0?Ogm`0A0?Ogm`030?ooo`3gmoL0moOg00X0moOg
6`3oool001T0oooo103gmoL00`3emOD0moOg0?Ogm`0B0?Ogm`0:079bLP1YJFT0LW9b09NGU`2][Jd0
^KVi09>CT`1oOgl0SXj>0:2PX080PX:200/0NWYj07MgM`28R8P0PX:207YjNP2@T900PX:207MgM`2>
SXh0QXJ607YjNP0205iNGP05079bLP1[Jf/0Jf][07=cL`22PX800P1ZJVX02`1eMGD0PX:208n?S`2R
XZ80/K6a0=;BdP2SXj<0[Jf]05iNGP22PX80Ti>C0080Xj>S1@3gmoL00`3oool0moOg0?Ogm`040?Og
m`030?ooo`3gmoL0moOg00@0moOg00<0oooo0?Ogm`3gmoL04@3gmoLN0?ooo`@0moOg00<0lo?c0?Og
m`3gmoL04P3gmoL02P1^KVh0HF5Q06YZJP2ATI40Y:BT0;>c/`2;Rh/0MGEe08B4Q02FUYH207YjNP0;
079bLP1/K6`0OWin07YjNP1bLW80QHF507YjNP1/K6`0Q8B407alO01bLW800P1CDe<01@1ZJVX0GUiN
05iNGP1VIVH0MWIf0080GEeM00/0IfMW07IfMP21PH40UYJF0:JVYP3<c<`0Vi^K0:BTY01CDe<0NWYj
08^;R`0209^KV`D0moOg00<0oooo0?Ogm`3gmoL0103gmoL00`3oool0moOg0?Ogm`040?Ogm`030?oo
o`3gmoL0moOg0140moOg6`3oool001T0oooo5P3gmoL02`3oool0moOg0?Ogm`3gmoL0][Jf08:2PP24
Q8@0R8R809>CT`2a/K40][Jf0080NWYj0`2CTi<0301[Jf/0Kfm_06m_K`22PX80QXJ606][J`2ATI40
QXJ60:2PX02@T900Xj>S07moO`80Lg=c0P26QXH00`2KVi/0XZ:R0::RXP020;fm_@0:0;Jf]P2<S8`0
S8b<07=cL`1JFUX0Jf][09>CT`2:RXX0Z:RX0?ooo`80moOg0P3oool20?Ogm`030?ooo`3gmoL0moOg
01l0moOg7P3ooolF0?Ogm`0;0?ooo`3gmoL0moOg0?Ogm`2b/[80NWYj07]kN`1nOWh0Rh^;0:JVYP2]
[Jd00P1bLW8308^;R`0<05iNGP1TI6@0I6AT07IfMP1lO7`0GUiN08J6QP1lO7`0UYJF08F5Q@2KVi/0
MGEe0P1VIVH207alO00308n?S`2FUYH0UYJF0080/;2`00X0[Jf]08>3P`23Ph<0IVIV04i>CP1NGUh0
Rh^;08:2PP2NWYh0oooo0P3gmoL20?ooo`80moOg00<0oooo0?Ogm`3gmoL07`3gmoLK0?ooo`006@3o
oolF0?Ogm`030?Gem@3gmoL0moOg0080moOg01T0a<C407=cL`24Q8@0UiNG0:f][@2f][H0^KVi08:2
PP2CTi<0MgMg08:2PP2@T900Ogmo06][J`1WIfL0MgMg06UYJ@28R8P0QXJ60:RXZ02PX:00emOG0<K6
aP2a/K40alO70080_[jn0P3Fe]H03036a/H0`L7109NGU`1jNWX0Ogmo06m_K`1YJFT0MgMg09^KV`2@
T900TI6A0?ooo`80moOg00<0oooo0?Ogm`3gmoL01P3gmoL20?oooa`0moOg7P3ooolF0?Ogm`030??c
l`3gmoL0moOg0080moOg01T0_Kfm06][J`1kNg/0TI6A0:BTY02][Jd0/k>c07YjNP2;Rh/0K6a/07Yj
NP25QHD0MGEe05iNGP1LG5`0K6a/065QH@1nOWh0O7al09jNWP2FUYH0c/k>0;fm_@2VYZH0^[Zj0080
/K6a0P3=cLd0302i^KT0^k^k096AT@1bLW80MGEe06ATI01QHF40K6a/08n?S`25QHD0QXJ60?ooo`80
moOg00<0oooo0?Ogm`3gmoL01P3gmoL20?oooa`0moOg6`3oool001T0oooo6@3gmoL01`3oool0moOg
0?Ogm`3alO40T92@08B4Q02GUiL00P31`L405@2m_Kd0UIFE0:2PX02HV9P0TI6A0:RXZ02f][H0S8b<
07YjNP1WIfL0PX:20:>SX`2f][H0[Jf]0<W9b@3:b/X0bLW90=;BdP3Ng]h0g=cL0;6a/@020:>SX`09
09FEU@24Q8@0PX:2069RHP1[Jf/0PX:208Z:RP2XZ:P0Xj>S00<0moOg00@0mOGe0?Ogm`3emOD0mOGe
0`3gmoL00`3emOD0moOg0?Ogm`030?Ogm`030?Gem@3gmoL0moOg01P0moOg7P3ooolI0?Ogm`070?oo
o`3gmoL0moOg0?3`l02:RXX0Ng]k096AT@020;^k^`0E0;Bd]02<S8`0UYJF09:BTP26QXH0WYjN0:f]
[@23Ph<0LW9b05aLG01jNWX0Vi^K0:f][@2TY:@0`l?30<C4a033`l<0c<c<0=[JfP3EeMD0YZJV0080
Vi^K00T0S8b<07]kN`1jNWX0FUYJ05iNGP1jNWX0PX:209jNWP2KVi/00`3gmoL0103clo<0moOg0??c
l`3clo<30?Ogm`030??cl`3gmoL0moOg00<0moOg00<0lo?c0?Ogm`3gmoL0603gmoLK0?ooo`006@3o
oolI0?Ogm`0:0?ooo`3gmoL0moOg0?Ogm`3oool0S8b<08n?S`2HV9P0^KVi0=CDe080^KVi00/0][Jf
0=GEe@3:b/X0]kNg0=cLg03clo<0jn_[0>;RhP3Lg=`0f][J0<W9b@030=;BdP050=[JfP31`L40UiNG
09NGU`2:RXX00P2<S8`0101gMgL0NWYj092@T02GUiL209>CT`05092@T03gmoL0moOg0?ooo`3emOD0
0`3gmoL00`3emOD0moOg0?Ogm`040?Ogm`080?ooo`3gmoL0moOg0?Gem@3gmoL0mOGe0?Ogm`3ooolF
0?Ogmah0oooo6@3gmoL02P3oool0moOg0?Ogm`3gmoL0oooo08>3P`29RHT0TY:B0;>c/`3>c/h20;>c
/`0;0;:b/P3AdM40a<C40:j^[P3EeMD0lO7a0>WYj@3Lg=`0eMGE0=CDe033`l<00`3<c<`01@3De=@0
^k^k096AT@2ATI40PX:20080Ph>300@0K6a/079bLP25QHD0TI6A0P2;Rh/01@25QHD0moOg0?Ogm`3o
ool0lo?c00<0moOg00<0lo?c0?Ogm`3gmoL0103gmoL0203oool0moOg0?Ogm`3clo<0moOg0??cl`3g
moL0oooo5P3gmoLK0?ooo`006@3ooolA0?Ogm`030?ooo`3gmoL0moOg00D0moOg00<0oooo0?Ogm`3g
moL00`3gmoL01`1cLg<0Ogmo0:>SX`2b/[80b/[:0=GEe@3Fe]H00`3EeMD06`3Ogml0emOG0=[JfP3G
emL0h^;R0>KViP3Ogml0g=cL0<71`@2^[Zh0bLW90:f][@2XZ:P0OWin08j>SP1gMgL0NWYj08b<S02E
UID0/K6a0:2PX02CTi<0]kNg0?Ogm`3emOD0moOg0?Gem@060?Ogm`030?Gem@3gmoL0moOg01<0moOg
00<0oooo0?Ogm`3emOD02P3gmoLN0?oooa40moOg00<0oooo0?Ogm`3gmoL01@3gmoL00`3oool0moOg
0?Ogm`030?Ogm`0706][J`1iNGT0Vi^K0:^[Z`34a<@0dM7A0=;BdP030=7Ad@0K0=_Kf`3>c/h0e=CD
0<k>cP3Lg=`0h^;R0=_Kf`3EeMD0^k^k0:FUY@33`l<0Y:BT0::RXP1hN7P0Q8B406a/K01bLW80Ph>3
08b<S02VYZH0UYJF08^;R`2^[Zh0moOg0??cl`3gmoL0lo?c00H0moOg00<0lo?c0?Ogm`3gmoL04`3g
moL00`3oool0moOg0??cl`0:0?Ogma/0oooo000I0?oooah0moOg00P0mOGe0?ooo`3gmoL0moOg0:JV
YP2<S8`0UIFE0=CDe080gmoO00l0g]kN0=cLg03Ph>00e]KF0=CDe03:b/X0^KVi0:f][@2f][H0^KVi
0:RXZ02HV9P0MWIf096AT@2HV9P00P2i^KT01031`L40^KVi09VIV@3emOD50?Ogm`030?ooo`3gmoL0
moOg00@0moOg00<0oooo0?Ogm`3oool00P3gmoL00`3emOD0moOg0?ooo`040?Ogm`030?ooo`3gmoL0
moOg00L0moOg0`3oool00`3emOD0moOg0?Ogm`030?Ogm`030?ooo`3gmoL0moOg0080moOg7P3ooolN
0?Ogm`080??cl`3oool0moOg0?Ogm`2MWId0Ph>308b<S03>c/h20=_Kf`0?0=[JfP3EeMD0fm_K0=;B
dP3>c/h0a<C40;>c/`2TY:@0[Jf]0;>c/`2RXZ80TY:B071`L026QXH0TY:B0080/k>c00@0^k^k0;>c
/`2CTi<0lo?c1@3gmoL00`3oool0moOg0?Ogm`040?Ogm`030?ooo`3gmoL0oooo0080moOg00<0lo?c
0?Ogm`3oool0103gmoL00`3oool0moOg0?Ogm`070?Ogm`<0oooo00<0lo?c0?Ogm`3gmoL00`3gmoL0
0`3oool0moOg0?Ogm`020?Ogma/0oooo000I0?oooa00moOg00<0oooo0?Ogm`3gmoL02@3gmoL0103e
mOD0oooo0?Ogm`3oool50?Ogm`060:JVYP2o_kl0a<C40<[:bP3Ph>00gmoO0P3Ph>00203Ogml0b/[:
0<[:bP2b/[80YZJV0<71`@3EeMD0[Zj^0P3:b/X0102^[Zh0Xj>S0<W9b@3/k>`20?ooo`<0moOg00<0
oooo0?Ogm`3gmoL00P3gmoL00`3oool0moOg0?Ogm`030?Ogm`030?Gem@3gmoL0moOg00@0moOg1P3o
ool40?Ogm`030?ooo`3gmoL0moOg0080oooo00<0moOg0?ooo`3gmoL02@3gmoLN0?oooa00moOg00<0
oooo0?Ogm`3gmoL02@3gmoL0103clo<0oooo0?Ogm`3oool50?Ogm`0409fMW@2j^[X0_Kfm0<C4a0D0
fm_K0P34a<@01@2[Zj/0WIfM0;^k^`3AdM40YJFU0080a<C400@0YJFU09^KV`33`l<0j^[Z0P3oool3
0?Ogm`030?ooo`3gmoL0moOg0080moOg00<0oooo0?Ogm`3gmoL00`3gmoL00`3clo<0moOg0?Ogm`04
0?Ogm`H0oooo103gmoL00`3oool0moOg0?Ogm`020?ooo`030?Ogm`3oool0moOg00T0moOg6`3oool0
01T0oooo3`3gmoL00`3emOD0moOg0?Ogm`0@0?Ogm`080?ooo`3gmoL0oooo0?Ogm`2f][H0/[:b0<[:
bP2g]kL20=KFeP0=0>;RhP3Ph>00jn_[0??cl`3Ogml0eMGE0=oOg`3Fe]H0eMGE0;Ng]`31`L40eMGE
0>c/k0020?Ogm`030?ooo`3emOD0moOg00D0moOg00@0mOGe0?Ogm`3gmoL0mOGe0P3gmoL00`3emOD0
moOg0?Ogm`040?Ogm`030?Gem@3gmoL0moOg00@0moOg00<0mOGe0?ooo`3emOD0103gmoL00`3emOD0
moOg0?Ogm`020?Ogm`030?Gem@3gmoL0moOg00L0moOg7P3oool?0?Ogm`030??cl`3gmoL0moOg0100
moOg00P0oooo0?Ogm`3oool0moOg0;:b/P2[Zj/0a<C40:j^[P80d];B00d0h>3P0=_Kf`3YjNT0lO7a
0=_Kf`3AdM40fm_K0=;BdP3AdM40[Zj^0;^k^`3AdM40j^[Z0080moOg00<0oooo0??cl`3gmoL01@3g
moL0103clo<0moOg0?Ogm`3clo<20?Ogm`030??cl`3gmoL0moOg00@0moOg00<0lo?c0?Ogm`3gmoL0
103gmoL00`3clo<0oooo0??cl`040?Ogm`030??cl`3gmoL0moOg0080moOg00<0lo?c0?Ogm`3gmoL0
1`3gmoLK0?ooo`006@3oool@0?Ogm`030?ooo`3gmoL0moOg00`0moOg00@0mOGe0?Ogm`3gmoL0oooo
0P3emOD20?Ogm`<0mOGe00P0k>c/0>CTi03clo<0jn_[0=GEe@3:b/X0eMGE0=KFeP80e=CD00<0emOG
0>c/k03gmoL0103gmoL00`3oool0moOg0?ooo`020?ooo`@0moOg0P3emOD50?Ogm`030?Gem@3gmoL0
mOGe00<0moOg00<0oooo0?Ogm`3gmoL01@3gmoL00`3oool0moOg0?ooo`070?Ogm`030?ooo`3gmoL0
moOg00L0moOg7P3oool@0?Ogm`030?ooo`3gmoL0moOg00`0moOg00@0lo?c0?Ogm`3gmoL0oooo0P3c
lo<20?Ogm`<0lo?c00P0j^[Z0>7Qh@3alO40jNWY0=7Ad@34a<@0dM7A0=;BdP80c/k>00<0dm?C0>[Z
jP3gmoL0103gmoL00`3oool0moOg0?ooo`020?ooo`@0moOg0P3clo<50?Ogm`030??cl`3gmoL0lo?c
00<0moOg00<0oooo0?Ogm`3gmoL01@3gmoL00`3oool0moOg0?ooo`070?Ogm`030?ooo`3gmoL0moOg
00L0moOg6`3oool001T0oooo4@3gmoL00`3emOD0moOg0?Ogm`070?Ogm`030?ooo`3emOD0moOg0080
moOg00<0mOGe0?Ogm`3gmoL01P3gmoL00`3oool0moOg0?Ogm`020?Ogm`<0mOGe00<0oooo0?Ogm`3g
moL00`3gmoL20?ooo`L0moOg00D0mOGe0?ooo`3gmoL0moOg0?ooo`020?Ogm`050?ooo`3gmoL0oooo
0?Ogm`3oool00`3gmoL00`3emOD0moOg0?Ogm`070?Ogm`040?Gem@3gmoL0moOg0?ooo`<0moOg00<0
oooo0?Ogm`3gmoL02P3gmoLN0?oooa40moOg00<0lo?c0?Ogm`3gmoL01`3gmoL00`3oool0lo?c0?Og
m`020?Ogm`030??cl`3gmoL0moOg00H0moOg00<0oooo0?Ogm`3gmoL00P3gmoL30??cl`030?ooo`3g
moL0moOg00<0moOg0P3oool70?Ogm`050??cl`3oool0moOg0?Ogm`3oool00P3gmoL01@3oool0moOg
0?ooo`3gmoL0oooo00<0moOg00<0lo?c0?Ogm`3gmoL01`3gmoL0103clo<0moOg0?Ogm`3oool30?Og
m`030?ooo`3gmoL0moOg00X0moOg6`3oool001T0oooo4P3gmoL00`3oool0moOg0?Ogm`0<0?Ogm`80
oooo0P3gmoL0103emOD0moOg0?Ogm`3oool20?Ogm`040?ooo`3gmoL0moOg0?ooo`80moOg00<0mOGe
0?Ogm`3gmoL00`3gmoL00`3emOD0moOg0?ooo`020?Ogm`090?ooo`3gmoL0moOg0?Ogm`3emOD0moOg
0?Gem@3gmoL0oooo00<0moOg00<0oooo0?Ogm`3gmoL01P3gmoL00`3oool0mOGe0?Ogm`020?Ogm`03
0?ooo`3gmoL0oooo0080moOg00<0mOGe0?Ogm`3gmoL00`3gmoL00`3emOD0oooo0?Ogm`070?Ogm`03
0?ooo`3gmoL0oooo01d0oooo4P3gmoL00`3oool0moOg0?Ogm`0<0?Ogm`80oooo0P3gmoL0103clo<0
moOg0?Ogm`3oool20?Ogm`040?ooo`3gmoL0moOg0?ooo`80moOg00<0lo?c0?Ogm`3gmoL00`3gmoL0
0`3clo<0moOg0?ooo`020?Ogm`090?ooo`3gmoL0moOg0?Ogm`3clo<0moOg0??cl`3gmoL0oooo00<0
moOg00<0oooo0?Ogm`3gmoL01P3gmoL00`3oool0lo?c0?Ogm`020?Ogm`030?ooo`3gmoL0oooo0080
moOg00<0lo?c0?Ogm`3gmoL00`3gmoL00`3clo<0oooo0?Ogm`070?Ogm`030?ooo`3gmoL0oooo01X0
oooo000I0?ooo`h0moOg00@0oooo0?Ogm`3gmoL0mOGe303gmoL01@3emOD0moOg0?Ogm`3gmoL0mOGe
00<0moOg00<0mOGe0?ooo`3emOD00P3gmoL01P3oool0moOg0?Ogm`3gmoL0oooo0?Gem@80moOg00<0
mOGe0?Ogm`3gmoL01P3gmoL0103oool0moOg0?Ogm`3emOD40?Ogm`060?Gem@3oool0oooo0?Ogm`3e
mOD0oooo0`3gmoL01@3oool0moOg0?Ogm`3gmoL0oooo0080moOg00D0oooo0?Ogm`3gmoL0oooo0?Og
m`020?ooo`80moOg00@0oooo0?Ogm`3gmoL0mOGe1`3gmoL00`3oool0moOg0?Ogm`020?Ogmah0oooo
3P3gmoL0103oool0moOg0?Ogm`3clo<<0?Ogm`050??cl`3gmoL0moOg0?Ogm`3clo<00`3gmoL00`3c
lo<0oooo0??cl`020?Ogm`060?ooo`3gmoL0moOg0?Ogm`3oool0lo?c0P3gmoL00`3clo<0moOg0?Og
m`060?Ogm`040?ooo`3gmoL0moOg0??cl`@0moOg00H0lo?c0?ooo`3oool0moOg0??cl`3oool30?Og
m`050?ooo`3gmoL0moOg0?Ogm`3oool00P3gmoL01@3oool0moOg0?Ogm`3oool0moOg0080oooo0P3g
moL0103oool0moOg0?Ogm`3clo<70?Ogm`030?ooo`3gmoL0moOg0080moOg6`3oool001T0oooo4`3g
moL00`3oool0moOg0?Ogm`0@0?Ogm`070?Gem@3gmoL0moOg0?Ogm`3emOD0moOg0?ooo`030?Ogm`03
0?ooo`3gmoL0oooo00D0moOg00<0mOGe0?Ogm`3oool02`3gmoL00`3emOD0moOg0?Ogm`030?Ogm`80
mOGe00H0oooo0?Ogm`3gmoL0oooo0?Ogm`3emOD:0?Ogm`030?Gem@3gmoL0moOg00H0moOg00<0mOGe
0?ooo`3gmoL00`3gmoLN0?oooa<0moOg00<0oooo0?Ogm`3gmoL0403gmoL01`3clo<0moOg0?Ogm`3g
moL0lo?c0?Ogm`3oool00`3gmoL00`3oool0moOg0?ooo`050?Ogm`030??cl`3gmoL0oooo00/0moOg
00<0lo?c0?Ogm`3gmoL00`3gmoL20??cl`060?ooo`3gmoL0moOg0?ooo`3gmoL0lo?c2P3gmoL00`3c
lo<0moOg0?Ogm`060?Ogm`030??cl`3oool0moOg00<0moOg6`3oool001T0oooo4@3gmoL00`3oool0
moOg0?Ogm`090?Ogm`030?Gem@3gmoL0moOg00H0moOg0P3emOD30?Ogm`030?Gem@3oool0oooo0080
moOg00<0mOGe0?Ogm`3gmoL0103gmoL20?Gem@80moOg00T0oooo0?Ogm`3oool0moOg0?ooo`3gmoL0
oooo0?Ogm`3oool0103gmoL00`3oool0moOg0?Ogm`020?Ogm`030?Gem@3gmoL0oooo00H0moOg00H0
oooo0?Ogm`3gmoL0moOg0?ooo`3emOD40?Ogm`040?ooo`3gmoL0moOg0?ooo`L0moOg0P3emODN0?oo
oa40moOg00<0oooo0?Ogm`3gmoL02@3gmoL00`3clo<0moOg0?Ogm`060?Ogm`80lo?c0`3gmoL00`3c
lo<0oooo0?ooo`020?Ogm`030??cl`3gmoL0moOg00@0moOg0P3clo<20?Ogm`090?ooo`3gmoL0oooo
0?Ogm`3oool0moOg0?ooo`3gmoL0oooo00@0moOg00<0oooo0?Ogm`3gmoL00P3gmoL00`3clo<0moOg
0?ooo`060?Ogm`060?ooo`3gmoL0moOg0?Ogm`3oool0lo?c103gmoL0103oool0moOg0?Ogm`3oool7
0?Ogm`80lo?c6`3oool001T0oooo4`3gmoL00`3oool0moOg0?Ogm`080?Ogm`050?ooo`3gmoL0mOGe
0?Ogm`3emOD01@3gmoL00`3oool0moOg0?Ogm`040?Ogm`030?Gem@3gmoL0moOg00P0moOg00@0mOGe
0?Ogm`3gmoL0oooo0`3gmoL00`3oool0mOGe0?ooo`0:0?Ogm`030?ooo`3emOD0mOGe0080moOg00<0
mOGe0?Ogm`3gmoL0203gmoL00`3oool0moOg0?Ogm`0:0?Ogm`030?ooo`3gmoL0oooo01d0oooo4`3g
moL00`3oool0moOg0?Ogm`080?Ogm`050?ooo`3gmoL0lo?c0?Ogm`3clo<01@3gmoL00`3oool0moOg
0?Ogm`040?Ogm`030??cl`3gmoL0moOg00P0moOg00@0lo?c0?Ogm`3gmoL0oooo0`3gmoL00`3oool0
lo?c0?ooo`0:0?Ogm`030?ooo`3clo<0lo?c0080moOg00<0lo?c0?Ogm`3gmoL0203gmoL00`3oool0
moOg0?Ogm`0:0?Ogm`030?ooo`3gmoL0oooo01X0oooo000I0?oooa/0moOg00<0mOGe0?ooo`3gmoL0
0`3gmoL20?Gem@80moOg0P3oool70?Ogm`060?Gem@3gmoL0oooo0?Ogm`3emOD0oooo103gmoL02`3o
ool0moOg0?ooo`3gmoL0oooo0?Ogm`3emOD0moOg0?Gem@3gmoL0oooo0080moOg00/0mOGe0?Ogm`3o
ool0mOGe0?ooo`3gmoL0mOGe0?Ogm`3oool0moOg0?ooo`0@0?Ogm`030?Gem@3gmoL0moOg00X0moOg
7P3ooolK0?Ogm`030??cl`3oool0moOg00<0moOg0P3clo<20?Ogm`80oooo1`3gmoL01P3clo<0moOg
0?ooo`3gmoL0lo?c0?ooo`@0moOg00/0oooo0?Ogm`3oool0moOg0?ooo`3gmoL0lo?c0?Ogm`3clo<0
moOg0?ooo`020?Ogm`0;0??cl`3gmoL0oooo0??cl`3oool0moOg0??cl`3gmoL0oooo0?Ogm`3oool0
403gmoL00`3clo<0moOg0?Ogm`0:0?Ogma/0oooo000I0?ooo`l0moOg00<0oooo0?Ogm`3oool00`3g
moL00`3emOD0moOg0?Ogm`020?Ogm`030?ooo`3gmoL0moOg00<0moOg00D0mOGe0?Ogm`3emOD0moOg
0?Gem@050?Ogm`030?Gem@3gmoL0moOg00<0moOg00<0oooo0?Ogm`3gmoL00P3gmoL0103oool0moOg
0?ooo`3oool90?Ogm`030?ooo`3gmoL0moOg0080moOg00<0mOGe0?Ogm`3gmoL00`3gmoL00`3oool0
moOg0?ooo`020?Ogm`030?Gem@3oool0moOg0080moOg00<0oooo0?Ogm`3gmoL0103gmoL00`3emOD0
moOg0?Gem@0<0?Ogmah0oooo3`3gmoL00`3oool0moOg0?ooo`030?Ogm`030??cl`3gmoL0moOg0080
moOg00<0oooo0?Ogm`3gmoL00`3gmoL01@3clo<0moOg0??cl`3gmoL0lo?c00D0moOg00<0lo?c0?Og
m`3gmoL00`3gmoL00`3oool0moOg0?Ogm`020?Ogm`040?ooo`3gmoL0oooo0?ooo`T0moOg00<0oooo
0?Ogm`3gmoL00P3gmoL00`3clo<0moOg0?Ogm`030?Ogm`030?ooo`3gmoL0oooo0080moOg00<0lo?c
0?ooo`3gmoL00P3gmoL00`3oool0moOg0?Ogm`040?Ogm`030??cl`3gmoL0lo?c00`0moOg6`3oool0
01T0oooo3`3gmoL0103oool0moOg0?Ogm`3ooolC0?Ogm`030?ooo`3gmoL0moOg00L0moOg00H0oooo
0?Ogm`3gmoL0moOg0?Gem@3gmoL20?ooo`T0moOg0`3oool90?Ogm`<0oooo3@3gmoL0103oool0mOGe
0?Ogm`3emOD20?Ogm`040?ooo`3gmoL0oooo0?Gem@H0moOg7P3oool?0?Ogm`040?ooo`3gmoL0moOg
0?oooa<0moOg00<0oooo0?Ogm`3gmoL01`3gmoL01P3oool0moOg0?Ogm`3gmoL0lo?c0?Ogm`80oooo
2@3gmoL30?ooo`T0moOg0`3oool=0?Ogm`040?ooo`3clo<0moOg0??cl`80moOg00@0oooo0?Ogm`3o
ool0lo?c1P3gmoLK0?ooo`00o`3oool]0?ooo`00o`3oool]0?ooo`00o`3oool]0?ooo`00o`3oool]
0?ooo`00o`3oool]0?ooo`00<03oool2@0000180oooo0T00000L0?ooo`9000000`3oool3@00001X0
oooo0T00001P0?ooo`900000A03oool00340oooo00=000000?ooo`3oool04@3oool00d000000oooo
0?ooo`0K0?ooo`03@000003oool0oooo00<0oooo00=000000?ooo`3oool06@3oool00d000000oooo
0?ooo`1O0?ooo`03@000003oool0oooo0480oooo00080?ooo`=0000000<0oooo@000040000000P3o
ool00d000000oooo0?ooo`02@00000<0oooo0T0000000`3ooom00000@00000020?ooo`04@000003o
oom00000@00000<0oooo0d0000030?ooo`9000000`3oool00d000000oooo0?ooo`0A0?ooo`03@000
003oool0oooo00T0oooo0T0000020?ooo`=000002`3oool00d000000oooo0?ooo`030?ooo`05@000
003ooom00000@000003oool00T00000:0?ooo`900000103oool2@00000<0oooo00A000000?ooo`3o
ool0oooo0d0000030?ooo`900000;03oool3@00000030?oood000000oooo00=000000P3oool3@000
00<0oooo0T00000<0?ooo`900000103oool2@00000<0oooo00A000000?ooo`3oool0oooo0d000003
0?ooo`900000>@3oool000T0oooo00E000000?ooo`3oool0oooo@00000020?ooo`03@000003ooom0
00000080oooo00=000000?oood000000103oool014000000oooo0?oood0000030?ooo`05@000003o
ool0oooo0?oood0000000`3oool024000000oooo0?oood000000oooo@000003ooom000004@3oool0
0d000000oooo@00000090?ooo`04@000003oool0oooo@0000080oooo00=000000?ooo`3oool02@3o
ool00d000000oooo@00000040?ooo`06@000003oool0oooo@000003ooom000003@3oool014000000
oooo0?oood0000020?ooo`05@000003ooom000000?oood0000000`3oool01D000000oooo0?ooo`3o
oom0000002l0oooo00A000000?oood00001000000P3oool01d000000oooo0?ooo`3ooom000000?oo
od0000000P3oool00d000000oooo0?ooo`0>0?ooo`04@000003oool0oooo@0000080oooo00E00000
0?oood000000oooo@00000030?ooo`05@000003oool0oooo0?oood000000>`3oool000T0oooo00E0
00000?ooo`3oool0oooo@00000020?ooo`03@000003ooom0000000@0oooo0d0000020?ooo`04@000
003oool0oooo@0000080oooo00=000000?ooo`3oool00P3oool01D000000oooo0?ooo`3ooom00000
00@0oooo00=000000?oood0000004@3oool00d000000oooo@00000090?ooo`04@000003oool0oooo
@0000080oooo00=000000?ooo`3oool02@3oool00d000000oooo@00000040?ooo`03@000003oool0
oooo00=00000303oool01D000000oooo0?ooo`3ooom0000000@0oooo00=000000?oood0000000`3o
ool014000000oooo0?ooo`3oool3@00002d0oooo00A000000?oood00001000000P3oool00d000000
oooo0?ooo`030?ooo`04@000003oool0oooo@00000l0oooo00E000000?ooo`3oool0oooo@0000004
0?ooo`03@000003ooom0000000<0oooo00A000000?ooo`3oool0oooo0d00000i0?ooo`002@3oool0
0d000000oooo0?ooo`04@00000030?oood0000100000009000000P3oool3@00000030?oood000010
0000009000000`3oool2@0000080oooo0T0000020?ooo`A0000000@0oooo@00004000000oooo0T00
000?0?ooo`90000000<0oooo@000040000002@3oool2@0000080oooo0d0000090?ooo`90000000@0
oooo@00004000000oooo0d0000020?ooo`04@000003ooom00000@00000/0oooo0T0000000`3ooom0
0000@0000002@00000040?oood00001000000?ooo`9000000P3oool014000000oooo0?ooo`3oool3
@00002d0oooo0T0000001@3ooom000000?ooo`3ooom0000000@0oooo00E000000?ooo`3oool0oooo
@000000?0?ooo`90000000<0oooo@000040000000T000000103ooom00000@000003oool2@0000080
oooo00A000000?ooo`3oool0oooo0d00000i0?ooo`002@3oool00d000000oooo0?ooo`060?ooo`03
@000003oool0oooo01H0oooo00=000000?ooo`3oool0:03oool00d000000oooo0?ooo`0C0?ooo`03
@000003oool0oooo0100oooo00=000000?ooo`3oool0203oool00d000000oooo0?ooo`0a0?ooo`90
000000/0oooo@00004000000oooo@000003ooom000000?oood000000oooo@00000020?ooo`03@000
003ooom000000140oooo00=000000?ooo`3oool0203oool00d000000oooo0?ooo`0m0?ooo`00203o
ool3@00001`0oooo00=000000?ooo`3oool0;@3oool00d000000oooo0?ooo`0>0?ooo`03@000003o
ool0oooo00900000703oool2@0000380oooo0T0000000`3ooom00000@0000005@00000040?oood00
00100000@0000080oooo0d00000K0?ooo`900000?`3oool00?l0oooo;@3oool00?l0oooo;@3oool0
0?l0oooo;@3oool00?l0oooo;@3oool00?l0oooo;@3oool00?l0oooo;@3oool00?l0oooo;@3oool0
0?l0oooo;@3oool00?l0oooo;@3oool00?l0oooo;@3oool00?l0oooo;@3oool00?l0oooo;@3oool0
0380oooo0T00000j0?ooo`9000000P3oool3@00007`0oooo0T00000i0?ooo`00=03oool00d000000
oooo0?ooo`0h0?ooo`05@000003oool0oooo0?oood000000O`3oool00d000000oooo0?ooo`0f0?oo
o`009P3oool3@00000<0oooo0d0000030?ooo`=000001@3oool014000000oooo0?ooo`3oool2@000
00H0oooo00=000000?ooo`3oool0203oool3@0000080oooo00=000000?oood0000000`3oool2@000
00`0oooo0T0000030?ooo`04@000003oool0oooo0?ooo`=000000`3oool2@0000080oooo0T00000?
0?ooo`9000000P3oool3@00000T0oooo00E000000?oood000000oooo@00000020?ooo`90000000<0
oooo@000040000000P3oool00d000000oooo0?ooo`02@0000080oooo0d0000001`3ooom00000@000
04000000oooo@000003oool00d0000030?ooo`90000000H0oooo@000003ooom000000?oood000002
0?ooo`9000004P3oool3@00000070?oood000000oooo@000003ooom000000?ooo`04@0000080oooo
0d0000020?ooo`9000000P3oool2@0000300oooo000W0?ooo`03@000003oool0oooo00<0oooo00E0
00000?ooo`3oool0oooo@00000020?ooo`03@000003oool0oooo00T0oooo00=000000?ooo`3oool0
3`3oool02T000000oooo0?oood000000oooo@000003ooom000000?oood0000020?ooo`03@000003o
ool0oooo00P0oooo00Q000000?ooo`3ooom000000?oood000000oooo@0000080oooo00I000000?oo
o`3ooom000000?oood0000060?ooo`03@000003oool0oooo00/0oooo00A000000?ooo`3ooom00000
0P3oool00d000000oooo0?ooo`080?ooo`07@000003ooom000000?oood000000oooo@00000020?oo
o`03@000003ooom000000080oooo00=000000?oood0000000P3oool00d000000oooo@00000040?oo
o`04@000003oool0oooo@0000080oooo00E000000?ooo`3oool0oooo@00000020?ooo`90000000H0
oooo@000003ooom000000?oood00000E0?ooo`09@000003oool0oooo@000003ooom000000?oood00
0000oooo00=000000P3oool01T000000oooo0?oood000000oooo@00000H0oooo00=000000?ooo`3o
ool0;@3oool002L0oooo00=000000?ooo`3oool00`3oool01D000000oooo0?ooo`3ooom000000080
oooo00=000000?ooo`3oool0203oool00d000000oooo0?ooo`0@0?ooo`0:@000003oool0oooo@000
003ooom000000?oood000000oooo@0000080oooo00=000000?ooo`3oool0203oool00d000000oooo
0?ooo`020?ooo`03@000003ooom000000080oooo00E000000?ooo`3ooom000000?ooo`03@00000<0
oooo00=000000?ooo`3oool0303oool014000000oooo0?oood0000020?ooo`03@000003oool0oooo
00P0oooo00M000000?oood000000oooo@000003ooom000000080oooo00=000000?oood0000000P3o
ool00d000000oooo@00000020?ooo`03@000003ooom0000000@0oooo00A000000?ooo`3ooom00000
0P3oool01D000000oooo0?ooo`3ooom000000080oooo0T0000001@3ooom000000?oood000000oooo
00=000004`3oool024000000oooo0?oood000000oooo@000003ooom000000`3oool014000000oooo
0?oood0000020?ooo`03@000003ooom00000009000000`3oool00d000000oooo0?ooo`0^0?ooo`00
9`3oool2@00000<0oooo0T0000040?ooo`=000002`3oool00d000000oooo0?ooo`0?0?ooo`03@000
003oool0oooo0090000000<0oooo@000040000000P3oool2@00000X0oooo14000000103ooom00000
@000003oool6@0000080oooo0d0000030?ooo`9000003P3oool2@0000080oooo0d0000090?ooo`90
000000<0oooo@000003oool00P3oool2@00000030?oood0000100000009000000`3oool2@0000080
oooo0d0000020?ooo`=000000P3oool4@0000080oooo0T0000001@3ooom00000@000003ooom00000
0080oooo0d00000B0?ooo`9000000P3oool2@00000030?oood000000oooo0080oooo0T0000030?oo
o`=0000000@0oooo@0000400001000000`3oool2@00002l0oooo000W0?ooo`04@000003oool0oooo
@00001<0oooo00=000000?oood0000003`3oool01D000000oooo@000003ooom0000001@0oooo00=0
00000?ooo`3oool09`3oool00d000000oooo0?ooo`0R0?ooo`03@000003oool0oooo0740oooo000V
0?ooo`E000000P3oool00d000000oooo0?ooo`0?0?ooo`03@000003oool0oooo00h0oooo1D00000o
0?ooo`03@000003oool0oooo0200oooo0T00000Y0?ooo`03@000003oool0oooo04L0oooo003o0?oo
obd0oooo003o0?ooobd0oooo0000\
\>"],
  ImageRangeCache->{{{0, 299}, {149, 0}} -> {-0.124513, -0.0238147, 
  0.00752183, 0.00752183}, {{16.5, 143.125}, {145.813, 
  19.1875}} -> {-30.3128, -6.32728, 1.18168, 1.18168}, {{155.813, 282.438}, {
  145.813, 19.1875}} -> {-194.936, -6.32728, 1.18168, 1.18168}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["1.5 Color image",
  FontFamily->"Times New Roman",
  FontSize->16,
  FontWeight->"Bold"]], "Section"],

Cell[TextData[{
  StyleBox["\t",
    FontFamily->"Times New Roman",
    FontSize->10.5],
  StyleBox["In order to represent a color image in a list \
\[OpenCurlyDoubleQuote]sample\[CloseCurlyDoubleQuote], we have to use the two \
",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"],
  StyleBox["Mathematica",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox[" commands; one is the \[OpenCurlyDoubleQuote]RGBColor\
\[CloseCurlyDoubleQuote] function, which converts the numerical data \
representing the red, green and blue components into RGB color form. The \
other is the \[OpenCurlyDoubleQuote]RasterArray\[CloseCurlyDoubleQuote] \
function, which displays a color image from the RGB color data.\n\tAt first, \
we convert the numerical data in the list \[OpenCurlyDoubleQuote]red\
\[CloseCurlyDoubleQuote], \
\[OpenCurlyDoubleQuote]green\[CloseCurlyDoubleQuote] and \
\[OpenCurlyDoubleQuote]blue\[CloseCurlyDoubleQuote] into a RGB color form by \
means of the function \
\[OpenCurlyDoubleQuote]RGBColor\[CloseCurlyDoubleQuote]. Secondly, we draw a \
color graphics image by combining a set of display commands \
\[OpenCurlyDoubleQuote]Show\[CloseCurlyDoubleQuote], \
\[OpenCurlyDoubleQuote]Graphics\[CloseCurlyDoubleQuote], and \
\[OpenCurlyDoubleQuote]RasterArray\[CloseCurlyDoubleQuote].",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell[CellGroupData[{

Cell[TextData[
"rgbSample=Table[RGBColor[red\[LeftDoubleBracket]i,j\[RightDoubleBracket],\
green\[LeftDoubleBracket]i,j\[RightDoubleBracket],blue\[LeftDoubleBracket]i,j\
\[RightDoubleBracket]],\n\t{i,128},{j,128}];\n\
Show[Graphics[RasterArray[rgbSample],\n\t\
AspectRatio->Automatic],PlotLabel->\"Fig.4. Color graphics image\"];"], 
  "Input",
  CellLabel->"In[29]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00744048 0.0238095 0.00744048 [
[.5 1.0125 -83 0 ]
[.5 1.0125 83 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -144 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Fig) show
81.000000 12.812500 moveto
(.4) show
93.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(.) show
105.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Color) show
141.000000 12.812500 moveto
(graphics) show
195.000000 12.812500 moveto
(image) show
225.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
384 string
128 128 8 [128 0 0 128 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
EFEFF7F7EFE7F7F7F7F7F7F7EFEFF7F7EFE7EFEFE7EFEFE7F7F7F7EFEFE7F7EFE7EFCEB5EFCEB5\
EFCEB5EFCEBDEFD6C6EFCEBDEFCEBDEFCEBDEFCEBDEFCEBDF7EFE7F7E7DEC6846B
E7C6ADEFCEBDE7C6ADE7C6ADE7BDA5EFC6A5EFC6A5E7BD9CEFC6A5EFC6ADEFC6A5EFC6ADE7BDA5\
E7BDA5EFC6A5EFC6A5EFCEADEFCEADEFC6ADEFC6ADEFC6A5EFC6A5EFC6A5EFC6AD
EFB59CEFC6ADEFC6ADEFC6ADF7CEB5F7CEB5F7CEB5F7CEB5F7CEB5F7CEB5F7CEB5EFCEADF7CEB5\
EFC6ADEFC6ADF7C6B5F7CEB5EFC6ADEFC6ADEFC6ADEFC6ADEFC6ADEFC6A5EFC6A5
EFC6A5EFC6A5EFC6ADEFC6ADE7C6ADEFC6ADEFC6ADEFC6A5EFC6ADEFC6ADEFC6A5F7DECEF7EFE7\
F7DECECE946BE7BDA5E7BDA5EFC6A5EFC6A5E7BDA5E7BDA5E7BDA5E7C6ADE7C6AD
E7C6ADE7C6ADE7C6ADE7C6ADEFCEB5EFCEADEFC6B5EFCEADF7D6BDF7CEB5F7D6BDF7D6BDF7D6BD\
EFCEBDF7D6BDEFCEB5E7C6B5E7C6ADD6BDADD6BDADE7BDA5E7BDA5E7BD9CD6BDAD
EFDECEE7DEDEDEAD8CE7CEBDEFE7E7F7EFF7F7F7F7EFEFF7
EFEFF7F7EFF7F7EFF7EFEFE7F7EFE7F7F7F7F7F7F7EFEFF7EFEFF7F7F7F7F7EFE7EFEFE7EFCEBD\
EFCEBDEFCEBDEFCEBDEFCEBDEFCEBDEFCEBDEFCEB5EFCEB5EFCEB5F7E7DED6A58C
EFC6ADEFCEB5E7C6B5E7C6ADE7C6ADE7BDA5E7BDA5E7BDA5EFBD9CEFC6A5EFC6ADEFC6A5EFC6AD\
EFC6A5EFBD9CEFC6ADEFCEB5EFC6ADEFC6ADEFC6A5EFC6A5EFB59CEFBD9CEFC6A5
EFC6A5E7BDA5EFC6A5EFC6ADEFC6A5EFC6ADEFCEADF7C6B5EFC6ADEFC6ADF7CEB5EFC6ADEFC6AD\
F7CEB5EFC6ADEFC6ADEFC6ADEFC6ADEFC6ADF7C6B5EFC6ADEFC6ADEFC6A5EFC6A5
EFC6ADEFC6ADEFC6ADEFC6ADEFC6ADE7C6ADE7BDA5EFC6ADEFC6ADEFC6A5EFC6ADEFC6A5F7DECE\
F7EFE7D6AD84DE8473EFC6A5EFC6A5EFC6A5E7BDA5E7BDA5E7BDA5E7BDA5E7BDA5
EFC6A5EFC6ADEFC6ADEFC6ADEFCEADEFC6ADEFCEB5EFC6ADEFCEB5EFCEB5EFCEBDEFCEBDEFCEBD\
F7D6BDEFCEBDEFCEBDE7C6ADE7C6B5E7C6ADE7C6ADE7BDA5E7BDA5E7C6ADEFE7DE
EFE7E7E7BD9CE7BD94E7BDA5EFE7E7F7EFF7EFEFF7F7EFE7
EFEFE7EFEFE7EFEFE7F7EFE7EFEFF7EFEFF7EFEFF7F7EFE7EFEFF7EFEFF7F7F7F7F7F7F7F7EFF7\
EFCEBDEFCEB5EFCEB5EFCEB5F7C6B5EFCEB5EFCEB5EFC6B5EFCEB5F7DED6F7E7DE
C67B4AE7C6ADEFC6B5E7C6B5E7BDA5E7B59CE7BDA5EFC6A5EFC6A5EFC6A5EFC6ADEFC6A5EFC6AD\
EFC6A5E7BDA5EFB59CEFCEADEFCEADEFC6ADEFC6A5EFBD9CEFBD9CE7BD9CE7BD9C
E7B59CE7B59CE7B59CEFBD9CEFC6A5EFC6ADEFC6ADEFCEADEFC6ADEFC6ADEFC6ADEFC6ADEFC6A5\
EFC6ADEFC6ADEFCEB5F7CEB5F7CEB5EFCEADF7C6B5F7CEB5EFC6ADEFC6ADEFC6AD
EFC6ADEFC6ADEFC6ADEFC6ADEFC6ADEFC6A5EFC6ADEFC6ADEFC6ADEFC6ADEFC6ADEFC6ADEFC6A5\
EFCEBDF7EFE7F7DECEC68463E7BDA5E7BDA5E7BDA5EFC6A5E7C6ADE7BDA5E7BDA5
EFC6A5E7BDA5E7BDA5EFC6ADEFCEB5EFCEADEFCEB5EFCEADEFCEB5EFCEB5EFCEBDEFD6C6F7D6BD\
EFD6C6EFCEBDE7CEBDEFC6B5E7C6ADEFC6ADE7C6ADE7C6ADE7CEBDE7D6CEE7D6C6
EFE7DEE7D6C6E7BD9CE7BDA5E7DED6EFEFE7F7F7F7F7EFE7
F7EFE7EFEFF7F7EFF7F7F7F7EFEFF7F7F7F7F7F7F7EFEFE7F7F7F7F7F7F7F7EFE7EFEFF7F7EFE7\
EFEFE7EFEFE7F7D6BDEFC6B5EFCEB5EFC6ADEFC6ADEFC6ADEFC6ADEFC6ADF7E7DE
EFD6C6DEAD9CE7C6ADE7C6B5E7C6B5E7BDA5E7BDA5E7BDA5E7BDA5E7BDA5EFC6A5EFC6ADEFC6AD\
EFC6A5E7BDA5E7BDA5EFC6A5EFC6ADEFC6ADEFC6ADEFBD9CEFC6A5E7BD9CE7B59C
E7BD9CE7BD9CE7B59CE7B594E7BDA5EFC6A5EFC6A5EFC6ADEFC6ADEFC6A5EFC6ADEFC6A5EFC6A5\
EFC6A5EFCEADF7D6BDF7CEB5F7CEB5F7CEB5F7D6BDF7CEB5F7CEB5EFCEADF7CEB5
F7CEB5EFC6ADEFC6ADEFC6B5EFC6B5EFC6B5EFC6ADEFC6B5EFC6B5EFC6ADEFC6ADEFC6ADEFC6AD\
EFC6ADEFCEBDF7EFE7F7DECEDE8473EFC6ADEFC6ADEFC6ADEFC6ADEFC6ADEFCEAD
EFC6ADEFC6ADEFC6B5EFC6ADEFCEADEFC6ADEFCEB5EFC6B5EFCEB5EFCEBDF7D6BDEFD6C6EFD6C6\
EFCEBDEFD6C6EFC6B5EFC6B5E7C6B5EFCEB5E7C6B5EFE7E7E7D6CEE7D6C6EFE7DE
E7BD9CE7DED6E7C6ADE7BD9CEFE7E7EFE7E7EFE7E7F7EFE7
EFEFF7F7EFF7EFEFF7F7EFF7F7F7F7F7EFF7F7EFF7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7EFE7\
F7F7F7EFEFF7F7EFE7F7D6BDEFCEB5F7CEB5EFC6ADEFCEADEFC6ADF7CEB5F7E7DE
F7E7DEDEAD9CEFC6ADEFC6B5E7CEBDE7BDA5E7BDA5E7BDA5EFC6A5E7BDA5E7BDA5EFC6A5EFC6A5\
EFC6ADEFC6A5EFC6A5EFC6ADEFC6A5EFBD9CEFBD9CEFBD9CEFC6A5EFC6A5EFC6A5
EFC6A5EFC6A5EFBD9CE7B59CE7BD9CE7BDA5EFC6A5EFB59CEFB59CEFB59CEFC6A5EFC6ADEFC6AD\
EFC6ADEFC6ADEFC6ADF7CEB5EFC6ADEFC6ADF7D6BDF7D6BDEFC6B5F7CEB5F7C6B5
F7CEB5F7C6B5EFC6ADEFCEB5EFCEB5EFC6B5EFC6B5EFCEB5EFCEB5EFCEB5EFC6ADEFCEB5EFC6AD\
EFC6ADEFC6ADEFCEBDF7EFE7DEAD8CE7AD9CEFC6ADEFCEADEFCEADEFCEADEFC6AD
EFC6ADEFC6ADEFCEADEFCEB5EFCEADEFCEB5F7CEB5EFCEB5EFCEB5F7CEB5F7D6BDEFD6C6EFD6C6\
EFD6C6EFCEBDEFCEBDEFCEBDE7C6B5EFD6C6EFEFE7EFE7E7EFE7DEEFE7DEEFEFE7
E7CEBDF7DED6E7BD9CE7BD9CEFE7E7F7F7F7F7EFE7EFEFE7
EFEFF7F7EFF7EFEFE7F7EFF7EFEFF7F7EFE7F7EFF7F7F7F7EFEFE7F7EFF7F7EFF7EFEFE7F7F7F7\
F7F7F7F7EFF7F7F7F7F7EFF7EFDECEEFCEB5F7CEB5EFCEB5EFCEB5EFCEB5EFCEBD
F7E7DEEFE7DEEFC6ADEFCEB5EFCEB5E7C6B5E7C6ADE7BDA5E7BDA5EFC6A5E7C6ADEFC6ADEFC6AD\
E7BDA5E7BDA5EFC6A5E7BDA5E7B59CEFBD9CEFBD9CE7BD9CEFC6A5EFC6A5EFC6A5
EFC6ADEFC6A5EFC6ADEFC6ADEFB59CE7B59CE7B59CEFBD9CE7B59CEFC6A5E7BDA5EFC6A5EFC6AD\
EFC6ADEFC6ADEFC6ADEFC6ADF7C6B5F7CEB5F7CEB5EFC6ADEFCEBDEFCEB5EFCEB5
EFCEB5F7CEB5EFCEB5F7CEB5EFCEB5EFCEBDEFCEB5EFC6B5EFCEB5EFC6B5EFC6B5EFC6B5EFC6AD\
EFCEADEFC6ADEFC6ADEFCEBDF7EFE7E7BDA5E7AD9CEFC6ADEFCEB5EFCEB5EFCEAD
EFC6B5EFCEADEFCEADF7CEB5F7CEB5F7CEB5F7CEB5EFCEB5F7CEB5EFCEBDEFCEBDEFD6C6EFD6C6\
EFD6C6EFCEBDE7C6B5DEC6B5E7BD9CE7D6CEEFE7DEF7EFE7E7C6ADE7D6CEE7C6AD
EFCEBDEFE7E7E7BDA5E7D6CEF7EFF7F7EFF7F7EFF7EFEFE7
EFEFF7F7F7F7F7F7F7F7F7F7EFEFE7F7F7F7EFEFE7F7EFF7F7EFF7F7F7F7EFEFE7F7F7F7F7F7F7\
EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7EFE7EFD6C6EFD6C6F7D6BDEFD6C6F7D6BD
F7D6BDF7EFE7E7D6D6EFC6B5EFCEBDEFCEBDE7CEBDE7C6B5E7C6ADE7BDA5E7BDA5E7BD9CE7BD9C\
E7BDA5E7B594DEAD94E7B594E7B594E7B594E7BD9CE7B594EFC6A5EFC6ADEFCEAD
EFCEADEFCEADEFCEADF7CEB5EFC6A5EFC6A5E7B59CEFBD9CE7BD9CEFBD9CE7B59CE7BD9CE7BDA5\
EFB59CEFC6A5EFC6A5EFC6ADEFC6ADEFCEADEFC6ADEFC6ADEFC6ADEFC6ADEFC6AD
EFC6B5EFC6ADEFC6ADEFCEB5EFCEB5EFC6B5EFC6B5EFC6B5EFC6ADEFC6ADEFC6ADEFC6ADEFC6AD\
E7C6ADEFC6ADEFC6ADE7C6ADEFD6C6F7EFE7F7DECEE7C6ADEFC6ADEFC6ADEFC6AD
EFC6A5EFCEADF7C6B5F7CEB5F7CEB5EFCEB5F7CEB5EFCEB5F7D6BDEFCEBDEFD6C6EFD6C6EFD6C6\
E7C6B5E7C6ADDEAD9CCEAD94E7BDA5EFE7E7E7DED6EFEFE7E7C6B5E7CEBDEFCEB5
E7CEBDE7CEBDE7BD94EFE7E7F7EFF7F7EFE7F7F7F7EFEFF7
EFEFF7F7EFE7F7EFF7F7EFF7F7EFF7F7F7F7F7EFF7F7F7F7EFEFF7EFEFF7EFEFE7EFEFF7EFEFF7\
F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7EFF7EFEFF7F7DED6F7DECEF7DECEF7DECE
EFDECEEFDECEF7EFE7EFD6C6BD947BEFCEBDEFC6B5EFC6ADE7BDA5E7BDA5E7BDA5E7BDA5E7BD9C\
DEAD94DEAD94E7B594E7B594E7B594E7B594E7B594E7B594E7BDA5EFC6A5EFC6AD
EFCEADEFCEADEFCEADF7CEB5EFC6ADEFC6ADEFB59CE7B59CE7B594E7B594E7B59CE7BDA5E7B59C\
E7B594E7B594E7B59CE7BDA5E7BDA5E7BDA5EFC6A5E7BDA5E7BDA5EFBD9CE7BDA5
EFC6A5E7BDA5EFC6A5E7C6ADE7BDA5E7C6ADEFC6A5EFC6A5E7BDA5E7BDA5E7BDA5E7BDA5E7BDA5\
E7BDA5E7BDA5EFC6A5E7BDA5E7BDA5E7D6D6F7E7DEE7C6B5E7C6ADEFC6A5EFC6AD
EFC6ADEFC6ADEFC6ADEFCEB5F7CEB5EFCEB5EFCEB5F7D6BDF7D6BDEFCEBDEFCEBDEFCEBDE7C6AD\
E7BDA5D69C7BD6AD84CEAD94E7C6ADE7D6CEE7C6ADDEAD8CE7BDA5EFC6A5E7BD94
E7D6CEE7C6B5E7BD9CEFE7DEF7EFF7EFEFE7F7EFE7EFEFF7
EFEFF7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7EFEFF7F7EFE7F7EFF7F7EFF7F7F7F7F7EFF7EFEFF7\
EFEFE7F7F7F7F7EFF7F7F7F7F7F7F7EFEFF7F7F7F7EFEFF7F7F7F7F7EFF7F7EFF7
F7F7F7F7F7F7F7EFF7F7EFF7F7EFE7D6BDADE7C6ADEFC6ADE7C6ADE7BDA5E7BDA5E7BDA5E7B59C\
E7BD9CD6B5A5E7BD9CE7BD9CEFBD9CEFC6A5EFC6A5EFBD9CE7B594EFBD9CEFC6A5
EFCEADEFCEADEFCEADEFCEADF7CEB5EFCEADEFC6A5EFB594EFBD9CEFC6A5EFB59CEFBD9CEFBD9C\
E7BDA5E7BDA5E7B594E7B594DEAD8CDEAD94DEAD8CDEA584DEAD94DEAD8CDEAD8C
DEAD8CDEA584DEAD8CDEAD8CDEAD94DEAD94DEAD94DEAD94DEAD94DEAD94DEAD94E7BD9CE7B59C\
E7BD9CE7BD9CE7BD9CE7B59CE7B594E7BD9CDEAD94E7CEC6E7CEC6D6AD8CDE8473
DEAD94E7BDA5E7BDA5EFC6ADEFC6ADEFC6ADEFCEB5EFCEBDEFCEBDEFD6C6EFCEBDE7C6B5CE9463\
D69C73DEAD8CCEB5A5DEAD8CDEAD8CE7C6B5E7C6ADE7BDA5E7BD94E7BD9CE7DED6
E7CEBDE7BD9CE7D6D6EFE7DEEFEFF7F7EFF7EFEFE7EFEFE7
F7F7F7F7EFF7F7F7F7F7EFE7F7F7F7F7F7F7F7F7F7F7EFF7F7EFF7EFEFE7F7EFE7EFEFF7EFEFF7\
F7EFE7F7F7F7EFEFF7EFEFE7F7F7F7EFEFF7F7F7F7F7EFF7F7F7F7F7EFF7EFEFF7
F7F7F7F7EFF7F7EFF7F7EFE7F7F7F7EFEFF7E7BD9CD69C7BE7D6C6E7BDA5DEAD9CE7BDA5E7BDA5\
E7BD9CD6B5A5D6B5A5DEAD94E7B594E7BD9CEFBD9CEFBD9CE7B594E7BD9CEFC6A5
EFC6A5F7CEB5EFCEADF7CEB5EFCEADEFC6ADEFC6ADEFBD9CEFBD9CEFBD9CEFBD9CEFC6A5EFBD9C\
EFC6A5EFC6A5EFC6A5EFBD9CEFC6A5EFBD9CEFBD9CE7BD9CE7B59CE7BD9CE7B59C
E7B59CE7B59CE7BD9CE7B59CE7B59CEFBD9CE7BD9CEFBD9CE7BDA5E7BDA5EFC6A5EFC6A5E7B59C\
EFC6A5EFC6A5EFC6A5E7BDA5EFC6A5E7BDA5E7BDA5EFBD9CEFC6B5E7CEBDE7CEC6
E7BDA5945A31E7B59CDEAD9CE7BDA5E7C6ADE7C6ADE7C6B5D6AD8CC6845AC67B4AC67B4ACE8C5A\
DEAD8CE7BD94E7BDA5DEAD8CE7BD94E7BD9CE7BDA5E7CEBDE7C6ADDEAD8CEFD6C6
E7D6C6DEAD8CEFDECEE7DED6F7EFE7F7EFF7F7F7F7EFEFF7
EFEFE7EFEFF7F7F7F7EFEFF7F7EFF7EFEFE7EFEFF7F7EFF7F7EFF7F7F7F7EFEFE7F7EFF7F7F7F7\
F7F7F7F7EFF7F7EFF7F7EFF7F7F7F7F7EFF7F7F7F7F7EFF7F7F7F7EFEFF7F7EFF7
F7EFF7EFEFF7F7F7F7EFEFF7F7EFF7F7EFF7E7BD9CD69C73DEAD94CEAD94DEAD9CE7BD9CE7BD9C\
E7BD9CE7BD9CE7BDA5D6B5A5E7B594E7BD9CEFBD9CEFBD9CE7B594E7BD94EFC6A5
EFC6ADEFC6A5EFC6ADEFCEADEFCEADEFCEADEFCEADEFC6A5EFBD9CEFBD9CEFC6A5EFC6A5EFC6A5\
EFC6A5EFC6A5EFC6A5EFC6A5EFBD9CEFB59CEFC6A5EFC6A5EFC6A5EFC6A5E7BDA5
E7BD9CEFBD9CEFBD9CEFC6A5EFC6A5EFBD9CEFBD9CEFBD9CE7BDA5EFC6A5EFC6A5EFC6A5EFC6A5\
EFC6A5EFBD9CEFC6A5EFBD9CEFC6A5EFC6A5EFC6ADEFC6A5E7BDA5EFC6ADEFC6A5
E7CEBDDECEBDE7D6D6D6AD8CBD947BBD947BD6A584BD8C63C67B4ACE8C5AC67B4AC6845AD69C73\
D69C73E7BD94DEAD94D6AD84EFE7DEE7BD94E7BD94DEC6B5DEA57BEFCEBDEFDECE
E7BD9CE7DED6E7C6B5EFEFE7EFE7E7EFEFE7EFEFE7F7F7F7
F7F7F7EFEFF7F7EFE7F7F7F7EFEFF7F7F7F7F7F7F7EFEFE7F7EFE7F7EFE7F7F7F7F7EFF7F7F7F7\
EFEFF7F7F7F7EFEFF7F7EFF7F7EFF7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7
EFEFF7EFEFF7EFEFE7EFEFE7F7EFF7EFEFE7E7C6B5E7C6ADCE9463D6AD84D6AD84CE946BE7BD9C\
E7BDA5E7B59CE7BD9CDEAD9CE7BD94E7BD9CE7B594EFBD9CE7BD94E7BD94EFC6A5
EFC6A5EFC6A5EFC6ADEFC6ADEFCEADEFC6A5EFCEADEFC6A5EFC6A5EFBD9CEFBD9CEFC6A5EFC6A5\
EFC6A5EFC6A5EFC6A5EFC6A5EFC6A5EFC6A5EFB59CEFBD9CEFBD9CEFC6A5EFC6A5
EFC6A5E7BD9CEFBD9CE7BDA5EFB59CEFBD9CEFC6A5EFC6A5EFB59CEFC6A5EFC6A5EFC6A5EFC6A5\
EFBD9CEFBD9CEFC6A5E7BDA5EFC6A5E7BD9CEFC6A5EFC6A5EFC6A5EFC6A5E7BDA5
E7BDA5E7BDA5E7CEBDE7CEC6E7CEC6D6BDADAD6331AD6B39C6845AC67B4AC6845ACE9463CE9463\
CE946BCE9463CEAD94D6B5A5E7DED6D69C73DEAD84E7C6ADDEA57BE7C6B5E7D6C6
E7BD94EFEFE7EFE7DEEFEFE7EFEFE7EFEFF7EFEFF7F7F7F7
EFEFF7F7F7F7F7F7F7EFEFF7EFEFF7F7F7F7F7EFE7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7\
F7EFF7F7EFE7F7F7F7F7F7F7F7F7F7F7F7F7F7EFE7F7EFF7F7F7F7F7F7F7F7EFF7
EFEFF7EFEFF7F7EFF7EFEFF7EFEFF7EFEFF7E7CEC6E7C6B5D6AD8CCE9463D6AD84C67B42AD6B39\
DEAD9CE7BD9CE7B59CE7B59CE7BD9CE7B59CE7BD9CEFB594E7B594E7BD9CEFC6A5
EFC6A5EFC6A5EFC6A5EFC6A5EFCEADEFC6A5EFC6A5EFC6A5EFC6A5EFC6A5EFC6A5EFC6A5EFC6A5\
EFC6A5EFC6ADEFC6A5EFC6A5EFC6A5EFC6A5EFBD9CEFBD9CEFBD9CEFC6A5EFBD9C
EFBD9CEFC6A5E7BD9CEFB59CEFBD9CEFBD9CEFBD9CE7BD9CE7BDA5EFC6A5EFC6ADEFC6A5EFC6A5\
EFB59CEFC6A5EFC6A5EFBD9CEFBD9CEFBD9CEFC6A5EFC6A5E7BDA5E7BDA5E7BDA5
E7BD9CDEAD94D6A584D69C7BC67B4AB56B42C67B4AC67B42B57B5AC67B42CE9463CE8C5ACE9463\
CE946BDEAD84DEAD84DEAD8CE7C6ADDEA57BDEAD84E7BD94DEAD84E7D6C6E7C6AD
E7CEBDEFE7DEEFEFE7F7EFF7EFE7DEF7F7F7F7F7F7F7EFF7
F7F7F7F7EFF7EFEFF7F7EFF7F7EFE7F7F7F7EFEFF7F7F7F7EFEFE7F7F7F7EFEFF7F7F7F7F7EFE7\
F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7EFEFF7F7EFF7F7F7F7F7F7F7EFEFF7F7F7F7
F7EFE7EFEFE7EFEFF7F7F7F7F7EFE7EFEFF7EFDECEEFE7DEE7D6C6CE8C5ACE9463C67B42B56B39\
945229E7B59CDEAD9CE7BD9CDEAD94DEAD9CE7B59CE7BD9CE7BD94E7BD9CEFC6A5
EFC6A5EFC6A5EFC6A5EFC6A5EFC6ADEFC6A5EFC6A5EFC6A5EFC6A5EFC6A5EFBD9CEFBD9CEFBD9C\
EFBD9CEFC6A5EFBD9CEFC6A5EFC6A5EFC6A5EFBD9CEFBD9CEFBD9CEFBD9CEFBD9C
E7BD9CE7BD9CE7BD9CEFBD9CEFBD9CEFBD9CEFBD9CE7BD9CEFBD9CEFBD9CEFC6A5E7BD9CEFBD9C\
EFBD9CEFC6A5EFC6A5EFBD9CE7BD9CEFBD9CEFBD9CEFBD9CE7B594E7BD9CDEAD94
DEAD8CD69C7BCE9463B5734AB56B42C67B4ACE8C5ACE8C5AC6946BC6845AC67B42CE9463CE9463\
DEA573DEAD8CDEAD84E7BD9CDEAD8CD69C73DEAD84DEAD84E7C6ADE7C6ADE7C6AD
E7D6C6F7EFF7EFEFE7F7EFE7F7EFE7F7EFF7F7EFF7EFEFE7
EFEFF7F7EFF7F7F7F7F7EFF7EFEFE7F7F7F7F7F7F7F7F7F7F7EFE7F7F7F7F7EFF7EFEFF7F7F7F7\
EFEFF7F7F7F7F7F7F7F7EFE7EFEFF7F7EFF7EFEFF7F7F7F7EFEFE7F7F7F7F7EFF7
F7EFE7F7F7F7F7EFF7F7EFF7EFEFE7F7EFE7E7D6CEF7EFE7E7C6ADCE8C5AC67B4AC67B42B56331\
9452297B3918DEA584DEAD8CDEAD94E7BD9CE7B59CE7BD9CE7B594E7BD94E7BDA5
EFC6A5EFC6A5EFC6A5EFC6A5EFBD9CEFC6A5EFC6A5EFC6A5EFC6A5EFC6A5EFC6A5EFC6A5EFBD9C\
EFC6A5EFBD9CEFBD9CEFBD9CEFC6A5EFC6A5EFC6A5EFC6A5EFB594EFB594EFBD9C
EFBD9CEFBD9CEFBD9CEFB59CEFBD9CE7BD9CEFB594E7BD94E7BD9CEFB59CEFC6A5EFBD9CEFC6A5\
EFBD9CE7BD9CEFC6A5EFC6A5EFBD9CEFBD9CE7BD9CE7B594E7B594DEAD8CDEAD84
D69C73D69C73C67B4AAD6B39C6845ACE8C5AC67B4ACE8C5AD69C7BCE8C5AC6845ACE8C5ADEA573\
CE9463D6AD84D69C73CEAD94DEA57BE7BD94E7BD94E7BD94EFDECEDEAD8CE7C6B5
EFEFE7EFEFE7F7EFF7F7E7DEEFEFF7EFEFE7F7F7F7F7EFF7
F7EFE7EFEFF7EFEFF7F7EFE7EFEFF7F7F7F7EFEFE7F7EFE7EFEFE7F7F7F7F7F7F7F7F7F7F7EFE7\
F7F7F7F7EFE7F7EFE7F7F7F7EFEFF7F7F7F7F7EFF7EFEFF7F7F7F7EFEFF7F7EFE7
F7F7F7F7EFE7F7F7F7F7EFF7F7EFE7EFEFE7EFDECEEFE7DEE7C6B5D6BDADC67B42C6845AB56B39\
9452297B39187B3918DEAD94DEAD94E7B594DEAD94E7BD9CE7BD94E7B594EFC6A5
EFC6A5EFC6A5EFC6A5EFC6A5EFC6A5EFBD9CEFBD9CEFC6A5EFC6A5EFBD9CEFBD9CEFBD9CEFBD9C\
EFB594E7BD9CEFBD9CEFC6A5EFC6A5EFC6A5EFBD9CEFBD9CEFBD9CE7BD9CEFB594
E7BD94E7B594EFBD9CEFBD9CEFBD9CEFB594E7BD9CE7AD8CE7BD9CE7BD94EFBD9CEFBD9CEFBD9C\
EFBD9CEFBD9CEFBD9CE7BD94DEAD84DEAD84DEA57BD69C73D69C73D69C73D69C73
C6845A9C6339945229C67B4AD69C73CE9463AD6B42CE8C5ACE946BD6AD84DEA573DEA573CE8C5A\
CE8C5ACE9463D69C73DEAD8CDEA57BE7BD94E7BD94EFE7DEE7BD9CE7C6ADEFD6C6
EFE7E7EFE7DEEFE7E7F7EFE7F7EFE7EFEFF7F7F7F7F7EFF7
EFEFE7F7F7F7F7EFF7EFEFF7F7F7F7EFEFF7EFEFF7F7EFF7F7F7F7F7EFF7F7EFF7F7F7F7F7EFF7\
F7F7F7F7EFF7F7F7F7F7F7F7F7EFF7F7F7F7F7EFF7F7EFE7F7EFE7F7F7F7F7EFF7
EFEFF7EFEFE7F7EFF7F7EFE7F7EFF7EFEFE7F7EFE7E7DED6E7DED6D6AD84C6845AC67B4AAD6331\
9452298C42217B39186B3118DEAD8CE7B59CCEAD94E7BD94E7B594E7BD94EFBD9C
EFC6A5EFBD9CEFBD9CEFBD9CEFBD9CEFC6A5EFBD9CEFBD9CEFC6A5EFBD9CEFBD9CEFC6A5EFBD9C\
EFBD9CEFB594E7BD94EFBD9CEFBD9CE7BD9CEFC6A5EFBD9CEFB594E7B594EFB594
E7B594E7B594E7B594E7B594E7BD94E7B594E7B594E7AD8CE7AD8CE7AD8CEFB594EFBD9CE7AD8C\
EFBD9CDEAD84E7BD94E7B594E7AD8CDEA57BDEA57BD69C73CE946BC6845AB5734A
945229AD5A31AD6331C6845ACE9463CE9463C68C63D69C73D69C73DEA573D69C73D69C73DEA573\
CE8C5ACE9463DEA57BDEA57BDEAD84E7BD94E7BDA5E7BD9CE7C6ADE7D6C6EFE7DE
EFE7E7E7DED6EFE7E7F7EFF7F7EFF7EFEFF7F7F7F7F7F7F7
F7EFE7EFEFE7F7F7F7F7F7F7F7F7F7EFEFE7F7F7F7F7F7F7F7F7F7F7EFE7EFEFF7F7F7F7F7EFE7\
F7EFF7EFEFE7F7EFF7EFEFF7EFEFF7F7F7F7F7F7F7F7F7F7F7EFF7F7EFF7F7F7F7
EFEFF7EFEFF7F7EFE7F7EFF7F7EFE7EFE7E7EFE7DEE7CEBDEFDECECE8C5AC6845AC67B42AD5A31\
9452299452298C42216B31184A1808D6A584DEAD9CDEAD94E7B594E7B594E7BDA5
E7BD9CEFBD9CEFBD9CEFBD9CEFBD9CEFC6A5EFBD9CEFC6A5EFBD9CEFBD9CEFBD9CEFBD9CE7BD9C\
EFBD9CEFBD9CEFB594EFB594E7BD94EFB594EFBD9CEFBD9CE7BD9CE7BD94EFB594
E7B594EFB594E7AD8CDEAD84E7AD8CEFB594E7AD8CE7AD8CEFB594E7AD8CE7BD94E7B594E7AD8C\
DEAD84E7B594DEAD8CDEAD8CDEAD84DEA57BD69C7BCE8C63B5734AAD6B39AD6331
9C6339AD6B42BD8C63CE946BCE8C5AC68C63CE9463D69C73CE9463C6845AC6845ACE9463CE8C5A\
DEA573DEA57BDEA57BDEA573E7BD94E7BDA5E7BDA5E7C6ADEFE7DEEFE7DEEFDECE
EFE7E7F7EFF7F7EFE7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
EFEFE7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7EFE7F7EFF7F7F7F7F7F7F7F7EFF7EFEFF7EFEFE7\
F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7EFEFF7F7EFF7F7EFF7F7EFF7F7F7F7
F7EFF7F7EFF7F7EFF7EFEFF7F7EFE7F7EFF7EFE7E7E7D6C6E7DED6CE9463C6845AC67B4AAD6331\
9452299452298C42216329106329104A1808DEAD94DEAD94E7BD9CE7B59CE7BD9C
E7BD9CEFBD9CEFBD9CEFBD9CEFBD9CEFBD9CEFC6A5EFC6A5EFBD9CEFBD9CEFBD9CEFBD9CEFBD9C\
EFBD9CEFBD9CE7BD94E7BD94EFBD9CEFB594E7BD9CEFB594EFB59CE7B594E7B594
E7B594E7B594E7AD8CE7AD8CE7AD8CE7AD8CDEAD84DEA57BDEAD84E7AD8CDEAD84E7BD9CDEA57B\
DEAD8CDEAD84DEAD84D69C7BDEA584D69C73C67B4AAD5A31AD6B39844221AD6B42
B5734AC67B4ACE9463CE8C5AC68C63C6946BC68C63DEA573D69C73D69C73D69C73DEA573DEA573\
DEA57BDEAD84D6AD84E7BD94E7BD9CE7BDA5E7BDA5EFCEBDEFD6C6EFDECEEFE7DE
EFEFE7F7EFE7F7F7F7F7EFF7F7F7F7F7EFF7EFEFF7F7F7F7
F7F7F7F7F7F7EFEFE7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7EFF7F7EFF7EFEFE7F7EFF7F7F7F7\
EFEFF7EFEFE7F7EFF7F7EFF7F7F7F7F7F7F7F7EFE7F7EFF7F7F7F7EFEFF7EFEFF7
F7EFF7F7F7F7F7EFF7EFEFF7F7EFE7EFEFE7EFE7DEE7DED6E7CEC6CE9463C6845AB56B42AD6331\
9C63399452297B39186329105221106B3118DEAD94DEAD94E7B594E7BD9CE7BD9C
E7BDA5E7BD9CEFC6A5EFBD9CEFC6A5EFBD9CEFBD9CEFBD9CEFBD9CEFBD9CEFB594EFBD9CEFBD9C\
E7BD94EFBD9CEFB594E7BD9CEFB594E7B594E7B594E7AD8CE7B594E7B594E7B594
E7B594E7AD8CE7AD8CDEAD84DEA584DEA57BDEA57BDEA57BDEAD84E7BD9CDEAD84D69C7BD69C73\
D69C7BDE9C73DE9C73CE8C63CE8C63C67B42C67B4A8C4A31AD5A319C6339AD6B39
9C6339C67B4ACE8C5AC6845AC6845AC68C63D69C73D69C73D6AD84DEAD8CD69C73DEA573E7BD94\
D6AD84DEAD84E7BD94E7BD94E7BDA5E7BD9CEFCEBDEFD6C6EFD6C6F7EFE7F7EFE7
F7F7F7F7F7F7F7EFF7F7EFF7F7F7F7EFEFF7F7F7F7F7F7F7
F7F7F7F7EFF7F7EFE7F7EFE7F7EFF7EFEFF7F7F7F7F7EFE7F7F7F7F7EFE7EFEFF7F7F7F7F7F7F7\
F7EFF7F7F7F7F7EFE7F7F7F7F7EFF7F7EFF7F7EFF7F7F7F7EFEFF7EFEFF7F7F7F7
F7F7F7F7EFF7F7F7F7F7EFE7F7EFF7EFEFE7F7E7DEE7D6C6D6AD84CE9463C6845AB5734AAD5A31\
B56B399452298C4A296B31186B31187B42217B4A29DEAD9CE7BD94E7BD9CEFC6A5
E7BD9CE7BD9CEFC6A5EFBD9CEFBD9CEFBD9CEFBD9CEFBD9CEFBD9CE7BD9CEFBD9CE7BD9CE7B594\
EFB59CEFBD9CE7BD94EFB594EFB594E7BD94E7AD8CE7BD94DEAD84E7B594E7BD94
E7B594E7AD8CE7AD8CDEA584DEA584CE946BD69C73DEAD8CE7BD9CDEAD8CCE8C63CE946BD69C73\
CE946BD69C73CE946BC67B4AC67B42B56331AD6331C67B4AAD6B42C67B4AC67B4A
BD8C63CE9463CE946BC68C63CE8C5AC68C63D69C73CE8C5ACE946BD69C73D69C73DEA57BD69C73\
D69C73E7BD94E7BD94E7BD94E7BD9CE7CEBDEFD6C6EFE7DEEFE7DEF7EFF7F7F7F7
EFEFF7EFEFE7F7F7F7F7F7F7F7EFF7F7EFF7F7F7F7F7EFF7
F7F7F7F7F7F7EFEFF7F7F7F7EFEFF7F7EFF7F7EFF7F7F7F7F7F7F7F7EFE7F7F7F7F7F7F7F7F7F7\
F7F7F7EFEFF7F7EFF7F7F7F7EFEFF7F7EFF7EFEFE7EFEFF7F7F7F7EFEFF7F7EFF7
F7F7F7F7EFE7F7EFF7F7EFE7EFEFE7EFE7DEEFE7E7DECEBDD6AD84C6845AC6845AB56B42B5734A\
AD6B398C4A298C4A297B39188442218C4221632910DEAD94E7BD9CE7BDA5EFC6A5
E7BD9CE7BD9CEFBD9CEFB594E7BD94EFBD9CEFB594E7BD94EFBD9CEFBD9CE7BD94EFB594E7BD94\
EFB594EFB594EFBD9CE7B594E7B594E7B594E7BD94DEAD84EFB594DEAD84E7AD8C
DEAD8CDEAD84DEA584DE9C7BCE946BD69C73D69C73E7BD94E7BD9CCE8C63CE946BD69C73D69C73\
CE8C63B57B5AB56B529C6339C67B42B56B39AD6331AD6B39C67B42C67B4AB56B42
C6845ACE9463CE9463CE8C5AC6845AB5734AD6AD84CE9463D6AD84CE946BE7BD94D69C73DEA57B\
E7BD94E7BD94E7BD94E7BD94E7C6ADE7C6B5EFE7DEEFE7E7EFE7E7F7EFF7F7F7F7
EFEFE7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7
F7F7F7EFEFF7F7F7F7F7EFE7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7\
F7F7F7F7EFF7F7EFE7F7F7F7F7F7F7F7EFF7F7EFF7EFEFE7F7F7F7F7EFF7F7F7F7
EFEFF7EFEFF7F7F7F7F7F7F7F7EFE7EFE7DEEFE7DEDEAD94D6AD84C6845AB5734AAD6B429C6339\
9C63398C42218C4A299452299452297B39184A1808E7BD9CE7B594E7BDA5E7BD9C
EFBD9CE7BD9CEFBD9CEFB594EFB594EFBD9CEFB594EFB594EFB594EFB594EFB594EFB594E7BD94\
E7BD94EFB594E7B594E7BD94E7B594E7B594DEAD84DEAD84DEAD84E7AD8CDEAD84
DEAD8CDEAD8CDE9C7BD69C73CE8C63CE8C63DEAD84DEAD94CE8C63C68463C68463C68C63C68463\
B57B5AAD73528C5A42AD6B42C67B42B56B39B56B39B56B39B56B42AD6B42B56B42
C6845ACE9463CE946BBD8C63BD8C63CE9463D69C7BCE946BD69C73CE946BCE946BDEA573DEA573\
DEA57BE7BD9CE7BD9CE7BDA5EFD6C6F7EFE7EFE7DEEFE7E7EFEFE7F7F7F7F7F7F7
F7EFF7F7F7F7F7F7F7EFEFF7F7EFF7EFEFF7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7EFF7F7F7F7F7EFF7F7F7F7F7EFF7F7F7F7F7F7F7\
F7F7F7F7F7F7F7EFF7F7EFF7F7EFF7F7EFF7F7EFF7F7F7F7F7F7F7F7EFF7F7F7F7
EFEFF7F7F7F7F7F7F7F7F7F7EFEFF7EFE7DEE7D6CED6AD84D69C73BD8C63B57B5AB56B42AD6B42\
8C4A29844221945229945A318C4A296B39216B3118E7BDA5E7B59CEFC6A5E7BDA5
E7B594EFBD9CE7BD9CE7BD9CEFBD9CEFB594EFB59CE7BD94EFB594E7AD8CEFB594EFB594E7AD8C\
E7AD8CE7AD8CE7AD8CEFB594DEAD84E7AD8CDEAD8CDEAD84E7AD8CDEA57BDEA584
DEA57BD69C7BD69C73C6846BCE8C63CE9463D69C73CE946BC6845AC68463C6845AC6845AB57B5A\
9C63399C6B4A9C6B4AAD6B39CE8C5AC67B4AC67B42B56B39AD6B39BD8C63C67B4A
C6845ABD8C63CE8C5AC6946BD6AD84D69C73D69C73C6946BCE946BCE946BCE946BD69C73E7BD94\
E7BDA5EFC6A5E7BDA5EFD6C6EFDECEEFE7DEEFEFE7EFE7DEEFEFE7F7EFE7EFEFE7
F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7EFF7F7EFF7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7\
F7F7F7F7EFF7F7F7F7F7EFF7F7EFF7F7F7F7F7F7F7F7EFF7F7F7F7F7EFF7F7EFF7
F7EFF7F7EFF7F7EFF7F7EFE7EFEFF7EFE7DEE7D6C6D6AD8CCE946BC6845AB5734AAD6B42AD6B39\
945A31945229AD6B399452296B31186B3118632910E7BDA5E7B59CE7BD9CDEAD94
E7BD9CEFBD9CEFBD9CE7AD8CE7AD8CEFB594E7B594E7AD8CE7AD8CE7AD8CDEAD84E7AD8CE7AD8C\
DEAD84DEAD84E7AD8CDEA584E7AD8CDEA584DEA584DEA584DEA584DEA57BDEA57B
D69C73D69C73CE946BCE8C5AC68463D69C7BC68C63B57B5AB56B52C67B4AB5734AB57B5A946342\
B5734A9C7352AD6B39AD6B42C67B4ACE8C5AC6845AB5734AC67B4AB57B5AC67B4A
BD8C63B5734AC68C63C6946BD6AD84D6AD84D6AD84CE9463CE946BD6AD84CE9463D69C73E7BD94\
E7BD9CE7C6ADEFD6C6EFE7DEF7EFE7EFE7DEEFEFE7EFE7DEF7EFE7F7EFE7F7F7F7
F7F7F7F7F7F7F7EFF7EFEFF7F7EFF7EFEFF7F7EFF7F7F7F7
F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7EFF7F7EFF7
F7F7F7F7EFE7EFEFF7F7F7F7F7F7F7EFE7DEE7BDA5D69C73D69C73BD8C63B5734AAD6B42AD6B42\
8C4A299C63399452298442216329106B3921632910E7BD9CE7BD9CE7BD9CE7BD9C
E7BD9CE7B594EFBD9CE7BD94E7AD8CEFB594E7AD8CDEAD84E7AD8CDEAD84DEA584DEAD84DEA584\
DEAD84DEA584DEA584DEA584DEAD8CDEAD84DEA57BDE9C7BD69C7BDEA57BD69C7B
D69C7BD69C73CE946BC6845ACE946BCE8C63B57B5AB56B52B5734AAD6B42AD6B42945A319C6B4A\
9C6B4A9452299C6339B56B42CE8C5ACE8C5ACE8C5ACE946BC67B4AC67B4AB5734A
B5734ABD8C63C6946BC6845AD6A584D6AD84D69C7BC6946BD6AD84DEAD8CD69C73DEAD84E7BD94\
E7BD94EFD6C6F7DECEEFE7DEE7DED6EFE7DEEFEFE7F7EFF7F7EFF7F7EFF7F7F7F7
F7EFF7F7F7F7F7F7F7F7F7F7F7EFF7F7EFF7F7F7F7F7EFF7
F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7EFF7F7F7F7F7EFF7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7\
F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7EFF7EFEFE7
F7EFF7EFEFE7F7F7F7F7EFF7F7EFE7F7EFE7CEAD94D69C73C68C63C6845A9C63399C6B4A945A31\
9C4A319C63399C4A317B42216B39217B42216B3118E7BDA5DEAD9CE7BD9CE7B594
E7BD9CE7B594E7AD8CE7BD94E7AD8CE7AD8CE7AD8CDEAD84DEA584DEA584DEA584DE9C73DE9C7B\
DEA57BDE9C7BDE9C7BDEA584DEA57BDEA57BD69C73DE9C73D69C73D69C73D69C73
D69C73CE8C63CE8C63C6845ACE946BC6845AB5734AAD6B42AD6342AD6342946342AD6B429C6B4A\
945A31945A319C6339B56B39C67B42CE8C5AC6845ACE8C5AC6845ABD8C63B5734A
B5734AB56B42C6845AD69C73D69C7BD69C73D6AD8CD6AD8CD6AD84CE946BD69C73DEAD84E7BD9C\
E7C6B5EFDECEE7DED6EFE7DEF7EFE7EFEFE7EFE7DEF7EFF7F7F7F7F7EFF7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7EFF7
F7F7F7F7EFF7F7EFF7F7F7F7F7EFF7F7EFF7F7F7F7F7F7F7F7F7F7F7EFF7EFEFF7F7F7F7F7F7F7\
F7EFF7F7F7F7F7F7F7F7EFF7F7EFF7F7EFE7EFEFF7F7F7F7F7EFF7F7EFF7F7F7F7
F7F7F7F7EFF7F7F7F7EFEFE7F7EFE7E7D6C6D6AD8CD69C73C6845AB57B5AAD6B42B5734A945229\
9C63399C6339945A315A31216329106B31186B3921E7BD9CDEAD94E7B59CDEAD94
E7B594E7B594E7AD8CE7AD8CE7AD8CDEA584DEAD84DEA57BDE9C7BDEA57BDE9C7BDE9C7BDE9C73\
CE946BCE946BCE946BD69C73D69C73DE9C7BD69C73D69C73CE946BCE946BCE946B
CE8C63CE8C63C68463BD8C63B5734AAD6B42AD6B399C6339AD6342AD6B42AD6B429C63399C6339\
9C6339AD6331B56B39B56B42C67B42CE8C5ADEA573D69C73DEAD84C68C63AD6B39
AD6B39B5734AC68C63C6845AD69C73D6AD84D6AD84D6AD84CE9463CE9463CE9463E7BD94E7C6AD\
E7C6B5E7DED6EFE7DEEFDECEEFEFE7EFE7DEF7F7F7F7EFF7F7F7F7F7F7F7F7F7F7
F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7EFF7
F7EFF7F7F7F7F7F7F7F7EFF7F7EFF7F7EFE7EFEFF7EFEFF7F7EFF7F7F7F7F7F7F7F7F7F7EFEFF7\
F7F7F7F7EFF7F7F7F7F7EFF7F7F7F7F7EFE7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7EFF7EFEFF7F7EFF7F7EFE7F7EFE7E7BDA5D6AD84C6946BBD8C63B5734A9C63399C6B4A945A31\
AD6B398C4A298442215229185229186B31186B3118E7BD9CDEAD94E7B594E7B59C
E7B594E7AD8CE7AD8CDEA584DEA57BDEA57BDEA57BDEA57BDE9C73D69C7BD69C73DE9C73D69C73\
D69C73CE946BCE946BCE946BCE946BD69C73D69C73CE946BCE946BCE946BC68463
C68463C6845AB57B5AC6845AB56B429C6339945A31AD6B429C6339AD6B42AD6B427B42217B4221\
8C4A29B56331C67B42C67B42C67B42C6845ACE9463D69C73CE946BD6AD84BD8C63
B5734AC6845AC6845ACE946BC6845AD6AD8CD6AD8CCE946BCE9463CE946BCE9463E7BD94E7C6AD\
EFE7DEE7DED6EFE7DEEFE7DEEFE7E7EFEFF7F7F7F7EFEFE7F7EFE7F7F7F7F7F7F7
F7EFF7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7EFE7F7EFF7F7F7F7F7EFE7F7F7F7F7EFF7F7F7F7F7EFF7F7F7F7F7EFF7F7EFE7
F7EFF7F7F7F7EFEFE7F7EFF7E7DED6D6B5A5D6AD84BD8C63B57B5AAD6B429C6B4A945A31945A31\
9C63398C4A297B39186B31186B39216B39217B3918DEAD94DEAD94DEAD8CDEAD8C
E7AD8CDEAD8CDEA584DEAD8CDEA584DEA584D69C7BDE9C73DE9C73CE946BCE946BCE946BC6846B\
CE8C63CE8C63C6846BCE946BCE946BC6846BCE946BCE946BCE946BC68463C6845A
C68463C6845AB5734ACE8C5AAD6B428C4A299C6B4A9C6B4A9C6339945A318442217B4221632910\
AD6331C67B42B56331C67B42B56B42C67B4ACE9463DEA573D69C7BDEAD84BD8C63
BD8C63CE9463BD8C63CE946BC6946BD6AD84CE946BCE946BC6845ACE8C5ADEAD84E7C6ADEFD6C6\
EFDECEEFDECEE7DED6EFEFE7F7EFE7F7EFE7F7F7F7F7EFF7F7EFF7F7F7F7F7F7F7
F7F7F7EFEFF7F7F7F7F7EFF7F7F7F7F7EFF7F7F7F7F7F7F7
F7F7F7F7F7F7F7EFF7F7F7F7F7EFF7F7EFF7EFEFF7F7EFF7F7EFF7F7F7F7F7EFF7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7EFEFF7F7EFE7F7EFF7EFEFF7F7F7F7F7F7F7F7EFF7F7F7F7
F7F7F7EFEFF7F7EFF7EFEFE7E7C6B5D6AD8CC69C84B57B5AB57B5A9C6B4AAD63429C6339945A31\
945A316B39216B39216B31186B39216B39216B3921DEAD94DEAD8CDEAD94E7BDA5
E7AD94E7AD94E7A594E7AD94E7A594E7A594DEAD8CDEA584DEA584D69C7BCE8C63C6845ACE8C63\
C67B5AC6845AC6845AC6845AC6845ACE8C63CE8C63C6845AC6845AC6845AB57B5A
B57B5AB56B52B5734AC6845A9C63397B4A299C6339AD6B428C4A297B42217B39187B4A29945229\
AD5A31C67B42C67B42B5734AC67B42AD6B39CE9463D69C73D6AD84CE946BC6946B
C6845AC68C63C68C63BD8C63D6AD84D6AD84CE9463D69C73CE9463D6AD84D6AD84DEC6B5F7EFE7\
EFD6C6E7DED6EFEFE7EFE7E7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7EFF7
F7EFF7F7F7F7F7F7F7EFEFE7EFEFE7F7F7F7F7EFF7F7F7F7F7F7F7F7EFF7F7EFF7F7F7F7F7F7F7\
EFEFF7F7F7F7F7EFF7F7F7F7F7EFE7F7EFF7F7EFE7F7F7F7F7F7F7F7EFF7F7EFF7
EFEFF7EFEFF7EFEFF7EFE7DEDEC6B5D6AD84C6946BB57B5AB5734AAD6B429C6339B5734A9C4A31\
945A315221107342296B39216B39216B3118845231DEAD94E7C6ADEFC6ADEFC6AD
EFC6ADEFC6A5EFC6A5EFB59CEFB59CEFB59CE7AD9CE7AD94E7AD94DEAD8CDEA584D69C7BC67B5A\
C67B5AC67B4AC67B5AC67B5AB57B5AB57B5AB57B5AC6845AC67B5AB57B5AC67B4A
B5734AAD6B42AD6B42C67B4A8C4A298C4A319C63398C5A428442216B31186B3921AD6331844221\
9C6339C67B4AC67B42B5734AAD6B39B5734ACE8C5AD69C7BDEAD84DEAD8CD6AD84
C6946BC6946BB57B5AB56B42D6AD84D6AD84C6946BCE946BD6AD84D6AD84E7BD9CEFEFE7EFE7DE\
EFE7DEEFE7DEEFEFE7F7EFE7F7EFF7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7
F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7EFEFF7
F7F7F7F7EFF7F7EFF7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7EFF7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7EFEFE7F7F7F7F7EFF7F7F7F7F7EFE7
EFEFF7F7EFF7F7EFF7E7CEBDD6B5A5D69C73C68C63B57B5AAD7352945A319C6339945A319C6339\
8442216329107B42217342296B39216B3118B58463EFC6ADEFC6B5F7D6BDF7C6B5
F7C6B5EFC6ADEFC6ADF7C6B5EFC6ADEFC6ADEFB59CEFB59CE7B59CE7AD94DEAD8CDEA584DE9C7B\
CE946BC67B4AB5734AB57B5AC67B4AC67B4AC67B5AB56B52B57B5AC67B4AB57B5A
B5734AAD6B42946342B5734A945A319C6339B5734A8442217B39186B3118734A31B56B398C4221\
9C6339B56B42C67B4AB56B39AD6B39B5734AC6845ACE8C5ADEAD84DEAD8CD6AD84
D69C73C6946BB5734ABD8C63D69C73D69C73D69C73D69C73E7BD94D69C73E7BD9CEFEFE7EFDECE\
E7D6C6F7E7DEEFE7E7F7F7F7F7EFF7F7F7F7EFEFF7F7EFF7EFEFF7F7EFF7F7EFF7
F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7EFF7F7F7F7F7EFE7F7F7F7F7EFF7F7EFE7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7\
F7EFE7F7F7F7F7EFF7F7EFF7F7F7F7F7EFF7F7EFF7F7F7F7F7EFF7EFEFF7EFEFF7
F7EFE7F7EFF7F7EFF7E7CEBDCEAD94C6946BBD8C63AD7352AD6B42AD6B429C6339945A319C6339\
6329106B39217B4A296B39216B3921B58C73EFC6B5F7CEB5F7D6BDF7CEB5F7D6BD
F7C6B5F7D6BDF7C6B5F7CEB5F7C6B5EFC6ADEFC6A5EFC6ADEFB59CEFB59CE7AD94E7AD8CDEA584\
DEA57BD69C73CE946BB5734AB5734AB5734AB5734AC67B4AB5734AB57B5AB5734A
AD63429C6B4A845239844221B5734A945A31C6845A7B39186B3118522110632910AD6B39B56B42\
945229B56B42CE8C5AAD6B39BD8C63B5734AC6845AD69C73DEAD84E7BD94E7BDA5
D6AD8CB56B42BD8C63BD8C63CE946BC68C63D69C73D6AD8CD6AD84DEA57BEFE7E7EFDECEEFCEBD\
EFE7DEF7EFE7F7EFF7F7F7F7F7F7F7F7EFE7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7
F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7
F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7EFF7F7EFE7F7F7F7F7F7F7F7F7F7\
F7EFE7F7EFF7F7F7F7F7EFF7F7EFF7F7EFF7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7
EFEFF7EFE7E7E7D6C6E7C6ADC69C84C6946BB57B5A9C6B4A945A319C63399C6339945A31844A29\
6329107B4A297B4A296B3921E7C6B5F7CEB5EFCEADF7CEB5F7D6BDF7D6BDEFD6C6
F7D6BDEFD6C6F7C6B5F7C6B5F7C6B5F7CEB5EFC6ADEFC6A5EFC6A5EFC6A5E7BD9CDEAD94DEAD8C\
E7AD8CDEA584D69C7BCE946BB56B52AD6B42AD6B42B5734AAD6B42B56B52AD6B42
AD63429C63398442217B4221C6845A844221CE8C639C63396B3921734A31522110844221C67B4A\
8C4221B56B42C67B4AB56B39C6845AC6845AC6845ACE9463D69C73E7BD9CE7BDA5
D6AD84C68C63B57B5ABD8C63C6946BC6946BD6AD84D6AD8CD6AD84E7BD94E7DED6E7D6CEE7DED6\
EFEFE7EFEFE7F7F7F7F7EFE7F7F7F7F7EFF7F7F7F7F7F7F7F7EFF7F7EFF7F7F7F7
F7EFF7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7\
F7EFF7F7EFE7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7
EFEFE7EFE7E7DECEBDD6BDADBD947BBD8C63B57B5AAD6B429463429C6339945A31945A316B3921\
6B31187B42216B3921A5846BEFCEB5F7CEB5EFC6ADF7CEB5F7CEB5F7D6BDF7D6BD
F7D6BDF7D6BDEFD6C6F7D6BDF7C6B5F7C6B5EFC6ADEFC6ADEFC6ADE7BDA5E7B59CE7BD9CE7B594\
E7AD8CDEAD94DEA584D69C7BC6846BCE946BAD6342AD6342AD6B429C6B4AAD6342
9463429C4A31844A31734229C67B4AAD7352B57B5AB5734A6B31185221107B42219C6339C67B4A\
C6845AC67B4AC67B4AC6845AAD6B42C68C63BD8C63C6946BD69C73D6AD84E7BD9C
E7BD94BD8C63B5734ABD8C63C67B4AC6946BD6B5A5E7BD94CEB5A5D6AD8CE7C6ADEFE7DEF7EFE7\
F7EFE7F7EFF7F7F7F7F7EFF7F7F7F7F7EFF7F7F7F7F7EFF7F7EFF7F7F7F7F7F7F7
F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7
EFEFF7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7EFE7F7F7F7F7EFF7F7EFF7F7F7F7F7EFF7F7EFF7\
F7EFF7F7EFE7F7F7F7F7EFF7F7EFF7F7EFE7F7F7F7F7F7F7EFEFE7F7F7F7EFEFF7
EFEFE7E7DED6DECEBDCEAD94BD947BBD8C63B5734A9C6B4A845239945A318C4A29945A31522918\
6B39217342298C5A42EFC6ADEFC6B5F7CEB5F7CEB5F7CEB5F7CEB5F7D6BDF7C6B5
F7D6BDF7C6B5F7C6B5F7D6BDF7C6B5F7C6B5EFC6ADEFC6A5EFC6ADEFC6ADEFC6A5E7B59CE7B59C\
E7B594DEAD94DEAD8CDEA584D69C7BCE946BC6846B9C6339AD6342AD6342945A42
9C6339844A297B4A296329109C6B4AD69C7B8C4A29CE946B946342AD6B426B3118AD63318C4A31\
BD8C63AD6331C67B42C67B4ABD8C63B58463C6946BB57B5AD6AD84CE9463E7BDA5
EFCEB5BD8C63B5734ABD8C63C68C63C69C84D69C73D6AD84D6AD8CE7BD94E7DED6EFE7DEEFE7E7\
F7EFE7EFEFE7F7EFF7F7F7F7F7EFF7F7F7F7F7F7F7F7EFF7F7EFF7F7F7F7F7EFF7
F7EFF7F7F7F7F7EFF7F7EFF7F7F7F7F7EFF7F7F7F7F7F7F7
F7EFF7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7EFF7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7\
F7EFF7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7EFE7E7
EFE7E7E7CEBDDECEBDC69C84C68C63AD7352B5734A946342945A31945A318452316B39216B3118\
844A29845A42EFC6B5EFC6ADEFCEADF7CEB5F7CEB5F7CEB5F7C6B5EFCEADEFC6AD
EFC6ADEFC6ADEFC6ADEFC6ADEFC6A5EFB59CEFB59CE7BDA5EFC6A5E7BD9CEFBD9CE7B59CE7B59C\
DEAD8CE7AD8CDEAD94DEAD8CDEA584D69C73CE946BCE8C639C63399C4A319C6339
8C4A318C4A296B39216B3921845239BD8C63B57B5A9C6B4AC69C848C4221B57B5A945A31AD6342\
B56B42C67B4AAD6B39C67B4ABD8C639C6339BD8C63BD8C63D69C73D69C73CEAD94
DEAD8CE7BD94BD8C63B56B42BD8C63C69C84C6946BD6AD84E7BD94E7D6CEEFEFE7E7DED6EFEFE7\
F7EFE7EFEFE7F7F7F7F7EFF7F7EFF7F7F7F7F7EFF7F7F7F7F7F7F7F7EFF7F7F7F7
F7EFF7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7EFF7F7EFF7F7EFF7F7EFF7F7F7F7\
F7F7F7F7EFF7F7F7F7F7EFF7F7EFE7EFEFF7F7EFF7F7EFF7F7F7F7F7F7F7EFE7E7
E7D6CEE7CEBDCEB5A5BD947BB57B5AAD7352946342945A31945A31945A315A31216B39216B3118\
6B3118EFC6B5EFC6B5F7CEB5EFCEADEFC6ADEFC6ADF7C6B5EFC6ADEFBD9CE7B59C
E7AD94E7AD94DEAD8CDEAD8CDEAD8CDEA584DEAD8CDEAD8CDEAD8CDEAD8CE7B594E7B594E7B594\
E7B59CE7B594DEAD8CDEAD8CDEA584DE9C7BD69C7BD69C73CE8C63B56B52945A31
845231844A317342296B3921734A31946342CE946BBD8C63A57B5AD69C73C67B4AB57B5A844221\
AD6B39C6845AC67B42C67B4AAD6B39B57B5AB57B5AD69C7BC6946BD69C73D6AD84
E7BDA5E7C6B5BD8C63C6946BD69C7BC6946BC68C63CEAD94E7BD9CF7EFE7E7DED6F7EFF7EFEFE7\
F7EFE7EFEFE7F7F7F7F7F7F7F7EFF7F7F7F7EFEFF7F7EFF7F7F7F7F7EFF7F7EFF7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7
F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7EFF7F7EFF7F7EFF7F7F7F7F7F7F7F7EFF7F7EFF7EFE7E7
E7D6C6DECEBDD6AD8CC6946BB5734AB5734AAD63428C4A31945A318452316B31186B3921844A29\
E7C6B5EFCEB5EFCEB5F7CEB5EFCEADEFC6ADEFC6ADEFC6A5E7BDA5E7AD94E7AD8C
DEA584DE9C7BE78C7BE78C7BE78C7BE78C7BE78C7BDEA584DE9C7BDEA584DEAD8CDEA584E7B594\
E7B594E7B59CDEAD94DEAD8CDEA584D6A584D69C7BCE946BCE946BC684638C5A42
8442297B4A296B39215229186B39218C634ACE946BAD7352945A31D6A584C67B4ACE9463B57B5A\
9C6339AD6B42CE8C5AC67B4AB5734ABD8C63B57B5AD69C73C6946BD6AD84D69C73
D6AD84E7C6ADD6AD84D69C73C69C84C69C84D69C73D6AD8CE7BDA5EFE7DEEFE7DEF7EFE7EFEFE7\
F7EFF7F7F7F7F7EFF7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7
F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7EFF7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7EFE7F7EFE7F7F7F7F7EFF7EFEFE7E7D6CE
E7CEBDDECEC6C69C84B57B5AAD73529C6339AD6342845239844A296B39216B39217B39187B4A29\
EFC6B5EFC6B5EFC6ADEFC6ADEFC6ADEFC6ADEFC6A5EFB59CDE7363CE6B5ADE7B6B
DE7B6BDE8473DE8473DE8473DE8473DE8473CE6B5ACE6B5ACE6B5ACE6B5AD69C7BDEAD8CDEAD8C\
E7B594E7B594E7B594DEAD94DEAD8CDEA584D69C7BD69C7BCE946BC6846BC6845A
7B4A296B39216B31185221106B3118845239AD7352D69C7BB58463C6846BD6AD84CE9463D69C73\
C6946BC67B4AB5734AC6845ABD8C63AD6B39B5734ABD8C63D69C73BD8C63DEAD84
D6AD8CE7BD94E7BDA5C69C84D6AD84C6946BD69C73E7BD94DECEBDE7D6CEEFE7E7EFEFE7EFE7E7\
EFEFE7F7EFE7F7F7F7EFEFF7F7EFF7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7EFF7
F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7
F7F7F7F7EFF7F7F7F7F7EFF7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7\
F7EFF7F7EFE7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7EFE7F7F7F7EFE7E7E7DED6
E7D6C6D6AD8CC6946BA57B5A9C6B4A9C6339945A317B4A298452397342296B39217B4A29EFCEBD\
EFC6B5EFC6ADEFC6ADEFC6A5EFCEADEFC6ADE78C7BDE8473DE8473DE8473EFC6B5
EFB59CE78C7BE78C7BE7A594EFB59CDE8473DE8473DE7B6BC6846BCE7363CE6B5AD69C7BDEAD8C\
DEAD94E7B594E7B59CDEAD94DEAD8CDEAD8CD6A584D69C7BCE946BDE8473C68463
B57B5A734A31522918522918522110845239522918D6A584DEAD8C9C6339D6AD8CB57B5ADEA57B\
D6AD84BD8C63C6845ACE9463AD6331C6845AB57B5ABD8C63C6946BCE946BD69C7B
D6AD8CE7BDA5E7C6B5BD947BB58463C6946BD69C73CEAD94EFE7DEEFE7DEEFEFE7EFEFE7EFE7DE\
F7F7F7F7F7F7EFEFF7F7EFF7F7EFF7F7F7F7F7EFF7F7F7F7F7EFF7F7EFF7F7F7F7
F7F7F7F7EFF7F7F7F7F7F7F7F7EFF7F7EFF7F7F7F7F7EFF7
F7EFF7F7F7F7F7EFF7F7F7F7F7EFF7F7F7F7F7EFF7F7F7F7F7EFF7F7EFF7F7F7F7F7EFF7F7EFF7\
F7EFF7F7EFF7F7EFF7F7EFF7F7EFE7F7F7F7F7F7F7EFEFF7F7F7F7E7D6D6DECEBD
CEAD94C6946BB58463A57B5A845239945A318C4A31945A316329106B39216B3921A5846BEFCEB5\
EFCEB5EFCEB5EFC6ADEFC6A5EFC6A5EFC6A5DE7B6BDE8473DE8473DE7B6BDE7363
DE7363DE7363DE8473CE6B5ACE6B5AC65A4AC6634AC6634AE78C7BCE7363CE7363C65A4AD6A58C\
E7AD94E7B594E7B594E7B594E7B594DEAD8CD6A584D69C7BD69C7BCE946BCE946B
C6845AAD73526B39216B39213918106B31188C5A42B58463C6946BB57B5ABD8C63D6AD84C6845A\
DEAD84EFCEADBD8C63B5734AC6845AC6845AAD6B42B57B5ACE9463C6946BD69C73
D69C73E7BDA5E7BDA5C69C84C6946BC69C84BD947BCEAD94EFE7DEEFE7E7F7EFE7EFE7E7EFE7E7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7EFF7F7F7F7F7EFF7F7EFF7F7EFF7F7F7F7F7EFF7F7EFF7\
F7EFF7F7F7F7F7F7F7F7EFF7F7EFF7F7F7F7F7EFF7F7EFF7F7EFF7E7D6CED6C6B5
D69C73C6946BAD73529463428C4A31945A31844A296B31187B42216B3118945A31EFCEBDEFCEBD\
EFCEB5EFC6ADEFC6ADEFC6A5E78C7BDE8473AD73529C4A31AD4A31BD5242AD7352
BD5242BD5242C65A4AB552399C4A319C31219C4229AD4A318C3121AD42319C4229844229945A42\
DE8473E7B594E7B594E7B594DEAD8CDEAD8CDEAD8CD69C7BD69C7BD69C73D69C7B
C68463B57B5A8C5A424A18083918106B3921734A31845A42BD8C63D6A584945A31D6A584B57B5A\
D69C7BE7BD9CEFCEADCE946BCE946BB56B39C6845AB57B5ABD8C63C68C63B57B5A
D6AD84E7BD94E7BDA5D6BDADD69C73D6AD84C69C84D6B5A5E7DED6EFEFE7EFE7DEEFEFE7F7EFF7\
EFEFE7F7F7F7F7F7F7F7EFF7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7EFF7F7F7F7F7F7F7
F7EFF7F7EFF7F7EFF7F7F7F7F7F7F7F7EFF7F7EFF7F7F7F7F7EFF7F7F7F7F7EFF7F7F7F7F7EFF7\
F7F7F7F7EFF7F7EFF7F7EFF7F7EFF7F7EFF7F7EFE7F7EFF7EFE7E7E7D6CED6BDAD
BD947BB57B5A9463428C4A318C5A428C4A297B4A297B4A297B4A29844229EFCEBDEFCEBDEFC6B5\
EFCEB5F7CEB5EFC6ADEFC6A5EFB59CEFC6A5E78C7BCE7363CE6B5AC6634ACE6B5A
C6634ACE6B5ADE7B6BC6634AC6634AC6634AC6634AC6634AC6634AD69C73D6A584D6A58CDEAD8C\
DEAD8CE7B594E7B594E7AD8CE7AD8CDEAD8CE7AD8CDEA584D69C7BD69C7BD69C73
CE946BC684639C73525A39293918103918105A3929845A429C7352D69C7BC6946B9C6B4AD69C73\
B57B5AE7BD9CE7BD9CEFCEB5AD7352C6845AC6845AB57B5ABD8C63BD8C63B57B5A
D6AD84D6AD84E7BDA5E7C6ADC6946BD6AD84D69C73E7D6C6EFE7E7EFE7E7EFE7DEEFE7DEF7EFF7\
F7EFF7F7EFF7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7EFF7
F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7
F7F7F7F7EFF7F7EFF7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7EFF7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7EFE7F7F7F7F7EFF7EFEFE7F7EFE7EFE7DEDECEC6D6AD8C
B584639C6B4A9C6B4A8C5A428C4A29844A297342297B4A29844221845231EFCEB5EFC6ADEFCEB5\
EFCEADEFC6ADEFCEADEFC6A5EFCEADF7CEB5F7CEB5F7D6BDEFD6C6EFC6B5EFC6AD
F7D6BDEFC6ADEFC6A5F7CEB5F7D6BDEFC6B5EFC6ADE7BDA5E7B59CE7BDA5E7B59CE7B594E7B594\
E7B59CE7B594E7B59CE7B594E7AD94DEAD8CDEAD8CDEA584DEA584D69C7BD69C73
CE946BCE946BB57B5A845231423129291008845A42734A31845A429C7352BD8C639C6339C6845A\
AD6B42C6845AE7BD9CE7BD9CD69C73CE946BBD8C63B5734AB5734ABD8C63CE946B
D69C73CE946BE7BDA5E7C6ADC69C84C69C84C68C63E7DED6EFE7DEEFE7DEEFE7E7EFE7DEF7F7F7\
F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7
F7EFF7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7
F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7EFF7\
F7EFF7F7F7F7F7F7F7F7EFF7F7EFE7F7EFF7F7EFF7EFE7E7DEC6B5E7BD9CC69C84
AD7352946342845231845231844A316B31187B4A297B4A297B4221D6B5A5EFCEB5EFCEB5EFCEB5\
F7C6B5F7CEB5EFC6ADF7CEB5EFC6ADF7CEB5F7CEB5F7D6BDF7CEB5F7D6BDF7CEB5
F7D6BDEFC6A5EFC6ADEFC6ADEFC6ADE7B59CE7B59CE7B59CE7B59CE7BD9CE7B59CE7BD9CEFC6A5\
E7B59CE7B594E7BD9CE7B59CE7AD94E7AD94DEAD8CDEA584DEA584D69C7BDE8473
CE946BCE946BB57B5A945A42522110422118734A31845231A5846B9C7352C69C849C6339945A31\
C68C63BD8C63DEAD94E7BD9CEFC6A5D6AD84C6845AC6845AC68C63B5734AB57B5A
B57B5ACE946BE7BDA5E7C6ADD69C73D6AD8CC6946BEFE7DEEFE7E7E7DED6EFE7DEF7EFE7F7F7F7\
F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7EFF7F7EFF7F7EFF7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7
F7EFF7F7F7F7F7EFF7F7EFF7F7EFF7F7EFF7F7F7F7F7EFE7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7\
F7F7F7F7EFF7F7F7F7F7EFF7F7EFF7F7EFE7F7EFF7F7EFF7DECEC6C69C84B57B5A
9C63399C6B4A844A29844A316B39217B4A297B4A297B4A297B4A29EFCEB5EFCEB5EFC6B5EFCEB5\
F7CEB5F7C6B5F7C6B5F7CEB5EFCEB5F7CEB5F7CEB5F7CEB5F7CEB5F7CEB5F7CEB5
EFCEB5EFC6ADEFC6A5EFC6A5EFC6A5E7B59CE7BD9CEFBD9CE7B59CE7BDA5E7B59CEFC6A5E7B59C\
EFC6A5E7B59CE7B59CE7AD94E7AD94E7B594DEAD8CDEA584DE9C7BDEA584D69C73
CE946BCE946BC684639C6B4A7342295A39293918107352428452399463429C6339AD73529C6339\
B57B5AA57B5ACE946BE7BD94E7BD94CE946BD69C73C6845ABD8C63B5734ABD8C63
B5734AD69C73D6AD84E7BDA5CEAD94C6946BD69C7BE7D6CEEFE7DEEFE7DEE7D6C6F7F7F7F7EFF7\
F7F7F7F7F7F7F7EFF7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7
F7F7F7F7F7F7F7EFF7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7EFF7F7F7F7F7EFF7F7EFF7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7EFF7F7EFE7DECEC6D6C6B5BD947BB5734A
9C6B4A844A298C5A426B39217B4A296B31187B4A29844A296B3921EFCEB5EFC6B5EFC6B5EFCEB5\
F7CEB5F7CEB5F7CEB5F7C6B5F7CEB5F7CEB5F7CEB5F7CEB5EFCEB5F7CEB5F7CEB5
EFC6A5EFC6A5E7B59CEFC6A5E7B59CE7AD8CE7B594E7BD9CE7B59CEFB59CEFBD9CEFC6A5EFB59C\
EFB59CEFC6ADEFC6A5E7B59CE7B59CE7AD94E7AD8CDEA584DEA584D69C7BD69C73
DE8473C6846BC68463B5734A734A31522110522918734A318C634A946B529C7352B584639C6B4A\
8C5A42946342BD947BC68C63DEA573EFC6A5D6AD84C67B4AC68C639C6B4AC6946B
BD8C63D69C7BD69C73E7BDA5CEAD94BD8C63E7C6B5E7D6C6EFE7E7EFE7E7EFE7E7F7EFF7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7
F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7\
F7F7F7F7EFF7F7EFF7F7EFF7F7F7F7F7F7F7EFE7E7DEC6B5C6A594BD947B9C6B4A
9C63399463428442297B4A297B4A29734A317B4A296B3921B58463E7C6B5EFC6B5EFC6B5F7CEB5\
F7CEB5F7CEB5F7CEB5F7D6BDF7CEB5EFCEB5F7CEB5F7CEB5F7CEB5EFC6ADEFC6AD
E7B59CDEAD8CDEA584E7AD94DEAD94DEA584DEAD8CE7AD94E7B594E7B59CEFBD9CE7BDA5EFC6A5\
EFC6ADEFC6ADEFB59CEFB59CE7B59CE7AD94DEAD8CDEA584DEA584D69C7BD69C7B
D69C73CE946BC67B5AB56B528C5A425A39296B39215A4239845A428452399C7352946342B5734A\
8452319C6339845239D6AD8CE7BD94D69C73DEA57BC68C63C6946BA57B5AB57B5A
BD8C63C69C84D69C73E7BD9CD6B5A5C6946BE7DED6E7BDA5F7EFF7EFE7E7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7
F7EFF7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7
F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7EFF7F7EFF7F7F7F7F7F7F7F7EFF7\
F7F7F7F7F7F7F7F7F7F7EFE7F7F7F7F7EFF7F7EFF7E7BD9CBD947BAD7352946342
8C4A318C4A317B4A296B39216B39217B4A297B4A296B3118E7C6B5EFC6B5EFC6B5F7C6B5F7CEB5\
F7CEB5F7CEB5F7CEB5F7CEB5F7CEB5EFCEADF7CEB5F7CEB5F7CEB5EFC6ADEFB59C
E7AD9CE7B594DE9C7BDEA584DEA584D69C7BD6A584DEAD8CDEAD8CE7B594E7B59CEFBD9CEFB59C\
EFC6A5EFC6A5EFC6A5EFB59CEFC6A5EFB594E7AD94DEAD8CDEA584D69C7BD69C7B
D69C73C6846BC68463B57B5A945A425A3929291008422921734A318452319C6B4A845239B5734A\
9C63399C63397B4A29D6A584C6845AD69C73EFCEADC6946BC68C63C68C63B57B5A
B58C73C6845AC6946BE7BD9CD6BDADD6BDADDECEBDE7D6CEE7D6CEE7CEC6F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFE7E7D6AD8CB58463946342845231
8C4A316B39217B4A297342297B4A298442296B31185A3121EFC6B5E7C6ADEFC6ADEFC6ADF7CEB5\
F7C6B5F7D6BDF7D6BDF7CEB5F7CEB5F7CEB5F7C6B5EFD6C6DE9C7BDE7B6BEFC6AD
EFC6ADEFB59CE7A594B56342B56342C6846BDE9C7BB57B5AD69C73DEAD8CE7B59CEFC6A5EFC6A5\
EFC6ADEFC6ADEFC6ADEFC6A5EFB59CE7B59CE7AD94E7AD8CDEA584DEA584D69C7B
D69C73CE946BC68463B56B52AD63427342293918104229215A3121734A31845239845A429C6B4A\
9C6B4A8452319C6B4A8C5A42BD8C63DEAD84D69C73DEAD84C6845ABD8C639C6339
B57B5AB57B5AD69C73E7BD94D6BDADEFE7E7CEAD94EFE7E7D6B5A5F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7
F7EFF7F7EFF7F7F7F7F7EFF7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7EFF7F7F7F7F7EFF7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7E7DEDEC6946BAD73529463429C6339
7B4A297B4A296B39217B42217B4A296B39215A3121845239EFC6B5EFC6ADEFCEB5F7CEB5F7D6BD\
F7CEB5F7C6B5F7D6BDF7C6B5F7CEB5EFCEADF7CEB5F7D6BDEFCEB5EFC6B5F7C6B5
F7C6B5EFC6ADE7B594DEAD8CDEAD94E7AD8CE7B594DEA584CE8C63D69C7BE7B59CEFC6ADEFC6AD\
EFC6ADEFC6ADEFC6ADEFB59CEFC6A5EFC6A5EFB594E7AD8CDEAD8CDEA584D69C7B
CE946BCE946BC68463C67B5A9C73528C5A422910083918104229215A42397352428C5A42845239\
9C7352845231945A31522918D6AD84CE8C63CE9463E7BD9CB57B5ABD8C639C6B4A
AD7352BD8C63C6946BCEAD94DEC6B5DEC6B5C6AD9CD6B5A5F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7EFF7F7EFF7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7EFF7F7EFF7F7F7F7F7F7F7\
F7F7F7F7F7F7F7EFE7F7F7F7F7F7F7F7F7F7E7D6CEBD8C63946342945A426B3921
734A31844A317342297B4A29844A31632910632910A57B63E7C6ADF7C6B5F7C6B5F7C6B5EFD6C6\
F7D6BDF7D6BDF7D6BDEFD6C6F7CEB5F7CEB5F7C6B5F7D6BDEFC6B5EFD6C6EFD6C6
EFD6C6F7C6B5EFC6A5E7B594E7AD9CE7AD9CDEAD94DEAD8CDEA584DEA584EFB59CEFC6ADEFC6AD\
F7C6B5EFC6ADEFC6ADEFC6ADEFB59CEFB59CEFB59CE7B594E7AD8CDEAD8CDE9C7B
DE8473DE8473C68463B57B5AAD6B42946342291008422118391810734A31845239946342734229\
9C6B4A845231945A315A3121C6946BBD8C63D6AD84E7BD9CB57B5ABD8C63AD7352
B57B5AB58463BD947BD6AD8CDEC6B5DEC6B5D6BDADDECEBDF7F7F7F7F7F7F7EFF7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7EFF7F7F7F7F7F7F7F7EFF7F7F7F7F7EFF7F7F7F7F7F7F7\
F7EFE7F7F7F7F7EFF7F7EFF7F7F7F7F7EFF7E7CEC6AD73528C5A42945A31845231
7B4A297B4A29844A298C4A317B42215229185A3929E7C6B5EFC6B5F7CEB5F7CEB5F7D6BDF7D6BD\
F7D6BDEFD6C6F7D6BDEFD6C6F7D6BDF7C6B5EFC6ADF7D6BDF7D6BDEFD6C6F7DED6
EFD6C6F7C6B5EFC6ADE7BDA5E7AD94E7A594DEAD94DEAD8CDEA584E7AD94EFB59CEFC6ADEFC6AD\
EFCEADEFC6ADF7C6B5EFC6ADEFC6A5EFC6A5EFB59CEFB59CE7AD94E7AD8CDEA584
DE9C7BCE946BC6846BB57B5AAD6B42945A315229181808084221187342295229189C6339845231\
9C6B4A7B42218452318C5A42AD7352C68C63DEA57BDEA57BD69C73B57B5ABD8C63
AD7352B57B5AB57B5ACEAD94E7C6ADD6B5A5E7CEC6F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7EFF7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7EFF7F7F7F7F7EFF7F7EFF7F7F7F7\
F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7EFE7C6946B9463429463426B3921734229
7342297B4A29844A317B4A29422118632910422118EFC6ADF7C6B5EFCEBDF7C6B5F7D6BDF7D6BD\
EFD6C6F7D6BDF7D6BDF7D6BDF7D6BDF7D6BDF7CEB5F7CEB5F7C6B5EFD6C6EFD6C6
EFD6C6F7CEB5EFC6ADE7AD94D6A58CDEA584DEAD8CD6A58CDEAD94E7B59CEFC6ADEFC6B5EFC6B5\
EFCEB5F7CEB5EFC6ADEFC6ADEFC6A5EFC6ADEFC6A5EFB59CE7AD94E7AD8CDEAD8C
DEA584D69C73C6846BB57B5AAD7352AD6342734A312110083918105A39297B5A428452398C5A42\
9463427B4A29845231734A319C7352C6845ACE946BDEAD8CE7BDA5B5734AB57B5A
9C7352B57B5AC6946BE7BD9CE7C6ADC69C84DECEBDF7F7F7F7EFF7F7F7F7F7EFF7F7EFF7F7EFF7\
F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7EFF7F7EFF7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7\
F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7EFEFF7B5846B946342844A296B3921845239
844A31844A317B4A293918105229185221105A3929EFC6ADF7CEB5F7D6BDEFD6C6EFD6C6EFD6C6\
EFD6C6EFD6C6EFD6C6EFD6C6EFD6C6F7D6BDF7D6BDF7C6B5EFCEBDF7C6B5F7D6BD
F7C6B5EFC6B5EFB59CE7B59CD6A58CDEAD8CDEAD94DEAD94E7B59CEFC6ADEFC6ADEFC6ADEFC6B5\
F7C6B5F7CEB5EFC6B5F7C6B5EFC6ADEFC6A5EFC6ADEFB59CEFB59CE7AD94E7AD8C
D6A584DEA584CE946BC68463AD73529C6B4A8C4A31291008423129522918734229734A31845231\
8452319C6339845231845231A57B5ABD8C63CE9463DEAD8CEFCEADB57B5AB5734A
9C6B4AA57B5AB58463CEAD94DEC6B5DECEBDF7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7
F7F7F7F7F7F7F7EFF7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7\
F7EFF7F7F7F7F7EFF7F7EFF7F7EFF7F7EFF7B5846B945A317B4A297B4A29845239
734A317B4A29844A31522918422118522918CEAD94EFCEB5EFCEB5F7D6BDEFD6C6EFD6C6EFD6C6\
EFD6C6F7DECEF7DECEF7DECEEFD6C6F7D6BDF7D6BDF7D6BDF7CEB5EFC6B5F7D6BD
F7D6BDEFC6ADEFB59CDEAD94DEAD94DEAD8CE7B594E7B59CE7BDA5EFC6ADEFCEB5EFC6B5F7C6B5\
F7C6B5F7D6BDEFCEBDF7C6B5EFC6B5EFC6ADEFC6ADEFB59CE7B59CE7B59CDEAD94
DEA584D69C7BD69C73C68463B56B529C6B4A9463424221182110085A31215229188452398C5A42\
7B4A29945A319C63398452319C7352C69C84D69C73DEAD84EFCEADAD7352C68C63
8C5A42B58463AD7352E7BD94E7CEBDDECEBDF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7
F7EFF7F7EFF7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7EFF7F7EFF7\
F7F7F7F7F7F7F7EFF7F7EFF7F7F7F7DEC6C69C73528C5A42734229845231845231
844A317B4A29522918422118391810EFB59CEFCEBDF7C6B5F7D6BDF7DECEEFD6C6EFD6C6F7DECE\
EFD6C6EFD6C6EFD6C6EFD6C6EFD6C6EFD6C6EFD6C6EFD6C6F7D6BDF7CEB5F7D6BD
F7D6BDF7C6B5EFC6ADE7B59CDEAD94E7B594E7B594E7B59CE7BDA5EFC6B5EFC6B5EFD6C6F7D6BD\
F7C6B5EFD6C6F7C6B5F7D6BDEFCEBDEFCEBDEFC6B5EFC6ADE7C6ADEFB59CE7B594
DEAD8CD6A584D69C7BD69C73B57B5A9C6B4A9C63397342296329106B3921734A31734A31946342\
8452319C63398C5A428C4A319C7352D6A584D69C73D6AD84E7BDA5BD8C63B5734A
845231A57B5AB57B5ADEAD8CE7D6C6EFEFE7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7EFF7F7EFF7F7F7F7F7F7F7F7EFF7F7F7F7
F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7EFF7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7EFF7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F79C7352945A318452315A31217B5A42734A31
734A31844A315229186B39215A3929EFC6ADEFC6B5EFD6C6F7D6BDEFD6C6EFD6C6F7DECEF7DECE\
EFD6C6EFD6C6F7D6BDF7DECEEFD6C6EFD6C6EFD6C6EFD6C6F7D6BDEFCEBDF7D6BD
F7D6BDF7D6BDF7C6B5E7B59CDEAD94E7B59CE7BD9CE7BDA5E7BDA5E7C6ADEFCEB5F7D6BDEFCEBD\
F7D6BDEFD6C6F7D6BDF7C6B5EFCEBDEFCEBDEFCEBDEFC6B5EFC6ADE7BDA5E7B59C
DEAD94DEAD8CD69C7BD69C73C67B5AB56B52945A42734A316B39216B39216B3921845239845231\
9C63399463428C5A4294735AB5846BD69C7BD69C73D69C73D6AD84C68C63AD6B39
844A29A57B5ABD947BD6AD8CE7DED6F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7
F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7
F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7\
F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7AD73529C6339734A316B39218C5A42845239
7B4A297342296B3921522918A58473F7C6B5EFCEBDEFD6C6EFD6C6EFD6C6F7DECEF7DECEEFD6C6\
F7D6BDEFD6C6F7D6BDF7D6BDEFD6C6F7DECEF7DECEEFD6C6EFD6C6F7D6BDF7D6BD
EFD6C6F7C6B5F7C6B5E7B59CDEAD94DEAD94E7BD9CE7BDA5EFC6ADEFC6ADEFCEBDEFCEBDEFCEBD\
EFD6C6EFD6C6F7C6B5F7C6B5F7D6BDF7CEB5EFCEB5EFC6B5EFC6ADEFC6ADE7BDA5
DEAD94DEAD8CD6A584D69C73C68463B56B52945A428C4A315A31215A31216B3921734A31844A31\
9463429C6339946342945A31D69C73D69C73D69C73D69C73D6A584D6AD84AD6B42
AD6B42AD7352B58463DEAD84EFEFE7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7EFF7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7EFF79C73529C7352845239734A31734229845239
844A315A3121734229845239EFC6B5F7CEB5EFCEBDEFD6C6EFD6C6EFD6C6EFD6C6EFD6C6EFD6C6\
EFD6C6F7D6BDEFD6C6EFCEBDEFD6C6EFD6C6EFD6C6EFD6C6F7D6BDF7D6BDEFC6B5
EFD6C6EFD6C6F7D6BDE7BDA5E7AD94DEAD94E7B59CE7BDA5E7BDA5E7C6ADEFC6B5EFCEBDEFCEBD\
EFCEBDEFD6C6EFCEBDF7D6BDEFCEBDEFC6B5EFC6B5EFC6ADEFC6B5E7C6ADE7BDA5
E7BDA5DEAD94D6A584D69C7BCE946BB57B5A9C6B4A8452397342296B31186B39216B3921845239\
945A318C634A845239844A29D6AD8CD69C73C6946BD69C7BC69C84DEAD8C945A31
AD7352AD7352A5846BD6AD84F7EFE7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7EFF7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7EFF7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7EFF7F7F7F7BDADAD945A318C634A8452318C5A428452318C4A31
6B39215A3929734229E7C6ADF7D6BDEFC6B5F7D6BDEFD6C6EFD6C6EFD6C6EFD6C6F7DECEEFD6C6\
EFD6C6F7D6BDEFCEBDEFC6B5EFC6B5EFCEBDEFCEBDF7D6BDF7D6BDF7C6B5F7CEB5
EFD6C6EFD6C6F7D6BDEFC6ADE7AD94DEAD8CDEAD94DEAD9CE7BD9CDEAD9CE7C6B5E7CEBDEFC6B5\
EFD6C6EFCEBDEFCEBDEFCEBDEFC6B5E7C6B5EFC6B5EFC6ADEFC6ADEFC6ADE7BDA5
E7BDA5DEAD9CDEAD8CD6A584DE8473C684639C6B4A945A31734A315229186B39216B3921734A31\
9C6B4A8C5A428C5A428C5A42C69C84C6946BD69C73D69C739C6B4AE7BD94844221
9C6B4ABD8C63C6946BCEAD94F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7EFF7F7F7F7A57B6BB58C739C6B4A734A319C6B4A734A318C4A31
5A3121734A317B4A29E7C6ADF7C6B5E7C6ADEFD6C6EFD6C6F7DECEEFD6C6EFD6C6F7D6BDEFD6C6\
EFCEBDEFCEBDEFB59CE7C6ADEFC6ADEFC6ADEFC6B5EFCEBDF7D6BDEFCEB5F7CEB5
F7D6BDEFD6C6F7D6BDEFC6ADE7A594DEAD8CD6A58CDEAD94DEAD94E7BDA5E7C6B5EFC6B5EFCEBD\
E7C6ADE7C6ADE7BDA5E7C6ADE7C6ADE7C6ADE7C6ADEFC6ADEFC6B5E7C6ADE7C6AD
D6B5A5E7BD9CDEAD8CD6A584D69C73C68463AD7352945A31844A315229185221106B3921734A31\
8C5A429C63398C5A428C5A42C69C84CE946BCE946BD69C73844A31DEAD84945A42
8C5A42B5846BD6A584E7C6ADF7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7EFF7F7EFF7\
F7EFF7F7EFF7F7F7F7F7F7F78C4A29B5947B8C5A42946B52845A428C5A42734A31
5229189C6339E7AD8CEFC6ADE7AD94EFC6B5F7D6BDEFD6C6EFD6C6EFD6C6EFD6C6EFCEBDE7CEBD\
EFC6B5EFC6B5EFC6ADDEAD9CDEAD94E7BDA5E7C6ADEFC6B5EFCEBDE7C6ADEFC6B5
EFD6C6EFD6C6F7D6BDEFB59CDEAD94DE9C7BD6AD8CD6A58CCEAD94D6B5A5E7C6ADE7C6B5E7BDA5\
E7BDA5D6B5A5E7AD9CDEAD8CDEAD8CD6A58CDEAD9CDEAD9CE7BDA5E7BDA5E7BDA5
E7BD9CE7BD9CDEAD94D6A584CE946BC6846BB56B529C6B4A8452397342293918106329106B3921\
8C5A428C5A429C6B4A845239BD947BD69C7BB57B5ABD8C63844A29E7BD949C6B4A
8C4A31C6946BD6AD84E7D6C6F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7EFF7F7F7F7\
F7F7F7F7F7F7F7F7F7FFFFFF9C6B4AA57B638452398C5A42845239945A42522110
845231844A31F7C6B5CE946BDEA584EFCEB5F7D6BDEFD6C6EFD6C6EFD6C6EFCEBDE7C6B5DEAD9C\
BD947BB58C73D6A58CCEA594BD947BDEAD9CDEAD9CEFCEBDEFCEBDEFC6B5EFC6B5
F7D6BDF7D6BDF7D6BDEFC6ADDEAD94D69C7BC69C84D69C7BE7BD9CDEAD9CE7C6B5E7AD9CDEAD9C\
C6A59CBD9C8CB5846BB58C73C69C84C69C84C69C84CEA594E7BD9CE7BDA5DEAD9C
DEAD9CDEAD9CDEAD8CD6A584C69C84C6846BB57B5A945A42845239734A316B39215A31215A3121\
8452398452318C634A8C5A42B5846BBD8C63B57B5AB57B5A945A31E7BD94945A31
8C4A31C69C84D69C73E7D6CEFFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7BD9C94A57B5A9C7352734A31845239734A31945A425A3121
945A31EFB594EFB59CE78C7BD6A58CEFCEB5EFCEBDEFD6C6EFD6C6EFC6B5E7AD9CB58463BD8C63\
DEAD9CBDADAD736B6373736BA58473C69C84DE8473DE8473EFC6B5EFC6B5E7C6AD
F7D6BDF7D6BDF7D6BDEFC6A5E7B59CD69C7BD6A584BD947BD6A5849C4A31C65A4AC6846BD6A58C\
DEC6C6947B73735A4AA57B6BA57B63A57B5AA57B63B5846BD6A58CDEAD94DEAD94
DEAD9CDEAD9CD6A58CD6A58CCE946BC6846BB56B529C6B4A8C5A42734A31845239522918522918\
8452398452398C5A429C6B4AB58463BD947BB5734AB57B5A945229E7BD9C9C6339
9C7352D6AD84D6AD84EFE7E7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7\
F7F7F7F7F7F7F7F7F7B5846BBD9C8C9C73528C634A5A3121845239945A426B3118
522918F7C6B5E7AD8CE7A594DEAD94EFCEBDF7D6BDEFCEBDE7C6ADE7AD9CB5846BC6846BD6BDB5\
E7D6CE7B7373736B63635A52847B73A57B6BC69C84BD947BE7AD9CDEAD94EFC6A5
F7D6BDF7D6BDEFCEB5EFC6ADE7B59CDEA584BD947BB5846BC6846BC69C84AD4231DEC6C6EFE7E7\
8C736394735A7B6B5A948C846B635ABD9C949C73528C6B52B5846BD6A584D6A584
DEAD94DEAD8CD6A58CD69C7BD69C73B5846BAD73529C6B4A845231734A315A3121291008422118\
8452398C5A427342299C6B4AB5846BB584639C6B4AA57B5AAD6342DEAD8C844A29
BD947BD6AD8CD6AD8CF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7FFFFFFF7EFF7A5846B8452317B4A295A3121845239845239845239
945A42F7C6B5DEA584E78C7BDEAD94E7C6B5EFCEB5EFC6ADDEAD9CBD947B94735A5A3929B5948C\
C6B5B5947B6BB5B5BD21181884736B5A4A4294735AB5846BBD947BE7B59CEFCEAD
F7D6BDF7D6BDF7CEB5EFC6ADE7BD9CE7B594BD947BB58C739C7352B58C73BD947B9C6B4ACEC6BD\
635A52B5BDCE21181873736B635A52BD9C94423129735242A57B63B58C73BD947B
D6A584D6A58CD6A584BD947BC6946BC68463AD7352945A42845239844A31422118391810422118\
522918845239734A31AD73529C7352A57B5AA57B5AB57B5AAD6342D6AD84844A29
BD8C63D69C7BDEC6B5F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7B5947BD6C6C6A58C7394735A7B5242734A31845239845239945A42
CE7363EFB59CE78C7BD69C7BDEAD8CEFC6B5EFCEB5E7B59CCEA594C6846B734A31846352846352\
5A42394229215A39298452398C6B52846352A57B63BD947BE7AD94EFBD9CF7CEB5
F7CEB5F7D6BDF7CEB5EFC6ADEFBD9CE7B59CDEA584BD947BC6846BAD735294735AA58C84A58C84\
5A39295229185A39295A3929734A315A4239735A4A7B5242A57B63B58463B5846B
CE946BD69C7BD69C7BBD947BB5846BB57B5A945A428C5A428C5A42734A316B39214221185A3929\
6B39216B3921734A319C6B4AAD73529C6B4A9C6339B57B5AAD7352D6AD84946342
BD8C63D69C73EFE7DEF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7AD7352BD9C94B59C8C8C5A42734A318C634A845239734A318C4A31
C68463E7A594D69C7BD69C7BDEAD8CEFC6B5E7C6B5E7C6ADE7BDA5DEAD94BD947BB56B528C634A\
7B52427B52427B524284523994735AC6846BD6A584E7B59CEFC6ADEFC6ADF7CEB5
F7D6BDF7D6BDF7CEB5EFC6ADEFC6ADEFC6A5E7B594DEA584D69C7BBD947BB5846B84634AA57B63\
A584739C7B6B846352634A425A4239734A319C7352BD8C63B58C73C6846BCE946B
D69C7BD69C7BBD947BCE946BBD8C63B56B52945A428C5A428452398452397342295229185A3929\
5A31215A31217342299C7352B57B5A9C73529C6339B57B5ABD8C63D6AD849C6B4A
BD8C63D6A584EFEFE7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7\
F7F7F7F7F7F7EFE7DEA58C7B946B52734A31734229734A31734A316B39219C6B4A
C68463CE946BC69C84BD947BD6A58CE7C6B5EFCEB5EFCEB5F7D6BDEFCEBDEFC6ADEFC6B5E7BDA5\
E7B59CE7AD9CE7B59CE7BDA5E7B59CD69C7BDEA584E7AD94EFC6A5F7D6BDF7CEB5
EFD6C6EFD6C6F7D6BDF7CEB5EFCEADEFC6ADE7B594D69C73DE9C7BBD947BD6A584D6A58CD6A584\
BD947BBD947BBD947BCE946BD69C7BD6A584D6A584DEAD8CE7AD8CDEAD94D6A58C
D6A584D69C7BCE946BC6846BBD8C63B57B5A945A428C634A8452396B39216B39215229185A3929\
734A317342296B39219C6B4ABD8C639C6B4A9C6339C6845ABD947BDEAD949C7352
BD947BEFDECEFFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7
F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7\
F7F7F7FFFFFFFFFFFF7342298C5A425A31216B39216B39219463425A31219C4A31
B56B52DE8473CE946BB58C73D6A584EFCEB5E7BDA5F7CEB5F7D6BDF7D6BDEFD6C6F7D6BDF7D6BD\
EFD6C6E7A594C6846BA57B639C7352B56B52E7B59CEFC6A5F7D6BDF7D6BDF7D6BD
F7DECEEFD6C6F7D6BDEFD6C6F7CEB5F7D6BDEFBD9CE7AD94C6846BAD63429C7352B56B52B58C73\
E7BDA5E7C6ADEFC6ADE7C6ADE7BDA5E7BDA5E7B59CE7B59CE7B59CDEAD94D6A584
C6946BB58463CE946BBD8C63B57B5AAD73529C6B4A8C5A42845231845239632910522918522918\
5A3929522110734A318C5A42AD73529C6B4A946342C68C63C6946BE7BD9CA57B5A
C69C84EFE7E7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7EFE7E7FFFFFF6B39217B4A295A31216B3921734A31845239734A319C6339
B56342B57B5ABD8C63C6846BC69C84EFC6ADDEC6B5E7BD9CEFC6B5F7D6BDEFD6C6EFD6C6F7C6B5\
B5846BA57B6394735AB56B52D6A584EFC6A5F7CEB5F7CEB5F7D6BDF7DECEF7D6BD
F7DECEEFD6C6F7D6BDF7D6BDF7D6BDF7CEB5F7CEB5EFC6A5E7AD94BD8C63945A42845239945A42\
B56B52DEA584E7AD9CE7C6ADEFC6ADEFC6ADEFB59CE7BDA5DEAD94DEA584BD947B
A57B5ACE946BB58C73B5846BAD73529C6B4A9C6B4A8C5A426B39216B39215229185A3121522918\
522110735242845A42946B52A57B5A9C7352945A31BD8C63BD8C63D6AD8CBD947B
C69C84F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7\
FFFFFFBDADADFFFFFF845231734229734A31734A315A31218452397B4A29945A31
945A42945A42A57B63B5846BC69C84E7C6B5EFCEBDBD947BC69C84D6A584D69C7BDE8473B56B52\
AD7352D69C7BF7CEB5F7D6BDF7D6BDF7DECEF7DECEF7DECEF7DECEF7DECEF7DECE
EFD6C6EFD6C6EFD6C6EFD6C6F7D6BDEFD6C6F7CEB5F7CEB5F7CEB5EFCEADE7B59CD6A584B58C73\
94735A8C5A429C7352AD6342CE6B5AB58C73C6846BB58463A57B63A57B5AB5846B
BD947BBD947BDE8473BD8C63AD73529C6B4A9C6B4A8452399C6B4A4221187342297342296B3921\
52291842292184634A9C6B4AAD73529C6B4A946342BD8C63D69C73B5846BAD6B42
DECEBDF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7\
F7F7F7C6A5949C7352734A31734A3184634A845239734A31734A31734A31845239
945A318C634A9C7352A57B5AD6A584E7C6B5EFCEB5EFCEB5EFC6ADD6A584BD9C8CDE8473DEAD9C\
EFD6C6F7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DED6
EFD6C6EFD6C6F7DECEF7DECEF7DECEF7D6BDF7D6BDEFD6C6F7D6BDF7CEB5F7C6B5EFC6ADEFC6AD\
EFC6ADE7C6ADE7C6ADC69C84A57B63AD7352A57B63A57B63BD947BC69C84BD947B
CE946BD69C73CE946BBD8C63AD73529C7352AD73528452396B3921734A316B39215A3121391810\
3918104221188C634A94735A8C5A42A57B5AAD6342C6946BC69C849C6B4ABD8C63
EFE7E7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7D6C6C69C6B4A7B5A42734A319C7B6B8C6B527B5A42845239734A318C5A42
8C5A428C634AAD7352AD7352D69C7BEFC6ADEFC6B5EFCEB5EFCEB5F7D6BDF7D6BDEFD6C6EFD6C6\
EFD6C6F7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DED6F7DECEF7DECE
EFD6C6F7DECEF7DECEF7DECEEFD6C6EFD6C6EFD6C6EFD6C6EFD6C6F7D6BDEFCEB5EFCEB5F7CEB5\
EFC6ADEFC6ADEFC6ADE7BDA5E7C6ADE7C6ADE7B59CDEAD94DEAD8CD6A58CD69C7B
D6A584BD947BB58C73B57B5AAD7352A57B5AAD73529C6B4A734A316B3921522110391810391810\
391810422118B58C738C634A8C5A42D69C739C6B4AB57B5AD6AD849C6B4AC69C84
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7CEB5A5844A29735242845A42A58C73946B52845239845A427B5A42845A42
845A428C5A42A57B5A9C7352D69C7BE7C6ADEFCEB5EFCEB5EFCEBDF7D6BDF7D6BDEFD6C6F7DECE\
F7DECEEFD6C6F7D6BDF7DECEF7DECEF7DECEF7D6BDF7DECEF7DECEF7DECEF7DECE
F7D6BDEFD6C6F7DECEEFD6C6EFD6C6F7DECEEFD6C6F7D6BDF7D6BDF7D6BDF7D6BDF7C6B5F7CEB5\
EFC6B5EFC6ADE7C6ADE7BDA5EFC6ADE7B59CE7B59CDEAD94D6A584D6A584D69C7B
D69C7BBD947BC6946BBD8C63B56B52AD7352AD73528C5A429C6B4A734229522918522918422118\
5A3121522110BD947BA57B5A8C5A42BD947BAD73529C6B4AD6AD8C9C6B4AD6BDAD
FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7DECEC68452398C6B528C634A9C73528C634A8C6B528C634A845A42845239
8452318452319C6B4A9C7352C6846BE7BD9CEFC6B5EFCEB5EFCEB5EFCEBDF7D6BDF7D6BDEFD6C6\
F7DECEF7DECEF7D6BDF7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECE
F7DECEF7DECEF7DECEF7DECEF7DECEEFD6C6EFD6C6EFD6C6F7CEB5F7CEB5F7CEB5F7CEB5F7CEB5\
EFC6ADEFC6A5E7C6ADEFC6ADE7BDA5E7BD9CE7B594DEAD94DEAD8CD6A58CD6A584
D69C7BD69C73CE946BB57B5AAD7352B57B5A9C73529C6B4A734A315A31216B39215A3121391810\
391810422118C6946BA57B639C6B4AD69C73B5734A8C634ABD947B9C6B4AF7EFF7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7EFF78C634A84523984523984523984634A8C634A845239845A42845239
845A42845239A57B5AB57B5AC6946BE7B59CE7BDA5EFCEADEFCEBDF7CEB5F7D6BDF7D6BDEFD6C6\
EFD6C6F7DECEF7DECEF7DECEF7DECEF7DECEF7D6BDF7D6BDF7DECEF7DECEF7DECE
F7DECEF7DECEEFD6C6EFD6C6EFD6C6EFD6C6EFD6C6F7C6B5F7CEB5F7CEB5F7CEB5EFCEADEFC6AD\
EFC6ADEFC6ADEFB59CE7BDA5E7BD9CE7BDA5E7B59CDEAD8CDEAD94DEA584D6A584
BD947BCE946BC6846BBD8C63B57B5AAD73529C6B4A845239734A315A3929734229422118391810\
3918105A31219C7352D69C73B58463D69C7BB57B5A9C7352946342CEAD94F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7FFFFFF7B52428C6B528452398C634A8C6B52946B528C634A845A42845A42
8452398C634A9C7352BD8C63BD947BDEAD8CE7BDA5EFCEB5EFCEBDF7D6BDF7D6BDF7D6BDF7D6BD\
F7DECEF7DECEF7D6BDF7D6BDF7DECEF7DECEF7D6BDF7DECEF7DECEEFD6C6F7DECE
F7DECEF7DECEEFD6C6EFD6C6EFD6C6F7D6BDF7D6BDF7D6BDF7D6BDF7CEB5F7CEB5EFCEADEFC6AD\
EFC6ADEFC6ADEFB59CE7B59CE7B59CE7B59CE7B59CE7AD94DEAD8CD6A58CD6A584
D69C7BCE946BB58C73B58463B58463A57B639C6B4A8C5A426B3921734A31522110422118422118\
39181042292194735ABD947B9C7352C6946BBD8C63A5846B946342E7CEC6F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7FFFFFF9C7B6B7352428C5A42946B52946B52845A428C634A8452397B5A42
946B528C634A9C7352B5846BC6946BD6A58CE7BDA5EFC6ADF7CEB5F7CEB5F7CEB5F7D6BDF7D6BD\
F7D6BDF7DECEF7DECEEFD6C6F7D6BDF7DECEF7DECEEFD6C6F7D6BDF7DECEF7D6BD
EFD6C6EFD6C6F7D6BDEFD6C6F7D6BDF7D6BDF7D6BDF7CEB5F7D6BDF7CEB5F7CEB5EFC6ADF7CEB5\
EFC6ADEFC6A5EFC6A5E7BDA5E7BD9CE7BDA5E7B594DEAD94DEAD8CD6A58CD6A584
BD947BCE946BC6846BB58463B584639C6B4A9C6B4A8C5A42734A316B3921522110391810291008\
2910087B52428C634AA57B5AAD7352C69C84C6946BD6AD8CC6946BF7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7FFFFFF845239A57B63A57B5A8C5A428C634A84634A8C5A42845A429C6339
7342298C634AA57B63BD8C63B58C73D6A584E7BD9CEFC6ADEFCEB5F7CEB5F7D6BDF7D6BDF7D6BD\
F7DECEF7DECEEFD6C6F7DECEF7DECEF7DECEF7D6BDF7DECEF7D6BDEFD6C6F7DECE
F7D6BDEFD6C6EFD6C6F7D6BDEFD6C6EFD6C6F7D6BDF7D6BDF7D6BDF7D6BDEFC6ADF7C6B5EFCEAD\
EFC6ADEFC6ADEFB59CEFC6A5E7B59CE7B59CDEAD94DEAD94DEAD8CD6A58CD6A584
BD947BD69C73B58C73B5846B9C7352946B52845A42734A318452395A3121391810291008422921\
29100884634A946B529C6B4A946342C6946BC6946BC69C84E7DED6F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7EFF7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7E7DEDEA57B637B5A427B5A42845239845239845231845A42845239
8C634A8C634AA57B5AB58C73C69C84D6A58CE7BD9CEFC6ADEFCEB5F7D6BDF7D6BDEFD6C6F7D6BD\
F7DECEF7DECEF7D6BDF7DECEF7D6BDF7DECEF7D6BDEFD6C6F7D6BDF7DECEF7D6BD
EFD6C6EFD6C6F7D6BDF7D6BDF7D6BDF7D6BDEFD6C6F7D6BDF7D6BDF7C6B5F7CEB5F7CEB5EFC6AD\
EFC6ADEFC6ADEFB59CEFC6A5E7B59CE7B59CDEAD94DEAD8CDEAD8CDEAD8CD6A584
C69C84D69C7BB5846BA57B639C73529C73529C6B4A7B5A426B39215A3121391810391810422921\
391810946B52946B529C73529C6339C6946BC69C84D6A58CF7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7FFFFFF8C634A7B5A42845239734A31845231735242734A317B5A42
8C634A9C6B4AB58463B58C73D69C7BD6AD8CE7BD9CEFC6ADF7CEB5F7C6B5F7D6BDEFD6C6F7D6BD\
F7D6BDF7D6BDF7D6BDEFD6C6F7DECEF7DECEF7DECEF7DECEEFD6C6EFD6C6F7DECE
F7D6BDF7D6BDF7D6BDF7D6BDF7D6BDF7D6BDF7D6BDF7D6BDF7C6B5F7CEB5F7CEB5F7CEB5EFC6AD\
F7CEB5EFC6ADEFC6A5EFC6A5EFBD9CE7B59CDEAD94DEAD8CD6A58CDEAD8CD6A584
D6A584BD947BB5846BB5846BA57B638C634A8C5A426B39215A3121422118422118291008392118\
3918109C7B63946B529C6339946342C69C84CEB5A5DECEC6F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7CEB5B584634A845239845239845231845239845239735242
8452399C6B4AA57B63B58C73C69C84DEAD9CE7BDA5EFC6ADF7CEB5F7CEB5F7D6BDEFD6C6EFD6C6\
F7DECEEFD6C6F7DECEF7DECEF7DECEF7DECEF7DECEEFD6C6F7DECEF7D6BDEFD6C6
F7DECEEFD6C6F7D6BDEFD6C6F7D6BDF7D6BDF7D6BDF7D6BDF7CEB5F7D6BDF7CEB5F7C6B5EFCEAD\
EFC6ADEFC6ADEFC6A5EFC6A5E7B59CE7B59CDEAD9CDEAD8CDEAD8CD6A584D6A58C
CE946BCE946BBD8C63A57B63A57B5A9C73528C5A425A39295A3121422118422921311818422118\
422118A57B63B5846B8C5A42AD7352C6946BE7BD9CF7F7F7F7F7F7F7EFF7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7EFF78C6B52734A31734A317352427352428452397B5A42
735242946B52B58463BD947BD6A584DEAD94EFC6A5EFC6ADEFC6B5EFCEB5F7CEB5F7D6BDF7D6BD\
F7D6BDF7D6BDF7D6BDF7DECEF7D6BDF7DECEEFD6C6F7D6BDF7D6BDEFD6C6F7D6BD
EFD6C6EFD6C6F7D6BDF7D6BDF7D6BDEFD6C6F7D6BDF7D6BDF7CEB5F7CEB5EFCEADF7CEB5F7C6B5\
EFC6ADEFC6ADEFC6ADE7BDA5E7BDA5E7BD9CE7B594DEAD8CDEAD8CD6A58CD69C7B
D69C7BB58C73BD8C63A57B639C73528C634A8452395A39295A3121422921422118522918522918\
3918109C6B4AB584639C6B4AC6845AD6A584DECECEF7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7A57B638C6B52735242845A427B5A427352427B5A42
845A42946B529C7352C6946BD6AD8CE7BDA5E7BDA5EFC6ADF7CEB5F7CEB5F7D6BDF7D6BDF7D6BD\
EFD6C6EFD6C6F7DECEF7DECEEFD6C6F7D6BDF7D6BDEFD6C6EFD6C6EFD6C6EFD6C6
F7D6BDF7D6BDEFD6C6F7D6BDF7D6BDF7D6BDF7D6BDF7CEB5F7CEB5F7CEB5EFCEADEFCEADEFC6AD\
EFC6A5EFC6A5EFC6ADE7BDA5E7BD9CE7B594E7AD94DEAD8CDEAD8CDEA584DEA584
CE946BB58C73B5846BAD73529C6B4A8C5A42734A315A39295A3929522918422118522918391810\
291008946B529C73529C6B4ABD8C63DEAD8CEFEFE7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFCEB5B5A57B63946B52946B52946B527B5A42
7B5A42946B52A5846BB58C73D69C7BE7B59CEFC6A5EFC6ADEFC6ADF7CEB5EFCEB5F7CEB5EFD6C6\
EFD6C6EFD6C6EFD6C6F7D6BDF7D6BDEFD6C6F7DECEF7D6BDEFD6C6F7D6BDF7D6BD
F7D6BDF7D6BDF7CEB5F7D6BDF7CEB5F7CEB5F7CEB5F7CEB5F7D6BDF7C6B5F7CEB5EFC6A5EFC6A5\
EFC6A5EFC6A5EFB59CE7BDA5E7BD9CE7B594DEAD94E7B594D6A584D6A584D6A584
B58C73B58C73A57B63A57B5A8C634A845239734229734A315A31215A3121422118391810211008\
5A3929B5846B9C7352B5734ACE946BCEAD94F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFFFFFFFEFE7E794735A946B52845A428C634A
84634A8C634AAD7352BD947BC69C84DEAD94EFC6A5EFC6ADEFC6ADF7CEB5F7CEB5F7D6BDF7D6BD\
F7CEB5EFD6C6EFD6C6F7D6BDF7D6BDF7D6BDF7D6BDF7D6BDF7D6BDEFD6C6F7D6BD
F7D6BDF7D6BDF7D6BDF7D6BDF7CEB5F7CEB5F7CEB5F7D6BDF7CEB5EFC6ADEFC6ADEFC6ADEFC6AD\
EFC6A5EFC6ADEFBD9CE7B59CE7B59CE7B59CE7B594DEAD8CD69C7BD6A58CBD947B
BD947BBD8C63AD7352945A42845239845A427342295A39295A3929422921522918211818211008\
A57B5AA57B63946342B57B5AC68C63E7CEBDF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFBD9C9484523984634A735242
8C634A8C634AA57B5ABD8C63D69C7BDEAD9CE7BDA5EFB59CEFC6ADEFC6ADF7CEB5EFCEADEFCEAD\
F7CEB5F7CEB5F7D6BDF7D6BDF7D6BDF7CEB5F7D6BDF7D6BDF7D6BDF7CEB5F7D6BD
EFCEB5F7CEB5EFCEBDF7CEB5F7CEB5F7CEB5EFCEADEFC6ADEFC6ADEFC6ADEFC6ADEFC6A5EFC6AD\
EFC6A5EFC6A5EFB59CE7B59CE7B59CE7B59CDEAD94DEAD94D6A58CD69C7BD6A584
B58C73A57B639C6B4A9463428C5A42845A42845A425A31215A3121522918391810291008B5846B\
9C7B639C6B4A946342BD8C63D6B5A5EFE7E7F7F7F7F7EFF7F7EFF7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFDECEBD6B3921845A42A57B5A
7B5A42A57B5AA57B5ABD8C63C69C84DEAD94E7BD9CE7C6ADEFC6ADEFC6A5EFC6ADF7CEB5F7CEB5\
F7D6BDF7CEB5EFCEBDF7D6BDF7CEB5F7D6BDF7D6BDF7D6BDF7D6BDF7D6BDF7CEB5
F7CEB5F7D6BDF7CEB5EFC6ADF7CEB5EFC6ADF7CEB5EFC6ADEFC6ADEFC6A5EFC6ADEFC6ADEFC6A5\
EFC6A5E7BD9CEFBD9CE7B594E7B594DEAD9CDEAD8CCEAD94BD947BD69C7BCE946B
B5846BA57B639C73529C6B4A845A42734A31735242946B524221183918103921187B5A42845239\
A57B5A9C6B4AAD7352C6946BE7BDA5F7EFF7F7F7F7F7EFF7FFFFFFF7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFCEB5A59C7352845239845239
84634AA57B63A57B5ABD8C63D69C7BDEAD94DEAD9CE7BDA5EFC6ADEFC6A5EFC6ADF7C6B5EFC6AD\
F7D6BDEFCEADF7CEB5F7CEB5F7CEB5F7CEB5F7CEB5F7CEB5F7CEB5F7D6BDF7C6B5
F7C6B5EFC6ADEFC6ADEFC6ADEFB59CEFC6ADEFC6A5EFC6A5EFC6A5EFC6A5EFC6A5EFC6ADEFC6A5\
EFC6A5E7B594E7B594E7B59CDEAD94DEAD94DEAD8CD6A584BD947BBD947BB5846B
AD73529C7352946342845A42845A428452398452395A3929734A315A3929734A31734229A57B63\
9C7352B58463BD8C63D6AD8CD6BDADF7F7F7FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFC6A594C69C84734229845231
7B5A428C5A429C7352B58463BD947BC69C84D6B5A5E7B59CE7BDA5EFC6A5EFB59CF7C6B5F7C6B5\
EFCEB5EFCEB5EFC6B5EFC6ADF7C6B5F7CEB5F7CEB5F7D6BDEFC6B5EFCEB5EFC6AD
EFC6ADEFC6A5EFB59CE7B59CE7B59CEFB594EFC6A5EFC6A5EFBD9CEFB59CEFBD9CEFB594E7B59C\
E7B59CDEAD8CE7AD94DEAD94D6A58CD6A58CD69C7BBD947BBD947BB58C73B5846B
AD7352A57B5A9C6B4A735242735242734A31734A315A42397342295A3121A5846B946B529C7352\
9C6B4AD69C7BC6946BE7BD9CF7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7FFFFFF
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E7DEDEDEC6C65A3121734229
9C6B4A8452399C7352A5846BB58C73D6A58CDEAD94DEAD9CE7B59CEFB59CEFB59CEFC6A5EFC6AD\
E7C6ADEFC6ADEFCEB5EFC6ADEFC6ADEFC6ADEFC6B5EFC6ADEFC6A5EFC6ADEFC6AD
EFBD9CE7B59CE7AD8CE7AD94E7AD94E7B594EFB594E7AD8CE7AD8CE7AD8CE7AD8CDEA584DEAD8C\
E7AD94D6A584DEAD8CD6A584D6A584C69C84D69C73BD947BB5846BB58463B58463
A57B5A9C73528C5A42845A427B5A427352428C6B527B5A42734A318C6B52B5846B94735AA57B63\
BD8C63D6A584E7BD9CD6BDADF7EFF7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7C6A5949C7B6B7B5A42
845A42946B528C634A9C7352A57B63BD947BD6A58CE7BD9CDEAD9CD6B5A5E7B59CE7B59CEFC6AD\
EFC6ADEFC6ADEFC6ADE7C6ADE7BDA5E7BDA5E7BDA5E7BDA5E7B59CDEAD9CDEAD8C
DEAD94DEAD94D6A584D6A584D69C7BD69C7BD69C7BD69C73DE9C7BD69C7BD69C73D69C73BD947B\
CE946BCE946BCE946BCE946BC6846BB58C73BD947BB58C73B5846BB57B5A9C6B4A
8C634A94735A946B52735A4A946B52946B52734A318C634A9C6B4A9C6B4A9C73529C6B4ABD8C63\
B58463DEAD94E7BD9CF7EFE7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7BDADAD94735A
845A428C634A946B52A57B5AB5846BA57B6BB58C73BD947BDEAD94D6B5A5E7BDA5EFC6A5E7C6AD\
E7BDA5E7BDA5E7BDA5E7BD9CDEAD94DEAD94D6A584DEAD94E7BD9CD6A58CDEA584
D6A584D6A58CBD947BC69C84C6846BCE946BBD8C63D69C7BCE7363CE946BB57B5AB58C73B57B5A\
B57B5ABD8C63B58463B58463B5846BB5846BA57B63B58C73BD947BA5846BA58C73
A57B5AA57B638C634A8C634A94735AA57B63845A426B3921845239B57B5AB58463B57B5ABD8C63\
CEAD94D6B5A5D6BDADF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFE7E7
A58C7B94735A7B5A429C7352A57B5A8C634AB58C73C69C84D6BDADE7C6B5E7C6B5E7C6B5E7BDA5\
E7BDA5D6B5A5DEAD9CD6A584CEAD94D6A58CD6A58CD6A584D6A58CD6A584D6A584
C6946BC6946BB58C73B58C73B5846BB58C73B5846BAD7352B5846BB584639C73529C6B4AB5846B\
9C7352B584639C7352AD7352A57B63A57B5AA57B638C634A946B5294735AAD7352
94735A9C735294735A9C7352845239845A428C6B529C6B4A9C7352A57B5AA57B5AC6946BD6B5A5\
D6B5A5C69C84F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
A58C7BA57B6BA57B639C7363A58C73C6A594CEA594BD9C8CDEAD9CCEA594DEAD9CD6BDADD6BDAD\
DEAD9CDEAD94D6A58CD6A584D6A58CBD947BC69C84D6A584C69C84C6946BC69C84
BD947BC6846BB58463B5846B9C7352BD947BA57B63BD947BB58463A57B63BD8C63A57B5A9C6B4A\
BD947BA57B5AB5846BA57B63A57B5AA5846BA58C7384634A946B52A57B5A9C7B63
8C6B5294735AA57B639463429C6B4A9463429C6B4A9463429C7352B58463D6AD84CEB5A5CEAD94\
D6AD8CE7CEC6F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
FFFFFF94735AA584739C7363946B52A5846BB58C73B58C73BD9C8CDEAD9CD6B5A5DEAD94CEAD94\
D6A58CD6AD8CC69C84C69C84C69C84B58C73BD947BB58C73BD947BB58C73BD947B
B5846BBD947BA57B5A9C7352A57B6B946342A5846BA57B5AB58C739C7352A57B63A57B5AA57B63\
C6946B8C634A9C73529C7352B5846BA57B5A946B52946B52845A427B5A42734A31
7352428C634A8452398452397B5A427B5A42946342B5734AC6946BD6AD84E7C6ADBD9C8CD6AD8C\
B58463F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7FFFFFFB5947BA57B6BA57B63BD9C94C69C84C6A594D6B5A5D6B5A5D6B5A5D6B5A5C69C84\
C69C84C69C84C69C84BD947BC69C84BD947BBD947BB5846BB5846BBD947BB58463
A57B5AA57B63946342A5846BA5846B8C634A734A31A57B63845A42B58463A57B5AA57B63A57B63\
8C5A429C6B4AA57B5A734229734A319C63398C5A42845A428C5A429C6339946342
9C6B4A9463429463428452399C63399C6B4ACEAD94BD947BD6AD8CD6BDAD8C634ABD9C8CA5846B\
DECECEFFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7C6A59CA5847384634A9C73639C6B4AA5846BC6A59CCEB5A5DEAD9CD6B5A5C6A594\
BD947BBD947BB58C73BD947BBD947BB58C73A5846BA58C73B58C73A57B63B58463
B584638C634AC6946BA57B5A8C634ABD947B8C634A845A42A57B638C634A8C634A946B52845A42\
8C5A428452317342298452398452399C63398452397B5A429463428C5A42845239
844A318C5A429C7352B58463B58463C69C84BD947BE7BD9CD6B5A5A5846BA57B5ABD9C8CA5846B\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7\
F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7FFFFFF735A4A9C7B6BBD9C8CA57B6BA5846BB5947BC6AD9CCEB5A5D6A58CC6A594\
A57B63B5846BA5846BBD947BBD947BB5846B9C7363B5846BB58463A57B63B58C73
A57B63B58463845A429C735294735A8C634AA57B5A845A428C634A946342845A4284634A845A42\
735242845239845239845239734A317342298452397B5A42845239845231845231
8C634AA57B5AA57B5AA57B5AA57B5AC69C84CEB5A59C7B639C7B63A5846BC6A594BD947BEFE7E7\
F7EFF7F7EFF7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7FFFFFF
F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F79C7B6B734A31B5947BB59C8CBD9C8CB5947BD6B5A5D6B5A5C6AD9C\
A57B5AB58C73A57B63A57B63B58463A57B5A94735AA5846BA5846B94735AA57B63
94735AA57B63845A42A57B5A9C6B4A946B52735242734A31A57B5A7352427B5A42845A427B5A42\
845231734A31734A316B39215A39297342297342297342298452319C6B4A845A42
8C634AA5846BC69C84BD947BE7BDA5CEB5A5BD9C8CA58C73946B52C69C84946B52EFE7E7FFFFFF\
FFFFFFF7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7EFF7F7F7F7FFFFFFA57B6B734229947363A58473B5947BCEB5A5D6BDADC6AD9C\
A57B5A946B52B5947BA57B63B58C73B5947BB58463946B52A5846BA57B5A8C634A
A57B63A57B638C634A9C7352A57B5A94735A8C6B525A3121734A317B5A42A57B5A845239845239\
6B39218452397342296B39215A31215A39295A31215A3121734A318C5A42A5846B
BD947BB5846BBD947BCEB5A5B5947B84634A947B6BB58463A5846B9C6B4AC6A59CF7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7DECECE7B6B5A7B5A4284634AA58C73BD9C8CC6AD9CD6B5A5\
A5846B946B52A57B5AB58C7394735A94735AA57B638C6B528C634A9C736394735A
8C6B52946B52A57B6394735A8C634AA57B5A9C73528C6B528C634A734A31734A3184634A845239\
8452398C5A428452319C6B4A845231845231945A319C6B4AAD7352A57B63BD8C63
C69C84DEC6B5B5947BBD9C8C9C7B6B734A3194735AA5846BB5947BB5947BF7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7D6BDB5947B6B8C735A84635284634AA58473A58C84\
D6B5A58C634A8C6B529C7B63B5846394735A946B52845A427B5A427B5A428C634A
8C634A946B5294735A8C634A8C634AA57B5AA5846B9C735294735A7B5A42A57B5A845239845231\
94735A946B528C634A9463429C6B4AA57B5AB58463C69C84B58C73BD947BD6B5A5
BD9C8CB59C8CA58C73A58C737B5A429C7363A58C73A5846BA57B6BFFFFFFF7F7F7FFFFFFFFFFFF\
F7F7F7F7EFF7FFFFFFF7EFF7FFFFFFF7F7F7F7EFF7F7F7F7FFFFFFF7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7BDADAD94735A9473639C7363A5846BA58C7B\
C69C84C6A5948C6B528C6B52A5846BA5846B946B52A5846B845239845A42845A42
9C6B4A946B529C7352845239A57B6B9C7352B58C73A57B63B5846BB5947B946B528C5A428C5A42\
9C73529C7352B58463B58463BD8C63BD8C63D6A584D6A584C6A594A57B639C7B6B
9C7B6B8C5A42734229845239A57B63A5846B9C7B63BD947BFFFFFFF7F7F7F7F7F7F7F7F7FFFFFF\
FFFFFFF7F7F7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7CEB5B5846352947363A58C73B5947B\
BD9C8CC6A594C6AD9C94735AA5846B8C634AA5847394735AA57B63946B52845239
7B5242734A318C634A7B5A429C73639C7352BD947BB58C73DEC6B5E7C6B5D6B5A5C69C84DEAD9C\
D6A58CD6A58CD6A58CE7C6ADE7C6ADDEAD94CEB5A5A58C738C6B529C7B63946B52
845A427B5A428C634AB58463B5947BA57B63A57B6BFFFFFFF7F7F7F7F7F7FFFFFFF7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7FFFFFFFFFFFFF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7EFEFF79C847B947363736352\
A58C73CEB5A5CEB5A5CEAD94A58473B58C73A58473A58C7BA57B6BBD947BC6A594
9C7B6B7B52428C6B527B524294735AB5947BC6A594BD9C8CA58C7BD6BDADD6BDB5D6BDADDEC6B5\
E7D6C6E7CEC6D6BDADC69C84B5947BB5947BA5847394736394735A946B52735242
84523994735A9C7B63BD947BA57B63B5947BF7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7EFF7\
F7EFF7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7FFFFFF9C7B6B846352\
9C8473A58C7BC6AD9CDEC6C6C6AD9CC6AD9CD6BDB5BDADADDECEBDD6BDB5C6A59C
E7CEC6EFD6C6F7EFE7EFE7DEEFD6C6E7CEC6E7CEBDD6BDADDECEBDDEC6B5DEC6B5DEC6B5E7CEBD\
CEB5A5A58C73C6A594A58C739C7B639C7B6B9C7B6B8C634A8C6B52735A4AA57B63
A58C73A5846BA5846BA57B63FFFFFFF7F7F7F7F7F7FFFFFFF7EFF7F7F7F7F7F7F7F7F7F7F7F7F7\
F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7
F7EFF7F7F7F7F7F7F7F7EFF7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E7DEDE\
8463528C7363B5947BBDA59CD6BDB5DECEBDE7D6CEDECEC6DECEBDDECEBDDECEBD
E7D6CEDEC6B5E7C6B5E7CEBDE7C6B5EFD6C6EFDECEE7D6CEDECEBDE7CEC6CEB5A5BD9C94D6BDAD\
BD9C8CB59C8CBD9C948C735AA57B5A8C634A8C6B529C7B6BA58473BD9C8CC69C84
B58C73A5846BC6A59CF7F7F7F7F7F7F7EFF7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7FFFFFFF7F7F7F7F7F7FFFFFFF7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7FFFFFFFFFFFFF7F7F7FFFFFFF7F7F7F7F7F7FFFFFF\
EFE7E7A584739C8473A58C84CEB5A5CEB5A5D6BDB5D6C6B5DECEBDE7D6CEE7D6CE
E7D6CEE7D6CEEFE7DEE7DED6E7D6D6E7D6CEEFDECEE7CEC6DECEBDD6BDB5CEC6BDB59C8CA58C84\
BD9C949C7B639C7B6B94735AA58C73846352A58C7BBD9C8CC69C84B59C8CA58C7B
C69C84E7DEDEF7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7FFFFFFF7F7F7\
F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7\
FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7\
FFFFFFF7F7F7F7F7F7B5948C9C7B6BA58473CEB5B5DEC6C6E7D6CEE7D6CEE7D6C6
E7CEC6DEC6C6E7D6D6DECEC6DEC6C6D6BDB5C6AD9CBD9C8CB5947BC6A594C6AD9CB59C8CA58C7B\
846B52A57B6BB59C8CA58C7BC6AD9CC6AD9CCEB5A5C6AD9CA58C84C6AD9CF7EFF7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7\
F7F7F7FFFFFFF7F7F7FFFFFFF7F7F7F7F7F7F7F7F7F7EFF7F7F7F7FFFFFFF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7FFFFFFFFFFFFFFFFFFF7EFF7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7FFFFFFF7F7F7F7F7F7\
FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7BD9C94B5948CC6B5B5CEB5B5D6BDB5
E7D6D6E7D6D6E7D6CEE7D6D6E7D6D6E7D6CED6BDB5D6BDB5C6A59CBDA59CB5948CCEB5A5DECEBD\
BD9C94D6BDB5DEC6C6D6BDB5BD9C94B5947BD6BDADEFE7E7FFFFFFFFFFFFFFFFFF
F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
FFFFFFF7F7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFF\
F7F7F7F7F7F7F7F7F7FFFFFFFFFFFFF7F7F7FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7FFFFFFF7F7F7F7F7F7BDADADBDA59CD6BDB5
C6A59CD6BDADDECEC6DECEC6E7DED6E7D6D6EFE7DEF7EFE7EFE7DEE7D6CEDECEBDE7D6CEDECEC6\
DECEBDC6A59CBD9C8CCEB5A5DECEBDEFE7E7F7F7F7F7F7F7FFFFFFFFFFFFF7EFF7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7\
F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7FFFFFFF7EFF7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7EFF7F7F7F7F7F7F7FFFFFFF7EFF7F7EFF7F7F7F7F7F7F7F7F7F7F7EFF7F7EFF7
F7EFF7EFE7E7EFE7E7E7DEDEF7EFE7EFE7DEDECEBDD6BDB5D6BDB5DECEBDDECEC6DEC6C6DEC6C6\
DECECEEFE7E7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFFFFFFFF7F7F7
FFFFFFFFFFFFFFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7EFF7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7FFFFFFF7EFF7F7F7F7F7F7F7F7F7F7FFFFFF
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7FFFFFFF7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7EFF7F7F7F7F7F7F7F7F7F7\
F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7EFF7F7EFF7F7EFF7FFFFFFF7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFFFFFFFF7F7F7F7F7F7F7F7F7FFFFFFF7F7F7
F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7FFFFFFF7F7F7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7FFFFFF\
F7F7F7FFFFFFF7F7F7FFFFFFF7F7F7F7EFF7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7FFFFFF\
F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7EFF7F7F7F7F7F7F7F7EFF7FFFFFFF7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7EFF7
F7F7F7F7F7F7FFFFFFF7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7\
F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7FFFFFFF7F7F7
F7F7F7F7F7F7F7EFF7FFFFFFF7F7F7FFFFFFFFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7FFFFFFF7EFF7F7EFF7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFF\
F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7FFFFFFFFFFFFF7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7F7EFF7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7FFFFFFFFFFFFF7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7FFFFFF
F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7FFFFFFF7F7F7F7F7F7FFFFFFFFFFFF
F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7EFF7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7\
FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFF
F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7FFFFFFF7F7F7F7F7F7F7EFF7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7EFF7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7FFFFFF\
F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7FFFFFFF7EFF7
F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7FFFFFFF7F7F7F7EFF7F7F7F7F7F7F7F7EFF7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFF
F7F7F7F7F7F7F7EFF7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7F7EFF7FFFFFFFFFFFFF7F7F7F7F7F7\
F7EFF7FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7FFFFFF
F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7FFFFFFF7F7F7F7F7F7FFFFFFFFFFFFF7F7F7F7F7F7\
FFFFFFF7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7
F7F7F7FFFFFFF7EFF7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7FFFFFFF7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7FFFFFFF7EFF7FFFFFFF7F7F7F7F7F7FFFFFF
F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7EFF7FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7EFF7F7F7F7
F7F7F7F7F7F7F7F7F7F7EFF7FFFFFFFFFFFFF7F7F7F7F7F7FFFFFFF7EFF7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7FFFFFFF7F7F7F7EFF7F7EFF7F7F7F7F7F7F7FFFFFFF7EFF7F7F7F7
FFFFFFF7F7F7FFFFFFF7F7F7F7F7F7FFFFFFF7F7F7FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7FFFFFFF7F7F7F7F7F7
F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7FFFFFFF7F7F7FFFFFFF7F7F7F7F7F7FFFFFFF7EFF7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7EFF7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7\
F7F7F7F7EFF7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFF
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7FFFFFFF7F7F7
FFFFFFF7F7F7F7F7F7F7F7F7F7EFF7FFFFFFF7EFF7FFFFFFF7F7F7F7F7F7F7F7F7F7EFF7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7EFF7F7EFF7F7F7F7
F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7FFFFFFF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7FFFFFFF7F7F7F7F7F7F7EFF7\
F7F7F7F7F7F7F7EFF7F7EFF7F7F7F7F7F7F7F7F7F7FFFFFFFFFFFFF7F7F7F7F7F7
F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7FFFFFFF7F7F7F7EFF7FFFFFF\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7FFFFFFF7F7F7F7EFF7FFFFFF
F7F7F7F7EFF7F7F7F7F7EFF7F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7F7EFF7F7F7F7F7F7F7FFFFFF\
F7EFF7FFFFFFF7F7F7F7EFF7F7F7F7F7EFF7FFFFFFF7F7F7FFFFFFF7F7F7F7F7F7
F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFF\
F7F7F7FFFFFFF7F7F7F7EFF7FFFFFFFFFFFFF7F7F7F7EFF7FFFFFFF7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFFFFFFFF7F7F7F7F7F7F7F7F7F7F7F7FFFFFF\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7FFFFFFFFFFFFFFFFFFFFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7FFFFFFF7F7F7\
F7F7F7F7F7F7FFFFFFFFFFFFFFFFFFFFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7FFFFFFFFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7
FFFFFFF7F7F7FFFFFFF7F7F7F7F7F7FFFFFFF7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7FFFFFFF7F7F7F7F7F7F7EFF7
F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7EFF7F7F7F7F7EFF7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7\
F7F7F7FFFFFFF7EFF7F7F7F7FFFFFFFFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7FFFFFFF7F7F7F7F7F7
F7EFF7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7EFF7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7FFFFFFF7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7FFFFFFF7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFFFFFFFF7F7F7F7F7F7F7F7F7\
F7EFF7F7F7F7F7F7F7FFFFFFFFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFFFFFFFFFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFFFFFFFFFFFFFF7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
FFFFFFF7F7F7F7EFF7F7F7F7F7EFF7F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7FFFFFF
F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[29]:=",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`003P3oool20>o_m`80mnoW103gmoL20>o_m`80mnoW
103_knL20?Ogm`80knoW0P3gknL60>o>]@80kljm0P3_e/H:0>o>_@80mnoW0P3gimh20<J4J`80ilJ]
0P3_c[d40>O6[@80ikfU103_aZD30>NmW080klJU0P3_aZd20>o6Y@80klJ]103W_JD40>o6Y@@0klj]
103_aZd60>o6Y@80klJ]0P3_]I`60>o6[@h0mlje0P3_cZd20?O>]@@0klJ]0P3ga[D20?O>]@X0klJ]
203_aZD40>o6[@80ilJ]103_aZd20>o6Y@@0klJ]0P3_aZD20?ONcP80mnoW0P3gg/h20<jDJ`@0ikfU
103_aZD60>NmY@d0ilJ]0P3_c[D20>o>[@80klJe0P3_cZd20?OF_@80mlje1P3ge[d20>o>_@80mmJm
0P3_c[D20>O6]@80ilJ]103F_Jd40>NmY@80ikfL0P3F_Jd20>oNcP80imkN0P3N[H`20>O>_@80knOW
0P3gkoL20?Ogm`80knog403oool000h0oooo0P3_koL20?O_i`@0moOg0P3_koL20?O_i`@0knoW0P3g
moL20>o_i`80mnoW1P3_c[D20>o>_@80kmK62P3_c[d20?O_i`80mnON0P36Q6/20>O6[@80kljm103W
aZd20>NmY@@0klJU0`3W_I`20>o6Y@80klJ]0P3_aZD20>o6[@@0ikfU103_aZD40>o>[@@0klJ]1P3_
aZD20>o6[@80kkFL1P3_aZd>0?O>]@80klj]0P3gc[D40>o6[@80mlJe0P3gc[D:0>o6[@P0klJU103_
aZd20>O6[@@0klJ]0P3_aZD40>o6[@80klJU0P3gg/h20?O_i`80mmk>0P3>U6/40>NmY@@0klJU1P3W
_JD=0>O6[@80klje0P3_cZd20>o6]@80klj]0P3ge[d20?O>]@H0mmJm0P3_c[d20?OF_@80klje0P3W
a[D20>O6[@@0e[f]103W_JD20>NmW080e[f]0P3_g/h20>ONgP80gZf<0P3Wc[d20>oWi`80mnog0P3g
moL20>o_ma00oooo000>0?ooo`80knog103gkoL20>o_i`80mnoW103gmoL40>o_m`80moOg0P3gknL2
0>o_i`h0kljm1P3_c[D20?OWgP80eZF<0P3_aZd20>o>]@80ilJe103WaZd70>NmY@80kkfL0P3_aZD2
0>o6[@80klJU0P3_aZd20>o6Y@80kkfL0P3_aZd20>o>]@@0klJ]103_aZD20>neW080kkfL103_aZD2
0>NmY@80klJU0P3_aZd20>o6Y@80klJ]0P3_cZd20?O6]@@0klJ]0P3gc[D40>o6[@80mlje2P3_aZd2
0?O6]@@0klJ]103_aZD:0>o6[@80ilJ]0P3W_JD40>o6[@80klJU0P3_aZd20>o6Y@80mmk>0P3gknL2
0=J]Q080gXAc1P3_aZD;0>NmY@80klJU1P3_aZd20>o>[@80klJ]0P3_c[D20>o6[@@0klje1P3_c[d2
0?OF_@@0kljm0P3WaZd20>O6]@@0ilJ]103W_JD20>O6[@80knON0P3_inL20>NmW080ikfD0P3W_JD2
0>oWi`80mnog0P3_koL20?O_ia00oooo000>0?ooo`80knog103gkoL20>o_i`80mnoW103gmoL40>o_
m`80moOg0P3gknL20>o_i`h0kljm1P3_c[D20?OWgP80eZF<0P3_aZd20>o>]@80ilJe103WaZd70>Nm
Y@80kkfL0P3_aZD20>o6[@80klJU0P3_aZd20>o6Y@80kkfL0P3_aZd20>o>]@@0klJ]103_aZD20>ne
W080kkfL103_aZD20>NmY@80klJU0P3_aZd20>o6Y@80klJ]0P3_cZd20?O6]@@0klJ]0P3gc[D40>o6
[@80mlje2P3_aZd20?O6]@@0klJ]103_aZD:0>o6[@80ilJ]0P3W_JD40>o6[@80klJU0P3_aZd20>o6
Y@80mmk>0P3gknL20=J]Q080gXAc1P3_aZD;0>NmY@80klJU1P3_aZd20>o>[@80klJ]0P3_c[D20>o6
[@@0klje1P3_c[d20?OF_@@0kljm0P3WaZd20>O6]@@0ilJ]103W_JD20>O6[@80knON0P3_inL20>Nm
W080ikfD0P3W_JD20>oWi`80mnog0P3_koL20?O_ia00oooo000>0?ooo`H0knoW0P3gknL60>o_m`80
mnoW103_koL40?Ogm`80mnog0P3_c[d60>o>]@80mlJe103_c[D20>o6]@80klje0P3gg]H20?OWgP80
aW]:0P3WaZd20>o6]@80ilJe0P3W_JD20>NeW080ikfU1`3_aZD20>o6[@80klJU0P3_aZd20>o6Y@80
ikfU0P3_]I`40>o>[@80klJ]0P3_aZD40>nmW0@0ikfL1P3W]I`20>nmW080klJU103_aZd20>o>[@P0
klJ]0P3_aZD40>o6[@80klje103gc[D20>o>[@80mlJe0P3gc[D@0>o6[@80klJU303_aZd20>o6Y@80
kljm0P3gknL20?ONcP80aXAS1P3W_JD20>o6Y@80ilJ]1@3W_JD20>o6Y@@0ikfU0P3_aZd20>o>]@80
klj]0P3_c[D20>o>[@@0klje0P3_c[d20>oFaP80mmJm0P3_e/H20>o>_@80iljm0P3_a[D20>O6[@80
klJ]103WaZd20>O>_@80imK>0P3We/H20>oWgP80imK60P3W_I`20>NmY@80imkF0P3_knL20?Ogm`80
mnoW403oool000h0oooo1P3_knL20?O_i`H0knog0P3gknL40>o_m`@0moOg0P3gkoL20>o>_@H0klje
0P3ga[D40>o>]@80klJe0P3_c[D20?ONeP80mnON0P36NdX20>O6[@80klJe0P3Wa[D20>NmY@80ikFL
0P3W_JD70>o6Y@80klJ]0P3_aZD20>o6[@80klJU0P3W_JD20>neW0@0klj]0P3_aZd20>o6Y@@0kkfL
103W_I`60>NeW080kkfL0P3_aZD40>o6[@80klj]203_aZd20>o6Y@@0klJ]0P3_c[D40?O>]@80klj]
0P3ga[D20?O>]A00klJ]0P3_aZD<0>o6[@80klJU0P3_c[d20?O_i`80mmk>0P36Q6<60>NmY@80klJU
0P3WaZd50>NmY@80klJU103W_JD20>o6[@80klje0P3_cZd20>o>]@80klj]103_c[D20>o>_@80kmK6
0P3ge[d20>oFaP80kljm0P3Wc[d20>o6]@80ilJ]0P3_aZd40>O6[@80iljm0P3We/h20>OFaP80knON
0P3We/H20>NmW080ikfU0P3Wg]H20>o_i`80moOg0P3gknL@0?ooo`003P3oool20?O_i`80knog0P3g
koL20?Ogm`80knog103gmoL20>o_i`@0moOg0P3gknL20>o_m`80mnoW103_knL20?OF_@80klJe0P3_
c[D:0>o6[@80mnON0P3_e/H20=j]W080ilJ]103Wa[D;0>NmY@80klJU103_aZd20>o6Y@@0ikfU0P3_
aZD60>o6[@80kkfL0P3_aZD20>NmW080ikFL103W_I`20>NeW080ikFD0P3W_JD40>o6Y@@0klJ]0P3_
aZD20>o6[@H0klJU0P3_cZd20?OF_@H0mlje0P3ge[d40?O>]@80klj]103gc[D40>o6[@H0klJe0P3_
aZd40>o6]@X0klJ]0P3_c[d20?O_i`80mmk>0P3NQ7<:0>o6[@<0klj]103_aZd20>o6]@80klJ]0P3_
cZd20>o6[@80klje0P3_a[D20>o>]@80kljm0P3ge[d40>oFaP80kljm0P3_e/H40>o6]@80ilJe0P3_
c[D20>O6]@80knOW0P3We/h20>OFaP80knON0P3W_I`20>ONeP80ilJ]0P3W_I`60>oWi`80mnoW403o
ool000h0oooo0P3gknL20>o_m`80mnog0P3gmoL20>o_m`@0moOg0P3_knL40?Ogm`80mnoW0P3_koL2
0?O_i`@0knoW0P3ge[d20>o6]@80klje2P3_aZd20?OWgP80kmK60P3N[I`20>O6[@@0ilJe2`3W_JD2
0>o6Y@@0klJ]0P3_aZD40>NmY@80klJU1P3_aZd20>nmW080klJU0P3W_I`20>NeW0@0ikfL0P3W]I`2
0>NeU080ikfU103_aZD40>o6[@80klJU0P3_aZd60>o6Y@80klj]0P3ge[d60?O>]@80mmJm103gc[D2
0>o>[@@0mlje103_aZd60>o6]@80klJ]103_a[D:0>o6[@80kljm0P3gknL20?ONcP80gXAc2P3_aZd3
0>o>[@@0klJ]0P3_a[D20>o6[@80klj]0P3_aZd20>o>]@80klJe0P3_c[D20>o>_@80mmJm103_e/H2
0>o>_@80kmK6103_a[D20>O6]@80klje0P3Wa[D20>oWi`80imK>0P3We/H20>oWgP80ikfL0P3Wg]H2
0>O6[@80ikfL1P3_inL20?O_ia00oooo000>0?ooo`80knog0P3gkoL20>o_m`80mnog0P3gmoL40?O_
m`80knog203gmoL20?O_i`80moOg0P3_koL20?O_i`80mmJm0P3_c[D20?O>]@80klJ]0P3_cZd20>o6
[@80mlje103gimh20=j]W080klJ]0P3_a[D20>O>_@L0ikfU0P3_aZD40>NmY@@0klJU0P3_aZd40>o6
Y@80klJ]0P3_aZD60>nmW0X0klJU0P3__I`20>NeW080ikfL0P3W_JD20>o6Y@H0kkFL0P3_aZD:0>o6
[@80mlje103_aZd40?OF_@80klJe0P3gc[D20?O6]@80mlje0P3ga[D20>o6[@@0klje103_a[D60>o>
]@80klJ]0P3_c[D60>o6[@80kljm0P3gknL20=j]S080ijfL0P3_aZd60>o>[@L0klJ]0P3_cZd20>o>
]@80klj]0P3_c[D20?O>]@@0klje0P3gc[D20?OF_@H0kmK61P3_c[d20>O6]@80kmK60P3_knL20>oW
i`@0knON0P3_knL20>O>_@80mmkF103W_I`20>oWi`80moOg0P3gknL20>o_ia00oooo000>0?ooo`80
knog0P3gkoL20>o_m`80mnog0P3gmoL40?O_m`80knog203gmoL20?O_i`80moOg0P3_koL20?O_i`80
mmJm0P3_c[D20?O>]@80klJ]0P3_cZd20>o6[@80mlje103gimh20=j]W080klJ]0P3_a[D20>O>_@L0
ikfU0P3_aZD40>NmY@@0klJU0P3_aZd40>o6Y@80klJ]0P3_aZD60>nmW0X0klJU0P3__I`20>NeW080
ikfL0P3W_JD20>o6Y@H0kkFL0P3_aZD:0>o6[@80mlje103_aZd40?OF_@80klJe0P3gc[D20?O6]@80
mlje0P3ga[D20>o6[@@0klje103_a[D60>o>]@80klJ]0P3_c[D60>o6[@80kljm0P3gknL20=j]S080
ijfL0P3_aZd60>o>[@L0klJ]0P3_cZd20>o>]@80klj]0P3_c[D20?O>]@@0klje0P3gc[D20?OF_@H0
kmK61P3_c[d20>O6]@80kmK60P3_knL20>oWi`@0knON0P3_knL20>O>_@80mmkF103W_I`20>oWi`80
moOg0P3gknL20>o_ia00oooo000>0?ooo`80knog0P3gkoL20>o_i`80mnog0P3_koL20?O_i`80mnog
0P3gmoL20>o_i`@0mnog0P3_knL40?Ogm`80mnog0P3gmoL20?O_m`80kmk>0P3_c[D20?O>]@H0klje
0P3_c[d20?OWgP80knON0P3_aZd40>o>]@80ilJe0P3WaZd50>NmY@80klJU0P3WaZd40>o6[@@0ikfU
0P3_aZD20>NmY@80ikFL103__I`20>NmW0H0klJU0P3_aZd20>o6Y@@0klJ]0P3_]I`40>NeW080kkfL
0P3W]I`20>o6Y@80ikfU0P3_aZD:0>o6[@80mlJe103gc[D20>o6[@80kljm1P3_c[D20?O>]@80klje
0P3gc[D20>o>]@80kljm0P3_c[D20>o6]@80klje1P3_a[D20>o6[@80klj]103_aZd20>o>_@80mnoW
0P3W_JD20>N]W080klJ]103_c[D30>o>[@80klJe103_cZd80?O>]@80klje0P3gc[D40>o>_@H0kmK6
0P3_c[d20>O6]@80g/Je0P3W_I`20>OFcP80knON0P3gknL20>O6[@80imK>0P3WaZd20>o>_@80knOW
0P3W_JD20>OFcPH0mnog0P3_knL@0?ooo`003P3oool20>o_m`80mnog0P3_knL20?O_m`80knog0P3g
knL20?O_m`80moOg0P3_knL40?O_m`80knoW103gmoL20?O_m`80moOg0P3gkoL20>oNcP80klje0P3g
c[D60>o>]@80kljm0P3gimh20>oWgP80klJ]103_c[D20>O6]@80ilJ]1@3W_JD20>o6Y@80ilJ]103_
aZd40>NmY@80klJU0P3W_JD20>NeW0@0kkfL0P3W_I`60>o6Y@80klJ]0P3_aZD40>o6[@80kkFL103W
]I`20>nmW080ikFL0P3_aZD20>NmY@80klJU2P3_aZd20?O6]@@0mlje0P3_aZd20>o>_@H0klje0P3g
c[D20>o>]@80mlje0P3_c[D20>o>_@80klje0P3_a[D20>o>]@H0klJe0P3_aZd20>o>[@@0klJ]0P3_
c[d20?O_i`80ikfU0P3W[I`20>o6[@@0klje0`3_cZd20>o6]@@0klj]203gc[D20>o>]@80mlje103_
c[d60>oFaP80kljm0P3Wa[D20=k6]@80ikfL0P3We/h20>oWgP80mnoW0P3WaZd20>OFcP80ilJ]0P3_
c[d20>oWi`80ikfU0P3We/h60?O_m`80knoW403oool000h0oooo0P3_koL60?Ogm`80knoW0P3gmoL2
0>o_i`@0mnog0P3gmoL20>o_i`@0moOg0P3_koL80?Ogm`80mnoW103_e/H20?OF_@80kmK6103ge[d2
0?O_i`80imKF0P3_a[D40>o>_@80iljm0`3Wa[D20>O6[@@0ikfU103W_I`20>NmY@80ikFD0P3N[I@6
0>NeU080ikfL0P3W]I@20>o6Y@80klJ]203_cZd20?O>]@@0klJU0P3W]I`20>nmW080ikfL0P3__I`2
0>NeW080ikfL0P3W_JD20>neW0@0klJU103_aZd20>o>[@X0klJ]0P3_a[D40>o6[@@0klje1P3_a[D:
0>o6[@80ilJ]103_aZd20>O6[@80kmK60P3gknL20?ONcP80ilJ]1`3_aZd20>o6Y@80klj]0P3ga[D4
0?O>]@80klje0P3gc[D20>o>]@80mmJm0P3_c[d60>oFaP80ilJe0P3WaZd20=j]W080cZfD0P3W_JD2
0>oWi`80imkF0P3_knL20>O6]@80iljm0P3_c[D40>O>_@80ikfD0P3_inL20?O_m`80mnoW0P3gmoL2
0>o_ma00oooo000>0?ooo`80knog1P3gmoL20>o_i`80moOg0P3_knL40?O_m`80moOg0P3_knL40?Og
m`80knog203gmoL20?O_i`@0kmK60P3ge[d20>oFaP@0mmJm0P3gknL20>OFeP80klJe103_c[d20>O>
_@<0ilJe0P3WaZd40>NmY@@0ikfL0P3W_JD20>NeU080gZfD1P3W]I@20>NmW080ikFD0P3_aZD20>o6
[@P0klj]0P3gc[D40>o6Y@80ikFL0P3__I`20>NmW080kkfL0P3W]I`20>NmW080ikfU0P3_]I`40>o6
Y@@0klJ]0P3_cZd:0>o6[@80klJe103_aZd40>o>]@H0klJe2P3_aZd20>O6[@@0klJ]0P3WaZd20>oF
aP80mnoW0P3gg/h20>O6[@L0klJ]0P3_aZD20>o>[@80mlJe103gc[D20>o>]@80mlje0P3_c[D20?OF
_@80kljm1P3_e/H20>O6]@80ilJ]0P3N[I`20<j]U080ikfU0P3_inL20>ONeP80knoW0P3Wa[D20>O>
_@80klje103Wc[d20>NmU080knOW0P3gkoL20?O_i`80moOg0P3_koL@0?ooo`003P3oool20>o_m`80
mnoW1P3gkoL20?Ogm`80mnog0P3gmoL40>o_m`80knoW103_koL20?Ogm`80mnog1P3gmoL20?O_m`80
knog0P3gg]H60?ONcP@0kmk>0P3gknL20>oFaP80_IAk0P3_c[d20>o6]@<0klJ]203W_JD20>NmW0@0
gZfD303W]I@20>NmY@80klJU0P3_aZd60>o>[@80mlje103_aZd20>neW080ikFL103W]I@20>NeW080
ikfU0P3W]I`40>NeU080ikFL1P3W_JD20>o6Y@@0ikfU0P3__I`20>NmY@80klJU0P3W_JD20>o6Y@80
ilJ]0P3W_JD20>O6[@@0klJU3P3W_JD20>o6Y@@0ikfU0P3We]H20?OWgP80ilJe0P3WaZd20>o6Y@T0
klJ]0P3_c[D20?O>]@@0klje103ge[d60>o>_@80ilJ]0P3W_JD20=JLN`80eZf40P3>[I@20>O6[@80
imK>0P3WaZd20=j]S080ikfU0P3_aZD20>NmU080imK>0P3Wa[D20>NmW080knON0P3gkoL20>o_i`80
mnoW0P3_koL@0?ooo`003P3oool20>o_m`80mnoW1P3gkoL20?Ogm`80mnog0P3gmoL40>o_m`80knoW
103_koL20?Ogm`80mnog1P3gmoL20?O_m`80knog0P3gg]H60?ONcP@0kmk>0P3gknL20>oFaP80_IAk
0P3_c[d20>o6]@<0klJ]203W_JD20>NmW0@0gZfD303W]I@20>NmY@80klJU0P3_aZd60>o>[@80mlje
103_aZd20>neW080ikFL103W]I@20>NeW080ikfU0P3W]I`40>NeU080ikFL1P3W_JD20>o6Y@@0ikfU
0P3__I`20>NmY@80klJU0P3W_JD20>o6Y@80ilJ]0P3W_JD20>O6[@@0klJU3P3W_JD20>o6Y@@0ikfU
0P3We]H20?OWgP80ilJe0P3WaZd20>o6Y@T0klJ]0P3_c[D20?O>]@@0klje103ge[d60>o>_@80ilJ]
0P3W_JD20=JLN`80eZf40P3>[I@20>O6[@80imK>0P3WaZd20=j]S080ikfU0P3_aZD20>NmU080imK>
0P3Wa[D20>NmW080knON0P3gkoL20>o_i`80mnoW0P3_koL@0?ooo`003P3oool20>o_m`80moOg0P3_
koL60?Ogm`80knog0P3gknL40?O_m`80moOg0P3gkoL20>o_m`80knoW0P3gmoL20?O_m`@0moOg0P3_
koL20?Ogm`80knog0P3gmoL40?O_m`@0moOg103gkoL20?O_i`80e[f]0P3WaZd30>o6[@80ilJ]1P3W
_JD20>NeW080ikfL0P3F]JD40>NmW080kkfL103_aZD20>nmW080ikFD0P3__I`20>o6Y@P0klj]0P3g
c[D20>o>[@80klJU0P3_]I@20>nmW080klJU0P3_]I`40>nmW0@0ikfU103W]I@20=j]S080gZfD0P3N
[H`20=jUQ080gZfD1P3N[H`20=jUQ0@0gZf<3P3N[I@20>NmW080ikFL1P3W_I`20>NeW080ikFD0P3W
_I`20=j]U0@0ilk60P3F[H`30=j4L`80gZfD103W_JD60>o6[@80klje103_c[d20>oFaP80kljm0P3W
a[D20<jDH`80eYac0P3N[H`20<jeY@@0gZf<0P3Wa[D20>O6[@80ikfU0P3W_I@20>NmW080imkF0P3W
c[d20>NmW080imKF0P3_imh20>o_m`80mnog103_knL@0?ooo`003P3oool20>o_m`80moOg0P3_koL6
0?Ogm`80knog0P3gknL40?O_m`80moOg0P3gkoL20>o_m`80knoW0P3gmoL20?O_m`@0moOg0P3_koL2
0?Ogm`80knog0P3gmoL40?O_m`@0moOg103gkoL20?O_i`80e[f]0P3WaZd30>o6[@80ilJ]1P3W_JD2
0>NeW080ikfL0P3F]JD40>NmW080kkfL103_aZD20>nmW080ikFD0P3__I`20>o6Y@P0klj]0P3gc[D2
0>o>[@80klJU0P3_]I@20>nmW080klJU0P3_]I`40>nmW0@0ikfU103W]I@20=j]S080gZfD0P3N[H`2
0=jUQ080gZfD1P3N[H`20=jUQ0@0gZf<3P3N[I@20>NmW080ikFL1P3W_I`20>NeW080ikFD0P3W_I`2
0=j]U0@0ilk60P3F[H`30=j4L`80gZfD103W_JD60>o6[@80klje103_c[d20>oFaP80kljm0P3Wa[D2
0<jDH`80eYac0P3N[H`20<jeY@@0gZf<0P3Wa[D20>O6[@80ikfU0P3W_I@20>NmW080imkF0P3Wc[d2
0>NmW080imKF0P3_imh20>o_m`80mnog103_knL@0?ooo`003P3oool20?Ogm`80mnog0P3gmoL20?O_
i`H0moOg103gkoL20>o_i`80mnoW103_koL20?O_i`80moOg0P3_koL20>o_i`80moOg0P3_koL20?Og
m`80mnog0P3gmoL20?O_m`80knog0P3gmoL40?O_m`80mnoW0P3gmoL20>o_m`80ikfL0`3FW7/20>OF
aP80ikfU0P3N[I`40>NmY@80ikfL103F]JD20=j]U080ikFD0P3W_I`40>nmW080ikFD0P3W_I`40>o6
Y@80mlje0P3_cZd20?O>]@80klj]103_aZd80>nmW080klJU0P3__I`60>o6Y@80kkfL0P3_aZD40>nm
W080ikfL0P3W]I`20>NmW0H0ikFL0P3W_I`40>NeW080kkfL0P3W_I`20>nmW0@0ikfU103_aZD20>Ne
W0H0klJU0P3W_JD20>o6Y@@0ikfU0P3__I`20>o6]@80iljm0`3Wc/H20>NmY@80U5Xa0P3W]I`20=j]
W080ikfU103WaZd20>O6]@80eZf<0P36Q5X40<IkBP80cXaJ0P3N[H`20>NmU080ikfU0P3N[H`20>Nm
U080ikfL0P3W_JD20>O>_@80ilJ]0P3N[H`20>oFaP80imK60P3N[H`20>oNcP80imkF0P3gknL20?O_
m`80moOg0P3_koL@0?ooo`003P3oool20?Ogm`80mnog0P3gmoL20?O_i`H0moOg103gkoL20>o_i`80
mnoW103_koL20?O_i`80moOg0P3_koL20>o_i`80moOg0P3_koL20?Ogm`80mnog0P3gmoL20?O_m`80
knog0P3gmoL40?O_m`80mnoW0P3gmoL20>o_m`80ikfL0`3FW7/20>OFaP80ikfU0P3N[I`40>NmY@80
ikfL103F]JD20=j]U080ikFD0P3W_I`40>nmW080ikFD0P3W_I`40>o6Y@80mlje0P3_cZd20?O>]@80
klj]103_aZd80>nmW080klJU0P3__I`60>o6Y@80kkfL0P3_aZD40>nmW080ikfL0P3W]I`20>NmW0H0
ikFL0P3W_I`40>NeW080kkfL0P3W_I`20>nmW0@0ikfU103_aZD20>NeW0H0klJU0P3W_JD20>o6Y@@0
ikfU0P3__I`20>o6]@80iljm0`3Wc/H20>NmY@80U5Xa0P3W]I`20=j]W080ikfU103WaZd20>O6]@80
eZf<0P36Q5X40<IkBP80cXaJ0P3N[H`20>NmU080ikfU0P3N[H`20>NmU080ikfL0P3W_JD20>O>_@80
ilJ]0P3N[H`20>oFaP80imK60P3N[H`20>oNcP80imkF0P3gknL20?O_m`80moOg0P3_koL@0?ooo`00
3P3oool20>o_i`80knog0P3gmoL20>o_m`80mnog0P3_knL20>o_m`@0mnog0P3gmoL20>o_i`80mnog
103gmoL60?O_m`80moOg0P3gkoL20?Ogm`80mnog0P3gmoL20>o_m`@0mnog0P3_koL20?Ogm`80knog
103gkoL20>NmW0<0eYac0P3N[I@20<j]U080gZfL203W_I`20>NmY@80e[FU0P3W]I@20>NmW0@0kkfL
0P3W]I@20>NmU080klJU0P3_aZd20>o6Y@80klJ]203_cZd20>o6Y@@0kkfL3P3_aZD20>nmW080kkFL
203_aZD20>NmY@80ikfL103__I`40>o6Y@H0kkfL0P3W_JD:0>o6Y@80kkfL0P3_aZD20>nmW0@0klJU
0P3_aZd20>o6Y@80ikfU0P3_aZd30>o6Y@80iljm0P3Nc[d20>OFeP80eZf<102mU7/20=JUQ080_HaS
0P36NdX20<j<FP80aW]:0P36Q5X40=JLL`80ikfD0P3N[I@20=J]Q080knON103W_I@20=k6]@80gZEk
0P3_c[d20>oNcP80ikfL0P3Wg]H20>O6]@80knoW0P3_inL40>o_i`80moOg403oool000h0oooo0P3_
knL20>o_m`80moOg0P3_koL20?O_m`80knoW0P3_koL40?O_m`80moOg0P3_knL20?O_m`@0moOg1P3g
koL20?Ogm`80mnog0P3gmoL20?O_m`80moOg0P3_koL40?O_m`80knog0P3gmoL20>o_m`@0mnog0P3W
_I`30=JLL`80gZfD0P3>[I@20=j]W0P0ikfL0P3W_JD20=JeY@80ikFD0P3W_I`40>nmW080ikFD0P3W
_I@20>o6Y@80klJ]0P3_aZD20>o6[@P0klj]0P3_aZD40>nmW0h0klJU0P3__I`20>neW0P0klJU0P3W
_JD20>NmW0@0kkfL103_aZD60>nmW080ikfU2P3_aZD20>nmW080klJU0P3__I`40>o6Y@80klJ]0P3_
aZD20>NmY@80klJ]0`3_aZD20>O>_@80g/jm0P3We]H20=J]S0@0_IAk0P3FYH@20;f<H`80aW]:0P3>
S5X20<IkBP80aXAJ103FW7<20>NmU080gZfD0P3F[H@20>oWgP@0ikfD0P3Na[D20=jUN`80kljm0P3_
g/h20>NmW080imkF0P3Wa[D20>o_i`80knOW103_knL20?Ogma00oooo000>0?ooo`80moOg0P3_koL2
0?O_i`80moOg0P3_koL40?Ogm`80knoW103gknL20?Ogm`80mnog0P3gmoL20>o_m`80moOg0P3_koL4
0?O_m`80moOg0P3_koL80?Ogm`@0knog103_knL20?O_m`80knoW0P3Wa[D30>O6[@80cYAS103F[H@2
0<jDJ`80ikfL0P3W_JD20>NeW080ikfL0P3N[I`20>NmU080ikfL0P3W]I@20>nmW0@0ikfD1P3_aZD4
0>o6[@80klj]0P3_aZD20>o>[@@0klJU103__I`@0>o6Y@80kkFL103__I`60>o6Y@80ikfL0P3__I`2
0>NmY@80kkFL0P3__I`40>o6Y@80kkFL203_aZD40>nmW080klJU0P3W_JD20>o6Y@80ikfL203_aZD7
0>NmY@80iljm103Wc/H20=Jm[@80[F<a0P2]JcT20<J4FP80aW]:0P36Q5X40<jDH`80cYA[0P3>U6<2
0<j]U080e[FU0P3Wg]H20=JLL`80gZf40P3WaZd20=jUN`80ilJe0P3We/H20>NmU080knoW0P3_imh4
0>o_i`@0knog0P3gmoL@0?ooo`003P3oool20?Ogm`80knog0P3gknL20?Ogm`80knog103gmoL20>o_
i`@0mnoW0P3gmoL20?O_m`80moOg0P3_koL20?Ogm`80knog103gkoL20?Ogm`80knog203gmoL40>o_
m`@0knoW0P3gkoL20>o_i`80ilJe0`3WaZd20<jDH`@0eZf40P3>U6/20>NmW080ikfU0P3W]I`20>Nm
W080gZfL0P3W_I@20>NmW080ikFD0P3__I`40>NmU0H0klJU103_aZd20>o>[@80klJU0P3_cZd40>o6
Y@@0kkfL403_aZD20>neW0@0kkfL1P3_aZD20>NmW080kkfL0P3W_JD20>neW080kkfL103_aZD20>ne
W0P0klJU103__I`20>o6Y@80ikfU0P3_aZD20>NmW0P0klJU1`3W_JD20>O>_@@0ilk60P3F_Jd20:eS
<@80[F/i0P36Q5X20<IkBP80aXAJ103>U6<20<jDJ`80cYAS0P3>[I@20=JeY@80imkF0P3FW7<20=j]
Q080ilJ]0P3NYG/20>O6]@80imK60P3W_I@20>o_i`80knON103_knL40>o_m`80moOg403oool000h0
oooo0P3_koL40?Ogm`@0knog0P3gmoL20?O_i`H0moOg0P3_koL40?Ogm`80mnog0P3gknL80?Ogm`80
mnoW0P3gkoL40?Ogm`80mnog103_koL20?O_m`H0knog0P3Wc/H30>O6]@80eZf<0P3>U6<20=J]Q080
aW]20P2]JcT20=j]W080ikfL103W]I`20>NmW080ikFL0P3W_I`20>neU080ikFD0P3W_I`:0>o6Y@80
klj]4P3_aZD20>o6[@P0klJU1P3__I`20>o6Y@@0kkfL0P3_aZD20>NmW080kkFL1P3__I`20>NmW080
ikfU0P3_aZD20>o6[@@0klJU0P3_]I`40>o6Y@H0kkfL103_aZD70>NmY@80ikfL0P3N[I@20=JUQ080
eYak0P36NdX20;E[@P80aW]:0P36Nd820;EkFP80aW]20P3>U6<20<j<FP80cYAS0P3>U6/40=j]Q080
gZf<0P3WaZd20=jUN`80gZf40P3W_I@20=j]Q080imK60P3WaZd20>O>_@80knON0P3_knL20?O_m`80
knON103gmoL20?O_ma00oooo000>0?ooo`80knog103gmoL40>o_m`80moOg0P3gknL60?Ogm`80knog
103gmoL20?O_m`80mnoW203gmoL20?O_i`80mnog103gmoL20?O_m`@0knog0P3gkoL60>o_m`80ilk6
0`3Wa[D20=J]S080cYAS0P3F[H@20<Ik@P80[F/i0P3N[I`20>NmW0@0ikFL0P3W_I`20>NeW080ikfL
0P3_]I@20>NeU080ikfL2P3_aZD20>o>[A80klJU0P3_aZd80>o6Y@H0kkfL0P3_aZD40>nmW080klJU
0P3W_I`20>neW0H0kkfL0P3W_I`20>NmY@80klJU0P3_aZd40>o6Y@80kkFL103_aZD60>nmW0@0klJU
1`3W_JD20>NmW080gZfD0P3FYH@20=JLN`80aW]:0P2eJd820<IkBP80aW]20P2eNeX20<Ik@P80cYAS
0P3>S5X20<jDH`80cYA[103N[H@20=j]S080ilJ]0P3NYG/20=j]Q080ikfD0P3N[H@20>OFaP80ilJ]
0P3Wc[d20>oWgP80knoW0P3gkoL20>oWgP@0moOg0P3gkoL@0?ooo`003P3oool20?Ogm`80mnog0P3_
koL20?O_m`80mnoW0P3gmoL20>o_m`80moOg0P3_knL20?Ogm`80knog0P3gmoL20?O_i`80moOg0P3_
koL60?Ogm`80knog0P3gkoL40?Ogm`80knog0P3gmoL20?O_i`80knoW0P3_koL20?Ogm`80mnoW0P3_
koL20>oNcP<0knON0P3We/H20<j<FP80cYAS0P36Nd820;E[>@80U58Y0P3W]I`20=j]W080ikfL0P3N
[I@20=j]W080ikFL0P3W_I`20>NmU080ikfL2P3_aZD20>o6[@X0klJU203__I`20>o6Y@80kkfL1P3_
aZD:0>nmW0H0ikfL203__I`20>NmW0@0kkfL0P3_aZD20>NmW0@0kkfL103_aZD20>nmW080ikfL1P3_
_I`20>NeU080ikfL0`3N[I@20=j]S080eYak0P3>U6<20;EcBP80]F]20P36NdX40<j<FP80aYA[0P36
Q5X20<Ik@P@0cYAS0P3NYG<20=j]S080gZf40P3W_I`20=j]S080eYac103N[H@60>O6[@80imK60P3g
koL20>o_i`@0mnoW103gkoL20>o_ia00oooo000>0?ooo`80moOg0P3gkoL20>o_m`80mnog0P3gknL2
0?Ogm`80knog0P3gmoL20>o_i`80moOg0P3_koL20?Ogm`80mnoW0P3gmoL20>o_m`H0moOg0P3_koL2
0?O_m`@0moOg0P3_koL20?Ogm`80mnoW0P3_knL20>o_m`80moOg0P3gknL20>o_m`80kmk>0`3_imh2
0>OFaP80cXaJ0P3>U6<20<Ik@P80]F/i0P2DDRT20>NeW080gZfL0P3W_I`20=j]U080gZfL0P3W]I`2
0>NmW080ikfD0P3W_I`:0>o6Y@80klJ]2P3_aZD80>nmW080klJU0P3__I`60>o6Y@X0kkfL1P3W_I`8
0>nmW080ikfL103__I`20>o6Y@80ikfL103__I`40>o6Y@80kkfL0P3W_I`60>nmW080ikFD0P3W_I`3
0=j]U080gZf<0P3FW7/20<jDH`80]G=:0P2eJd820<IkBP@0cXaJ0P36U6/20<J4FP80aW]2103>U6<2
0=jUL`80gZf<0P3N[H@20>NmW080gZf<0P3FW7<40=j]Q0H0ilJ]0P3We/H20?O_m`80knoW103gknL4
0?O_m`80knoW403oool000h0oooo0P3_koL20?O_m`80moOg0P3gkoL20>o_i`H0moOg0P3gknL20?Og
m`80mnog0P3_koL20?Ogm`80knog103gmoL20?O_i`80knog0P3gkoL20>o_m`80moOg0P3_knL20?Og
m`80mnog0P3gknL20?Ogm`@0mnog0P3_knL20?O_i`80imK>0`3gknL20>O6[@80cXaJ0P36NdX20<Ik
@P80]F<a0P2DDRT207/i6080gZF40P3N[H`20=j]U080ikfL0P3W]I`20>NmW080ikFD0P3W_I@20>Nm
Y@P0klJU0P3__I`>0>o6Y@80kkfL0P3_aZD60>nmW0P0klJU103_]I@80>nmW080kkFL0P3__I`20>Nm
W080kkFD0P3W_I@20>NmW080kkFL0P3_aZD20>nmW080klJU0P3__I`20>NmW0@0klJU103__I`20>Nm
W0@0ikFD0P3N[H`30=j]Q0@0eYac0P36NdX20:e[>@80aXAJ0P3>S5X20<IkBP80cXaJ0P3FW7/20<j<
FP80aXAJ0P3>S5X20=jUL`80cYAS0P3F[H@20=JLL`80cZfD0P3NYG/60>NmU080kmk>0P3N[H`20>O6
]@@0knoW0P3gkoL20?OWgP80knog0P3_knL20?Ogm`80mnog403oool000h0oooo0P3_koL20?O_m`80
moOg0P3gkoL20>o_i`H0moOg0P3gknL20?Ogm`80mnog0P3_koL20?Ogm`80knog103gmoL20?O_i`80
knog0P3gkoL20>o_m`80moOg0P3_knL20?Ogm`80mnog0P3gknL20?Ogm`@0mnog0P3_knL20?O_i`80
imK>0`3gknL20>O6[@80cXaJ0P36NdX20<Ik@P80]F<a0P2DDRT207/i6080gZF40P3N[H`20=j]U080
ikfL0P3W]I`20>NmW080ikFD0P3W_I@20>NmY@P0klJU0P3__I`>0>o6Y@80kkfL0P3_aZD60>nmW0P0
klJU103_]I@80>nmW080kkFL0P3__I`20>NmW080kkFD0P3W_I@20>NmW080kkFL0P3_aZD20>nmW080
klJU0P3__I`20>NmW0@0klJU103__I`20>NmW0@0ikFD0P3N[H`30=j]Q0@0eYac0P36NdX20:e[>@80
aXAJ0P3>S5X20<IkBP80cXaJ0P3FW7/20<j<FP80aXAJ0P3>S5X20=jUL`80cYAS0P3F[H@20=JLL`80
cZfD0P3NYG/60>NmU080kmk>0P3N[H`20>O6]@@0knoW0P3gkoL20?OWgP80knog0P3_knL20?Ogm`80
mnog403oool000h0oooo0P3gknL40>o_m`80mnoW0P3_koL20?Ogm`80knoW0P3gknL20>o_i`H0moOg
0P3gknL20?Ogm`@0mnoW0P3gmoL20>o_m`80moOg0P3gkoL20>o_m`80moOg0P3_koL20?O_i`80moOg
0P3gknL20?Ogm`80mnog0P3gknL20>o_i`80kmk>0`3_imh20>O6]@80e[f]0P36Nd820<J4FP80]F/i
0P2DDRT407/i60@0gZfD0P3W]I@20=j]U080ikfL0P3W_I@20>NeU0`0klJU103__I`40>o6Y@P0kkfL
0P3_]I@20>NmW080kkfL1P3_aZD60>nmW080ikfL0P3_]I@20>NmU080ikFD1P3__I`20>neU080ikfL
0P3W[H`20>NmW080ikfD303__I`20>NmU0@0gZf40P3NYG/90=JLL`80aXAJ0P2LHcT209AB:@80aW]:
0P3FW7<20<jDH`80[F]20P3>S5X20<jDJ`80eZf4103NYG<40<j<FP80cYAS0P3FW7<20=j]S080gZEk
103W_I@20>oWgP80ikfL0P3WaZd20>oFaP80knOW0P3_imh20>oWi`@0mnoW0P3_koL20?Ogm`80mnog
403oool000h0oooo0P3gknL40>o_m`80mnoW0P3_koL20?Ogm`80knoW0P3gknL20>o_i`H0moOg0P3g
knL20?Ogm`@0mnoW0P3gmoL20>o_m`80moOg0P3gkoL20>o_m`80moOg0P3_koL20?O_i`80moOg0P3g
knL20?Ogm`80mnog0P3gknL20>o_i`80kmk>0`3_imh20>O6]@80e[f]0P36Nd820<J4FP80]F/i0P2D
DRT407/i60@0gZfD0P3W]I@20=j]U080ikfL0P3W_I@20>NeU0`0klJU103__I`40>o6Y@P0kkfL0P3_
]I@20>NmW080kkfL1P3_aZD60>nmW080ikfL0P3_]I@20>NmU080ikFD1P3__I`20>neU080ikfL0P3W
[H`20>NmW080ikfD303__I`20>NmU0@0gZf40P3NYG/90=JLL`80aXAJ0P2LHcT209AB:@80aW]:0P3F
W7<20<jDH`80[F]20P3>S5X20<jDJ`80eZf4103NYG<40<j<FP80cYAS0P3FW7<20=j]S080gZEk103W
_I@20>oWgP80ikfL0P3WaZd20>oFaP80knOW0P3_imh20>oWi`@0mnoW0P3_koL20?Ogm`80mnog403o
ool000h0oooo0P3_knL20?Ogm`80mnog0P3_koL20?Ogm`@0knog0P3gkoL20?Ogm`@0mnog0P3gmoL2
0?O_m`80moOg0P3gkoL40?Ogm`80mnog0P3gmoL20?O_m`@0mnoW0P3gmoL20?O_m`80knog0P3_knL2
0?O_m`80mnoW0P3gkoL20>o_i`80mnoW1@3Wg]H20=J]Q080aXAJ0P36NdX20:eS<@80U58Y0P2<@R42
07/i6080Jc4H0P3N[H`20>NeW080cZfD0P3W_I@20>NeU080ikfD0P3__I`20>o6Y@P0kkfL0P3_aZD4
0>nmW080klJU103__I`20>o6Y@@0kkfL0P3_]I@20>NmU0@0kkfL0P3W_I`20>o6Y@80kkfL0P3_]I@2
0>NeU080kkFD203W]I@20>NmU0@0ikFD1P3W[H`20>neU080kkfL0P3W[H`20>nmW080gZf40P3W_I@2
0>NeU080ijf<103NYG/20=JLL`80cYA[0P36Q5X30;EcBP80U58Y0P2]FS420:eS<@80aXAJ103>U6<2
0<J<H`@0eYac0P3NYG<40=JLL`80gZEc0P3>S5X20<jDH`@0gZEk0P3N[H@20>NmU080ikfU0P3W_I`2
0>O6[@80imK60P3_imh20>oWi`80imkF0P3_inL40?O_m`80knog103gmoL@0?ooo`003P3oool20>o_
i`80moOg0P3gkoL20>o_m`80moOg103_koL20?O_m`80moOg103gkoL20?Ogm`80mnog0P3gmoL20?O_
m`@0moOg0P3gkoL20?Ogm`80mnog103gknL20?Ogm`80mnog0P3_koL20>o_i`80mnog0P3gknL20?O_
m`80knoW0P3gknL50>ONeP80eZf40P36Q5X20<IkBP80[F<a0P2DDRT208a28@80NcTH0P1[<AP20=j]
S080ikFL0P3>[I@20>NmU080ikFD0P3W_I@20>nmW080klJU203__I`20>o6Y@@0kkfL0P3_aZD40>nm
W080klJU103__I`20>neU080ikfD103__I`20>NmW080klJU0P3__I`20>neU080ikFD0P3_]I@80>Ne
U080ikfD103W]I@60>N]S080kkFD0P3__I`20>N]S080kkfL0P3N[H@20>NmU080ikFD0P3W[H`40=jU
N`80eYac0P3>U6/20<J4FP<0]G=:0P2DDRT20:eJ<@80[F<a0P36Q5X40<jDH`80aXaS103FW7<20=jU
L`@0eYac0P3NYG<20<j<FP80cYAS103NYG/20=j]Q080ikfD0P3W_JD20>NmW080ilJ]0P3We/H20>oW
gP80knOW0P3Wg]H20>oWi`@0mnog0P3_koL40?Ogma00oooo000>0?ooo`80mnoW0P3_knL60?Ogm`80
knoW1P3gmoL20?O_i`80knog0P3gmoL20?O_i`80mnog0P3_knL20?O_m`@0knog1P3gmoL40?O_m`80
moOg103_koL20?O_i`80mnog0P3gknL20>oWi`80knON0`3Wc[d20>oNcP80cXaJ0P36Q5X20<Ik@P80
[EXa102DDRT208a28@80Jc4H0P1:60P20=JUQ080gZfL0P3N[I@40>NeU080ikfU0P3W_I`80>nmW080
klJU0P3__I`20>o6Y@P0kkfL0P3W_I`40>nmW0@0kkFD0P3W_I@20>neU0@0kkfL0P3W_I`20>NmU080
kkFD0P3W]I@20>neU080ijf<0P3N[H@20>N]S080kkFD103W[H`20>neU080ijf<0P3W_I@20>NeU080
ijf<0P3N[H@20>NeU0@0gZf<0P3N[H@20=jUN`80eYak0P3>S6<20;EcBP80[F/i0`2]Hc4209aS>@80
[F]20P2mS6<20<jDJ`80cXaJ0P36S6<20<jDH`80eYac0P3>U6<40<J4FP80cYAS0P3>S5X20=jUL`@0
gZEk0P3NYG<20>NmU0@0ikfU0P3WaZd40>oWgP80kmk>0P3_inL20?O_m`80mnoW2P3gmoL@0?ooo`00
3P3oool20?O_i`80knoW1P3gmoL20>o_i`H0moOg0P3gknL20>o_m`80moOg0P3gknL20?O_m`80knoW
0P3gkoL40>o_m`H0moOg103gkoL20?Ogm`@0knog0P3gknL20?O_m`80mnoW0P3_inL20>oWgP<0iljm
0P3_g/h20<j<FP80aXAJ0P36Nd820:eJ<@@0U58Y0P2<@R4206/a6080BQP80P3FYH@20=j]W080gZfD
103W]I@20>NmY@80ikfL203__I`20>o6Y@80kkfL0P3_aZD80>nmW080ikfL103__I`40>neU080ikfD
0P3_]I@40>nmW080ikfL0P3W_I@20>neU080ikFD0P3_]I@20>N]S080gZf40P3W[H`20>neU0@0ijf<
0P3_]I@20>N]S080ikfD0P3W]I@20>N]S080gZf40P3W]I@40=j]S080gZf40P3NYG/20=JLN`80cXaS
0P2eLdX20:e[>@<0[F<a0P2LHcT20:e[@P80_HaS0P3>U6/20<j<FP80aXaS0P3>U6<20=JLL`80cYAS
1036Q5X20<jDH`80cXaJ0P3NYG<40=jUN`80gZEc0P3W_I@40>NmY@80ilJ]103_imh20>oNcP80knOW
0P3gkoL20?O_i`X0moOg403oool000h0oooo0P3_knL20?Ogm`80mnog1P3gmoL20?O_i`80mnog103g
moL20?O_m`80knog0P3_knL20?O_m`P0moOg0P3gkoL20>o_m`H0mnog0P3gmoL60?O_m`80knog0P3g
knL20?O_m`80knOW0`3We/H20>ONeP80cYAS0P36Q5X20<IkBP80[F<a102DDRT208a28@@0HbT@0P1:
60P40=j]U080ikfL0P3W]I`40>NmW0X0kkfL103_aZD>0>nmW0@0ikfD0P3__I`20>neU080ikfL0P3_
]I@20>neW0P0ikFD203W[H`20=j]Q080gZEk0P3N[H@20>N]S080gZf40P3W_I`20=jUN`80gZf<103N
[H@20=JLN`80gZF40P3FW7<20<IkBP80[EXa0P2]JcT208A28@<0[F]20P2eLdX20<IkBP80cYAS0P3>
S5X20<J<H`80aYA[0P36S6<20=jUL`H0eYac103NYG<20=jUN`80gZf40P3F[H@20>NmU080ikfL103W
_JD20>o>_@80kmK60P3_g/h20>oWgP80knoW0P3gknL20?Ogm`80mnog0P3gmoL20?O_m`80knog0P3g
moL@0?ooo`003P3oool20>o_i`80moOg0P3gkoL60?Ogm`80mnoW0P3gkoL40?Ogm`80mnog0P3_koL2
0>o_i`80mnog203gmoL20?O_m`80knog1P3gkoL20?Ogm`H0mnog0P3_koL20?O_i`80mnog0P3_inL3
0>OFaP80imkF0P3>U6<20<J4FP80aW]:0P2]Hc4409AB:@80S48Q101S:A0204XH20@0gZfD0P3W_I`2
0>NeW0@0ikfL2P3__I`40>o6Y@h0kkfL103W_I@20>nmW080kkFD0P3W_I`20>neU080kkFL203W]I@8
0>N]S080gZf40P3NYG/20=j]Q080ijf<0P3N[H@20>NmW080gZEk0P3N[H`40=j]Q080eYak0P3NYH@2
0=JLL`80aW]:0P2]FS420:e[>@80Q48Q0`2]Jd820;EcBP80aW]:0P3>U6<20<j<FP80aXaS0P36U6/2
0<J<H`80gZEc1P3FW7<40=jUL`80gZEk0P3N[H@20=J]Q080ikfD0P3W_I`40>NmY@80kljm0P3_e/H2
0>oNcP80knON0P3_knL20?O_i`80moOg0P3gkoL20?Ogm`80mnog0P3_koL20?Ogma00oooo000>0?oo
o`@0moOg0P3_knL20?Ogm`80mnog1P3gmoL40?O_m`80knoW0P3gkoL20?Ogm`80knog0P3_knL40?O_
m`@0moOg0P3gknL20?O_m`80moOg103_koL20?O_m`80moOg0P3gkoL20>o_m`80mnoW0P3_knL20>oW
gP<0imkF0P3Wc/H20<jDH`80aXAJ0P2eJd820:eS<@80W6<i0P2DDRT207/i6080HbT@0P1B8A0206/a
60@0gZfD0P3W]I@40>NmW080ikfU0P3W_I`20>o6Y@80kkfL0P3_aZD:0>nmW080kkFD103__I`20>Nm
U080kkfL0P3_]I@20>NmW080kkFD103W]I@20>N]S0P0ikFD103W[H`20=j]Q080gZF41P3NYG/20=j]
Q080ikfL0P3N[H@20=JLN`80eYac0P3FW7/40=jLL`@0cXaS0P36Nd820<IkBP80S4Xa0P2]FS4209aS
>@<0[F/i0P2LHcT20<IkBP80cXaJ1036Q5X20<J<H`@0eYac0P3F[H@20=j]S080eYac0P3NYG<20>Nm
U080eZf40P3N[H@40>NmU080ikfU0P3W_I`20>o>_@@0kmK6103gknL40?Ogm`@0mnog0P3gmoL20>o_
m`@0moOg403oool000h0oooo103gmoL20>o_i`80moOg0P3gkoL60?Ogm`@0mnog0P3_knL20?O_m`80
moOg0P3_koL20>o_i`@0mnog103gmoL20?O_i`80mnog0P3gmoL40>o_m`80mnog0P3gmoL20?O_m`80
knog0P3gknL20>o_i`80knON0`3Wg]H20>O>aP80cYAS0P36Q5X20;E[@P80[F<a0P2LHcT209AB:@80
NcTH0P1S:A02058Q4080Jc4H103N[I@20>NeU0@0ikfL0P3W_JD20>NmW080klJU0P3__I`20>o6Y@X0
kkfL0P3_]I@40>nmW080ikfD0P3__I`20>neU080ikfL0P3_]I@40>NeU080ijf<203W]I@40>N]S080
gZf40P3NYH@60=jUN`80gZf40P3W_I`20=j]Q080eYak0P3FW7<20=JLN`@0gYac103>S6<20<Ik@P80
aW]:0P2<BS420:eJ<@80W6<i0`2]JcT209aS>@80aW]:0P3>S5X40<J4FP80aXaS103FW7<20=J]Q080
gZf<0P3FW7<20=jUL`80ikfD0P3F[H@20=j]Q0@0ikfD0P3W_JD20>NmW080kljm103_e/H40?O_i`@0
moOg103gkoL20?Ogm`80knog103gmoL@0?ooo`003P3oool20?Ogm`80mnog103gknL20?O_m`80knog
0P3gmoL20?O_i`80moOg0P3gknL20>o_m`@0moOg0P3gkoL20?Ogm`80mnoW0P3gmoL60?O_m`80moOg
103_koL40?Ogm`80mnog0P3gmoL20?O_i`80mnog0P3_knL20?OWgP<0imK60P3F[H@20<jDH`80aXAJ
0P2eLdX20:eJ<@80]F/i0P2DDRT208a::@@0Jc4H0P1k@R4207]::@80gZfL0P3W_I@20>NmW080klJU
103W_I`20>o6Y@`0kkfL0P3W_I`20>nmW080ikfL0P3W]I@20>neW080kkfL0P3W_I@40>neU080ikfD
0P3W[H`20>NmU080gZf40P3W]I@20>NmU080ikFD103W[H`40=jUQ080cYA[0P3FW7<20=j]S080ikfL
0P3N[H`20<j<H`80cYA[0P3FW7<20<jDJ`80eYac0P3>U6/20<IkBP80aW]20P2eHc420:eS<@80aW]:
0P2]Jd850<IkBP80_HaS0P3>U6<20<jDJ`80aXaS0P3>S5X20<J<H`80eYac0P3>S5X20<jDJ`@0eYac
0P3NYG/40=JLL`H0ikfD0P3W_I`20>O>_@80kmK6103_imh20?O_m`80moOg0P3_koL20>o_i`@0moOg
103gkoL20?Ogm`80mnog403oool000h0oooo0P3gmoL20?O_m`@0mnoW0P3gkoL20>o_m`80moOg0P3g
knL20?Ogm`80mnoW0P3_koL40?Ogm`80mnog0P3gmoL20?O_i`80moOg1P3gkoL20?Ogm`@0knog103g
moL20?O_m`80moOg0P3gknL20?O_m`80knoW0P3gimh30>OFaP80eZf40P3>U6<20<J4FP80]G=:0P2]
FS420;E[>@80U58Y0P2<BRT406/a6080Nd8Q0P1kBRT20=j]W080ikfD0P3W_I`20>o6Y@@0ikfL0P3_
aZD<0>nmW080ikfL0P3__I`20>NmW080ikFD0P3_]I`20>nmW080ikfD103_]I@20>NmU080ijf<0P3W
_I@20=j]Q080ikFD0P3W_I@20>NeU0@0ijf<103NYH@20<jDJ`80eYac0P3N[H`20>NmW080gZf<0P3>
S6<20<jDJ`80eYac0P3>U6/20=JLL`80cYA[0P36NdX20<Ik@P80]F<a0P2]Hc420<IkBP80[F]21@36
NdX20;f<H`80cYAS0P3>U6/20<J<H`80cXaJ0P36S6<20=JLL`80cXaJ0P3>U6/40=JLL`80gZEk103F
W7<60>NmU080ikfL0P3Wc[d20>oFaP@0knON0P3gkoL20?Ogm`80knog0P3_knL40?Ogm`@0mnog0P3g
moL20?O_ma00oooo000>0?ooo`@0moOg0P3_koL20?Ogm`80knog103gkoL40?Ogm`80mnoW203gmoL2
0>o_m`80mnog0P3gmoL20>o_m`80mnog0P3_knL20>o_m`80moOg0P3_koL20?O_m`80moOg0P3gknL2
0?O_m`80mnoW0P3_knL20>oWgP80knOW0`3Nc[d20=J]Q0@0aXAJ0P2eJd820;EcBP80[F/i102<BRT2
07/i6080Q48Q0P2<@R4206<Y4080gZfD0P3W_I`20>NmY@80klJU103W_I`20>nmW080kkFD0P3W_I@2
0>nmW080kkFD0P3W_I@40>nmW080ikfD0P3_]I@20>NmU0@0kkFD0P3__I`60>NeU080ikfD0P3N[H@2
0>neU080gZf40P3W[H`20=j]S080gZf40P3NYH@20=jLN`80cYA[103FW7<20>NmU080ikfL0P3>S6<2
0<jDJ`@0eYac0P3>S6<20;EkFP80]F]B0P2LHcT20<Ik@P80]F/i0P2]Hc420:e[>@80aW]20P36NdX3
0;E[@P80aXAJ103>U6<20<j<FP80aXAJ0P2eLdX20=J]Q080cYAS0P3F[H@20<jDJ`80ikfD0P3FW7<2
0=jUN`P0ikfD0P3WaZd20>O6]@80knON103_inL20?O_m`80moOg0P3_knL60?Ogm`80knog1P3gmoL@
0?ooo`003P3oool40?Ogm`80knog0P3gmoL20>o_m`@0mnog103gmoL20?O_i`P0moOg0P3_koL20?O_
m`80moOg0P3_koL20?O_m`80knoW0P3_koL20?Ogm`80knog0P3gkoL20?Ogm`80mnoW0P3gkoL20?O_
i`80knoW0P3_imh20>oWi`<0g/jm0P3F[H@40<J4FP80]F]20P2eLdX20:e[>@@0S4XY0P1k>AP208A2
8@80S48Q0P1S:A020=j]U080ikfL0P3W_JD20>o6Y@@0ikfL0P3__I`20>neU080ikfD0P3__I`20>ne
U080ikfD103__I`20>NmU080kkFD0P3W_I@40>neU080kkfL1P3W]I@20>NmU080gZf40P3_]I@20=j]
Q080ijf<0P3N[H`20=j]Q080gZF40P3NW7/20<jDJ`@0eYac0P3W_I@20>NmW080cXaS0P3>U6/40=JL
L`80cXaS0P2eNeX20;E[DP80W6<i0P36Nd820;E[>@80[F<a0P2]JcT20<Ik@P80aW]:0`2eJd820<J4
FP@0cYAS0P3>S5X20<J4FP80]G=:0P3F[H@20<jDH`80eZf40P3>U6/20>NmU080eYac0P3NYG/80>Nm
U080ilJ]0P3Wa[D20>oWgP@0knOW0P3gkoL20?Ogm`80knoW1P3gmoL20>o_m`H0moOg403oool000h0
oooo0P3gmoL20>o_m`80moOg0P3gknL:0?Ogm`80mnog203gmoL20?O_m`80mnoW103gmoL40?O_m`80
knoW0P3gmoL20?O_m`80moOg103_koL40?Ogm`80mnoW103_imh30=j]U080eZf40P36Q5X20;EcBP80
[F]2102LHcT208a28@80S4XY102DDRT207/i6080BQP80P3W_I`20>NeU080ikfU0P3W_I`20>nmW080
ikfL0P3__I`40>neU080kkfL303_]I@40>NmU080kkFD0P3W]I@20>NmU0@0ikFD1P3N[H@20>N]S080
gZf4103N[H`20=jLN`80eYac103>S6<20=j]Q080gZfD0P3>S6<40<J4H`80aXaS0P36Q6<20;EkFP80
[G=B0P2<FT820:e[@P80aW]21P2eJcT20;E[@P80[F]20`2eJd820<J4FP80cYAS0P3>U6/40;f<H`80
cYAS0P3FW7/20<jDJ`80eYac103>U6/40=jUL`80gZEk103W_I`20>NmY@80kmK60P3gknL20>oWgP80
knOW0P3_knL40?Ogm`80mnog103gmoL20>o_m`80mnog0P3_koL40?Ogma00oooo000>0?ooo`80moOg
0P3_koL20?Ogm`80mnoW2P3gmoL20?O_m`P0moOg0P3gkoL20?O_i`@0moOg103gkoL20>o_i`80moOg
0P3gkoL20?Ogm`@0knog103gmoL20?O_i`@0knON0`3N[I@20=J]Q080aXAJ0P2eLdX20:e[@P@0W6<i
0P2<@R4208a::@@0U58Y0P1k>AP204XH2080ikfL0P3W]I@20>NmY@80ikfL0P3__I`20>NmW080kkfL
103_]I@20>nmW0`0kkFD103W_I@20>neU080ikFD0P3W_I@40>NeU0H0gZf40P3W[H`20=j]Q0@0gZf<
0P3NW7/20=JLL`@0cXaS0P3N[H@20=j]U080cXaS1036Q6<20<J<H`80aXAS0P2eNeX20:ecDP80S5Y2
0P2]Jd820<Ik@PH0]F/i0P2eJd820:e[@P<0]F]20P36Q5X20<jDH`80cYA[102mS6<20<jDH`80eYak
0P3>U6/20=JLL`@0cYA[103NYG<20=jUN`@0ikfL0P3W_JD20>oFaP80mnoW0P3_imh20>oWi`80knoW
103gmoL20?O_m`@0moOg0P3_koL20?O_m`80knog103gmoL@0?ooo`003P3oool60?Ogm`80knog103g
moL20?O_m`80moOg0P3gkoL20?Ogm`80mnog203gmoL:0?O_m`@0moOg0P3gkoL20?Ogm`80knog1P3g
moL20>o_m`80knON0P3We/h30=J]Q080eYac0P2mS6<20;EkFP80]F]20P2]Jd8208a::@80Q48Q0P2D
DRT209AJ<@80S4XY0P1[>B4206/a6080ikfU0P3W]I`20>o6Y@80ikfU0P3W]I@20>nmW0@0ikfL0P3_
_I`20>neU080kkFL0P3W_I@20>neU080ijf<103_]I@80>N]S080kkFD0P3N[H@20>N]S080gZf<0P3N
[H@20>N]S080gZEk0P3NYH@20=jUN`80eYak0P3FW7<20<J4J`80cXaS0P3>U6<20=JLL`80cYA[0P36
Q5X20<J4H`@0aXAJ0P2eNeX209aS>@@0W6]:0P2]JcT20<j<FP80aW]:0P36Nd820;E[>@80[F/i0P2m
S6<30<IkBP80aXAJ0P2mS6<20<j<FP80aYA[0P3F[H@40=JLL`80aYA[1P3>U6/20=JLL`80ikfD0P3W
_JD20>o6Y@80ikfU0P3_e/H20>oNcP80knON0P3_knL20>oWgP80knoW0P3gknL20>o_i`@0moOg0P3g
koL:0?Ogma00oooo000>0?ooo`H0moOg0P3_koL40?Ogm`80mnog0P3gmoL20?O_m`80moOg0P3gkoL8
0?Ogm`X0mnog103gmoL20?O_m`80moOg0P3_koL60?Ogm`80knog0P3_imh20>OFcP<0eZf40P3FW7<2
0;f<H`80]G]J0P2eJd820:e[@P80S4XY0P24@R4209AB:@80U5Xa0P2<BRT206/i8@80Jc4H0P3W_JD2
0>NeW080klJU0P3W_JD20>NeU080kkfL103W_I`20>nmW080kkFD0P3_]I`20>NmU080kkFD0P3W[H`4
0>neU0P0ijf<0P3_]I@20=j]Q080ijf<0P3N[H`20=j]Q080ijf<0P3NYG/20=jUQ080gZEk0P3FW7/2
0=JLL`80aXA[0P3>S6<20<jDH`80eYac0P3>U6/20<J4FP80aXAS1036Q5X20;EkFP80W6<i102LJdX2
0:e[>@80cXaJ0P36NdX20<Ik@P80]F/i0P2]JcT20;f<H`<0aW]:0P36Q5X20;f<H`80cXaJ0P36U6/2
0=J]Q0@0eYac0P36U6/60<jDJ`80eYac0P3W_I@20>NmY@80klJU0P3W_JD20>oFaP80kmk>0P3_imh2
0>o_i`80knON0P3_knL20?O_i`80knoW103gmoL20?O_m`X0moOg403oool000h0oooo0P3gmoL20?O_
m`H0moOg103gkoL40?Ogm`80mnog203gmoL20?O_m`80moOg103gkoL40?Ogm`80mnog0P3gmoL:0?O_
m`80mnoW0P3_koL20>oWgP80imK60`3F[H`20<jDJ`80aXAJ0P2eLdX20:e[@P80[F/i0P2DFS4209AB
:@80[F/i0P2DDRT406/a6080HbT@0P3W_JD20>NeW080ikfL0P3N[I@20>NmW0@0kkfL103W[H`20>ne
U080ikFD1P3W[H`20=j]Q0@0ijf<103N[H@20>N]S080gZF40P3W[H`80=jUQ0@0gZEk103FW7<20<jD
J`80cXaJ0P36Q6<20=JLN`80aXaS0P2eNeX20;E[DP80aW]:0P2eLdX20;EkFP80U6=20P2eLdX209ac
DP80[F/i0P2]Jd820<IkBP80cXaJ0P36Q5X20;EcBP80aW]:0P2eNeX30<IkBP80_HaS0P2eLdX20<J<
H`80aYA[1P3F[H@20<jDH`80cYA[0P3F[H@20<jDH`80eYac0P3W_I@20>NmW080ilJ]0P3_e/H20>oW
gP80mnoW0P3_imh20>o_i`80knON103gknL60?Ogm`80mnog0P3_koL20?O_m`80knog0P3gkoL20?Og
ma00oooo000>0?ooo`80moOg0P3gkoL60?Ogm`@0mnog103gmoL20?O_m`P0moOg0P3gkoL20?Ogm`@0
mnog103gmoL20?O_m`80moOg2P3gkoL20?O_i`80knog0P3_imh20>OFaP<0eZf<0P3>U6/20<J4FP80
]G=:0P2]Jd820:e[>@80U5Xa0P2DDRT20:e[>@80U58Y101[<AP206<Y4080ikfU0P3W]I`20>NmW080
gZfD0P3W_I`40>nmW0@0ijf<0P3_]I@20>NeU0H0ijf<0P3N[H@40>N]S0@0gZf40P3W[H`20=jUQ080
ijf<203NYH@40=jUN`@0eYac0P3>U6/20<j<FP80aXAS0P3FW7/20<J<H`80]G]J0P2eJe820<IkBP80
]G=:0P2eNeX209AS@P80]G=:0P2LLe820:e[>@80[F]20P36NdX20<j<FP80aXAJ0P2eLdX20<IkBP80
]G]J0`36NdX20;f<H`80]G=:0P36S6<20<JDJ`H0eZf40P3>U6<20<jDJ`80eZf40P3>U6<20=JLL`80
ikfD0P3W_I`20>O6[@80kmK60P3_imh20?O_i`80knON0P3_knL20>oWgP@0mnoW1P3gmoL20?O_m`80
knog0P3gkoL20>o_m`80mnog0P3gmoL@0?ooo`003P3oool60?Ogm`80mnog103gmoL20?O_m`H0moOg
0P3gkoLB0?Ogm`80mnog0P3gmoL40?O_m`80moOg0P3gknL20>o_m`@0moOg0P3_imh20>NmY@D0eYac
0P2mS6<20;EcBP@0[F]20P2<BRT209aS>@80U58Y0P24@R4206<Y4080JcTQ0P1S:A0:0>NmW080ikFD
0P3__I`20>NmU080ijf<0P3_]I@20>N]S080gZf40P3W[H`20=j]Q080gZF40P3N[H@20=jUQ080gZf4
1P3NYH@20=j]S080gZf40P3NYG/20=jLN`80eYak0P3NYG/40=JLN`80eYac0P3>U6/20<J4FP80cYA[
0P3>S6<20;EkFP80]F]B0P2eLdX40:e[@P80U5Xa102LJdX209AB:@80W6<i0P2eJd860<j<FP80cYA[
1036NdX50;EcBP80_HaS0P36U6/20<J4FP80eZF40P3F[H@20=JLN`80aYA[0P3F[H@20=j]S080eYac
0P3N[H@40>NmU080kmK60P3gg/h20>oWgP80imkF0P3_imh20>o_i`H0mnog0P3gmoL20?O_m`H0moOg
103gkoL20?Ogm`80mnog403oool000h0oooo1P3gmoL20?O_m`@0moOg0P3gkoL60?Ogm`80mnog4P3g
moL20?O_m`80moOg103gkoL20?Ogm`80mnoW0P3_koL40?Ogm`80knON0P3W_JD50=JLL`80_HaS0P2e
LdX40:e[@P80S4XY0P2LHcT209AB:@80Q48Q0P1S:A0206/i8@80HbT@2P3W_I`20>NeU080kkfL0P3W
_I@20>N]S080kkFD0P3W[H`20=j]Q080ijf<0P3N[H@20=jUQ080gZf40P3NYH@20=j]Q0H0gZF40P3N
[H`20=j]Q080gZEk0P3NW7/20=JLN`80gZEk103FW7/20=JLL`80cYA[0P36Q5X20<jDJ`80cXaS0P2e
NeX20;E[DP80]G=:102]Jd8209AJ<@@0W6]:0P2DDRT209aS>@80]F]21P3>S5X20<jDJ`@0aW]:1@2e
LdX20;f<H`80aYA[0P36Q5X20=JUQ080eZf40P3FW7/20<JDJ`80eZf40P3N[H`20=JLL`80gZf4103W
_I@20>oFaP80mmk>0P3_imh20>ONeP80knON0P3_knL60?O_m`80moOg0P3gkoL60?Ogm`@0mnog0P3g
moL20?O_ma00oooo000>0?ooo`P0moOg103gkoL20?Ogm`80mnog0P3_koL80?Ogm`80mnog2P3gmoL2
0?O_m`@0moOg0P3gkoL20>o_i`80mnog0P3_knL20?Ogm`80mnog103gknL20<j]U0<0eYac0P36S6<2
0<J4FP80W6<i0P2LJdX209AJ<@80W4Xa0P2LHcT209a:<@80Nd8Q0P1[>B4207]28@80Jc4H0P3W_JD2
0=j]W080ikfL0P3W]I@20>NmW080ikFD0P3W[H`20>NmU0H0ijf<0P3N[H@60=jUQ080gYac0P3NW7/2
0=jUN`@0gYak0P3NYH@40=jUN`80eYac0P3NW7<80=JLL`@0cXaS0P36Q5X20<jDJ`80aXAJ0P2eLdX2
0:e[@P@0[F=20P2DHd820:e[@P80W6]:102DFS4209aS>@80]F/i0P36Nd820<j<FP80aXAJ0P3>S5X2
0<J4FP80_HaS1@2eLdX20;E[@P80aXAJ0P3FW7<20=JLN`80eYac103F[H`20=J]Q080cYA[0P3FW7<2
0=j]Q080ikfL0P3Wa[D20>oNcP80imkF0P3_imh20?O_i`80knoW0P3_imh20?O_m`80moOg0P3gkoL:
0?Ogm`80mnog103gmoL20?O_ma00oooo000>0?ooo`P0moOg103gkoL20?Ogm`80mnog0P3_koL80?Og
m`80mnog2P3gmoL20?O_m`@0moOg0P3gkoL20>o_i`80mnog0P3_knL20?Ogm`80mnog103gknL20<j]
U0<0eYac0P36S6<20<J4FP80W6<i0P2LJdX209AJ<@80W4Xa0P2LHcT209a:<@80Nd8Q0P1[>B4207]2
8@80Jc4H0P3W_JD20=j]W080ikfL0P3W]I@20>NmW080ikFD0P3W[H`20>NmU0H0ijf<0P3N[H@60=jU
Q080gYac0P3NW7/20=jUN`@0gYak0P3NYH@40=jUN`80eYac0P3NW7<80=JLL`@0cXaS0P36Q5X20<jD
J`80aXAJ0P2eLdX20:e[@P@0[F=20P2DHd820:e[@P80W6]:102DFS4209aS>@80]F/i0P36Nd820<j<
FP80aXAJ0P3>S5X20<J4FP80_HaS1@2eLdX20;E[@P80aXAJ0P3FW7<20=JLN`80eYac103F[H`20=J]
Q080cYA[0P3FW7<20=j]Q080ikfL0P3Wa[D20>oNcP80imkF0P3_imh20?O_i`80knoW0P3_imh20?O_
m`80moOg0P3gkoL:0?Ogm`80mnog103gmoL20?O_ma00oooo000>0?ooo`80moOg103gkoL20?Ogm`@0
mnog1P3gmoL20?O_m`80knog103gmoL20?O_m`@0moOg103gkoL20?O_i`80knog0P3gmoL40?O_m`@0
moOg0P3gkoL20?Ogm`80knoW0P3gknL20>OFaP80eZf<0`3FW7<20<J4FP80]G]J0P2]Jd820;EcBP80
U58Y102LHcT209AJ<@80FS4Q0P1S:A0206/a6080JcTQ0P3W_I`20=j]U080ikFL0P3N[I@40>NeU0H0
ijf<0P3NYH@20=j]Q080gZEk0P3NW7/20=jUN`@0gYak0P3NW7<60<jDJ`@0eYac0P3NW7/40=JLL`H0
cYA[103>S6<20<J4H`80_HaS0P2eLdX20:e[@P80[F/i0P2LHcT20:eS@P@0[F]21P2LHcT20:eS<@80
]F/i0P2eJd820<Ik@P80cXaJ0P3NYG<20=JLL`80gZf40P36S6<50:e[>@80]G=:0P36S6<20<J4FP80
eYac1P3F[H@60<jDH`80ikfD0P3WaZd20>O6]@80imkF0P3_imh20>oNcP80knoW0P3_imh20?Ogm`80
mnog203gmoL20?O_m`H0moOg0P3_koL20?Ogm`80mnog403oool000h0oooo0P3gmoL40?O_m`80moOg
103gkoL60?Ogm`80mnog0P3_koL40?Ogm`80mnog103gmoL40?O_m`80mnoW0P3_koL20?Ogm`@0mnog
103gmoL20?O_m`80moOg0P3_knL20?O_i`80imK60P3F[H`30=JLL`80aXAJ0P2eNeX20:e[@P80]G=:
0P2DDRT409aS>@80U5Xa0P1J<B4206<Y4080Jc4H0P1[>B420>NmW080gZfD0P3W]I`20=j]U0@0ikFD
1P3W[H`20=jUQ080gZf40P3NYG/20=jLN`80gZEk103NW7/20=jLL`H0cYA[103FW7<20=jLN`@0eYac
1P3>U6/40<j<H`80aXAS0P2mS6<20;EcBP80[F]20P2]JcT209aS>@80[F=2102]Jd8609aS>@80[F<a
0P2eJcT20;E[@P80aW]20P3>S5X20=jUL`80eYac0P3N[H@20<J<H`D0[F/i0P2eLdX20<J<H`80aXAJ
0P3FW7<60=J]Q0H0cYAS0P3W_I@20>O6[@80ilJe0P3Wg]H20>oWgP80kmk>0P3_knL20>oWgP80moOg
0P3gkoL80?Ogm`80mnog1P3gmoL20>o_m`80moOg0P3gkoL@0?ooo`003P3oool20?O_m`@0moOg103g
koL20?O_i`@0knog0P3gkoL60?Ogm`80knog0P3gmoL20?O_m`80moOg0P3gkoL20?Ogm`80mnoW2P3g
moL20?O_m`80knog0P3gkoL40?O_i`80ikfU0P3F[H@30<JDJ`80_HaS0P2eLdX209aS>@80W6]:0P2D
FS420:e[>@80S4XY0P24@R44058Y60@0Jc4H0P3W_I`20=j]U080ikFD0P3W]I`20>NeU0@0ijf<0P3N
YH@80=jUN`80gYac0P3FW7/20=JLL`80gYac103FW7<80<jDJ`@0eYac1P3>U6/40<J4H`80aXAJ0P2e
NeX20<J4FP80]F]20P2LHcT209AJ<@80[F]20P2LHcT40:e[@P@0Nd8Q0P2<BRT20;ES<@H0aW]20P36
Q5X20<jDH`80eYac0P3>U6/20=J]Q0<0_HaS0P2eLdX40<J4FP80cYA[0P36Q5X40=J]S080cYA[0P3>
U6<20<jDJ`80cYAS0P3W_I@20>O6[@80knON0P3Wg]H40>oWgP80knOW0P3_koL20?Ogm`80knoW0P3g
knL40?Ogm`80mnog1P3gmoL20?O_m`H0moOg403oool000h0oooo0P3gkoL40?Ogm`@0mnog0P3gknL4
0>o_m`80mnog1P3gmoL20>o_m`80moOg0P3gkoL20?Ogm`80mnog0P3gmoL20?O_i`X0moOg0P3gkoL2
0>o_m`80mnog103gknL20>NmY@80eZf40`36U6/20;f<H`80]G=:0P2LHcT209a[BP80U5Xa0P2]JcT2
08a::@80Q48Q101B:AP406/a6080ikfL0P3N[I@20>NeU080ikFL0P3W]I@40>N]S080gZF4203NYG/2
0=jLL`80eYak0P3FW7<20=jLL`@0eYac203>U6/40=JLL`H0cYA[1036Q6<20<J4FP80]G]J0P36Q5X2
0;E[@P80W6<i0P2DFS420:e[@P80W6<i102]Jd8407]28@80S4XY0P2eHc460<Ik@P80aXAJ0P3>U6<2
0=JLL`80cYA[0P3F[H@30;f<H`80]G=:1036Q5X20<jDJ`80aXAJ103F[H`20<jDJ`80cYAS0P3>U6/2
0<jDH`80ikfD0P3WaZd20>oWgP80imkF103_imh20>oWi`80knog0P3gmoL20>o_i`80mnoW103gmoL2
0?O_m`H0moOg0P3gkoL60?Ogma00oooo000>0?ooo`P0moOg0P3gkoL@0?Ogm`80mnoW0P3gkoL20?Og
m`80mnoW0P3gmoL20?O_m`80moOg0P3gkoL20?Ogm`80mnog0P3gknL20?O_m`80moOg0P3_knL20?O_
m`80imkF0P3F]JD20=J]Q0<0_HaS0P2eNeX20:e[@P80W6]:102DFS4209aS>@80S4XY0P1k>AP206/a
60@0JcTQ0P1k>AP40=j]U0@0gZf<0P3W[H`20=j]S080gZF40P3N[H`40=jUQ080eYak103NW7<60<jD
J`80aXA[103>S6<20<J4J`@0cYA[0P36Q6/60<jDJ`80aXAS0P36Q5X20<J4H`80aXAJ0P2eLdX20<j<
FP80[F]20P2<BRT409a[BP80W6<i0P2DFS4208A28@80Nd8Q0P1S:A020:eS<@80aW]20P2eHc420<Ik
@P80]F]20P36NdX20<jDH`80gZEc0P3FW7/20=j]Q0D0_HaS0P3>U6<20;f<H`80cYA[0P36U6/20=J]
Q0@0cYA[0P36Q5X20<j<FP80gZf40P3WaZd20>oFaP@0kmk>0P3Wg]H20>o_i`@0mnoW0P3gmoL40?O_
m`H0moOg0P3_koL20?Ogm`80mnog0P3gmoL20?O_m`@0moOg403oool000h0oooo203gmoL20?O_ma00
moOg0P3gknL20?O_m`80moOg0P3gknL20?Ogm`80mnog0P3gmoL20?O_m`80moOg0P3gkoL20?O_i`80
mnog0P3gmoL20>o_i`80mnog0P3Wg]H20=JeY@80eZf40`2mS6<20;EkFP80[F]20P2LJdX409AJ<@80
W6<i0P2<BRT207/i6080Jc4H101[>B4207/i60@0gZfD103N[H`20>N]S080gZf<0P3NYH@20=j]S0@0
gZF40P3FW7/40=jLL`H0cYA[0P36Q6/40<j<H`80aXA[103>U6/20<J4J`H0cYA[0P36Q6<20<J4FP80
aXAS0P36Q5X20;EcBP80cXaJ0P2]Jd8208a::@@0W6]:0P2LHcT209AJ<@80Q48Q0P1k@R4206<Y4080
[F<a0P36Nd820;ES<@80aW]20P2eJd820<IkBP80cYAS0P3NYG<20=JLN`80gZf41@2mS6<20<jDH`80
_HaS0P3>U6/20<JDJ`80eZf4103>U6/20<J4FP80cXaJ0P3N[H@20>O6[@80kmK6103_g/h20>ONeP80
knoW103gknL20?Ogm`@0mnog1P3gmoL20>o_m`80moOg0P3gkoL20?Ogm`80mnog103gmoL@0?ooo`00
3P3oool40?Ogm`80mnog0P3gmoL40?O_m`80knog103gkoL20?Ogm`80mnog2P3gmoL20>o_m`80mnoW
0P3gkoL20>o_m`@0moOg0P3gkoL40?Ogm`80knog0P3gkoL20>o_i`80ilJe0P3F[H`20<JLQ0D0]G]J
0P2LJdX20:eS@P80W6<i102DFS4406/i8@80Jc4H1P1[>B420=j]U080gZf<0P3N[I@20>NmY@@0ijfD
0P3WYI@20>N]U0@0ijFD0P3N[H`40=jUQ080eYak0P3>S6<20<J4FP80cXaS0P36NeX80<J4FP@0cXaS
1P36Q5X40;EkFP80]F]B0P2eLdX20<J4FP80W6<i0P1kBRT209aS>@80[F]20P2<BRT207]28@80NcTH
0P1kBRT209AB:@80[EXa1036Nd820;EcBP80aW]20P2]JcT20<jDH`80eYac0P3F[H@20<jDJ`<0aYA[
0P36Q5X40<J<H`80_HaS103F[H@20<jDH`80eYac0P3>U6<40=J]Q080g/Je0P3gknL20>oFaP80imkF
0P3_knL20>oWi`P0moOg0P3gkoL>0?Ogm`80mnog0P3gmoL20?O_ma00oooo000>0?ooo`@0moOg0P3g
koL20?Ogm`@0mnog0P3_koL40?O_m`80moOg0P3gkoL:0?Ogm`80knog0P3gknL20?O_m`80knog103g
moL20?O_m`@0moOg0P3_koL20?O_m`80knoW0P3Wa[D20=J]S080aYb41@2eNeX209a[BP80[F=20P2L
HcT409AJ<@@0JcTQ0P1[<AP606/i8@80gZfD0P3N[H`20=j]U080ikfU103W[I@20>NUU080ijfD103W
YI@20=j]S0@0gZF40P3FW7/20<j<H`80aXAJ0P3>S6<20<IkFPP0aXAJ103>S6<60<J4FP@0]G]J0P2e
Je820;EcBP80aXAJ0P2LHcT207]::@80W6<i0P2]Jd8208a::@80Nd8Q0P1k>AP207]::@80U58Y0P2]
FS440<Ik@P80]G=:0P36Nd820:e[>@80cYAS0P3FW7<20=J]Q080cYA[0`36U6/20<J4FP@0aXaS0P2m
S6<40=J]Q080cYAS0P3FW7<20<jDH`@0eZf40P3Na[D20?O_i`80kmK60P3Wg]H20>o_i`80knOW203g
moL20?O_m`h0moOg0P3gkoL20?Ogm`80mnog403oool000h0oooo0P3gkoL40?Ogm`@0knoW0P3gmoL2
0?O_m`@0moOg103gkoL40?Ogm`80knog0P3gmoL20?O_m`80moOg0P3gknL20?O_m`80mnoW103gmoL4
0?O_m`H0knog0P3_imh20=k6]@80eZf40P36U6/30;EkFP80]G=:0P2]Jd8209aS>@80]G=:0P2LBS42
09AJ<@80DR4@0P1c@RT406/i8@80Jc4H0P24DS420=j]U080ilJ]1P3_aZd40>o6Y@H0kkFL0P3W[I`4
0>N]U080gZf<0P3NYH@20=JLN`@0aW]J0P36NdX40<IkFPH0]G]J0P36Q5X20<IkFP80]G]J0P36NdX2
0;EcBP@0[F]20P36NdX208a::@80S4Xa0P2LHcT208aJ@P80Q48Q0P1[<AP206/i8@80[F<a0P24@R42
09aS>@80aW]:0P36Nd820;EcBP80[F/i0P2eLdX20<j<FP80eYak0P3N[H@20=j]S0<0eZf41036U6/2
0;EkFP80]F]2103F[H@20<JDJ`80cYA[103F[H@20>NmW080knoW1P3_imh20>o_i`80mnoW0P3gkoL2
0?Ogm`80mnog203gmoL20?O_m`X0moOg0P3gkoL20>o_ma00oooo000>0?ooo`80mnog103gmoL40>o_
i`80moOg0P3gkoL40?Ogm`@0mnog103gmoL20>o_m`80moOg0P3gkoL20?Ogm`80mnoW0P3gkoL20?O_
i`@0moOg103gkoL60>o_m`80knON0P3Na[D20=J]Q080aYA[0`2eNeX20;EcBP80[F]20P2LHcT20;Ec
BP80W4Xa0P2DFS42058Q4080Ld8Y101[>B4206/a6080Q58a0P3N[I@20>O6[@H0klJ]103_aZD60>ne
W080ijfL103W[I@20=j]S080gZF40P3FW7/40<IkFP80aW]:1036NeX60;EkFP80aXAJ0P36NeX20;Ek
FP80aW]:0P2eLdX40:e[@P80aW]:0P2<BRT208a:<@80W6<i0P2<FT8208A28@80Jc4H0P1[>B420:eS
<@80Q48Q0P2LHcT20<IkBP80aW]20P2eLdX20:e[>@80]G=:0P3>S5X20=JLN`80gZf40P3N[H`30=J]
Q0@0aYA[0P2eNeX20;E[@P@0eZf40P36U6/20<jDJ`@0eZf40P3W_I`20>o_i`H0knON0P3_knL20?O_
i`80mnog0P3gmoL20?O_m`P0moOg0P3gkoL:0?Ogm`80mnog0P3_koL@0?ooo`003P3oool20?O_m`@0
moOg103_knL20?Ogm`80mnog103gmoL40?O_m`@0moOg0P3_koL20?Ogm`80mnog0P3gmoL20?O_i`80
mnog0P3gknL40?Ogm`@0mnog1P3_koL20>oWgP80g/Je0P3F[H@20<JDJ`<0]G]J0P2eLdX20:e[@P80
W6<i0P2eLdX209a:<@80U5Xa0P1B8A0207=2:@@0JcTQ0P1[<AP208AB<@80gZfD0P3WaZd60>o6[@@0
klJU1P3_]I`20>N]W0@0ijfD0P3N[H`20=jUQ080eYak1036NeX20<IkBP@0aW]J1P2eNeX20<J4FP80
aW]J0P2eNeX20<IkBP80]G=:102]Jd820<IkBP80S4XY0P2<BS4209aS>@80S5Y20P24@R4206/a6080
JcTQ0P2]Hc4208A28@80W6<i0P36NdX20<Ik@P80]G=:0P2]JcT20;EcBP80cXaJ0P3FW7/20=j]Q080
gZf<0`3F[H@40<JDJ`80]G]J0P2eJd840=J]Q080aYA[0P3>U6/40=J]Q080ikfL0P3_knL60>oWgP80
knoW0P3gknL20?O_m`80moOg0P3gkoL80?Ogm`80mnog2P3gmoL20?O_m`80knog403oool000h0oooo
0P3gmoL40?O_m`H0moOg0P3gkoL<0?Ogm`80mnog103gmoL20?O_m`@0moOg0P3_knL20?Ogm`80mnog
0P3gmoL20?O_i`80knog103gkoL20>O>_@80e[FU0P3FW7<20<J<H`<0]G]J0P2]Le8209AJ<@80W6<i
0P2DFS4209aS>@80Q48Q0P1S:A0207]28@80Ld8Y0P1[>B4206/a6080]HAS0P3_aZd20>o6]@80mmJm
103ga[D40>o6[@80mlJe103_aZd40>neW080ikFL0P3W[I@20=j]S080gZF40P3NW7/20<jDJ`80aW]:
0P2eLdX20;EkFP@0aW]:0P36NeX20;E[DP80]G]J0P36NdX20;EkFP80]G=:0P2]Jd8209AS@P80]G=:
0P2DFS4209aS>@80]G=:0P24@R4207/i6080Jc4H0P1cBS420;E[>@80S48Q0P2LHcT20;E[@P80aW]:
0P2eJcT20:e[>@80]G=:0P36Q5X20<j<FP80gZf40P3N[H`30=J]Q080eYac0P36U6/20;EcBP80_HaS
203FW7<20>NmU080eYac0P3W_I`20>o_i`80kmk>0P3We/H20?OWgP80knOW0P3gmoL20?O_m`80moOg
0P3_koL20?O_m`80knog103gkoL40?Ogm`80mnog2P3gmoL@0?ooo`003P3oool20?Ogm`@0mnog1P3g
moL20?O_m``0moOg0P3gkoL40?Ogm`80mnog103gmoL20>o_i`80moOg0P3gkoL20?Ogm`80mnoW0P3_
koL40?O_m`80iljm0P3F]JD20=JLL`80aXaS0`2eNeX20:ecDP80U5Xa0P2LHcT209AJ<@80W6<i0P24
@R4206<Y4080Nd8Q0P1c@RT206/i8@80Jc4H0P2eQ6<20>o6[@80klJe0P3ge[d40?O6]@@0klJ]0P3g
a[D40>o6[@@0kkFL0P3W]I`20>N]U080gZf<0P3NYH@20=jLN`80cYA[0P36NdX20;EcBP80]G]J1036
NdX20<IkFP80]F]B0P2eNeX20<IkBP80]G]J0P2eLdX20:e[@P80U6=20P2eLdX209AJ<@80W6<i0P2e
LdX208A28@80NcTH0P1[<AP207=:<@80]F/i0P2<@R4209aS>@80]F]20P36NdX20;E[>@80[F/i0P2e
LdX20<J4FP80cXaJ0P3N[H@20=j]S0<0eZf40P3FW7<20<JDJ`80]G=:0P2mS6<80=JLL`80ikfD0P3F
W7<20>NmW080knoW0P3_g/h20>OFaP80mnON0P3_inL20?Ogm`80mnog0P3gmoL20>o_m`80mnog0P3_
koL40?O_m`@0moOg0P3gkoL:0?Ogma00oooo000>0?ooo`80mnog0P3gmoL20?O_i`80moOg0P3gkoL2
0?O_i`80moOg0P3_koL80?Ogm`80mnog0P3gknL20?Ogm`@0mnog0P3gmoL40?O_m`80moOg0P3gkoL4
0>o_m`80mnoW103gkoL20>O>_@80cZfD0P36U6/20;f<H`<0[G=B102]Jd8209aS>@80U5Xa0P2LHcT2
06<Y4080JcTQ0P1kBRT406/i8@80]Hac0P3_a[D20?O>]@80mmJm0P3gc[D20?OF_@80mlJe0P3ge[d2
0?O6]@80mlje0P3ga[D20>o6[@80klJU0P3_aZd40>neW080ijfD0P3W[H`20=jUQ080gZEk0P3FW7<2
0<jDJ`P0]G=:0P36NdX20;EcBP80]G]J0P2eLdX20:eS@P80W6]:0P24DST208A28@80]G=:0P2DFS42
0<J4FP80NcTH0P1[<AP2058Q4080HbT@0P2]JcT20;E[@P80U58Y0P2eJd820<j<FP80[F/i0P2mS6<2
0;EcBP80aXAJ0P3FW7<20=j]Q080ikfD0`3W_JD20=J]S080]F]2102mS6<20<jDJ`80aXaS0P3FW7<2
0=J]S080eZf40P3NYG/20>oWi`80kmk>0P3_c[d20>oWgP80mnoW0P3gkoL40?Ogm`80mnoW203gmoL4
0?O_m`P0moOg0P3gkoL40?Ogma00oooo000>0?ooo`80mnog0P3gmoL20?O_i`80moOg0P3gkoL20?O_
i`80moOg0P3_koL80?Ogm`80mnog0P3gknL20?Ogm`@0mnog0P3gmoL40?O_m`80moOg0P3gkoL40>o_
m`80mnoW103gkoL20>O>_@80cZfD0P36U6/20;f<H`<0[G=B102]Jd8209aS>@80U5Xa0P2LHcT206<Y
4080JcTQ0P1kBRT406/i8@80]Hac0P3_a[D20?O>]@80mmJm0P3gc[D20?OF_@80mlJe0P3ge[d20?O6
]@80mlje0P3ga[D20>o6[@80klJU0P3_aZd40>neW080ijfD0P3W[H`20=jUQ080gZEk0P3FW7<20<jD
J`P0]G=:0P36NdX20;EcBP80]G]J0P2eLdX20:eS@P80W6]:0P24DST208A28@80]G=:0P2DFS420<J4
FP80NcTH0P1[<AP2058Q4080HbT@0P2]JcT20;E[@P80U58Y0P2eJd820<j<FP80[F/i0P2mS6<20;Ec
BP80aXAJ0P3FW7<20=j]Q080ikfD0`3W_JD20=J]S080]F]2102mS6<20<jDJ`80aXaS0P3FW7<20=J]
S080eZf40P3NYG/20>oWi`80kmk>0P3_c[d20>oWgP80mnoW0P3gkoL40?Ogm`80mnoW203gmoL40?O_
m`P0moOg0P3gkoL40?Ogma00oooo000>0?ooo`80moOg0P3gkoL:0?Ogm`80knog0P3gkoL20?O_i`H0
moOg0P3gknL20?O_m`80moOg203gkoL80?Ogm`80knog0P3_inL20>OFaP80ilJ]0P36W8@20<JDJ`80
]G]J0`2LJdX209AJ<@@0W6<i0P2DFS4208A::@80HbT@101kBRT206/i8@80ilJe0P3gc[D20>o>[@80
mlje103ge[d20>oFaP80mmJm0P3_e/H60?O6]@80mlje0P3_aZd60>o6Y@80ikfL0P3N[I@20=j]S080
ijf<0P3NYH@20=JLN`80cYA[0P2eJe840:e[@P80]G=:0P2]Jd820;E[DP80[F]20P2]Hd8209aS>@80
Q48Q0P1k@R420<J4FP80Q48Q0P3>S6<209aS>@80JcTQ0P1cBS42058Q4080Q48Q0P36NdX208a28@80
]F]20P36NdX20;E[>@H0aXAJ0P3>U6<20=JLL`80ikfL0`3W_JD20=J]Q080aXaS0P2eNeX20;f<H`@0
aYA[0P3F[H@20=J]S080eZf40P3W_I@20>ONeP80imK>0P3Wg]H40>o_i`80moOg0P3gknL20?Ogm`80
mnog103gmoL40?O_m`80moOg103gkoL<0?Ogma00oooo000>0?ooo`80moOg0P3gkoL:0?Ogm`80knog
0P3gkoL20?O_i`H0moOg0P3gknL20?O_m`80moOg203gkoL80?Ogm`80knog0P3_inL20>OFaP80ilJ]
0P36W8@20<JDJ`80]G]J0`2LJdX209AJ<@@0W6<i0P2DFS4208A::@80HbT@101kBRT206/i8@80ilJe
0P3gc[D20>o>[@80mlje103ge[d20>oFaP80mmJm0P3_e/H60?O6]@80mlje0P3_aZd60>o6Y@80ikfL
0P3N[I@20=j]S080ijf<0P3NYH@20=JLN`80cYA[0P2eJe840:e[@P80]G=:0P2]Jd820;E[DP80[F]2
0P2]Hd8209aS>@80Q48Q0P1k@R420<J4FP80Q48Q0P3>S6<209aS>@80JcTQ0P1cBS42058Q4080Q48Q
0P36NdX208a28@80]F]20P36NdX20;E[>@H0aXAJ0P3>U6<20=JLL`80ikfL0`3W_JD20=J]Q080aXaS
0P2eNeX20;f<H`@0aYA[0P3F[H@20=J]S080eZf40P3W_I@20>ONeP80imK>0P3Wg]H40>o_i`80moOg
0P3gknL20?Ogm`80mnog103gmoL40?O_m`80moOg103gkoL<0?Ogma00oooo000>0?ooo`P0moOg0P3_
koL>0?Ogm`80knog0P3gkoL20?O_i`@0moOg0P3gkoL:0?Ogm`80mnog0P3_knL20>oWi`80g/jm0P3F
_Jd20;fDN`80_HaS0P2eNeX30:e[@P80U6=20P2LHcT409AJ<@80JcTQ0P1[<AP207]28@80JcTQ0P2U
Q6/20>o>]@80mlje0P3_aZd40?O>]@P0mmJm0P3_e/H20?OF_@@0mlJe1P3_aZd20>NmY@80ikFL0P3W
_I`20>NeU080ijf<0P3N[I@20=jUQ080eYak0P36Q6/20<jDJ`@0[F=20P2]Jd8209a[BP80[F=20P2D
Hd8209a:<@80Q4Xa0P1c@RT20<IkBP80[G=B0P2eNeX20;EcBP80Jc4H0P1B8A0207]28@80W6<i0P36
NdX20<J4FP@0aW]:0P36Q5X20:e[@P80aXaS0P2mS6<20<JDJ`80eYac0P3F[H@30>NmW080ikfD0P2m
S6<20;EcBP80_HaS0P36NdX20<JDJ`80e[FU0P3W_I@20<jeY@80eZf<0P3WaZd20>oWgP@0mnoW0P3g
koL20?Ogm`80mnog0P3gmoL20?O_m`80moOg103gkoL80?Ogm`80mnog1P3gmoL20?O_m`80moOg403o
ool000h0oooo203gmoL20>o_m`h0moOg0P3_koL20?O_m`80mnoW103gmoL20?O_m`X0moOg0P3gkoL2
0>o_i`80knOW0P3Nc[d20=Jm[@80_IAk0P2mS6<20;EkFP<0[F]20P2DHd8209aS>@@0U5Xa0P1[>B42
06/a6080Nd8Q0P1[>B420:F4J`80klje0P3gc[D20>o6[@@0mlje203ge[d20>oFaP80mmJm103ga[D6
0>o6[@80ikfU0P3W]I`20>NmW080ikFD0P3W[H`20=j]U080gZF40P3FW7/20<J4J`80cYA[102]Hd82
0:e[@P80W6]:0P2]Hd8209AS@P80W4Xa0P24BS4207=2:@80aW]:0P2]Le820;EkFP80]G=:0P1[<AP2
058Q4080Nd8Q0P2LHcT20<IkBP80aXAJ1036NdX20<J4FP80[F]20P36S6<20;f<H`80aYA[0P3FW7<2
0=J]Q0<0ikfL0P3W_I@20;f<H`80]G=:0P2mS6<20<IkBP80aYA[0P3F]JD20>NmU080c[FU0P3F[H`2
0>O6[@80knON103gknL20?O_m`80moOg0P3gkoL20?Ogm`80mnog0P3gmoL40?O_m`P0moOg0P3gkoL6
0?Ogm`80mnog0P3gmoL@0?ooo`003P3oool20>o_m`80moOg0P3gkoL60?Ogm`80mnoW0P3gmoL40?O_
m`80moOg1P3gkoL20?O_i`80moOg103gkoL20?O_i`@0moOg0P3_knL20?Ogm`80knog0P3_knL20>ON
eP80g/jm0P3>[I@20;fDN`80_HaS0P2eLdX309a[BP80Q58i0P2DFS4208a::@80U5Xa0P1B:AP206/i
8@80Ld8Y0P2<FT820>o6[@80klJe203gc[D20?OF_@80mlJe0P3ge[d40?O6]@80mmJm103ga[D20>o6
[@80klJU103_aZd20>o6Y@@0ikFL0P3W]I@20=j]U080gZf<0P3NYH@20=JLN`80cYA[0P36Q6/209aS
>@@0[F=20P2DFT8209aS>@80Q4XY0P1kBRT206<Y4080W6]:0P3FW7/208a::@80cYA[0P2DHd820:e[
@P80Jc4H0P2]Hc4208a:<@80_HaS0P2]Hc420<Ik@P80aW]:0P2mS6<20;F4H`80aYA[0P2eNeX20=J]
Q080cYAS0`3W_JD20>o>]@80_HaS0P2eLdX20;f<H`80aXaS0P36W8@20=JLL`80eZf40P3F[H`20>Nm
U080imkF0P3_imh20>oWi`80mnoW0P3_knL20?O_m`80moOg0P3gkoL40?Ogm`@0mnog0P3gmoL40?O_
m`80moOg103gkoL20?Ogm`80mnog103gmoL@0?ooo`003P3oool20>o_m`80moOg0P3gkoL60?Ogm`80
mnoW0P3gmoL40?O_m`80moOg1P3gkoL20?O_i`80moOg103gkoL20?O_i`@0moOg0P3_knL20?Ogm`80
knog0P3_knL20>ONeP80g/jm0P3>[I@20;fDN`80_HaS0P2eLdX309a[BP80Q58i0P2DFS4208a::@80
U5Xa0P1B:AP206/i8@80Ld8Y0P2<FT820>o6[@80klJe203gc[D20?OF_@80mlJe0P3ge[d40?O6]@80
mmJm103ga[D20>o6[@80klJU103_aZd20>o6Y@@0ikFL0P3W]I@20=j]U080gZf<0P3NYH@20=JLN`80
cYA[0P36Q6/209aS>@@0[F=20P2DFT8209aS>@80Q4XY0P1kBRT206<Y4080W6]:0P3FW7/208a::@80
cYA[0P2DHd820:e[@P80Jc4H0P2]Hc4208a:<@80_HaS0P2]Hc420<Ik@P80aW]:0P2mS6<20;F4H`80
aYA[0P2eNeX20=J]Q080cYAS0`3W_JD20>o>]@80_HaS0P2eLdX20;f<H`80aXaS0P36W8@20=JLL`80
eZf40P3F[H`20>NmU080imkF0P3_imh20>oWi`80mnoW0P3_knL20?O_m`80moOg0P3gkoL40?Ogm`@0
mnog0P3gmoL40?O_m`80moOg103gkoL20?Ogm`80mnog103gmoL@0?ooo`003P3oool20?O_m`80moOg
0P3gkoL60?Ogm`@0mnog203gmoL40?O_m`80moOg0P3gkoL<0?Ogm`80mnog103_inL20>O>_@80g/jm
0P36W8@20<J<H`80[G=B0P2eLdX309AS@P@0U5Xa0P24DS4206/i8@80Jc4H0P24BRT208AJ@P80klJe
0P3_aZd20>o>[@H0mlje0P3ga[D20>o>[@X0klJ]0P3_aZD40>neW080ikfU0P3_aZD20>NmW080kkfL
103W]I`20=j]S080ijf<0P3N[I@20=j]S080gZF40P3FW7<20<jDJ`80cXaS0P2LHcT209a:<@80W6<i
0P2<BS4208a::@@0JcTQ0P24DST20;f<H`80]G]J0P2LJdX20<JLQ080S48Q0P2eNeX209AJ<@80[F=2
0P2eJd820<IkBP80[F/i0P36NdX20;f<H`80W6<i102mS6<40=JLL`<0cZfD0P3N[H`20>NmU080_HaS
0P2eJd820;f<H`80aYb40P36U6/20=J]Q080ikfD0P3We/h20>o_i`80imkF0P3_knL20?O_i`80knoW
0P3gmoL40?O_m`80moOg0P3gkoL40?Ogm`80mnog0P3gmoL20?O_m`H0moOg0P3gkoL60?Ogma00oooo
000>0?ooo`80mnog0P3gmoL20?O_m`H0moOg103gkoL80?Ogm`@0mnog0P3gmoL20?O_m``0moOg0P3g
koL40>oWi`80iljm0P3Nc[d20<JLQ080aXaS0P2]Le820;EcBP<0U6=2102DFS4208AB<@80JcTQ0P1[
<AP208A::@80Q5Y20P3_a[D20>o6[@80klj]1P3gc[D20?O6]@80klj]2P3_aZd20>o6Y@@0kkFL0P3W
_JD20>o6Y@80ikfL0P3__I`40>NeW080gZf<0P3W[H`20=j]U080gZf<0P3NYH@20=JLL`80cYA[0P3>
S6<209aS>@80W4Xa0P2LHcT208a:<@80S4XY101[>B4208AB>@80_HaS0P2eNeX209a[BP80aYb40P2<
@R420;EkFP80U5Xa0P2]Hd820;E[@P80aW]:0P2]JcT20<IkBP80_HaS0P2LHcT40;f<H`@0eYac0`3>
[I@20=j]S080ikfD0P2mS6<20;E[@P80_HaS0P36W8@20<JDJ`80eZf40P3W_I@20>OFcP80knoW0P3W
g]H20>o_i`80mnoW0P3_knL20?Ogm`@0mnog0P3gmoL20?O_m`@0moOg0P3gkoL20?Ogm`80mnog1P3g
moL20?O_m`H0moOg403oool000h0oooo103gmoL20?O_m`H0moOg0P3gkoL20?Ogm`P0mnog103gmoL2
0?O_m`80moOg0P3gkoL20?O_i`80knog103gkoL40?Ogm`80knOW0P3We/h20>O>_@80c[FU0P2mU7/2
0;EkFP80[G=B0P2DHd8709AJ<@80FS4Q0P1[>B4406/a60@0klJe0P3gc[D20>o>[@@0klJ]0P3ga[D2
0>o6[@80kkfL0P3W]I`40>N]U0H0gZf<0P3NYH@80=j]S0H0ikFD0P3W]I`20>NeU0@0gZf<0P3NYH@2
0=jLN`80eYak0P3FW7<20<j<H`80]F]B0P2DFS4208AB<@80Q4Xa0P1c@RT206/i8@80LdXa0P2DHd82
0<jDJ`80_HaS0P2UNeX20=JLL`80aW]:0P2eNeX208A28@80[F/i0P36Q5X20<Ik@P80aW]:0P2]JcT4
0;EkFP80eYak0P36U6/20=JLL`<0eZf40P3W_JD20>O6]@80_HaS0P36U6/20=JLN`80aYA[0P36S6<2
0<j]U080ikfL0P3gknL20>ONeP80mnog0P3_knL20?O_i`80knoW103gmoL20?O_m`80moOg0P3_koL2
0?O_m`80moOg103gkoL>0?Ogm`80mnog403oool000h0oooo103gmoL20?O_m`H0moOg0P3gkoL20?Og
m`P0mnog103gmoL20?O_m`80moOg0P3gkoL20?O_i`80knog103gkoL40?Ogm`80knOW0P3We/h20>O>
_@80c[FU0P2mU7/20;EkFP80[G=B0P2DHd8709AJ<@80FS4Q0P1[>B4406/a60@0klJe0P3gc[D20>o>
[@@0klJ]0P3ga[D20>o6[@80kkfL0P3W]I`40>N]U0H0gZf<0P3NYH@80=j]S0H0ikFD0P3W]I`20>Ne
U0@0gZf<0P3NYH@20=jLN`80eYak0P3FW7<20<j<H`80]F]B0P2DFS4208AB<@80Q4Xa0P1c@RT206/i
8@80LdXa0P2DHd820<jDJ`80_HaS0P2UNeX20=JLL`80aW]:0P2eNeX208A28@80[F/i0P36Q5X20<Ik
@P80aW]:0P2]JcT40;EkFP80eYak0P36U6/20=JLL`<0eZf40P3W_JD20>O6]@80_HaS0P36U6/20=JL
N`80aYA[0P36S6<20<j]U080ikfL0P3gknL20>ONeP80mnog0P3_knL20?O_i`80knoW103gmoL20?O_
m`80moOg0P3_koL20?O_m`80moOg103gkoL>0?Ogm`80mnog403oool000h0oooo0P3gmoL20?O_m`H0
moOg0P3gkoL80?Ogm`80mnog2P3gmoL60?O_m`@0moOg103gkoL20>oWi`80imK60P3Nc[d20=J]S080
aYA[102eLdX20:eS@P<0S4Xa0P2DFS4208AB<@80Jc4H0P1[>B4208A::@80ilJe103_c[D20?O>]@80
klj]103_aZd20>o6Y@80ikfU0P3W[I@20>N]S080gZF40P3NW7/:0>N<N`80gZF40P3NW7/20=jUQ080
gZf<0P3NYH@40>NeU080ikFL0P3N[I@20=j]S080gZF40P3FYH@20=JLN`@0cYA[0P36Q6<208aJ@P80
Q48Y0P1kBRT206/i8@80DRTH0P1[>B4208aSBP80cYA[0P2]Le8209AJ<@80eZF40P36NdX20<jDH`80
]G]J0P2LHcT20:e[@P80cXaJ0P36NdX20;EcBP80_HaS0P2eNeX20=JLL`80aYA[0P3F[H@30=JLL`80
eZf40P3WaZd20=J]Q080eYac1036W8@20=JLL`80eZf<0P3W_JD40>oWgP80mnoW0P3_knL20?O_m`80
moOg0P3gkoL40?Ogm`80knog1P3gmoL20?O_m`@0moOg0P3gkoL<0?Ogma00oooo000>0?ooo`80moOg
0P3gkoL60?Ogm`80mnog203gmoL20?O_m`X0moOg1P3gkoL40?Ogm`@0mnog0P3_inL20>OFaP80g/jm
0P3F[H`20<JDJ`@0]G=:0P2]Hd8308a:<@80U5Xa0P24DS4206/a6080JcTQ0P24BRT20>O6]@@0klje
0P3gc[D20>o>[@@0klJ]0P3_aZD20>NmY@80ijfD0P3W[H`20=jUQ080gYak2P3WS7/20=jUQ080gYak
0P3NYH@20=j]S080gZF4103W]I@20>NeW080gZfD0P3N[H`20=jUQ080eZF40P3FW7/40<jDJ`80aXAS
0P2<FT8208A2:@80NdXY0P1[>B42058Y6080JcTQ0P2<HdX20<jDJ`80[G=B0P2DFS420=JUQ080aW]:
0P3>U6<20;EkFP80W6<i0P2]Jd820<j<FP80aW]:0P2eLdX20;f<H`80]G]J0P3FW7<20<JDJ`80eZf4
0`3FW7<20=J]Q080ilJ]0P3F[H@20=JLL`@0aYb40P3FW7<20=J]S080ikfU103_imh20?O_i`80knoW
0P3gkoL20?Ogm`80mnog103gmoL20>o_m`H0moOg0P3gkoL40?Ogm`80mnog303gmoL@0?ooo`003P3o
ool20?Ogm`80mnog103gmoL20?O_m`X0moOg0P3gkoL<0?Ogm`80mnog103gknL20?Ogm`80mnog0P3_
knL20>OFcP80iljm0P3Nc/H20<JLQ080]G]J0P2]Le8209aS>@80[F=20`24DST208A::@@0JcTQ0P1k
>AP207]::@@0klJe203_aZd20>o6Y@80kkFL0P3NLf<20<i[FP@0gW][2P3NQ7<80<i[FP80eYak103N
[H`60>NeU080gZfD0P3N[H`20=jUQ0@0eYak0P3>U6/20<J4J`80aXAJ0P1kBRT206/i8@80Jc4H0P1B
8A0206/a6080Q58i0P2]Le820=JLN`80]HAS0P36Q6/20=J]Q080cYAS0P3FW7<20<JDJ`80aW]:0P2e
LdX20<J4FP80_HaS0P2]JcT20;EcBP80_HaS0P3FW7<20;f<H`<0gZf40P3F[H`20>NmU080ikfU0P36
W8@20=J]Q080aYA[0P3FW7<20>NmU080g/jm0P3We/h20>oWi`80knoW0P3_inL20>o_i`80mnoW0P3g
moL20>o_m`80mnog0P3gmoL20?O_m`H0moOg0P3gkoL40?Ogm`80mnog103gmoL20?O_m`@0moOg403o
ool000h0oooo0P3gmoL20?O_m`@0moOg0P3gkoL:0?Ogm`80mnog303gmoL20?O_m`@0mnoW0P3gmoL2
0?O_m`80knoW0P3We/h20>O>_@80g/k60P36W8@20;EkFP80[G=B0P2LHcT20:eS@P<0Q58i0P24BRT4
06/i8@80NcTH0P1kBRT40>o6]@P0klJ]0P3_aZD20>neW080gW=S0P3>JeX40=ikJ`X0gXAc203>JeX2
0=JLN`@0gZf<1P3W]I@20=j]U080gZf<0P3NYH@40=JLN`80cYA[0P36Q6/20<J4FP80NdXY0P1[>B42
06/a6080DR4@0P1[<AP208AB>@80[G=B0P3FW7/20;F4H`80aXA[0P3F[H@20<jDH`80eYac0P36U6/2
0<IkBP80]G=:0P36Q5X20;f<H`80[F/i0P2eLdX20;f<H`80eYac0P2mS6<30=j]Q080eZf<0P3W_I@2
0>NmY@80aYb40P3F[H@20<JDJ`80eYac0P3W_I@20=k>_@80imK>0P3_inL20>o_i`80knOW0P3_knL2
0?O_i`80moOg0P3_koL20?O_m`80moOg0P3gkoL60?Ogm`80mnog103gmoL20?O_m`@0moOg0P3gkoL4
0?Ogma00oooo000>0?ooo`80moOg0P3gkoL20?Ogm`80mnog0P3gmoL20?O_m`P0moOg0P3gkoL40?Og
m`80mnog0P3gknL40?Ogm`80mnog103gmoL20?O_i`80moOg0P3_inL20>ONeP80imK60P3F[H`20<JD
J`80YG]J0P2LJdX209aS>@80U5Xa0`1kBRT208AB>@80Ld8Y0P1[>B4207]::@80kljm0P3_a[D40>o6
[@80klJU0P3_cZd20>o6[@80ihak1P3NQ7<20>o6]@80kkFL103WS7/20>NUU080kkFL103NQ7<20=ik
J`80aXA[0P3>Lf<20<i[FP80eYak0P3N[H`20=j]U080ikFD0P3W]I`20=j]U0@0gZf<0P3FYH@20=JL
N`80cYA[0P3NQ7<20<J4H`80]G]J0P1cBS44058Y6080DR4@0P24DST2058Y6080eZF40P3N[H`209aS
>@80eZf<0P2eNeX20=jUN`80eZf40P2mS6<20<J4FP80cYAS0P2]Hc420<J4FP80]G]J0P2mS6<20<JD
J`80cYA[0`3FW7/20=J]S080ikfU0P3Wa[D20;fDN`80]HAS0P36U6/20=JLL`80cZfD103_imh40>o_
i`80knON103gmoL20>o_m`@0mnog0P3gmoL20?O_m`80moOg103gkoL40?Ogm`80mnog103gmoL40?O_
m`80moOg0P3gkoL@0?ooo`003P3oool20?Ogm`80mnog0P3gmoL20?O_m`80moOg0P3gkoL80?Ogm`80
mnog103gmoL20?O_m`80mnoW103gmoL20?O_m`@0moOg0P3gknL20?Ogm`80knOW0P3Wg]H20>OFaP80
eZf<0P36U6/20:EkFP80W6]:0P2LHcT209AJ<@<0NdXY0P24DST207=2:@80JcTQ0P1kBRT20>o>_@80
klJe103_aZd20>o6Y@80klj]0P3_aZd20>N<N`H0gXAc0P3_a[D20>neW0@0ihak0P3WYI@20>neW0@0
gXAc0P3NNf/20<J4J`80cW=S0P3>JeX20=JLN`80gZf<0P3N[I@20>NeU080ikFL0P3N[I@40=j]S080
eZF40P3FW7/20<jDJ`80gXAc0P36Q6<20;EkFP80LdXa101B:AP2058Q4080Q58i0P1B:AP20=JUQ080
gZf<0P2LHcT20=J]S080]G]J0P3NYG/20=J]Q080_HaS0P36Q5X20<jDH`80[F<a0P36Q5X20;EkFP80
_HaS0P36U6/20<jDJ`<0eYak0P3F[H`20>NmY@80ilJe0P2mU7/20;F4H`80aYA[0P3FW7<20<j]U0@0
knON103_knL20>oWgP@0moOg0P3_koL40?O_m`80moOg0P3gkoL20?Ogm`@0mnog103gmoL20?O_m`@0
moOg103gkoL20?Ogm`80mnog403oool000h0oooo0P3gkoL20?Ogm`80mnog0P3gmoL20?O_m`80moOg
0P3gkoL20?Ogm`@0mnog0P3gmoL<0?O_m`80mnoW103gmoL20>o_m`80moOg0P3We]H20=k>_@80cZfD
0P36U6/20;F4H`80YG]J0P24DST209AJ<@80S4Xa0`2DFS4206<Y40@0JcTQ0P2UQ6/60>o>]@80klJ]
1P3_aZD20=ikJ`@0gXAc0P3NNf/60=icH`80gXAc103>JeX20<IJBP@0aV=:0P3WS7/40<icH`80aUY:
0P3FYH`20>N]U0P0ikFD0P3N[H`20=JUQ0@0eYak103>U6/20<J4FP80[G=B101[>B4203TH4080Jc4H
0P2<FT820;F4H`80aYA[0P2eNeX20;f<H`80eZf40P36Q5X20=j]Q080klj]0P2mS6<20;EcBP@0aXAJ
0P2]Jd820;EkFP80cYAS0P36U6/50=JLL`@0ikfU0P36W8@20<JDJ`80aYb40P2mU7/20<j]U080knON
0P3_inL20?O_i`@0knOW3P3gmoL20?O_maH0moOg403oool000h0oooo0P3gkoL20?Ogm`80mnog0P3g
moL20?O_m`80moOg0P3gkoL20?Ogm`@0mnog0P3gmoL<0?O_m`80mnoW103gmoL20>o_m`80moOg0P3W
e]H20=k>_@80cZfD0P36U6/20;F4H`80YG]J0P24DST209AJ<@80S4Xa0`2DFS4206<Y40@0JcTQ0P2U
Q6/60>o>]@80klJ]1P3_aZD20=ikJ`@0gXAc0P3NNf/60=icH`80gXAc103>JeX20<IJBP@0aV=:0P3W
S7/40<icH`80aUY:0P3FYH`20>N]U0P0ikFD0P3N[H`20=JUQ0@0eYak103>U6/20<J4FP80[G=B101[
>B4203TH4080Jc4H0P2<FT820;F4H`80aYA[0P2eNeX20;f<H`80eZf40P36Q5X20=j]Q080klj]0P2m
S6<20;EcBP@0aXAJ0P2]Jd820;EkFP80cYAS0P36U6/50=JLL`@0ikfU0P36W8@20<JDJ`80aYb40P2m
U7/20<j]U080knON0P3_inL20?O_i`@0knOW3P3gmoL20?O_maH0moOg403oool000h0oooo203gmoL4
0?O_m`80moOg1P3gkoL20?Ogm`H0mnog103gmoL40?O_m`80moOg1P3gkoL20>OFcP80e/Je0P3FW7<2
0<JDJ`80[G=B0P2DHd8208a:<@80U5Xa0P24BRT306/a6080Nd8Q0P1[<AP209AJ<@@0kljm0P3_c[D4
0>o6[@80klJU0P3WS7/20=j4L`80[G=B0P2LBS420:e:<@80_E920P2]Le840;eB@P80aUY:0P2eDST2
09a:<@80W34Q0P2L@RT20:e:<@80S34Q0P2]@S4209a2:@80Q48Y0P2DFT820=j4L`H0ikFD1P3N[H`4
0=JLN`80eYac0P3FW7/20<J4H`80]G]J0P2<FT8204XH2080>AP@0P1[>B4207=:<@80Q5Y20P2mS6<2
0=JUQ080U5Xa0P3FYH@20;EkFP80eYak0P3W_I`20>o>[@@0cYA[0P2eJcT20<J4FP80]G]J0P2mS6<2
0<J<H`<0]G]J0P3F[H@20>NmU080ikfU0P3F_Jd20=JLL`80eZf40P36W8@20=JeY@80imkF0P3_knL2
0>oWgP80knoW0P3gkoL20>o_i`@0moOg0P3gkoL20?Ogm`80mnog403gmoL20?O_m`80moOg0P3gkoL4
0?Ogma00oooo000>0?ooo`P0moOg103gkoL20?Ogm`H0mnog0P3gmoL60?O_m`@0moOg103gkoL20?Og
m`H0mnog0P3We/h20=K6]@80eYac0P36U6/20:ecDP80U6=20P2<BS4209AJ<@80Q4XY0`1[<AP207]2
8@80Jc4H0P2DFS440>o>_@80klje103_aZd20>o6Y@80ihak0P3NQ7<20:ecDP80W4Xa0P2]BS420;eB
@P80[G=B102mDT820<IJBP80]E8i0P2LBS4209`a8@80W48Y0P2]BS4208`a8@80[D8a0P2L@RT208A2
:@80U5Y20P3NQ7<60>NeU0H0gZf<103FW7/20=JLL`80eYak0P36Q6<20;EkFP80S5Y20P1:60P203TH
4080JcTQ0P1cBS4208AJ@P80_HaS0P3FYH@209AJ<@80eZF40P2eNeX20=JLN`80ikfL0P3_cZd40<jD
J`80]F/i0P36Q5X20;EkFP80_HaS0P36S6<30;EkFP80eZf40P3W_I@20>NmY@80e[f]0P3FW7<20=J]
Q080aYb40P3F]JD20>ONeP80knoW0P3_imh20>o_i`80mnog0P3_knL40?Ogm`80mnog0P3gmoL20?O_
ma00moOg0P3gkoL20?Ogm`80mnog103gmoL@0?ooo`003P3oool60?O_m`@0moOg103gkoL20?Ogm`80
mnog0P3gmoL20?O_m`80moOg0P3gkoL20?Ogm`X0mnog0P3gknL20?O_m`80knOW0P3We/h20=Jm[@80
_IAk0P2eNeX209AS@P80S4Xa0P2<FT8208a::@L0NdXY0P24@RT40>o>_@80klJe0P3_c[D20?O>]@80
klJ]0P3_aZD20>neW080klJU0P3WS7/20<icH`80cV]J0P36HdX20<i[FP80aV=:0P3>JeX20=ikJ``0
aV=:0P3FW7<20=JUQ080eZF<103N[H`40>NeU0@0ijf<0P3N[H`20>N]S080gZF4103FW7/20=JLL`80
cYA[0P36Q6<209acDP80FSTY100i610205Xi:@80Q5Y20P2LLe820=JLN`80aYA[0P2LJdX20=JLL`80
]G]J103W_I`20>o>]@80[G=B1036Q5X20;EkFP@0_HaS0`2eNeX40=J]Q080ikfU0P3WaZd20<JDJ`80
eZf40P3FW7<20>OFaP@0knOW103_imh80?O_m`P0moOg0P3gkoL40?Ogm`80mnog103gmoL20?O_m`@0
moOg0P3gkoL40?Ogma00oooo000>0?ooo`H0mnog103gmoL40?O_m`80moOg0P3gkoL20?Ogm`80mnog
0P3gmoL20?O_m`80moOg2P3gkoL20?O_i`80mnog0P3_inL20>OFcP80e[f]0P2mU7/20;EkFP80U6=2
0P2<BS4208aJ@P80S4XY1`1kBRT208A2:@@0kljm0P3_a[D20>o>]@80mlje0P3_aZd20>o6Y@80kkFL
0P3_aZD20>N<N`80cW=S0P3>JeX20<ISBP80cV]J0P36HdX20<i[FP80gW][3036HdX20=JLL`80eZF4
0P3FYH`40=j]S0@0ikFD103W[H`20=j]S080ijf<0P3NYH@40=JLN`80eYac0P3>U6/20<J4H`80W7=B
0P1J>BT403TH4080FSTY0P24FT8209acDP80eYak0P36U6/209a[BP80eYac0P2eNeX40>NmW080klje
0P2]Le840<J4FP80]G]J102mS6<30;EkFP@0eZf40P3W_JD20>O6[@80aYA[0P3F[H@20=JLL`80imK6
103_inL40>oWgPP0mnog203gmoL20?O_m`@0moOg0P3gkoL40?Ogm`80mnog103gmoL20?O_m`@0moOg
403oool000h0oooo0P3gmoL40?O_m`80moOg0P3gkoL60?Ogm`80mnog0P3gmoL20?O_m`X0moOg0P3g
knL20?Ogm`80mnog0P3_knL20?O_i`80knON0P3Nc/H20=J]S080]HAS102LJdX208aJ@P80S4XY0P24
BRT207=2:@<0NdXY0P24@R4208AB<@80klje0P3_aZd20>o>]@80klj]0P3_aZd20>o>[@80klJU0P3_
cZd40?O>]@80mmJm0P3_e/H20>o6]@80klJ]0P3ge[d20>o6[@80klJU0P3gc[D20?OF_@80klJe0P3_
aZd20>NmY@80ikFL0P3W_JD20>NeW0@0ikFD0P3W]I`20>NeU080ikFL0P3W]I@20>N]U0@0gZf<103N
YH@20=JLN`80eYac103>U6/20;EkFP80Q58a0P12<BT202T@2080Q5Y20P1cBS4208AJ@P80W7=B0P2m
S6<209aS>@80aXAJ0P2]Jd820<J4FP@0ikfL0P3FW7<20<jDJ`80_HaS102eLdX20;f<H`<0cYA[0P3F
W7<20<jDJ`80ikfU0P3WaZd40<JLQ080aXaS0P3Wg]H40>oWgP80knOW0P3_imh60?Ogm`80mnog303g
moL20?O_m`80moOg0P3gkoL60?Ogm`80mnog1P3gmoL@0?ooo`003P3oool20?Ogm`@0mnog0P3gmoL2
0?O_m`H0moOg0P3gkoL20?Ogm`80mnog2P3gmoL20?O_i`80moOg0P3gkoL20>o_i`80mnoW0P3_imh2
0=k>aP80eZf<0P2eQ6<409a[BP80S5Y20P2<BRT208A::@80Ld8Y0`1kBRT208A28@80Q58a0P3_c[D2
0>o6[@80klje0P3_cZd20>o6[@80klj]0P3_aZD20>o>[@@0mlje0P3ge[d20>oFaP80klJe0P3_aZd2
0?OF_@80klJ]0P3_aZD20?O>]@80mmJm0P3_a[D20>o6[@80ikfU0P3W]I`20>NmY@80ikFL103W]I@2
0>NeW080ikFD0P3W]I`20>NeU080ijfD103N[H`40=jUQ080eYak0P3FW7<40<jDJ`80]G]J0P24DS42
048a:@80:A080P24FT8207=:<@80Q5Y20P2LLe820;f<H`80W6<i0P36Q5X20:e[@P80aXAJ103W_I`2
0=JLL`80cYA[0P2mS6<40;EcBP80_HaS0`3>U6/20=JLL`80cYA[0P3W_JD20>O6[@@0aYb40P36S6<2
0>ONeP@0knON0P3_inL20>oWgPH0moOg0P3gkoL<0?Ogm`80mnog0P3gmoL20?O_m`H0moOg0P3gkoL6
0?Ogma00oooo000>0?ooo`80mnog2P3gmoL20?O_m`H0moOg0P3gkoL20?Ogm`@0mnog103gmoL20?O_
m`80mnoW103gkoL20>oWi`80g/Je0P3W_I`20<JLQ080[G=B0P2DHd8408AB<@80Q4Xa0P1[<AP507]:
:@80Nd8Q0P3F]JD60>o>]@80mlJe0P3gc[D20>o6[@80mlje0P3_aZd40?O>]@80mmJm0P3gc[D20?OF
_@80mlje0P3ge[d20>o6Y@H0klJ]203W]I`20>NmW080ikFL0P3W_I`20>o6Y@80ikFL0P3W]I@20>Nm
W080ikFL103W[I@20=j]S0@0gZF40P3FW7/20=j4L`@0cYA[0P2eNeX209AJ@P80DR4@0P128AP207=:
<@80Q58a0P2UQ6/209acDP80aYb40P2LHcT209AJ<@80aXaS0P2mS6<20=j]U080ikfL0P3_aZD20=J]
Q0@0aXAJ0P36S6<20;EcBPD0]G]J0P3>U6/20>NmY@80ilJ]0P3FW7<20=J]S080aYA[0P3_imh20>oW
i`80imkF0P3_imh20?O_i`H0moOg0P3gkoL40?Ogm`H0mnog503gmoL20?O_ma00oooo000>0?ooo`80
mnog2P3gmoL20?O_m`H0moOg0P3gkoL20?Ogm`@0mnog103gmoL20?O_m`80mnoW103gkoL20>oWi`80
g/Je0P3W_I`20<JLQ080[G=B0P2DHd8408AB<@80Q4Xa0P1[<AP507]::@80Nd8Q0P3F]JD60>o>]@80
mlJe0P3gc[D20>o6[@80mlje0P3_aZd40?O>]@80mmJm0P3gc[D20?OF_@80mlje0P3ge[d20>o6Y@H0
klJ]203W]I`20>NmW080ikFL0P3W_I`20>o6Y@80ikFL0P3W]I@20>NmW080ikFL103W[I@20=j]S0@0
gZF40P3FW7/20=j4L`@0cYA[0P2eNeX209AJ@P80DR4@0P128AP207=:<@80Q58a0P2UQ6/209acDP80
aYb40P2LHcT209AJ<@80aXaS0P2mS6<20=j]U080ikfL0P3_aZD20=J]Q0@0aXAJ0P36S6<20;EcBPD0
]G]J0P3>U6/20>NmY@80ilJ]0P3FW7<20=J]S080aYA[0P3_imh20>oWi`80imkF0P3_imh20?O_i`H0
moOg0P3gkoL40?Ogm`H0mnog503gmoL20?O_ma00oooo000>0?ooo`80mnog0P3gmoL80?O_m`80moOg
0P3gknL80?Ogm`80mnog0P3gmoL20?O_m`80moOg103gkoL20?O_i`@0mnog0P3Nc/H20<JLQ080]G]J
0P2LHcT209a[BP80Q4XY0P24BS4206/i8@T0NdXY103_c[D20>o6]@80klje0P3gc[D40?O6]@80mlje
0P3_c[D<0?O>]@80klje0P3_aZd60>o6Y@80ikFL0P3W_I`20>nmW080ikFL0P3W_JD20>NeW080klJU
0P3W]I`20>o6Y@@0ikFL103W[I@20>NeU080gZf<0P3NYH@20=jLN`80gZF40P3FW7<40<jDJ`80aXAS
0P2LJdX207=2:@80FSTY0P0i610207=B@P80Q58i0P2DHd8209aS>@80[G=B0P2LHcT20;EkFP80YG]J
0P3>U6/40>NmU080cYA[0P3FW7<20<J4FP80_HaS0P2eLdX30;f<H`80]G=:0P3FW7<20=J]Q080ikfU
0P3>[I@20<JDJ`80eYak0P3We/h40>oWgP80imK60P3gmoL20?O_m`@0moOg0P3gkoL20?Ogm`80mnog
203gmoL20?O_m`H0moOg103gkoL80?Ogma00oooo000>0?ooo`80mnog0P3gmoL80?O_m`80moOg0P3g
knL80?Ogm`80mnog0P3gmoL20?O_m`80moOg103gkoL20?O_i`@0mnog0P3Nc/H20<JLQ080]G]J0P2L
HcT209a[BP80Q4XY0P24BS4206/i8@T0NdXY103_c[D20>o6]@80klje0P3gc[D40?O6]@80mlje0P3_
c[D<0?O>]@80klje0P3_aZd60>o6Y@80ikFL0P3W_I`20>nmW080ikFL0P3W_JD20>NeW080klJU0P3W
]I`20>o6Y@@0ikFL103W[I@20>NeU080gZf<0P3NYH@20=jLN`80gZF40P3FW7<40<jDJ`80aXAS0P2L
JdX207=2:@80FSTY0P0i610207=B@P80Q58i0P2DHd8209aS>@80[G=B0P2LHcT20;EkFP80YG]J0P3>
U6/40>NmU080cYA[0P3FW7<20<J4FP80_HaS0P2eLdX30;f<H`80]G=:0P3FW7<20=J]Q080ikfU0P3>
[I@20<JDJ`80eYak0P3We/h40>oWgP80imK60P3gmoL20?O_m`@0moOg0P3gkoL20?Ogm`80mnog203g
moL20?O_m`H0moOg103gkoL80?Ogma00oooo000>0?ooo`80moOg0P3gkoL20?Ogm`@0mnog1P3gmoL2
0?O_ma00moOg103gkoL20?O_i`80g/k60P3Fa[D20;fDN`80]G=:0P2LJdX208A::@80S5Y20P1[>B42
07]::@80Jc4H0P1kBRT308A::@80JcTQ0P3_c[D40>o6]@80klje1P3gc[D20?O6]@P0mlje0P3_c[D4
0?O>]@@0klJU0P3W]I`20>o6Y@80ikFL0P3W[H`20>NeU080ikfL0P3W]I`20>neW080kkfL0P3_aZD4
0>neW080klJ]0P3_aZD40>NeW080ijfD0P3W[H`40=jUQ080eYak0P3FW7<20=j4L`80aXA[0P36Q6<2
0;EcBP80LdXa0P1B8A02058Y6080LdXa0P2<HdX209A[DP80W7=B0P2eQ6<209a[BP80S5Y20P2DHd82
0;fDN`80aXaS0P3NYG<20>o6Y@80eZf40P36NdX20<J<H`80W6]:0`36U6/20;f<H`80eYak0P3FW7<2
0>NmY@80cZfD0P2mS6<20>O6]@80imK61P3_inL20?O_m``0moOg0P3gkoL60?Ogm`80mnog0P3gmoL2
0?O_m`h0moOg403oool000h0oooo0P3gmoL20?O_m`80moOg103gkoL60?Ogm`80mnog403gmoL40?O_
m`80mnoW0P3Nc/H20=K6]@80_IAk0P2eLdX209a[BP80Q4XY0P2<FT8206/i8@80NdXY0P1[<AP207]:
:@<0Q4XY0P1[>B420>o>]@@0klJe0P3_c[D60?O>]@80mlJe203gc[D20>o>]@@0mlje103_aZD20>Ne
W080klJU0P3W]I`20>N]S080ikFD0P3W_I`20>NeW080kkFL0P3__I`20>o6Y@@0kkFL0P3_aZd20>o6
Y@@0ikFL0P3W[I@20>N]S0@0gZF40P3FW7/20=JLL`80gXAc0P36Q6/20<J4H`80]G=:0P1cBS42058Q
4080DRTH0P1cBS4208aSBP80U6]B0P2LLe820;F4H`80W6]:0P2<FT8209AS@P80_IAk0P36S6<20=jU
L`80klJU0P3F[H@20<IkBP80aXaS0P2LJdX30<JDJ`80_HaS0P3FW7/20=JLL`80ikfU0P3>[I@20;f<
H`80ilJe0P3We/H60>oWi`80mnog303gmoL20?O_m`H0moOg0P3gkoL20?Ogm`80mnog3P3gmoL@0?oo
o`003P3ooolB0?Ogm`80mnog203gmoL60?O_m`@0moOg0P3_inL20=k6]@80aZFD0P2mU7/209a[BP80
W6<i0P2DHd8208A2:@@0NdXY0P1cBS4207]::@<0JcTQ0P2eQ6<20>O6]@@0klJe203gc[D20?OF_@80
mlje0P3_c[D60?O>]@@0klJ]0P3W]I`20=j]S080gZF40P3W[I@20=j]U080gZF40P3N[H`20>N]U080
ikFD0P3W]I`20>nmW080ikfU0P3_aZD40>o6[@@0kkFL0P3W]I`20>N]U080gZf<103NYH@40=JLN`80
eYac0P3>U6/20<IkFP80]F]B0P2<FT8205Xi:@80JcTQ0P1J@ST208AJ@P80Q58i0P2LLe8209AS@P80
]G=:0P24DS4209aS>@80Q58i0P3F[H`20>NmU080eYac0P3NYG/20<J<H`80aYA[0P2UNeX30;EkFP80
_HaS0P36W8@20=JLL`80ikfL0P3F]JD20<JDJ`80imkF0P3W_JD20?O_m`80knOW303gmoL20?O_m``0
moOg103gkoL40?Ogm`80mnog203gmoL@0?ooo`003P3ooolB0?Ogm`80mnog203gmoL60?O_m`@0moOg
0P3_inL20=k6]@80aZFD0P2mU7/209a[BP80W6<i0P2DHd8208A2:@@0NdXY0P1cBS4207]::@<0JcTQ
0P2eQ6<20>O6]@@0klJe203gc[D20?OF_@80mlje0P3_c[D60?O>]@@0klJ]0P3W]I`20=j]S080gZF4
0P3W[I@20=j]U080gZF40P3N[H`20>N]U080ikFD0P3W]I`20>nmW080ikfU0P3_aZD40>o6[@@0kkFL
0P3W]I`20>N]U080gZf<103NYH@40=JLN`80eYac0P3>U6/20<IkFP80]F]B0P2<FT8205Xi:@80JcTQ
0P1J@ST208AJ@P80Q58i0P2LLe8209AS@P80]G=:0P24DS4209aS>@80Q58i0P3F[H`20>NmU080eYac
0P3NYG/20<J<H`80aYA[0P2UNeX30;EkFP80_HaS0P36W8@20=JLL`80ikfL0P3F]JD20<JDJ`80imkF
0P3W_JD20?O_m`80knOW303gmoL20?O_m``0moOg103gkoL40?Ogm`80mnog203gmoL@0?ooo`003P3o
ool20?O_m`X0moOg0P3gkoL20?Ogm`@0mnog103gmoL20?O_m`H0moOg0P3gknL20?Ogm`@0mnog0P3W
_I`20;fDN`80[G=B0P2DHd8408a:<@80NdXY101[>B4407]::@<0Jc4H0P3Wa[D40>o6]@80mlJe303g
c[D20>o>[@H0mlje0P3_aZd20>neW080ijfL0P3W]I@20=jLN`@0gZF40P3FW7/20=JUQ0@0gZf<0P3W
]I@20>NeW080kkfL0P3_]I`60>o6Y@80kkFL0P3_aZD20>neU080ijfD0P3N[H`20=jUQ0@0eYak0P3F
W7<20<J4J`80aXAS0P2eNeX209AJ@P80FSTY0P0Y40P2048Y8@80LdXa0P24DS4209a[BP80Q58i0P2e
LdX409aS>@80NdXY0P3FYH@20<J4FP80eYac0P3_cZd20<JDJ`@0aXaS0`2eNeX20;F<L`80aXAJ0P36
U6/20>NmW0@0e[f]0P3Nc[d40>OFcP80ilk6303gmoL20?O_ma@0moOg0P3gkoL80?Ogma00oooo000>
0?ooo`80mnog2P3gmoL20?O_m`80moOg103gkoL40?Ogm`80mnog1P3gmoL20?O_i`80moOg103gkoL2
0>NmW080_IAk0P2]Le8209AS@P@0S4Xa0P1kBRT406/i8@@0NdXY0`1[<AP20>O6]@@0klJe0P3ga[D<
0?O>]@80klj]1P3gc[D20>o6[@80kkFL0P3W[I`20>NeU080gYak103NYH@20=JLN`80eZF4103N[H`2
0>NeU080ikFL0P3__I`20>neW0H0klJU0P3_]I`20>o6Y@80kkFD0P3W[I@20=j]S080gZF4103FW7/2
0=JLL`80aXA[0P36Q6<20;EkFP80U5Y20P1J>BT202T@2080@RTQ0P1cBS4208AB<@80W6]:0P24DST2
0;EcBP@0W6<i0P1kBRT20=JUQ080aXAJ0P3FW7<20>o>[@80aYA[1036S6<30;EkFP80]Hac0P36Q5X2
0<JDJ`80ikfL103F_Jd20=k>_@@0imK>0P3Wc/H<0?Ogm`80mnog503gmoL20?O_m`P0moOg403oool0
00h0oooo3P3gmoL20?O_m`H0moOg0P3gkoL>0?Ogm`80knOW0P3F[H`20;F4H`80U6=20P24DS4208a:
<@80JcTQ0P1kBRT207=2:@80NdXY0P24@RT206/a60<0FS4Q0P3_a[D20>O6[@@0klJ]0P3gc[D20?O6
]@@0mmJm1P3gc[D20?O6]@80kmK60P3NW7/20=ikJ`@0klJ]0P3_]I`20>NUU0@0]F=20P36Q6/20=jL
N`80]G]J0P3FW7<20=j]S080ikFL103_aZD60>o6[@80klJU0P3_]I`20>NeW080ijfD0P3W[H`40=jU
Q080eYak0P3FW7<20<jDJ`80aXAS0P2eJe820:eS@P80Ld8Y0P0i6102048Y8@80FS4Q0P1cBS4208AB
>@80Q5Y2102LJdX208AB<@80W6]:0P2<FT820;f<H`80gZf40P3FW7<20=j]Q080aXAJ0P2mS6<309aS
>@@0]G]J0P3FW7<20>NmU080e[f]0P3_inL20<j]U080knOW0P3F]JDZ0?Ogm`80mnog0P3gmoL@0?oo
o`003P3oool>0?Ogm`80mnog1P3gmoL20?O_m`h0moOg0P3_inL20=J]S080]HAS0P2DHd8208AB<@80
S4Xa0P1[>B4207]::@80Ld8Y0P1kBRT208A2:@80Jc4H0`1J<B420>o6]@80ilJ]103_aZd20?O>]@80
mlJe103ge[d60?O>]@80mlJe0P3_e/H20=jLN`80gW][103_aZd20>neW080ijFD102eHd820<J4J`80
gYak0P2eNeX20=JLL`80gZf<0P3W]I`40>o6Y@H0klJ]0P3_aZD20>neW080ikFL0P3W[I@20>N]S0@0
gZF40P3FW7/20=JLL`80cYA[0P36Q6<20;E[DP80[F=20P1c@RT203TH4080@RTQ0P1J<B4207=:<@80
Q58i0P24FT8409a[BP80Q58a0P2LJdX208aJ@P80_HaS0P3N[H@20=JLL`80gZf40P36Q5X20;f<H`<0
W6<i102eNeX20=JLL`80ikfD0P3F_Jd20>oWi`80cZfD0P3_inL20=JeYBX0moOg0P3gkoL20?Ogma00
oooo000>0?ooo`@0mnog0P3gmoL40?O_m`P0moOg103gkoL20?Ogm`80mnog2P3gmoL20?O_m`80imkN
0P36U6/20:ecDP80U6=20P2LHcT407]::@80JcTQ0P1k@R4207]::@80JcTQ0P1J<B4308AB>@80klJe
0P3_aZd20>o>]@80mlje0P3ge[d20?O>]@80mlJe0P3ge[d20?O6]@80mlje0P3_cZd20?O>]@80mmJm
0P3_c[D20>o6]@@0mlJe0P3_aZd20>NeU080gZf<0P3N[I@20>N]S080ikFD0P3NYH@20<j<H`80eYak
0P3W]I`:0>o6[@80kkFL103_aZD20>neU080ijf<0P3N[H`20=jUQ080eYak103>U6/20<J4H`80aW]J
0P2LLe8208aJ@P80:A080P0i6102048Y8@80FT8i0P1cDT8208aJ@P80Q58i0P2LLe8208AB<@80U5Xa
0P1B:AP20=J]Q080cXaS0P3>U6<20>NmW080]G]J0P2mS6<309a[BP80[G=B0P2mS6<20<JDJ`80cZfD
103Na[D20<J]W080e[FU103gmoL20?O_m`X0moOg0P3gkoL80?Ogm`80mnog2P3gmoL40?O_m`H0moOg
403oool000h0oooo103gkoL20?Ogm`@0mnog203gmoL40?O_m`80moOg0P3gkoL:0?Ogm`80mnog0P3W
g]h20<JDJ`80[G=B0P2DHd8209aS>@@0NdXY0P1[>B4207]28@80NdXY0P1[>B4205Xa8@<0Q58i0P3_
a[D20>o6[@80klje0P3gc[D20?OF_@80mlje0P3ga[D20?OF_@80mlJe0P3gc[D20>o>[@80mlje0P3g
e[d20>o>]@80klJe103ga[D20>o6[@80ikFD0P3N[H`20=j]U080ijf<0P3W]I@20=jUQ080cXaS0P3F
W7/20>NeW0X0klJ]0P3_]I`40>o6Y@80kkFD0P3W[H`20=j]S080gZF40P3FW7/40<jDJ`80aXAS0P36
NeX209acDP80S5Y20P0Y40P203TH4080@RTQ0P1J@ST207=B@P80S5Y20P24DST209acDP80Q58a0P2D
FS42058Y6080eZf40P3>S6<20<jDH`80ikfL0P2eNeX20;f<H`<0W6]:0P2]Le820;f<H`80aYA[0P3>
[I@40=k6]@80aZfL0P3F]JD40?Ogm`80mnog2P3gmoL20?O_m`P0moOg0P3gkoL:0?Ogm`@0mnog1P3g
moL@0?ooo`003P3oool<0?Ogm`80mnog103gmoL40?O_m`P0moOg0P3gknL60?Ogm`80imK>0P2mS6<2
09AS@P80U5Y20P1[>B4207=:<@80Q4Xa0P1c@RT207]::@80Q4Xa101S:A030:EkH`80ilJ]1P3ga[D2
0>oFaPH0mmJm0P3_e/H40?O>]@80mlJe0P3ge[d20>o6]@H0kmK60P3ga[D20>o6Y@80ikFD103W[I`2
0=j]U080gZf<103NYH@20>neW0@0klJ]0P3ga[D60>o6[@H0kkFL0P3W]I@20>N]S080gZf<0P3NW7/4
0=j4L`80aXAS0P2eNeX20:e[@P80U6=20P0Y40P2048Q6080>AP@0P1cBS4208AB>@80U6=20P1c@RT2
09a[BP80Q58a0P2DFS4205Xa8@80aYA[0P2mS6<20=J]Q080ikfL0P2eNeX20;f<H`<0[G=B0P2eNeX2
0;F4H`80_IAk0P3F[H`40=k6]@80e[f]0P3Nc[d40?Ogm`80mnog3P3gmoL20?O_ma80moOg0P3gkoL6
0?Ogma00oooo000>0?ooo``0moOg0P3gkoL40?Ogm`@0mnog203gmoL20?O_i`H0moOg0P3We/h20;f<
H`80U6=20P2DFT8206/i8@80LdXa0P24BS4207=2:@80NdXY0P24BS4406<Y40<0YG]S0P3WaZd60?O6
]@80kmK61P3ge[d20>oFaP@0mlje0P3ga[D20?OF_@80klJe1P3_e/H20?O6]@80klJU0P3W]I@40>N]
W080gZfD0P3N[H`40=jUQ080kkFL103_aZd20?O6]@H0klJ]1P3_]I`20>NeU080ijf<0P3N[H`20=jL
N`@0gXAc0P36Q6<20;EkFP80[F]20P2DHd8202T@2080@R4H0P0i610207=:<@80Q58i0P2DHd8207=2
:@80W6]:0P24DS4209AJ<@80FS4Q0P36U6/20;f<H`80eZf40P3W_I`20;EkFP80_HaS0`2]Le820;Ek
FP80]HAS0P2mU7/20=J]S0@0g/Je0P3F_Jd20=k>_@@0moOg0P3gkoL>0?Ogm`80mnog4P3gmoL20?O_
m`H0moOg403oool000h0oooo1P3gmoL20?O_m`80moOg0P3gkoL40?Ogm`80mnog0P3gmoL20?O_m`@0
moOg0P3gknL20?Ogm`@0mnog0P3gmoL20?O_m`80ilk60P2]Le8208aJ@P80U5Xa0P24DS4407]::@80
Q4XY0P2<BS4207]28@80DRTH0P1J>BT30>O6]@80klJe103gc[D60?OF_@80kmK60P3ge[d20>oFaP80
mmJm0P3ga[D20>o6[@@0mmJm0P3_e/H20?ONeP80kmK60P3ga[D20>o6[@80ikfU0P3W[I@20>NUU080
gZfD0P3N[H`20=jUQ080ijfD0P3_]I`40>o6[@80klj]0P3_aZd20?O6]@80klJ]103_aZD40>neW080
ijfD0P3W[H`20=jUQ080gYak0P3>U6/20<J4J`80]G]J0P2]Jd8209AJ<@80DRTH0P0H20P2048Q6080
Ld8Y0P1B:AP209aS>@80Q58a0P2LJdX207]28@80Q58a0P2<FT820:ecDP80aXaS103NYG/20=JLL`80
]G]J0`2mS6<20:ecDP@0]G]J0P3>[I@20>O6[@80e[FU0P3Wc/H20?O_m`h0moOg103gkoLN0?Ogma00
oooo000>0?ooo`H0moOg0P3gkoL20?Ogm`80mnog103gmoL20?O_m`80moOg0P3gkoL40?Ogm`80mnoW
0P3gmoL40?O_m`80moOg0P3gkoL20>O>aP80[G=B0P2<FT8209AJ<@80Q58a101kBRT208A::@80S4Xa
0P1k@R42058Y6080FSTY0`3Wa[D20>o6]@@0mlje1P3ge[d20>oFaP80mmJm0P3_e/H20?OF_@80mlJe
0P3_aZd40?OF_@80kmK60P3gg]H20>oFaP80mlJe0P3_aZd20>NmY@80ijfD0P3WYI@20=j]U080gZf<
0P3NYH@20>N]U080kkFL103_aZd20>o>[@80klJ]0P3ga[D20>o6[@@0klJU103_]I`20>N]U080ijf<
0P3NYH@20=jLN`80cYA[0P36Q6/20;EkFP80[F]20P2DFS42058Y608060P80P128AP207=2:@80DRTH
0P2LHcT208AB<@80W6]:0P1k@R4208AB<@80S5Y20P2]Le820<J<H`@0gZEk0P3FW7<20;EkFP<0_HaS
0P2]Le840;EkFP80cZfD0P3WaZd20=JeY@80ilk60P3gkoL>0?Ogm`@0mnog7P3gmoL@0?ooo`003P3o
ool>0?Ogm`@0mnog0P3gmoL40?O_m`@0moOg0P3gkoL60?Ogm`80mnoW0P36U6/409AS@P80JcTQ101c
@RT207]::@80Q4Xa0P1kBRT2048Q6080HbT@0P128AP30>o6[@80mlJe0P3_c[d20?O6]@@0mmJm0P3_
e/H:0?OF_@@0mlje0P3ga[D60>oFaP80mlje0P3_aZd20>N]U080eZF<0P3NYH@20=j]S080eZF<0P3N
[I@20>NeW080klJ]103_a[D20>o>]@80mlje103_aZd20>o6Y@80klJ]0P3_aZD20>neW080ijfD0P3W
[H`20=j]S080gZF40P3FW7<20<J4J`80]G]J0P2]Le820:eS@P80LdXa0P0Q40P203TH4080FSTY0P1k
FT8208AB>@80S5Y20P2DHd8207]::@80Q58a0P1cBS4209acDP80aXAJ0P3>U6/20=j]S080ikfU0P2e
LdX30;EkFP80W7=B0P2eNeX20<JDJ`80ikfL0P3WaZd20<JLQ080g/jm0P3gmoL20?O_m`80moOg1P3g
koL60?Ogm`80mnog4P3gmoL20?O_m`X0moOg403oool000h0oooo3P3gmoL40?O_m`80moOg103gkoL4
0?Ogm`80mnog1P3gmoL20?O_i`80aYA[102DHd8206/i8@@0Ld8Y0P1kBRT208A:<@80NdXY0P128AP2
06<Y4080@R4H0`3_aZd20?O6]@80kljm0P3ga[D40?OF_@80kmK62P3ge[d40?O>]@80mlJe1P3_e/H2
0?O>]@80klJ]0P3W[I@20=JUS080gZF40P3N[H`20=JUS080gZfD0P3W]I`20>o6[@@0klJe0P3_c[D2
0?O>]@@0klJ]0P3_aZD20>o6[@80klJU0P3_]I`20>N]U080ijf<0P3N[H`20=jUQ080eYac0P36Q6/2
0;EkFP80[G=B0P2]Hd8207=:<@808A080P0i610205Xi:@80NeY20P24DST208aJ@P80U6=20P1kBRT2
08AB<@80LdXa0P2LLe820<J4FP80cYA[0P3N[H`20>NmY@80]G=:0`2eNeX209acDP80]G]J0P36U6/2
0>NmW080ilJ]0P36W8@20=k>_@80moOg0P3gkoL20?Ogm`H0mnog1P3gmoL20?O_ma80moOg0P3gkoL:
0?Ogma00oooo000>0?ooo`@0mnog1P3gmoL20?O_m``0moOg0P3gkoL20?Ogm`80mnog1P3gmoL20>o_
m`80]HA[0P2DHd8208A::@80JcTQ0P24DST408A:<@80NdXY0P0i6102058Y6080DR4@0P1J>BT30>o6
[@80mlje0P3ge[d@0>oFaP@0mmJm0P3ga[D20>o>_@80mlJe0P3ge[d20?O6]@80klJe0P3_]I`20>Ne
W080eZF<0P3N[H`40=j]U080ikFL1P3_aZd20>o6]@80mlJe0P3gc[D20>o6]@80mlJe0P3_aZd20>o6
Y@80klJ]103_]I`20>N]U080ijf<0P3FYH@20=jUQ080cYA[0P36Q6<20:ecDP80W6]:0P2<BS4202T@
2080@S4Y0P1B:AP207=2:@80LdXa1024DS4209aS>@@0Q58a0P2UNeX20;f<H`80cYAS0P3N[H`20>o>
[@80]G]J0`2eLdX209a[BP80YG]J0P2eQ6<20<j]U080g/Je0P3Nc[d20?O_ma`0moOg0P3gkoL80?Og
m`@0mnog203gmoL@0?ooo`003P3oool40?O_m`H0moOg0P3gkoL<0?Ogm`80mnog0P3gmoL20?O_m`H0
moOg0P3_koL20;F4J`80U6=20P24BRT206/i8@80Q58i1024BS4207]::@80>AP@0P1B:AP2058Q4080
FSTY0`3_aZd20?O>]@80mmJm403_e/H40?OF_@80mlJe0P3_c[d20?O6]@80mmJm0P3ga[D20>o6]@80
kkFL0P3W]I`20=JUS080gZf<103N[I@20>NeW0H0klJ]0P3_a[D20?O6]@80mlje0P3_a[D20?O6]@80
klJ]0P3_aZD20>o6[@@0kkFL0P3W[I@20>N]S080eZF40P3NYH@20<jDJ`80aXAS0P2]Le8209a[BP80
S4Xa0P0Y40P2048a:@80DRTH0P1c@RT207=:<@@0Q58a0P2LHcT408AB<@80YG]J0P2mS6<20<jDH`80
gZf<0P3_cZd20;EkFP<0]G=:0P2LJdX20:EkFP80]HAS0P3>[I@20=k6]@80g/jm0P3gkoLL0?Ogm`80
mnog203gmoL40?O_m`P0moOg403oool000h0oooo203gmoL20?O_m``0moOg0P3gkoL20?Ogm`80mnog
0P3gmoL80?O_m`80]HA[0P2DFS4407]::@80Q58i0P1cBS4207]::@80Q4Xa0P1B:AP2048Q6080DRTH
0P3>[I@50>o>]@80mmJm203_e/H60?ONcP80kmK61P3ge[d20?O>]@80klJe103ge[d20>o6[@80kkFL
103N[I@20=j]S080ikFD0P3W]I`20>NmY@80klJ]0P3_c[D20>o6]@@0mlJe0P3ge[d20>o>_@80mlJe
0P3_a[D40>o6[@80kkFL103W]I`20=j]U080gZF40P3FW7/20=JLL`80aXAS0P2eJe8209a[BP80U6=2
0P128AP2024@2080FS4Q0P1B:AP208AB>@80S5Y20P1kBRT209AJ<@80W6<i0P24DS4209acDP80aYb4
0P3FW7<20=j]Q080klj]0P2]Le830<J<H`80S5Y20P2eQ6<20:ecDP80ikfD0P3Wc[d20=k>_C00moOg
0P3gkoL20?Ogma00oooo000>0?ooo`P0moOg0P3gkoL<0?Ogm`80mnog0P3gmoL20?O_m`80moOg203g
koL20;F4J`80U5Xa101kBRT208AB>@80LdXa0P1kBRT208A:<@80DRTH0P128AP2058Y6080cZfD1@3_
c[D20?OF_@P0kmK61P3gg/h20>oFaPH0mmJm0P3gc[D20>o6]@@0mmJm0P3_aZd20>neW0@0gZfD0P3N
[H`20>NeU080ikFL0P3W_JD20>o6[@80klje0P3_a[D40?O6]@80mmJm0P3_c[d20?O6]@80klJe103_
aZd20>neW0@0ikFL0P3N[I@20=jUQ080eYak0P3FW7<20<J4H`80]F]B0P2LJdX209AS@P80@R4H0P0Q
40P205Xa8@80DRTH0P24DST208aJ@P80NdXY0P2DFS4209aS>@80Q58a0P2LLe820<JLQ080eYac0P3N
[H@20>o>[@80[G=B0`36S6<208aJ@P80]HAS0P2]Le820>NmU080iljm0P3Nc[d`0?Ogm`80mnog0P3g
moL@0?ooo`003P3oool60?O_m`h0moOg1P3gkoL40?Ogm`@0mnog0P3gmoL20=k6aP80W7=B0P2<FT82
07=2:@@0Q58a0P24BS4207]::@80DRTH0P128AP203TH4080kkFL0P3_c[d30?O6]@80mmJm0P3gg/h4
0>oFaP80mmk>403_e/H20?OF_@80mlje103ge[d20?O6]@80klJ]0P3W]I`20=j]U0@0ikFD0P3W]I`2
0>NmY@@0klJe0P3_e/H20?OF_@80mlJe0P3_e/H20?O6]@80mmJm103_c[d20>o6]@80klJ]0P3WaZd2
0>neW080ikFD0P3N[H`20=JUQ080eYak0P3FW7<20;EkFP80W6]:0P2LHcT207=2:@80HbT@0P1[>B44
07=:<@80U6=20P24DS4209aS>@80S5Y20P2<BS4209acDP80eZF40P3FW7<20=J]Q080ikfU0P2mS6<3
0;EcBP80Q58a0P2UNeX20;EkFP80gZf<0P3We/H20>o_ia80moOg0P3gkoL40?Ogm`@0mnog103gmoL2
0?O_m`80moOg0P3gkoL>0?Ogma00oooo000>0?ooo`H0mnog3P3gmoL60?O_m`@0moOg103gkoL20?Og
m`80g/K60P2LLe8208aJ@P80Ld8Y1024DS4208A:<@80NdXY0P1B:AP2048Q6080>AP@0P3_]I`20>o>
_@<0mlJe0P3ge[d20?ONcP@0kmK60P3gg/h@0>oFaP80mmJm0P3gc[D40?OF_@80mlJe0P3_aZd20>Ne
W080gZfD103W]I@20>NeW080ikfU103_a[D20>oFaP80mmJm0P3ga[D20>oFaP80mlJe0P3ge[d40>o>
_@80klJe0P3_aZd20>O6[@80kkFL0P3W]I@20=j]S080eZF40P3FW7/20=JLL`80]G]J0P2LJdX209aS
>@80Ld8Y0P1S:A0206/i8@@0LdXa0P2DHd8208AB<@80W6<i0P2<FT8208a:<@80W7=B0P3FYH@20=JL
L`80eZf40P3W_JD20;f<H`<0]G=:0P24DS420:EkFP80]G]J0P3N[H`20>OFaP80knoW4P3gmoL20?O_
m`@0moOg103gkoL40?Ogm`80mnog0P3gmoL20?O_m`h0moOg403oool000h0oooo0P3gkoL20?Ogm`80
mnog303gmoL20?O_m`@0moOg0P3gkoL:0?Ogm`80W7=B0P2DFS4208AB<@80FS4Q0P1kFT8407=:<@80
Q4Xa0P1B:AP206/i8@80FSTY0P3_aZd20>o6]@<0kmK60P3ge[d40>oFaP@0mmk>103_e/H20?OF_@80
mmk>203_e/H20?OF_@80kljm1P3ge[d20?O6]@80ikFL0P3N[I@20>NeW080ikfL103W_JD20>O6[@80
klje0P3ge[d20>o>_@80mmJm0P3_e/H20?OF_@80mlJe1P3_c[d20>o6]@80klJ]0P3W_JD20>NeW080
gZfD0P3N[H`20=JLN`80eYac0P36NeX20;E[DP80U5Y20P1cBS4606/i8@80Q58i0P24DS4209aS>@80
U6=20P2<FT8209AcFP80]HA[0P3FW7/40=JLL`80eZf40P36S6<30:e[>@80Q4XY0P2UNeX20;fDN`80
eZf<0P3Wg]HT0?Ogm`80mnog1P3gmoL20?O_m`P0moOg403oool000h0oooo0P3gkoL20?Ogm`80mnog
303gmoL20?O_m`@0moOg0P3gkoL:0?Ogm`80W7=B0P2DFS4208AB<@80FS4Q0P1kFT8407=:<@80Q4Xa
0P1B:AP206/i8@80FSTY0P3_aZd20>o6]@<0kmK60P3ge[d40>oFaP@0mmk>103_e/H20?OF_@80mmk>
203_e/H20?OF_@80kljm1P3ge[d20?O6]@80ikFL0P3N[I@20>NeW080ikfL103W_JD20>O6[@80klje
0P3ge[d20>o>_@80mmJm0P3_e/H20?OF_@80mlJe1P3_c[d20>o6]@80klJ]0P3W_JD20>NeW080gZfD
0P3N[H`20=JLN`80eYac0P36NeX20;E[DP80U5Y20P1cBS4606/i8@80Q58i0P24DS4209aS>@80U6=2
0P2<FT8209AcFP80]HA[0P3FW7/40=JLL`80eZf40P36S6<30:e[>@80Q4XY0P2UNeX20;fDN`80eZf<
0P3Wg]HT0?Ogm`80mnog1P3gmoL20?O_m`P0moOg403oool000h0oooo0P3gkoLF0?Ogm`80mnog1P3g
moL20?O_m`80moOg0P2]Le8209aS>@80LdXa0P1[>B4208aJ@P80Q58i0P1kBRT207=2:@80JcTQ0P1B
:AP20:F4L`80mlJe0P3_c[d70>oFaP@0mmk>0P3_e/H20?OF_@80kmK6103ge[d20>oFaP@0mmk>103_
e/H40?OF_@80kmK6103ga[D20>NeW0@0gZfD0P3W_I`20>NmY@@0klJ]1P3_c[d40>oFaP@0mlJe0P3g
e[d20?O>]@80klje0P3_a[D40>o6[@80ikfU0P3N[I@20=j]S080eZF40P3FW7<20<J4H`80]F]B0P2D
FT8208a:<@@0FS4Q0P1[>B4207=:<@80Q4Xa0P2DHd8209aS>@80U6=20P2DFS480=JLL`80eZF40P3F
[H@50:e[@P80[G=B0P2eQ6<20=j]Q080knoW6P3gmoL20?O_m`80moOg0P3gkoLF0?Ogma00oooo000>
0?ooo`80mnog5P3gmoL20?O_m`H0moOg0P3gkoL20?Ogm`80[G=B0P2LHcT207=:<@80JcTQ0P2<FT82
08AB>@80NdXY0P1c@RT206/i8@80DRTH0P2UQ7<20?O6]@80kljm1`3_e/H40?ONcP80kmK60P3ge[d2
0>oFaP@0mmJm0P3_e/H40?ONcP@0kmK6103ge[d20>oFaP@0mlJe0P3W]I`40=j]U080ikfL0P3W_JD4
0>o6[@H0kljm103_e/H40?O6]@80mmJm0P3gc[D20>o>]@80klJe103_aZd20>NmY@80gZfD0P3N[H`2
0=JUQ080eYac0P36Q6<20;E[DP80U5Y20P2<BS4405Xa8@80JcTQ0P1cBS4208A:<@80U6=20P2LHcT2
09AS@P80U5Xa203FW7<20=JUQ080eZf41@2]Jd820:ecDP80]HAS0P3N[H@20>o_iaX0moOg0P3gkoL2
0?Ogm`80mnog5P3gmoL@0?ooo`003P3oool40?Ogm`80mnog0P3gmoL20?O_m`H0moOg0P3gkoL@0?Og
m`80mnog102LLe8208AB>@80LdXa0P1c@RT208AB>@80Q4Xa0P1J<B4207=2:@80Q58i0P3_a[D20?O>
]@80kljm3`3_e/H20?OF_@80kmK60P3_c[d80>oFaP@0mmJm0P3_a[D40>oFaP80mmJm0P3W_JD20>N]
U080gZfD0P3W]I`40>NmY@80ilJ]0P3_a[D60>o>_@80kmK60P3_c[d20?OF_@80kljm103_a[D20>o6
[@80klJe0P3WaZd40>NmY@80gZfD0P3FYH@20=JLN`80cYA[0P2eNeX209a[BP80Q58i0P1c@RT206/a
60@0JcTQ0P24DST209AJ<@80S6=:0P24DST208A::@80eZf<0P3FW7<20<JDJ`80eYak0P36W8@20=j]
S0<0U5Xa102]Le820:F4J`80eZf40P3gknLR0?Ogm`80mnog4P3gmoL@0?ooo`003P3oool40?Ogm`80
mnog0P3gmoL20?O_m`H0moOg0P3gkoL@0?Ogm`80mnog102LLe8208AB>@80LdXa0P1c@RT208AB>@80
Q4Xa0P1J<B4207=2:@80Q58i0P3_a[D20?O>]@80kljm3`3_e/H20?OF_@80kmK60P3_c[d80>oFaP@0
mmJm0P3_a[D40>oFaP80mmJm0P3W_JD20>N]U080gZfD0P3W]I`40>NmY@80ilJ]0P3_a[D60>o>_@80
kmK60P3_c[d20?OF_@80kljm103_a[D20>o6[@80klJe0P3WaZd40>NmY@80gZfD0P3FYH@20=JLN`80
cYA[0P2eNeX209a[BP80Q58i0P1c@RT206/a60@0JcTQ0P24DST209AJ<@80S6=:0P24DST208A::@80
eZf<0P3FW7<20<JDJ`80eYak0P36W8@20=j]S0<0U5Xa102]Le820:F4J`80eZf40P3gknLR0?Ogm`80
mnog4P3gmoL@0?ooo`003P3oool20?O_m`H0moOg0P3gkoL20?Ogm`80mnog0P3gmoL20?O_m``0moOg
0P3gkoL20?Ogm`80_Jf]0P2DFS4208aSBP80Q58a0P2<FT8208AB<@80S4Xa0P1[>B4205Xi:@80Ld8Y
0P3WaZd20?OF_@80klJe0P3ge[d90>oFaP80mmk>103_e/H20?OF_@80kljm103_a[D40>o>_@@0mmJm
0P3ga[D20?O>]@@0kmK60P3ge[d20>o6[@80ijfD0P3N[H`20=j]U080gZfL0P3W_I`20=j]W080ilJe
0P3Wc[d20>o6]@80kmK61P3_c[d20>o6]@80ilJe0P3_a[D60>o6[@@0ikfU0P3N[I`20=j]S080eZF4
0P3NQ7<20<J4H`80W6]:0P2DFS4207=:<@80DRTH101[>B4207=:<@80W6]:1P2<FT820<JLQ080aYA[
103FW7<209a[BP80ikfD0`24@R4209a[BP80_HaS0P36U6/20<j]U200moOg0P3gkoLF0?Ogma00oooo
000>0?ooo`80mnog1P3gmoL20?O_m`80moOg0P3gkoL20?Ogm`80mnog303gmoL20?O_m`80moOg0P2m
[Jd209AJ<@80S6=:0P24DS4208aJ@P80Q58a0P2<BS4206/i8@80FSTY0P1c@RT20>O6[@80mmJm0P3_
a[D20?OF_@T0kmK60P3gg/h40>oFaP80mmJm0P3_c[d40>o6]@@0kljm103ge[d20?O6]@80mlje103_
e/H20?OF_@80klJ]0P3W[I@20=j]S080gZfD0P3N[I`20>NmW080gZfL0P3Wa[D20>O>_@80klJe0P3_
e/H60>o>_@80klJe0P3Wa[D20>o6]@H0klJ]103W_JD20=j]W080gZf<0P3FYH@20=j4L`80aXAS0P2L
JdX209AJ<@80LdXa0P1B:AP406/i8@80LdXa0P2LJdX608aJ@P80aYb40P36U6/40=JLL`80W6]:0P3W
_I@308A28@80W6]:0P2mS6<20<JDJ`80cZfD803gmoL20?O_maH0moOg403oool000h0oooo1P3gmoL2
0?O_m`@0moOg0P3gkoL@0?Ogm`80mnog0P3gmoL20:EkJ`80]Hac0P2LJdX207=:<@80W6]:0P1cBS42
08a:<@80FS4Q0P1cBS4207]::@80ilJ]0P3ga[D20>O6[@D0kmK60P3gg/h40>oFaP80mmJm0P3_e/H4
0>o>_@80kkFL0P3WaZd40>o6[@80klJe0P3_c[d20?OF_@80klje0P3gc[D20?OF_@80kmK60P3ge[d2
0>o6[@80ijFD0P3N[H`20=JUS0@0gZfD0P3W_JD20>O6]@80klJe0P3_c[d40>O6[@80ikfU203WaZd2
0>o6[@80klJe103WaZd20=JeY@80ikfL0P3N[H`20=JUQ080eYac0P36Q6<20:ecDP80U5Xa0P24BS42
058Y6080DR4@0P1[>B4207=:<@80S5Y20P2LHcT408aJ@P80aYb4103>U6/20=JLL`80Q4Xa0P3N[H@3
09AJ@P80S5Y20P2eQ6/20=JUQ080ilJ]1P3gmoL20?O_maP0moOg0P3gkoLF0?Ogma00oooo000>0?oo
o`H0moOg0P3gkoL40?Ogm`80mnog403gmoL20?O_m`80moOg0P2UNf/20;F<L`80W6]:0P1cBS4209a[
BP80LdXa0P2<BS4205Xa8@80LdXa0P1kBRT20>O6[@80mlJe0P3WaZd50>oFaP80mmk>103_e/H20?OF
_@80kmK6103_c[d20>neW080ilJ]103_aZd20>o6]@80kljm0P3ge[d20>o>]@80mlje0P3ge[d20>oF
aP80mmJm0P3_aZd20>NUU080gZf<0P3FYH`40=j]U080ikfU0P3Wa[D20>o6]@80kljm103WaZd20>Nm
Y@P0ilJ]0P3_aZd20>o6]@@0ilJ]0P3F]JD20>NmW080gZf<0P3FYH@20=JLL`80aXAS0P2]Le8209AJ
<@80Q4Xa0P1B:AP2058Q4080JcTQ0P1cBS4208aJ@P80W6<i102<FT820<JLQ0@0cYA[0P3FW7<208A:
<@80gZf40`2DFT8208aJ@P80]HA[0P3FYH@20>O6[@H0moOg0P3gkoLH0?Ogm`80mnog5P3gmoL@0?oo
o`003P3oool60?Ogm`80mnog1P3gmoL20?O_m`H0moOg203gkoL40?Ogm`80S4XY0P2eU7/208aJ@P80
U6]B0P24FT8208aJ@P80LdXa0P1B:AP209aS>@80ijf<0P3_aZd20>N]U080klJe0P3ge[d90>oFaP80
kljm0P3Wc[d40>o6]@80klJ]0P3N[I`20=j]U080ikfU0P3WaZd20>o6]@80kljm0P3WaZd20>o6]@@0
kmK60P3ge[d20>neW080gZfD0P3NW7/20=J]S080eZF<0P3>[I@20=JeY@80ilJ]0P3Wa[D40>NmY@80
e[FU0P3W[I`40=j]S080eZF<103N[I`60>NmY@@0ikfL0P3N[I@20=JUQ080cYA[0P36Q6/20;E[DP80
W6]:0P24DST207=2:@80>AP@0P1S:A0206/i8@@0S5Y20P2LJdX208AB>@80_IAk0P3FW7/20;EkFP80
_HaS0P24BRT20>NmU0<0W6]:0P2<BS420<JDJ`80eZf40P3We/H@0?Ogm`80mnog5P3gmoL20?O_m`h0
moOg403oool000h0oooo1P3gmoL20?O_m`H0moOg0P3gkoL60?Ogm`P0mnog103gmoL208a::@80]IAk
0P2<FT8209A[DP80Q5Y20P2<FT8207=:<@80DRTH0P2LHcT20>N]S080klJ]0P3W[I@20>o6]@80mmJm
2@3_e/H20>o>_@80iljm103_a[D20>o6[@80gZfL0P3N[I@20>NmY@80ilJ]0P3_a[D20>o>_@80ilJ]
0P3_a[D40>oFaP80mmJm0P3_]I`20=j]U080gYak0P3F[H`20=JUS080cZfD0P3F]JD20>O6[@80ilJe
103W_JD20=JeY@80ijfL103N[H`20=JUS0@0gZfL1P3W_JD40>NmW080gZfD0P3FYH@20<jDJ`80aXA[
0P2eJe8209a[BP80Q58i0P1c@RT203TH4080HbT@0P1[>B4408aJ@P80W6]:0P24DST20;fDN`80eYak
0P2eNeX20;f<H`80Q4XY0P3W_I@309a[BP80S4Xa0P36U6/20=J]Q080imK6403gmoL20?O_maH0moOg
0P3gkoL>0?Ogma00oooo000>0?oooa80moOg0P3gkoL20?Ogm`80mnog203gmoL20?ooo`80W6]:0P2U
Nf<208AB>@80S5Y20P24DST209AJ@P80DR4@0P24DS4208A:<@80mlJe0P3>U6/20=jUQ080klje0P3g
e[d70>oFaP80kljm0P3Wa[D20=j]W080_IAk0P2eS7<20=JUS080cZFD0P2mU7/40=j]W0@0kljm103_
a[D60?OF_@80klJ]0P3N[I@20=JLN`80aYb40P3FW7/20>NmW080gZfL0P3Wa[D20>N]W080gZfL0P36
YI`20;fLS080]HA[0P2eS7<60<JLQ080cZFD0P3W_I`20>NmY@H0gZfL0P3N[H`20=JUQ080aYb40P36
Q6/20;EkFP80U5Y20P24DST207=:<@80JcTQ101J<B4208AB>@80Q58a0P2<HdX208aJ@P80]HA[0P2m
S6<40;EkFP80U5Xa0P3W_I@309AJ<@80S4Xa0P36W8@20=JLL`80imK>0P3ooolf0?Ogma00oooo000>
0?oooa80moOg0P3gkoL20?Ogm`80mnog203gmoL20?ooo`80W6]:0P2UNf<208AB>@80S5Y20P24DST2
09AJ@P80DR4@0P24DS4208A:<@80mlJe0P3>U6/20=jUQ080klje0P3ge[d70>oFaP80kljm0P3Wa[D2
0=j]W080_IAk0P2eS7<20=JUS080cZFD0P2mU7/40=j]W0@0kljm103_a[D60?OF_@80klJ]0P3N[I@2
0=JLN`80aYb40P3FW7/20>NmW080gZfL0P3Wa[D20>N]W080gZfL0P36YI`20;fLS080]HA[0P2eS7<6
0<JLQ080cZFD0P3W_I`20>NmY@H0gZfL0P3N[H`20=JUQ080aYb40P36Q6/20;EkFP80U5Y20P24DST2
07=:<@80JcTQ101J<B4208AB>@80Q58a0P2<HdX208aJ@P80]HA[0P2mS6<40;EkFP80U5Xa0P3W_I@3
09AJ<@80S4Xa0P36W8@20=JLL`80imK>0P3ooolf0?Ogma00oooo000>0?ooo`80mnog203gmoL20?O_
m`80moOg0P3gkoL@0?Ogm`80_IbD0P2UNeX209acDP80LdXa0P24DST207=:<@80U5Y20P1J<B4209AJ
<@80kkFD0P3_]I`20>N<N`80eZF<0P3_c[D20>o>_@D0kmK60P3_a[D20>N]W080]HAS0P2mS6<20=j]
W080_Jf]0P1cJf<207=cJ`80YHAc0P36W8@40=j4L`@0klJe0P3WaZd60?OF_@80klJU0P3W]I`20=JL
N`80eZF40P2mU7/20=JUQ080W4Xa0P36FTX20<J4J`80eZF<0P3Na/H209AkL`80LeY:0P2UNf/20:Ek
H`80YG]J0P2UNf<20;F4J`80eZF<103N[I@40=j]W0@0eZF<0P3>U6/20<J4J`80]F]B0P2LJdX208aJ
@P80LdXa0P24DST4058Y60@0Q58i0P2<FT8209a[BP80]HAS0P2mU7/20;EcBP80]G]J0P2DDRT20>Nm
W0<0W6<i0P2LLe840=J]Q080knOW7P3gmoL20?O_maP0moOg403oool000h0oooo0P3gkoL80?Ogm`80
mnog0P3gmoL20?O_ma00moOg0P2mW9@20:EkFP80W7=B0P1cBS4208AB>@80LdXa0P2DFT8205Xa8@80
U5Xa0P3_]I@20>neW080ihak0P3FYH`20>o>]@80kljm1@3_e/H20>o6]@80ijfL0P2eQ6<20;f<H`80
gZfL0P2m[Jd207=[H`80Lg=[0P2UQ7<20<JLQ0@0gXAc103_a[D20>O6[@H0mmJm0P3_aZD20>NeW080
eYak0P3FYH@20;fDN`80eZF40P2LBS420<IJBP80aXA[0P3FYH`20=k6aP80U7]c0P1cFTX20:EkJ`80
YG]S0P2UNeX20:EkH`80]HA[0P3FYH`40=j]U0@0gZfL103FYH`20<jDJ`80aXA[0P2eJe8209a[BP80
S5Y20P1cBS4208AB>@@0DRTH1024DST208aJ@P80W6]:0P2eQ6<20;fDN`80]G=:0P2eNeX209AB:@80
ikfL0`2LHcT209acDP@0eZf40P3_inLN0?Ogm`80mnog603gmoL@0?ooo`003P3ooolF0?Ogm`80mnog
203gmoL20;F4J`80_Ib<0P2LLe8208aSBP80FS4Q0P24DST209AJ@P80Jc4H0P1B:AP20?O6]@80ijf<
0P3WYI@20=j]U080kljm0P3ge[d30>o>_@80ilJ]0P3W[I`20;F4J`80aXA[0P3F_KD20>OFcP80Ng=c
0P1cJf<206=JDP80Q7]c0P2UNf/20<JLQ080_IAk0P3W[I`20=j]U080klJU103ge[d20>o>]@80klJ]
0P3W]I`20=jUQ080_IAk0P2eQ6/20<J4J`80aYb40P2]@S420=k6aP80knOW0P2<Lf<209AcFP80Nf]J
0P2DS8@206]SFP80_IbD0P2LLe8208a[DP80]HA[103FYH@20=j]U080gZf<0P3FYH`20=JLN`80eYac
0P2eQ6/20:ecDP80W6]:0P24DS4207=:<@80FS4Q0P0Y40P2048Q6080Q58i0P2<FT8207=2:@80W6]:
0P2eQ6/20;F4H`80W6]:0P2UNeX20:eS@P80gZf<0`24BRT20;fDN`@0eZf<6P3gmoL20?O_m`H0moOg
0P3gkoLF0?Ogma00oooo000>0?oooaH0moOg0P3gkoL80?Ogm`80]HA[0P2mW8`209acDP80S6=:0P1J
<B4208AB>@80U5Y20P1[<AP2058Y6080mlJe0P3W[H`20>NUU080gZfD0P3_c[d20?OF_@<0kljm0P3W
aZd20>N]W080]HA[0P36Q6/20=Jm]@80imK>0P1kLg<207=[H`80HeYB0P24Ng<20:EkJ`80aYb40P2m
U7/20>N]W080gZfD0P3_aZD40?OF_@80klje0P3_aZd20>NeW080gZF40P2mU7/20;F4J`80aXA[0P36
W8@20:e2<@80g/K60P3_inL208acH`80U7=J0P1kJeX209B<Q080Jf=J0P2mW9@209acDP80S6]B0P2e
Q6/40=JUQ080gZfD0P3N[H`20=JUS080eYak0P3FW7<20;F4J`80[G=B0P2LJdX208AB<@80LdXa0P1J
<B4202T@2080@R4H0P24DST208aJ@P80Ld8Y0P2LJdX20;F4J`80]HAS0P2LJdX20:EkFP80[F=20P3N
[H`308A::@80_IAk103F[H`J0?Ogm`80mnog1P3gmoL20?O_maH0moOg403oool000h0oooo403gmoL2
0?O_m``0moOg0P3oool20?O_m`80YHA[0P24DS4207]::@80FS4Q1P24DST209AJ@P80mlJe0P3NYH@2
0>N<N`80gZfD0P3Wa[D20>o>]@<0klJ]0P3N[I`20;fDN`80U7=J0P1J>BT20;FDS080a[Fe0P2DNf/2
0;Fe_@808APH0P24Lf/205Y:@P80U7=J0P2eQ6/20;fDN`80ikFL0P3_cZd40?OF_@80mlje0P3_aZd2
0>NmW080ikFD0P2mU7/20;F<L`80W7=B0P2eS7<20;fDN`80W6]:0P3>a[d206=JDP80]Kg>0P0Q61P2
07=cJ`80HeYB0P2mW9@2048a:@80Le920P2UNf<20;F<L`80_IAk0P3FYH@20=JUS080eZF40P2mU7/2
0<JDJ`80aXAS0P2]Le8209AJ@P80Q58i0P24BS42048Q6080>AP@0P128AP2058Y6080Q58i0P1cBS42
0:ecDP80W7=B102UNeX20;EkFP80[F=20P3F[H@308A::@80_HaS0P3FW7/20=k6]CX0moOg403oool0
00h0oooo403gmoL20?O_m``0moOg0P3oool20?O_m`80YHA[0P24DS4207]::@80FS4Q1P24DST209AJ
@P80mlJe0P3NYH@20>N<N`80gZfD0P3Wa[D20>o>]@<0klJ]0P3N[I`20;fDN`80U7=J0P1J>BT20;FD
S080a[Fe0P2DNf/20;Fe_@808APH0P24Lf/205Y:@P80U7=J0P2eQ6/20;fDN`80ikFL0P3_cZd40?OF
_@80mlje0P3_aZd20>NmW080ikFD0P2mU7/20;F<L`80W7=B0P2eS7<20;fDN`80W6]:0P3>a[d206=J
DP80]Kg>0P0Q61P207=cJ`80HeYB0P2mW9@2048a:@80Le920P2UNf<20;F<L`80_IAk0P3FYH@20=JU
S080eZF40P2mU7/20<JDJ`80aXAS0P2]Le8209AJ@P80Q58i0P24BS42048Q6080>AP@0P128AP2058Y
6080Q58i0P1cBS420:ecDP80W7=B102UNeX20;EkFP80[F=20P3F[H@308A::@80_HaS0P3FW7/20=k6
]CX0moOg403oool000h0oooo7P3gmoL20;FDN`80e/K60P2US7<209AcFP80Ne920P1cBS4408AB>@80
U5Y20P3>Lf<20>neW080ihak0P3FW7/20=j]S080klJe0P3_c[D30>NeW080cZFD0P36Q6/207=:<@@0
Q6=B0P1J@ST2048Y8@80FSTY0P24DST208a[DP80Q6=B0P2UNf<20;fDN`80ijfD0P3__I`40?O>]@80
mmJm0P3gc[D20>o6[@80kkfL0P3W]I`20=jUQ080_IAk0P36Q6/20:ecDP80U7=J102US8@205Xi:@80
DRTH101J>BT207=:<@80FT8i0P1cFTX207]B@P80YG]S0P2eQ6<20;F4J`80cYA[103FW7/20;fDN`80
]HA[0P2eNeX209AJ@P@0S5Y20P1cBS4206/i8@80@R4H0P1J>BT406/i8@80LdXa0P2LJdX20:ecDP80
W6]:0P2LHcT20;EkFP80[G=B0P3F[H@309AS@P80_HaS0P3FW7<20>oWgRX0moOg0P3gkoL>0?Ogma00
oooo000>0?oooah0moOg0P2eU7/20=K6aP80YHac0P2DLeX207]B@P80LdXa1024DST209AJ@P80cW=S
0P3_]I`20>N<N`80eYak0P3N[H`20>o6]@80klje0`3W]I`20<jUU080aXA[0P1cBS4408ASDP80FT8i
0P12:B4205Xi:@80Q58i0P2<Je8208ASDP80YG]S0P2mU7/20>N]U080kkfL103gc[D20?OF_@80mlje
0P3_aZd20>nmW080ikFL0P3NYH@20;fDN`80aXA[0P2]Le8209AcFP@0YHb40P1J>BT2058Y60@0FSTY
0P1cBS4205Y2>@80LeY:0P1kDT820:EkH`80]HAS0P2eQ6/20<jDJ`@0eYak0P2mU7/20;F4J`80]G]J
0P2DFT8408aJ@P80LdXa0P1[>B42048Q6080FSTY101[>B4207=:<@80W6]:0P2]Le8209a[BP80W6<i
0P2eNeX20:ecDP80eZf40`2DHd820;f<H`80eYac0P3_imhZ0?Ogm`80mnog3P3gmoL@0?ooo`003P3o
ool80?Ogm`80mnog1P3gmoL20?O_m``0moOg0P2]Le820;fLU080]Ib<0P2<FT8207=:<@80S6=:0P24
DST207=:<@80S4Xa0P36Q6<20>NUU0@0eYak0P3N[H`20>o6]@80ilJe0`3WaZd20>NmY@80gZfD0P2m
U7/20;E[DP80S6=:1P1kDT8208AB>@80U7=J0P36Q6/20=JUQ080ikFL103_aZd20?O>]@@0mmJm0P3g
c[D40>o6[@80klJU0P3W]I@20=jUQ080eYak0P2mU7/20;F4J`80Q6=:0P2UNf<20:F4L`80W7][0P24
He8206=:@P80FT8i0P1cBS4209acDP80_HaS0P2eS7<20<J4J`80cYA[103FW7/20;fDN`80cYA[0P2m
S6<20;E[DP80U5Y20P2<FT8408AB>@80Ld8Y0P1B:AP205Xi:@@0FS4Q0P1c@RT209acDP80]G]J0P2L
Le8209aS>@80]G]J0P2mS6<20=J]Q0<0W6]:0P2mS6<20=JUQ080knoW>P3gmoL@0?ooo`003P3oool8
0?Ogm`80mnog1P3gmoL20?O_m``0moOg0P2]Le820;fLU080]Ib<0P2<FT8207=:<@80S6=:0P24DST2
07=:<@80S4Xa0P36Q6<20>NUU0@0eYak0P3N[H`20>o6]@80ilJe0`3WaZd20>NmY@80gZfD0P2mU7/2
0;E[DP80S6=:1P1kDT8208AB>@80U7=J0P36Q6/20=JUQ080ikFL103_aZd20?O>]@@0mmJm0P3gc[D4
0>o6[@80klJU0P3W]I@20=jUQ080eYak0P2mU7/20;F4J`80Q6=:0P2UNf<20:F4L`80W7][0P24He82
06=:@P80FT8i0P1cBS4209acDP80_HaS0P2eS7<20<J4J`80cYA[103FW7/20;fDN`80cYA[0P2mS6<2
0;E[DP80U5Y20P2<FT8408AB>@80Ld8Y0P1B:AP205Xi:@@0FS4Q0P1c@RT209acDP80]G]J0P2LLe82
09aS>@80]G]J0P2mS6<20=J]Q0<0W6]:0P2mS6<20=JUQ080knoW>P3gmoL@0?ooo`003P3ooolH0?Og
m`80mnog103gmoL20>oWgP80YHak0P2DJe8207=:<@80Ld8Y101cBS4206/i8@80W6]:0P36Q6<20<jD
J`80aYb40P2mU7/20=JUS080ilJe1@3_c[D20?OF_@80kljm0P3_aZd20>o6]@80ikfU0P3W]I`20>N]
W080ikFL0P3W_JD20>NeW080eYak0P3NYH@20>N]U080klJU0P3ge[d20?O>]@@0kmK60P3ge[d20?O>
]@80klj]0P3_aZd20>NeU080eYac0P3NW7/20;fDN`80eZF40P3FYH`20=JUQ0H0_IAk0P3>U6/20=JL
N`@0eZF40P3N[H`20>N]S080gZfD0P3FYH`20=JUQ080eYak0P3>U6/20<J4J`80_HaS0P2eNeX209AJ
@P80S6=:0P24DST406/i8@80DRTH0P1J>BT207=:<@80Ld8Y0P1[>B4209a[BP80_HaS0P2LJdX209aS
>@80aXAJ0P2mU7/20=j]U0<0W7=B0P2mU7/20>oNcP80oooo=P3gmoL20?O_m`80moOg403oool000h0
oooo603gmoL20?O_m`@0moOg0P3_imh20:F<N`80U6]B0P1cBS4207=2:@@0LdXa0P1[>B4209a[BP80
aXAS0P3>U6/20<JLQ080_IAk0P3FYH`20>O6]@D0klje0P3ge[d20>o>_@80klJ]0P3_a[D20>NmY@80
ikFL0P3W[I`20>NeW080ikfU0P3W]I`20=JLN`80gZF40P3W[I@20>o6Y@80mmJm0P3gc[D40>oFaP80
mmJm0P3gc[D20>o>[@80klJ]0P3W]I@20=JLL`80gYak0P2mU7/20=JUQ080eZF<0P3FYH@60;fDN`80
cYA[0P3FW7/40=JUQ080gZf<0P3W[H`20=j]U080eZF<0P3FYH@20=JLN`80cYA[0P36Q6/20;f<H`80
]G]J0P2DFT8208aSBP80Q58i101[>B42058Y6080FSTY0P1cBS4207=2:@80JcTQ0P2LJdX20;f<H`80
W6]:0P2LHcT20<J4FP80_IAk0P3N[I@309acDP80_IAk0P3_g/h20?ooocH0moOg0P3gkoL20?Ogma00
oooo000>0?ooo`@0moOg0P3gkoL40?Ogm`80mnog2P3gmoL20?O_m`@0moOg103oool207=2:@80S5Y2
0P1J<B4406/i8@80U6=20P1J<B4209a:<@80]F]B0P3NQ7<20<jDJ`80]Hac0P3FYH@20>o>]@80ikfU
0`3gc[D40?OF_@80kmK6103ge[d20>oFaP80ijFD0P36Q6/20:EkH`80W7=B0P2eJe820>NeW080klJU
1P3ge[d20?ONcP80kmK60P3ge[d20>oFaP80mlje0P3ge[d20>nmW080ijfD0P36Q6/20:eS@P80W7=B
0P2eJe820;F<L`80ikfU0P3WaZd20>o6[@80ilJ]103W_JD60>NeW080gZfD0P3FYH@20<JDJ`80]HAS
0P3>U6/20;f<H`80]G]J0P2]Le8209a[BP80S5Y20P24DS4208AB>@80HbT@101B:AP205Xi:@80DR4@
0P1cBS4208aJ@P80[G=B0P2LJdX209AS@P80aXaS0P36U6/20>NmW0<0YG]J0P36W8@20>oWic`0moOg
403oool000h0oooo103gmoL20?O_m`@0moOg0P3gkoL:0?Ogm`80mnog103gmoL40?ooo`80Ld8Y0P2<
FT8205Xa8@@0JcTQ0P2DHd8205Xa8@80W4Xa0P2eJe820=j4L`80cYA[0P2eS7<20=JUQ080klje0P3W
_JD30?O>]@@0mmJm0P3_e/H40?OF_@80kmK60P3WYI@20<J4J`80YG]S0P2LLe820;E[DP80ikFL0P3_
aZD60?OF_@80mmk>0P3_e/H20?OF_@80kmK60P3gc[D20?OF_@80kkfL0P3W[I@20<J4J`80[F=20P2L
Le820;E[DP80]Hac0P3W_JD20>O6[@80klJ]0P3WaZd40>NmY@H0ikFL0P3N[I@20=JUQ080aYA[0P2e
Q6<20<jDJ`80_HaS0P2eNeX20:ecDP80W6]:0P2<FT8208AB<@80Q58i0P1S:A04058Y6080FSTY0P1B
8A0207=:<@80S5Y20P2]Le8209a[BP80U6=20P36S6<20<JDJ`80ikfL0`2UNeX20<JLQ080knOW?03g
moL@0?ooo`003P3ooolL0?Ogm`80knOW0P3oool206/i8@80NdXY0P1J<B4206/i8@80LdXa0P24DST2
07=:<@80W6<i0P2eHd820;EkFP80_HaS0P36Q6/20<JLQ080klJ]0P3Na[D30>NmW080klJe0P3ge[d4
0>oFaP80mlJe0P2eQ6/20:EkH`80U7=J0P2eJe820=JUQ080klJU103gc[D20?OF_@80mmk>0P3ge[d2
0?ONcP80kmK61P3ge[d40?O>]@80klJU0P3W[I@20;f<H`80U5Y20P24DST209AJ@P80]F]B0P3NYH@2
0>N]W080ilJ]103_aZd20>neW080ikfU0P3N[I@20=jUQ080_IAk0P2UNeX20<jDJ`80]Hac0P2eQ6/2
0:ecDP@0W6]:0P2<FT8406/i8@80DRTH0P1J<B42058Y6080DR4@0P1cDT8208AJ@P80U6]B0P2UNeX2
09acDP80U5Xa102mS6<20=J]S0<0_IAk0P36W8@n0?Ogma00oooo000>0?oooa`0moOg0P3_inL20?oo
o`80JcTQ0P1kBRT205Xa8@80JcTQ0P1cBS4208AB>@80LdXa0P2LHcT20;ES@P80]G]J0P2mS6<20<J4
J`80aYb40P3_aZd20=k6]@<0ikfL0P3_a[D20?OF_@@0kmK60P3ga[D20;F4J`80YG]S0P2DLeX20;E[
DP80eZF40P3_aZD40?O>]@80mmJm0P3gg/h20?OF_@80mmk>0P3_e/H60?OF_@@0mlje0P3_aZD20>N]
U080_HaS0P2DFT8208AB>@80U5Y20P2eJe820=jUQ080ijfL0P3WaZd40>o6[@80kkFL0P3W_JD20=j]
U080gZF40P2mU7/20:EkFP80cYA[0P2eS7<20;F4J`80[G=B102LJdX208aJ@P@0JcTQ0P1B:AP205Xa
8@80DRTH0P1B8A0207=B@P80Q5Y20P2DJe820:EkFP80W7=B0P2DFS440;f<H`80eZf<0`2mU7/20<JL
Q3h0moOg403oool000h0oooo5P3gmoL20?O_m`80moOg0P3oool20;f][@80oooo0P24DS4207=2:@@0
LdXa0P1J<B4208AB>@80NdXY0P2DFS4409AJ@P80YG]S0P2eQ6/20<JLQ080ilJe0P3_c[d30;fDN`80
aYb40P3FYH@20=JLN`80gXAc0P2eJe820:ecDP80eYak0P3gc[D40?OF_@`0mmk>203_e/H20?OF_@80
kmK61P3gc[D20>o>[@80ikFL0P3FYH@20;F<L`80U7=J0P2<FT8209acDP80[F=20P3>JeX20;F<L`80
aXA[0P2eQ6<20:EkH`80YG]J0P2eQ6/40;fDN`80gXAc0P2mS6<20:ecDP@0W6]:0P24DST209a[BP80
@R4H101c@RT206/i8@80DRTH0P12:B4208ASBP80W6]:0P2]Le8209a[BP80U6=20P2mS6<20=JLL`80
]HA[0`2]Jd820=k>_B80moOg0P3gkoLJ0?Ogma00oooo000>0?oooaH0moOg0P3gkoL20?Ogm`80oooo
0P2m[Jd20?ooo`80Q58a0P1c@RT407=:<@80FS4Q0P24DST207]::@80U5Xa102DFT820:EkH`80]HA[
0P36W8@20>O6]@80kljm0`2mU7/20<JLQ080eZF40P3FW7/20=j4L`80]F]B0P2]Le820=JLN`80mlje
103ge[d<0?ONcPP0kmK60P3ge[d20>oFaPH0mlje0P3_cZd20>NeW080eZF40P2eS7<209AcFP80S5Y2
0P2LLe820:eS@P80cV]J0P2eS7<20<J4J`80]HAS0P2UNf<20:EkFP80]HA[102mU7/20=j4L`80_HaS
0P2]Le8409a[BP80Q58i0P2LJdX2048Q60@0Ld8Y0P1[>B42058Y6080@RTQ0P24HdX209a[BP80[G=B
0P2LJdX209AS@P80_HaS0P3FW7<20;F4J`<0[F]20P3Nc[dR0?Ogm`80mnog6P3gmoL@0?ooo`003P3o
oolF0?Ogm`80mnog103gmoL20<JUU080W7=B101cBS4208ASBP80Q58i1P1cBS4208AB>@80U5Xa0P2<
HdX209acDP80YG]J0P3FYH@20>O6]@D0klje0P3_aZd20=JUQ080_Ib<0P3NQ7<20=j]W080kmK64P3g
g/h20?ONeP@0kmK61P3gg/h40?OF_@80kmK60P3ge[d20?O>]@80mlJe1P3_aZd40>O6[@80aYb40P2U
Nf<20:ecDP@0YG]S0P2mU7/20<JLQ080_IAk0P3>U6/20=JLL`80cYA[0P2mS6<20:ecDP80W7=B0P2]
Le8208AB>@80JcTQ0P1cBS4206/i8@80FS4Q100i6102048Q6080S6=:0P2DLeX208aJ@P80YG]J0P2]
Hd820<JDJ`80aYb40P2LJdX30;f<H`80knOW9P3gmoL20?O_maH0moOg403oool000h0oooo5P3gmoL2
0?O_m`@0moOg0P36YI@209acDP@0LdXa0P24HdX208AB>@H0LdXa0P24DST209AJ<@80S6=:0P2LLe82
0:EkFP80eZF40P3Wa[D50>o>]@80klJ]0P3FYH@20;fLS080gXAc0P3N[I`20>oFaQ80mmk>0P3gg]H4
0>oFaPH0mmk>103ge[d20>oFaP80mmJm0P3gc[D20?O6]@H0klJ]103WaZd20<JLQ080YG]S0P2]Le84
0:EkH`80_IAk0P36W8@20;fDN`80cYA[0P3FW7<20<jDJ`80_HaS0P2]Le8209acDP80[G=B0P24DST2
06/i8@80LdXa0P1[>B4205Xa8@@0>AP@0P128AP208aSBP80U7=J0P2<FT820:EkFP80[F=20P36U6/2
0<JLQ080W6]:0`2mS6<20>oWibH0moOg0P3gkoLF0?Ogma00oooo000>0?ooo`P0moOg0P3gkoL60?Og
m`80mnog2P3gmoL20=K6aP80W6]:0P1kFT8207=:<@80W7][0P2<Je8207]J@P80Q58i0P1cBS4408aJ
@P80S6=:102]Le820=JLN`80klJ]0P3_a[D50>o>]@@0mmJm1P3_e/H>0?ONcP80mmkF103gg/h20>oF
aPH0mmk>2P3_e/H20?OF_@@0klje0P3gc[D60>o6[@80ikfU103WaZd20>NeW080gZfD0P3N[H`20=JU
S080eYak0P3FYH@20;fDN`80]Hac0P2eNeX20:ecDP80YG]J0P2]Le8209a[BP80LdXa0P1[>B42058Q
40H0>AP@0P128AP20;F<L`80S6=:0P2<FT820=JLL`80W6]:0P2eNeX20=J]Q080W6]:0`36W8A00?Og
ma00oooo000>0?ooo`P0moOg0P3gkoL60?Ogm`80mnog2P3gmoL20=K6aP80W6]:0P1kFT8207=:<@80
W7][0P2<Je8207]J@P80Q58i0P1cBS4408aJ@P80S6=:102]Le820=JLN`80klJ]0P3_a[D50>o>]@@0
mmJm1P3_e/H>0?ONcP80mmkF103gg/h20>oFaPH0mmk>2P3_e/H20?OF_@@0klje0P3gc[D60>o6[@80
ikfU103WaZd20>NeW080gZfD0P3N[H`20=JUS080eYak0P3FYH@20;fDN`80]Hac0P2eNeX20:ecDP80
YG]J0P2]Le8209a[BP80LdXa0P1[>B42058Q40H0>AP@0P128AP20;F<L`80S6=:0P2<FT820=JLL`80
W6]:0P2eNeX20=J]Q080W6]:0`36W8A00?Ogma00oooo000>0?ooo`@0moOg0P3gkoL80?Ogm`80mnog
303gmoL20<jeY@80Q4XY0P1cDT8208AJ@P80YHac0P2DJe8208AB>@80Q5Y20P1kFT8408AJ@P80S5Y2
0P2UNeX209acDP80eYak0P3WaZd50>o>]@80kljm103ge[d20>oFaP@0mmk>0P3_e/H20?OF_@H0mmk>
0P3ge[d80?ONcP80mmJm0P3_e/H20?ONcP@0kmK60P3gg/h20>oFaPP0mmJm0P3ga[D20?O>]@80klJe
0P3_aZd20>O6[@80ikfU0P3_aZd40>NeW080gZfD103FYH@40=JLN`80_IAk0P36U6/20;f<H`80]F]B
102]Le8208aJ@P80W6]:0P1c@RT4058Y6080@R4H0P1J<B42058Q4080_IAk0P2UNeX208aJ@P80_IAk
0P2]Le8209a[BP80eZf<0P2LJdX30=Jm[@80oooo?P3gmoL@0?ooo`003P3oool40?Ogm`80mnog203g
moL20?O_m``0moOg0P3>]JD208A::@80Le920P24FT820:F<L`80U6]B0P24DST208AJ@P80NeY21024
FT8208aJ@P80YG]J0P2LLe820=JLN`80ilJ]1@3_c[D20>o>_@@0mmJm0P3_e/H40?ONcP80kmK60P3g
e[d60?ONcP80mmJm203gg/h20?OF_@80kmK60P3gg/h40>oFaP80mmk>0P3_e/H80?OF_@80mlJe0P3g
c[D20>o6]@80klJ]0P3WaZd20>NmY@80klJ]103W]I`20=j]U0@0eZF4103FW7/20;fDN`80aYA[0P2m
S6<20;E[DP@0[G=B0P2<FT8209a[BP80Ld8Y101B:AP2048Q6080FS4Q0P1B8A020;fDN`80YG]J0P2<
FT820;fDN`80[G=B0P2LJdX20=J]S080W6]:0`3F_Jd20?oooch0moOg403oool000h0oooo703gmoL2
0=k>aP80Q58i0P2<Je8208aSBP80W7=B0P2<HdX208a[DP80S6=:0P24FT8208AB>@@0Q58a0P2LJdX2
09acDP80aXA[0P3W_I`20>o6]@D0klje0P3_c[d40?OF_@80kmK6103gg/h20?OF_AX0mmk>1P3_e/H:
0?O>]@80klJ]0P3_aZD20>O6[@80klJ]0P3W_JD20>NmW080ikFD0P3N[I@20=j]S080eZF<0P3FYH@2
0=JLN`80eYac0P3>U6/20;EkFP80[G=B0P2eNeX209acDP80W6]:0P1cBS4205Xa8@80JcTQ0P1J<B44
03TH4080@R4H0P36U6/20:EkH`80W6]:0P3FW7<20;EcBP80S6=:0P2mU7/209a[BP<0mnog@03gmoL@
0?ooo`003P3ooolL0?Ogm`80g/k60P24DST208a[DP80S6=:0P2LLe8208aSBP80S6]B0P2<HdX208AJ
@P80Q58i1024DS4209a[BP80W7=B0P36Q6/20>NmW080klJe1@3_c[D20>o>_@@0mmJm0P3_e/H40?ON
cP80mmJm6P3gg/h60>oFaPX0mlje0P3_aZd20>o6Y@80ilJ]0P3_aZd20>NmY@80ikfL0P3W]I@20=j]
U080gZf<0P3FYH`20=JUQ080eYak0P3FW7<20<jDJ`80]G]J0P2]Le820;EkFP80W7=B0P2LJdX207=:
<@80FS4Q0P1[>B4205Xa8@@0>AP@0P128AP20<JDJ`80YG]S0P2LJdX20=JLL`80]G=:0P2<HdX20;fD
N`80W6]:0`3gkoM00?Ogma00oooo000>0?ooo`X0moOg0P3gkoL@0?Ogm`80mnog0P2<HdX608AB>@80
Q6=:0P2<HdX208AB>@80Q5Y20P24DST208AJ@P80Q58i0P2UNeX20;EkFP80aYA[0P3W]I`20>NmY@<0
klj]0P3_c[d20?O>]@@0mmJm103_e/H:0?ONcP@0mmJm2P3gg/h:0>oFaP80mlJe1P3gc[D20>o>[@H0
klJ]0P3_]I`20>NmY@80ikfL0P3W_JD20>NeW080gZf<0P3N[I@20=jUQ080eZF40P2mU7/20<jDJ`80
aXA[0P2mS6<20;EkFP80[G=B0P2LJdX208AB>@80LdXa0P1J>BT207=2:@80@R4H100i610205Xa8@80
W7=B0P3FW7<20;F4H`80eYak0P2eNeX209acDP80U6=20P3>[I@Y0?Ogm`80mnog603gmoL@0?ooo`00
3P3oool:0?Ogm`80mnog403gmoL20?O_m`80S6=:1P24DST208ASBP80S6=:0P24DST208AJ@P80Q58i
0P24FT8208AB>@80YG]J0P2eNeX20<JDJ`80ikFL0P3W_JD30>o>[@80kljm0P3gc[D40?OF_@@0kmK6
2P3gg/h40?OF_@X0mmk>2P3_e/H20?O6]@H0mlje0P3_cZd60>o6[@80kkFL0P3W_JD20>NmW080ikfU
0P3W]I`20=j]S080gZfD0P3NYH@20=JUQ080_IAk0P3>U6/20<J4J`80_HaS0P2eNeX20:ecDP80W6]:
0P24DST207=:<@80FSTY0P1c@RT2048Q60@0>AP@0P1J<B4209acDP80eYac0P2eQ6<20=JLN`80]G]J
0P2LLe8209AS@P80cZfD:@3gmoL20?O_maP0moOg403oool000h0oooo703gmoL20?ooo`80Ne920P2<
Je8208AB>@80S6=:0P2<Je8209A[DP80S6=:1024FT8208AB>@80S6=:0P2LLe820;f<H`80_IAk0P3N
[H`20>NmY@<0klje0P3_c[d80?OF_@@0mmk>103ge[d40?ONcP80mmJm103gg/h20>oFaPH0mmk>1P3_
e/H80?OF_@@0mlje0P3_cZd60>o6[@80kkFL203W]I`20>N]U080gZf<0P3FYH`20=JUQ080eYak0P3>
U6/20;F<L`@0]HAS0P2UNf<209a[BP80S5Y20P1[>B4207=:<@80DR4@10128AP203TH4080@RTQ0P2D
LeX20;fDN`80W7=B0P36U6/20;f<H`80YHA[0P2DHd820>O>aT<0moOg403oool000h0oooo703gmoL2
0?ooo`80Ne920P2<Je8208AB>@80S6=:0P2<Je8209A[DP80S6=:1024FT8208AB>@80S6=:0P2LLe82
0;f<H`80_IAk0P3N[H`20>NmY@<0klje0P3_c[d80?OF_@@0mmk>103ge[d40?ONcP80mmJm103gg/h2
0>oFaPH0mmk>1P3_e/H80?OF_@@0mlje0P3_cZd60>o6[@80kkFL203W]I`20>N]U080gZf<0P3FYH`2
0=JUQ080eYak0P3>U6/20;F<L`@0]HAS0P2UNf<209a[BP80S5Y20P1[>B4207=:<@80DR4@10128AP2
03TH4080@RTQ0P2DLeX20;fDN`80W7=B0P36U6/20;f<H`80YHA[0P2DHd820>O>aT<0moOg403oool0
00h0oooo703gmoL20?ooo`80W7][0P1cDT8208aJ@P@0U6]B0P24FT8208aSBP80Q58i0P1kFT8209A[
DP80S6=:0P2LLe820;F4J`80aYA[0P3FYH`20>NmY@<0klJ]1P3gc[D60?OF_@@0mmk>0P3_e/H20?OF
_@@0mmk>0P3_e/H20?OF_@80mmk>0P3ge[d40>oFaP80mmJm0P3_e/H60?OF_@80mlje0P3ge[d40?O>
]@80klJ]0P3gc[D20>o6[@@0klJU0P3W_JD20>NmW080ikfU0P3W]I@20=j]U080gZf<0P3FYH`20=JU
Q080_IAk0P3>U6/20<J4J`@0]HAS102LJdX208aJ@P80LdXa0P1[>B42058Q4080>AP@100Y40P207]B
@P80S6=:0P2UNeX20:ecDP80aYb40P36U6/20=J]S080aYA[A@3gmoL@0?ooo`003P3ooolL0?Ogm`80
oooo0P2LNf/207=B@P80S5Y2102DJe8208AJ@P80S6=:0P24DST207]J@P80U6]B0P2<HdX209acDP80
]HA[0P36U6/20=JUS080ikfU0`3_aZd60?O>]@H0mmJm103gg/h20>oFaP80mmJm103gg/h20>oFaP80
mmJm0P3gg/h20?OF_@@0kmK60P3ge[d20>oFaPH0mmJm0P3gc[D20?OF_@@0mlje0P3_aZd20?O>]@80
klJ]103_aZD20>NmY@80ikfL0P3W_JD20>NeU080gZfD0P3N[H`20=JUS080eZF40P2mU7/20<jDJ`80
aXA[102eQ6<409a[BP80S5Y20P1cBS4206/i8@80DR4@0P0i610402T@2080Ne920P2<HdX20:EkFP80
[G=B0P36W8@20<JDJ`80eZf<0P36U6]50?Ogma00oooo000>0?oooa`0moOg0P3oool208AB>@80YG]S
0P2UNeX208aJ@P80S6=:0P24HdX208aJ@P80Q5Y20P2LHcT207=2:@80S6=:0P2UNf<20;f<H`80]Hac
0P3FYH@20>NmW0<0klJ]0P3_c[D20?O>]@H0mmJm103gg/h20>oFaPH0mmk>0P3ge[d20?ONcP80mmJm
0P3_e/H20?ONcP80mmJm103_e/H20?OF_@@0kmK6203ge[d20>o6[@80mlJe0P3_cZd40>o6[@80kkFL
0P3_aZD40>NeW0@0gZfD0P3N[H`20=JUS080eZF40P2mU7/20=JLL`80]Hac0P2eQ6/209acDP80U6]B
0P24FT8207=:<@80Q58i0P1J<B4203TH4080:A080P12:B4202T@2080Q6=:0P2DJe8209a[BP80U6=2
1036U6/20<JLQ080imkFA@3gmoL@0?ooo`003P3ooolL0?Ogm`80oooo0P24DST20:EkH`80YG]J0P2<
FT8208aSBP80Q6=:0P2<FT8208AJ@P80W6<i0P1c@RT208aSBP80YG]S0P2mS6<20;F<L`80eZF40P3W
_I`30>o6[@80klje0P3gc[D60?OF_@@0mmk>0P3_e/H60?ONcP80mmJm0P3gg/h20?OF_@80kmK60P3g
g/h20?OF_@@0kmK60P3ge[d40>oFaPP0mmJm0P3_aZd20?O6]@80klj]103_aZd20>neW080klJU103W
]I`40=j]U080gZf<0P3FYH`20=JUQ080_IAk0P3FW7<20;F<L`80]HA[0P2LLe8209A[DP80Q5Y20P1c
BS4208AB>@80FS4Q0P0i610202T@2080@RTQ0P0Y40P208ASBP80U6]B0P2LJdX209AS@P@0aYA[0P36
W8@20>ONeTD0moOg403oool000h0oooo103gmoL20?O_m`80moOg0P3gkoLD0?Ogm`80imkN0P2UNf<4
07]J@P@0Q58i0P24DS4208AJ@P80Q58i102<HdX20:EkFP80]Hac0P36W8@20=JUS080ikfL0`3_aZd2
0>o>]@@0mmJm0P3_e/H20?OF_@@0mmk>0P3ge[d20?ONcP80mmJm0P3gg/h20?OF_@80kmK60P3ge[d2
0?ONcP80mmJm103_e/H80?OF_@80kmK6103ge[d20?O6]@@0mlje1P3_aZd20>neW080klJU103W]I`2
0=j]U0H0gZf<0P3FYH@20<JLQ080eYak0P2eQ6/20:EkH`@0W7=B0P2LJdX207]J@P80JcTQ0P1J<B44
03TH4080@RTQ0P0i610409A[DP80W7=B0P2LHcT20<JDJ`80aYb40P3FYHa70?Ogma00oooo000>0?oo
o`@0moOg0P3gkoL20?Ogm`80mnog503gmoL20>ONgP80YG]S101kFT8408AB>@80Q58a0P24FT8208AB
>@@0S6=:0P2UNeX20;F<L`80aYb40P3FYH`20>NmW0<0klJ]0P3_c[D40?OF_@80kmK60P3ge[d40?ON
cP80mmJm0P3gg/h20?OF_@80mmk>0P3ge[d20>oFaP80mmJm0P3gg/h20?OF_@@0kmK6203ge[d20>oF
aP@0mmJm0P3ga[D40?O>]@H0klJ]0P3_]I`20>o6Y@@0ikFL0P3N[I@60=j]S080eZF40P36W8@20=JL
N`80]HA[0P2UNf<409acDP80W6]:0P1kFT8206/i8@80FS4Q100i6102048Y8@80>AP@102DJe8209ac
DP80W6<i0P36U6/20<JLQ080eZF<A`3gmoL@0?ooo`003P3ooolN0?Ogm`80oooo0P2<HdX207]J@P80
Q58i0P1cBS4208AB<@80Le920P1cBS4207]J@P80S6=:0P2LJdX20;F4H`80]Hac0P3FW7/20=J]S080
ikfL0`3_aZd20?O>]@80mlJe0P3ge[d20>oFaPP0mmJm0P3_e/H80?ONcP@0kmK60P3gg/h@0?OF_@80
mlJe1P3gc[D20>o6[@80mlje0P3_aZd40>o6Y@80kkfL0P3W]I`20=j]U080gZf<0P3FYH`20=j]S0@0
eZF40P2mU7/40;F4J`80YG]S0P2<HdX208aJ@P80JcTQ0P1J<B44048Q6080:A080P0i8AP203TH4080
W7]S0P2DJe8209aS>@80U6=20P36W8@20<jeY@80g/k6A`3gmoL@0?ooo`003P3ooolN0?Ogm`80oooo
0P2<HdX207]J@P80Q58i0P1cBS4208AB<@80Le920P1cBS4207]J@P80S6=:0P2LJdX20;F4H`80]Hac
0P3FW7/20=J]S080ikfL0`3_aZd20?O>]@80mlJe0P3ge[d20>oFaPP0mmJm0P3_e/H80?ONcP@0kmK6
0P3gg/h@0?OF_@80mlJe1P3gc[D20>o6[@80mlje0P3_aZd40>o6Y@80kkfL0P3W]I`20=j]U080gZf<
0P3FYH`20=j]S0@0eZF40P2mU7/40;F4J`80YG]S0P2<HdX208aJ@P80JcTQ0P1J<B44048Q6080:A08
0P0i8AP203TH4080W7]S0P2DJe8209aS>@80U6=20P36W8@20<jeY@80g/k6A`3gmoL@0?ooo`003P3o
oolP0?Ogm`80c[Fe0P24HdX408AB>@80Q58a1024DST207=B@P80Q58i0P2LJdX20:EkH`80]Hac0P36
W8@20=j]W080ikfU0`3_aZd40?O>]@80mmJm103_e/H20?ONcP80kmK62P3gg/h20>oFaP80mmk>0P3g
e[d20>oFaP80mmk>0P3_e/H20?OF_@80kmK6203ge[d20?O>]@80mmJm0P3gc[D20?O6]@80klj]103_
aZd40>o6Y@@0ikFL0P3N[I`40=j]S080eZF40P3FYH`40<jDJ`80_HaS0P2UNf<20:EkFP80W7=B0P2<
FT8205Xi:@80FS4Q0P128AP2048Y8@80<APH10128AP20:EkH`80]HA[0P2<FT820:ecDP80aYA[0P3W
_I`40?Ogm`80mnog@`3gmoL@0?ooo`003P3ooolP0?Ogm`80c[Fe0P24HdX408AB>@80Q58a1024DST2
07=B@P80Q58i0P2LJdX20:EkH`80]Hac0P36W8@20=j]W080ikfU0`3_aZd40?O>]@80mmJm103_e/H2
0?ONcP80kmK62P3gg/h20>oFaP80mmk>0P3ge[d20>oFaP80mmk>0P3_e/H20?OF_@80kmK6203ge[d2
0?O>]@80mmJm0P3gc[D20?O6]@80klj]103_aZd40>o6Y@@0ikFL0P3N[I`40=j]S080eZF40P3FYH`4
0<jDJ`80_HaS0P2UNf<20:EkFP80W7=B0P2<FT8205Xi:@80FS4Q0P128AP2048Y8@80<APH10128AP2
0:EkH`80]HA[0P2<FT820:ecDP80aYA[0P3W_I`40?Ogm`80mnog@`3gmoL@0?ooo`003P3oool20?Og
m`80mnog703gmoL20?O_m`80S6]B101cBS4407=B@P80Q58i0P1kFT8207=B@P80U6]B0P2eQ6<20;fD
N`80eZF40P3N[I@20>o6Y@<0klJ]0P3_a[D20>o>]@80mlje2P3ge[d20?ONcP80mmJm0P3gg/h20>oF
aP@0mmJm0P3_e/H20?OF_@@0kmK61P3ge[d20>oFaP@0mmJm103gc[D20>o>[@80mlje0P3ga[D60>o6
[@@0ikfU0P3W_I`20>NeU0@0gZf<0P3FYH`40=JLN`80]Hac0P2mS6<20:EkH`80W7=B0P2<HdX208AB
>@80FSTY0P1J<B42048Y8@80@R4H101B:AP203TH4080W6]:0P2eQ6<209a[BP80aXAJ0P3FYH@20=k>
cTT0moOg403oool000h0oooo0P3gmoL20?O_ma`0moOg0P3gkoL208a[DP@0LdXa101cDT8208AB>@80
NeY20P1cDT8209A[DP80]HAS0P2mU7/20=JUQ080gZfD0P3_aZD30>o6[@80klJe0P3_c[D20?O>]@X0
mmJm0P3gg/h20?OF_@80mmk>0P3_e/H40?OF_@80kmK60P3ge[d40>oFaPH0mmJm0P3_e/H40?OF_@@0
mlje0P3_cZd20?O>]@80mlJe1P3_aZd40>NmY@80ikfL0P3W]I@40=j]S080eZF<103FW7/20;F<L`80
_HaS0P2UNf<209acDP80S6=:0P24DST205Xi:@80FS4Q0P12:B42048Q60@0DRTH0P0i610209a[BP80
]HAS0P2LJdX20<J4FP80eZF40P3Nc/i90?Ogma00oooo000>0?ooob80moOg0P2UNf<208a[DP80Le92
0P24FT8207]J@P80Le920P1kFT8208AJ@P80U6]B0P2LLe820<JDJ`80eZf<103W_JD30>o6[@@0mlje
1P3ge[d40>oFaP@0mmk>0P3_e/H40?OF_@P0kmK6103ge[d20>oFaPP0mmJm1P3gc[D40>o>[@80klJ]
103_aZD20>o6[@80ikfU0P3W_I`20>NeU080ijfD103N[H`40=jUQ080cYA[0P2eS7<20;F4J`80[G=B
0P2LJdX208aJ@P80LdXa101J>BT2058Y6080@R4H0P1B:AP203TH4080:A080P2DJe8209acDP80W6]:
0P2mS6<20=j]S080knoWB@3gmoL@0?ooo`003P3ooolR0?Ogm`80YG]S0P2<Je8207=B@P80Q5Y20P1k
FT8207=B@P80NeY20P24FT8209A[DP80W7=B0P36U6/20=J]S0@0ikfU0`3_aZd40?O>]@H0mmJm103_
e/H40?ONcP80kmK6103ge[d80>oFaP@0mmJm0P3_e/H80?OF_@H0mlje103_cZd20>o6[@@0klJU0P3_
aZd20>NmY@80ikfL0P3W]I@20>N]U0@0gZf<103NYH@20<jDJ`80]Hac0P2eQ6/20:ecDP80W6]:0P2<
FT8207=:<@@0FSTY0P1B:AP2048Q6080DRTH0P0i610202T@2080U6]B0P2LLe8209a[BP80_HaS0P3N
[H`20>o_idT0moOg403oool000h0oooo8P3gmoL20?ooo`80c[Fe0P2UNf<609A[DP@0NeY20P2DJe82
0:F4J`80]Hac0P3FW7/20>NeW080klJU1@3_aZd20?O>]@80klje0P3gc[D80>oFaP@0mmJm0P3_e/H2
0?ONcP80mmJm0P3_e/H80?OF_@80mlje0P3ge[d80?O>]@80mmJm0P3ga[D20?O>]@P0klJU0P3_]I`2
0>NmY@80ikfL0P3W]I@20=j]U080ikFD1P3FYH@40;F<L`80YG]S0P2UNeX208aSBP80Q58i0P1c@RT2
07=:<@@0FS4Q0P128AP203TH40808A080P1J>BT20;F4J`80W7=B0P2eLdX20<jDJ`80cZfD0P3gmoL2
0?O_mdL0moOg403oool000h0oooo8P3gmoL20?ooo`80c[Fe0P2UNf<609A[DP@0NeY20P2DJe820:F4
J`80]Hac0P3FW7/20>NeW080klJU1@3_aZd20?O>]@80klje0P3gc[D80>oFaP@0mmJm0P3_e/H20?ON
cP80mmJm0P3_e/H80?OF_@80mlje0P3ge[d80?O>]@80mmJm0P3ga[D20?O>]@P0klJU0P3_]I`20>Nm
Y@80ikfL0P3W]I@20=j]U080ikFD1P3FYH@40;F<L`80YG]S0P2UNeX208aSBP80Q58i0P1c@RT207=:
<@@0FS4Q0P128AP203TH40808A080P1J>BT20;F4J`80W7=B0P2eLdX20<jDJ`80cZfD0P3gmoL20?O_
mdL0moOg403oool000h0oooo0P3gmoL20?O_ma80moOg0P3gkoL:0?Ogm`@0oooo0P3_inL209AcFP80
U6]B0P24FT8208aSBP80Q6=:0P2<HdX20:ecDP80_IAk0P36W8@20=j]U080klJU1@3_aZd40?O>]@@0
mmJm0P3gc[D40>oFaP`0mmJm0P3_e/H:0?OF_@H0mlje0P3ge[d20?O>]@P0klJ]0P3_aZD20>o6[@80
kkfL1P3W]I`20>NeU080gZf<0P3FW7/20=JUS0@0_IAk0P2mS6<20:ecDP80U5Y20P24DST208AJ@P80
Ld8Y101J>BT2048Y8@80DRTH0P0Q61P2024@2080YG]J0P2UNf<209AS@P80]G]J0P36S6<20>O>_D/0
moOg403oool000h0oooo0P3gmoL20?O_ma80moOg0P3gkoL:0?Ogm`@0oooo0P3_inL209AcFP80U6]B
0P24FT8208aSBP80Q6=:0P2<HdX20:ecDP80_IAk0P36W8@20=j]U080klJU1@3_aZd40?O>]@@0mmJm
0P3gc[D40>oFaP`0mmJm0P3_e/H:0?OF_@H0mlje0P3ge[d20?O>]@P0klJ]0P3_aZD20>o6[@80kkfL
1P3W]I`20>NeU080gZf<0P3FW7/20=JUS0@0_IAk0P2mS6<20:ecDP80U5Y20P24DST208AJ@P80Ld8Y
101J>BT2048Y8@80DRTH0P0Q61P2024@2080YG]J0P2UNf<209AS@P80]G]J0P36S6<20>O>_D/0moOg
403oool000h0oooo9P3gmoL20?ooo`80_IbD0P24DST208ASBP80Le92102<HdX20:EkFP80_HaS0P3F
W7/20=j]W080ikfU0`3_]I`40>o6[@80mlje103_cZd40?O>]@H0mmJm0P3gc[D60?OF_@80mlje0P3g
e[d20>o>]@80mlje0P3_c[d60?O>]@80klj]203_aZd20>o6Y@80klJ]103_aZD20>neW0H0ikFL103N
[I@20=JUS080eYak0P3FYH@20;F<L`80YG]S0P2LJdX209AS@P80S5Y21024FT8405Xa8@80DRTH0P0i
610202T@2080]HA[0P2LNf<209a[BP80U6=20P2mS6<20=JeY@80knOW0P3gmoL40?O_mdD0moOg403o
ool000h0oooo9P3gmoL20?ooo`80_IbD0P24DST208ASBP80Le92102<HdX20:EkFP80_HaS0P3FW7/2
0=j]W080ikfU0`3_]I`40>o6[@80mlje103_cZd40?O>]@H0mmJm0P3gc[D60?OF_@80mlje0P3ge[d2
0>o>]@80mlje0P3_c[d60?O>]@80klj]203_aZd20>o6Y@80klJ]103_aZD20>neW0H0ikFL103N[I@2
0=JUS080eYak0P3FYH@20;F<L`80YG]S0P2LJdX209AS@P80S5Y21024FT8405Xa8@80DRTH0P0i6102
02T@2080]HA[0P2LNf<209a[BP80U6=20P2mS6<20=JeY@80knOW0P3gmoL40?O_mdD0moOg403oool0
00h0oooo9P3gmoL20?ooo`80g/jm0P1[>B4208AJ@P80YG]J0P1kFT840:EkFP80_HaS0P36W8@20=j]
U080ikfL0`3WaZd20>o6[@80klJU0P3_aZd40?O>]@80mmJm0P3gc[D20>o>_@80mmJm0P3gc[D:0?OF
_@@0mlje0P3ge[d20?O>]@80klJ]0P3gc[D20>o6[@80mlje103_aZd20>o6Y@@0klJ]103_aZD20>Nm
W080kkfL103W]I@20=j]W080gZf<0P3>[I@20;fDN`80eYak0P3>U6/20;F4J`80YG]S0P2LLe8209a[
BP80Q5Y20P1cBS4207=B@P80U6]B0P128AP203TH4080>B4H0P1kFT8208AB>@80YG]J0P2LJdX20:ec
DP80aYA[0P3W_JD20?O_m`80moOg0P3gkoL20?ooodD0moOg403oool000h0oooo9P3gmoL20?ooo`80
g/jm0P1[>B4208AJ@P80YG]J0P1kFT840:EkFP80_HaS0P36W8@20=j]U080ikfL0`3WaZd20>o6[@80
klJU0P3_aZd40?O>]@80mmJm0P3gc[D20>o>_@80mmJm0P3gc[D:0?OF_@@0mlje0P3ge[d20?O>]@80
klJ]0P3gc[D20>o6[@80mlje103_aZd20>o6Y@@0klJ]103_aZD20>NmW080kkfL103W]I@20=j]W080
gZf<0P3>[I@20;fDN`80eYak0P3>U6/20;F4J`80YG]S0P2LLe8209a[BP80Q5Y20P1cBS4207=B@P80
U6]B0P128AP203TH4080>B4H0P1kFT8208AB>@80YG]J0P2LJdX20:ecDP80aYA[0P3W_JD20?O_m`80
moOg0P3gkoL20?ooodD0moOg403oool000h0oooo9P3gmoL20?ooo`80c[FU0P2LLe8408AB>@80Q6=:
0P2UNf<20:EkFP80_HaS0P3FW7/20=j]U080gZfL0`3W_JD20>o6[@80klJU0P3_aZd20?O6]@80klJ]
0P3ge[d20>o>[@h0mlje0P3ge[d40?O6]@H0klJ]0P3_]I`20>o6[@X0klJU0P3_aZd40>o6Y@@0ikFD
0P3W]I`40=j]U080gZf<0P3FYH@40;fDN`80]HA[0P2]Le8209acDP80U6=21024FT8408AB>@80FSTY
0P1cBS4205Xi:@80LdXa0P1c@RT20:EkH`80W7=B0P2eQ6<20;f<H`80eZf<0P3F_Jd20?Ogm`80oooo
B@3gmoL@0?ooo`003P3ooolV0?Ogm`80oooo0P3>]JD209acDP@0Q58i0P24HdX20:EkH`80YG]J0P2m
S6<20=JLN`80gZfD0P3N[I`30>NmY@80klJ]0P3_aZD20>o6[@80mlJe0P3_aZd20?OF_@80klj]3P3g
c[D20?OF_@@0mlJe1P3_aZd20>neW080klJ]2P3_aZD20>o6[@@0klJU103W]I@20>NeW0@0gZfD0P3N
[H`20=JUQ0@0_IAk0P2eQ6/20:ecDP80W7=B0P2DHd8408AJ@P@0Q58i0P1J>BT207=:<@80FSTY0P1c
BS4207=2:@80YG]S0P2LLe820;F4H`80_HaS0P3F[H`20=Jm[@80moOg0P3ooom90?Ogma00oooo000>
0?ooobH0moOg0P3oool20<JUU080aYb40P1c@RT208AB<@80NeY20P2<FT8209acDP80]HAS0P2mU7/2
0<JLQ080e[FU0`3W]I`20>NmY@80klJU0P3_]I`40?O6]@@0klje0P3_a[D20>o6[@80mlJe103gc[D2
0?OF_@80klJe0P3_c[D40>o6[@80klJU0P3_]I`40>NeW080kkFD103_aZD20>nmW080kkFL0P3__I`2
0>neU0@0ikFL0P3N[H`20>N]U080gZfD103FYH`20=JLN`@0_IAk0P2eS7<20;F4J`80[G=B0P2UNeX2
09a[BP@0Le92101cBS4205Y2>@80Ld8Y0P1J<B420:F4J`80U6]B0P2LLe8209a[BP80eYak0P36U6/2
0>NmW0H0moOg0P3gkoL40?Ogm`<0oooo8P3gmoL20?oooa`0moOg403oool000h0oooo9P3gmoL20?oo
o`80aZFD0P36W8@207=2:@80Q58a0P1kFT8208aJ@P80W7=B0P2eQ6<20;fDN`80aYb40P3F]JD30>Ne
W080ikfU0P3_aZD20>neW0@0mlJe103_c[D20>o6]@80klJ]0P3ga[D40?O>]@80mmJm0P3_a[D20>o>
]@@0klJ]0P3_aZD20>neW0@0ikFL0P3_]I@40>o6Y@80kkfL0P3_]I`20>nmW080kkFD103W]I`20=j]
S080ijfD0P3N[I@40=JUS080eYak102mU7/20;F<L`80]HA[0P2]Le820:EkFP80W6]:101cDT8407=:
<@80FT8i0P1c@RT205Xa8@80YHA[0P2DJe8209acDP80W6]:0P3FW7/20<JDJ`80ikfL1P3gmoL20?O_
m`@0moOg0`3ooolR0?Ogm`80oooo703gmoL@0?ooo`003P3ooolX0?Ogm`80imkN0P3Na/H205Xa8@80
Ld8Y0P2LJdX208AB>@80W7=B0P2UQ6/20;F<L`80eZF<0P3N[I@30=j]W080ikFL103_]I`20>o6Y@80
klJ]0P3WaZd20>o6[@80klje1P3_aZd20>o6]@80klJ]0P3_aZD40>o6[@80kkfL0P3W]I`20>N]S0@0
ijfD0P3W]I@20>neU0P0ijf<0P3NYH@20=j]S080ijfD0P3FYH@20=j]S0@0eZF40P36W8@20=JLL`80
_IAk0P2eQ6/40;F4H`80YG]J0P2LLe8208aJ@P80Q5Y20P1kFT8207=B@P80S6]B0P1kFT8207=:<@80
S6]B0P2eQ6/209AcFP80YG]S0P2mS6<20=JUQ080ikfL0P3F_Jd20?O_m`H0moOg0P3ooolK0?Ogm`80
mnog:03gmoL@0?ooo`003P3ooolX0?Ogm`80imkN0P3Na/H205Xa8@80Ld8Y0P2LJdX208AB>@80W7=B
0P2UQ6/20;F<L`80eZF<0P3N[I@30=j]W080ikFL103_]I`20>o6Y@80klJ]0P3WaZd20>o6[@80klje
1P3_aZd20>o6]@80klJ]0P3_aZD40>o6[@80kkfL0P3W]I`20>N]S0@0ijfD0P3W]I@20>neU0P0ijf<
0P3NYH@20=j]S080ijfD0P3FYH@20=j]S0@0eZF40P36W8@20=JLL`80_IAk0P2eQ6/40;F4H`80YG]J
0P2LLe8208aJ@P80Q5Y20P1kFT8207=B@P80S6]B0P1kFT8207=:<@80S6]B0P2eQ6/209AcFP80YG]S
0P2mS6<20=JUQ080ikfL0P3F_Jd20?O_m`H0moOg0P3ooolK0?Ogm`80mnog:03gmoL@0?ooo`003P3o
oolZ0?Ogm`80aZFD0P2LNf/207]J@P80Q5Y20P2DJe8208aSBP80W7=B0P2UNf<20;fDN`80eZF<0`3W
_I`20=j]W080e[FU103W]I`80>o6[@80ilJ]203W_JD20>NeW080gZfL0P3N[H`40=j]U0@0eZF41P3F
W7/20=JLL`80gYak0P3FW7/40=JLL`80_IAk203>U6/20<J4J`80]Hac0P2mU7/20;F<L`80]HA[0P2e
NeX209a[BP80S6=:0P2DLeX209A[DP80LeY:102DJe8207=:<@80S6=:102LJdX209acDP80W6]:0P2m
S6<20;F4H`80gZfD0P3W_I`20?O_idl0moOg403oool000h0oooo:P3gmoL20<JUU080W7][0P1kFT82
08AJ@P80U6]B0P2<HdX209acDP80YG]S0P2mU7/20=JUS0<0ikfL0P3N[I`20=JeY@@0ikFL203_aZd2
0>O6[@P0ikfU0P3W]I`20=j]W080gZf<103N[I@40=JUQ0H0eYak0P3FW7<20=jLN`80eYak103FW7<2
0;fDN`P0cYA[0P36Q6/20;F<L`80_IAk0P2eS7<20;F4J`80]G]J0P2LJdX208aSBP80U7=J0P2DJe82
07=JBP@0U6]B0P1cBS4208aSBP@0W6]:0P2LLe8209a[BP80_HaS0P2eQ6<20=j]U080ikfL0P3gknM?
0?Ogma00oooo000>0?ooobX0moOg0P36YI@209akJ`80NeY20P24FT8209A[DP80S6=:0P2LLe820:Ek
H`80_IAk0P3FYH`30>NmW080gZfL0P3F]JD40>NeW0P0klJ]0P3WaZd80>NmY@80ikFL0P3N[I`20=j]
S0@0gZfD103FYH@60=JLN`80eYac0P3NW7/20=JLN`@0eYac0P2mU7/80<jDJ`80aXA[0P2eS7<20;fD
N`80]Hac0P2eQ6/20;EkFP80W6]:0P2<HdX209AcFP80U6]B0P1cFTX409A[DP80LdXa0P2<HdX409a[
BP80W7=B0P2LJdX20;f<H`80]HAS0P3N[I@20>NmW080mnoWC`3gmoL@0?ooo`003P3oool/0?Ogm`80
_Jf]0P2DLeX208AJ@P80S6=:0P2DJe820:EkFP80]HA[0P2UNf/20;F<L`<0_IAk0P3N[I@20=JeY@80
ikfU0P3_aZD20>O6[@H0ikfU0P3W_I`40=j]U080eZF40P3N[I@20>NmW080eZF<0P3NYH@20=JUQ080
eZF<0P2mU7/20<JLQ080aXA[0P3>U6/20;f<H`80eYak0P3>Lf<20<jDJ`80]G]J0P2eS7<40;EkFP80
_HaS102eQ6<40;F4J`80YG]S0P2eS7<20;fDN`80YHA[0P2US7<20:EkFP80YG]S102<HdX209AcFP80
YG]S0P24FT8206/i8@80Q58i0P2eNeX20;F4H`80]G]J0P2mS6<20<j]U080e[FU0P3F_Jd>0?Ogm`<0
mnog8P3gmoL20?oooa`0moOg403oool000h0oooo;03gmoL20;f][@80U7=J0P24FT8208aSBP80U6]B
0P2UNeX20;F4J`80YG][0P2eS7<30;fDN`80gZfD0P3F]JD20>NmY@80klJU0P3WaZd60>NmY@80ikfL
103N[I@20=JUQ080gZfD0P3W_I`20=JUS080gZF40P3FYH@20=JUS080_IAk0P36W8@20<J4J`80cYA[
0P2mS6<20=JLN`80cW=S0P3>U6/20;EkFP80]Hac102eNeX20;f<H`@0]HAS102eQ6/20:EkH`80]Hac
0P2mU7/20:F4J`80YHac0P2UNeX20:EkH`@0S6=:0P2DLeX20:EkH`80Q5Y20P1[>B4208AB>@80]G]J
0P2eQ6<20;EkFP80_HaS0P3>[I@20=JeY@80e[f]3P3gmoL30?O_mb80moOg0P3ooolL0?Ogma00oooo
000>0?ooobh0moOg0P3_inL20:F<N`80U7=J0P1kFT8209acDP80YG]J0P2<HdX20;F<L`<0aYb40P3F
_Jd60>O6]@@0ikfU0P3F]JD20=j]W080eZF40P3>[I@40=JUS080eZF40P3FYH`40=JUQ0@0aYA[102e
S7<20;F4J`80]Hac0P2eQ6/20:ecDP80]HA[0P2eQ6<209acDP80W6]:0P2eQ6/209acDP80]HAS0P2L
Le820:ecDP80YG]S0P2UNeX20:EkH`80S6=:0P2DJe8209AcFP80[G=B0P2DLeX209acDP80U7=J0P2L
Le8208AB>@80Q5Y20P2<Je8209a[BP80W7=B102UNeX20<JDJ`@0e[FU0P36W8@80?Ogm`80mnog8`3g
moL20?O_mb@0moOg403oool000h0oooo;P3gmoL20>oWi`80YHak0P2DLeX207]J@P80W7=B0P2UNeX2
08aSBP80]Hac0`36W8@20=Jm[@H0ilJe103W_JD20=JeY@80gZfL0P3FYH@20<j]U0@0eZF<0P3FYH@2
0=JUS0@0eZF41036U6/40;F<L`80]HA[0P2eS7<20;F4J`80[G=B0P2eQ6/20;F4H`80W7=B0P2LJdX2
0;F4J`80W7=B0P2eQ6<209acDP80[G=B0P2UNf<20:EkFP80YG]S0P2<HdX209A[DP80U7=J0P2]Le82
09AcFP80W7=B0P2DLeX209acDP80Q58i0P24FT8208a[DP80W6]:0P2LLe840:EkFP80aYA[103F]JD2
0<JLQ0P0moOg0P3gkoLS0?Ogm`80mnog903gmoL@0?ooo`003P3oool>0?Ogm`80mnog0P3gmoL20?O_
ma`0moOg0P2US7/20:EkJ`80YG]S0P2LLf<20:F<L`80aZFD0P3>YI@30;fLS080gZfL0P3>YI@20=j]
W0@0e[f]0P3N[I`20=j]U080eZF<0P3FYH@20=JUS080_IAk0P36W8@20=JUQ080aYb40P36U6/20<JL
Q080_IAk0P36Q6/20;F4H`80]HA[0P2LLe820;fDN`80YG]S0P2mU7/20;F4H`80YG]S0P2mS6<20:Ek
FP80W6]:0P2mU7/20:EkFP80]HA[0P2UNf<20:EkFP80YHA[0P2US7<208ASBP80U6]B0P2UNeX209ak
H`80S6]B0P2DLeX20:EkH`80U6=20P2LJdX209AS@P80W6]:0P2DHd8209acDP80]HAS0P3F[H@20<je
Y@80cZfD0P3F[H`20>O>aPP0moOg0P3ooom90?Ogma00oooo000>0?ooo`h0moOg0P3gkoL20?Ogm`80
mnog703gmoL20:F<N`80YG][0P2UNf<209acH`80YHac0P36YI@20<jUU0<0_Ib<0P3N[I`20<jUU080
gZfL103F_Jd20=j]W080gZfD0P3FYH`20=JUQ080eZF<0P2mU7/20<JLQ080eZF40P36W8@20<JDJ`80
aYb40P2mU7/20<J4J`80]HAS0P2eQ6/209acDP80_IAk0P2UNf<20;fDN`80]HAS0P2UNf<20;f<H`80
YG]J0P2LJdX20;fDN`80YG]J0P2eQ6/20:EkH`80YG]J0P2UQ6/20:F<L`80Q6=:0P2DJe820:EkFP80
W7]S0P2<Je8209AcFP80YG]S0P2DHd8209a[BP80U6=20P2LJdX209AS@P80W7=B0P2eQ6<20=J]Q080
c[FU0P3>[I@20=J]S080ilk6203gmoL20?ooodT0moOg403oool000h0oooo103gmoL20?O_mbX0moOg
0P3oool209AcFP80YHAc0P2LLf<209A[DP80YHA[1@2eS7<20;fLS080gZfL0P3F]JD20=j]U080cZfD
0P3FYH`20=J]S0H0aYb40P2eS7<20;fDN`80]Hac0P2mU7/20;F<L`80_IAk0P2eQ6/20;fDN`80YG]J
0P2LLe820:EkJ`80U6=20P2UQ6/20:EkFP80]Hac0P2LLe820:EkH`80YG]J0P2UNf<20<JDJ`80S6=:
102LLe820;F4J`80YG]J102DJe8208AJ@P80NeY20P1cBS4207=B@P80S6=:1024DST407]J@P80U6=2
0P2eLdX20<JDJ`80eZf40P3WaZd20;fLS080eZf<0P2eQ6=E0?Ogma00oooo000>0?ooo`@0moOg0P3g
koLZ0?Ogm`80oooo0P2DLeX20:F4L`80W7=S0P2DJe820:F4J`D0]Hac0P2mW8`20=j]W080e[FU0P3N
[I@20<j]U080eZF<0P3F[H`60<JLQ080]Hac0P2mU7/20;F<L`80_IAk0P2eS7<20;fDN`80]HA[0P2m
U7/20:EkFP80W7=B0P2UNf/209AS@P80YHA[0P2UNeX20;F<L`80W7=B0P2UNf<20:EkFP80YG]S0P36
U6/208aSBP@0W7=B0P2eQ6/20:EkFP@0U6]B0P24FT8207]J@P80LdXa0P1cDT8208aSBP@0Q58i101k
FT8209AS@P80]G=:0P36U6/20=J]Q080ilJ]0P2mW8`20=J]S080]HASE@3gmoL@0?ooo`003P3ooolb
0?Ogm`80oooo0P2eU7/20:EkJ`80YG]S0P2mW9@20<JLQ0<0aZFD203F]JD80<JLQ080_IAk0P36W8@4
0;fDN`@0]HA[0P2mU7/20;F4H`80YG]J0P2UNf<209AS@P@0YHA[0P2<HdX207=:<@80YG]S0P24FT82
0;F4H`80YG]J102UNf<208aJ@P80W6]:0P2UNeX207=2:@80LdXa0P2LHcT208aJ@P80Q5Y20P2<FT82
09aS>@80U6=20P2LJdX409AS@P80Q58i0P2LHcT209a[BP80cZfD0P2mU7/20=J]S080e[f]0P2<HdX2
0;fLS080YHA[0P3Nc/h20?ooo`h0moOg0P3gkoM30?Ogma00oooo000>0?oooc80moOg0P3oool20;FD
N`80YG][0P2UNf<20;fLU080aYb40`36YI@80=JeY@P0aYb40P2mU7/20<JLQ0@0_IAk102eQ6/20;fD
N`80]HAS0P2UNeX20:EkH`80U6=2102UQ6/208aSBP80LdXa0P2UNf<208AJ@P80]HAS0P2UNeX40:Ek
H`80S5Y20P2LJdX20:EkFP80Ld8Y0P1cBS4209aS>@80S5Y20P24FT8208aJ@P80W6<i0P2DHd8209a[
BP@0U6=20P24DST209aS>@80W6]:0P3>[I@20;fDN`80eZf<0P3F_Jd208aSBP80_Ib<0P2UQ6/20=k>
cP80oooo3P3gmoL20?O_md<0moOg403oool000h0oooo=03gmoL20<JUW080YHAc0P24HdX209acH`80
W6]:0`2UQ6/20<JUW080c[FU0P3N[I`20=JeY@80aZFD102mU7/20;F<L`@0_IAk0P2eS7<20:F4J`80
YHac0P2eS7<20:EkH`@0]HAS0P2<HdX20<JDJ`80YG]J0P2<HdX20;fDN`80S6=:0P24FT820:EkH`@0
S6=:0P2DJe8208AJ@P80S5Y20P24DS4207=2:@@0Q58i0P2LHcT208AB>@80NeY20P2DHd8208aJ@P80
Q58i0P24BS4208aJ@P80W7=B102eQ6<20<JLQ080_IAk0P3W_I`20=JeY@80YHA[0P2UNeX20;fLS080
YHA[2P3gmoL20?O_m`@0moOg0P3gkoLM0?Ogm`80mnog103gmoL20?ooob00moOg403oool000h0oooo
=03gmoL20<JUW080YHAc0P24HdX209acH`80W6]:0`2UQ6/20<JUW080c[FU0P3N[I`20=JeY@80aZFD
102mU7/20;F<L`@0_IAk0P2eS7<20:F4J`80YHac0P2eS7<20:EkH`@0]HAS0P2<HdX20<JDJ`80YG]J
0P2<HdX20;fDN`80S6=:0P24FT820:EkH`@0S6=:0P2DJe8208AJ@P80S5Y20P24DS4207=2:@@0Q58i
0P2LHcT208AB>@80NeY20P2DHd8208aJ@P80Q58i0P24BS4208aJ@P80W7=B102eQ6<20<JLQ080_IAk
0P3W_I`20=JeY@80YHA[0P2UNeX20;fLS080YHA[2P3gmoL20?O_m`@0moOg0P3gkoLM0?Ogm`80mnog
103gmoL20?ooob00moOg403oool000h0oooo=03gmoL20?ooo`80LeY:0P2LNf/20;fLS080YG][0`2U
Q6/20;FDN`80aZfL0P3>]JD20=JUS080aZFD0P2UNf<20;F4J`80YHA[102mU7/20;F4J`80W7=S0P2e
Q6/20;F4H`80YG]S0P2eS7<20:EkH`80]HAS0P24FT8209acDP80U7=J0P2<HdX20:EkFP80Q5Y20P2<
HdX209AS@P80Q5Y20P24HdX208AJ@P80Le921P24DST207=:<@80Ld8Y0P24DST207]J@P80Q58i1024
DS4208aSBPP0YG]J0P36W8@20<jeY@@0W7]S0P2UQ6/20<JUU080_IAk0P3_inL40?O_m`@0moOg0P3g
koL40?Ogm`80mnog103gmoL30?ooo`P0moOg0P3ooolf0?Ogma00oooo000>0?oooc@0moOg0P3oool2
07=JBP80W7][0P2mW8`20:EkJ`<0YHA[0P2eU7/20<J]W080c[FU0P3FYH`20<JUU080YG]S0P2eQ6/2
0:F4J`@0_IAk0P2eQ6/209acH`80]HA[0P2eQ6<20:EkH`80]Hac0P2UNf<20;F4H`80Q5Y20P2LLe82
09AcFP80S6=:0P2UNeX208AJ@P80S6=:0P2DHd8208AJ@P80Q6=:0P24FT8207=B@PH0Q58i0P1cBS42
07=2:@80Q58i0P1kFT8208AB>@@0Q58a0P2<HdX80:EkFP80aYb40P3>]JD409akH`80YHA[0P36YI@2
0;fDN`80knOW103gkoL40?Ogm`80mnog103gmoL20?O_m`@0moOg0`3oool80?Ogm`80oooo=P3gmoL@
0?ooo`003P3ooolh0?Ogm`80W7][0P1cBS420;FDN`<0]Ib<0P2mW8`20;FDN`@0e[FU0P36[I`20:Ek
FP80]Hac102UNf<20;F4H`80YG]J0P2DLeX40:F4J`80U7=J0P2UNf<209AcFP80YG]S0P24FT820:Ek
FP80W6]:0P2DJe8207=B@P80LdXa0P2UNeX207=B@P80NeY20P24FT8207]J@P80Q58a101cBS4206/i
8@80FSTY1P1c@RT208AB<@80W6]:0P24FT8208aSBP80YHA[0P36W8@20;fDN`80ikfU0P3>]JD20;fL
S080YHac0P2DJe820<JLQ080U6]B0P3_inL40?ooo`80mnogD`3gmoL@0?ooo`003P3ooolh0?Ogm`80
W7][0P1cBS420;FDN`<0]Ib<0P2mW8`20;FDN`@0e[FU0P36[I`20:EkFP80]Hac102UNf<20;F4H`80
YG]J0P2DLeX40:F4J`80U7=J0P2UNf<209AcFP80YG]S0P24FT820:EkFP80W6]:0P2DJe8207=B@P80
LdXa0P2UNeX207=B@P80NeY20P24FT8207]J@P80Q58a101cBS4206/i8@80FSTY1P1c@RT208AB<@80
W6]:0P24FT8208aSBP80YHA[0P36W8@20;fDN`80ikfU0P3>]JD20;fLS080YHac0P2DJe820<JLQ080
U6]B0P3_inL40?ooo`80mnogD`3gmoL@0?ooo`003P3ooold0?Ogm`80mnog0P3gmoL20?ooo`80YG][
0P1c@RT309AcH`80YHAc0P2eU7/20<jeY@80e[f]0P36[I`20:EkFP80U6]B0P2eU7/20:EkH`80]Hac
0P2eU7/20;F4H`80U6]B0P2UQ6/20:EkFP80S6=:102UNf<208aSBP80W7=B0P2UNeX209AcFP80S6]B
0P1J<B4207=:<@80NeY20P2UNeX408AB>@80JcTQ0P24DST207=2:@80JcTQ0P1J<B4205Xi:@@0FS4Q
0P1cBS4208aJ@P80YHA[0P2mU7/20;F4J`80_IAk0P3>]JD20;FDN`80Q6=:0P2DNf/20;F4H`80YHA[
0P2LJdX20<JUW0`0moOg0P3gkoL20?Ogm`80oooo5`3gmoL20?O_ma80moOg0P3ooolL0?Ogma00oooo
000>0?oooc@0moOg0P3gkoL20?Ogm`80oooo0P2UNf/207=2:@<0U7=S0P2UQ7<20;FDN`80c[FU0P3F
_Jd20<J]W080YG]J0P2DJe820;FDN`80YG]S0P2eS7<20;FDN`80]HAS0P2DJe820:F4J`80YG]J0P2<
HdX40:EkH`80S6=:0P2LLe820:EkFP80U7=J0P2<Je8205Xa8@80LdXa0P1kFT820:EkFP@0Q58i0P1[
>B4208AB>@80Ld8Y0P1[>B4205Xa8@80FSTY101J<B4207=:<@80S5Y20P2UQ6/20;fDN`80]HA[0P2m
U7/20<jeY@80]IAk0P24HdX209AkJ`80]HAS0P2UQ6/209a[BP80aZFL303gmoL20?O_m`80moOg0P3o
oolG0?Ogm`80mnog4P3gmoL20?oooa`0moOg403oool000h0oooo2P3gmoL20?O_mbh0moOg0P3Nc/h2
07][FP<0NeY20P24HdX20:F<L`80_Ib<0P36[I`20=JeY@80YHA[0P2DJe820:EkFP80]Hac102DLeX2
0:EkH`80S6]B0P2<HdX209acH`80U7=J0P2<Je8209A[DP80YG]S0P2DLeX208aSBP80YG]J0P2LLe82
08a[DP80S6=:101cBS4208ASBP@0Q58i0P2<FT8208AB<@80W6]:1024DS4209AJ<@80W6]:0P2]Le82
0:EkH`80_HaS0P36W8@20=k6]@80]IAk0P2mW8`209akJ`80LdXa0P2DLeX20:F4J`@0]IAk303gmoL2
0?ooo`80moOg0P3gkoL;0?Ogm`80oooo403gmoL20?ooob`0moOg403oool000h0oooo2P3gmoL20?O_
mbh0moOg0P3Nc/h207][FP<0NeY20P24HdX20:F<L`80_Ib<0P36[I`20=JeY@80YHA[0P2DJe820:Ek
FP80]Hac102DLeX20:EkH`80S6]B0P2<HdX209acH`80U7=J0P2<Je8209A[DP80YG]S0P2DLeX208aS
BP80YG]J0P2LLe8208a[DP80S6=:101cBS4208ASBP@0Q58i0P2<FT8208AB<@80W6]:1024DS4209AJ
<@80W6]:0P2]Le820:EkH`80_HaS0P36W8@20=k6]@80]IAk0P2mW8`209akJ`80LdXa0P2DLeX20:F4
J`@0]IAk303gmoL20?ooo`80moOg0P3gkoL;0?Ogm`80oooo403gmoL20?ooob`0moOg403oool000h0
oooo?03gmoL20=Jm]@<0U7][0P2<LeX208ASDP80Q6=:0P2UQ7<20:F<Q080e[FU0P2<HdX208a[DP80
W7]S0P2eQ6<209AcFP80U6]B0P24FT8407]J@P@0S6=:0P2DJe8209AcFP@0S6=:0P2UNeX20:F4J`80
W7=B0P2DLeX207]J@P80YG]J0P24DST208AB<@80U7=J0P2DJe8208aSBP80U6=20P2LJdX20:EkFP80
]HAS0P36W8@20;F<L`80_IAk0P3F]JD20;fLS080]Ib<102US7<207]J@P80W7=S0P2US7<20:F4J`80
YG][0P3oool20?Ogm`@0oooo0P3gmoL20?O_m`80oooo0P3gkoL20?ooo`80moOg0P3gkoL20?Ogm`80
oooo8@3gmoL20?ooob80moOg403oool000h0oooo?03gmoL20=Jm]@<0U7][0P2<LeX208ASDP80Q6=:
0P2UQ7<20:F<Q080e[FU0P2<HdX208a[DP80W7]S0P2eQ6<209AcFP80U6]B0P24FT8407]J@P@0S6=:
0P2DJe8209AcFP@0S6=:0P2UNeX20:F4J`80W7=B0P2DLeX207]J@P80YG]J0P24DST208AB<@80U7=J
0P2DJe8208aSBP80U6=20P2LJdX20:EkFP80]HAS0P36W8@20;F<L`80_IAk0P3F]JD20;fLS080]Ib<
102US7<207]J@P80W7=S0P2US7<20:F4J`80YG][0P3oool20?Ogm`@0oooo0P3gmoL20?O_m`80oooo
0P3gkoL20?ooo`80moOg0P3gkoL20?Ogm`80oooo8@3gmoL20?ooob80moOg403oool000h0oooo=03g
moL20?ooo`P0moOg0`2m[Jd209AcFP80U7=S0P2LLf<20:F4J`80YHak0P36W8@20<JUU0@0S6]B102U
Q6/209A[DP80YHA[0P24DST408AJ@P80W6]:0P2DJe8209acDP80Q58i0P2UNf/209acDP80]Hac0P2U
Nf<20;F4J`80]IAk0P2DJe8408aJ@P@0W7=B102eQ6<40;f<H`@0eZF40P36YI@20:EkH`@0W7][0P2<
FT8207=2:@80Q58i0P2UNf<20:F4J`80W7]S0P2mU7/20?ooo`H0moOg103oool40?Ogm`80ooooC`3g
moL@0?ooo`003P3ooold0?Ogm`80oooo203gmoL30;f][@80U7=J0P2DLf<209acH`80YHA[0P2US7/2
0<JLQ080aZFD102<Je840:F4J`80U6]B0P2UQ6/208AB>@@0Q5Y20P2LJdX209A[DP80W7=B0P24DST2
0:EkJ`80W7=B0P2eS7<20:EkH`80]HA[0P2eU7/209A[DP@0S5Y2102LLe840;F4H`@0_HaS103FYH@2
0<JUU080YG]S102LNf/208aJ@P80Ld8Y0P24DST20:EkH`80YHA[0P2LNf<20;fDN`80oooo1P3gmoL4
0?ooo`@0moOg0P3ooom?0?Ogma00oooo000>0?oooc@0moOg0P3gkoL40?Ogm`80mnog1@3gmoL20<je
]@80Q6=B0P2DLf<20:F<L`80]IAk0P2mW8`20<JUU080aZfL0P2DLeX20:F4J`80S6=:0P2UQ7<209Ac
FP80YG]S0P2DJe8208AB>@80Ne920P1cBS4208aSBP80NeY20P2LLf<209acDP80_IAk0P2eS7<20=k6
]@80ilJe0P3F]JD20<JLQ080gZfL1P3FYH`40>O6[@80gZfD0P3>]JD20:F<L`80S6]B0P2LNf<209A[
DP80Q5Y20P1kFT8208aSBP80]HAS0P2eU7/20:EkH`80YG][0P3oool40?Ogm`80oooo3P3gmoL20?O_
m`@0moOg103ooom30?Ogma00oooo000>0?oooc@0moOg0P3gkoL40?Ogm`80mnog1@3gmoL20<je]@80
Q6=B0P2DLf<20:F<L`80]IAk0P2mW8`20<JUU080aZfL0P2DLeX20:F4J`80S6=:0P2UQ7<209AcFP80
YG]S0P2DJe8208AB>@80Ne920P1cBS4208aSBP80NeY20P2LLf<209acDP80_IAk0P2eS7<20=k6]@80
ilJe0P3F]JD20<JLQ080gZfL1P3FYH`40>O6[@80gZfD0P3>]JD20:F<L`80S6]B0P2LNf<209A[DP80
Q5Y20P1kFT8208aSBP80]HAS0P2eU7/20:EkH`80YG][0P3oool40?Ogm`80oooo3P3gmoL20?O_m`@0
moOg103ooom30?Ogma00oooo000>0?oooc`0moOg0P3oool50?Ogm`80knog0P2LQ7/209AcH`80Lf=B
0P2US7<40<jeY@80cZfD0P2UQ7<20;F<L`80YHAc0P2US7/20:EkJ`80_IAk0P36YI@209akJ`80Ne92
0P2<Je8207]B@P80U7=J0P2eU7/20<JUU080_Ib<0P2US7/20=Jm[@80e[fe0P3F_Jd20=k6]@80imK6
0P3Wc/H20=Jm[@80aYb4102eU7/20:F4L`80U7=S0P2DLeX209A[DP80Le920P24DST209AcFP80W7]S
0P2mU7/20:EkH`80]IAk1P3gmoL20?O_m`@0moOg103gkoL60?Ogm`80mnog3@3gmoL20?O_mch0moOg
403oool000h0oooo?03gmoL20?ooo`D0moOg0P3_koL209b4N`80U7=S0P1cHe820:F<L`@0c[FU0P3>
[I@20:F4L`80]Hac0P2UQ7<20:F<N`80YG][0P2mU7/20<JUU080W7][0P1kDT8208a[DP80Ne920P2D
LeX20;FDN`80aZFD0P2mW8`20:F<N`80e[f]0P3F_KD20=Jm[@80g/Je0P3We/H20>O>aP80e[f]0P36
W8@40;FDN`80YHAc0P2DLf<209AcFP80U6]B0P1cDT8208AB>@80U7=J0P2LNf<20;fDN`80YG]S0P2e
U7/60?Ogm`80mnog103gmoL40?O_m`H0moOg0P3gkoL=0?Ogm`80mnog?P3gmoL@0?ooo`003P3oooll
0?Ogm`80oooo1`3gmoL20?ooo`80W7][0P24He8209b4L`80YHak0P36[I`20=k6aP@0aZfL0P3F_KD2
0;f][@80g/jm0P3F_KD20<JUW080ilk60P3_e/H20?O_i`80knON0P3_e/H20>O>aP80iljm0P3F_Jd2
0=k>_@H0g/Je0P3Wc[d20<jeY@80YHac0P36YI@20:F<L`80W7]S102LNf/208aSBP80S6]B0P1cFTX2
0:EkH`80YHac102UQ6/20:EkH`80oooo103gmoL20?ooo`80mnog203gmoL20?O_m`P0moOg0P3gkoL4
0?Ogm`80oooo1@3gmoL20?O_m`@0moOg0P3gkoL20?Ogm`80oooo=03gmoL@0?ooo`003P3oooll0?Og
m`80oooo1`3gmoL20?ooo`80W7][0P24He8209b4L`80YHak0P36[I`20=k6aP@0aZfL0P3F_KD20;f]
[@80g/jm0P3F_KD20<JUW080ilk60P3_e/H20?O_i`80knON0P3_e/H20>O>aP80iljm0P3F_Jd20=k>
_@H0g/Je0P3Wc[d20<jeY@80YHac0P36YI@20:F<L`80W7]S102LNf/208aSBP80S6]B0P1cFTX20:Ek
H`80YHac102UQ6/20:EkH`80oooo103gmoL20?ooo`80mnog203gmoL20?O_m`P0moOg0P3gkoL40?Og
m`80oooo1@3gmoL20?O_m`@0moOg0P3gkoL20?Ogm`80oooo=03gmoL@0?ooo`003P3ooolX0?Ogm`80
oooo4P3gmoL20?ooo`/0moOg0P3Wg]h208ASDP80S7=S0P2eU7/20;fUW080e[fe0P3Nc[d20>OFcP80
g/k61P3Nc[d20>OFcP80g/Je0P3Wa[D20>O>_@80ilJe0P3_e/H20>oNcP80imK>0P3Nc[d20>O>aP80
c[FU0P2mW9@20=Jm[@80_Ib<0P2eW8`20;fLU080S7=J0P2UNeX208aSBP80S6]B0P2LNf/20:F4L`80
_Ib<0P36W8@20;F<L`80YHA[0P36YI`40?Ogm`80mnog0P3gmoL20?O_m`h0moOg0P3gkoL]0?Ogm`80
oooo103gmoL20?ooo`80moOg0P3gkoLH0?Ogma00oooo000>0?ooobP0moOg0P3ooolB0?Ogm`80oooo
2`3gmoL20>ONgP80Q6=B0P2<Lf<20;FDN`80_JFL0P3F_KD20=k>_@80imK>0P3Nc/H60=k>_@80imK>
0P3Na[D20>O6]@80iljm0P3Wa[D20>oFaP80kmk>0P3We/h20=k>_@80ilk60P3>]JD20;fLU080e[f]
0P2mW8`20;FLS080_IbD0P2<LeX20:EkFP80S6=:0P2<Je8209akJ`80YHAc0P2mW8`20<JLQ080]Hac
0P2UQ6/20<JUW0@0moOg0P3gkoL20?Ogm`80mnog3P3gmoL20?O_mbd0moOg0P3oool40?Ogm`80oooo
0P3gmoL20?O_maP0moOg403oool000h0oooo>03gmoL20?ooo`80moOg1@3oool20?Ogm`80oooo103g
moL20?ooo`80knOW0P2UQ7<209b4L`80YHb4103>]JD20=Jm]@80e/Je0P3Nc[d80>OFcP80knON0P3W
g]H20>OFeP80imK>0P3_g/h20>O>aP80g/jm0P3F_KD20<k6_@80]Ib<0P2US8@20;fLU080W7]S0P2L
Nf/209AcFP80YHac0P24He820:F<N`80_Ib<0P36W8@20;FLS080YHak0P36W8@20>ONgPH0moOg0P3g
koL60?Ogm`80oooo0P3gmoL20?ooo`@0moOg0P3gkoLC0?Ogm`80oooo3P3gmoL20?ooo`P0moOg0P3o
ool80?Ogm`80oooo6P3gmoL@0?ooo`003P3ooolh0?Ogm`80oooo0P3gmoL50?ooo`80moOg0P3oool4
0?Ogm`80oooo0P3_inL20:F4L`80W8Ac0P2US8@40<jeY@80e[fe0P3Fa[D20=k>_@P0imK>0P3_imh2
0>ONeP80imKF0P3We/h20>oNcP80ilk60P3Nc[d20=Jm]@80c/Jm0P2eW8`20:F<Q080_IbD0P2LNf<2
09akJ`80U7=J0P2US7<208ASDP80YHak0P2mW8`20<JLQ080]Ib<0P2US7/20<JLQ080imkN1P3gmoL2
0?O_m`H0moOg0P3oool20?Ogm`80oooo103gmoL20?O_ma<0moOg0P3oool>0?Ogm`80oooo203gmoL2
0?ooo`P0moOg0P3ooolJ0?Ogma00oooo000>0?ooodL0moOg0P3gkoL20?Ogm`80oooo103gmoL20;FD
S080W7][0P2UQ7<20<je]@80g/K6103We/h20>OFaP80ilk60P3Na/H20>OFeP80g/k60P3Na/H20=Jm
]@80aZfL0P2mW8`20;FDN`80aZFD0P36[I`20;FLS080YHak0P24Je820:EkJ`80]Ib<0P2US7/40<J]
W080c[FU0P36[I`20:F<Q080aZfL0P3gkoL<0?Ogm`80oooo203gmoL20?O_m`@0moOg0P3oool20?Og
m`80oooo1P3gmoL20?O_m`80moOg0P3oool;0?Ogm`80oooo5P3gmoL60?ooo`80mnog303gmoL20?oo
o`X0moOg403oool000h0ooooA`3gmoL20?O_m`80moOg0P3oool40?Ogm`80]IB<0P2LNf/20:F4L`80
c[Fe0P3Na/H40>OFcP80imK60P3Wc/H20=k6aP80imKF0P3Nc/H20=k6aP80e[fe0P36[I`20;fLS080
]IAk0P36YI@20<J]W080]Ib<0P2US7/208A[DP80YG][0P2eW8`20:F<N`@0aZfL0P3>]JD20<J]W080
YHb40P36[I`20?O_m``0moOg0P3oool80?Ogm`80mnog103gmoL20?ooo`80moOg0P3oool60?Ogm`80
mnog0P3gmoL20?ooo`/0moOg0P3ooolF0?Ogm`H0oooo0P3gkoL<0?Ogm`80oooo2P3gmoL@0?ooo`00
3P3ooolV0?Ogm`80oooo6`3gmoL20?O_m`80oooo103gmoL20?ooo`X0moOg0P2mW9@20;FDS080a[Fe
0P3>]KD20=Jm]@@0imKF0P3We/h40>OFeP80imK>103F_KD20<JUW080_JFL0P2eU8`20<jeY@80g/jm
0P2mW9@20=Jm]@80g/K60P3F_KD20;fLU080]IAk0P3F_Jd20>oWi`H0oooo1P3gmoL20?ooo`X0moOg
0P3oool<0?Ogm`80mnog3`3gmoL20?ooo`80moOg2P3oool:0?Ogm`80oooo1P3gmoL40?ooo`80moOg
0P3ooolH0?Ogma00oooo000>0?ooobH0moOg0P3ooolK0?Ogm`80mnog0P3oool40?Ogm`80oooo2P3g
moL20;fLU080]IB<0P36]KD20<je]@80e[fe103We]H20>OFcP@0imKF0P3We/h40=Jm]@80aZFL0P2m
YI`20;FDS080c[FU0P3Nc[d20;fLU080e[fe0P3Na/H20=Jm]@80_IbD0P2eU7/20=Jm[@80knOW1P3o
ool60?Ogm`80oooo2P3gmoL20?ooo``0moOg0P3gkoL?0?Ogm`80oooo0P3gmoL:0?ooo`X0moOg0P3o
ool60?Ogm`@0oooo0P3gmoL20?oooaP0moOg403oool000h0oooo903gmoL20?O_mb/0moOg0P3oool2
0?Ogm`80oooo103gmoL20;f][@80_JFL0P3F_KD20<JUW080e[f]103Nc/H20>ONeP80imKF0P3_imh2
0?O_i`80knON0P3We/h20=k>_@80imK>0P3Nc/H20=k>_@80aZFL0P2mW8`20<jeY@80g/jm0P3_inL4
0?Ogm`@0oooo0P3gkoL>0?Ogm`80mnog103gmoL20?O_m`H0moOg0P3gkoL>0?Ogm`80mnog3`3gmoL2
0?O_m`80moOg0P3oool20?O_m`X0moOg0P3gkoL80?Ogm`80mnog5P3gmoL@0?ooo`003P3ooolT0?Og
m`80mnog:`3gmoL20?ooo`80moOg0P3oool40?Ogm`80_Jf]0P2mYI`20=Jm]@80aZFL0P3F_Jd40=k>
aP80imkF0P3We]H20>oWgP80mnoW0P3_imh20>OFcP80g/jm0P3We/h20=k>aP80g/jm0P36YI`20;fL
S080c[FU0P3Nc[d20>oWi`@0moOg103oool20?O_m`h0moOg0P3gkoL40?Ogm`80mnog1P3gmoL20?O_
m`h0moOg0P3gkoL?0?Ogm`80mnog0P3gmoL20?ooo`80mnog2P3gmoL20?O_m`P0moOg0P3gkoLF0?Og
ma00oooo000>0?ooobH0moOg0P3ooolS0?Ogm`80mnog103gmoL20?ooo`@0mnog1P3gmoL60?O_m`@0
knOW0P3Wg]h20?O_i`80knON0P3Nc[d40=Jm]@80g/jm0P3Nc/H40=k6aP80g/k>0P3_inL20?O_m`X0
moOg103oool20?Ogm`H0oooo2P3gmoL40?O_m``0moOg0P3gkoL20?Ogm`80oooo0P3gkoL60?Ogm`<0
oooo4P3gmoL20?ooo`80moOg0P3oool@0?Ogm`80oooo3P3gmoL20?ooo`H0moOg403oool000h0oooo
9P3gmoL20?ooob<0moOg0P3gkoL40?Ogm`80oooo103gkoL60?Ogm`H0mnog103_inL20>ONgP80mnoW
0P3_imh20=k>_@@0e[fe0P3Nc[d20=k>aP@0g/K60P3Nc/h20>oWi`80mnog2P3gmoL40?ooo`80moOg
1P3oool:0?Ogm`@0mnog303gmoL20?O_m`80moOg0P3oool20?O_m`H0moOg0`3ooolB0?Ogm`80oooo
0P3gmoL20?oooa00moOg0P3oool>0?Ogm`80oooo1P3gmoL@0?ooo`003P3ooolX0?Ogm`80mnog5`3g
moL20?ooo`80mnog203gmoL20?O_ma80moOg0P3oool:0?Ogm`P0mnog0P3oool<0?Ogm`@0oooo1P3g
moL20?ooo`P0moOg0P3gkoL20?Ogm`80oooo103gmoL20?ooo`H0moOg0P3oool20?Ogm`80oooo0P3g
moL20?ooo`80moOg0P3gkoL40?Ogm`80mnog5`3gmoL20?O_m`@0moOg0P3oool80?Ogm`80oooo703g
moL@0?ooo`003P3ooolX0?Ogm`80mnog5`3gmoL20?ooo`80mnog203gmoL20?O_ma80moOg0P3oool:
0?Ogm`P0mnog0P3oool<0?Ogm`@0oooo1P3gmoL20?ooo`P0moOg0P3gkoL20?Ogm`80oooo103gmoL2
0?ooo`H0moOg0P3oool20?Ogm`80oooo0P3gmoL20?ooo`80moOg0P3gkoL40?Ogm`80mnog5`3gmoL2
0?O_m`@0moOg0P3oool80?Ogm`80oooo703gmoL@0?ooo`003P3ooom;0?Ogm`80mnog103gmoL20?O_
m`80oooo1P3gmoL20?O_m`80moOg0P3gkoL40?Ogm`80oooo0P3gkoL<0?Ogm`80oooo103gmoL20?O_
m``0moOg0P3oool20?Ogm`80oooo1P3gmoL20?O_m`80oooo0P3gmoL40?oooa80moOg0P3oool40?O_
m`80moOg0P3gkoLA0?Ogm`80oooo303gmoL20?ooo`H0moOg0P3gkoL20?Ogm`@0oooo403gmoL20?oo
o`80moOg0P3gkoL20?Ogma00oooo000>0?oood/0moOg0P3gkoL40?Ogm`80mnog0P3oool60?Ogm`80
mnog0P3gmoL20?O_m`@0moOg0P3oool20?O_m``0moOg0P3oool40?Ogm`80mnog303gmoL20?ooo`80
moOg0P3oool60?Ogm`80mnog0P3oool20?Ogm`@0oooo4P3gmoL20?ooo`@0mnog0P3gmoL20?O_ma40
moOg0P3oool<0?Ogm`80oooo1P3gmoL20?O_m`80moOg103oool@0?Ogm`80oooo0P3gmoL20?O_m`80
moOg403oool000h0oooo:P3gmoL20?ooob<0moOg103oool60?Ogm`80mnog103gmoL20?ooo`H0moOg
0P3oool40?Ogm`80oooo1P3gmoL20?O_m``0moOg0P3gkoL20?Ogm`80oooo103gmoL40?ooo`H0moOg
0P3gkoL40?Ogm`80mnog0P3gmoL20?ooo`P0moOg0P3ooolB0?Ogm`<0oooo0P3gkoL80?Ogm`80oooo
103gmoL20?ooo`@0moOg0P3gkoL<0?Ogm`80mnog0P3ooolD0?Ogm`80oooo0P3gmoL@0?ooo`003P3o
oolZ0?Ogm`80oooo8`3gmoL40?ooo`H0moOg0P3gkoL40?Ogm`80oooo1P3gmoL20?ooo`@0moOg0P3o
ool60?Ogm`80mnog303gmoL20?O_m`80moOg0P3oool40?Ogm`@0oooo1P3gmoL20?O_m`@0moOg0P3g
koL20?Ogm`80oooo203gmoL20?oooa80moOg0`3oool20?O_m`P0moOg0P3oool40?Ogm`80oooo103g
moL20?O_m``0moOg0P3gkoL20?oooa@0moOg0P3oool20?Ogma00oooo000>0?ooob80moOg0P3oool4
0?Ogm`80mnog103gmoL20?O_maL0moOg0P3gkoL20?ooo`H0moOg0P3gkoL80?Ogm`80mnog0P3oool2
0?O_m`H0moOg0P3oool60?Ogm`80oooo0P3gmoL20?O_m`@0moOg0P3gkoLD0?Ogm`80oooo103gmoL2
0?O_m`80moOg0P3oool60?Ogm`80mnog103oool40?Ogm`80mnog0P3oool80?Ogm`80oooo1P3gmoL3
0?ooo`H0moOg0P3oool40?Ogm`80oooo103gmoL40?ooo`@0moOg0P3oool60?Ogm`80mnog403gmoL2
0?ooo`X0moOg403oool000h0oooo8P3gmoL20?ooo`@0moOg0P3gkoL40?Ogm`80mnog5`3gmoL20?O_
m`80oooo1P3gmoL20?O_m`P0moOg0P3gkoL20?ooo`80mnog1P3gmoL20?ooo`H0moOg0P3oool20?Og
m`80mnog103gmoL20?O_ma@0moOg0P3oool40?Ogm`80mnog0P3gmoL20?ooo`H0moOg0P3gkoL40?oo
o`@0moOg0P3gkoL20?ooo`P0moOg0P3oool60?Ogm`<0oooo1P3gmoL20?ooo`@0moOg0P3oool40?Og
m`@0oooo103gmoL20?ooo`H0moOg0P3gkoL@0?Ogm`80oooo2P3gmoL@0?ooo`003P3oool/0?Ogm`80
oooo;@3gmoL20?O_m`H0moOg0P3oool20?O_m`80moOg0P3oool80?Ogm`80oooo0P3gmoL20?ooo``0
moOg0P3gkoL20?Ogm`80oooo6P3gmoL20?O_m``0moOg0P3gkoL20?ooo`80mnog0P3oool40?Ogm`<0
oooo103gmoL20?O_maP0moOg0P3gkoLB0?Ogm`80mnog0P3oool:0?Ogma00oooo000>0?ooob`0moOg
0P3oool]0?Ogm`80mnog1P3gmoL20?ooo`80mnog0P3gmoL20?ooo`P0moOg0P3oool20?Ogm`80oooo
303gmoL20?O_m`80moOg0P3ooolJ0?Ogm`80mnog303gmoL20?O_m`80oooo0P3gkoL20?ooo`@0moOg
0`3oool40?Ogm`80mnog603gmoL20?O_ma80moOg0P3gkoL20?ooo`X0moOg403oool000h0oooo:03g
moL20?oooa/0moOg0P3gkoLD0?Ogm`@0mnog203gmoL20?O_m`@0oooo103gmoL20?ooo`80mnog2P3g
moL20?ooo`80moOg103gkoL40?Ogm`80oooo0P3gkoL20?Ogm`80oooo0P3gmoL20?ooo`@0moOg0P3o
ool20?Ogm`80oooo2P3gmoL20?ooo`X0moOg0P3gkoL20?Ogm`80oooo1`3gmoL20?ooo`H0moOg0P3o
ool20?Ogm`80oooo103gmoL20?ooo`80mnog2P3gmoL20?ooo`@0moOg0P3ooolB0?Ogm`@0mnog403o
ool000h0oooo:03gmoL20?oooa/0moOg0P3gkoLD0?Ogm`@0mnog203gmoL20?O_m`@0oooo103gmoL2
0?ooo`80mnog2P3gmoL20?ooo`80moOg103gkoL40?Ogm`80oooo0P3gkoL20?Ogm`80oooo0P3gmoL2
0?ooo`@0moOg0P3oool20?Ogm`80oooo2P3gmoL20?ooo`X0moOg0P3gkoL20?Ogm`80oooo1`3gmoL2
0?ooo`H0moOg0P3oool20?Ogm`80oooo103gmoL20?ooo`80mnog2P3gmoL20?ooo`@0moOg0P3ooolB
0?Ogm`@0mnog403oool000h0oooo;03gmoL20?oooaT0moOg0P3oool40?Ogm`80mnog0P3gmoL20?O_
m``0moOg0P3oool>0?Ogm`80mnog0P3ooolF0?Ogm`80mnog0P3gmoL20?ooo`80moOg0P3oool60?Og
m`80mnog0P3oool20?O_m`80oooo1P3gmoL20?O_ma00moOg0P3oool40?O_m`L0moOg0P3gkoL80?Og
m`80oooo3P3gmoL20?oooaP0moOg0P3gkoL20?Ogm`80oooo0P3gmoL@0?ooo`003P3oool/0?Ogm`80
oooo6@3gmoL20?ooo`@0moOg0P3gkoL20?Ogm`80mnog303gmoL20?ooo`h0moOg0P3gkoL20?oooaH0
moOg0P3gkoL20?Ogm`80oooo0P3gmoL20?ooo`H0moOg0P3gkoL20?ooo`80mnog0P3oool60?Ogm`80
mnog403gmoL20?ooo`@0mnog1`3gmoL20?O_m`P0moOg0P3oool>0?Ogm`80oooo603gmoL20?O_m`80
moOg0P3oool20?Ogma00oooo000>0?ooobh0moOg0P3gkoLA0?Ogm`80mnog0P3oool40?Ogm`80mnog
103gmoL40?O_m`H0moOg103oool60?Ogm`80mnog203gmoL20?O_m`@0moOg0P3oool20?Ogm`80mnog
0P3oool:0?Ogm`80oooo0P3gmoL20?ooo`80moOg0P3gkoL20?ooo`80moOg0P3gkoL20?Ogm`80mnog
103gmoL20?ooo`@0moOg0P3gkoL40?Ogm`80oooo0P3gkoL20?ooo`80moOg0P3gkoL20?Ogm`80mnog
0P3oool20?Ogm`80oooo1`3gmoL20?O_mah0moOg0P3gkoLL0?Ogma00oooo000>0?ooobh0moOg0P3g
koLA0?Ogm`80mnog0P3oool40?Ogm`80mnog103gmoL40?O_m`H0moOg103oool60?Ogm`80mnog203g
moL20?O_m`@0moOg0P3oool20?Ogm`80mnog0P3oool:0?Ogm`80oooo0P3gmoL20?ooo`80moOg0P3g
koL20?ooo`80moOg0P3gkoL20?Ogm`80mnog103gmoL20?ooo`@0moOg0P3gkoL40?Ogm`80oooo0P3g
koL20?ooo`80moOg0P3gkoL20?Ogm`80mnog0P3oool20?Ogm`80oooo1`3gmoL20?O_mah0moOg0P3g
koLL0?Ogma00oooo000>0?ooodT0moOg0P3oool20?Ogm`80oooo0P3gmoL20?O_m`@0oooo0P3gmoL2
0?O_m`80oooo403gmoL40?ooo`P0moOg0P3oool<0?Ogm`80oooo2P3gmoL80?ooo`P0moOg0P3gkoL2
0?Ogm`80oooo1P3gmoL80?ooo`d0moOg103oool80?Ogm`80mnog303gmoL20?ooo`P0moOg0P3oool8
0?Ogm`80oooo0P3gmoL20?ooo`@0moOg0P3oool40?Ogma00oooo000>0?ooodT0moOg0P3oool20?Og
m`80oooo0P3gmoL20?O_m`@0oooo0P3gmoL20?O_m`80oooo403gmoL40?ooo`P0moOg0P3oool<0?Og
m`80oooo2P3gmoL80?ooo`P0moOg0P3gkoL20?Ogm`80oooo1P3gmoL80?ooo`d0moOg103oool80?Og
m`80mnog303gmoL20?ooo`P0moOg0P3oool80?Ogm`80oooo0P3gmoL20?ooo`@0moOg0P3oool40?Og
ma00oooo000>0?ooob@0moOg0P3oool20?Ogm`80oooo103gmoL20?O_m`80moOg0P3gkoL:0?Ogm`<0
oooo303gmoL20?O_m`80moOg0P3gkoL20?Ogm`80mnog3P3gmoL20?O_m``0moOg0P3oool80?Ogm`80
oooo0P3gkoL20?Ogm`@0oooo5P3gmoL20?ooo`X0moOg0P3gkoL<0?Ogm`80oooo0P3gmoL20?ooo`D0
moOg0P3gkoL20?Ogm`80oooo1P3gmoL20?oooa00moOg0P3gkoL20?Ogm`80mnog703gmoL@0?ooo`00
3P3ooolT0?Ogm`80oooo0P3gmoL20?ooo`@0moOg0P3gkoL20?Ogm`80mnog2P3gmoL30?ooo``0moOg
0P3gkoL20?Ogm`80mnog0P3gmoL20?O_m`h0moOg0P3gkoL<0?Ogm`80oooo203gmoL20?ooo`80mnog
0P3gmoL40?oooaH0moOg0P3oool:0?Ogm`80mnog303gmoL20?ooo`80moOg0P3oool50?Ogm`80mnog
0P3gmoL20?ooo`H0moOg0P3oool@0?Ogm`80mnog0P3gmoL20?O_ma`0moOg403oool000h0oooo903g
moL20?ooo`@0moOg0P3ooolM0?Ogm`80mnog303gmoL20?ooo`80moOg0P3ooolD0?Ogm`@0oooo1P3g
moL20?O_m`@0moOg103ooolF0?Ogm`H0oooo5P3gmoL60?oooal0moOg0P3oool20?Ogm`80mnog0P3g
moL20?O_m`@0moOg0P3oool40?Ogm`80oooo0P3gkoL>0?Ogma00oooo000>0?ooob@0moOg0P3oool4
0?Ogm`80oooo7@3gmoL20?O_m``0moOg0P3oool20?Ogm`80oooo503gmoL40?ooo`H0moOg0P3gkoL4
0?Ogm`@0oooo5P3gmoL60?oooaH0moOg1P3ooolO0?Ogm`80oooo0P3gmoL20?O_m`80moOg0P3gkoL4
0?Ogm`80oooo103gmoL20?ooo`80mnog3P3gmoL@0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00
o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00
o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00
BP3oool2@0000480oooo0T00000;0?ooo`=00000=@3oool2@00004/0oooo001<0?ooo`03@000003o
ool0oooo0440oooo00=000000?ooo`3oool02@3oool00d000000oooo0?ooo`0f0?ooo`03@000003o
ool0oooo04P0oooo000n0?ooo`=000000`3oool3@00000<0oooo0d0000050?ooo`03@000003oool0
oooo0080oooo0d0000040?ooo`03@000003oool0oooo00T0oooo0T0000030?ooo`9000000P3oool3
@00000<0oooo0T0000020?ooo`=000003P3oool3@00000040?oood0000100000@0000080oooo1400
00001@3ooom00000@00004000000oooo00=0000000<0oooo@000003oool00d0000020?ooo`=00000
0P3oool2@0000140oooo0d0000001`3ooom000000?oood000000oooo@000003oool0140000020?oo
o`=000000P3oool2@00004H0oooo000o0?ooo`03@000003oool0oooo00<0oooo00E000000?ooo`3o
ool0oooo@00000020?ooo`03@000003oool0oooo00T0oooo00=000000?ooo`3oool03P3oool00d00
0000oooo0?ooo`020?ooo`04@000003oool0oooo@0000080oooo00E000000?ooo`3oool0oooo@000
00020?ooo`04@000003oool0oooo@00000h0oooo00A000000?ooo`3ooom000000P3oool014000000
oooo0?ooo`3oool3@0000080oooo00I000000?ooo`3ooom000000?oood0000020?ooo`04@000003o
ool0oooo@00000<0oooo00=000000?ooo`3oool0103oool00d000000oooo0?ooo`0?0?ooo`09@000
003oool0oooo@000003ooom000000?oood000000oooo00=000000P3oool01T000000oooo0?oood00
0000oooo@00004P0oooo000o0?ooo`03@000003oool0oooo00<0oooo00E000000?ooo`3oool0oooo
@00000020?ooo`03@000003oool0oooo00L0oooo1400000?0?ooo`03@000003oool0oooo0080oooo
00A000000?ooo`3ooom000000P3oool01D000000oooo0?ooo`3ooom000000080oooo00A000000?oo
o`3ooom000003P3oool014000000oooo0?oood0000020?ooo`03@000003oool0oooo00<0oooo00A0
00000?ooo`3ooom000000P3oool00d000000oooo@00000020?ooo`04@000003oool0oooo@00000<0
oooo00=000000?ooo`3oool00`3oool00d000000oooo0?ooo`0@0?ooo`08@000003oool0oooo@000
003ooom000000?oood0000030?ooo`04@000003oool0oooo@0000080oooo00=000000?oood000000
0T0000160?ooo`00?`3oool2@00000<0oooo0T0000040?ooo`=000002@3oool00d000000oooo@000
000@0?ooo`03@000003oool0oooo00<0oooo0T0000030?ooo`03@000003oool0oooo0080oooo0T00
00020?ooo`A000003@3oool3@00000030?oood0000100000009000000P3oool2@00000030?oood00
00100000009000000P3oool3@0000080oooo0T0000030?ooo`=000000`3oool2@0000100oooo0T00
00020?ooo`90000000<0oooo@000003oool00P3oool2@00000<0oooo0d000000103ooom00000@000
040000160?ooo`00?`3oool014000000oooo0?oood00000D0?ooo`900000403oool00d000000oooo
@00000080?ooo`03@000003oool0oooo02X0oooo00=000000?ooo`3oool0O03oool003h0oooo1D00
00020?ooo`03@000003oool0oooo0100oooo00=000000?ooo`3oool03P3oool3@00000L0oooo0T00
000[0?ooo`9000001@3oool00d000000oooo0?ooo`0J0?ooo`03@000003oool0oooo05T0oooo003o
0?ooob40oooo003o0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-7.15527, -3.20068, 0.495855, 
  0.495855}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["1.6 Window operation",
    FontFamily->"Times New Roman",
    FontSize->16,
    FontWeight->"Bold",
    FontSlant->"Plain"],
  StyleBox[" ",
    FontFamily->"Times New Roman",
    FontSize->10,
    FontSlant->"Plain",
    FontColor->RGBColor[0, 0, 0.996109]]
}], "Section"],

Cell[TextData[{
  StyleBox["\t",
    FontFamily->"Times New Roman",
    FontSize->10.5],
  StyleBox[
  "Sometimes, we are required to focus on a particular region on an image. In \
such case, it is convenient to use a window operation extracting a region of \
interest [2]. Window operation is one of the convolution operations, and \
performs the element-to-element multiplications between the two lists \
containing the window and image data. In this textbook, we work out a simple \
round shape of window constructed by a following function. ",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell[BoxData[
    \(\(window[xl_, yl_, radius_] := \n\t
      Module[{i = 0, j = 0, k = 0, p = 0, q = 0, win = {{0. }}}, \n\t\t\t\t
        win = ZeroMatrix[yl, xl]; \n\t\t\t\tp = Round[0.5\ yl]; 
        q = Round[0.5\ xl]; \n\t\t\t\t
        Do[j = Round[Sqrt[radius^2 - i^2]]; \n\t\t\t\t\t
          Do[win[\([p + i, k]\)] = 1. , {k, q - j, q + j}], \n
          \t\t\t{i, \(-radius\), radius}]; \n\t\twin]; \)\)], "Input",
  CellLabel->"In[31]:="],

Cell[TextData[{
  StyleBox["\t",
    FontFamily->"Times New Roman",
    FontSize->10.5],
  StyleBox[
  "In the function \[OpenCurlyDoubleQuote]window\[CloseCurlyDoubleQuote], the \
parameters \[OpenCurlyDoubleQuote]xl\[CloseCurlyDoubleQuote], \
\[OpenCurlyDoubleQuote]yl\[CloseCurlyDoubleQuote] and \
\[OpenCurlyDoubleQuote]radius\[CloseCurlyDoubleQuote] are the number of \
pixels in the direction of x, y axes and a radius of circular window, so that \
the a number of pixels for the parameter \[OpenCurlyDoubleQuote]radius\
\[CloseCurlyDoubleQuote] should be always smaller than those of the half of \
\[OpenCurlyDoubleQuote]xl\[CloseCurlyDoubleQuote] as well as \
\[OpenCurlyDoubleQuote]yl\[CloseCurlyDoubleQuote]. Using this function, we \
work out a 128 by 128 pixels list \[OpenCurlyDoubleQuote]win128\
\[CloseCurlyDoubleQuote] having a window's radius 60. ",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell["win128=window[128,128,60];", "Input",
  CellLabel->"In[32]:="],

Cell[TextData[{
  StyleBox["\t",
    FontFamily->"Times New Roman",
    FontSize->10.5],
  StyleBox[
  "By means of the window \[OpenCurlyDoubleQuote]win128\
\[CloseCurlyDoubleQuote], we carry out the convolution operations to the \
monochrome as well as each of the color components in Fig.1. ",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell["\<\
wMonoG=ListDensityPlot[win128*monoData[[1]],
\tMesh->False,Frame->False,PlotLabel->\"Monochrome\",
\tDisplayFunction->Identity];
redW=win128*red;
greenW=win128*green;
blueW=win128*blue;\
\>", "Input",
  CellLabel->"In[33]:="],

Cell[TextData[{
  StyleBox["\t",
    FontFamily->"Times New Roman",
    FontSize->10.5],
  StyleBox[
  "After converting the color image data into a RGB form, we draw the images \
having circular shape windows. Figure 5 shows the circular window operated \
images.",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell[CellGroupData[{

Cell[TextData[{
  "rgbSampleW=\n\tTable[RGBColor[redW\[LeftDoubleBracket]i,j\
\[RightDoubleBracket],greenW\[LeftDoubleBracket]i,j\[RightDoubleBracket],\
blueW\[LeftDoubleBracket]i,j\[RightDoubleBracket]],\n\t{i,128},{j,128}];\n\
wColorG=Show[Graphics[RasterArray[rgbSampleW],\n\t\
AspectRatio->1.0],PlotLabel->\"Color\",\n\tDisplayFunction->Identity];\n\
Show[GraphicsArray[{wMonoG,wColorG}],\n\tPlotLabel->\"Fig. 5. Examples of \
window operation\",\n\t",
  "ImageSize->{300,150}",
  "];"
}], "Input",
  CellLabel->"In[37]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .47619 
%%ImageSize: 300 150 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0113379 0.47619 [
[.5 .48869 -110 0 ]
[.5 .48869 110 12.5625 ]
[ 0 0 0 0 ]
[ 1 .47619 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .48869 -171 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Fig) show
81.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(.) show
93.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(5.) show
111.000000 12.812500 moveto
(Examples) show
165.000000 12.812500 moveto
(of) show
183.000000 12.812500 moveto
(window) show
225.000000 12.812500 moveto
(operation) show
279.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
0 0 m
1 0 L
1 .47619 L
0 .47619 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0113379 0.477324 0.464853 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00751202 0.0192308 0.00751202 [
[.5 1.0125 -32 0 ]
[.5 1.0125 32 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -93 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Monochrome) show
123.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
128 string
128 128 8 [128 0 0 128 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000DD0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000C5C6CEC3C3C3CECFCFCFCFCFD7CFCFDDDDD0D7D2
D7D2CF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
CFCECFCFC3C1C1C8C1CEC6CECFCFCFCFCFD2D7D7CFD6D5D5
D5D7D5D7D5D6D50000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000C0CECFD4
D4D4D4D7CECEC1C8C5C8C1C5C6C3CECECFCFD4CFCFCFCFCF
D0CFCFD5D5D0D0D0CFCFCF00000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
0000000000000000000000000000000000C0C0C0C0C6CECF
D4D4D4D7CFCFC3C1C0C0C1C6C1C0C0C1C6C6C6CEC6C6C8C6
CEC6CECDC6CDCECEC6C6C6C6C6C600000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000C5C5C8CECEC8C0C8CE
D4D4D4D4D7D4CEC2C8CEC3C8C8C6C6C0C0B8B8B8B2B8B8B8
B8B2B8B8B8B8B8B8B8B8B8C5C1C5C5C50000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
00000000000000000000000000C5BDBDB8C0C5C8C8C0C5CE
CED7D4D7D4CFCFC8C8C8C8CEC8CECECEC8CEC8C8C5C1C5C1
C1C1C5C1C1C8C5C8C6C6CECEC1CECECEC6CE000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
0000000000000000000000C5C5C5C5C6BDC0C5C8C8C0C5CE
CFCECFD4D4D4D4CEC8C8CECECECECECECEC8C3CECECECEC6
C5C8C8CECEC8C8C8C6CECECECECEC8CEC8CECECF00000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000B4B4A0C5C6C1C5B9C5C5C0C8C5C5CE
CECECFCFD4CED4CECEC8C8CECECECECECECECEC3C8C8CECE
CEC5C8C6C3C8CECEC3CECECECEC8C8CEC6CEC5CECECE0000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
00000000000000CEB5A0B48B79B9C5C1C1C5C1C5C2C0C5CE
CECECECED4CECECECECECECECECECFCECECECEC8C8C8CEC8
C8CEC5C3C8C8C8C5C6CECFCECEC3CECEC8C8C8CECEC6C6C6
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000E1E8D99AA08B7B61C1B9C5B8B9C1C5C5C5CE
CECECECECFCECECECECEC8C8C8C8CEC8CECECEC8C8C8C8C8
C5C5C5C8C8C8C8C5C8C8CEC5C8C8CECEC8C5C8C8C8C0C5B8
B80000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
00000000EEF0DAF0CD9A8C8B766149B2B8B8C5C1C5C0C5C6
CECECECEC8CECECECECECECEC8CEC8C8C8CECECECEC2C2C8
C8C8C8C3C8C5C2C5C5C3CEC8CEC8C5CECEC8C8C5C0C0B8B7
A8A88C000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000F2F0EEE1E8CEC28B937B614949B8B8C0B8C5C5C0CE
CECECECECEC8C8CECEC8C8C8C8C2C5C8CECECEC8C8C8C5C2
C5C0C8C8C8C2C5BAC5C5C8C8C8C8C8C8C5B7B7B1A8A8A8A8
936F618C0000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
0000F2F0F2EEF0DFDFB4938C736154493FB8C1B4C5C0C5C8
CEC8C8C8C8CEC8C8CEC8C8CEC8C8C2C5C8C8C5CEC8C2C0C2
C0C0C0C0C5C0C0BABABAC2C8BAC8B7C5C0BAB1B1A8A09382
616E7393A000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
EFEFF0F2F0E9E8D3E19A938B6E6161543F25B0B9B8C0C0C6
C5C8C8C8C8CEC8CEC8C8C8C8C5C8C8C2C2C5C2C8C8C5C5C2
C0C2BAB7BAC2BABAC2BAC5C0BAB7C0B8B8B7B1A99B827973
6F7A96A09A98A00000000000000000000000000000000000
0000000000000000
0000000000000000000000000000000000000000000000F7
F2F2F2EFF0F2E9D9DFA0938C73616154373725B8B8C5C1C5
C5C8C8C8C8C8CECEC8C8C8C8C8C8C8C5C5C8C2C5C2C3C0C0
C0C0BABABABAB7B1B7BAB7C5B1B8B7B7A9B2A88C6E79527A
828CA09A989E98B000000000000000000000000000000000
0000000000000000
00000000000000000000000000000000000000000000EFEF
F2F7F2EFF0EEE8DFD4A0937C736F6149372D3FB8B8C0C5C5
C6C5CEC8CEC8C8C8C8C8C2C8C8C5C8C2C5C2C0C0BAC0C0C0
C0BABAB7B2B1B1B1B7C5B7A9A8A9ABAB9B9B8B8C5B6E6F79
6F8C9A939398A8A8B4000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000EFEFF7
F7F2F7F0F2EEEAD9B4A093826E7B615A3F3F4F55B9C5C5CE
C5C5CEC8C8C8C8C8C8C5C8C5C0C3C8C5C2C2C5BAC5B7C0C5
C0BABAB2B2A0A8B8C5B89BA0A8A0A8A08C8B76738C7A8C8C
96A0A0989A98A89AA0A80000000000000000000000000000
0000000000000000
0000000000000000000000000000000000000000EFF7EFF2
F7F0F2F0EEE8E9D0B493937C82795A5A49525437B8C5C6CE
C5C5C8C2C5C8C2C5C8C8C5C2C5C2C2C8C0C0C0C5B7C2B7BA
B8B7B2ACA0A8A8C5C59BA0A8A89B887E6F8B7B73798B8C7C
93A0A09A9382B4A0B4A0C500000000000000000000000000
0000000000000000
00000000000000000000000000000000000000F2EEF7F2F7
EFEFF7F7F0E8E8B8B493827A6F6F545A61614925C5C0C6C5
C8C5C8C2C2C8C2C2C2C2C2C2C5C5C2C0C5C0C0B7B7B7BAB7
B8B8ACA89B9BB7B89B949498948880667A8B7B7B7B7C7A7C
93A0A09696A0A9A0A8A0A0B0000000000000000000000000
0000000000000000
000000000000000000000000000000000000F2F2F7F7F2F7
EFF7F7F7EFE8DAB4A896887C7A5A5261665A453FC6C1CEC6
C0C8C5C5C8C2C3C5C2BAC2C2BABABABAC2B7BAB8B7BAB1B2
B1A9A8959BA0A8A093949393886F7676799A8C8B7B79968C
93969A9EB4A8A89EA0A0A0A8C50000000000000000000000
0000000000000000
0000000000000000000000000000000000F2F7F7F2F7F2F2
F2F2F2F0EFE8D9B5A093827A79666179613F3F37C6C1C5B8
C5C8C8BABAC2C0BABABAB7BABAB7B7BAB2BAB2B2B2B2B1B1
A8A8A09A94A998887E8C82886E827B797A8C9A93828C888C
9682989EB4B4B4A0A0B4A0A8C5C500000000000000000000
0000000000000000
0000000000000000000000000000000000F7F7F7F2F7F2F2
F7F0EFF7F7E8C6A8A896827A7A5A6F6152374537C5C5C5C5
C5C0C8C5BAC2BAB7BAB7B2B7B2B7B2B2B2B8B7B1ACA9B1A9
A9A8A093A09B887E827A7A667676616F7C9A9A9AA08C8C82
82969E93B0B4A99EB4B8A8B7C5C500000000000000000000
0000000000000000
00000000000000000000000000000000F7F7F7F2F7F7F2EE
F2EEF7F2F0F0B4A898936F76665F6F5F4F454F3FC6B9C5C0
C5C0BAC5BABABAB7B2B2B2ABACB1ACACB2B1B1A8ABA8A8A8
A89B9B93A093827A75756E7A7666666F7B8B9A939A939682
827C93A8A9A8B5B5B4A0A8B7C5CEE1000000000000000000
0000000000000000
000000000000000000000000000000F7F2F2F0EFF7F2F2F7
F7F2F7EEF0D9B5A893887A82616F6F663B373F45C5B8C1B8
C0C0BABABAB2B7B1ACB1ACACABA0A0A0A8A8ACA8A8A0A0A0
9B9B9496827A796F757A7A6F6F6F737B7C8B9AB0A8B79879
79829893A8B4B4B4A0A0A0C5CDCEDFE80000000000000000
0000000000000000
0000000000000000000000000000F2F7F2F7F0F7F7F7F7F7
F2EFF2F0F0C6B49E96826F7666795A5233333F3FC5B8C0C1
C0BABAB2B1B1B1B1ABA9A8ABA8A8A0A0A0A0A8A8A0A0A094
949388937C6F667A6F7A7A4F4F5A768B8B8B93A0A8A0B496
829393A093B5B5A0A0A0A0C5CDE8DFE8E800000000000000
0000000000000000
0000000000000000000000000000F2F7F0F7F2F7F2F7F2F0
F2F7EEF2DFBDB496887A7666666F5A493F454549B8B8B8B8
BAB8B2B8B2B2A9ABABA0A0A0959B9B95A0A095A0A0A09493
9493829A7A5A76766F66524F37738B768B7C8CA0B0A9B796
96A096A09EB4A0A0939AB7CDDBE1E1DFEE00000000000000
0000000000000000
00000000000000000000000000F7F7F7EFF0F2EFF7F7F2F7
F7EFF2EECEB5A5888876756F666645453F454545B8B8B8C6
BBBBB6BBB6B6B8B2B2A99B939B8D939393939B9B93939388
887E82936F556F7A5A4F4955616E8B8B828B79A0A8B4A09E
93989896B4B4A0A8A0B4B4CBF0DBDFEEE9F7000000000000
0000000000000000
000000000000000000000000F7EFF7F2F7F0F2F0F7F7F2F2
EFEFEFE8CBB49E88827A6F825F662D4D45453F5DB8CDCFCF
CFCECEC3C3C3BCBBBBB8B2A98D8D8C8D8D888888938D888C
827A7A8C5A5B6F66523F4573526F8C8B8279829AA9B7B8B4
9E9E887CB4B49EA0B4B4C5EEE8E8E8EEF0F2F70000000000
0000000000000000
000000000000000000000000F7F2F7F7F2F7F7EEF7F2F7F0
EFF2F2D3BDA8988880666F666F52374F4D453F8FCFD0DDD2
D2CFCFD2CFCFC3C3C1BBB8B2ACA08C82888C8C8D7E888C88
827A6E82666F8252493F537B546F7C8C7B7982939AB7B8B4
A89E8296A8A8A8A8C5A8C5EEE1D9EAE9F7F2F70000000000
0000000000000000
0000000000000000000000F7F2F0F7F2F2F7F2F2F7F2EFEF
F0F2F2D3B49E96807A7A6F666F374555454595D0D7DDD7DD
D2DDD2D7D2CFCECFC3C3BBBAB2B1A8A0828282828C828882
75765E52826693493F2D37797C617C9A79968293A8B7C5C6
B57C9696A098A8B5B4B1E9E1D6E8F0F2F7F7F0F700000000
0000000000000000
00000000000000000000F7F7F7F0F2F7F2F2F2F2F7F7F7F7
EFE9D9CDA59E8876666F6F665737555545CED7D4D7DDDDDB
DDDBD2D2D2D7CFCECECEC5B8B8BAB2A9A07E7A7A827A7E7A
756F524F93529B6F45532D528C547C8C7B939393A0A8C5C6
B49888969E9EB4B5B4C5DFDADFEEEEF7F0F7F2F7F7000000
0000000000000000
00000000000000000000F7F7EFF2F0F7F7F2F7F7F7F7F7F2
EEE9D0C29D96887A6E6F6666453F4F458BD5D7CFD7D7DDDD
DDDDDBDDD2D2CFCFCFC6C1C5C0BAB8B2A995A075757A7675
6E5F584D8C8088823F2D4F6F8C938C8C937A98969EA8B4C5
C59682968C9EBDC5BAB5CDE8F0F0F2F7F2F7F2F7F2000000
0000000000000000
000000000000000000F2F7F2F2F2F0F7F2F2F0F7F7EEF7EF
EEDFD0B49D9682765E665A6633454D66CFD0D7D7D7D7DDD2
DDD2D2DDD2D2CFCECFCFCEC1C1C0B8B8B2A9A0956F757568
6F57553776A95AA06E7A3F735B96738B8C968F9E88B4A0C6
D596829698A5A8B4B5C5DFE8E9F0EEF2F7F2F7F7F2F20000
0000000000000000
000000000000000000F7F7F7F2F2F7F2F7F7F7F7F7F7F2E9
E9D3D0A59880826E66665D453F5763D0CFD4D7D7D7D2D4CF
CFCFCFCFCEC3C3C6CEC5C8C1C1B8BAB8B8B2A8A09B6F5F6F
5B5A45455E968876A5548866757C8C798C966F9696A8A8B4
B8C5967C96A59EB4C5DAEEDFEEF0EEF7F2F2F7F2F7F70000
0000000000000000
0000000000000000F2F2F2F2F7F7F2F7F2F0EFF2F2F7F7E9
DAD3BA9D88806E6666663B453F3FD0D0D7D4CFCFD2CFC8C1
BBBBB8B8B8B2B8B8B8B8C0C0C0C1C0B8B8B2ACA9A89B7E66
5D584D45536EA09683A88C885279938B8C798888A99EA8B4
C6CE969EA99E98B4C5F0DFF2EEF0EEF7F7F2F7EFF2F7F200
0000000000000000
0000000000000000F7F7F2F7F7F7F7F7F2F2F2F7F7F2F2E9
D9D0B59E8282755B665D3F4557CED5D5D7D4CFCFCEC6BBBA
B2ACA5A5A5A5A5B2ACB2B8B2C0C0C1B8B8B2B0A9A0A09466
53554533456CA08066B08CA0886F7A9A8C829688A89EB4A8
B4CDB4A8A5A5A8B5C6E8E8F0EEF2F7F2F7F7EFF7F7F7F200
0000000000000000
0000000000000000F7F7F2F7F7F7F7F7F7F2F0F0F7F2EEDA
D3D1A588806F755E5745454955D0D0CFCFCFCFCEC3918696
969D9D9D9D9D86868686A9B8B8C0C0C0B8B8B2A9A9A09593
55453F2D3F5E80A98F95B4A0A89E8C829396798296A896B7
B5C5C6A5B49EA8C5D0DAE9EEE9EEF0F7EFF2F7F2F7F7F700
0000000000000000
00000000000000F7F7F7F2F7F7F2F0F7F7F2F7F7F0F7E9DF
D9B59E83766F66555E4D4555D6D0CFCFCED4CFA59D9D9DD0
C3A5A5B6C39D9D96958C86A9B8B8C0C1B8B8B8B0A9A09D94
885333332D5E33B0B86FB588B1B49693A0739388969EA0A9
B5C6CE9D8F9EA8B4E8E8EEEEE8F7F7EFF2F2F7F2F7F2F2F7
0000000000000000
00000000000000F7F2F2F7F2F2F2F2F2F2F0F7F7EFF7DBD0
B49E8F835E665B663745458BD5D5D5CFCECECE969D9D9691
91919D8686787D7DA58C8C78B0BBC0C0C0C0B8B0A9A9A0A0
93804545213F668F9E8896B493B7D4968293937A88A09EA8
A8C6C6A59EA59DB4E8E9F0E9E9F7F7F7F7F7F7F7F2F7F7F7
0000000000000000
000000000000F7F2F2F2F7F2F2F2F7F7F2F2F7F2F2F2DAC8
A89E806E5B66573F4F3F66D6D6D5CFCFCEA59D805F647080
7070786C5F4F5A644A605A53689DC0C0C0B8B8B8A9A9A8A9
948866252145536396B066B088A9C5D4A0A07B9388969888
B4C5C6C2A8B4A5BDDFEEE8EEF2EEF7F7F2F7F2F7F7F7F7F7
F700000000000000
000000000000F2F7F2F7F2F7F2F7F2F2F2F2F2F0F2E9DAC2
9D886E5B665A55555553D6D6D0D5D7CFCEC3CEA58C867D86
7D86967D7D7D7D7D7DA8B0B0B8B8C0C0BABAB8BAB2A9A9A8
A0947B41212141637BA99E76A888C5C5D580939388969688
B4B4C6CD9EB4A8D9E9E9E8E8F2F2F2F2F7F7F7F7F2F7F7F2
F700000000000000
000000000000F7F7F2F7F2F7F7F7F7F7F0F7F2EEF0E8D1B5
8F7676665A574D55525DD5CFD5D4CFD4CED4D7D7DDDBD0CF
DDCFCED7DDD0CFC6C1C6C1C0C0C1C0C1C0BBB8B8B2B2A9A8
A0A0885D35166353637B966F937A93C5C5A8A096828296A0
A8A0C6CDA5A598DFE8E8E9E8F7F7F7F2F7F7F7F7F7F7F2F7
F200000000000000
0000000000F7F2F7F7F7F2F7F2F2F7F7F2F0F2F2E9CBC5A5
806E5D5D583F55554FBDD5D5D5D2D7CFD7CFD7D7DDD7DDD7
DDCECFCFCFC1C1C1C1C5C1C5CEC1C0C5C1BBBBB8B2B2A99D
A0A088682D29535D8B7BA56F669896B8C5CEB49393988288
88A0C6CDA8B59EE8E9DFE8F0F7F7F7F2F7F7F2F2F2F7F7F7
F7F7000000000000
0000000000F2F7F0F7F7F7F7F2F7F2F7F2F2F0F2F2D1A588
6F7657584555555555D5D5D0D5D7D2D2D7D5D7D7D7D7D7D7
D5CFCECECEC1C5C8C1C6C1CEC1CEC1C1BBBBC0B8B2ACB2A8
A0A094764D41215A5E6E6F806F8883A0C5C5A0A893968296
82A8B4C6B49EA9DAE8E8D9F7F2F7F7F2F7F2F7F7F7F7F2F7
F7F7000000000000
0000000000F7F7F7F2F7F7F7F7F7F7F7F7F2F2F0D1C89D82
76576645553F555745D5D0D0D5D7D7D7D2D7D7D7D7D5D7D7
CECEC1CEC1BAC0C5C1C3C8CEC3C3CFCEC1C1BBBAB2B2A9A8
9D959482532D33536C747B8F76666E9D98B0CEB48C98769E
96A9A8C6B496CED9E9E9E9F2F7F7F7F7F7F7F2F7F7F7F2F7
F2F7000000000000
0000000000F7F7F7F7F2F7F7F7F7F2F2F2F7F7E9CBAD9D76
6F6E5355555355458FCED0D0D7D7D7D7DDD7D5D7D7D7CFCF
C1B8B2BBB8B2B8BBC0C1C8C6CECFCFC3C3C1BBB8B2B2A9A9
A8A08D7E66414548635E7B6E825D6F5EB5C5A8B1989E8388
96A5A8C5BD9EDFC6F2E9F7F7F7F7F7F7F2F7F7F7F7F7F7F2
F2F7000000000000
00000000F7F7F2F7F2F2F7F7F2F7F7F7F0F7F2F2C59D806E
5B5B55454555553FCED0D0D2D7D7D7D7D7D7D4D7D7D7CFC3
BCC0ACB2B2A9B0B8B8C0C1C8C3CECECEC3CEC2BBB8B2A9A9
A89594886841162F535D765E826F6F55B093A8D49E989888
95939EC5C2C2D0DADAD4F7F7F7F7F7F7F2F7F7F7F7F7F7F7
F7F7F70000000000
00000000F7F7F7F2F7F7F7F2F7F7F7F7F7F7F7E9B58F6E5D
5B45554D55533F3BD0CDCFCFD7D2DDDDD7D7D7D2DBAC96CF
CFC3B6777795AC88A8B8C1CECECFCFCFCEC3C1BBBAB2B2A9
A8A0947E754D212F3B535E6376765D766696B7A8B793966F
8888A8C5C2E9B4E9BDF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F70000000000
00000000F2F7F7F7F7F2F2F7F2F7F7F7F7F7F2E09E806E6F
5555454F55453B5ED0CFD5D7DDD7D2DDD2D7D4D7DDD5D0D2
D2CFC0B8B8BAC0B29BA9C1CFCFCFCFCFC3CECEC2BAB8B2A9
A0A0948D7B6616212F485A665E7B5D6633B49BA0C5889676
80969EB4CBCBB2BDF7F7F2F7F7F7F7F7F2F7F7F7F7F2F7F7
F7F7F70000000000
00000000F7F7F2F7F7F2F2F7F7F7F7F0F7F7F7DA966E6845
53584D5558373784CDD2D2D2DBDDDDDDDBD7D7D2DDD0DBDB
DBD2CEC0BCBCB8B8B2B2C3CFCFD2CFCFCFC3C3C3C0BAB8AC
9D9D94887A6E162921535E6E4D765D663B9E96B4C5889680
888F9DB5CBCBC2D0F7F7F2F7F7F7F7F7F7F7F2F7F7F7F7F7
F7F7F70000000000
00000000F7F2F7F7F2F7F2F7F7F0F7F2F2F7F2D48066665D
5555575B4F3341CED0D7D7DDDDDDDBDDDBDDD2CFDDDDDBE4
DBD2CFC6BBB6B8B8B2BBC3CFCFD4CFD2CFCECEC3C3BBBAB2
ACA095887A66330C294D336F5D764F5D668098B1B1A88896
808888B4CDBDD4F2F7F7F7F7F7F7F7F2F2F7F7F7F7F7F7F7
F7F7F70000000000
00000000F7F7F7F2F2F7F2F2F7F7F2F7F7F7F09E6E6E454D
4D555855293729CFD2D6D2DDDDDBDDDDDDDDDDD7D7D2DBDB
DBD7CFBBB0B2B8B0B8C1CFD0D0D5D7CFCFCECFCEC3BBBAB8
B2A89588807553142141615E666E555D537B93A0B8C68288
7B889EC5CDA5D0F7F2F7F2F2F2F7F7F7F2F7F7F7F7F7F7F7
F7F7F20000000000
000000F7F7F2F7F7F7F7F7F7F2F7F2F7F7F7EF8F6E57455E
58585521332D41CFD7DDDBDBDBDBDBDBDBDBDDDDD2D6D2DD
D2D0C3C1B0B8B8B8C1CFCFCFD0D2D7D0D2CFCECFC3C3BBBA
B0B2A09480765B1635334D535D5D6F5D5D8396A0B8D48882
76838FB4CBD0F2F7F7F7F7F7F7F7F7F7F7F7F7F7F7F2F7F7
F7F7F2F200000000
000000F7F2F7F7F7F7F7F7F2F7F2F7F2F2F2F28F6655555E
535558332933B4D5D5DDDBDBDBDBE3E3E3DBDDDDDDD7D0DD
DDCFC3B8B8B8C0C1C6CFD5D0D2D2DDD6D2D0CFCFC3C1C1B8
B2A9A8947E766E29143B335E6655666F5D7BA5A8B7D48098
668F80C5D3D0F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F700000000
000000F7F7F7F7F7F7F7F2F2F2F7F7F2F2F7CD7B664D5D5D
5855332921C3D6D2DDE3DBDBE3DBDBDBDBDBDBDBDBDDD7DD
DDD2CFC1B8C0C0C1C6D0D0DBDDD2DBD2DDD6D6D0CFCDC3C0
B8B0A9A888766F4D374553536E5D6F665B7BB0A8B4C69682
5D8388B8D9EEF7F7F7F7F7F7F7F7F7F2F7F7F2F2F7F7F2F7
F2F7F7F700000000
000000F7F7F7F7F7F7F2F7F7F2F7F7F7F7F77B665D3B6153
5358334541CFD0DBDDDBDBE3E3DBDBDDE3DBDBDBDBDDD6DD
DDDDD2C1B8C1C5C6C6CDD5DDD6DDDBDDD2D6D6D6D0CFC6C1
B8B8A9A88D7E68534545455E5D6F6E667A8FA9A8A8B49879
57839DB5DFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F2
F7F7F7F200000000
000000F7F7F7F7F7F7F7F7F7F2F7F7F7F2F7806F5345665E
554D45338CD2D6DBDBDBE3E3DBDDDBDDDDDBE3E3DBDBDDDD
DBD2D2C1B8B8C5C6CFCFD6D6D6DBDBD2D2DDD7D5D0CFCFC6
B8B8B0A8947E685B3B3B4553586E6F6E66A8A8A8A8B0B47A
7A808FB7EEF7F7F7F7F7F7F7F7F7F7F7F7F7F2F7F2F7F7F7
F7F7F7F700000000
000000F7F2F7F7F7F2F7F7F7F7F7F7F7F7F27B7B5E534D5E
583B4D5ED0D7D6DBDBDBDBDBDBDBDDDBD6DBDBDBDBDDDDD0
DBDBDDC6BBB8C1C6C6CDD0D6D6D6DBD6DDD6D0D0CFD0CDC6
C6B8B0A9A088765E4D3F45455E666C5E57B5A89EA9A5B866
80808BB4F0F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F2F7
F7F7F7F700000000
000000F7F2F7F2F7F2F7F7F7F7F7F7F2F7B1666C5D665D5B
45414DCDDDD0DDDBDBDBDBE3DBDBDDD6D0D0D6D6DDDDD2D7
DBDBDDCFBBB8B8B9C5B9CED3D0DBD6D6D6D0CED0CFCFCFC6
C6B9B8B09D947666533345455376666666A59EA8A876C552
76969EB4F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F2F7F7F7
F7F7F7F700000000
000000F2F7F7F2F7F7F7F7F7F7F7F7F2F78595765376535B
3B5355CDD2CDDBDBE3DBDBDDDBD6D6C3CDCFCFD0D6DDD5D7
DDDBDDCFB6B8B0B8B8C6CED0D6CDCDC6CDCDCDCDCFD0CDCD
BDC5B8B0A894806658332D4553666F6666A5A0A0A858B768
668FB0CDF7F7F7F2F7F7F7F7F7F7F7F7F7F7F7F7F2F7F7F7
F7F7F7F700000000
000000F2F7F7F7F2F7F7F7F2F2F2F2F7F75A9B6674636653
336FBACFBBD0DDDBDBDBDBD6D3D0D0CFB9B8C6CDD0D6CDD0
DBDBDDC3B8ACB5B0B4BDCDCEC6C6BDBCB8B8B0B9B9C6C6C6
C5C5B8B0A0957E765E4D2137456666765E9DA9889657C576
5B9EB4D9F7F7F7F7F7F7F7F7F2F7F7F7F7F7F7F7F7F7F7F7
F2F7F7F700000000
000000F7F7F7F7F7F7F2F7F2F7F7F7F7FF76845E665E682D
5D58D2A0B2D5DDDBDBDBD6CEB99D95B0AF9DB9B9D6D6D0D0
DDDDDDCFB8A9A5A9C5B9CEBCB9ADA48F95A5A5A5AFC5C6B9
B9B9B8B0A59588685E53453B3B5E5D6C668F96888866C566
5BA5A8DAFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F700000000
000000F7F7F2F7F2F7F7F7F7F7F7F7F7A5837B535E53683B
66C2C3A5B0D5D6DBDBD0BC8F96B9B16C728CA59D9DD0D0CD
DDDDDDCEC1A9B09DB05F7895B0CD815F858483848FB0B8B8
B9B9B0B0A0957E7666535E33335E5E66768F9D828861C56F
7BB4B4E9F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F2F7F7F7F7
F7F7F7F700000000
000000F7F7F7F7F7F7F7F7F2F7F7F7F78FA47B6C3B5E683F
33D2BAB6B8D6DDD6CDBC8F95C3DA756C5B7C85A59DBCB8CE
DDDDD5CFC1B29D8F95A560CDE9787A6D8D64A57B728FB0B0
B8B8B0A9A88F80765D533B16295E664D768F8F768375B857
9DB5B5F7F7F7F7F7F7F7F7F7F7F7F7F7F2F7F7F7F2F7F7F7
F7F7F7F700000000
000000F7F7F7F7F7F2F7F7F7F7F7F7FFF28B5D553B5E5E5E
68D2B2A5B8CED5CFB99D7A419DBA80B51A774D7A8F9DC1D4
DDDDD7CFC5C09D957B959D76C75BBC1A725BA5355A84959D
B0B0B09D9E9480685E58292129335E53807B83838875B457
96A9CBF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F700000000
000000F7F7F7F7F7F7F7F7F7F7F7F79BCA907A5C535E5E68
8CC3A5A9B8D0D5C1AF95536B6B482F415E726B849DBBC8D7
D7DDD7CFC8C1B29D95807A92924133414153485F5C848F8F
A0A9A99D8F88686666534529414545537680766F8880B46E
96A8E8F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F2F7F7F700000000
000000F7F2F7F7F7F2F7F7F7F7F7F780A5A166536C5E535B
94B6A9A9B8D0CECDC6B89D7E6C5C5C5C5E7A95B0C1CFCFD7
DDDDD7CFCFCEC0B2A99D8F6A848C836B5048537B969595A0
A9A99DA0967E68665E5E4D33413B3B4D7B887B6F8896B476
96B0EEF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F700000000
00000000F7F7F7F7F7F7F7F7F2F7F7E89174534D53534576
94A0A59DB0CED5D5DDD6CFD0C6C1BCC1C6C1A9B2BBCEDDD7
DBDBDDD7D4CFC0A8AC9DB0B0B09D9D9DA0A9B0B0B8BAB8B0
B0A9A0959688686C5E45453341534D457696766F939DB87B
9DE1FFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F70000000000
00000000F7F2F7F7F7F7F7F2F7F7FFFF4D663B45456E3B5F
7E9DA095B0D5C6D7DDDDDBDDDDDBB695847B7EC1CEDDDDDD
E3DBDDDBD7DDC8BB95757B7E95C6CDCFCDC6C6C1C1C1B8B0
9E8FA096888076665D5E373333412D536680766E989EC583
A5E9F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F70000000000
00000000F7F7F7F7F7F7F7F7F7F7E9FF45553B45535E536F
77889695A5CFCBC5D0DDDBDBD28F847A7EB0CED7D7DDE3DD
E3DBDDDDDDD7D7CEBB96685E687EB2BCCDCFCFC3C6B8B29D
83A0958F807676664545333B332D5A6374837B669696B59D
A5F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F70000000000
00000000F7F7F7F7F7F7F7F2F7FFB1FF5D4D53533B5E5566
6868848FA5CED69DA5B0A99D7E80A9D7DDDDE3E3E3E3E3E3
DBDBDBDBDDDBD7D7D7D4C1B0957A667B758695958F84838F
9D9D9D968076765E76294D4D45332F6A7680766E96A88F7A
D0F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F2F7F7F7F7F7
F7F7F70000000000
00000000F7F7F7F7F7F7F7F2F7F7AD7B53536A5E5353535E
666C7B83B0CED5D5CFB0A49DB9DBE3E3E3E3E3E3E3E3E3E4
DBDBE3E3E3DDDDDBDDD7D2CFCFCFCDCDA5848084849DA59D
A0A8A096807B805E4553453B2121296C7A6683759EA57696
E9F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F2F7F7F7
F7F7F70000000000
00000000F2F7F7F7F2F7F7F7F7F7CA7661538372615E5366
666C8080A9CFD0D5D5DDDDDBDBDBE3E3E3E3E3E3E3E4E3E3
DBE3E3E3DBDBDBDBDBDDD5D5D7CFCFCFC6CDCDC1B8B8B0A9
B09D95888083807653452D21212129956C66A87688B476A5
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F70000000000
0000000000F7F7F2F7F7F7F7F7F7BA575A6390745E636163
6366837BA9CDD5D5D6DDDDDBE3E3DBDDE3E3E3DDE3E3E3E3
DDDBE3DBDBE3DBDDDDDDDDD2D7D0CFCDC6CFC1C1B8B0B0A9
A99D9E967E808066764D3333293B2D9D83669D8076B576C2
FFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7000000000000
0000000000F7F7F7F7F7F7F7F7F7D15E726C7B6C726C635E
5D5D767B95C5D0D5D5D6DDDDDBE3E3DDE3E3E3E3E3E3E3E3
E3E3E3E3E3DBDBDBD7D7D7D7D7CFCECDCFC6C5C0B8B8B0B0
A9A8A08880887B76533B453B2121299E8476A8826C9D76F2
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7000000000000
0000000000F2F7F7F7F7F7F7F7F7F26C5E5E5E6A6C5E635E
635E83889EC1C6D4D6D7DDDDDBDBE3E3E3E3E3DDDDE3E3E3
E3E3DBDBDBDBDBD2D7D7D7D4CFCFCFC3C6C5C6C1B8B8B2B0
9DA095968880765E53414D2921213B7BA88FA9887B6EB4F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F2F7F7F7F7
F7F7000000000000
0000000000F7F7F7F7F7F7F7F7F7FF5C725E6C72746C6363
5E6C7B969DB8C6D5D6DDDDDDDDE3E3DDDDE3E3DDE3E3DBE3
E3E3DBDBDBDDDDDDDDD7D7D4CFCFCFC3C1C1C1C1BBB8B0B0
A9A0958F8F84766645532D2929212F7A9D7B9E968B6ED4F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7000000000000
000000000000F7F7F7F7F7F7F7F7FF835A667474636C5E61
746C7B8F9EB0C6CFD7D7D7DDDDDDE3E3DBDDE3E3DBDDE3DD
DBDBDDDBDDDDDDD7DDD7D7CFD7CFCECEC6C5C6C0B8B8B0B0
9DA0958F8F76766653452D2116165C6C8380A59EB59EF7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F700000000000000
000000000000F7F7F7F7F7F7F7F7FF5E8483666C6A66636F
4D6C849695B0C5CFD5D7DDDDDDE3E3DBE3E3E3DDE3DDDBE3
DDDBDBDDDBDBDDDDDDDDCFD2D4CFCFC3CEC1C1B8B8B8B0B0
9DA8958F7B7463535E3B21162F166A74766E9E9EA5DFF7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F700000000000000
000000000000F7F7F7F7F7F7F7F7F7E08461615E5E5D635E
6C6C8395A5B0C5CFD5DDDDDBDDE3E3DDE3DDE3DDDBDDE3DD
DBDBDDDDDDDDDBDDDDD2D7D7CFCFCFC3CEC1C1B8B8B8B8B0
A5A98F847B7B7661453B21212F2174747B6F9EA5B0F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F700000000000000
00000000000000F7F7F7F7F7F7F7F7FF6C615E535D5A5361
6C768F95A9B5C5CFD7D2DDDBDDDDDDDDDBE3E3E3E3DBDBE3
DDDDDDDDDDDDDDDDD2D7D7D7CFD7CFCECEC8C1B8B8B0B8B0
B09D8F8F846C66453B292916272182746F6EA5BAD1F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
0000000000000000
00000000000000F7F7F7F7F7F7F7F7F7BC6A5E5E5D5E5E5A
5E768495A5B9C6CFD7D7DDDBDBE3DBE3E3E3E3E3DBE3DDDB
E3DBDDDBDDDDDDDDD7DDD7D2D4CFCFCECEC1C1B9B8B8B0B0
A0A09684837B66413B292F1F2929848F66809EC5F7F7F2F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
0000000000000000
0000000000000000F7F7F7F7F7F7F7F7F27253535A5A5E61
5A748F9DB0B8CECFD0D5D7DDDDDDDDDDE3DDE3DBDDDDDBDD
DBDBDDDDDDDBDDDDD7D7D4D7D2CFCFCFC6C6C5C0B8B8B0A9
A99596847B6C5E413B2F29333321768F7693B0D2F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F700
0000000000000000
0000000000000000F7F7F7F7F7F7F7F7F784725A63615A61
63747B9EB5C6C6CFD7D7DDDDDDDBDBE3E3DBDDDDDBDBDBDB
DDDDDBDDDDDDDDD7D7D7D4D4CFCECECFC6C5C0BBB8B8B2B2
A0958F8076665341413329332116747B7696B8EEF7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F700
0000000000000000
0000000000000000F7F7F7F7F7F7F7F7F7FFBC8474747461
61748B95A9C1CECFCFD7D5D7DBDBDBDBDDDDDBE3DDDBDDDD
DDDDD7DDD7D7D7D7DDD2D7CECECECEC3C6C5C0B8C0B0B0B0
959584836C5E4D533B3B292114418F7B82A0B4F7F2F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F700
0000000000000000
000000000000000000F7F7F2F7F7F7F7F7FFFFE97A74636C
6A6C809DA5B8CECFCFD7D7DDDDD7DBDBDDDDDDDDDDDDDBDD
DDDDDDDDD7D7D7DDD7CFCFCFCFCECFC8C1C1C1C0B8A9B09D
9D9680685E634D41412F331A1483846E8898D3F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F70000
0000000000000000
000000000000000000F7F7F7F7F7F7F7F7F7F7FFA55E6A5A
6C6C8396A9B9C6C3CFCFD7D4D4D7D7DDDDDDD7DDDDDDD7DD
D5D7D6D7D7D7D4CFCFCFCFCECFCECEC3C1C1C1B8B8B0A9B0
9584766E6663633B3B3321168F82766E96BDE9F7F2F2F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F70000
0000000000000000
00000000000000000000F7F7F7F7F7F7F7F7F7FFD0456383
61838396A5B8C5CDCFCECFD7D7DDD7D6DDD7DDDDDDDDDDD7
D7DDD7CFD7CFD7CFCFCECFCFCECEC5C8C0C0B9B8B49DA9A0
8F847B7663535A74292127615E8376809EC6F2F7F2FFF7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7000000
0000000000000000
00000000000000000000F7F7F7F7F7F7F7F7F7FFBA7B5E5E
6A848396A9B8B9C6CFCECFD2CFDDD4D7D7D7D7D7D7D7DDD2
D2CFCFCFC3CFCECECECECECFCECEC0C0C1B8B8B8B09D9D8F
807B6E63635E5E415341534D847B8F96B5C2F7FFF7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7000000
0000000000000000
0000000000000000000000F7F7F7F7F7F7F7F7FFADA54D5D
61667B8F9DA5BDC1C6CEC3D2D2D5D5D0CFD2D7D7DDD0D5CF
CFCEC3C1C1C2CECEC8C3C8C2C1C1B8BBB8B0B0A99D9D958F
8083765A5A5353484D3B8B747B76A99EC5F7F7F7F2F7F7FF
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFF7F700000000
0000000000000000
000000000000000000000000F7F7F7F7F7F7F7F7E0CD3B4D
765E7B8B95B0B8B9C1C3C3CECFCDCFD5CFCFCFD0CFCECFCF
C8C1BABBBBC0C2BABABABAB2B8BBB0B8B0B0A5A89D8F8F8F
837B6663615A726153728F7A8496B0C5C2F2F7F7F7FFF7F7
F7F7F7F7F7F7F7F7F7F7F7F2F7F7F7F7F7F7F70000000000
0000000000000000
000000000000000000000000F7F7F7F7F7F7F7F7F7AD8361
63746C7B849DB0C5B9BDC1C1CFCFCFCFCDC6C6C6C6C1B9B8
B8B8B0B0A9A9A9A8ACA9A8A89DA0A0A0A095959D958F8876
6C7A745F7474536C76767B76968FB8C5F0F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F70000000000
0000000000000000
00000000000000000000000000F7F7F7F7F7F7F7F7F7B17A
636C74838F85959DB8BDC6CECDC6C6C6C5B8B8B0B8C5B0B2
B0B09DA595A096A98CA088958888968F8F8F8F84959D8B90
83846C6C7A8463455E888F8896B4BDC2F7F7F7F7F7F7F7F2
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FF000000000000
0000000000000000
0000000000000000000000000000F7F7F7F7F7F7F7F7F7E9
917A617B836C95A5C2CECECEC6C6BDB9B0B4B0B0B0B0B0B0
9E9E95958F958F808F8F7B768F7B8F7B808483846C747A80
7A7B7A7B5E6372767B83839EBDBDA5F7F7F7F7F2F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F2F7F7F700000000000000
0000000000000000
0000000000000000000000000000F7F7F7F7F7F7F7F7F7F7
9185847D90ADAFA4B9AFB9C2C2B9B8B0B0B09DA5B0A59EA5
9D958F8F7B9D849D8F849683769D838F84838B906A748382
727A846E766E766E7B8FB4BAB4B5D4F7F7F7F7FFF7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F700000000000000
0000000000000000
000000000000000000000000000000F7F7F7F7F7F7F7F7F7
FF7A8C7D748B9595A4B9BDB8B4B0B5A5A5A5959D959D959D
8F9D837B856E8B83957B8483849E6C7B7B8F837474636153
5A6C5E5E61616E829EB4CDA4B58FF7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F70000000000000000
0000000000000000
00000000000000000000000000000000F7F7F7F7F7F7F7F7
F7FF9B8584A5A5ADBDBDBDBDA5A5A5A59DA59D9D8F8F9D8F
83846E8B8B6C5384638F8384846676834D536F6663666F6E
766E6E5E6F76B49DB5C26CA48BD2FFF7F7F7F7F7F7F7F2F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7000000000000000000
0000000000000000
0000000000000000000000000000000000F7F7F7F7F7F7F7
F7F7AD8C6A7D768BADBAB9BDAD9D9D959D9D958B9095848F
8F6C9E836C9D6C63846C6C7463665D4D5E5E6F5E616E665E
58667B8F8FA59DC5BD8B83A48BF7F7F7F7F7F2F7F7F2F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F2F700000000000000000000
0000000000000000
0000000000000000000000000000000000F7F7F7F7F7F7F7
F7F7FF5F83A4858B9BB2BAB0AD848F8B9D9D8F7D8F8F8495
848F637B7A6C83636C6E636A635A5E5E5E534D5E615E5D5D
6C83838383A5BA82828BAD9DE9F2F2F7F7F2F7F7F2F7F7FF
F7F7F7F7FFF7F7F7F7F7F7F7F7F700000000000000000000
0000000000000000
000000000000000000000000000000000000F7F7F7F7F7F7
F7F7F7F783539BA1A49BBDBDB2839584848F837A8B8B7A84
7A84638376745A53835A6163615D535345414D4D4D5D7663
6C8BA59DC6BAA49074A574E9FFFFF2F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F70000000000000000000000
0000000000000000
00000000000000000000000000000000000000F7F7F7F7F7
F7F7F2F7FF854D7B8C9BBAC2B283749B84959B8F748B836C
84846C7B837A723B5361835E5E455E4D453B413B3B53668B
9D8F9DBA9B6A808F8B76ADF7F7F7F7F7F7F2F7FFF7F7F7F7
F7F7F7F7F7F7F7F2F7F7F7F7000000000000000000000000
0000000000000000
0000000000000000000000000000000000000000F7F7F7F7
F7F7F7F7F7D26D616A90A4B2BD8B7483957A7A84726C7D7A
7274847A6C837B726C53536A5E5E665D765D5D6676808496
A5CB9BA483537A8B9B9BF7F7F7F7F7F7FFF7F2F7F7F7F7F7
FFF7F7F7F7F7F7F7F7FFF700000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000F7F7F7
F7F7F7F7F7F7C380776B6A8C92BD6C72828F7A746361616C
6C747A6C6C838B7B7A61835E5D7A746C6E76838FA5959DBD
A4A19090617D908B85FFF7FFFFF7F2FFF2FFF7F2F7FFF7F7
F7F7F7F7F7F7F7F7F7F70000000000000000000000000000
0000000000000000
00000000000000000000000000000000000000000000F7F7
F7F7FFF7F7F7F7B17A7B7D8B91A5AD72728B8B748B5E6363
76747B5E857B95848F9B7466667B7B8F8F9696B0B0AD8483
83664D5E848B829DFFF7F7F7FFFFF7F7FFF7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7000000000000000000000000000000
0000000000000000
0000000000000000000000000000000000000000000000F7
F7F7F2F7F7F2F7F7BC6B7B909BA4ADB27A8B6C8C7A84745E
5C536C617D7B9D95CBCEBDA5B9B0B0B0CDCDB8BA90728274
63616C8F9B8485FFF7F7FFF7F7F7F7F7F7F7F2F7F7FFFFF7
F7F7F7F7F7F7F7F700000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
F7F7F7F7F7F7FFF7F7EF8A7B6590BABAB48C958C91859DAD
835C725C7A9BADA491C2C3C2CBD9D4C2A59B9B8C7B7A745A
5E7A829D849BF7F7F7F2F7F7F2F2F7F7F7F2F7F7F7F7F7F7
F2F7F7F7F7F7F70000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
0000F7F7F7F7FFF7F7F7FF836B8991B2CDB2B2C3B1D0C3AD
D4DBF0E8DBD4D3C2D0CBCBCBD3BA90AD908283836C725F84
908B8B84FFF7F7FFF2F7F7F7F7F2F7F7F7F7F2F7F7FFF7F7
F2F7F7F2F700000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000F7F7F7FFF7F7F7F7F7E06B789BABC3D0DAD1D0D0D0
DACBCED3CEDBE1DAD0D4BAA5C2A4A1A577836C72838CA4A5
958BADF7F7F2F7F2F7F7F7F7F7F7F7F2F7F7F7F7F7F7F7F7
F7F7F7F70000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
00000000FFF7FFFFF7FFF7F7FFE98C8992BABAC3C8D0DADA
DADAE8DFDBDAE1D4D0C3C7A192A582837A906B91A4A5A191
A5E0F7F7F7F2F7F7F7FFF7FFF7F7F2F7F7F7F7F7F7F7F7F7
FFF7F7000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000F7F7F7F7F7F2F7FFF7F79D838CBCCDDADAD9
D4CDDBD1CDC3B2A49BADB2A1916F85A191B2B2BAB292B2F2
F7F7F7F7F7F7FFF7F7F7F7F2F7F7FFF7FFF7F7F7F2F7FFF7
F70000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
00000000000000F7F7F2FFF7F7FFF7F7F7F7F7A59DBABCC3
DBDBDADBDBDAC3C3ADAB9DBAD0A5C3CDC3A59BC2E9FFFFFF
F7F7F7FFF7F7F7F7F7FFF7F7F7F7F7F7F2F7F7F7F7F7F7F7
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000F7F7F7F7F7F7F7FFF7FFF7F7B1ABC3
ADC2D1D1DFDBE8F0E8DAD0DAD1D0ADA4BAD0E9F7F7FFFFF2
F7F7F7F7F7F7F7F2F7F7F2F7F7F7F2F7F7F7F7F7F7F70000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
0000000000000000000000F7F7F2F7F7FFF2F2F7F7F7F2F2
F2E9E9E0F0E8D0C3C3D0D1CDCDD2E9F2F7F7F7F7F7FFFFF7
FFFFFFF7F7F7F7F7F2F2F7F7F7F7F7F7F2F7FFF200000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
00000000000000000000000000F7F2F7F7F7F7F7F7F7F7F7
FFF7F7F7F7F7F2F2F2F2FFF7F7F7F7F7F7FFFFF7F7F7FFF7
F7F7F7F2F7FFF7F7FFF7F7F7FFF7FFF7FFF7000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000F7F2FFF7F7F7F2F7F2
F7F7FFF2F7F7F7F7F7F7FFF7F7F2F7F7F7F7F7F7FFF7FFF7
F7F7F2FFF7FFFFF7F7F7F7F7F7F7F7F70000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
0000000000000000000000000000000000F7F7F7F2F7F7FF
F7F7F7FFF7F7FFF7F7F7F2F7F7F7F7F7F7F2F7FFF7F7FFFF
F7F7F7F2F7F7F2F7FFF7F7F7F7FF00000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000F7F2FFF2
F7F7F7FFF7F7F7FFF7F2F7F7F2F7F7F7F7F7F7F7F7F7F7FF
F7F7F2F7FFF7F7F7F2FFFF00000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
F7FFF2F7FFF7F7F7F7FFF7FFF7F7F7F7F7F7F2F7FFF7F7F7
F7F7F7F7F7F7F70000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000FFFFF7F7FFF2F7F7F7F7F7FFF7F2F2F7F7FFF2F7
FFF7FF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000F70000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0113379 0.97619 0.464853 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00744048 0.0238095 0.00744048 [
[.5 1.0125 -17 0 ]
[.5 1.0125 17 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Color) show
93.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
384 string
128 128 8 [128 0 0 128 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000F7D6BD000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000E7BD9CE7BDA5EFC6A5EFB59CEFB59CEFB59CEFC6A5EFC6ADEFC6AD\
EFC6ADEFC6ADEFC6ADF7CEB5EFC6ADEFC6ADF7D6BDF7D6BDEFC6B5F7CEB5F7C6B5
F7CEB5F7C6B5EFC6AD000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
EFC6ADEFC6A5EFC6ADEFC6ADEFB59CE7B59CE7B59CEFBD9CE7B59CEFC6A5E7BDA5EFC6A5EFC6AD\
EFC6ADEFC6ADEFC6ADEFC6ADF7C6B5F7CEB5F7CEB5EFC6ADEFCEBDEFCEB5EFCEB5
EFCEB5F7CEB5EFCEB5F7CEB5EFCEB5EFCEBDEFCEB5000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000E7B594EFC6A5EFC6ADEFCEAD
EFCEADEFCEADEFCEADF7CEB5EFC6A5EFC6A5E7B59CEFBD9CE7BD9CEFBD9CE7B59CE7BD9CE7BDA5\
EFB59CEFC6A5EFC6A5EFC6ADEFC6ADEFCEADEFC6ADEFC6ADEFC6ADEFC6ADEFC6AD
EFC6B5EFC6ADEFC6ADEFCEB5EFCEB5EFC6B5EFC6B5EFC6B5EFC6ADEFC6ADEFC6AD000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000E7B594E7B594E7B594E7B594E7BDA5EFC6A5EFC6AD
EFCEADEFCEADEFCEADF7CEB5EFC6ADEFC6ADEFB59CE7B59CE7B594E7B594E7B59CE7BDA5E7B59C\
E7B594E7B594E7B59CE7BDA5E7BDA5E7BDA5EFC6A5E7BDA5E7BDA5EFBD9CE7BDA5
EFC6A5E7BDA5EFC6A5E7C6ADE7BDA5E7C6ADEFC6A5EFC6A5E7BDA5E7BDA5E7BDA5E7BDA5E7BDA5\
E7BDA5000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000E7BD9CE7BD9CEFBD9CEFC6A5EFC6A5EFBD9CE7B594EFBD9CEFC6A5
EFCEADEFCEADEFCEADEFCEADF7CEB5EFCEADEFC6A5EFB594EFBD9CEFC6A5EFB59CEFBD9CEFBD9C\
E7BDA5E7BDA5E7B594E7B594DEAD8CDEAD94DEAD8CDEA584DEAD94DEAD8CDEAD8C
DEAD8CDEA584DEAD8CDEAD8CDEAD94DEAD94DEAD94DEAD94DEAD94DEAD94DEAD94E7BD9CE7B59C\
E7BD9CE7BD9CE7BD9C000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
E7BD9CD6B5A5D6B5A5DEAD94E7B594E7BD9CEFBD9CEFBD9CE7B594E7BD9CEFC6A5
EFC6A5F7CEB5EFCEADF7CEB5EFCEADEFC6ADEFC6ADEFBD9CEFBD9CEFBD9CEFBD9CEFC6A5EFBD9C\
EFC6A5EFC6A5EFC6A5EFBD9CEFC6A5EFBD9CEFBD9CE7BD9CE7B59CE7BD9CE7B59C
E7B59CE7B59CE7BD9CE7B59CE7B59CEFBD9CE7BD9CEFBD9CE7BDA5E7BDA5EFC6A5EFC6A5E7B59C\
EFC6A5EFC6A5EFC6A5E7BDA5EFC6A5000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000E7BD9CE7BD9C\
E7BD9CE7BD9CE7BDA5D6B5A5E7B594E7BD9CEFBD9CEFBD9CE7B594E7BD94EFC6A5
EFC6ADEFC6A5EFC6ADEFCEADEFCEADEFCEADEFCEADEFC6A5EFBD9CEFBD9CEFC6A5EFC6A5EFC6A5\
EFC6A5EFC6A5EFC6A5EFC6A5EFBD9CEFB59CEFC6A5EFC6A5EFC6A5EFC6A5E7BDA5
E7BD9CEFBD9CEFBD9CEFC6A5EFC6A5EFBD9CEFBD9CEFBD9CE7BDA5EFC6A5EFC6A5EFC6A5EFC6A5\
EFC6A5EFBD9CEFC6A5EFBD9CEFC6A5EFC6A5EFC6AD000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000D6AD84D6AD84CE946BE7BD9C\
E7BDA5E7B59CE7BD9CDEAD9CE7BD94E7BD9CE7B594EFBD9CE7BD94E7BD94EFC6A5
EFC6A5EFC6A5EFC6ADEFC6ADEFCEADEFC6A5EFCEADEFC6A5EFC6A5EFBD9CEFBD9CEFC6A5EFC6A5\
EFC6A5EFC6A5EFC6A5EFC6A5EFC6A5EFC6A5EFB59CEFBD9CEFBD9CEFC6A5EFC6A5
EFC6A5E7BD9CEFBD9CE7BDA5EFB59CEFBD9CEFC6A5EFC6A5EFB59CEFC6A5EFC6A5EFC6A5EFC6A5\
EFBD9CEFBD9CEFC6A5E7BDA5EFC6A5E7BD9CEFC6A5EFC6A5EFC6A5000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000E7C6B5D6AD8CCE9463D6AD84C67B42AD6B39\
DEAD9CE7BD9CE7B59CE7B59CE7BD9CE7B59CE7BD9CEFB594E7B594E7BD9CEFC6A5
EFC6A5EFC6A5EFC6A5EFC6A5EFCEADEFC6A5EFC6A5EFC6A5EFC6A5EFC6A5EFC6A5EFC6A5EFC6A5\
EFC6A5EFC6ADEFC6A5EFC6A5EFC6A5EFC6A5EFBD9CEFBD9CEFBD9CEFC6A5EFBD9C
EFBD9CEFC6A5E7BD9CEFB59CEFBD9CEFBD9CEFBD9CE7BD9CE7BDA5EFC6A5EFC6ADEFC6A5EFC6A5\
EFB59CEFC6A5EFC6A5EFBD9CEFBD9CEFBD9CEFC6A5EFC6A5E7BDA5E7BDA5E7BDA5
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000EFDECEEFE7DEE7D6C6CE8C5ACE9463C67B42B56B39\
945229E7B59CDEAD9CE7BD9CDEAD94DEAD9CE7B59CE7BD9CE7BD94E7BD9CEFC6A5
EFC6A5EFC6A5EFC6A5EFC6A5EFC6ADEFC6A5EFC6A5EFC6A5EFC6A5EFC6A5EFBD9CEFBD9CEFBD9C\
EFBD9CEFC6A5EFBD9CEFC6A5EFC6A5EFC6A5EFBD9CEFBD9CEFBD9CEFBD9CEFBD9C
E7BD9CE7BD9CE7BD9CEFBD9CEFBD9CEFBD9CEFBD9CE7BD9CEFBD9CEFBD9CEFC6A5E7BD9CEFBD9C\
EFBD9CEFC6A5EFC6A5EFBD9CE7BD9CEFBD9CEFBD9CEFBD9CE7B594E7BD9CDEAD94
DEAD8C000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000EFEFE7F7EFE7E7D6CEF7EFE7E7C6ADCE8C5AC67B4AC67B42B56331\
9452297B3918DEA584DEAD8CDEAD94E7BD9CE7B59CE7BD9CE7B594E7BD94E7BDA5
EFC6A5EFC6A5EFC6A5EFC6A5EFBD9CEFC6A5EFC6A5EFC6A5EFC6A5EFC6A5EFC6A5EFC6A5EFBD9C\
EFC6A5EFBD9CEFBD9CEFBD9CEFC6A5EFC6A5EFC6A5EFC6A5EFB594EFB594EFBD9C
EFBD9CEFBD9CEFBD9CEFB59CEFBD9CE7BD9CEFB594E7BD94E7BD9CEFB59CEFC6A5EFBD9CEFC6A5\
EFBD9CE7BD9CEFC6A5EFC6A5EFBD9CEFBD9CE7BD9CE7B594E7B594DEAD8CDEAD84
D69C73D69C73C67B4A000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000F7EFF7F7EFE7EFEFE7EFDECEEFE7DEE7C6B5D6BDADC67B42C6845AB56B39\
9452297B39187B3918DEAD94DEAD94E7B594DEAD94E7BD9CE7BD94E7B594EFC6A5
EFC6A5EFC6A5EFC6A5EFC6A5EFC6A5EFBD9CEFBD9CEFC6A5EFC6A5EFBD9CEFBD9CEFBD9CEFBD9C\
EFB594E7BD9CEFBD9CEFC6A5EFC6A5EFC6A5EFBD9CEFBD9CEFBD9CE7BD9CEFB594
E7BD94E7B594EFBD9CEFBD9CEFBD9CEFB594E7BD9CE7AD8CE7BD9CE7BD94EFBD9CEFBD9CEFBD9C\
EFBD9CEFBD9CEFBD9CE7BD94DEAD84DEAD84DEA57BD69C73D69C73D69C73D69C73
C6845A9C6339945229C67B4A000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000F7EFF7F7EFE7F7EFF7EFEFE7F7EFE7E7DED6E7DED6D6AD84C6845AC67B4AAD6331\
9452298C42217B39186B3118DEAD8CE7B59CCEAD94E7BD94E7B594E7BD94EFBD9C
EFC6A5EFBD9CEFBD9CEFBD9CEFBD9CEFC6A5EFBD9CEFBD9CEFC6A5EFBD9CEFBD9CEFC6A5EFBD9C\
EFBD9CEFB594E7BD94EFBD9CEFBD9CE7BD9CEFC6A5EFBD9CEFB594E7B594EFB594
E7B594E7B594E7B594E7B594E7BD94E7B594E7B594E7AD8CE7AD8CE7AD8CEFB594EFBD9CE7AD8C\
EFBD9CDEAD84E7BD94E7B594E7AD8CDEA57BDEA57BD69C73CE946BC6845AB5734A
945229AD5A31AD6331C6845ACE9463000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
EFEFF7EFEFF7F7EFE7F7EFF7F7EFE7EFE7E7EFE7DEE7CEBDEFDECECE8C5AC6845AC67B42AD5A31\
9452299452298C42216B31184A1808D6A584DEAD9CDEAD94E7B594E7B594E7BDA5
E7BD9CEFBD9CEFBD9CEFBD9CEFBD9CEFC6A5EFBD9CEFC6A5EFBD9CEFBD9CEFBD9CEFBD9CE7BD9C\
EFBD9CEFBD9CEFB594EFB594E7BD94EFB594EFBD9CEFBD9CE7BD9CE7BD94EFB594
E7B594EFB594E7AD8CDEAD84E7AD8CEFB594E7AD8CE7AD8CEFB594E7AD8CE7BD94E7B594E7AD8C\
DEAD84E7B594DEAD8CDEAD8CDEAD84DEA57BD69C7BCE8C63B5734AAD6B39AD6331
9C6339AD6B42BD8C63CE946BCE8C5AC68C63CE9463000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000F7F7F7
F7EFF7F7EFF7F7EFF7EFEFF7F7EFE7F7EFF7EFE7E7E7D6C6E7DED6CE9463C6845AC67B4AAD6331\
9452299452298C42216329106329104A1808DEAD94DEAD94E7BD9CE7B59CE7BD9C
E7BD9CEFBD9CEFBD9CEFBD9CEFBD9CEFBD9CEFC6A5EFC6A5EFBD9CEFBD9CEFBD9CEFBD9CEFBD9C\
EFBD9CEFBD9CE7BD94E7BD94EFBD9CEFB594E7BD9CEFB594EFB59CE7B594E7B594
E7B594E7B594E7AD8CE7AD8CE7AD8CE7AD8CDEAD84DEA57BDEAD84E7AD8CDEAD84E7BD9CDEA57B\
DEAD8CDEAD84DEAD84D69C7BDEA584D69C73C67B4AAD5A31AD6B39844221AD6B42
B5734AC67B4ACE9463CE8C5AC68C63C6946BC68C63DEA573000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000EFEFF7EFEFF7
F7EFF7F7F7F7F7EFF7EFEFF7F7EFE7EFEFE7EFE7DEE7DED6E7CEC6CE9463C6845AB56B42AD6331\
9C63399452297B39186329105221106B3118DEAD94DEAD94E7B594E7BD9CE7BD9C
E7BDA5E7BD9CEFC6A5EFBD9CEFC6A5EFBD9CEFBD9CEFBD9CEFBD9CEFBD9CEFB594EFBD9CEFBD9C\
E7BD94EFBD9CEFB594E7BD9CEFB594E7B594E7B594E7AD8CE7B594E7B594E7B594
E7B594E7AD8CE7AD8CDEAD84DEA584DEA57BDEA57BDEA57BDEAD84E7BD9CDEAD84D69C7BD69C73\
D69C7BDE9C73DE9C73CE8C63CE8C63C67B42C67B4A8C4A31AD5A319C6339AD6B39
9C6339C67B4ACE8C5AC6845AC6845AC68C63D69C73D69C73D6AD84000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000EFEFF7EFEFF7F7F7F7
F7F7F7F7EFF7F7F7F7F7EFE7F7EFF7EFEFE7F7E7DEE7D6C6D6AD84CE9463C6845AB5734AAD5A31\
B56B399452298C4A296B31186B31187B42217B4A29DEAD9CE7BD94E7BD9CEFC6A5
E7BD9CE7BD9CEFC6A5EFBD9CEFBD9CEFBD9CEFBD9CEFBD9CEFBD9CE7BD9CEFBD9CE7BD9CE7B594\
EFB59CEFBD9CE7BD94EFB594EFB594E7BD94E7AD8CE7BD94DEAD84E7B594E7BD94
E7B594E7AD8CE7AD8CDEA584DEA584CE946BD69C73DEAD8CE7BD9CDEAD8CCE8C63CE946BD69C73\
CE946BD69C73CE946BC67B4AC67B42B56331AD6331C67B4AAD6B42C67B4AC67B4A
BD8C63CE9463CE946BC68C63CE8C5AC68C63D69C73CE8C5ACE946BD69C73000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000EFEFF7F7F7F7EFEFF7F7EFF7
F7F7F7F7EFE7F7EFF7F7EFE7EFEFE7EFE7DEEFE7E7DECEBDD6AD84C6845AC6845AB56B42B5734A\
AD6B398C4A298C4A297B39188442218C4221632910DEAD94E7BD9CE7BDA5EFC6A5
E7BD9CE7BD9CEFBD9CEFB594E7BD94EFBD9CEFB594E7BD94EFBD9CEFBD9CE7BD94EFB594E7BD94\
EFB594EFB594EFBD9CE7B594E7B594E7B594E7BD94DEAD84EFB594DEAD84E7AD8C
DEAD8CDEAD84DEA584DE9C7BCE946BD69C73D69C73E7BD94E7BD9CCE8C63CE946BD69C73D69C73\
CE8C63B57B5AB56B529C6339C67B42B56B39AD6331AD6B39C67B42C67B4AB56B42
C6845ACE9463CE9463CE8C5AC6845AB5734AD6AD84CE9463D6AD84CE946BE7BD94000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000F7EFF7EFEFE7F7F7F7F7EFF7F7F7F7
EFEFF7EFEFF7F7F7F7F7F7F7F7EFE7EFE7DEEFE7DEDEAD94D6AD84C6845AB5734AAD6B429C6339\
9C63398C42218C4A299452299452297B39184A1808E7BD9CE7B594E7BDA5E7BD9C
EFBD9CE7BD9CEFBD9CEFB594EFB594EFBD9CEFB594EFB594EFB594EFB594EFB594EFB594E7BD94\
E7BD94EFB594E7B594E7BD94E7B594E7B594DEAD84DEAD84DEAD84E7AD8CDEAD84
DEAD8CDEAD8CDE9C7BD69C73CE8C63CE8C63DEAD84DEAD94CE8C63C68463C68463C68C63C68463\
B57B5AAD73528C5A42AD6B42C67B42B56B39B56B39B56B39B56B42AD6B42B56B42
C6845ACE9463CE946BBD8C63BD8C63CE9463D69C7BCE946BD69C73CE946BCE946BDEA573000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000F7EFF7F7EFF7F7F7F7F7F7F7F7EFF7F7F7F7
EFEFF7F7F7F7F7F7F7F7F7F7EFEFF7EFE7DEE7D6CED6AD84D69C73BD8C63B57B5AB56B42AD6B42\
8C4A29844221945229945A318C4A296B39216B3118E7BDA5E7B59CEFC6A5E7BDA5
E7B594EFBD9CE7BD9CE7BD9CEFBD9CEFB594EFB59CE7BD94EFB594E7AD8CEFB594EFB594E7AD8C\
E7AD8CE7AD8CE7AD8CEFB594DEAD84E7AD8CDEAD8CDEAD84E7AD8CDEA57BDEA584
DEA57BD69C7BD69C73C6846BCE8C63CE9463D69C73CE946BC6845AC68463C6845AC6845AB57B5A\
9C63399C6B4A9C6B4AAD6B39CE8C5AC67B4AC67B42B56B39AD6B39BD8C63C67B4A
C6845ABD8C63CE8C5AC6946BD6AD84D69C73D69C73C6946BCE946BCE946BCE946BD69C73E7BD94\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000F7EFF7F7F7F7F7F7F7F7EFF7F7F7F7F7EFF7F7EFF7
F7EFF7F7EFF7F7EFF7F7EFE7EFEFF7EFE7DEE7D6C6D6AD8CCE946BC6845AB5734AAD6B42AD6B39\
945A31945229AD6B399452296B31186B3118632910E7BDA5E7B59CE7BD9CDEAD94
E7BD9CEFBD9CEFBD9CE7AD8CE7AD8CEFB594E7B594E7AD8CE7AD8CE7AD8CDEAD84E7AD8CE7AD8C\
DEAD84DEAD84E7AD8CDEA584E7AD8CDEA584DEA584DEA584DEA584DEA57BDEA57B
D69C73D69C73CE946BCE8C5AC68463D69C7BC68C63B57B5AB56B52C67B4AB5734AB57B5A946342\
B5734A9C7352AD6B39AD6B42C67B4ACE8C5AC6845AB5734AC67B4AB57B5AC67B4A
BD8C63B5734AC68C63C6946BD6AD84D6AD84D6AD84CE9463CE946BD6AD84CE9463D69C73E7BD94\
E7BD9C000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7EFF7F7EFF7
F7F7F7F7EFE7EFEFF7F7F7F7F7F7F7EFE7DEE7BDA5D69C73D69C73BD8C63B5734AAD6B42AD6B42\
8C4A299C63399452298442216329106B3921632910E7BD9CE7BD9CE7BD9CE7BD9C
E7BD9CE7B594EFBD9CE7BD94E7AD8CEFB594E7AD8CDEAD84E7AD8CDEAD84DEA584DEAD84DEA584\
DEAD84DEA584DEA584DEA584DEAD8CDEAD84DEA57BDE9C7BD69C7BDEA57BD69C7B
D69C7BD69C73CE946BC6845ACE946BCE8C63B57B5AB56B52B5734AAD6B42AD6B42945A319C6B4A\
9C6B4A9452299C6339B56B42CE8C5ACE8C5ACE8C5ACE946BC67B4AC67B4AB5734A
B5734ABD8C63C6946BC6845AD6A584D6AD84D69C7BC6946BD6AD84DEAD8CD69C73DEAD84E7BD94\
E7BD94000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7EFF7EFEFE7
F7EFF7EFEFE7F7F7F7F7EFF7F7EFE7F7EFE7CEAD94D69C73C68C63C6845A9C63399C6B4A945A31\
9C4A319C63399C4A317B42216B39217B42216B3118E7BDA5DEAD9CE7BD9CE7B594
E7BD9CE7B594E7AD8CE7BD94E7AD8CE7AD8CE7AD8CDEAD84DEA584DEA584DEA584DE9C73DE9C7B\
DEA57BDE9C7BDE9C7BDEA584DEA57BDEA57BD69C73DE9C73D69C73D69C73D69C73
D69C73CE8C63CE8C63C6845ACE946BC6845AB5734AAD6B42AD6342AD6342946342AD6B429C6B4A\
945A31945A319C6339B56B39C67B42CE8C5AC6845ACE8C5AC6845ABD8C63B5734A
B5734AB56B42C6845AD69C73D69C7BD69C73D6AD8CD6AD8CD6AD84CE946BD69C73DEAD84E7BD9C\
E7C6B5EFDECE000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000F7F7F7F7EFF7F7EFF7F7EFE7EFEFF7F7F7F7F7EFF7F7EFF7F7F7F7
F7F7F7F7EFF7F7F7F7EFEFE7F7EFE7E7D6C6D6AD8CD69C73C6845AB57B5AAD6B42B5734A945229\
9C63399C6339945A315A31216329106B31186B3921E7BD9CDEAD94E7B59CDEAD94
E7B594E7B594E7AD8CE7AD8CE7AD8CDEA584DEAD84DEA57BDE9C7BDEA57BDE9C7BDE9C7BDE9C73\
CE946BCE946BCE946BD69C73D69C73DE9C7BD69C73D69C73CE946BCE946BCE946B
CE8C63CE8C63C68463BD8C63B5734AAD6B42AD6B399C6339AD6342AD6B42AD6B429C63399C6339\
9C6339AD6331B56B39B56B42C67B42CE8C5ADEA573D69C73DEAD84C68C63AD6B39
AD6B39B5734AC68C63C6845AD69C73D6AD84D6AD84D6AD84CE9463CE9463CE9463E7BD94E7C6AD\
E7C6B5E7DED6EFE7DE000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000F7EFF7F7F7F7F7EFF7F7F7F7F7EFE7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7EFF7EFEFF7F7EFF7F7EFE7F7EFE7E7BDA5D6AD84C6946BBD8C63B5734A9C63399C6B4A945A31\
AD6B398C4A298442215229185229186B31186B3118E7BD9CDEAD94E7B594E7B59C
E7B594E7AD8CE7AD8CDEA584DEA57BDEA57BDEA57BDEA57BDE9C73D69C7BD69C73DE9C73D69C73\
D69C73CE946BCE946BCE946BCE946BD69C73D69C73CE946BCE946BCE946BC68463
C68463C6845AB57B5AC6845AB56B429C6339945A31AD6B429C6339AD6B42AD6B427B42217B4221\
8C4A29B56331C67B42C67B42C67B42C6845ACE9463D69C73CE946BD6AD84BD8C63
B5734AC6845AC6845ACE946BC6845AD6AD8CD6AD8CCE946BCE9463CE946BCE9463E7BD94E7C6AD\
EFE7DEE7DED6EFE7DEEFE7DE000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000F7EFF7F7F7F7F7EFE7F7F7F7F7EFF7F7F7F7F7EFF7F7F7F7F7EFF7F7EFE7
F7EFF7F7F7F7EFEFE7F7EFF7E7DED6D6B5A5D6AD84BD8C63B57B5AAD6B429C6B4A945A31945A31\
9C63398C4A297B39186B31186B39216B39217B3918DEAD94DEAD94DEAD8CDEAD8C
E7AD8CDEAD8CDEA584DEAD8CDEA584DEA584D69C7BDE9C73DE9C73CE946BCE946BCE946BC6846B\
CE8C63CE8C63C6846BCE946BCE946BC6846BCE946BCE946BCE946BC68463C6845A
C68463C6845AB5734ACE8C5AAD6B428C4A299C6B4A9C6B4A9C6339945A318442217B4221632910\
AD6331C67B42B56331C67B42B56B42C67B4ACE9463DEA573D69C7BDEAD84BD8C63
BD8C63CE9463BD8C63CE946BC6946BD6AD84CE946BCE946BC6845ACE8C5ADEAD84E7C6ADEFD6C6\
EFDECEEFDECEE7DED6EFEFE7000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
F7F7F7F7F7F7F7F7F7EFEFF7F7EFE7F7EFF7EFEFF7F7F7F7F7F7F7F7EFF7F7F7F7
F7F7F7EFEFF7F7EFF7EFEFE7E7C6B5D6AD8CC69C84B57B5AB57B5A9C6B4AAD63429C6339945A31\
945A316B39216B39216B31186B39216B39216B3921DEAD94DEAD8CDEAD94E7BDA5
E7AD94E7AD94E7A594E7AD94E7A594E7A594DEAD8CDEA584DEA584D69C7BCE8C63C6845ACE8C63\
C67B5AC6845AC6845AC6845AC6845ACE8C63CE8C63C6845AC6845AC6845AB57B5A
B57B5AB56B52B5734AC6845A9C63397B4A299C6339AD6B428C4A297B42217B39187B4A29945229\
AD5A31C67B42C67B42B5734AC67B42AD6B39CE9463D69C73D6AD84CE946BC6946B
C6845AC68C63C68C63BD8C63D6AD84D6AD84CE9463D69C73CE9463D6AD84D6AD84DEC6B5F7EFE7\
EFD6C6E7DED6EFEFE7EFE7E7F7F7F7000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000F7F7F7\
EFEFF7F7F7F7F7EFF7F7F7F7F7EFE7F7EFF7F7EFE7F7F7F7F7F7F7F7EFF7F7EFF7
EFEFF7EFEFF7EFEFF7EFE7DEDEC6B5D6AD84C6946BB57B5AB5734AAD6B429C6339B5734A9C4A31\
945A315221107342296B39216B39216B3118845231DEAD94E7C6ADEFC6ADEFC6AD
EFC6ADEFC6A5EFC6A5EFB59CEFB59CEFB59CE7AD9CE7AD94E7AD94DEAD8CDEA584D69C7BC67B5A\
C67B5AC67B4AC67B5AC67B5AB57B5AB57B5AB57B5AC6845AC67B5AB57B5AC67B4A
B5734AAD6B42AD6B42C67B4A8C4A298C4A319C63398C5A428442216B31186B3921AD6331844221\
9C6339C67B4AC67B42B5734AAD6B39B5734ACE8C5AD69C7BDEAD84DEAD8CD6AD84
C6946BC6946BB57B5AB56B42D6AD84D6AD84C6946BCE946BD6AD84D6AD84E7BD9CEFEFE7EFE7DE\
EFE7DEEFE7DEEFEFE7F7EFE7F7EFF7F7F7F7000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000F7F7F7\
F7EFF7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7EFEFE7F7F7F7F7EFF7F7F7F7F7EFE7
EFEFF7F7EFF7F7EFF7E7CEBDD6B5A5D69C73C68C63B57B5AAD7352945A319C6339945A319C6339\
8442216329107B42217342296B39216B3118B58463EFC6ADEFC6B5F7D6BDF7C6B5
F7C6B5EFC6ADEFC6ADF7C6B5EFC6ADEFC6ADEFB59CEFB59CE7B59CE7AD94DEAD8CDEA584DE9C7B\
CE946BC67B4AB5734AB57B5AC67B4AC67B4AC67B5AB56B52B57B5AC67B4AB57B5A
B5734AAD6B42946342B5734A945A319C6339B5734A8442217B39186B3118734A31B56B398C4221\
9C6339B56B42C67B4AB56B39AD6B39B5734AC6845ACE8C5ADEAD84DEAD8CD6AD84
D69C73C6946BB5734ABD8C63D69C73D69C73D69C73D69C73E7BD94D69C73E7BD9CEFEFE7EFDECE\
E7D6C6F7E7DEEFE7E7F7F7F7F7EFF7F7F7F7000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000F7F7F7F7EFF7\
F7EFE7F7F7F7F7EFF7F7EFF7F7F7F7F7EFF7F7EFF7F7F7F7F7EFF7EFEFF7EFEFF7
F7EFE7F7EFF7F7EFF7E7CEBDCEAD94C6946BBD8C63AD7352AD6B42AD6B429C6339945A319C6339\
6329106B39217B4A296B39216B3921B58C73EFC6B5F7CEB5F7D6BDF7CEB5F7D6BD
F7C6B5F7D6BDF7C6B5F7CEB5F7C6B5EFC6ADEFC6A5EFC6ADEFB59CEFB59CE7AD94E7AD8CDEA584\
DEA57BD69C73CE946BB5734AB5734AB5734AB5734AC67B4AB5734AB57B5AB5734A
AD63429C6B4A845239844221B5734A945A31C6845A7B39186B3118522110632910AD6B39B56B42\
945229B56B42CE8C5AAD6B39BD8C63B5734AC6845AD69C73DEAD84E7BD94E7BDA5
D6AD8CB56B42BD8C63BD8C63CE946BC68C63D69C73D6AD8CD6AD84DEA57BEFE7E7EFDECEEFCEBD\
EFE7DEF7EFE7F7EFF7F7F7F7F7F7F7F7EFE7F7F7F7000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000F7F7F7F7F7F7F7F7F7\
F7EFE7F7EFF7F7F7F7F7EFF7F7EFF7F7EFF7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7
EFEFF7EFE7E7E7D6C6E7C6ADC69C84C6946BB57B5A9C6B4A945A319C63399C6339945A31844A29\
6329107B4A297B4A296B3921E7C6B5F7CEB5EFCEADF7CEB5F7D6BDF7D6BDEFD6C6
F7D6BDEFD6C6F7C6B5F7C6B5F7C6B5F7CEB5EFC6ADEFC6A5EFC6A5EFC6A5E7BD9CDEAD94DEAD8C\
E7AD8CDEA584D69C7BCE946BB56B52AD6B42AD6B42B5734AAD6B42B56B52AD6B42
AD63429C63398442217B4221C6845A844221CE8C639C63396B3921734A31522110844221C67B4A\
8C4221B56B42C67B4AB56B39C6845AC6845AC6845ACE9463D69C73E7BD9CE7BDA5
D6AD84C68C63B57B5ABD8C63C6946BC6946BD6AD84D6AD8CD6AD84E7BD94E7DED6E7D6CEE7DED6\
EFEFE7EFEFE7F7F7F7F7EFE7F7F7F7F7EFF7F7F7F7F7F7F7000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000F7F7F7F7F7F7EFEFF7\
F7EFF7F7EFE7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7
EFEFE7EFE7E7DECEBDD6BDADBD947BBD8C63B57B5AAD6B429463429C6339945A31945A316B3921\
6B31187B42216B3921A5846BEFCEB5F7CEB5EFC6ADF7CEB5F7CEB5F7D6BDF7D6BD
F7D6BDF7D6BDEFD6C6F7D6BDF7C6B5F7C6B5EFC6ADEFC6ADEFC6ADE7BDA5E7B59CE7BD9CE7B594\
E7AD8CDEAD94DEA584D69C7BC6846BCE946BAD6342AD6342AD6B429C6B4AAD6342
9463429C4A31844A31734229C67B4AAD7352B57B5AB5734A6B31185221107B42219C6339C67B4A\
C6845AC67B4AC67B4AC6845AAD6B42C68C63BD8C63C6946BD69C73D6AD84E7BD9C
E7BD94BD8C63B5734ABD8C63C67B4AC6946BD6B5A5E7BD94CEB5A5D6AD8CE7C6ADEFE7DEF7EFE7\
F7EFE7F7EFF7F7F7F7F7EFF7F7F7F7F7EFF7F7F7F7F7EFF7000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000F7EFF7F7F7F7F7EFF7F7EFF7\
F7EFF7F7EFE7F7F7F7F7EFF7F7EFF7F7EFE7F7F7F7F7F7F7EFEFE7F7F7F7EFEFF7
EFEFE7E7DED6DECEBDCEAD94BD947BBD8C63B5734A9C6B4A845239945A318C4A29945A31522918\
6B39217342298C5A42EFC6ADEFC6B5F7CEB5F7CEB5F7CEB5F7CEB5F7D6BDF7C6B5
F7D6BDF7C6B5F7C6B5F7D6BDF7C6B5F7C6B5EFC6ADEFC6A5EFC6ADEFC6ADEFC6A5E7B59CE7B59C\
E7B594DEAD94DEAD8CDEA584D69C7BCE946BC6846B9C6339AD6342AD6342945A42
9C6339844A297B4A296329109C6B4AD69C7B8C4A29CE946B946342AD6B426B3118AD63318C4A31\
BD8C63AD6331C67B42C67B4ABD8C63B58463C6946BB57B5AD6AD84CE9463E7BDA5
EFCEB5BD8C63B5734ABD8C63C68C63C69C84D69C73D6AD84D6AD8CE7BD94E7DED6EFE7DEEFE7E7\
F7EFE7EFEFE7F7EFF7F7F7F7F7EFF7F7F7F7F7F7F7F7EFF7F7EFF7000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000F7F7F7F7F7F7F7F7F7F7EFF7\
F7EFF7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7EFE7E7
EFE7E7E7CEBDDECEBDC69C84C68C63AD7352B5734A946342945A31945A318452316B39216B3118\
844A29845A42EFC6B5EFC6ADEFCEADF7CEB5F7CEB5F7CEB5F7C6B5EFCEADEFC6AD
EFC6ADEFC6ADEFC6ADEFC6ADEFC6A5EFB59CEFB59CE7BDA5EFC6A5E7BD9CEFBD9CE7B59CE7B59C\
DEAD8CE7AD8CDEAD94DEAD8CDEA584D69C73CE946BCE8C639C63399C4A319C6339
8C4A318C4A296B39216B3921845239BD8C63B57B5A9C6B4AC69C848C4221B57B5A945A31AD6342\
B56B42C67B4AAD6B39C67B4ABD8C639C6339BD8C63BD8C63D69C73D69C73CEAD94
DEAD8CE7BD94BD8C63B56B42BD8C63C69C84C6946BD6AD84E7BD94E7D6CEEFEFE7E7DED6EFEFE7\
F7EFE7EFEFE7F7F7F7F7EFF7F7EFF7F7F7F7F7EFF7F7F7F7F7F7F7000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000F7EFF7F7EFF7F7EFF7F7EFF7F7F7F7\
F7F7F7F7EFF7F7F7F7F7EFF7F7EFE7EFEFF7F7EFF7F7EFF7F7F7F7F7F7F7EFE7E7
E7D6CEE7CEBDCEB5A5BD947BB57B5AAD7352946342945A31945A31945A315A31216B39216B3118\
6B3118EFC6B5EFC6B5F7CEB5EFCEADEFC6ADEFC6ADF7C6B5EFC6ADEFBD9CE7B59C
E7AD94E7AD94DEAD8CDEAD8CDEAD8CDEA584DEAD8CDEAD8CDEAD8CDEAD8CE7B594E7B594E7B594\
E7B59CE7B594DEAD8CDEAD8CDEA584DE9C7BD69C7BD69C73CE8C63B56B52945A31
845231844A317342296B3921734A31946342CE946BBD8C63A57B5AD69C73C67B4AB57B5A844221\
AD6B39C6845AC67B42C67B4AAD6B39B57B5AB57B5AD69C7BC6946BD69C73D6AD84
E7BDA5E7C6B5BD8C63C6946BD69C7BC6946BC68C63CEAD94E7BD9CF7EFE7E7DED6F7EFF7EFEFE7\
F7EFE7EFEFE7F7F7F7F7F7F7F7EFF7F7F7F7EFEFF7F7EFF7F7F7F7F7EFF7000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7EFF7F7EFF7F7EFF7F7F7F7F7F7F7F7EFF7F7EFF7EFE7E7
E7D6C6DECEBDD6AD8CC6946BB5734AB5734AAD63428C4A31945A318452316B31186B3921844A29\
E7C6B5EFCEB5EFCEB5F7CEB5EFCEADEFC6ADEFC6ADEFC6A5E7BDA5E7AD94E7AD8C
DEA584DE9C7BE78C7BE78C7BE78C7BE78C7BE78C7BDEA584DE9C7BDEA584DEAD8CDEA584E7B594\
E7B594E7B59CDEAD94DEAD8CDEA584D6A584D69C7BCE946BCE946BC684638C5A42
8442297B4A296B39215229186B39218C634ACE946BAD7352945A31D6A584C67B4ACE9463B57B5A\
9C6339AD6B42CE8C5AC67B4AB5734ABD8C63B57B5AD69C73C6946BD6AD84D69C73
D6AD84E7C6ADD6AD84D69C73C69C84C69C84D69C73D6AD8CE7BDA5EFE7DEEFE7DEF7EFE7EFEFE7\
F7EFF7F7F7F7F7EFF7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7EFF7000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7EFE7F7EFE7F7F7F7F7EFF7EFEFE7E7D6CE
E7CEBDDECEC6C69C84B57B5AAD73529C6339AD6342845239844A296B39216B39217B39187B4A29\
EFC6B5EFC6B5EFC6ADEFC6ADEFC6ADEFC6ADEFC6A5EFB59CDE7363CE6B5ADE7B6B
DE7B6BDE8473DE8473DE8473DE8473DE8473CE6B5ACE6B5ACE6B5ACE6B5AD69C7BDEAD8CDEAD8C\
E7B594E7B594E7B594DEAD94DEAD8CDEA584D69C7BD69C7BCE946BC6846BC6845A
7B4A296B39216B31185221106B3118845239AD7352D69C7BB58463C6846BD6AD84CE9463D69C73\
C6946BC67B4AB5734AC6845ABD8C63AD6B39B5734ABD8C63D69C73BD8C63DEAD84
D6AD8CE7BD94E7BDA5C69C84D6AD84C6946BD69C73E7BD94DECEBDE7D6CEEFE7E7EFEFE7EFE7E7\
EFEFE7F7EFE7F7F7F7EFEFF7F7EFF7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7\
F7EFF7F7EFE7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7EFE7F7F7F7EFE7E7E7DED6
E7D6C6D6AD8CC6946BA57B5A9C6B4A9C6339945A317B4A298452397342296B39217B4A29EFCEBD\
EFC6B5EFC6ADEFC6ADEFC6A5EFCEADEFC6ADE78C7BDE8473DE8473DE8473EFC6B5
EFB59CE78C7BE78C7BE7A594EFB59CDE8473DE8473DE7B6BC6846BCE7363CE6B5AD69C7BDEAD8C\
DEAD94E7B594E7B59CDEAD94DEAD8CDEAD8CD6A584D69C7BCE946BDE8473C68463
B57B5A734A31522918522918522110845239522918D6A584DEAD8C9C6339D6AD8CB57B5ADEA57B\
D6AD84BD8C63C6845ACE9463AD6331C6845AB57B5ABD8C63C6946BCE946BD69C7B
D6AD8CE7BDA5E7C6B5BD947BB58463C6946BD69C73CEAD94EFE7DEEFE7DEEFEFE7EFEFE7EFE7DE\
F7F7F7F7F7F7EFEFF7F7EFF7F7EFF7F7F7F7F7EFF7F7F7F7F7EFF7F7EFF7F7F7F7
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000F7F7F7F7EFF7F7EFF7F7F7F7F7EFF7F7EFF7\
F7EFF7F7EFF7F7EFF7F7EFF7F7EFE7F7F7F7F7F7F7EFEFF7F7F7F7E7D6D6DECEBD
CEAD94C6946BB58463A57B5A845239945A318C4A31945A316329106B39216B3921A5846BEFCEB5\
EFCEB5EFCEB5EFC6ADEFC6A5EFC6A5EFC6A5DE7B6BDE8473DE8473DE7B6BDE7363
DE7363DE7363DE8473CE6B5ACE6B5AC65A4AC6634AC6634AE78C7BCE7363CE7363C65A4AD6A58C\
E7AD94E7B594E7B594E7B594E7B594DEAD8CD6A584D69C7BD69C7BCE946BCE946B
C6845AAD73526B39216B39213918106B31188C5A42B58463C6946BB57B5ABD8C63D6AD84C6845A\
DEAD84EFCEADBD8C63B5734AC6845AC6845AAD6B42B57B5ACE9463C6946BD69C73
D69C73E7BDA5E7BDA5C69C84C6946BC69C84BD947BCEAD94EFE7DEEFE7E7F7EFE7EFE7E7EFE7E7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000F7F7F7F7EFF7F7EFF7F7EFF7F7F7F7F7EFF7F7EFF7\
F7EFF7F7F7F7F7F7F7F7EFF7F7EFF7F7F7F7F7EFF7F7EFF7F7EFF7E7D6CED6C6B5
D69C73C6946BAD73529463428C4A31945A31844A296B31187B42216B3118945A31EFCEBDEFCEBD\
EFCEB5EFC6ADEFC6ADEFC6A5E78C7BDE8473AD73529C4A31AD4A31BD5242AD7352
BD5242BD5242C65A4AB552399C4A319C31219C4229AD4A318C3121AD42319C4229844229945A42\
DE8473E7B594E7B594E7B594DEAD8CDEAD8CDEAD8CD69C7BD69C7BD69C73D69C7B
C68463B57B5A8C5A424A18083918106B3921734A31845A42BD8C63D6A584945A31D6A584B57B5A\
D69C7BE7BD9CEFCEADCE946BCE946BB56B39C6845AB57B5ABD8C63C68C63B57B5A
D6AD84E7BD94E7BDA5D6BDADD69C73D6AD84C69C84D6B5A5E7DED6EFEFE7EFE7DEEFEFE7F7EFF7\
EFEFE7F7F7F7F7F7F7F7EFF7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7000000000000000000000000000000000000000000
000000000000000000000000000000000000F7EFF7F7F7F7F7EFF7F7F7F7F7EFF7F7F7F7F7EFF7\
F7F7F7F7EFF7F7EFF7F7EFF7F7EFF7F7EFF7F7EFE7F7EFF7EFE7E7E7D6CED6BDAD
BD947BB57B5A9463428C4A318C5A428C4A297B4A297B4A297B4A29844229EFCEBDEFCEBDEFC6B5\
EFCEB5F7CEB5EFC6ADEFC6A5EFB59CEFC6A5E78C7BCE7363CE6B5AC6634ACE6B5A
C6634ACE6B5ADE7B6BC6634AC6634AC6634AC6634AC6634AC6634AD69C73D6A584D6A58CDEAD8C\
DEAD8CE7B594E7B594E7AD8CE7AD8CDEAD8CE7AD8CDEA584D69C7BD69C7BD69C73
CE946BC684639C73525A39293918103918105A3929845A429C7352D69C7BC6946B9C6B4AD69C73\
B57B5AE7BD9CE7BD9CEFCEB5AD7352C6845AC6845AB57B5ABD8C63BD8C63B57B5A
D6AD84D6AD84E7BDA5E7C6ADC6946BD6AD84D69C73E7D6C6EFE7E7EFE7E7EFE7DEEFE7DEF7EFF7\
F7EFF7F7EFF7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7EFF7
F7F7F7000000000000000000000000000000000000000000
000000000000000000000000000000000000F7F7F7F7F7F7F7EFF7F7F7F7F7EFF7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7EFE7F7F7F7F7EFF7EFEFE7F7EFE7EFE7DEDECEC6D6AD8C
B584639C6B4A9C6B4A8C5A428C4A29844A297342297B4A29844221845231EFCEB5EFC6ADEFCEB5\
EFCEADEFC6ADEFCEADEFC6A5EFCEADF7CEB5F7CEB5F7D6BDEFD6C6EFC6B5EFC6AD
F7D6BDEFC6ADEFC6A5F7CEB5F7D6BDEFC6B5EFC6ADE7BDA5E7B59CE7BDA5E7B59CE7B594E7B594\
E7B59CE7B594E7B59CE7B594E7AD94DEAD8CDEAD8CDEA584DEA584D69C7BD69C73
CE946BCE946BB57B5A845231423129291008845A42734A31845A429C7352BD8C639C6339C6845A\
AD6B42C6845AE7BD9CE7BD9CD69C73CE946BBD8C63B5734AB5734ABD8C63CE946B
D69C73CE946BE7BDA5E7C6ADC69C84C69C84C68C63E7DED6EFE7DEEFE7DEEFE7E7EFE7DEF7F7F7\
F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7
F7EFF7000000000000000000000000000000000000000000
000000000000000000000000000000F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7EFF7\
F7EFF7F7F7F7F7F7F7F7EFF7F7EFE7F7EFF7F7EFF7EFE7E7DEC6B5E7BD9CC69C84
AD7352946342845231845231844A316B31187B4A297B4A297B4221D6B5A5EFCEB5EFCEB5EFCEB5\
F7C6B5F7CEB5EFC6ADF7CEB5EFC6ADF7CEB5F7CEB5F7D6BDF7CEB5F7D6BDF7CEB5
F7D6BDEFC6A5EFC6ADEFC6ADEFC6ADE7B59CE7B59CE7B59CE7B59CE7BD9CE7B59CE7BD9CEFC6A5\
E7B59CE7B594E7BD9CE7B59CE7AD94E7AD94DEAD8CDEA584DEA584D69C7BDE8473
CE946BCE946BB57B5A945A42522110422118734A31845231A5846B9C7352C69C849C6339945A31\
C68C63BD8C63DEAD94E7BD9CEFC6A5D6AD84C6845AC6845AC68C63B5734AB57B5A
B57B5ACE946BE7BDA5E7C6ADD69C73D6AD8CC6946BEFE7DEEFE7E7E7DED6EFE7DEF7EFE7F7F7F7\
F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7EFF7F7EFF7F7EFF7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7000000000000000000000000000000000000
000000000000000000000000000000F7EFF7F7F7F7F7EFE7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7\
F7F7F7F7EFF7F7F7F7F7EFF7F7EFF7F7EFE7F7EFF7F7EFF7DECEC6C69C84B57B5A
9C63399C6B4A844A29844A316B39217B4A297B4A297B4A297B4A29EFCEB5EFCEB5EFC6B5EFCEB5\
F7CEB5F7C6B5F7C6B5F7CEB5EFCEB5F7CEB5F7CEB5F7CEB5F7CEB5F7CEB5F7CEB5
EFCEB5EFC6ADEFC6A5EFC6A5EFC6A5E7B59CE7BD9CEFBD9CE7B59CE7BDA5E7B59CEFC6A5E7B59C\
EFC6A5E7B59CE7B59CE7AD94E7AD94E7B594DEAD8CDEA584DE9C7BDEA584D69C73
CE946BCE946BC684639C6B4A7342295A39293918107352428452399463429C6339AD73529C6339\
B57B5AA57B5ACE946BE7BD94E7BD94CE946BD69C73C6845ABD8C63B5734ABD8C63
B5734AD69C73D6AD84E7BDA5CEAD94C6946BD69C7BE7D6CEEFE7DEEFE7DEE7D6C6F7F7F7F7EFF7\
F7F7F7F7F7F7F7EFF7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7
F7F7F7F7F7F7000000000000000000000000000000000000
000000000000000000000000000000F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7EFF7F7EFE7DECEC6D6C6B5BD947BB5734A
9C6B4A844A298C5A426B39217B4A296B31187B4A29844A296B3921EFCEB5EFC6B5EFC6B5EFCEB5\
F7CEB5F7CEB5F7CEB5F7C6B5F7CEB5F7CEB5F7CEB5F7CEB5EFCEB5F7CEB5F7CEB5
EFC6A5EFC6A5E7B59CEFC6A5E7B59CE7AD8CE7B594E7BD9CE7B59CEFB59CEFBD9CEFC6A5EFB59C\
EFB59CEFC6ADEFC6A5E7B59CE7B59CE7AD94E7AD8CDEA584DEA584D69C7BD69C73
DE8473C6846BC68463B5734A734A31522110522918734A318C634A946B529C7352B584639C6B4A\
8C5A42946342BD947BC68C63DEA573EFC6A5D6AD84C67B4AC68C639C6B4AC6946B
BD8C63D69C7BD69C73E7BDA5CEAD94BD8C63E7C6B5E7D6C6EFE7E7EFE7E7EFE7E7F7EFF7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7
F7EFF7F7F7F7000000000000000000000000000000000000
000000000000000000000000000000F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7\
F7F7F7F7EFF7F7EFF7F7EFF7F7F7F7F7F7F7EFE7E7DEC6B5C6A594BD947B9C6B4A
9C63399463428442297B4A297B4A29734A317B4A296B3921B58463E7C6B5EFC6B5EFC6B5F7CEB5\
F7CEB5F7CEB5F7CEB5F7D6BDF7CEB5EFCEB5F7CEB5F7CEB5F7CEB5EFC6ADEFC6AD
E7B59CDEAD8CDEA584E7AD94DEAD94DEA584DEAD8CE7AD94E7B594E7B59CEFBD9CE7BDA5EFC6A5\
EFC6ADEFC6ADEFB59CEFB59CE7B59CE7AD94DEAD8CDEA584DEA584D69C7BD69C7B
D69C73CE946BC67B5AB56B528C5A425A39296B39215A4239845A428452399C7352946342B5734A\
8452319C6339845239D6AD8CE7BD94D69C73DEA57BC68C63C6946BA57B5AB57B5A
BD8C63C69C84D69C73E7BD9CD6B5A5C6946BE7DED6E7BDA5F7EFF7EFE7E7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7
F7EFF7F7F7F7000000000000000000000000000000000000
000000000000000000000000F7F7F7F7F7F7F7EFF7F7F7F7F7EFF7F7EFF7F7F7F7F7F7F7F7EFF7\
F7F7F7F7F7F7F7F7F7F7EFE7F7F7F7F7EFF7F7EFF7E7BD9CBD947BAD7352946342
8C4A318C4A317B4A296B39216B39217B4A297B4A296B3118E7C6B5EFC6B5EFC6B5F7C6B5F7CEB5\
F7CEB5F7CEB5F7CEB5F7CEB5F7CEB5EFCEADF7CEB5F7CEB5F7CEB5EFC6ADEFB59C
E7AD9CE7B594DE9C7BDEA584DEA584D69C7BD6A584DEAD8CDEAD8CE7B594E7B59CEFBD9CEFB59C\
EFC6A5EFC6A5EFC6A5EFB59CEFC6A5EFB594E7AD94DEAD8CDEA584D69C7BD69C7B
D69C73C6846BC68463B57B5A945A425A3929291008422921734A318452319C6B4A845239B5734A\
9C63399C63397B4A29D6A584C6845AD69C73EFCEADC6946BC68C63C68C63B57B5A
B58C73C6845AC6946BE7BD9CD6BDADD6BDADDECEBDE7D6CEE7D6CEE7CEC6F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7000000000000000000000000000000
000000000000000000000000F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFE7E7D6AD8CB58463946342845231
8C4A316B39217B4A297342297B4A298442296B31185A3121EFC6B5E7C6ADEFC6ADEFC6ADF7CEB5\
F7C6B5F7D6BDF7D6BDF7CEB5F7CEB5F7CEB5F7C6B5EFD6C6DE9C7BDE7B6BEFC6AD
EFC6ADEFB59CE7A594B56342B56342C6846BDE9C7BB57B5AD69C73DEAD8CE7B59CEFC6A5EFC6A5\
EFC6ADEFC6ADEFC6ADEFC6A5EFB59CE7B59CE7AD94E7AD8CDEA584DEA584D69C7B
D69C73CE946BC68463B56B52AD63427342293918104229215A3121734A31845239845A429C6B4A\
9C6B4A8452319C6B4A8C5A42BD8C63DEAD84D69C73DEAD84C6845ABD8C639C6339
B57B5AB57B5AD69C73E7BD94D6BDADEFE7E7CEAD94EFE7E7D6B5A5F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7000000000000000000000000000000
000000000000000000000000F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7EFF7F7F7F7F7EFF7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7E7DEDEC6946BAD73529463429C6339
7B4A297B4A296B39217B42217B4A296B39215A3121845239EFC6B5EFC6ADEFCEB5F7CEB5F7D6BD\
F7CEB5F7C6B5F7D6BDF7C6B5F7CEB5EFCEADF7CEB5F7D6BDEFCEB5EFC6B5F7C6B5
F7C6B5EFC6ADE7B594DEAD8CDEAD94E7AD8CE7B594DEA584CE8C63D69C7BE7B59CEFC6ADEFC6AD\
EFC6ADEFC6ADEFC6ADEFB59CEFC6A5EFC6A5EFB594E7AD8CDEAD8CDEA584D69C7B
CE946BCE946BC68463C67B5A9C73528C5A422910083918104229215A42397352428C5A42845239\
9C7352845231945A31522918D6AD84CE8C63CE9463E7BD9CB57B5ABD8C639C6B4A
AD7352BD8C63C6946BCEAD94DEC6B5DEC6B5C6AD9CD6B5A5F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7000000000000000000000000000000
000000000000000000000000F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7EFF7F7EFF7F7F7F7F7F7F7\
F7F7F7F7F7F7F7EFE7F7F7F7F7F7F7F7F7F7E7D6CEBD8C63946342945A426B3921
734A31844A317342297B4A29844A31632910632910A57B63E7C6ADF7C6B5F7C6B5F7C6B5EFD6C6\
F7D6BDF7D6BDF7D6BDEFD6C6F7CEB5F7CEB5F7C6B5F7D6BDEFC6B5EFD6C6EFD6C6
EFD6C6F7C6B5EFC6A5E7B594E7AD9CE7AD9CDEAD94DEAD8CDEA584DEA584EFB59CEFC6ADEFC6AD\
F7C6B5EFC6ADEFC6ADEFC6ADEFB59CEFB59CEFB59CE7B594E7AD8CDEAD8CDE9C7B
DE8473DE8473C68463B57B5AAD6B42946342291008422118391810734A31845239946342734229\
9C6B4A845231945A315A3121C6946BBD8C63D6AD84E7BD9CB57B5ABD8C63AD7352
B57B5AB58463BD947BD6AD8CDEC6B5DEC6B5D6BDADDECEBDF7F7F7F7F7F7F7EFF7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7000000000000000000000000000000
000000000000000000000000F7F7F7F7EFF7F7F7F7F7F7F7F7EFF7F7F7F7F7EFF7F7F7F7F7F7F7\
F7EFE7F7F7F7F7EFF7F7EFF7F7F7F7F7EFF7E7CEC6AD73528C5A42945A31845231
7B4A297B4A29844A298C4A317B42215229185A3929E7C6B5EFC6B5F7CEB5F7CEB5F7D6BDF7D6BD\
F7D6BDEFD6C6F7D6BDEFD6C6F7D6BDF7C6B5EFC6ADF7D6BDF7D6BDEFD6C6F7DED6
EFD6C6F7C6B5EFC6ADE7BDA5E7AD94E7A594DEAD94DEAD8CDEA584E7AD94EFB59CEFC6ADEFC6AD\
EFCEADEFC6ADF7C6B5EFC6ADEFC6A5EFC6A5EFB59CEFB59CE7AD94E7AD8CDEA584
DE9C7BCE946BC6846BB57B5AAD6B42945A315229181808084221187342295229189C6339845231\
9C6B4A7B42218452318C5A42AD7352C68C63DEA57BDEA57BD69C73B57B5ABD8C63
AD7352B57B5AB57B5ACEAD94E7C6ADD6B5A5E7CEC6F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7EFF7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7000000000000000000000000000000
000000000000000000000000F7F7F7F7F7F7F7F7F7F7EFF7F7EFF7F7F7F7F7EFF7F7EFF7F7F7F7\
F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7EFE7C6946B9463429463426B3921734229
7342297B4A29844A317B4A29422118632910422118EFC6ADF7C6B5EFCEBDF7C6B5F7D6BDF7D6BD\
EFD6C6F7D6BDF7D6BDF7D6BDF7D6BDF7D6BDF7CEB5F7CEB5F7C6B5EFD6C6EFD6C6
EFD6C6F7CEB5EFC6ADE7AD94D6A58CDEA584DEAD8CD6A58CDEAD94E7B59CEFC6ADEFC6B5EFC6B5\
EFCEB5F7CEB5EFC6ADEFC6ADEFC6A5EFC6ADEFC6A5EFB59CE7AD94E7AD8CDEAD8C
DEA584D69C73C6846BB57B5AAD7352AD6342734A312110083918105A39297B5A428452398C5A42\
9463427B4A29845231734A319C7352C6845ACE946BDEAD8CE7BDA5B5734AB57B5A
9C7352B57B5AC6946BE7BD9CE7C6ADC69C84DECEBDF7F7F7F7EFF7F7F7F7F7EFF7F7EFF7F7EFF7\
F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7EFF7000000000000000000000000000000
000000000000000000F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7\
F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7EFEFF7B5846B946342844A296B3921845239
844A31844A317B4A293918105229185221105A3929EFC6ADF7CEB5F7D6BDEFD6C6EFD6C6EFD6C6\
EFD6C6EFD6C6EFD6C6EFD6C6EFD6C6F7D6BDF7D6BDF7C6B5EFCEBDF7C6B5F7D6BD
F7C6B5EFC6B5EFB59CE7B59CD6A58CDEAD8CDEAD94DEAD94E7B59CEFC6ADEFC6ADEFC6ADEFC6B5\
F7C6B5F7CEB5EFC6B5F7C6B5EFC6ADEFC6A5EFC6ADEFB59CEFB59CE7AD94E7AD8C
D6A584DEA584CE946BC68463AD73529C6B4A8C4A31291008423129522918734229734A31845231\
8452319C6339845231845231A57B5ABD8C63CE9463DEAD8CEFCEADB57B5AB5734A
9C6B4AA57B5AB58463CEAD94DEC6B5DECEBDF7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7
F7F7F7F7F7F7F7EFF7F7EFF7000000000000000000000000
000000000000000000F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7\
F7EFF7F7F7F7F7EFF7F7EFF7F7EFF7F7EFF7B5846B945A317B4A297B4A29845239
734A317B4A29844A31522918422118522918CEAD94EFCEB5EFCEB5F7D6BDEFD6C6EFD6C6EFD6C6\
EFD6C6F7DECEF7DECEF7DECEEFD6C6F7D6BDF7D6BDF7D6BDF7CEB5EFC6B5F7D6BD
F7D6BDEFC6ADEFB59CDEAD94DEAD94DEAD8CE7B594E7B59CE7BDA5EFC6ADEFCEB5EFC6B5F7C6B5\
F7C6B5F7D6BDEFCEBDF7C6B5EFC6B5EFC6ADEFC6ADEFB59CE7B59CE7B59CDEAD94
DEA584D69C7BD69C73C68463B56B529C6B4A9463424221182110085A31215229188452398C5A42\
7B4A29945A319C63398452319C7352C69C84D69C73DEAD84EFCEADAD7352C68C63
8C5A42B58463AD7352E7BD94E7CEBDDECEBDF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7000000000000000000000000
000000000000000000F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7EFF7F7EFF7\
F7F7F7F7F7F7F7EFF7F7EFF7F7F7F7DEC6C69C73528C5A42734229845231845231
844A317B4A29522918422118391810EFB59CEFCEBDF7C6B5F7D6BDF7DECEEFD6C6EFD6C6F7DECE\
EFD6C6EFD6C6EFD6C6EFD6C6EFD6C6EFD6C6EFD6C6EFD6C6F7D6BDF7CEB5F7D6BD
F7D6BDF7C6B5EFC6ADE7B59CDEAD94E7B594E7B594E7B59CE7BDA5EFC6B5EFC6B5EFD6C6F7D6BD\
F7C6B5EFD6C6F7C6B5F7D6BDEFCEBDEFCEBDEFC6B5EFC6ADE7C6ADEFB59CE7B594
DEAD8CD6A584D69C7BD69C73B57B5A9C6B4A9C63397342296329106B3921734A31734A31946342\
8452319C63398C5A428C4A319C7352D6A584D69C73D6AD84E7BDA5BD8C63B5734A
845231A57B5AB57B5ADEAD8CE7D6C6EFEFE7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7EFF7F7EFF7F7F7F7F7F7F7F7EFF7F7F7F7
F7EFF7F7F7F7F7F7F7F7F7F7000000000000000000000000
000000000000000000F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7EFF7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F79C7352945A318452315A31217B5A42734A31
734A31844A315229186B39215A3929EFC6ADEFC6B5EFD6C6F7D6BDEFD6C6EFD6C6F7DECEF7DECE\
EFD6C6EFD6C6F7D6BDF7DECEEFD6C6EFD6C6EFD6C6EFD6C6F7D6BDEFCEBDF7D6BD
F7D6BDF7D6BDF7C6B5E7B59CDEAD94E7B59CE7BD9CE7BDA5E7BDA5E7C6ADEFCEB5F7D6BDEFCEBD\
F7D6BDEFD6C6F7D6BDF7C6B5EFCEBDEFCEBDEFCEBDEFC6B5EFC6ADE7BDA5E7B59C
DEAD94DEAD8CD69C7BD69C73C67B5AB56B52945A42734A316B39216B39216B3921845239845231\
9C63399463428C5A4294735AB5846BD69C7BD69C73D69C73D6AD84C68C63AD6B39
844A29A57B5ABD947BD6AD8CE7DED6F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7
F7F7F7F7F7F7F7F7F7F7EFF7000000000000000000000000
000000000000000000F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7\
F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7AD73529C6339734A316B39218C5A42845239
7B4A297342296B3921522918A58473F7C6B5EFCEBDEFD6C6EFD6C6EFD6C6F7DECEF7DECEEFD6C6\
F7D6BDEFD6C6F7D6BDF7D6BDEFD6C6F7DECEF7DECEEFD6C6EFD6C6F7D6BDF7D6BD
EFD6C6F7C6B5F7C6B5E7B59CDEAD94DEAD94E7BD9CE7BDA5EFC6ADEFC6ADEFCEBDEFCEBDEFCEBD\
EFD6C6EFD6C6F7C6B5F7C6B5F7D6BDF7CEB5EFCEB5EFC6B5EFC6ADEFC6ADE7BDA5
DEAD94DEAD8CD6A584D69C73C68463B56B52945A428C4A315A31215A31216B3921734A31844A31\
9463429C6339946342945A31D69C73D69C73D69C73D69C73D6A584D6AD84AD6B42
AD6B42AD7352B58463DEAD84EFEFE7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7000000000000000000000000
000000000000000000F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7EFF79C73529C7352845239734A31734229845239
844A315A3121734229845239EFC6B5F7CEB5EFCEBDEFD6C6EFD6C6EFD6C6EFD6C6EFD6C6EFD6C6\
EFD6C6F7D6BDEFD6C6EFCEBDEFD6C6EFD6C6EFD6C6EFD6C6F7D6BDF7D6BDEFC6B5
EFD6C6EFD6C6F7D6BDE7BDA5E7AD94DEAD94E7B59CE7BDA5E7BDA5E7C6ADEFC6B5EFCEBDEFCEBD\
EFCEBDEFD6C6EFCEBDF7D6BDEFCEBDEFC6B5EFC6B5EFC6ADEFC6B5E7C6ADE7BDA5
E7BDA5DEAD94D6A584D69C7BCE946BB57B5A9C6B4A8452397342296B31186B39216B3921845239\
945A318C634A845239844A29D6AD8CD69C73C6946BD69C7BC69C84DEAD8C945A31
AD7352AD7352A5846BD6AD84F7EFE7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7000000000000000000000000
000000000000000000F7F7F7F7EFF7F7F7F7F7EFF7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7EFF7F7F7F7BDADAD945A318C634A8452318C5A428452318C4A31
6B39215A3929734229E7C6ADF7D6BDEFC6B5F7D6BDEFD6C6EFD6C6EFD6C6EFD6C6F7DECEEFD6C6\
EFD6C6F7D6BDEFCEBDEFC6B5EFC6B5EFCEBDEFCEBDF7D6BDF7D6BDF7C6B5F7CEB5
EFD6C6EFD6C6F7D6BDEFC6ADE7AD94DEAD8CDEAD94DEAD9CE7BD9CDEAD9CE7C6B5E7CEBDEFC6B5\
EFD6C6EFCEBDEFCEBDEFCEBDEFC6B5E7C6B5EFC6B5EFC6ADEFC6ADEFC6ADE7BDA5
E7BDA5DEAD9CDEAD8CD6A584DE8473C684639C6B4A945A31734A315229186B39216B3921734A31\
9C6B4A8C5A428C5A428C5A42C69C84C6946BD69C73D69C739C6B4AE7BD94844221
9C6B4ABD8C63C6946BCEAD94F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7000000000000000000000000
000000000000000000F7EFF7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7EFF7F7F7F7A57B6BB58C739C6B4A734A319C6B4A734A318C4A31
5A3121734A317B4A29E7C6ADF7C6B5E7C6ADEFD6C6EFD6C6F7DECEEFD6C6EFD6C6F7D6BDEFD6C6\
EFCEBDEFCEBDEFB59CE7C6ADEFC6ADEFC6ADEFC6B5EFCEBDF7D6BDEFCEB5F7CEB5
F7D6BDEFD6C6F7D6BDEFC6ADE7A594DEAD8CD6A58CDEAD94DEAD94E7BDA5E7C6B5EFC6B5EFCEBD\
E7C6ADE7C6ADE7BDA5E7C6ADE7C6ADE7C6ADE7C6ADEFC6ADEFC6B5E7C6ADE7C6AD
D6B5A5E7BD9CDEAD8CD6A584D69C73C68463AD7352945A31844A315229185221106B3921734A31\
8C5A429C63398C5A428C5A42C69C84CE946BCE946BD69C73844A31DEAD84945A42
8C5A42B5846BD6A584E7C6ADF7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7000000000000000000000000
000000000000000000F7EFF7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7EFF7F7EFF7\
F7EFF7F7EFF7F7F7F7F7F7F78C4A29B5947B8C5A42946B52845A428C5A42734A31
5229189C6339E7AD8CEFC6ADE7AD94EFC6B5F7D6BDEFD6C6EFD6C6EFD6C6EFD6C6EFCEBDE7CEBD\
EFC6B5EFC6B5EFC6ADDEAD9CDEAD94E7BDA5E7C6ADEFC6B5EFCEBDE7C6ADEFC6B5
EFD6C6EFD6C6F7D6BDEFB59CDEAD94DE9C7BD6AD8CD6A58CCEAD94D6B5A5E7C6ADE7C6B5E7BDA5\
E7BDA5D6B5A5E7AD9CDEAD8CDEAD8CD6A58CDEAD9CDEAD9CE7BDA5E7BDA5E7BDA5
E7BD9CE7BD9CDEAD94D6A584CE946BC6846BB56B529C6B4A8452397342293918106329106B3921\
8C5A428C5A429C6B4A845239BD947BD69C7BB57B5ABD8C63844A29E7BD949C6B4A
8C4A31C6946BD6AD84E7D6C6F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7EFF7F7F7F7F7F7F7F7F7F7000000000000000000000000
000000000000000000F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7EFF7F7F7F7\
F7F7F7F7F7F7F7F7F7FFFFFF9C6B4AA57B638452398C5A42845239945A42522110
845231844A31F7C6B5CE946BDEA584EFCEB5F7D6BDEFD6C6EFD6C6EFD6C6EFCEBDE7C6B5DEAD9C\
BD947BB58C73D6A58CCEA594BD947BDEAD9CDEAD9CEFCEBDEFCEBDEFC6B5EFC6B5
F7D6BDF7D6BDF7D6BDEFC6ADDEAD94D69C7BC69C84D69C7BE7BD9CDEAD9CE7C6B5E7AD9CDEAD9C\
C6A59CBD9C8CB5846BB58C73C69C84C69C84C69C84CEA594E7BD9CE7BDA5DEAD9C
DEAD9CDEAD9CDEAD8CD6A584C69C84C6846BB57B5A945A42845239734A316B39215A31215A3121\
8452398452318C634A8C5A42B5846BBD8C63B57B5AB57B5A945A31E7BD94945A31
8C4A31C69C84D69C73E7D6CEFFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7000000000000000000000000
000000000000000000F7F7F7F7F7F7F7EFF7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7BD9C94A57B5A9C7352734A31845239734A31945A425A3121
945A31EFB594EFB59CE78C7BD6A58CEFCEB5EFCEBDEFD6C6EFD6C6EFC6B5E7AD9CB58463BD8C63\
DEAD9CBDADAD736B6373736BA58473C69C84DE8473DE8473EFC6B5EFC6B5E7C6AD
F7D6BDF7D6BDF7D6BDEFC6A5E7B59CD69C7BD6A584BD947BD6A5849C4A31C65A4AC6846BD6A58C\
DEC6C6947B73735A4AA57B6BA57B63A57B5AA57B63B5846BD6A58CDEAD94DEAD94
DEAD9CDEAD9CD6A58CD6A58CCE946BC6846BB56B529C6B4A8C5A42734A31845239522918522918\
8452398452398C5A429C6B4AB58463BD947BB5734AB57B5A945229E7BD9C9C6339
9C7352D6AD84D6AD84EFE7E7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7000000000000000000000000
000000000000000000F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7\
F7F7F7F7F7F7F7F7F7B5846BBD9C8C9C73528C634A5A3121845239945A426B3118
522918F7C6B5E7AD8CE7A594DEAD94EFCEBDF7D6BDEFCEBDE7C6ADE7AD9CB5846BC6846BD6BDB5\
E7D6CE7B7373736B63635A52847B73A57B6BC69C84BD947BE7AD9CDEAD94EFC6A5
F7D6BDF7D6BDEFCEB5EFC6ADE7B59CDEA584BD947BB5846BC6846BC69C84AD4231DEC6C6EFE7E7\
8C736394735A7B6B5A948C846B635ABD9C949C73528C6B52B5846BD6A584D6A584
DEAD94DEAD8CD6A58CD69C7BD69C73B5846BAD73529C6B4A845231734A315A3121291008422118\
8452398C5A427342299C6B4AB5846BB584639C6B4AA57B5AAD6342DEAD8C844A29
BD947BD6AD8CD6AD8CF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7000000000000000000000000
000000000000000000F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7FFFFFFF7EFF7A5846B8452317B4A295A3121845239845239845239
945A42F7C6B5DEA584E78C7BDEAD94E7C6B5EFCEB5EFC6ADDEAD9CBD947B94735A5A3929B5948C\
C6B5B5947B6BB5B5BD21181884736B5A4A4294735AB5846BBD947BE7B59CEFCEAD
F7D6BDF7D6BDF7CEB5EFC6ADE7BD9CE7B594BD947BB58C739C7352B58C73BD947B9C6B4ACEC6BD\
635A52B5BDCE21181873736B635A52BD9C94423129735242A57B63B58C73BD947B
D6A584D6A58CD6A584BD947BC6946BC68463AD7352945A42845239844A31422118391810422118\
522918845239734A31AD73529C7352A57B5AA57B5AB57B5AAD6342D6AD84844A29
BD8C63D69C7BDEC6B5F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7000000000000000000000000
000000000000000000F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7B5947BD6C6C6A58C7394735A7B5242734A31845239845239945A42
CE7363EFB59CE78C7BD69C7BDEAD8CEFC6B5EFCEB5E7B59CCEA594C6846B734A31846352846352\
5A42394229215A39298452398C6B52846352A57B63BD947BE7AD94EFBD9CF7CEB5
F7CEB5F7D6BDF7CEB5EFC6ADEFBD9CE7B59CDEA584BD947BC6846BAD735294735AA58C84A58C84\
5A39295229185A39295A3929734A315A4239735A4A7B5242A57B63B58463B5846B
CE946BD69C7BD69C7BBD947BB5846BB57B5A945A428C5A428C5A42734A316B39214221185A3929\
6B39216B3921734A319C6B4AAD73529C6B4A9C6339B57B5AAD7352D6AD84946342
BD8C63D69C73EFE7DEF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7EFF7F7F7F7F7F7F7F7F7F7000000000000000000000000
000000000000000000F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7AD7352BD9C94B59C8C8C5A42734A318C634A845239734A318C4A31
C68463E7A594D69C7BD69C7BDEAD8CEFC6B5E7C6B5E7C6ADE7BDA5DEAD94BD947BB56B528C634A\
7B52427B52427B524284523994735AC6846BD6A584E7B59CEFC6ADEFC6ADF7CEB5
F7D6BDF7D6BDF7CEB5EFC6ADEFC6ADEFC6A5E7B594DEA584D69C7BBD947BB5846B84634AA57B63\
A584739C7B6B846352634A425A4239734A319C7352BD8C63B58C73C6846BCE946B
D69C7BD69C7BBD947BCE946BBD8C63B56B52945A428C5A428452398452397342295229185A3929\
5A31215A31217342299C7352B57B5A9C73529C6339B57B5ABD8C63D6AD849C6B4A
BD8C63D6A584EFEFE7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7000000000000000000000000
000000000000000000000000F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7\
F7F7F7F7F7F7EFE7DEA58C7B946B52734A31734229734A31734A316B39219C6B4A
C68463CE946BC69C84BD947BD6A58CE7C6B5EFCEB5EFCEB5F7D6BDEFCEBDEFC6ADEFC6B5E7BDA5\
E7B59CE7AD9CE7B59CE7BDA5E7B59CD69C7BDEA584E7AD94EFC6A5F7D6BDF7CEB5
EFD6C6EFD6C6F7D6BDF7CEB5EFCEADEFC6ADE7B594D69C73DE9C7BBD947BD6A584D6A58CD6A584\
BD947BBD947BBD947BCE946BD69C7BD6A584D6A584DEAD8CE7AD8CDEAD94D6A58C
D6A584D69C7BCE946BC6846BBD8C63B57B5A945A428C634A8452396B39216B39215229185A3929\
734A317342296B39219C6B4ABD8C639C6B4A9C6339C6845ABD947BDEAD949C7352
BD947BEFDECEFFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7000000000000000000000000000000
000000000000000000000000F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7\
F7F7F7FFFFFFFFFFFF7342298C5A425A31216B39216B39219463425A31219C4A31
B56B52DE8473CE946BB58C73D6A584EFCEB5E7BDA5F7CEB5F7D6BDF7D6BDEFD6C6F7D6BDF7D6BD\
EFD6C6E7A594C6846BA57B639C7352B56B52E7B59CEFC6A5F7D6BDF7D6BDF7D6BD
F7DECEEFD6C6F7D6BDEFD6C6F7CEB5F7D6BDEFBD9CE7AD94C6846BAD63429C7352B56B52B58C73\
E7BDA5E7C6ADEFC6ADE7C6ADE7BDA5E7BDA5E7B59CE7B59CE7B59CDEAD94D6A584
C6946BB58463CE946BBD8C63B57B5AAD73529C6B4A8C5A42845231845239632910522918522918\
5A3929522110734A318C5A42AD73529C6B4A946342C68C63C6946BE7BD9CA57B5A
C69C84EFE7E7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7000000000000000000000000000000
000000000000000000000000F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7EFE7E7FFFFFF6B39217B4A295A31216B3921734A31845239734A319C6339
B56342B57B5ABD8C63C6846BC69C84EFC6ADDEC6B5E7BD9CEFC6B5F7D6BDEFD6C6EFD6C6F7C6B5\
B5846BA57B6394735AB56B52D6A584EFC6A5F7CEB5F7CEB5F7D6BDF7DECEF7D6BD
F7DECEEFD6C6F7D6BDF7D6BDF7D6BDF7CEB5F7CEB5EFC6A5E7AD94BD8C63945A42845239945A42\
B56B52DEA584E7AD9CE7C6ADEFC6ADEFC6ADEFB59CE7BDA5DEAD94DEA584BD947B
A57B5ACE946BB58C73B5846BAD73529C6B4A9C6B4A8C5A426B39216B39215229185A3121522918\
522110735242845A42946B52A57B5A9C7352945A31BD8C63BD8C63D6AD8CBD947B
C69C84F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7000000000000000000000000000000
000000000000000000000000F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7\
FFFFFFBDADADFFFFFF845231734229734A31734A315A31218452397B4A29945A31
945A42945A42A57B63B5846BC69C84E7C6B5EFCEBDBD947BC69C84D6A584D69C7BDE8473B56B52\
AD7352D69C7BF7CEB5F7D6BDF7D6BDF7DECEF7DECEF7DECEF7DECEF7DECEF7DECE
EFD6C6EFD6C6EFD6C6EFD6C6F7D6BDEFD6C6F7CEB5F7CEB5F7CEB5EFCEADE7B59CD6A584B58C73\
94735A8C5A429C7352AD6342CE6B5AB58C73C6846BB58463A57B63A57B5AB5846B
BD947BBD947BDE8473BD8C63AD73529C6B4A9C6B4A8452399C6B4A4221187342297342296B3921\
52291842292184634A9C6B4AAD73529C6B4A946342BD8C63D69C73B5846BAD6B42
DECEBDF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7000000000000000000000000000000
000000000000000000000000F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7\
F7F7F7C6A5949C7352734A31734A3184634A845239734A31734A31734A31845239
945A318C634A9C7352A57B5AD6A584E7C6B5EFCEB5EFCEB5EFC6ADD6A584BD9C8CDE8473DEAD9C\
EFD6C6F7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DED6
EFD6C6EFD6C6F7DECEF7DECEF7DECEF7D6BDF7D6BDEFD6C6F7D6BDF7CEB5F7C6B5EFC6ADEFC6AD\
EFC6ADE7C6ADE7C6ADC69C84A57B63AD7352A57B63A57B63BD947BC69C84BD947B
CE946BD69C73CE946BBD8C63AD73529C7352AD73528452396B3921734A316B39215A3121391810\
3918104221188C634A94735A8C5A42A57B5AAD6342C6946BC69C849C6B4ABD8C63
EFE7E7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7000000000000000000000000000000
000000000000000000000000F7EFF7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7D6C6C69C6B4A7B5A42734A319C7B6B8C6B527B5A42845239734A318C5A42
8C5A428C634AAD7352AD7352D69C7BEFC6ADEFC6B5EFCEB5EFCEB5F7D6BDF7D6BDEFD6C6EFD6C6\
EFD6C6F7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DED6F7DECEF7DECE
EFD6C6F7DECEF7DECEF7DECEEFD6C6EFD6C6EFD6C6EFD6C6EFD6C6F7D6BDEFCEB5EFCEB5F7CEB5\
EFC6ADEFC6ADEFC6ADE7BDA5E7C6ADE7C6ADE7B59CDEAD94DEAD8CD6A58CD69C7B
D6A584BD947BB58C73B57B5AAD7352A57B5AAD73529C6B4A734A316B3921522110391810391810\
391810422118B58C738C634A8C5A42D69C739C6B4AB57B5AD6AD849C6B4AC69C84
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7000000000000000000000000000000
000000000000000000000000000000F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7CEB5A5844A29735242845A42A58C73946B52845239845A427B5A42845A42
845A428C5A42A57B5A9C7352D69C7BE7C6ADEFCEB5EFCEB5EFCEBDF7D6BDF7D6BDEFD6C6F7DECE\
F7DECEEFD6C6F7D6BDF7DECEF7DECEF7DECEF7D6BDF7DECEF7DECEF7DECEF7DECE
F7D6BDEFD6C6F7DECEEFD6C6EFD6C6F7DECEEFD6C6F7D6BDF7D6BDF7D6BDF7D6BDF7C6B5F7CEB5\
EFC6B5EFC6ADE7C6ADE7BDA5EFC6ADE7B59CE7B59CDEAD94D6A584D6A584D69C7B
D69C7BBD947BC6946BBD8C63B56B52AD7352AD73528C5A429C6B4A734229522918522918422118\
5A3121522110BD947BA57B5A8C5A42BD947BAD73529C6B4AD6AD8C9C6B4AD6BDAD
FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7000000000000000000000000000000000000
000000000000000000000000000000F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7DECEC68452398C6B528C634A9C73528C634A8C6B528C634A845A42845239
8452318452319C6B4A9C7352C6846BE7BD9CEFC6B5EFCEB5EFCEB5EFCEBDF7D6BDF7D6BDEFD6C6\
F7DECEF7DECEF7D6BDF7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECE
F7DECEF7DECEF7DECEF7DECEF7DECEEFD6C6EFD6C6EFD6C6F7CEB5F7CEB5F7CEB5F7CEB5F7CEB5\
EFC6ADEFC6A5E7C6ADEFC6ADE7BDA5E7BD9CE7B594DEAD94DEAD8CD6A58CD6A584
D69C7BD69C73CE946BB57B5AAD7352B57B5A9C73529C6B4A734A315A31216B39215A3121391810\
391810422118C6946BA57B639C6B4AD69C73B5734A8C634ABD947B9C6B4AF7EFF7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7000000000000000000000000000000000000
000000000000000000000000000000F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7EFF78C634A84523984523984523984634A8C634A845239845A42845239
845A42845239A57B5AB57B5AC6946BE7B59CE7BDA5EFCEADEFCEBDF7CEB5F7D6BDF7D6BDEFD6C6\
EFD6C6F7DECEF7DECEF7DECEF7DECEF7DECEF7D6BDF7D6BDF7DECEF7DECEF7DECE
F7DECEF7DECEEFD6C6EFD6C6EFD6C6EFD6C6EFD6C6F7C6B5F7CEB5F7CEB5F7CEB5EFCEADEFC6AD\
EFC6ADEFC6ADEFB59CE7BDA5E7BD9CE7BDA5E7B59CDEAD8CDEAD94DEA584D6A584
BD947BCE946BC6846BBD8C63B57B5AAD73529C6B4A845239734A315A3929734229422118391810\
3918105A31219C7352D69C73B58463D69C7BB57B5A9C7352946342CEAD94F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7000000000000000000000000000000000000
000000000000000000000000000000F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7FFFFFF7B52428C6B528452398C634A8C6B52946B528C634A845A42845A42
8452398C634A9C7352BD8C63BD947BDEAD8CE7BDA5EFCEB5EFCEBDF7D6BDF7D6BDF7D6BDF7D6BD\
F7DECEF7DECEF7D6BDF7D6BDF7DECEF7DECEF7D6BDF7DECEF7DECEEFD6C6F7DECE
F7DECEF7DECEEFD6C6EFD6C6EFD6C6F7D6BDF7D6BDF7D6BDF7D6BDF7CEB5F7CEB5EFCEADEFC6AD\
EFC6ADEFC6ADEFB59CE7B59CE7B59CE7B59CE7B59CE7AD94DEAD8CD6A58CD6A584
D69C7BCE946BB58C73B58463B58463A57B639C6B4A8C5A426B3921734A31522110422118422118\
39181042292194735ABD947B9C7352C6946BBD8C63A5846B946342E7CEC6F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7000000000000000000000000000000000000
000000000000000000000000000000000000F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7FFFFFF9C7B6B7352428C5A42946B52946B52845A428C634A8452397B5A42
946B528C634A9C7352B5846BC6946BD6A58CE7BDA5EFC6ADF7CEB5F7CEB5F7CEB5F7D6BDF7D6BD\
F7D6BDF7DECEF7DECEEFD6C6F7D6BDF7DECEF7DECEEFD6C6F7D6BDF7DECEF7D6BD
EFD6C6EFD6C6F7D6BDEFD6C6F7D6BDF7D6BDF7D6BDF7CEB5F7D6BDF7CEB5F7CEB5EFC6ADF7CEB5\
EFC6ADEFC6A5EFC6A5E7BDA5E7BD9CE7BDA5E7B594DEAD94DEAD8CD6A58CD6A584
BD947BCE946BC6846BB58463B584639C6B4A9C6B4A8C5A42734A316B3921522110391810291008\
2910087B52428C634AA57B5AAD7352C69C84C6946BD6AD8CC6946BF7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7000000000000000000000000000000000000000000
000000000000000000000000000000000000F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7FFFFFF845239A57B63A57B5A8C5A428C634A84634A8C5A42845A429C6339
7342298C634AA57B63BD8C63B58C73D6A584E7BD9CEFC6ADEFCEB5F7CEB5F7D6BDF7D6BDF7D6BD\
F7DECEF7DECEEFD6C6F7DECEF7DECEF7DECEF7D6BDF7DECEF7D6BDEFD6C6F7DECE
F7D6BDEFD6C6EFD6C6F7D6BDEFD6C6EFD6C6F7D6BDF7D6BDF7D6BDF7D6BDEFC6ADF7C6B5EFCEAD\
EFC6ADEFC6ADEFB59CEFC6A5E7B59CE7B59CDEAD94DEAD94DEAD8CD6A58CD6A584
BD947BD69C73B58C73B5846B9C7352946B52845A42734A318452395A3121391810291008422921\
29100884634A946B529C6B4A946342C6946BC6946BC69C84E7DED6F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7000000000000000000000000000000000000000000
000000000000000000000000000000000000F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7E7DEDEA57B637B5A427B5A42845239845239845231845A42845239
8C634A8C634AA57B5AB58C73C69C84D6A58CE7BD9CEFC6ADEFCEB5F7D6BDF7D6BDEFD6C6F7D6BD\
F7DECEF7DECEF7D6BDF7DECEF7D6BDF7DECEF7D6BDEFD6C6F7D6BDF7DECEF7D6BD
EFD6C6EFD6C6F7D6BDF7D6BDF7D6BDF7D6BDEFD6C6F7D6BDF7D6BDF7C6B5F7CEB5F7CEB5EFC6AD\
EFC6ADEFC6ADEFB59CEFC6A5E7B59CE7B59CDEAD94DEAD8CDEAD8CDEAD8CD6A584
C69C84D69C7BB5846BA57B639C73529C73529C6B4A7B5A426B39215A3121391810391810422921\
391810946B52946B529C73529C6339C6946BC69C84D6A58CF7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7000000000000000000000000000000000000000000
000000000000000000000000000000000000000000F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7FFFFFF8C634A7B5A42845239734A31845231735242734A317B5A42
8C634A9C6B4AB58463B58C73D69C7BD6AD8CE7BD9CEFC6ADF7CEB5F7C6B5F7D6BDEFD6C6F7D6BD\
F7D6BDF7D6BDF7D6BDEFD6C6F7DECEF7DECEF7DECEF7DECEEFD6C6EFD6C6F7DECE
F7D6BDF7D6BDF7D6BDF7D6BDF7D6BDF7D6BDF7D6BDF7D6BDF7C6B5F7CEB5F7CEB5F7CEB5EFC6AD\
F7CEB5EFC6ADEFC6A5EFC6A5EFBD9CE7B59CDEAD94DEAD8CD6A58CDEAD8CD6A584
D6A584BD947BB5846BB5846BA57B638C634A8C5A426B39215A3121422118422118291008392118\
3918109C7B63946B529C6339946342C69C84CEB5A5DECEC6F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7CEB5B584634A845239845239845231845239845239735242
8452399C6B4AA57B63B58C73C69C84DEAD9CE7BDA5EFC6ADF7CEB5F7CEB5F7D6BDEFD6C6EFD6C6\
F7DECEEFD6C6F7DECEF7DECEF7DECEF7DECEF7DECEEFD6C6F7DECEF7D6BDEFD6C6
F7DECEEFD6C6F7D6BDEFD6C6F7D6BDF7D6BDF7D6BDF7D6BDF7CEB5F7D6BDF7CEB5F7C6B5EFCEAD\
EFC6ADEFC6ADEFC6A5EFC6A5E7B59CE7B59CDEAD9CDEAD8CDEAD8CD6A584D6A58C
CE946BCE946BBD8C63A57B63A57B5A9C73528C5A425A39295A3121422118422921311818422118\
422118A57B63B5846B8C5A42AD7352C6946BE7BD9CF7F7F7F7F7F7F7EFF7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7EFF78C6B52734A31734A317352427352428452397B5A42
735242946B52B58463BD947BD6A584DEAD94EFC6A5EFC6ADEFC6B5EFCEB5F7CEB5F7D6BDF7D6BD\
F7D6BDF7D6BDF7D6BDF7DECEF7D6BDF7DECEEFD6C6F7D6BDF7D6BDEFD6C6F7D6BD
EFD6C6EFD6C6F7D6BDF7D6BDF7D6BDEFD6C6F7D6BDF7D6BDF7CEB5F7CEB5EFCEADF7CEB5F7C6B5\
EFC6ADEFC6ADEFC6ADE7BDA5E7BDA5E7BD9CE7B594DEAD8CDEAD8CD6A58CD69C7B
D69C7BB58C73BD8C63A57B639C73528C634A8452395A39295A3121422921422118522918522918\
3918109C6B4AB584639C6B4AC6845AD6A584DECECEF7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7A57B638C6B52735242845A427B5A427352427B5A42
845A42946B529C7352C6946BD6AD8CE7BDA5E7BDA5EFC6ADF7CEB5F7CEB5F7D6BDF7D6BDF7D6BD\
EFD6C6EFD6C6F7DECEF7DECEEFD6C6F7D6BDF7D6BDEFD6C6EFD6C6EFD6C6EFD6C6
F7D6BDF7D6BDEFD6C6F7D6BDF7D6BDF7D6BDF7D6BDF7CEB5F7CEB5F7CEB5EFCEADEFCEADEFC6AD\
EFC6A5EFC6A5EFC6ADE7BDA5E7BD9CE7B594E7AD94DEAD8CDEAD8CDEA584DEA584
CE946BB58C73B5846BAD73529C6B4A8C5A42734A315A39295A3929522918422118522918391810\
291008946B529C73529C6B4ABD8C63DEAD8CEFEFE7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFCEB5B5A57B63946B52946B52946B527B5A42
7B5A42946B52A5846BB58C73D69C7BE7B59CEFC6A5EFC6ADEFC6ADF7CEB5EFCEB5F7CEB5EFD6C6\
EFD6C6EFD6C6EFD6C6F7D6BDF7D6BDEFD6C6F7DECEF7D6BDEFD6C6F7D6BDF7D6BD
F7D6BDF7D6BDF7CEB5F7D6BDF7CEB5F7CEB5F7CEB5F7CEB5F7D6BDF7C6B5F7CEB5EFC6A5EFC6A5\
EFC6A5EFC6A5EFB59CE7BDA5E7BD9CE7B594DEAD94E7B594D6A584D6A584D6A584
B58C73B58C73A57B63A57B5A8C634A845239734229734A315A31215A3121422118391810211008\
5A3929B5846B9C7352B5734ACE946BCEAD94F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000F7F7F7F7F7F7F7EFF7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFFFFFFFEFE7E794735A946B52845A428C634A
84634A8C634AAD7352BD947BC69C84DEAD94EFC6A5EFC6ADEFC6ADF7CEB5F7CEB5F7D6BDF7D6BD\
F7CEB5EFD6C6EFD6C6F7D6BDF7D6BDF7D6BDF7D6BDF7D6BDF7D6BDEFD6C6F7D6BD
F7D6BDF7D6BDF7D6BDF7D6BDF7CEB5F7CEB5F7CEB5F7D6BDF7CEB5EFC6ADEFC6ADEFC6ADEFC6AD\
EFC6A5EFC6ADEFBD9CE7B59CE7B59CE7B59CE7B594DEAD8CD69C7BD6A58CBD947B
BD947BBD8C63AD7352945A42845239845A427342295A39295A3929422921522918211818211008\
A57B5AA57B63946342B57B5AC68C63E7CEBDF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFBD9C9484523984634A735242
8C634A8C634AA57B5ABD8C63D69C7BDEAD9CE7BDA5EFB59CEFC6ADEFC6ADF7CEB5EFCEADEFCEAD\
F7CEB5F7CEB5F7D6BDF7D6BDF7D6BDF7CEB5F7D6BDF7D6BDF7D6BDF7CEB5F7D6BD
EFCEB5F7CEB5EFCEBDF7CEB5F7CEB5F7CEB5EFCEADEFC6ADEFC6ADEFC6ADEFC6ADEFC6A5EFC6AD\
EFC6A5EFC6A5EFB59CE7B59CE7B59CE7B59CDEAD94DEAD94D6A58CD69C7BD6A584
B58C73A57B639C6B4A9463428C5A42845A42845A425A31215A3121522918391810291008B5846B\
9C7B639C6B4A946342BD8C63D6B5A5EFE7E7F7F7F7F7EFF7F7EFF7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFDECEBD6B3921845A42A57B5A
7B5A42A57B5AA57B5ABD8C63C69C84DEAD94E7BD9CE7C6ADEFC6ADEFC6A5EFC6ADF7CEB5F7CEB5\
F7D6BDF7CEB5EFCEBDF7D6BDF7CEB5F7D6BDF7D6BDF7D6BDF7D6BDF7D6BDF7CEB5
F7CEB5F7D6BDF7CEB5EFC6ADF7CEB5EFC6ADF7CEB5EFC6ADEFC6ADEFC6A5EFC6ADEFC6ADEFC6A5\
EFC6A5E7BD9CEFBD9CE7B594E7B594DEAD9CDEAD8CCEAD94BD947BD69C7BCE946B
B5846BA57B639C73529C6B4A845A42734A31735242946B524221183918103921187B5A42845239\
A57B5A9C6B4AAD7352C6946BE7BDA5F7EFF7F7F7F7F7EFF7FFFFFFF7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFCEB5A59C7352845239845239
84634AA57B63A57B5ABD8C63D69C7BDEAD94DEAD9CE7BDA5EFC6ADEFC6A5EFC6ADF7C6B5EFC6AD\
F7D6BDEFCEADF7CEB5F7CEB5F7CEB5F7CEB5F7CEB5F7CEB5F7CEB5F7D6BDF7C6B5
F7C6B5EFC6ADEFC6ADEFC6ADEFB59CEFC6ADEFC6A5EFC6A5EFC6A5EFC6A5EFC6A5EFC6ADEFC6A5\
EFC6A5E7B594E7B594E7B59CDEAD94DEAD94DEAD8CD6A584BD947BBD947BB5846B
AD73529C7352946342845A42845A428452398452395A3929734A315A3929734A31734229A57B63\
9C7352B58463BD8C63D6AD8CD6BDADF7F7F7FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFC6A594C69C84734229845231
7B5A428C5A429C7352B58463BD947BC69C84D6B5A5E7B59CE7BDA5EFC6A5EFB59CF7C6B5F7C6B5\
EFCEB5EFCEB5EFC6B5EFC6ADF7C6B5F7CEB5F7CEB5F7D6BDEFC6B5EFCEB5EFC6AD
EFC6ADEFC6A5EFB59CE7B59CE7B59CEFB594EFC6A5EFC6A5EFBD9CEFB59CEFBD9CEFB594E7B59C\
E7B59CDEAD8CE7AD94DEAD94D6A58CD6A58CD69C7BBD947BBD947BB58C73B5846B
AD7352A57B5A9C6B4A735242735242734A31734A315A42397342295A3121A5846B946B529C7352\
9C6B4AD69C7BC6946BE7BD9CF7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7FFFFFF
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E7DEDEDEC6C65A3121734229
9C6B4A8452399C7352A5846BB58C73D6A58CDEAD94DEAD9CE7B59CEFB59CEFB59CEFC6A5EFC6AD\
E7C6ADEFC6ADEFCEB5EFC6ADEFC6ADEFC6ADEFC6B5EFC6ADEFC6A5EFC6ADEFC6AD
EFBD9CE7B59CE7AD8CE7AD94E7AD94E7B594EFB594E7AD8CE7AD8CE7AD8CE7AD8CDEA584DEAD8C\
E7AD94D6A584DEAD8CD6A584D6A584C69C84D69C73BD947BB5846BB58463B58463
A57B5A9C73528C5A42845A427B5A427352428C6B527B5A42734A318C6B52B5846B94735AA57B63\
BD8C63D6A584E7BD9CD6BDADF7EFF7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7C6A5949C7B6B7B5A42
845A42946B528C634A9C7352A57B63BD947BD6A58CE7BD9CDEAD9CD6B5A5E7B59CE7B59CEFC6AD\
EFC6ADEFC6ADEFC6ADE7C6ADE7BDA5E7BDA5E7BDA5E7BDA5E7B59CDEAD9CDEAD8C
DEAD94DEAD94D6A584D6A584D69C7BD69C7BD69C7BD69C73DE9C7BD69C7BD69C73D69C73BD947B\
CE946BCE946BCE946BCE946BC6846BB58C73BD947BB58C73B5846BB57B5A9C6B4A
8C634A94735A946B52735A4A946B52946B52734A318C634A9C6B4A9C6B4A9C73529C6B4ABD8C63\
B58463DEAD94E7BD9CF7EFE7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7BDADAD94735A
845A428C634A946B52A57B5AB5846BA57B6BB58C73BD947BDEAD94D6B5A5E7BDA5EFC6A5E7C6AD\
E7BDA5E7BDA5E7BDA5E7BD9CDEAD94DEAD94D6A584DEAD94E7BD9CD6A58CDEA584
D6A584D6A58CBD947BC69C84C6846BCE946BBD8C63D69C7BCE7363CE946BB57B5AB58C73B57B5A\
B57B5ABD8C63B58463B58463B5846BB5846BA57B63B58C73BD947BA5846BA58C73
A57B5AA57B638C634A8C634A94735AA57B63845A426B3921845239B57B5AB58463B57B5ABD8C63\
CEAD94D6B5A5D6BDADF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7FFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFE7E7
A58C7B94735A7B5A429C7352A57B5A8C634AB58C73C69C84D6BDADE7C6B5E7C6B5E7C6B5E7BDA5\
E7BDA5D6B5A5DEAD9CD6A584CEAD94D6A58CD6A58CD6A584D6A58CD6A584D6A584
C6946BC6946BB58C73B58C73B5846BB58C73B5846BAD7352B5846BB584639C73529C6B4AB5846B\
9C7352B584639C7352AD7352A57B63A57B5AA57B638C634A946B5294735AAD7352
94735A9C735294735A9C7352845239845A428C6B529C6B4A9C7352A57B5AA57B5AC6946BD6B5A5\
D6B5A5C69C84F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7EFF7F7F7F7F7F7F7F7F7F7000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
A58C7BA57B6BA57B639C7363A58C73C6A594CEA594BD9C8CDEAD9CCEA594DEAD9CD6BDADD6BDAD\
DEAD9CDEAD94D6A58CD6A584D6A58CBD947BC69C84D6A584C69C84C6946BC69C84
BD947BC6846BB58463B5846B9C7352BD947BA57B63BD947BB58463A57B63BD8C63A57B5A9C6B4A\
BD947BA57B5AB5846BA57B63A57B5AA5846BA58C7384634A946B52A57B5A9C7B63
8C6B5294735AA57B639463429C6B4A9463429C6B4A9463429C7352B58463D6AD84CEB5A5CEAD94\
D6AD8CE7CEC6F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
FFFFFF94735AA584739C7363946B52A5846BB58C73B58C73BD9C8CDEAD9CD6B5A5DEAD94CEAD94\
D6A58CD6AD8CC69C84C69C84C69C84B58C73BD947BB58C73BD947BB58C73BD947B
B5846BBD947BA57B5A9C7352A57B6B946342A5846BA57B5AB58C739C7352A57B63A57B5AA57B63\
C6946B8C634A9C73529C7352B5846BA57B5A946B52946B52845A427B5A42734A31
7352428C634A8452398452397B5A427B5A42946342B5734AC6946BD6AD84E7C6ADBD9C8CD6AD8C\
B58463F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7FFFFFFB5947BA57B6BA57B63BD9C94C69C84C6A594D6B5A5D6B5A5D6B5A5D6B5A5C69C84\
C69C84C69C84C69C84BD947BC69C84BD947BBD947BB5846BB5846BBD947BB58463
A57B5AA57B63946342A5846BA5846B8C634A734A31A57B63845A42B58463A57B5AA57B63A57B63\
8C5A429C6B4AA57B5A734229734A319C63398C5A42845A428C5A429C6339946342
9C6B4A9463429463428452399C63399C6B4ACEAD94BD947BD6AD8CD6BDAD8C634ABD9C8CA5846B\
DECECEFFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7C6A59CA5847384634A9C73639C6B4AA5846BC6A59CCEB5A5DEAD9CD6B5A5C6A594\
BD947BBD947BB58C73BD947BBD947BB58C73A5846BA58C73B58C73A57B63B58463
B584638C634AC6946BA57B5A8C634ABD947B8C634A845A42A57B638C634A8C634A946B52845A42\
8C5A428452317342298452398452399C63398452397B5A429463428C5A42845239
844A318C5A429C7352B58463B58463C69C84BD947BE7BD9CD6B5A5A5846BA57B5ABD9C8CA5846B\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7\
F7F7F7000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7FFFFFF735A4A9C7B6BBD9C8CA57B6BA5846BB5947BC6AD9CCEB5A5D6A58CC6A594\
A57B63B5846BA5846BBD947BBD947BB5846B9C7363B5846BB58463A57B63B58C73
A57B63B58463845A429C735294735A8C634AA57B5A845A428C634A946342845A4284634A845A42\
735242845239845239845239734A317342298452397B5A42845239845231845231
8C634AA57B5AA57B5AA57B5AA57B5AC69C84CEB5A59C7B639C7B63A5846BC6A594BD947BEFE7E7\
F7EFF7F7EFF7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7FFFFFF
F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F79C7B6B734A31B5947BB59C8CBD9C8CB5947BD6B5A5D6B5A5C6AD9C\
A57B5AB58C73A57B63A57B63B58463A57B5A94735AA5846BA5846B94735AA57B63
94735AA57B63845A42A57B5A9C6B4A946B52735242734A31A57B5A7352427B5A42845A427B5A42\
845231734A31734A316B39215A39297342297342297342298452319C6B4A845A42
8C634AA5846BC69C84BD947BE7BDA5CEB5A5BD9C8CA58C73946B52C69C84946B52EFE7E7FFFFFF\
FFFFFFF7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7EFF7F7F7F7FFFFFFA57B6B734229947363A58473B5947BCEB5A5D6BDADC6AD9C\
A57B5A946B52B5947BA57B63B58C73B5947BB58463946B52A5846BA57B5A8C634A
A57B63A57B638C634A9C7352A57B5A94735A8C6B525A3121734A317B5A42A57B5A845239845239\
6B39218452397342296B39215A31215A39295A31215A3121734A318C5A42A5846B
BD947BB5846BBD947BCEB5A5B5947B84634A947B6BB58463A5846B9C6B4AC6A59CF7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7DECECE7B6B5A7B5A4284634AA58C73BD9C8CC6AD9CD6B5A5\
A5846B946B52A57B5AB58C7394735A94735AA57B638C6B528C634A9C736394735A
8C6B52946B52A57B6394735A8C634AA57B5A9C73528C6B528C634A734A31734A3184634A845239\
8452398C5A428452319C6B4A845231845231945A319C6B4AAD7352A57B63BD8C63
C69C84DEC6B5B5947BBD9C8C9C7B6B734A3194735AA5846BB5947BB5947BF7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7D6BDB5947B6B8C735A84635284634AA58473A58C84\
D6B5A58C634A8C6B529C7B63B5846394735A946B52845A427B5A427B5A428C634A
8C634A946B5294735A8C634A8C634AA57B5AA5846B9C735294735A7B5A42A57B5A845239845231\
94735A946B528C634A9463429C6B4AA57B5AB58463C69C84B58C73BD947BD6B5A5
BD9C8CB59C8CA58C73A58C737B5A429C7363A58C73A5846BA57B6BFFFFFFF7F7F7FFFFFFFFFFFF\
F7F7F7F7EFF7FFFFFFF7EFF7FFFFFFF7F7F7F7EFF7F7F7F7FFFFFFF7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000F7F7F7F7F7F7
F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7BDADAD94735A9473639C7363A5846BA58C7B\
C69C84C6A5948C6B528C6B52A5846BA5846B946B52A5846B845239845A42845A42
9C6B4A946B529C7352845239A57B6B9C7352B58C73A57B63B5846BB5947B946B528C5A428C5A42\
9C73529C7352B58463B58463BD8C63BD8C63D6A584D6A584C6A594A57B639C7B6B
9C7B6B8C5A42734229845239A57B63A5846B9C7B63BD947BFFFFFFF7F7F7F7F7F7F7F7F7FFFFFF\
FFFFFFF7F7F7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000F7F7F7
F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7CEB5B5846352947363A58C73B5947B\
BD9C8CC6A594C6AD9C94735AA5846B8C634AA5847394735AA57B63946B52845239
7B5242734A318C634A7B5A429C73639C7352BD947BB58C73DEC6B5E7C6B5D6B5A5C69C84DEAD9C\
D6A58CD6A58CD6A58CE7C6ADE7C6ADDEAD94CEB5A5A58C738C6B529C7B63946B52
845A427B5A428C634AB58463B5947BA57B63A57B6BFFFFFFF7F7F7F7F7F7FFFFFFF7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7FFFFFFFFFFFFF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7EFEFF79C847B947363736352\
A58C73CEB5A5CEB5A5CEAD94A58473B58C73A58473A58C7BA57B6BBD947BC6A594
9C7B6B7B52428C6B527B524294735AB5947BC6A594BD9C8CA58C7BD6BDADD6BDB5D6BDADDEC6B5\
E7D6C6E7CEC6D6BDADC69C84B5947BB5947BA5847394736394735A946B52735242
84523994735A9C7B63BD947BA57B63B5947BF7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7EFF7\
F7EFF7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7FFFFFF9C7B6B846352\
9C8473A58C7BC6AD9CDEC6C6C6AD9CC6AD9CD6BDB5BDADADDECEBDD6BDB5C6A59C
E7CEC6EFD6C6F7EFE7EFE7DEEFD6C6E7CEC6E7CEBDD6BDADDECEBDDEC6B5DEC6B5DEC6B5E7CEBD\
CEB5A5A58C73C6A594A58C739C7B639C7B6B9C7B6B8C634A8C6B52735A4AA57B63
A58C73A5846BA5846BA57B63FFFFFFF7F7F7F7F7F7FFFFFFF7EFF7F7F7F7F7F7F7F7F7F7F7F7F7\
F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7
F7EFF7F7F7F7F7F7F7F7EFF7F7F7F7000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E7DEDE\
8463528C7363B5947BBDA59CD6BDB5DECEBDE7D6CEDECEC6DECEBDDECEBDDECEBD
E7D6CEDEC6B5E7C6B5E7CEBDE7C6B5EFD6C6EFDECEE7D6CEDECEBDE7CEC6CEB5A5BD9C94D6BDAD\
BD9C8CB59C8CBD9C948C735AA57B5A8C634A8C6B529C7B6BA58473BD9C8CC69C84
B58C73A5846BC6A59CF7F7F7F7F7F7F7EFF7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFF7F7F7FFFFFFFFFFFFF7F7F7FFFFFFF7F7F7F7F7F7FFFFFF\
EFE7E7A584739C8473A58C84CEB5A5CEB5A5D6BDB5D6C6B5DECEBDE7D6CEE7D6CE
E7D6CEE7D6CEEFE7DEE7DED6E7D6D6E7D6CEEFDECEE7CEC6DECEBDD6BDB5CEC6BDB59C8CA58C84\
BD9C949C7B639C7B6B94735AA58C73846352A58C7BBD9C8CC69C84B59C8CA58C7B
C69C84E7DEDEF7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7FFFFFFF7F7F7\
F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
FFFFFFF7F7F7F7F7F7000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7\
FFFFFFF7F7F7F7F7F7B5948C9C7B6BA58473CEB5B5DEC6C6E7D6CEE7D6CEE7D6C6
E7CEC6DEC6C6E7D6D6DECEC6DEC6C6D6BDB5C6AD9CBD9C8CB5947BC6A594C6AD9CB59C8CA58C7B\
846B52A57B6BB59C8CA58C7BC6AD9CC6AD9CCEB5A5C6AD9CA58C84C6AD9CF7EFF7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7\
F7F7F7FFFFFFF7F7F7FFFFFFF7F7F7F7F7F7F7F7F7F7EFF7F7F7F7FFFFFFF7F7F7
F7F7F7000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000F7F7F7F7F7F7F7EFF7FFFFFFF7F7F7F7F7F7\
FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7BD9C94B5948CC6B5B5CEB5B5D6BDB5
E7D6D6E7D6D6E7D6CEE7D6D6E7D6D6E7D6CED6BDB5D6BDB5C6A59CBDA59CB5948CCEB5A5DECEBD\
BD9C94D6BDB5DEC6C6D6BDB5BD9C94B5947BD6BDADEFE7E7FFFFFFFFFFFFFFFFFF
F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7FFFFFFF7F7F7F7F7F7BDADADBDA59CD6BDB5
C6A59CD6BDADDECEC6DECEC6E7DED6E7D6D6EFE7DEF7EFE7EFE7DEE7D6CEDECEBDE7D6CEDECEC6\
DECEBDC6A59CBD9C8CCEB5A5DECEBDEFE7E7F7F7F7F7F7F7FFFFFFFFFFFFF7EFF7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7\
F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000F7F7F7F7F7F7\
F7EFF7F7F7F7F7F7F7FFFFFFF7EFF7F7EFF7F7F7F7F7F7F7F7F7F7F7EFF7F7EFF7
F7EFF7EFE7E7EFE7E7E7DEDEF7EFE7EFE7DEDECEBDD6BDB5D6BDB5DECEBDDECEC6DEC6C6DEC6C6\
DECECEEFE7E7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFFFFFFFF7F7F7
FFFFFFFFFFFFFFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7EFF7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7FFFFFFF7EFF7000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7EFF7F7EFF7F7EFF7FFFFFFF7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFFFFFFFF7F7F7F7F7F7F7F7F7FFFFFFF7F7F7
F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7FFFFFFF7F7F7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7FFFFFF\
F7F7F7FFFFFFF7F7F7FFFFFFF7F7F7000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000F7F7F7F7EFF7FFFFFFF7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7EFF7
F7F7F7F7F7F7FFFFFFF7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7\
F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7FFFFFFF7F7F7
F7F7F7F7F7F7F7EFF7FFFFFFF7F7F7FFFFFFFFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7FFFFFF
F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7FFFFFFF7F7F7F7F7F7FFFFFFFFFFFF
F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7EFF7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7\
FFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000F7F7F7F7EFF7FFFFFFF7EFF7
F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7FFFFFFF7F7F7F7EFF7F7F7F7F7F7F7F7EFF7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFF
F7F7F7F7F7F7F7EFF7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7F7EFF7FFFFFFFFFFFF000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
F7F7F7FFFFFFF7EFF7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7FFFFFFF7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFF7F7F7F7F7F7FFFFFFF7EFF7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7FFFFFFF7F7F7F7EFF7F7EFF7F7F7F7F7F7F7FFFFFFF7EFF7F7F7F7
FFFFFFF7F7F7FFFFFF000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000F7F7F7000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[37]:=",
  ImageSize->{300, 150},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004/0000UR000`400?l00000o`00003oo`3oool]
0?ooo`00o`3oool]0?ooo`00o`3oool]0?ooo`00o`3oool]0?ooo`00o`3oool]0?ooo`00o`3oool]
0?ooo`00o`3oool]0?ooo`006@3ooom]000001l0ooooJ`00000L0?ooo`006@3ooom]000001l0oooo
J`00000L0?ooo`006@3ooom]000001l0ooooJ`00000L0?ooo`006@3oool/000000030<G5a@36a/H0
c/k>0080`l?300<0c/k>0<o?c`3?cll00P3?cll00`3GemL0clo?0<o?c`020=gMg@050=3@d03Bd]80
emOG0=;BdP3?cll0;@00000O0?ooob/0000000<0ikfL0>NmY@3_aZD00P3_]I`00`3_aZD0klJ]0>o6
[@020>o6[@030?O>]@3_aZd0klJ]0080mmJm00D0mlje0?O6]@3gc[D0mlJe0>o6[@0/000001`0oooo
000I0?ooobT000000`3?cll01`33`l<0`L710<71`@38b<P0c/k>0<K6aP3>c/h0103?cll01@3Bd]80
emOG0=OGe`3?cll0e]KF0080eMGE00D0emOG0=GEe@3GemL0e]KF0=GEe@0Z000001l0oooo:0000000
103_aZd0klJU0>o6[@3_]I`20>NeW0040>nmW03W]I`0ikfU0>o6Y@@0klJ]00@0mlJe0?O>]@3gc[D0
klJ]0`3_c[D01@3gc[D0klje0>o>]@3_c[d0klje02T00000703oool001T0oooo9@0000000`30`<00
c/k>0<o?c`030=CDe0040=OGe`3>c/h0c/k>0<71`@80b<S800D0`L710<G5a@36a/H0`l?30<k>cP02
0<o?c`030=CDe03?cll0clo?0080clo?00@0d=3@0<o?c`3?cll0eMGE0`3@d=030<o?cbH000007`3o
oolU000000030>NeU03_aZd0klj]00<0klj]0P3_aZD0203W]I`0kkfL0>NmW03W]I`0ikfL0>NmY@3_
]I`0klJU0P3_aZd00`3_cZd0klJ]0>o6[@020>o6[@040>o6]@3_aZd0klJ]0>o>]@<0klJe0P3_aZdV
000001`0oooo000I0?ooob<000000`30`<000`36a/H0c/k>0<o?c`020=CDe0090=OGe`3?cll0clo?
0<?3``31`L40`<300<71`@36a/H0`L710080`<300`36a/H01`3>c/h0a/K60<K6aP36a/H0c/k>0<K6
aP3>c/h00P3=cLd20<k>cPD0a/K69000000O0?ooob800000103W]I@00`3_aZD0klJ]0>o>[@020>o>
[@80klJ]00H0kkFL0>NeW03W]I@0ikFL0>NmY@3W]I`20>NeU0<0ikfU00T0klJU0>NmY@3__I`0ikfU
0>o6Y@3W_JD0klJU0>NmY@3WaZd00P3_aZD50>NmYB<00000703oool001T0oooo8@0000020<G5a@06
0<S8b03>c/h0b<S80<30`038b<P0c/k>0`3De=@01P3GemL0e=CD0<k>cP32`/80c/k>0<?3``80b<S8
0P36a/H01@30`<00^;Rh0;Rh^02h^;P0/[:b00<0^;Rh00<0/[:b0;Rh^02h^;P01P2h^;P01031`L40
aLG50<G5a@35aLDR000001l0oooo8@000000103W_I`0kkfL0>o6Y@3_aZD20>nmW00:0>o6Y@3_cZd0
klj]0>o>[@3gc[D0klj]0>o6Y@3_]I@0kkfL0>neW080kkfL0P3W_JD01@3W]I@0gZf<0=j]U03N[H`0
gZF400<0gZf<00<0gZF40=j]S03N[I@01@3N[I@0103W_I`0ikFL0>NmW03W_I`R000001`0oooo000I
0?oooal0000000T0aLG50;fm_@2m_Kd0^;Rh0<30`035aLD0b<S80<30`035aLD00P3>c/h00`3De=@0
emOG0=CDe0020<o?c`<0b<S800H0c/k>0<S8b03>c/h0c/k>0<S8b03>c/h20<S8b0030<G5a@31`L40
`L710080`L7100D0aLG50<71`@38b<P0aLG50<S8b0020<K6aP030<k>cP31`L40c/k>0080c/k>00<0
a/K60<k>cP0000007`00000O0?oooal0000000D0ikfL0=JeY@3N[I@0ikFD0>NmW0020>nmW0040>Nm
W03_aZD0klJU0?O>]@80klj]0P3_aZd30>nmW0060>o6Y@3__I`0klJU0>o6Y@3__I`0klJU0P3__I`2
0>NmW0<0ikFL00H0ikfL0>NeW03__I`0ikfL0>nmW03W_JD20>o6Y@050>NeW03_aZD0klJU0>NmY@3_
aZD08000000L0?ooo`006@3ooolL00000080];Bd00D0X:2P0<K6aP31`L40aLG50;Vi^@020<G5a@03
0<S8b035aLD0aLG50080c/k>0P3?cll0103De=@0c/k>0=CDe03>c/h20<S8b0L0c/k>00<0`l?30<S8
b038b<P00P3>c/h01035aLD0b<S80<K6aP38b<P20<k>cP040<?3``3>c/h0c/k>0<k>cP80b<S800<0
c/k>0<K6aP3>c/h00`3>c/hM000001l0oooo6`0000020=J]Q00:0<jDJ`3W_I`0ikfU0>NeW03N[I`0
ikfD0>NmW03W]I@0kkfL0>NmU0<0klJU00@0klJ]0>o>[@3_aZD0klj]0P3_aZD00`3__I`0klJU0>o6
Y@050>o6Y@030>neW03__I`0klJU0080klJU00@0ikfL0>nmW03_]I`0kkfL0P3_aZD0103_]I`0klJU
0>o6Y@3_aZD20>nmW0030>NmY@3_aZD0ikfL0080klJU7@00000L0?ooo`006@3ooolJ000000070<k>
cP2e]KD0X:2P0;Bd]02;Rh/0^KVi0<G5a@020<71`@050<G5a@31`L40`/;20<30`035aLD0103>c/h0
0`3De=@0c/k>0<k>cP060<k>cP040<o?c`3>c/h0c/k>0<k>cPD0b<S800<0c/k>0<G5a@33`l<00P38
b<P01P35aLD0a/K60<k>cP3?cll0c/k>0<?3``80c/k>0P38b<P20<k>cP<0a/K66`00000O0?oooaX0
000000d0ilJe0<jDH`3F[H@0aW]20:e[>@3N[I`0ikfL0>NeW03W_I`0ikFL0>NmW03_]I@0ikfL00@0
klJU00<0klj]0>o6Y@3_aZD01P3_aZD0103_aZd0klJU0>o6Y@3_aZD20>nmW0050>o6Y@3__I`0kkfL
0>o6Y@3W_I`00`3__I`00`3W_I`0ikfU0>o6[@020>o6Y@030>neW03_aZD0kkfL0080kkfL0P3_aZD2
0>NmYA/00000703oool001T0oooo6@000000303QhN40j>SX0=WIf@2JVYX0X:2P08^;R`1QHF40`L71
0;Vi^@35aLD0^;Rh0;Vi^@<0aLG5103>c/h00`3?cll0c/k>0<k>cP020<k>cP@0b<S8103>c/h40<S8
b0<0aLG50`38b<P01035aLD0b<S80<S8b03>c/h20<S8b080c/k>00H0b<S80<G5a@38b<P0b<S80<30
`035aLD20;Rh^1X000007`3ooolI0000000<0>oNcP3_imh0cXaJ0<jDH`36Nd80]F/i09AB:@3W]I`0
ikfL0=j]U03N[I`0ikFL0P3W_I`40>o6Y@030>o6[@3_aZD0klJU0080klJU103__I`40>o6Y@@0kkfL
0`3W_I`30>nmW0040>NmW03__I`0klJU0>NmW080kkfL00<0klJU0>nmW03W_I`00`3__I`00`3W_I`0
gZfD0=j]S00J000001`0oooo000I0?oooaP0000000X0k^k^0=[JfP3`l?00cLg=09ZJVP2<S8`0Rh^;
065QH@19BDT0/[:b0P2h^;P20<G5a@030<30`035aLD0a/K600<0c/k>00<0b<S80<k>cP3>c/h0103>
c/h01038b<P0c/k>0<S8b038b<P40<k>cP030<;2`P38b<P0b<S80080b<S800<0`l?30<G5a@32`/80
0P35aLD01@33`l<0c/k>0<k>cP38b<P0aLG50080c/k>00P0b<S80<G5a@30`<00`<300;Rh^02g]kL0
Z:RX08b<S1T000007`3ooolG0000000A0>o_i`3gknL0imK>0?O_i`3>S5X0aW]:0<Ik@P2eHc40U58Y
07/i603N[H`0gZfD0>NmW03W]I`0ikfL0>NmU03W_JD00`3_aZD00`3__I`0klJU0>o6Y@040>o6Y@04
0>nmW03_aZD0kkfL0>nmW0@0klJU00<0kkFD0>nmW03__I`00`3__I`02P3W_I`0kkFD0>NmU03W_I`0
klJU0>nmW03_aZD0kkfL0>NmW03_aZD20>nmW0040>NmW03W]I@0gZf<0=j]Q080eYac00<0aW]:0000
000000005P00000L0?ooo`006@3ooolG000000090?;blP3`l?00hN7Q0>SXj03>c/h0`/;208^;R`2C
Ti<0HF5Q0080BDU90P2h^;P01030`<00aLG50<G5a@30`<050<k>cP80b<S800<0c/k>0<S8b038b<P0
0P38b<P00`32`/80aLG50<k>cP020<k>cP<0b<S800<0`/;20<G5a@30`<000P38b<P00`32`/80aLG5
0;Zj^P020<G5a@D0b<S800<0aLG50;Ng]`2a/K40102XZ:P00`2CTi<0HF5Q08b<S00H000001l0oooo
5P0000002`3gkoL0mnoW0>o_i`3_g/h0knON0=Jm[@36Nd80aXAJ0;E[>@2DDRT0NcTH0080gZfD00@0
ikFD0=j]U03W_I`0ikFD1@3_aZD20>nmW080klJU0`3__I`00`3_]I@0ikfL0>o6Y@020>o6Y@80kkfL
00@0ikfL0>neU03W_I@0ikFD0P3__I`0103_]I@0ikfL0>N]S03W_I`50>nmW0040>NmU03N[H@0gZf4
0=jUN`<0eYac00@0aXAJ09aS>@2DDRT0aW]:5`00000L0?ooo`006@3ooolD00000080kno_00T0l?3`
0?;blP3`l?00j>SX0=?Cd`3QhN40VYZJ09>CT`2;Rh/00P1QHF401@1DE5@0?clo02DU9@2`/;00^;Rh
0080`<3000<0a/K60<G5a@38b<P00P38b<P00`3>c/h0b<S80<k>cP030<S8b0060<G5a@38b<P0b<S8
0<;2`P35aLD0`/;20P38b<P01`35aLD0`/;20<30`032`/80^[Zj0;Ng]`32`/800P2j^[X01P32`/80
^[Zj0<G5a@2j^[X0]kNg0<30`080^;Rh00`0]kNg0:VYZ@2KVi/0PX:207UiN@1cLg<0Kfm_09JFUP2P
X:00VYZJ09RHV02PX:0E000001l0oooo500000020>o_m`090?O_m`3gknL0knOW0>oWgP3Wc[d0cXaJ
0<J4FP36Nd80[EXa0080U58Y00P0Jc4H04XH203FYH@0gZfL0=j]U03W]I@0ikfU0>NmW0<0kkfL00<0
klJU0>nmW03_aZD00`3__I`01P3W_I`0kkfL0>nmW03_]I@0ikfD0>neU080kkfL00@0ikfD0>neU03W
]I@0kkFD0P3W[H`05P3_]I@0ijf<0>N]S03_]I@0ikfD0>NeU03W[H`0gZf40>NeU03N[H`0gZf40=jU
N`3FW7/0cXaS0:e[>@2]Hc40W6<i0:e[@P2mS6<0cYA[0<J<H`3>U6<E000001`0oooo000I0?oooa@0
00000`3bl_80203_knl0l?3`0>WYj@3IfMT0gmoO0:2PX02CTi<0S8b<0P1QHF401`1DE5@0=cLg03Lg
=`0U9BD0^;Rh0<G5a@31`L400P35aLD40<S8b080c/k>1P38b<P01P35aLD0b<S80<;2`P35aLD0`/;2
0<?3``<0`<300`2j^[X01`2g]kL0/K6a0;Ng]`2j^[X0]kNg0;6a/@2h^;P00P2g]kL03@2YZJT0/[:b
08b<S01^KVh0NGUi059BDP1jNWX0PX:20:2PX02JVYX0V9RH09jNWP2HV9P05@00000O0?oooa<00000
00`0moOg0?O_m`3gkoL0knog0?O_i`3gkoL0knOW0>OFaP3>U6<0aXAJ0<IkBP2]Hc4209AB:@80HbT@
00@0BQP80=j]U03N[I@0ikFL0P3W_I`40>nmW080klJU1P3__I`01@3W_I@0kkfL0>neU03W_I`0kkFD
00@0ikFD0`3W[H`05P3N[H@0gZEk0=j]Q03N[H@0ikfL0=jUN`3N[H`0gZf40=JLN`3NYH@0eYac0<Ik
BP2]FS40Q48Q0:e[@P2eLdX0aW]:0<jDH`3>S5X0aYA[0<J<H`3NYG<D000001`0oooo000I0?oooa<0
000001@0kno_0?;blP3gmoL0l_;b0>o_k`3`l?00j>SX0=oOg`3De=@0X:2P09>CT`1lO7`0Kfm_065Q
H@19BDT0=cLg02d];@0o?cl0^;Rh0<30`080aLG500@0a/K60<k>cP38b<P0c/k>1038b<P01`32`/80
b<S80<S8b035aLD0b<S80<G5a@32`/800P30`<00102j^[X0`<300<30`030`<020;Zj^P090;Ng]`2a
/K40/K6a0;6a/@2g]kL0aLG50;Ng]`2XZ:P0ZJVY0080Zj^[0P2KVi/01`2<S8`0Fe]K06i^KP1_Kfl0
NGUi06m_K`2JVYX00P2CTi<00`2HV9P0Z:RX0;Bd]00D000001l0oooo4P0000020>o_m`0@0?O_m`3g
moL0knog0?O_i`3_knL0knON0>ONeP3>U6<0aXAJ0;E[@P2]Hc40W6<i09AB:@1S:A00DR4@06/a6080
gZfD0P3W_I`0103W_JD0ikfL0>o6Y@3_aZD40>nmW0070>neU03__I`0kkfL0>NmU03__I`0ikfL0>ne
U0020>NeU0040>N]S03W]I@0ikFD0>NeU080ijf<00@0gZF40=jUN`3NYG/0gZEk0P3N[H@0103FW7/0
eYac0=JLN`3NW7<20<j<H`0:0<Ik@P36NdX0S4Xa09aS>@2]JcT0W6<i0<IkBP3>S5X0aXAJ0<J<H`80
eYac00<0eZf40000000000004@00000L0?ooo`006@3ooolB00000080kno_00h0moOg0?;blP3gmoL0
l?3`0?;blP3Zj^X0fMWI0;Bd]02PX:00Ti>C08:2PP1kNg/0HF5Q05YJFP80?clo00L0Cdm?0;Vi^@35
aLD0aLG50<k>cP35aLD0c/k>00D0b<S800H0aLG50<S8b035aLD0`<300<?3``38b<P20<;2`P060<G5
a@2j^[X0aLG50;Ng]`35aLD0`<300P2j^[X0402b/[80X:2P0:RXZ02h^;P0aLG50;Rh^02KVi/0Z:RX
0:2PX02XZ:P0X:2P08b<S02;Rh/0Lg=c08b<S01jNWX208b<S00809JFUP2PX:00V9RH09ZJVP2HV9P0
Z:RX0:2PX02XZ:PC000001l0oooo4@0000020>o_m`80moOg00`0mnog0?O_i`3gkoL0knoW0?OWgP3W
e/H0cYAS0<J4FP2eLdX0[EXa0;E[>@2DDRT206/a600507]28@1kBRT0gZfL0>NmW03_aZD00P3W_I`0
0`3_aZD0kkfL0>nmW0040>nmW0040>NmW03W]I@0kkFL0>nmW080kkFD00H0ikfD0>N]S03W_I@0ikFD
0>NmU03W]I@20>N]S00>0=jUQ03>U6/0eYac0=j]S03W_I`0cXaS0<jDJ`3FW7<0cYA[0=JLL`36NdX0
aW]20;ES<@2]Hc430<IkBP030;f<H`3>U6<0cYA[0080aXaS00@0eYac0<j<FP3>U6/0eYac4P00000L
0?ooo`006@3ooolA0000000;0>o_k`3gmoL0kno_0?Ogm`3`l?00l_;b0?3`l03^k^h0jNWY0=3@d02d
];@00P2CTi<05P1lO7`0NGUi05YJFP1JFUX0BDU9059BDP1DE5@0^;Rh0<G5a@36a/H0c/k>0<G5a@38
b<P0`/;20<G5a@38b<P0`/;20<G5a@38b<P0aLG50<;2`P35aLD20<;2`P<0`<3000P0aLG50;Ng]`32
`/80^[Zj0;Rh^02g]kL0/[:b0:b/[080Z:RX0P35aLD04P2KVi/0X:2P0:RXZ02KVi/0R8R807inOP1_
Kfl0Rh^;07=cL`1iNGT0Rh^;08b<S01lO7`0Ti>C0:2PX02JVYX0Ti>C08:2PP80];Bd00<0X:2P0<G5
a@0000004@00000O0?oooa40000000@0moOg0>o_m`3gkoL0moOg0P3gknL0103_knL0knON0>oWi`3N
c[d20<J4FP0;0;E[@P2eLdX0[F/i08a::@1k>AP0Q48Q08a28@1S:A00gZfD0>NmY@3_aZD00P3W_I`0
2@3__I`0ikfD0>nmW03_]I@0ikfD0>nmW03W_I@0kkFD0>NmU0020>neU0<0ikFD00P0ikfD0=j]Q03N
[H@0ijf<0=j]S03N[H@0gZF40<jDJ`80eYac00<0ikfD0>NmW03>U6/00P3FW7<02P3>S6<0]G]J09aS
>@36Nd80]F/i0:eS<@2]JcT0aW]:0;E[@P36Q5X20<jDH`060<j<FP2eLdX0eZf40<jDH`3F[H@0cYA[
4P00000L0?ooo`006@3oool?00000080l_;b0P3gmoL00`3bl_80kno_0?Ogm`020?Ogm`0B0>o_k`3J
f]X0];Bd0:RXZ02FUYH0R8R807alO01JFUX0DU9B065QH@1VIVH0FUYJ04E5A@36a/H0`L710<k>cP36
a/H0`<300P35aLD01@38b<P0`/;20<?3``35aLD0^[Zj0080`/;20`2j^[X04`32`/80]kNg0;Zj^P2h
^;P0]kNg0;Zj^P2b/[80/K6a0:VYZ@2XZ:P0UIFE0:2PX02XZ:P0X:2P09>CT`2DU9@0Ti>C08R8R01_
Kfl00P1fMWH02`1iNGT0VYZJ08^;R`1kNg/0NGUi09JFUP2<S8`0Ti>C09ZJVP2NWYh0];Bd0080Z:RX
0`2PX:000`2XZ:P0aLG50000000?000001l0oooo3`0000020?O_m`040?Ogm`3gkoL0moOg0>o_m`80
moOg01P0knog0>oWgP3We/h0eZf40;f<H`2eNeX0]F]20:e[@P2<BRT0Q48Q09AJ<@2<BRT0JcTQ06/a
603W_JD0klJU0>NmY@3W]I@0kkfL0>NmW03__I`0kkFD0>neW03W_I@30>neU0<0ijf<00h0kkFD0=j]
Q03W[H`0gZf<0=j]Q03NYG/0gZF40=jUN`3FW7/0eYac0<j<H`3>U6<0eYac0<jDJ`<0aXAJ00h0]G]J
09aS>@2LJdX0[F/i0<j<FP36NdX0aW]20;E[>@2mS6<0aW]:0<J4FP2mS6<0cXaJ0<JDJ`80eYac00D0
aYA[0<jDJ`3>U6/0eYac0>NmU00@000001`0oooo000I0?ooo`h0000000D0l_;b0?Ogm`3gmoL0l_;b
0?Ogm`040?;blP0<0?3`l03_knl0fMWI0;Fe]@2PX:00Ti>C08:2PP1jNWX0IVIV065QH@1iNGT0HF5Q
0P0o?cl01P36a/H0`L710<G5a@2h^;P0aLG50<S8b080^[Zj00D0`/;20<30`02j^[X0^[Zj0;Ng]`02
0;Zj^P80]kNg00<0/[:b0;Zj^P2b/[800`2b/[806@2a/K40Z:RX0:RXZ02PX:00VYZJ0:VYZ@2HV9P0
R8R807inOP2<S8`0PX:206i^KP22PX80Ng]k07UiN@1jNWX0S8b<09>CT`22PX80S8b<08R8R02<S8`0
UYJF09RHV02NWYh00`2d];@0102PX:00];Bd0:2PX02XZ:P20<G5a@l000007`3oool>000000040?O_
m`3gmoL0moOg0?Ogm`@0mnog00X0mnoW0>o_m`3_imh0imK60=J]S036Q5X0]G=:0:e[@P2]JcT0U5Xa
0P2DDRT206/a600506<Y403W_JD0ikfL0=j]U03W_I`00P3__I`00`3W[H`0kkFD0>NeU0020>N]S003
0=j]Q03W[H`0ijf<0080gZf400<0gZF40>N]S03NYH@00P3NYH@20=jUN`80eYac01H0cYA[0<J4H`3F
W7/0aXaS0;EkFP2eJe80]G=:0;EkFP2DHd80]G=:09acDP2]Jd80aW]:0<j<FP36Q5X0]G=:0;EkFP36
NdX0_HaS0;EcBP36S6<0aYA[0P3F[H@01P3>U6<0cYA[0=J]Q03FW7<0ikfD0>NmW0l00000703oool0
01T0oooo3P0000030?Ogm`060?;blP3gmoL0l_;b0?Ogm`3`l?00kno_0P3gmoL03036a/H0Z:RX0:RX
Z02FUYH0PX:207YjNP1JFUX0Kfm_065QH@1BDU80=cLg04E5A@D0aLG500D0b<S80<G5a@2j^[X0`/;2
0;Zj^P020;Ng]`040;:b/P2g]kL0/[:b0;Ng]`80/[:b00@0^;Rh0;Ng]`2a/K40[:b/0`2YZJT01`2X
Z:P0X:2P09>CT`2KVi/0R8R807inOP22PX800P1jNWX207IfMP03065QH@1_Kfl0O7al0080VYZJ00<0
X:2P08b<S02<S8`00P22PX802@2NWYh0Ti>C0;2`/02d];@0ZJVY0;Bd]02h^;P0Z:RX0;Ng]`020<G5
a@l000007`3oool>000000@0moOg0P3gkoL02@3gmoL0mnoW0?Ogm`3gmoL0knON0>NmY@3FW7<0_HaS
0;EcBP020:e[@P0608a::@2LHcT0Q48Q06<Y401[>B40HbT@103W_I`02`3W]I@0kkfL0>N]S03_]I@0
ijf<0=j]Q03W[H`0gZF40=j]Q03NYH@0gZf40080gZF400D0gZf<0=j]Q03NYG/0gYak0=jUN`020=JL
N`090=JLL`3>U6/0cYA[0<j<H`2eNeX0]F]B0;EcBP2]Jd80U5Xa0080W6]:00<0U58Y0;E[@P3>S5X0
0P3>S5X03@3>U6/0aW]:0;EcBP2eLdX0_HaS0<JDJ`36Q5X0eZf40=JLN`36U6/0eZf40=j]S03N[H@0
0P3W_I@?000001`0oooo000I0?ooo`h000000P3gmoL00`3bl_80moOg0?Ogm`020?;blP0G0>k^kP3g
moL0l_;b0?3`l02d];@0Z:RX09RHV02CTi<0Kfm_07IfMP1OGel0Kfm_05mOG`1?Cdl0ADE504m?C`36
a/H0^KVi0<G5a@30`<00aLG50;Zj^P35aLD00`2j^[X0202g]kL0/[:b0;:b/P2[Zj/0[:b/0;6a/@2/
[:`0/[:b0P2a/K400`2XZ:P0Zj^[0:RXZ0020:RXZ080Vi^K0P2CTi<01P22PX80NWYj07EeM@1eMGD0
KVi^07IfMP80IVIV00L0Kfm_07]kN`2;Rh/0Ti>C09ZJVP2CTi<0UYJF0080PX:200/0Ti>C0:RXZ02Y
ZJT0Z:RX0;Fe]@2d];@0X:2P0:RXZ02g]kL0aLG50<k>cP0?000001l0oooo3@0000030?Ogm`070?O_
m`3gmoL0mnog0>o_i`3gkoL0knoW0?O_m`020?O_i`0A0<j]U03FW7<0aXAJ09aS>@2LJdX0U5Xa09a:
<@2LHcT0Nd8Q06/i8@1k@R40Jc4H0>NmY@3W_I`0ikFD0>NmW03W]I@0103W[H`0203N[H@0gZF40=jU
Q03NW7<0gYak0=jUN`3NW7/0gZF40P3NYG/00`3FW7<0gYac0=JLL`020=JLL`80cXaS00P0cYA[0<J4
FP2eLdX0[F]20:eS@P2DHd80[F]209a[BP80U5Xa00H0]F/i0<Ik@P3>S5X0aXAJ0<j<FP2mS6<20;Ec
BP040;E[@P36Q5X0eYac0=JLL`80eZf<00H0eZf40<jDJ`3N[H@0ikfL0>O6]@3_g/h>000001`0oooo
000I0?ooo`d0000000D0moOg0?;blP3`l?00kno_0?Ogm`020?;blP0;0?Ogm`3bl_80moOg0>k^kP3`
l?00]KFe0:RXZ02CTi<0R8R807YjNP22PX800P1_Kfl02@1VIVH0>c/k03Lg=`0o?cl0aLG50;Rh^031
`L40^;Rh0<30`0030;Zj^P040;:b/P2g]kL0/K6a0;6a/@80[:b/00<0Zj^[0:2PX02PX:000P2XZ:P0
0`2/[:`0Z:RX0:RXZ0020:2PX080Vi^K00H0U9BD09JFUP1jNWX0NGUi06m_K`1eMGD207YjNP80Kfm_
00P0Lg=c07]kN`1lO7`0Rh^;0;2`/02XZ:P0]kNg09RHV080NGUi00<0V9RH09>CT`2XZ:P00P2d];@3
0:2PX0040<G5a@3=cLd0c/k>0>SXj0h000007`3oool<000000050?Ogm`3gkoL0mnog0?O_i`3_koL0
0P3gkoL20?Ogm`0:0?O_m`3_knL0mnoW0>OFaP3F[H`0eYac0;EkFP2]Jd80]G=:09AB:@80W6<i00L0
FS4Q06<Y401[<AP0JcTQ0>NmW03W]I`0gZfD0080ikFD0P3W[H`00`3NYH@0gZf40=jUN`030=jLN`03
0=jLL`3>U6/0cYA[0080eYac00<0gYak0=JLL`3FW7<00P3>U6/20<j<H`070<J4H`2eLdX0[F]20:e[
>@2LHcT0[F=20:e[@P0309aS>@070:eS<@2eJd80aW]20<j<FP3NYG<0eYac0<J<H`020:e[>@030;Ec
BP36S6<0aXAJ00<0eZf40P3>U6<01@3W_I@0ilJ]0>O6]@3Wg]H0knON00d00000703oool001T0oooo
30000000103bl_80moOg0?Ogm`3`l?040?Ogm`030?;blP3_knl0l_;b0080l?3`00T0];Bd09jNWP2F
UYH0PX:206m_K`1fMWH0NGUi05YJFP1BDU800P0c<c<0200o?cl0aLG50;Rh^030`<00`L710<30`02j
^[X0/[:b102a/K400`2YZJT0Z:RX0:^[Z`020:RXZ0<0X:2P0P2XZ:P20:2PX080U9BD00L0Ti>C08R8
R02CTi<0Kfm_06IVIP1jNWX0Kfm_0080NWYj00<0Cdm?05YJFP1fMWH00`2;Rh/02@2PX:00Z:RX0:2P
X02d];@0UYJF08:2PP2CTi<0X:2P09>CT`020;Fe]@<0X:2P00<0aLG50<g=c@3Xj>P00P3Xj>P=0000
01l0oooo30000000103gmoL0mnog0?Ogm`3gknL40?Ogm`0=0?O_m`3_koL0mnoW0?O_i`3W_JD0eZf4
0<JDJ`2eLdX0W6<i09a[BP2DFS40[F/i08a::@02058Y6080Jc4H00@0ikfL0>NeU03W]I`0ikFD0P3W
[H`40=jUN`030=jLL`3FW7<0gYac0080eYac0`3>U6/20=JLL`80cYA[0P36Q6<02036Q5X0]G]J0;E[
@P2LHcT0U5Xa0:e[@P2LHcT0[F]20P1k@R402P2<BRT0]F<a0<Ik@P36Nd80aXAJ0<jDH`3FW7<0eZf4
0;f<H`2eLdX20<J4FP0;0<jDJ`3F[H`0eZf<0<jDJ`3>U6<0cYA[0>NmU03WaZd0knON0>ONeP3_imh0
3@00000L0?ooo`006@3oool;000000<0moOg00<0l?3`0?;blP3_knl00P3gmoL01`3bl_80moOg0>o_
k`3bl_80k^k^0<k>cP2UYJD00P28R8P0101fMWH0MGEe06m_K`1VIVH204E5A@0303lo?`15ADD0ADE5
00<0^;Rh00@0a/K60;^k^`2f][H0^k^k0P2f][H01`2h^;P0/[:b0:VYZ@2KVi/0Ti>C09^KV`2=SHd0
0`2CTi<209^KV`80Ti>C0P28R8P02`1nOWh0PX:209>CT`1EEED0Kfm_07YjNP1JFUX0Cdm?04U9B@1Q
HF40KVi^0080Rh^;00X0PX:208^;R`2PX:00Z:RX0;Bd]02PX:00WYjN09>CT`2HV9P0UYJF0P2d];@2
0:2PX080];Bd00H0bl_;0?3`l03Kfm/0k^k^0>WYj@3gmoL<000001l0oooo2`0000020?Ogm`060>o_
m`3gknL0mnog0>o_m`3gmoL0mnog0P3gmoL02@3_koL0knoW0>O6]@3F[H`0aYb40;EkFP2LJdX0[F=2
09aS>@0209AJ<@0306/i8@1[<AP0JcTQ0080JcTQ0P3N[I@00`3W_JD0ijfD0>N]U0030>NUU0070=j]
S03NYH@0gZF40<j<H`36Q5X0cXaS0<IkFP030<J4FP80cXaS0P36Q5X20;EkFP0D0;E[DP2eLdX0W6<i
07]::@2LHcT0[F]208a::@1k>AP0NdXY09AB:@2]FS40aW]20;EcBP36Nd80[F/i0<jDH`3FW7<0cYA[
0<JDJ`36Q5X20<J<H`0<0;f<H`3F[H@0cYAS0=JLL`3>U6<0eZf40=k6]@3gknL0kmK60>ONeP3_knL0
moOg3000000L0?ooo`006@3oool:000000070?Ogm`3_knl0moOg0?;blP3`l?00l_;b0?3`l0020?Og
m`0?0?;blP3_knl0kno_0>o_k`3Xj>P0bl_;09jNWP28R8P0PX:207YjNP1_Kfl0PX:206IVIP0];Bd0
CDe=0080ADE500<0?clo0;Rh^03=cLd00`3?cll02@3>c/h0`l?30<?3``33`l<0_;bl0;^k^`2h^;P0
/[:b0:VYZ@0208f=S@0308b<S02=SHd0R8R80080R8R800@0Ti>C08f=S@2<S8`0PX:20P1jNWX05@2<
S8`0Fe]K06m_K`1VIVH0DU9B03lo?`15ADD0DU9B06m_K`2<S8`0Rh^;08:2PP1iNGT0VYZJ0:VYZ@2g
]kL0^;Rh0;Bd]02NWYh0R8R807alO0020;Bd]00509jNWP2d];@0];Bd0<G5a@3^k^h00P3Xj>P0103^
k^h0l?3`0?;blP3gmoL;000001l0oooo2P000000203gmoL0knog0?O_m`3gmoL0mnoW0?O_m`3gknL0
moOg0P3gkoL20>o_m`0;0>oWgP3Na[D0eZf40<JDJ`2eNeX0[F]209aS>@2eLdX0W4Xa09AJ<@1B8A00
0P1[>B400`1[<AP0Q58a0=j]U0030>o6[@80klJU0P3_]I`01@3W[I`0ijfD0>N]U03NYH@0eYak0080
aW]J00<0aW]:0<IkFP2eNeX00P2eNeX01036Q5X0]G]J0<IkBP2eLdX20:e[@P0A08a::@2<BS40W6<i
08aJ@P24@R40JcTQ0:eS<@24@R40W6<i0<IkBP2eLdX0[F/i0;EcBP3>S5X0eYak0=j]S03F[H@00P36
U6/01@2eNeX0]F]20=J]Q036U6/0cYA[0080eZf400L0knoW0>oWgP3_imh0knON0>o_i`3gkoL0moOg
00/00000703oool001T0oooo2P0000000`3gmoL0l_;b0?Ogm`030?Ogm`050>k^kP3gmoL0l_;b0?Og
m`3_knl00P3bl_804@3Cdm<0_Kfm09RHV028R8P0P82006IVIP1_Kfl0IVIV059BDP0g=cL0Cdm?04e=
C@15ADD0?clo0<o?c`3@d=00gMgM0080d];B00@0clo?0=;BdP3?cll0clo?0P33`l<01`2k^k/0^;Rh
0;:b/P2/[:`0X:2P08b<S028R8P00P2<S8`0702=SHd0OWin08R8R028R8P0PX:207YjNP1^KVh0PX:2
06m_K`22PX80DU9B04U9B@0o?cl0De=C05ADE01_Kfl0O7al08b<S01kNg/0NGUi09>CT`2JVYX0]kNg
0;Rh^02d];@0Z:RX08:2PP2FUYH30:RXZ00:0<G5a@2XZ:P0aLG50>k^kP3QhN40fMWI0>WYj@3gmoL0
l_;b0?Ogm`/000007`3oool:000000040?Ogm`3gkoL0moOg0?O_m`80moOg01L0knoW0?O_m`3gmoL0
mnoW0>o_m`3gkoL0iljm0=JeY@3FW7<0aXaS0;EkFP2DFS40W6<i09AJ<@2LHcT0Q48Q06<Y401c@RT0
JcTQ06/a602eQ6<0klJ]0?OF_@020?O6]@@0klJ]0P3_]I`01`3W]I`0gZf<0=jUQ03NW7/0cYA[0<Ik
BP2eNeX00P36NdX07036NeX0]F]B0<IkBP2eNeX0]G=:0:e[@P2DHd80U5Xa09aS>@2eLdX0Q48Q07/i
601cBS40]F/i08a28@2LHcT0]F]20;E[>@2]JcT0]G=:0<J4FP3>S5X0gZf<0=J]Q03FW7<0aYA[0;Ec
BP2mS6<30=JLL`090>NmU03FW7<0knoW0>oNcP3We/H0mnON0>oWi`3gkoL0moOg00/00000703oool0
01T0oooo2@0000001P3gmoL0l_;b0?3`l03gmoL0l_;b0?Ogm`80l_;b00@0moOg0?;blP3_knl0l?3`
0P3bl_80103Cdm<0];Bd09JFUP20P80207YjNP0506m_K`1VIVH0=cLg04E5A@1EEED00P15ADD01@2E
UID0emOG0=gMg@3GemL0gMgM0080d];B00/0emOG0=;BdP3?cll0c/k>0<o?c`33`l<0^k^k0;Zj^P2b
/[80/K6a0:RXZ00408:2PP0I08b<S022PX80PX:207EeM@1fMWH0GUiN059BDP1VIVH0Ti>C04U9B@0o
?cl0;Bd]03Lg=`1lO7`0HF5Q07alO02JVYX0NGUi09JFUP2CTi<0Z:RX0;Ng]`35aLD0a/K60;Fe]@02
09JFUP0:0:2PX02HV9P0Z:RX0;Bd]02a/K40jNWY0>7Qh@3Fe]H0j>SX0?;blP80moOg00<0l?3`0?Og
m`0000002@00000O0?ooo`T0000000<0moOg0?O_m`3gknL00P3gkoL0103gmoL0mnog0?O_m`3gkoL2
0>o_m`0<0?O_i`3gkoL0iljm0<j]U036U6/0_HaS0:ecDP2]Jd80W6<i09AJ<@2LHcT0HbT@0`1[>B40
1`2eS7<0klJe0?O>]@3gc[D0mmJm0?O6]@3ge[d00P3ga[D02@3_aZd0klJU0>o6[@3_]I`0ijfD0>N]
S03NYH@0gZEk0=JLL`040;EcBP0I0<IkBP2eNeX0]G=:0:eS@P2LJdX0Q58i0;EcBP2DFS40aXAJ07/i
601[<AP0HbT@0:e[>@2eJd80U58Y0;E[@P2]JcT0_HaS0;EcBP36Q5X0eYac0>NmU03W_JD0eZf<0;E[
@P020;f<H`0=0<J<H`3FW7<0eZf<0=J]Q03NYG/0kmk>0>o>_@3_imh0mnoW0?O_m`3gmoL0mnoW0?Og
m`0:000001`0oooo000I0?ooo`P000000`3gmoL00`3`l?00l_;b0?Ogm`030?;blP<0moOg00P0kno_
0>WYj@3IfMT0cLg=0:FUY@28R8P0MWIf06IVIP80Kfm_00H0IVIV03Lg=`1EEED0EEEE04E5A@3>c/h2
0=OGe`80gMgM00<0fm_K0=gMg@3Bd]800P3Bd]801@3GemL0clo?0<k>cP3>c/h0aLG50080^;Rh00@0
^[Zj0;:b/P2PX:00OWin0P1jNWX04P22PX80NWYj07YjNP1eMGD0Kfm_059BDP1?Cdl0DU9B09^KV`1_
Kfl0ADE505=CD`0];Bd0S8b<05ADE01lO7`0S8b<07]kN`80Ti>C00L0X:2P0:RXZ035aLD0a/K60;Bd
]028R8P0UYJF0080WYjN0P2d];@02@35aLD0gmoO0=[JfP3Ogml0k^k^0?Ogm`3`l?00moOg0?;blP02
0?Ogm`T000007`3oool8000000<0moOg00<0mnoW0?Ogm`3gkoL00`3gkoL30?Ogm`070>o_m`3_inL0
ilJ]0<JLQ036U6/0]G]J09a[BP0209aS>@0=09AJ<@24BRT0HbT@07]::@1[>B40ilJe0?O>]@3_cZd0
mlje0?OF_@3_e/H0mmJm0>oFaP020?O6]@0;0?O>]@3_aZd0klJU0>o6Y@3W_I`0gZfD0=j]S03W[H`0
gZF40<jDJ`2eJe800P2]Jd804@2eLdX0]F]B0:e[@P2]Hd80W6<i08A28@36Q5X0Q48Q0<j<H`2LHcT0
JcTQ058Q4024@R40aW]:08a28@2eJd80]F/i00<0aXAJ00h0cYAS0>NmW03W_JD0eZf40<J<H`2eNeX0
_HaS0<JDJ`3F[H@0eZf<0=J]Q03W_I@0imK>0>ONeP80knoW0P3gmoL00`3gkoL0moOg0?Ogm`090000
01`0oooo000I0?ooo`P0000000P0moOg0?;blP3bl_80l_;b0?3`l03gmoL0l_;b0?3`l080moOg0180
k^k^0?Ogm`3^k^h0gmoO0=3@d02d];@0WIfM08:2PP1fMWH0GUiN06IVIP1JFUX0IVIV04E5A@1=CDd0
IVIV0<o?c`3@d=030=OGe`050=gMg@3Bd]80gMgM0=;BdP3MgMd00P3Bd]80103?cll0c/k>0<o?c`3>
c/h20<71`@0]0<30`02h^;P0/[:b0:VYZ@2PX:00UIFE06m_K`1eMGD0J6QX06m_K`1GEeL0EEEE03Lg
=`2YZJT0FUYJ0:2PX01^KVh0NWYj03lo?`1KFe/0UYJF07=cL`2;Rh/0S8b<09JFUP2NWYh0R8R80;Bd
]02PX:00a/K60=GEe@22PX80UYJF09RHV02UYJD0Z:RX0;Fe]@35aLD0gmoO0>SXj03YjNT0l?3`0?;b
lP3gmoL0l_;b0080moOg00<0l_;b0000000000001`00000O0?ooo`L0000000<0mnog0?Ogm`3gkoL0
0P3gkoL05`3gmoL0mnog0?O_m`3gknL0moOg0>o_i`3gmoL0knog0>o_i`3Wg]H0cZfD0;fDN`2mS6<0
]G=:09a[BP2DFS40S4XY09AJ<@1B:AP0JcTQ07=2:@3_aZd0klJe00<0mlje00<0mmJm0?O6]@3ge[d0
103ga[D0103_aZd0klJU0>o6[@3_aZD20>NeW00Z0>NeU03N[I@0gZF40=JLN`3>U6/0aXA[09aS>@2]
Hd80U5Y209aS>@24BRT0NdXY09a[BP3FW7/0S4XY0<jDJ`2DHd80Jc4H0:eS<@2<BS40_HaS0:eS<@36
NdX0_HaS0;F4H`36U6/0]G]J0<jDH`3W_JD0klje0;f<H`2eLdX0_HaS0<JLQ03FW7<0eZf40=J]S03W
_I@0knON0>oWi`3gknL0knoW0P3gkoL20?Ogm`80mnog2000000L0?ooo`006@3oool800000080moOg
0P3bl_800`3gmoL0l_;b0?Ogm`040?Ogm`080?;blP3YjNT0dm?C0=3@d02UYJD0V9RH08:2PP1^KVh2
06IVIP0705eMG@15ADD0EeMG06=SH`3@d=00clo?0=CDe0020=OGe`030=;BdP3De=@0clo?00<0clo?
00H0c/k>0<?3``33`l<0a/K60<G5a@38b<P20<71`@070;Rh^02j^[X0^;Rh0;:b/P2XZ:P0X:2P09^K
V`0206m_K`0?05]KF`1JFUX0ADE504E5A@2FUYH0R8R807IfMP2UYJD0E5AD08R8R01eMGD0O7al08b<
S01iNGT0S8b<00<0UYJF0P2XZ:P03P2d];@0^;Rh09JFUP1lO7`0UYJF0:FUY@2NWYh0aLG50=[JfP3^
k^h0gmoO0>k^kP3`l?00moOg0P3bl_800`3gmoL0l_;b0?Ogm`09000001l0oooo1`0000030?Ogm`<0
mnog1@3gmoL04@3gkoL0knOW0>oWi`3Wc[d0aYb40<J<H`2]Le80]G=:09AS@P2DFS40Q58a06/i8@1[
<AP0Q4XY08AJ@P3_aZd0klj]00<0mlje00<0klj]0>o6[@3_aZd00P3_aZd01P3_aZD0kkFL0>neW03W
_JD0klJU0>nmW080ikFL01D0gZf<0>N]S03N[H`0gZF40=JLL`3>U6/0cXaS09a:<@2LHcT0S4Xa08a:
:@1[>B40Q58i0;f<H`2eNeX0W6]:0<JLQ02eNeX0U5Xa0:eS@P2eJd800P36NdX05`2mS6<0W6<i0;f<
H`2mS6<0eYac0<j]U03N[H`0ikfD0;f<H`2eJd80aYb40<JDJ`3F[H@0ikfD0>OFcP3Wg]H0knoW0?O_
i`3_knL0moOg0?O_m`3gmoL0mnog0080moOg2000000L0?ooo`006@3oool7000000<0l_;b0P3gmoL0
103bl_80moOg0?3`l03_knl20?;blP80moOg00H0f][J0=?Cd`2j^[X0WIfM08R8R01^KVh306IVIP03
03/k>`15ADD0?clo0080d=3@00P0emOG0=CDe03?cll0d];B0<o?c`38b<P0`L710;^k^`<0^;Rh00@0
/[:b0;Rh^02h^;P0^;Rh0`30`<00:P31`L40`<300;Rh^02b/[80[:b/0:VYZ@2XZ:P0Vi^K06IVIP1M
GEd0F5QH04e=C@15ADD0KVi^0:2PX02FUYH0Ph>30:RXZ02<S8`0DU9B07UiN@2CTi<0Rh^;08b<S01i
NGT0R8R80:VYZ@2NWYh0Z:RX0;Bd]036a/H0UYJF09jNWP2YZJT0WYjN09RHV035aLD0l?3`0=oOg`3b
l_80k^k^0?3`l080moOg00<0l_;b0?Ogm`3_knl00P3bl_88000001l0oooo1`0000030?O_m`<0moOg
00@0mnog0?O_i`3_koL0mnog0P3gmoL01`3_inL0imK>0>O>_@2mU7/0]G]J0:ecDP2DHd800P2DFS40
1`1J<B40JcTQ06/a601[<AP0klJe0?O>]@3_cZd00P3_aZd00`3ga[D0kkfL0>NeW0020>N]U080gZf<
00@0gZF40=j]S03N[H`0gZf<0`3W]I@0603W]I`0ikFD0=j]S03NYH@0gYak0=JLN`3FW7<0]F]B09AJ
<@24DS40Q4Xa07=2:@1cBS40U6=20<jDJ`2mS6<0YG]J0<IkBP2eNeX0Q48Q0:e[>@36Q5X0aW]:0:e[
>@80]G]J00H0eYak0=JLL`3F[H@0ikfU0>O6]@2mS6<20<JDJ`0>0<J<H`3>[I@0ikfL0?O_i`3gkoL0
knoW0?O_i`3_knL0moOg0?O_m`3gmoL0knog0?O_m`3gmoL8000001`0oooo000I0?ooo`L0000000<0
moOg0?;blP3gmoL0103gmoL20?;blP80moOg0P3bl_80303IfMT0d=3@0;Fe]@2NWYh0PX:207EeM@1K
Fe/0IVIV05eMG@0o?cl0ADE50<k>cP80eMGE00P0emOG0=CDe03?cll0c/k>0<K6aP2k^k/0^[Zj0;:b
/PD0YJFU0P2b/[802@2h^;P0/[:b0<30`030`<00`L710;Rh^02b/[80/;2`0:VYZ@020:2PX00F06IV
IP1CDe<0EEEE04E5A@0c<c<0K6a/0:2PX020P800IVIV0;2`/02<S8`0R8R806m_K`1jNWX0VYZJ08b<
S022PX80R8R80:RXZ02NWYh0];Bd0:RXZ080];Bd00D0Z:RX0:FUY@2UYJD0Z:RX0<K6aP020>SXj004
0?3`l03^k^h0l_;b0?;blP80moOg00@0kno_0?Ogm`3gmoL0l_;b2000000O0?ooo`L0000000<0moOg
0?O_m`3gmoL00`3gmoL30?O_m`070?Ogm`3gkoL0mnog0>oWi`3We/H0g/jm0<JDJ`020;EcBP0:0:eS
@P2<BS40Q58a06/a601[>B40Q4XY0>O6]@3_c[D0mlje0>o>[@80klJ]00D0klJU0>N]U03W[H`0gZF4
0=jLN`040>N<N`040=jUQ03NW7/0gZf<0=jUQ080ikFD00X0ikFL0=j]S03NYH@0eZF40=JLN`3>U6/0
aXAS08aJ@P24@RT0NdXY0P1[>B40802<HdX0cYA[0:ecDP2DFS40aW]:0<jDH`2eNeX0W6<i0:e[@P36
NdX0]G=:0;f<H`2eNeX0eYac0=J]Q03FW7<0eZf40>O6[@3F[H@0eYac0<JLQ03FW7<0eZf<0>NmY@3_
imh0mnoW0>o_i`3gkoL0moOg0?O_m`3gmoL0knog0`3gmoL8000001`0oooo000I0?ooo`L0000000<0
moOg0?;blP3gmoL0103gmoL03P3bl_80l?3`0?3`l03gmoL0l_;b0>k^kP3Cdm<0dM7A0:FUY@28R8P0
P82007EeM@1NGUh0EeMG0P15ADD00`19BDT0d=3@0=3@d0040<o?c`030<?3``2ATI40QXJ60080UYJF
102MWId308J6QP030:VYZ@2h^;P0^;Rh0080`<300P2h^;P0:`2b/[80ZJVY0:VYZ@2PX:00Ti>C05EE
E@15ADD0?clo02d];@1NGUh0P8200:VYZ@2?Shl0UIFE0;Bd]02XZ:P0WYjN08b<S022PX80Ti>C09JF
UP22PX80UYJF0:RXZ02FUYH0]kNg0;Fe]@36a/H0YJFU0;Bd]02NWYh0Z:RX0=3@d03Jf]X0jNWY0>k^
kP3YjNT0k^k^0?Ogm`3_knl0l_;b0?Ogm`3bl_800P3gmoL8000001l0oooo1`0000000`3gmoL0mnog
0?Ogm`040?Ogm`0=0?O_m`3gknL0mnoW0?O_m`3_knL0imK>0>O>_@3Nc/H0]G]J0:ecDP2LHcT0[F=2
08AB>@0206/i8@0407/i601kBRT0klJe0>o6]@<0klJ]00<0klJU0>neW03>JeX00P3NNf/40=j4L`<0
cV]J00<0eYak0=j]S03N[H`00P3W]I@00`3N[I@0gZf<0=jUQ0020=JLN`040<J4J`36Q5X0NdXY06/i
8@80Jc4H00d0Q58i0:ecDP3FW7/0]HAS0=J]Q03>U6<0eYac0<JDJ`36NdX0aXAJ0;f<H`2]JcT0]G=:
0080_HaS0180gZf40=J]S03W_I@0ikfU0<JLQ036U6/0eYac0>NmU03Nc[d0imK>0>o_i`3_inL0knoW
0?O_i`3gmoL0mnog0?Ogm`3gkoL20?Ogm`P00000703oool001T0oooo1P0000020?Ogm`070?;blP3g
moL0moOg0?;blP3`l?00moOg0?;blP020?Ogm`0?0?3`l03gmoL0jNWY0=WIf@2e]KD0WYjN08>3P`1f
MWH0IVIV05EEE@1NGUh0CDe=04E5A@1EEED0d=3@0080clo?00<0c/k>0=CDe03?cll00`2MWId01@3@
d=00`l?30:FUY@2f][H0`l?30080WIfM00@0UYJF08b<S026QXH0ZJVY0P2h^;P02P30`<00^;Rh0;Rh
^02h^;P0/;2`0:VYZ@2PX:00U9BD08R8R01CDe<203<c<`0G05iNGP0c<c<0/;2`0;Rh^01_Kfl0]KFe
0;6a/@2d];@0UYJF09>CT`2PX:00Lg=c08R8R02FUYH0WYjN0:2PX02YZJT0]KFe0<k>cP2MWId0Shn?
09jNWP2XZ:P00P3Xj>P20>k^kP030>SXj03gmoL0kno_0080l_;b00D0moOg0?;blP3gmoL0l_;b0?Og
m`07000001l0oooo1P0000020?Ogm`040?O_m`3gmoL0moOg0?O_m`80moOg01L0mnog0?Ogm`3gmoL0
moOg0>oWi`3Wg]H0imK60=J]S02UNeX0W6]:09aS>@2DFS40NdXY07=2:@1[>B40NdXY0>o>_@3_a[D0
klJ]0>o6Y@3_cZd0klJ]0>N<N`020=j4L`050>o6]@3_]I`0ihak0>N<N`3_]I`00P3NQ7<0203NNf/0
aXA[0<i[FP3FW7/0gZf<0=j]U03W]I@0gZfD0P3N[H`07`3FYH@0eYak0=j4L`36Q6<0]G]J07=:<@1B
:AP0DR4@08AB>@1B:AP0eZF40=j]S03F[H`0]G]J0=jUN`3F[H@0_HaS0<jDH`2]Hc40aXAJ0;EkFP2m
S6<0cYA[0=JLN`3F[H`0ikfU0>O6]@2mU7/0aYA[0=JLL`3>[I@00P3_imh02`3_knL0knON0?Ogm`3g
moL0knog0?O_m`3gmoL0mnog0?Ogm`3gkoL0moOg00L00000703oool001T0oooo1@000000103gmoL0
l_;b0?;blP3gmoL30?;blP80moOg00<0l_;b0?Ogm`3bl_800P3bl_803@3Jf]X0Z:RX09jNWP20P800
KVi^05]KF`1GEeL0?clo04m?C`0o?cl0IVIV0=KFeP3EeMD00P3?cll04`3>c/h0YJFU09fMW@1OGel0
I6AT071`L020P800L71`07QhN01/K6`0GemO04m?C`1JFUX0I6AT061PH01JFUX0De=C06QXJ02MWId0
0P30`<030;Rh^0<0ZJVY00h0U9BD08R8R01VIVH09BDU04E5A@1CDe<0Hf=S09JFUP2`/;00IVIV08R8
R02YZJT0aLG50=CDe080X:2P01D0Ti>C08R8R02FUYH0V9RH08R8R02d];@0a/K60<;2`P2XZ:P0];Bd
0:FUY@3Ogml0k^k^0>SXj03^k^h0l_;b0>k^kP3gmoL0l_;b0?Ogm`3bl_801@3gmoL6000001l0oooo
1@000000103gmoL0mnog0?O_m`3gmoL30?O_m`040?Ogm`3gkoL0mnog0?Ogm`80mnog00P0imK>0=K6
]@3FW7<0aYA[09AS@P2<BS40U5Xa08A::@80Jc4H00`0U5Xa0>o>_@3_c[d0klje0>o6[@3_aZD0ihak
0=j4L`2]Le80W4Xa0;eB@P2]Le820;eB@P0:0<IJBP2LBS40W34Q09a2:@2]BS40S34Q09a2:@24@RT0
U5Y20=j4L`80ikFD0`3N[H`0403FW7/0eYac0=JLN`36Q6<0]G]J08aJ@P0i6100JcTQ07=:<@24FT80
_HaS09AJ<@3FYH@0]G]J0=JLN`3W_I`20<jDJ`0=0;E[>@36Q5X0]G]J0<J<H`2eNeX0eZf40>NmU03W
_JD0e[f]0=J]Q036W8@0e[FU0>ONeP020>o_i`030?O_m`3_knL0moOg0080moOg00<0mnog0?Ogm`3g
moL00`3gmoL6000001`0oooo000I0?ooo`D0000000L0l_;b0?Ogm`3bl_80l_;b0?Ogm`3bl_80moOg
00@0l_;b00T0l?3`0?;blP3YjNT0f][J09fMW@28R8P0KVi^05]KF`1VIVH00`1EEED03`1CDe<0e]KF
0=KFeP3EeMD0emOG0<o?c`3>c/h0`l?30<k>cP2<S8`0QXJ607emO@26QXH0OGem09JFUP0507emO@03
0:RXZ02`/;00/;2`0080^;Rh01@0`<300;Zj^P2j^[X0^;Rh0;Zj^P2b/[80ZJVY0:RXZ02PX:00U9BD
07]kN`11@D408B4Q0451@@1SHf<0Ng]k0:VYZ@2NWYh0Z:RX08R8R080aLG500@0eMGE0820P02CTi<0
R8R80P2FUYH01`28R8P0];Bd0<K6aP3=cLd0WYjN0;Bd]02XZ:P00P3YjNT20>SXj0<0l_;b103gmoL0
103bl_80moOg0?;blP3gmoL6000001l0oooo1@0000001`3gkoL0moOg0?Ogm`3gkoL0moOg0?O_m`3g
moL0103gkoL02@3gknL0knOW0>OFcP3F_Jd0_IAk0;EkFP2<BS40S5Y208a::@0207]::@0@08A2:@3_
c[d0kljm0>o6]@3_c[D0mlje0>o6Y@3_]I`0klJU0>N<N`3>Lf<0aV=:0<i[FP36HdX0cV]J0=ikJ`D0
aV=:00D0eZF40=JUS03N[H`0gZf<0>NeU0020>N]S0080=j]S03W[H`0gZF40=JLN`3FW7<0cYA[0<J4
H`2LLe8203TH400:05Xi:@24FT80W7=B0<JDJ`2LJdX0eYac0;EkFP3W_I`0klje0:ecDP80aXAJ00<0
]G]J0;f<H`2eNeX00P3F[H@01@3W_JD0ilJ]0=J]Q03FW7<0imK60080knOW00<0knON0?O_m`3gkoL0
0P3gkoL30?Ogm`040?O_m`3gmoL0mnog0?Ogm`H00000703oool001T0oooo1@0000020?Ogm`80l_;b
1P3gmoL01P3bl_80k^k^0?3`l03Xj>P0dM7A08n?S`80MWIf01P0IVIV05YJFP1=CDd0EEEE059BDP1M
GEd0eMGE0<o?c`3De=@0clo?0=CDe03>c/h0e=CD0=OGe`3MgMd0fm_K0=3@d03?cll0gMgM0<k>cP3G
emL0gMgM0=3@d03?cll20<K6aP040<71`@30`<00`<300<71`@80`<3000<0^k^k0;Rh^02h^;P00P2b
/[803P2XZ:P0X:2P0:2PX028R8P0GEeM01HF5P1SHf<0De=C06=SH`1kNg/0UYJF09>CT`1jNWX0Ti>C
0P35aLD02@2XZ:P0UYJF08:2PP22PX80UYJF0:2PX02XZ:P0a/K60<g=c@020:FUY@0509RHV03Xj>P0
j>SX0>WYj@3Xj>P00P3gmoL00`3bl_80moOg0?Ogm`030?Ogm`030?;blP3gmoL0l_;b00H000007`3o
ool5000000<0moOg00<0mnog0?Ogm`3gmoL00P3gmoL05P3gknL0moOg0?O_m`3_knL0knON0=k>aP3F
[H`0]HAS09a[BP2<FT80S4XY08A::@1c@RT0NdXY08AB<@3_c[D0klJ]0>o>]@3_cZd0klJ]0>o6Y@3_
cZd20?O>]@0:0?OF_@3_a[D0klJ]0?OF_@3_aZd0klJU0?OF_@3_a[D0klJ]0>NmY@80ikFL0P3W]I@0
103W]I`0ikFD0>NeU03W[I@20=j]S0030=jUQ03FW7/0eYac0080cYA[01T0]G]J048a:@0Y40P0Q5Y2
07=:<@24FT80_HaS09aS>@36Q5X0[F]20<J4FP3W_I`0eYac0<jDJ`2mS6<0]G=:0;f<H`3>U6/0eYac
0<jDJ`3W_JD0ilJ]0<JLQ036S6<0imkF00<0knON0`3gmoL00`3gkoL0moOg0?Ogm`040?Ogm`030?O_
m`000000000000@00000703oool001T0oooo100000001P3gmoL0l_;b0?Ogm`3gmoL0l_;b0?Ogm`80
l_;b0P3gmoL0203`l?00l_;b0?;blP3YjNT0bl_;0<G5a@20P800KVi^0P1MGEd01@1HF5P0EEEE05EE
E@1?Cdl0_Kfm0080eMGE00/0d];B0=OGe`3?cll0emOG0<o?c`3GemL0gMgM0=OGe`3MgMd0emOG0=gM
g@030<o?c`<0`L7100L0aLG50<71`@35aLD0c/k>0<71`@30`<00`L710080^k^k00@0^;Rh0;:b/P2b
/[80WIfM0P2PX:003P28R8P0J6QX02TY:@1CDe<0GEeM08^;R`1kNg/0YJFU06IVIP2HV9P0UYJF0;Rh
^035aLD0c/k>0P2CTi<03@2HV9P0PX:208R8R028R8P0a/K60<g=c@2XZ:P0]KFe09jNWP3YjNT0gmoO
0>SXj03`l?000P3gmoL00`3bl_80moOg0?Ogm`030?;blP@0moOg1@00000O0?ooo`@0000000H0moOg
0?O_m`3gmoL0moOg0?O_m`3gmoL20?O_m`030?Ogm`3gkoL0mnoW0080mnog00P0g/Je0>NmW036W8@0
[G=B09AS@P24DS40Q4Xa06/a6080NdXY00D0e[FU0>o>]@3_c[D0klje0?O6]@020?O>]@030>o6[@3g
c[D0mlje0080mmJm00<0mlje0?OF_@3_aZD00P3_aZd50>NeW0050>NmW03_aZD0ikFL0>NeU03W]I`0
0P3W[I@0103N[H`0gZF40=JLN`3NQ7<20<jDJ`0>0;EkFP1B8A00@R4H07=:<@24DS40YHA[0<JLQ02L
HcT0U5Xa0<J<H`2mS6<0ikfL0>o6Y@3F[H@20<J4FP0<0;EcBP2eNeX0]G]J0<jDJ`3W_JD0ilJ]0=J]
S036U6/0knON0>oWi`3Wg]H0mnoW0`3gmoL00`3gkoL0moOg0?O_m`020?O_m`@0moOg1@00000L0?oo
o`006@3oool4000000030?;blP3gmoL0l?3`00<0moOg00H0l_;b0?Ogm`3bl_80moOg0?;blP3`l?02
0?;blP070=7Ad@2UYJD0Kfm_07IfMP1GEeL0F5QH04E5A@0305EEE@80eMGE00H0d=3@0=OGe`3Bd]80
d];B0=OGe`3EeMD50=OGe`0=0=GEe@3>c/h0c/k>0<k>cP31`L40aLG50<S8b036a/H0`L710<k>cP31
`L40c/k>0<71`@020;^k^`050<30`02h^;P0/[:b0:b/[02XZ:P00P2PX:001`2DU9@0MWIf0451@@0Q
8B40FUYJ05iNGP1^KVh00P1_Kfl00`28R8P0Ph>30:2PX0020<G5a@0;0:RXZ02CTi<0UYJF08:2PP2F
UYH0PX:20;Bd]036a/H0];Bd09jNWP2YZJT00P3Xj>P01`3IfMT0moOg0?;blP3gmoL0l_;b0?Ogm`3b
l_800`3gmoL0103bl_80moOg0?Ogm`3gmoL5000001l0oooo100000000`3gkoL0moOg0?O_i`030?Og
m`030?O_m`3gmoL0moOg0080mnog00T0mnoW0?O_m`3Nc/H0aYb40;EkFP2LHcT0W6]:08A:<@1[>B40
0`1kBRT20>o>]@060>o6]@3_c[D0mlje0?O6]@3gc[D0klje1@3gc[D01`3_c[D0klJ]0>o6Y@3_aZD0
ikFL0>NmW03__I`00P3W]I`0103_aZD0ikFL0>o6Y@3W]I`20>N]U0050>NeU03N[H`0gZF40=jUQ03F
W7<00P3>U6/02`36Q6<0Ld8Y05Xi:@0i6100Le9208AB>@2LHcT0[G=B09aS>@2eNeX0YG]J0080ikfD
00`0cYA[0=JLL`36Q5X0]G=:0;f<H`2eLdX0eYac0=J]Q03W_JD0aYA[0=JLN`3We/h20>oWgP040?Og
m`3gkoL0moOg0?Ogm`80mnog1`3gmoL5000001`0oooo000I0?ooo`@00000203gmoL20?;blP80moOg
00L0jNWY0<_;b`2][Jd0WIfM06m_K`1^KVh0De=C00<0EEEE00<0ADE508n?S`3>c/h00P3@d=030=OG
e`030=gMg@3GemL0eMGE0080emOG0P3?cll02`31`L40/[:b0;^k^`2h^;P0/[:b0;Rh^02k^k/0`L71
0<S8b036a/H0c/k>0080clo?00@0`l?30<71`@2k^k/0^;Rh0P2b/[807P2YZJT0Z:RX0:2PX02=SHd0
OWin0451@@15ADD0B4Q806=SH`1NGUh0Ng]k08:2PP1MGEd0Kfm_05iNGP2e]KD0aLG50;6a/@2HV9P0
WYjN08>3P`28R8P0UYJF0:RXZ035aLD0_Kfm09jNWP3Ogml0l_;b0>WYj@D0moOg00<0l_;b0?Ogm`3g
moL00`3gmoL20?;blP030?Ogm`000000000000<000007`3oool4000000<0moOg00<0mnog0?Ogm`3g
moL00P3gmoL20?O_m`80moOg00H0knOW0<JUU02mU7/0W6]:09aS>@2DHd8207]::@0407=:<@1kBRT0
JcTQ0>O6]@80klJe0`3gc[D00`3ge[d0mlje0>o>]@020?O>]@80klJ]00/0ikFL0=j]S03NYH@0gZfD
0=jUQ03N[H`0ijfD0>NeU03__I`0ikfU0>o6Y@020>o6[@050>neW03W]I`0ijfD0=j]S03NYH@00P3F
W7/07@3FW7<0cYA[0<IkFP2<FT80FSTY06/i8@1J@ST0Q5Y209acDP2DHd80]G=:08AB<@2LHcT0eZf<
0>NmU03FW7<0gZEk0<J<H`2UNeX0]G]J0;f<H`36W8@0eYac0>NmW036U6/0imkF0>NmY@3gkoL0knOW
00X0moOg0P3gkoL00`3gmoL0000000000003000001`0oooo000I0?ooo`<000000P3gmoL00`3bl_80
moOg0?;blP020?Ogm`030?;blP3gmoL0moOg0080moOg0P3bl_800`35aLD0WIfM0820P00205]KF`06
05EEE@15ADD0ADE505EEE@0o?cl0c/k>0P3@d=000`3Bd]80emOG0=OGe`030=OGe`070=CDe03GemL0
emOG0<o?c`33`l<0_;bl0:b/[0020;:b/P070:VYZ@2`/;00^;Rh0<30`031`L40b<S80<?3``020<k>
cP0B0<?3``3>c/h0`/;20;^k^`2h^;P0/[:b0:VYZ@2XZ:P0UIFE09BDU028R8P0@D5101HF5P0_;bl0
De=C05eMG@1fMWH0PX:20P1_Kfl01@1EEED0/;2`09>CT`3De=@0WYjN0080V9RH00@0R8R809FEU@2N
WYh0aLG50P32`/800`3@d=00f][J0=CDe0050?Ogm`030?;blP3gmoL0moOg00L0moOg1000000O0?oo
o`<000000P3gmoL00`3gkoL0moOg0?O_m`020?Ogm`050?O_m`3gmoL0moOg0?O_i`3gmoL00P3gkoL0
0`2mU7/0[G=B09AS@P0208a:<@80JcTQ0P1kBRT0101[<AP0klJe0>o6]@3ga[D50?O>]@0;0>o>[@3g
c[D0mlje0>o6[@3_]I`0ijfL0>NeU03NW7/0gZF40=JLN`3FYH@00P3N[H`00`3W]I`0kkfL0>neW002
0>o6Y@050>neW03_aZD0kkFD0>N]U03N[H`00P3FW7/02`3FW7<0aXA[0<J4H`2DFT80FSTY02T@2012
:B40LdXa09a[BP24DST0]G=:0080W6<i00d0eZF40<J4FP3FW7<0klj]0<JDJ`36S6<0]G]J0;F<L`36
Q5X0aYA[0>NmW03F_Jd0g/jm0080imK>00<0ilk60?Ogm`3gmoL0303gmoL4000001`0oooo000I0?oo
o`<000000`3gmoL0103bl_80moOg0?Ogm`3bl_860?Ogm`0=0>WYj@2e]KD0Shn?06i^KP1KFe/0ADE5
05EEE@1=CDd0EEEE03lo?`0k>c/0d=3@0<g=c@020<o?c`030=;BdP3MgMd0gMgM00<0emOG00<0fm_K
0:b/[02FUYH00P3?cll0202f][H0MgMg07MgM`2EUID0[:b/08R8R02h^;P0`L710P3>c/h20<o?c`0A
0<k>cP33`l<0`L710;^k^`2j^[X0/[:b0:VYZ@2XZ:P0X:2P09BDU01nOWh0CDe=024Q8@0_;bl0>c/k
05=CD`1NGUh00P1fMWH0401MGEd0MWIf06IVIP2FUYH0Z:RX0;Ng]`2CTi<0UYJF06m_K`28R8P0Z:RX
0<G5a@32`/80jNWY0;Bd]02m_Kd@0?Ogm`@000007`3oool3000000<0moOg00@0mnog0?Ogm`3gmoL0
mnog1P3gmoL0303_inL0]HAS09AS@P24DS40S4Xa06/i8@1c@RT0NdXY08A2:@1[<AP0FS4Q0>O6[@80
klJ]00<0mlje0?O6]@3ge[d00`3gc[D00`3ga[D0kmK60=ikJ`020>o6[@080>neW03WYI@0]F=20<J4
J`3NW7/0]G]J0=JLL`3W]I`20>o6Y@80klJ]0140klJU0>neW03W]I`0ijfD0>N]S03NYH@0eYak0=JL
L`3>U6/0aXAS0:eS@P1c@RT0>AP@048Y8@1J<B40Q58i08AJ@P0209a[BP0808AB<@2<FT80_HaS0=j]
Q03FW7<0gZf40;f<H`2LHcT20;EkFP060=JLL`3W_I@0knOW0<j]U03_inL0e[FU3`3gmoL4000001`0
oooo000I0?ooo`<0000000<0l_;b0?Ogm`3gmoL00P3gmoL00`3bl_80moOg0?;blP040?Ogm`050?;b
lP3Ph>00WYjN0820P01^KVh00P1EEED02015ADD0Cdm?05EEE@0k>c/0GUiN0=3@d03?cll0eMGE0P3G
emL0203Bd]80gMgM0=;BdP3GemL0e=CD0=gMg@3EeMD0d=3@0P3Bd]802030`<00^;Rh0;Rh^02j^[X0
`<300;:b/P2YZJT0`L71103?cll01`33`l<0c/k>0<k>cP32`/80^[Zj0;Rh^02YZJT00P2PX:005P2D
U9@0SHf=06IVIP0F5QH08B4Q02l_;`18B4P0FUYJ05iNGP1kNg/0GEeM06IVIP0c<c<0];Bd0:2PX035
aLD0R8R809JFUP1fMWH0P82009jNWP2d];@20<_;b`040;:b/P3gmoL0moOg0?;blP@0moOg00<0l_;b
0?Ogm`3gmoL01`3gmoL4000001l0oooo0`000000103gkoL0moOg0?Ogm`3gmoL20?O_m`030?Ogm`3g
koL0moOg00<0moOg00D0mnog0>ONgP2]Le80U6=209aS>@0207]::@0:07]28@1kBRT0JcTQ05Xa8@24
DST0klJ]0>o>]@3gc[D0mmJm0?O>]@80mlJe00D0mlje0>o>[@3gc[D0mmJm0>o6]@020?O6]@080>o6
[@3W]I@0gZfD0>N]S03W]I@0gZF40<j<H`3W]I`40>o6[@070>neW03_aZD0klJU0>neU03W[H`0gZF4
0=JLN`020<jDJ`0I0<J4H`2LLe80S5Y202T@200i6100@RTQ07=B@P2<FT80Q58i09acDP24DS40DRTH
0=J]Q03>S6<0cYAS0>NmW02mS6<0W6]:0:ecDP2mS6<0aYA[0<j]U03Na[D0aZfL0=JeY@0;0?Ogm`03
0?O_m`3gmoL0moOg0080moOg1000000L0?ooo`006@3oool300000080moOg00@0l_;b0?Ogm`3gmoL0
l_;b103gmoL03`3`l?00moOg0?Ogm`3Jf]X0UYJF06i^KP1XJ6P0De=C05QHF01=CDd0EEEE05QHF00g
=cL0Q8B40<g=c@030=;BdP<0gMgM00D0fm_K0=OGe`3GemL0gMgM0=3@d0030=_Kf`040<k>cP30`<00
_;bl0;bl_080^;Rh00D0/[:b0<?3``3?cll0clo?0=;BdP020<o?c`<0`l?300<0`<300;Zj^P2/[:`0
0P2MWId05P2DU9@0R8R806i^KP0F5QH0:BTY024Q8@1CDe<0GUiN04e=C@1fMWH0GEeM06IVIP0k>c/0
WYjN0;Bd]035aLD0R8R809JFUP20P800R8R809fMW@2e]KD20<_;b`040<;2`P3gmoL0moOg0?;blPH0
moOg00<0l_;b0?Ogm`3gmoL01@3gmoL4000001l0oooo0`0000020?Ogm`040?O_m`3gmoL0mnog0?O_
m`<0moOg00`0mnoW0?Ogm`3gmoL0moOg0>OFcP2DHd80U5Y206/i8@1cBS40Q4Xa07]::@24BS4206<Y
40050:EkH`3ga[D0mlJe0?O6]@3_e/H00P3ge[d01@3_e/H0mlje0?O>]@3ga[D0mmJm00<0kmK600P0
mlJe0>o6Y@3W[I`0ijfL0=j]U03N[H`0gZF40>neW080klJ]00<0mlJe0>o6[@3_aZd00`3_]I`00`3W
]I@0gZf<0=jLN`020=j4L`0I0<J4H`2]Jd80U6=202T@20128AP0>AP@08AB>@2DHd80Ld8Y09a[BP24
DS40FS4Q0<JDJ`2mS6<0eZf40>NmW02mS6<0[G=B0;EkFP2eQ6<0_IAk0=J]S03Na[D0e[f]0=k>_@08
0?Ogm`030?O_m`3gmoL0moOg00D0moOg1000000L0?ooo`006@3oool3000000<0moOg103bl_820?Og
m`050?;blP3gmoL0moOg0?3`l02NWYh00P1^KVh01@15ADD0CDe=05EEE@1HF5P0EEEE0080:BTY00H0
clo?0=;BdP3Fe]H0d];B0=gMg@3Kfm/50=gMg@030=OGe`3Bd]80fm_K0080fm_K00P0clo?0;^k^`2`
/;00/[:b0;Rh^02`/;00`L710<o?c`80d=3@02H0eMGE0=OGe`3?cll0c/k>0<o?c`3>c/h0`l?30;^k
^`2h^;P0/[:b0:RXZ02EUID0R8R807EeM@1CDe<051@D024Q8@11@D40HF5Q06IVIP1^KVh0EEEE05eM
G@1CDe<0Ng]k0:2PX02h^;P0a/K608:2PP28R8P0Ng]k09jNWP35aLD0cLg=0:FUY@3@d=00l_;b0?Og
m`<0l_;b0P3gmoL00`3bl_80moOg0?Ogm`060?Ogm`030?;blP0000000000008000007`3oool30000
00<0moOg00@0mnog0?Ogm`3gkoL0mnog1@3gmoL0103gknL0aYA[09AS@P1[>B4207=2:@80NdXY00H0
@R4H06<Y40128AP0klJ]0>o>_@3ga[D20?OF_@030>oFaP3ge[d0mmJm0080mmJm0P3gc[D30>oFaP08
0?O>]@3_aZd0eZF<0=jUQ03N[H`0eZF<0=j]U03_aZd20>o6]@0V0>o>]@3gc[D0klJ]0>o6Y@3_aZd0
klJU0>neW03W[H`0gZf<0=jUQ03FW7<0aXA[0:ecDP2]Hd80LdXa024@200i6100NeY208AB>@2<FT80
U6=207]::@1cBS40W7=B0<J4FP3>U6/0gZf<0;EcBP2eNeX0W7=B0;EkFP36U6/0ikfL0<JLQ03Nc[d0
moOg0?O_m`3gmoL20?O_m`/0moOg00<0mnog0000000000000P00000L0?ooo`006@3oool200000080
moOg00<0l_;b0?Ogm`3gmoL00`3gmoL00`3bl_80moOg0?;blP020?Ogm`050>o_k`2?Shl0KVi^05MG
E`15ADD00P1HF5P01`1EEED08B4Q03<c<`11@D40clo?0=OGe`3MgMd01`3Kfm/02@3MgMd0d];B0=KF
eP3Bd]80gMgM0=;BdP33`l<0`L710;2`/0030;Rh^0<0clo?00L0d=3@0=;BdP3GemL0d];B0<o?c`3>
c/h0clo?0080`l?300/0^[Zj0;2`/02b/[80X:2P09BDU01fMWH0Fe]K01HF5P0e=CD0<c<c04e=C@02
05eMG@0?06m_K`1MGEd0GEeM08>3P`2PX:00^;Rh0=CDe028R8P0PX:207IfMP2?Shl0];Bd0<_;b`3@
d=00l_;b0100moOg0P3bl_83000001l0oooo0P0000020?Ogm`030?O_m`3gmoL0moOg00<0moOg00<0
mnog0?Ogm`3gmoL00P3gmoL01@3_koL0]HA[08A::@1[>B40Q58i0080Q4Xa00H0>AP@058Y601B8A00
FSTY0>o6[@3ge[d70>oFaP80mmJm0P3ga[D01P3ge[d0mlJe0>o6]@3_]I`0eZF<0=j]S080gZfD01L0
ikFL0>o6[@3_aZd0klJe0?O6]@3gc[D0mlJe0>o6[@3_aZD0klJ]0>neW03W[I@0ijf<0=JUQ03NYH@0
cYA[0:ecDP2LJdX0S4Xa02T@2012<BT0Ld8Y07=:<@0208AB<@0>09aS>@24DS40YG]J0;f<H`3>U6<0
gZf<0;EkFP2eLdX0W6]:0:EkFP2eQ6<0cZfD0=k>_@3gkoL<0?Ogm`040?O_m`3gmoL0moOg0?Ogm`80
mnog0`00000L0?ooo`006@3oool2000000030?Ogm`3bl_80moOg00@0moOg00@0l_;b0?Ogm`3bl_80
moOg0`3bl_802P2?Shl0IVIV05EEE@1EEED0De=C05EEE@1HF5P0<c<c02TY:@2d];@20=GEe@040=gM
g@3Kfm/0fm_K0=_Kf`<0hn?S00D0fm_K0=gMg@3MgMd0emOG0=3@d0020=gMg@090<?3``2h^;P0^;Rh
0;Rh^030`<00`L710<o?c`3EeMD0d=3@0080d];B00<0gMgM0=;BdP3@d=000P3?cll07@33`l<0`L71
0;Rh^02b/[80ZJVY0:RXZ02DU9@0MWIf06i^KP0Y:BT051@D03/k>`0c<c<0IVIV05EEE@1VIVH0Kfm_
05eMG@1kNg/0Z:RX0;Ng]`3De=@0P82009RHV01VIVH0P8200<G5a@3Cdm<0d=3@01<0moOg0`00000O
0?ooo`80000000<0moOg0?O_m`3gmoL0103gmoL00`3gkoL0moOg0?O_m`040?O_m`0<0;F4J`1kBRT0
NdXY08AB>@1cBS40NdXY058Y60128AP0DRTH0<j]U03_c[D0mmJm103_e/H20?ONcP050>oFaP3ge[d0
mmJm0?OF_@3_a[D00P3ge[d02@3_aZd0kkFL0=j]U03N[H`0ikFD0>NeW03W_JD0klje0>o6]@020?O6
]@030?OF_@3ga[D0klJe0080klJ]01`0kkFL0>NeW03N[I@0gZF40=JLN`3FW7<0]F]B09a[BP2DHd80
@R4H024@201B:AP0Q58i08aJ@P1kBRT0U5Xa08AB<@2LLe80aYb40=JLL`3N[H@0[G=B0<J<H`2<FT80
]HAS0:ecDP3W_I@0g/jm4`3gmoL3000001`0oooo000I0?ooo`8000001P3gmoL30?;blP80moOg0100
l_;b0?Ogm`3=cLd0Ng]k06IVIP1=CDd0GEeM05QHF01EEED0<c<c02TY:@0Q8B40e]KF0=;BdP3MgMd0
hn?S2@3Kfm/01`3MgMd0emOG0=gMg@3MgMd0clo?0<71`@2h^;P00P30`<002031`L40d=3@0=3@d03K
fm/0gMgM0=;BdP3Kfm/0gMgM0P3Fe]H07P3@d=00clo?0<g=c@30`<00^;Rh0;2`/02YZJT0Z:RX07If
MP1_Kfl0CDe=03Lg=`15ADD0De=C06i^KP1MGEd0Kfm_06IVIP1KFe/0Ng]k0:RXZ02d];@0a/K609JF
UP22PX80GEeM08R8R02h^;P0fMWI0>k^kPL0moOg00<0l_;b0?Ogm`3gmoL00P3bl_80103gmoL0l_;b
0?Ogm`3bl_830?Ogm`<000007`3oool2000000H0moOg0`3gkoL01`3gmoL0mnog0?O_m`3gmoL0g/K6
09acDP1c@RT00P24DS402024BS40NdXY048Q600i6100kkFL0>o>_@3ga[D0mmk>0P3_e/H00`3gg/h0
kmK60>oFaP050>oFaP060?O>]@3ge[d0mmJm0?O6]@3_aZd0gZfD0P3W]I@0203W]I`0ikfU0>o6]@3_
e/H0mmJm0?O6]@3_e/H0mmJm0P3_c[d0303_a[D0klJ]0>neW03W]I@0gZf<0=JUQ03FW7/0]G]J09a[
BP2LHcT0Ld8Y06<Y4080LdXa00l0U6=208AB<@2LHcT0S4Xa09acDP3FYH@0eYac0=J]Q02mS6<0]G=:
08AB<@2UNeX0]G]J0=j]S03_knL0203gmoL0103gkoL0moOg0?O_m`3gkoL30?Ogm`040?O_m`3gmoL0
moOg0?Ogm`<00000703oool001T0oooo0P0000080?Ogm`030?;blP3gmoL0moOg0080moOg00d0Ng]k
06IVIP1MGEd0>c/k065QH@1CDe<0F5QH03<c<`15ADD0@D510=3@d03Kfm/0gMgM0080fm_K00D0hn?S
0=_Kf`3Kfm/0gMgM0>?Sh`030=_Kf`0A0=gMg@3Fe]H0gMgM0=gMg@3Bd]80`L710;Rh^031`L40aLG5
0<K6aP3=cLd0eMGE0=gMg@3Fe]H0gMgM0=_Kf`3Bd]800`3Fe]H00`3@d=00clo?0<71`@020;Rh^005
0:VYZ@2XZ:P0OWin06QXJ01CDe<00`15ADD01P1MGEd0Kfm_06i^KP1VIVH0NWYj08n?S`80Z:RX00L0
];Bd09RHV01iNGT0EeMG09fMW@2e]KD0gmoO00l0moOg00D0l_;b0?Ogm`3gmoL0moOg0?;blP030000
01l0oooo0P0000050?Ogm`040?O_m`3gmoL0moOg0?O_m`@0moOg00@0W7=B09AJ<@1J<B40NeY20P1c
BS401@24BS40JcTQ05Xi:@3_aZd0klJe00<0kmK60P3gg/h20>oFaP030?ONcP3_e/H0kmK60080kmK6
00P0kljm0?OF_@3ge[d0mmJm0?O6]@3N[I@0ikFL0>NmW080ikfU00H0klje0?OF_@3_c[d0mmJm0>oF
aP3ga[D30>o>_@0:0>o6]@3W_JD0ikFL0=j]U03N[H`0eYak0<IkFP2eJe80U5Y207=:<@80JcTQ00L0
Q58i08AB<@2LHcT0U6=209AcFP2eQ6/0eYak0080eYac00H0aXaS0:e[>@24BRT0YG]J0;fDN`3F[H`?
0?Ogm`050?O_m`3gmoL0moOg0?Ogm`3gkoL00`00000L0?ooo`006@3oool2000000P0moOg00<0l_;b
0?Ogm`3gmoL00P3gmoL02`20P800Kfm_05=CD`15ADD0IVIV05EEE@1=CDd0ADE503<c<`2<S8`0e]KF
00<0fm_K0P3Shn<01P3MgMd0fm_K0=gMg@3MgMd0fm_K0>?Sh`80fm_K0P3MgMd00`3Kfm/0d];B0<71
`@020;Rh^0030<G5a@36a/H0clo?00<0e]KF0P3Kfm/01`3Bd]80gMgM0=OGe`3EeMD0d=3@0<o?c`36
a/H00P2h^;P01@2`/;00Z:RX07inOP1XJ6P0Fe]K0080>c/k00H0ADE505QHF01^KVh0Kfm_06i^KP1V
IVH30:RXZ0070;2`/02d];@0NWYj07YjNP2?Shl0]kNg0>k^kP0;0?Ogm`030?;blP3gmoL0l_;b00H0
moOg0`00000O0?ooo`800000203gmoL0403gkoL0moOg0?Ogm`3gkoL0moOg0:ecDP2LHcT0JcTQ08aJ
@P24DST0NdXY07=2:@1B:AP0YHAc0?O6]@3_c[d20>oFaP80mmk>00D0kmK60?OF_@3_e/H0mmJm0>oF
aP020?ONcP040>oFaP3ge[d0mmJm0>oFaP80mlJe0P3N[I@00`3W_I`0ikfU0>o6[@030>o>_@80kmK6
01D0mlJe0?OF_@3gc[D0klje0>o6]@3_aZd0ikfU0=j]U03N[H`0eZF40<J4H`2eJe80U5Y208a:<@1J
<B40JcTQ07=:<@24BS40U6=209aS>@2DFS40103FW7<01P3F[H@0[F]20:e[@P2]Le80]HAS0=j]Q0/0
moOg00<0mnog0?Ogm`3gkoL01P3gmoL3000001`0oooo000I0?ooo`80000000H0moOg0?;blP3gmoL0
l_;b0?Ogm`3bl_850?Ogm`0;0?;blP2a/K40IVIV06a/K01MGEd0IVIV05eMG@15ADD0@D5104e=C@3=
cLd00P3MgMd40=_Kf`040>?Sh`3Kfm/0gMgM0=KFeP80d=3@00T0e]KF0=gMg@3MgMd0d];B0=OGe`3K
fm/0gMgM0<o?c`2k^k/00P2h^;P20;Vi^@040<k>cP3Cdm<0d=3@0=_Kf`80e]KF00<0d=3@0<k>cP3@
d=000P3?cll20<K6aP0;0;Vi^@2h^;P0/;2`09BDU01fMWH0IVIV05=CD`0c<c<0ADE505=CD`1fMWH0
0`1VIVH02@2UYJD0Z:RX0:RXZ01fMWH0aLG5059BDP1fMWH0WYjN0;Bd]00>0?Ogm`030?;blP3gmoL0
moOg00@0moOg0`00000O0?ooo`80000000@0moOg0?O_m`3gmoL0mnog1P3gmoL03P3gkoL0moOg0;f]
[@2DFS40S6=:08aJ@P24DS40S4Xa06/i8@1J>BT0ilJ]0?OF_@3_a[D0mmJm0`3_e/H0103gg/h0kmK6
0>oFaP3ge[d20>o6]@80kljm00<0mmJm0?O6]@3gc[D00P3_e/H02P3ge[d0ijfD0=j]S03N[I@0gZfL
0>NmW03Wa[D0iljm0>o6]@3_e/H20>o>_@030>o6]@3Wa[D0klJe0080klJ]0P3W_JD01`3N[I`0gZf<
0=j4L`36Q6<0W6]:09AJ<@1cBS400P1[>B401P1cBS40W6]:08aJ@P2<FT80aYb40<JDJ`80eYac00H0
ikfD08A28@2LJdX0_HaS0<JDJ`3>[I@=0?Ogm`030?O_m`3gmoL0moOg00@0moOg0`00000L0?ooo`00
6@3oool2000000040?;blP3gmoL0moOg0?;blPL0moOg00`0l_;b08F5Q@2EUID0MWIf05=CD`1fMWH0
De=C03/k>`1CDe<0EEEE0<g=c@3Bd]820=_Kf`040>?Sh`3Kfm/0fm_K0=gMg@80e]KF00P0`l?30<g=
c@3?cll0clo?0=KFeP3MgMd0eMGE0=OGe`80gMgM00T0clo?0;Jf]P2h^;P0/;2`0;Rh^036a/H0c/k>
0=3@d03Fe]H01P3=cLd0403?cll0d=3@0<g=c@2m_Kd0aLG50;Rh^02`/;00U9BD0820P01VIVH0F5QH
03<c<`0];Bd0De=C06IVIP1_Kfl206IVIP090:FUY@2PX:00Z:RX05QHF02g]kL0J6QX06IVIP2`/;00
cLg=00h0moOg00<0l_;b0?Ogm`3gmoL0103gmoL3000001l0oooo0P000000103gkoL0moOg0?Ogm`3g
koL60?Ogm`040?O_m`3gmoL0YG][0;F<L`80W6]:00L0LdXa08a:<@1J<B40LdXa0>O6[@3ga[D0ilJ]
00@0kmK600D0mmJm0>oFaP3_c[d0kljm0>O6[@020>o6[@0:0>o6]@3_c[d0klje0?O>]@3ge[d0kmK6
0?OF_@3WYI@0gZf<0=JUS080gZfD00<0ilJe0>o6]@3_c[d01P3WaZd04P3_aZd0ilJ]0>O6[@3F]JD0
ikfL0=j]S03FW7<0aXAS0:ecDP2DFS40Q4Xa058Q401[>B40LdXa08aJ@P2LHcT0S5Y20<JLQ080cYA[
00L0eYac0=j]Q02DFT80S5Y20;F4J`3FYH@0ilJ]0080moOg00<0mnog0?Ogm`3gmoL0203gmoL00`3g
koL0moOg0?Ogm`040?Ogm`<00000703oool001T0oooo0P0000001@3bl_80moOg0?Ogm`3gmoL0l_;b
0080moOg103bl_803@3gmoL0FUYJ09^KV`1VIVH0M7Ad06=SH`1VIVH0<c<c06m_K`2j^[X0clo?0;^k
^`3MgMd0103Kfm/05@3Fe]H0d=3@0=3@d03?cll0^KVi0;Rh^036a/H0d=3@0=KFeP3=cLd0d=3@0=_K
f`3MgMd0`l?30;Rh^02/[:`0]KFe0;2`/02m_Kd0cLg=0<k>cP020<K6aP040;fm_@2h^;P0^;Rh0;2`
/080^KVi0P36a/H20<G5a@090;Rh^02`/;00UIFE07inOP1fMWH0GUiN04e=C@0Q8B40ADE50080IVIV
00/0MWIf05iNGP2MWId0R8R809JFUP1GEeL0aLG507IfMP1KFe/0];Bd0=WIf@070?Ogm`030?;blP3g
moL0moOg00L0moOg00@0l_;b0?Ogm`3gmoL0moOg0`00000O0?ooo`80000000D0mnog0?Ogm`3gmoL0
moOg0?O_m`020?Ogm`<0mnog0P3gmoL0302<BRT0]IAk08aJ@P24FT80S5Y207=:<@1B:AP0W6<i0>o6
[@3W[I@0klJe0?OF_@<0kmK600/0kljm0>O>_@3_a[D0klJe0=j]W03N[I@0ikfU0>O6[@3_a[D0ilJ]
0>o6]@020>oFaP080?OF_@3N[I@0gYak0=J]S03FYH`0cZfD0>O6[@3Wa[D20>NmY@040=JeY@3N[H`0
gZf<0=JUS080gZfL0P3W_JD20>NmW0090=j]U03>U6/0aXA[0;E[DP2LJdX0Q58i03TH401S:A00JcTQ
0080S5Y200/0Q58i0;fDN`3FW7/0]G]J0;f<H`3W_I@0W6]:08a:<@36U6/0eZf40>OFaP060?Ogm`03
0?O_m`3gmoL0moOg00L0moOg00@0mnog0?Ogm`3gmoL0moOg0`00000L0?ooo`006@3oool2000000L0
moOg00<0l_;b0?Ogm`3gmoL00P3gmoL0301fMWH0Q8B405iNGP1VIVH0GUiN06QXJ01MGEd0F5QH0=;B
dP2PX:00/[:b0=gMg@<0fm_K00P0e]KF0<k>cP2MWId0UIFE0;2`/02_[jl0WIfM0;Vi^@80e]KF0P3@
d=020=gMg@0<0<o?c`2h^;P0ZJVY0:FUY@2YZJT0^KVi0<k>cP2l_;`0^KVi0:f][@2TY:@0UIFE0`2U
YJD00`2_[jl0aLG50;Vi^@020;Vi^@0>0;Rh^02`/;00UIFE08R8R01XJ6P0GUiN05=CD`15ADD0>c/k
05iNGP1MGEd0K6a/06IVIP2?Shl208R8R00706IVIP35aLD0IVIV05]KF`2XZ:P0f][J0?ooo`0D0?Og
m`<000007`3oool2000000D0moOg00<0mnog0?Ogm`3gkoL00`3gmoL00`3oool0W6]:0:EkH`0208AB
>@0809AJ@P1B8A00Q58a08A:<@3>U6/0gZF40>o>]@3ge[d20>oFaP070>o>_@3Wa[D0gZfL0;fDN`2e
S7<0cZFD0;fDN`020=j]W0030>o>_@3_a[D0klJe00<0mmJm00/0gZfD0=JLN`36W8@0eYak0>NmW03W
a[D0ijfL0=j]W036YI`0_Ib<0;F<L`030<JLQ0030<jUU03W_JD0gZfL0080gZfL00L0gZf<0<JLQ036
Q6/0]G]J09AJ@P24DST0JcTQ0080FS4Q00D0Q58i08AB<@2<FT80]HA[0;f<H`020;EkFP060>NmU02D
FS40S4Xa0<JLQ03FW7<0imK>503gmoL3000001`0oooo000I0?ooo`8000000P3gmoL00`3bl_80moOg
0?;blP070?Ogm`0<08>3P`1kNg/0De=C05iNGP1CDe<0J6QX06IVIP32`/80`l?30:FUY@2`/;00e]KF
0P3Kfm/02P3@d=00_;bl08n?S`2i^KT0/K6a06a/K01bLW80S8b<0:FUY@2MWId20=3@d00E0<g=c@3M
gMd0gMgM0<k>cP31`L40ZJVY0;2`/02MWId0GemO07QhN02EUID0/;2`0<g=c@21PH40QHF508B4Q023
Ph<0Q8B408n?S`2`/;00^;Rh0080^KVi0P2`/;001`2EUID0OWin07IfMP1VIVH0De=C05iNGP0c<c<0
0P1NGUh02`1VIVH0MWIf08n?S`22PX80R8R8065QH@35aLD0Kfm_07]kN`2d];@0jNWY00d0moOg00<0
l_;b0?Ogm`3gmoL01@3gmoL3000001l0oooo0P0000020?Ogm`030?O_m`3gmoL0mnog00H0moOg00<0
_IbD0:EkFP2LLe800P1cBS404P2DFT80FS4Q09AJ<@3_]I@0ihak0=JUS03_c[D0kljm0>oFaP3_a[D0
ijfL0;F4H`2mS6<0gZfL0;f][@1cLf/0YHAc0<JLQ080gXAc00<0klJe0>O6[@3ge[d00P3ge[d03`3W
]I`0eYak0=JUQ02mU7/0eZF40<IJBP36Q6/0eZF<0=k6aP2DNg<0YG][0:EkH`2UNeX0YG]S0;F4J`02
0=j]U080gZfL00L0eZF<0<jDJ`36Q6/0]F]B09a[BP2<FT80Q58i0080DRTH0P24DST0202LJdX0]HAS
0;fDN`2eLdX0]G]J0>NmW02LHcT0W7=B0P3F[H@00`3_inL0moOg0?Ogm`0:0?Ogm`030?O_m`3gmoL0
moOg00D0moOg0`00000L0?ooo`006@3oool2000000D0moOg00<0l_;b0?Ogm`3gmoL00`3gmoL01@3o
ool0Rh^;05eMG@1EEED0>c/k0080GUiN01/0J6QX0=;BdP2b/[80YJFU0;Rh^03EeMD0clo?0;Vi^@2M
WId0NWYj0451@@2j^[X0P8200;Fe]@0J6QX0MgMg04e=C@2?Shl0WIfM0<71`@3De=@0gMgM0=OGe`3?
cll0aLG50<30`02MWId00P2EUID0302MWId0MWIf0<O7a`1KFe/0_;bl079bLP1KFe/0YJFU03De=@1J
FUX0Q8B409fMW@<0/;2`00H0WIfM09BDU020P800J6QX05iNGP1HF5P202TY:@0<03<c<`1NGUh0De=C
0820P01kNg/0Ph>308R8R01eMGD0];Bd05MGE`2FUYH0bl_;5P3gmoL3000001l0oooo0P00000:0?Og
m`050?ooo`3gkoL0YHA[08AB<@1kBRT00`24DST0502DFT80mlJe0>N<N`3N[I@0ilJe0>o>]@3_aZd0
_IAk09AcFP1J>BT0]IB<0<Je]@2DNf/08APH08AcJ`1JBT80U7=J0;F4J`3W]I`0klj]0P3ge[d08@3g
c[D0ikfL0>NeU02mU7/0]Hac09acDP2mU7/0W6]:0<k6_@1SFU80]Kg>07=cJ`1SFU80_IbD048a:@1c
DT80]Hac0;fDN`3FYH@0eZF<0=JUQ036U6/0aXAS0:ecDP2DFT80Q58i048Q600i6100@R4H058Y6024
DST0[G=B09acDP020:EkFP060;EkFP3F[H@0Q4XY0;f<H`3FW7/0g/Je5@3gmoL3000001`0oooo000I
0?ooo`8000002`3gmoL01@2KVi/0T92@07YjNP1LG5`0De=C0080GUiN01@0S8b<0<?3``2UYJD0ZJVY
0;Rh^03EeMD0`L710:n_[`2EUID0De=C06][J`18B4P0;bl_0451@@1NGUh0LW9b06][J`2MWId0^k^k
0<S8b0<0emOG00L0clo?0<S8b031`L40/[:b09fMW@20P800NWYj0080TY:B00X0@D5103<c<`11@D40
De=C04Q8B01OGel0G5aL08B4Q02?Shl0X:2P0P2YZJT00`2MWId0R8R806QXJ00206IVIP0305=CD`15
ADD0@D510080ADE500X0De=C07IfMP20P800Kfm_08R8R020P800];Bd06i^KP2FUYH0j>SX4P3gmoL0
103bl_80moOg0?Ogm`3gmoL3000001l0oooo0P00000:0?Ogm`050;FDN`3Fa/H0YHac09AcFP1kDT80
0P24DST02P2DFT80cW=S0>neW03FW7/0gZf<0>o6]@3_c[D0ikFL0<J4J`1cBS4208ASDP0805Y2>@12
:B40Q58i08a[DP24He80YG]S0;fDN`3__I`20?O>]@080?OF_@3gc[D0kkfL0>NeW03NYH@0_IAk0<J4
J`2DLeX20:F<Q00:05Xi:@1B:AP0FSTY07=:<@1J@ST0LeY:07]B@P2eQ6<0]HA[0<jDJ`80eYak00<0
]HA[0;EkFP2DFT800P2<FT800`1[>B40@R4H05Xi:@0206/i8@0:09a[BP2]Le80W6]:09aS>@2eNeX0
eZf409AS@P2mS6<0eYac0>oWgQ40moOg00@0mnog0?Ogm`3gmoL0moOg0`00000L0?ooo`006@3oool2
000000030?Ogm`3bl_80moOg0080moOg00<0l_;b0?Ogm`3gmoL00`3gmoL02@20P800XJ6Q06IVIP1C
De<0K6a/05iNGP1CDe<0U9BD0;Jf]P020:VYZ@070;Rh^03>c/h0cLg=0<K6aP2h^;P0WIfM07inOP03
05aLG00405iNGP1jNWX0UIFE0<71`@80clo?00<0emOG0=gMg@3GemL00P3?cll0403>c/h0`<300;:b
/P2MWId0Shn?06YZJP24Q8@0S8b<08>3P`1@D500B4Q805=CD`1kNg/0UYJF09FEU@2PX:020:VYZ@05
09fMW@2PX:00OWin06QXJ01VIVH00P1NGUh03P1=CDd0@D5103/k>`0k>c/0CDe=07]kN`28R8P0Kfm_
08R8R02FUYH0];Bd07IfMP2FUYH0k^k^5P3gmoL3000001l0oooo0P0000000`3gmoL0mnog0?Ogm`07
0?Ogm`0C0:ecDP2mW9@0]Ib<08aJ@P1cBS40Q58i07=:<@2<BS40aXAS0>NUU03FW7/0gZf<0>o6]@3W
a[D0ilJ]0=j]U02mU7/0]F]B08aSBP0207]B@P0708AB>@2DLeX0aXA[0=JUQ03W]I`0klJ]0?O>]@02
0?OF_@0B0?O>]@3_aZd0klJU0>NeU03NYH@0eYak0;F4J`24HdX0YG]S0:F4L`2LNf/0HdY205Y2>@1c
BS40W7=B0;f<H`36Q6/0cYA[0P3FW7/02@2mU7/0_HaS0;E[DP2DFT80S5Y208AB>@1c@RT0DRTH05Xi
:@0205Xa8@0:09acDP2eNeX0W7=B09aS>@2eNeX0eZf409a[BP2mS6<0eZF40>o_iaD0moOg0`00000L
0?ooo`006@3oool3000000L0moOg00L0l_;b0?Ogm`3gmoL0j>SX07AdM01CDe<0CDe=0080De=C00H0
ADE509BDU02PX:00YJFU09fMW@2`/;020=GEe@0F0=gMg@3Fe]H0clo?0=3@d031`L40_;bl0<71`@36
a/H0`L710:VYZ@2k^k/0c/k>0=gMg@3GemL0fm_K0=gMg@3GemL0e=CD0<o?c`30`<00Z:RX09fMW@<0
/;2`0P2MWId01P2PX:00ZJVY0;2`/02`/;00^;Rh0;Zj^P80/;2`00L0ZJVY0:2PX02EUID0R8R806QX
J01/K6`0GUiN0080ADE500d0@D5105=CD`1=CDd0ADE507IfMP2FUYH0Kfm_09>CT`2MWId0^;Rh07]k
N`2MWId0oooo01D0moOg1000000O0?ooo`<000001`3gmoL03`3gkoL0moOg0>oWgP2US7/0U6]B07=:
<@1c@RT0LdXa06/i8@2LJdX0aXAS0<jDJ`2mU7/0eZF<0>O6]@020>o>]@0=0>o>_@3_aZd0klJe0>Nm
Y@3W]I`0ijfL0>NmY@3W]I`0eYak0=jUQ03W[I@0mmJm0?O>]@020>oFaP090?OF_@3_cZd0klJ]0>Ne
U03FW7<0gYak0=JUQ03FYH`0eZF40080_IAk01h0cYA[0=JLN`3FYH@0eZF40=j]S03N[I@0eZF<0=JU
Q03FW7/0cYA[0;f<H`2eNeX0U5Y208aSBP24DST0JcTQ058Y601J>BT0LdXa07=2:@2LJdX0_HaS09a[
BP2LHcT0aXAJ0=j]U02LLe80_IAk0>oNcP3ooolD0?Ogm`@00000703oool001T0oooo0`0000000`3g
moL0l_;b0?Ogm`030?Ogm`030?;blP3gmoL0moOg0080oooo00d0IVIV03/k>`15ADD0ADE506i^KP0k
>c/0OWin09fMW@2PX:00UIFE0;2`/036a/H0emOG0080gMgM00T0fm_K0=gMg@3Kfm/0][Jf09FEU@24
Q8@0Ng]k07inOP3>c/h00`3MgMd0303Shn<0gMgM0=_Kf`3GemL0gMgM0<S8b02k^k/0MGEe07]kN`1n
OWh0UIFE0<K6aP80cLg=0P36a/H30<71`@0G0;2`/02NWYh0Shn?0:2PX02FUYH0P82007IfMP1VIVH0
GEeM05iNGP0g=cL0<c<c0451@@0];Bd0De=C06IVIP20P800KVi^09RHV02NWYh0aLG508>3P`2UYJD0
5P3gmoL4000001l0oooo0`0000000`3gmoL0mnog0?Ogm`030?Ogm`0D0?O_m`3gmoL0moOg0?ooo`1c
@RT0S5Y205Xa8@1[>B40U6=205Xa8@2LBS40]F]B0=j4L`2eS7<0eZF40>o>]@3W_JD0mlje0?OF_@3_
e/H20?OF_@070>oFaP3WYI@0YG]S09acDP2eJe80ikFL0>o6Y@020?OF_@0<0?ONcP3_e/H0mmJm0?O>
]@3ge[d0kkfL0>N]U036Q6/0W7=B0;E[DP2eS7<0ikfU0P3WaZd20>NmY@80ikFL00/0gZfD0=JUQ036
U6/0]HAS0<jDJ`2eNeX0[G=B09a[BP2<FT80Q58a06<Y4002058Y600;05Xi:@1B8A00S5Y20:ecDP2L
JdX0U6=20<J<H`3W_I`0YG]J0<JLQ03_inL05@3gmoL4000001`0oooo000I0?ooo`<000002@3gmoL0
4@3YjNT0oooo05EEE@0k>c/0ADE505=CD`1NGUh0De=C07MgM`28R8P0UYJF09FEU@2UYJD0bl_;0<G5
a@3@d=00gMgM0080fm_K00/0Shn?08B4Q01jNWX0OWin0;2`/03>c/h0emOG0=gMg@3Shn<0gMgM0>?S
h`030=gMg@80emOG00P0c/k>09JFUP1XJ6P0GUiN06QXJ01nOWh0/[:b0<g=c@80clo?00P0`l?30<K6
aP2h^;P0WIfM08>3P`2PX:00UIFE08n?S`80MWIf00<0IVIV04E5A@15ADD00P0c<c<01P0];Bd0FUYJ
06=SH`1dM7@0Ph>306IVIP80UYJF00<0]KFe09fMW@2UYJD05P3gmoL4000001l0oooo0`0000090?Og
m`0@0?ooo`1[>B40NdXY05Xa8@1[>B40Q58i07=:<@2LHcT0]F=20;EkFP36Q6/0aYb40>o6[@3Na[D0
ikfL0?OF_@80kmK600H0mlJe0;F4J`2UNf<0]F]B0=JUQ03_aZD20?O>]@040?ONcP3ge[d0mmk>0>oF
aP80mmJm0P3gc[D0203_aZD0ijfD09AJ@P24DST0U5Y20;E[DP3NYH@0ilJ]0P3_aZd0203_]I`0ikfU
0=jUQ02mU7/0YG]J0<jDJ`2eS7<0[G=B0P2LJdX03`2<FT80JcTQ058Y601J<B40DRTH058Q401cDT80
U6]B0:EkFP2LLe80U5Xa0;f<H`3F[H`0_IAk0<JLQ00F0?Ogm`@00000703oool001T0oooo0`000006
0?Ogm`080?;blP3gmoL0moOg0:f][@1kNg/0De=C06YZJP1NGUh305=CD`0506IVIP1/K6`0Ng]k08>3
P`2`/;000P3EeMD01@3?cll0/;2`0:BTY02MWId0fm_K00P0hn?S00<0i>CT0=_Kf`3Shn<00P3Shn<2
0=gMg@030=_Kf`3GemL0d];B00<0clo?00@0cLg=0:FUY@24Q8@0P8200P24Q8@209fMW@0:0:2PX02X
Z:P0X:2P09JFUP1kNg/0P82005iNGP15ADD0De=C04E5A@808B4Q00X0:BTY06a/K01jNWX0IVIV07Ee
M@2NWYh0YJFU07IfMP2FUYH0jNWY403gmoL00`3bl_80moOg0?Ogm`030?Ogm`@000007`3oool30000
00H0moOg00@0mnog0?Ogm`3gmoL0W7=B0P1cBS402P24HdX0Q58i07=:<@1cBS40Q58i09AJ<@2<HdX0
YG]J0=JUQ03Wa[D20>o>]@050=JUQ02mW8`0gXAc0=j]W03_e/H01`3gg/h00`3gg]H0kmK60>oFaP02
0?ONcP80mmJm00<0kmK60?OF_@3ga[D00`3_aZd0103WaZd0aYb40:EkH`2]Le820:EkH`090<JLQ02m
U7/0cYA[0=JLL`3>U6/0[G=B09acDP2]Le80Q58i0080JcTQ00`0FS4Q03TH400i6100@R4H09AcFP2<
FT80YG]J0:eS@P36U6/0W6]:0;f<H`3_inL@0?Ogm`030?O_m`3gmoL0moOg00<0moOg1000000L0?oo
o`006@3oool3000000050?;blP3gmoL0moOg0?Ogm`3bl_80103gmoL02P3:b/X0MWIf05=CD`23Ph<0
LW9b065QH@1NGUh0De=C06IVIP1/K6`20820P0040:VYZ@3@d=00eMGE0=GEe@80gMgM0P3Kfm/60>?S
h`040>CTi03Shn<0hn?S0=_Kf`80hn?S103Kfm/0103MgMd0eMGE0=GEe@3GemL20<o?c`040<K6aP3=
cLd0cLg=0<71`@80^;Rh00/0ZJVY0;2`/02MWId0UIFE08R8R023Ph<0P82007IfMP1CDe<0ADE502d]
;@02024Q8@0902TY:@2EUID0K6a/06IVIP1fMWH0R8R80;Bd]01fMWH0YJFU01L0moOg1000000O0?oo
o`<0000000<0mnog0?Ogm`3gmoL01P3gmoL01`2LJdX0NeY207=:<@2LNf/0S6]B08AB>@1cBS400P2<
FT801P2<HdX0[G=B0=JLN`3_aZd0klJe0>o>]@80mmJm0`3_e/H80?ONcP030>oFaP3gg/h0mmk>00D0
kmK60P3_c[D0103gc[D0klJ]0>o6[@3W_JD20>O6[@0=0>NeW03N[I@0eZF<0=JLN`3FYH@0_IAk0;F<
L`2]Le80YG]J0:ecDP2LJdX0LdXa058Q400303TH4008048Q602<HdX0S5Y20=JLL`2LJdX0]G]J09a[
BP36W8@G0?Ogm`@00000703oool001T0oooo100000020?Ogm`030?;blP3gmoL0moOg00<0moOg00d0
^[Zj05MGE`1SHf<0T92@07AdM01NGUh0Hf=S065QH@1SHf<0IVIV08>3P`1kNg/0ZJVY0080eMGE00L0
e]KF0=gMg@3MgMd0fm_K0>?Sh`3Kfm/0gMgM00L0hn?S00H0gMgM0>?Sh`3Kfm/0fm_K0>?Sh`3Kfm/3
0=gMg@060=;BdP3GemL0d=3@0<o?c`36a/H0clo?0P31`L401`2h^;P0/;2`0:VYZ@2YZJT0WIfM09jN
WP2FUYH00P20P800401VIVH0MWIf04e=C@0c<c<0:BTY03/k>`0];Bd0WIfM08>3P`1VIVH0P82007If
MP2e]KD0MWIf0<;2`P3ooolE0?Ogm`D000007`3oool400000080moOg00<0mnog0?Ogm`3gmoL00`3g
moL01`24BRT0Le9208AJ@P2US7<0U6]B08AJ@P1kFT800P24FT80102<FT80W7=B0=JLN`3WaZd20>o>
]@80mmJm00@0kmK60?ONcP3gg/h0kmK60`3gg/h02P3ge[d0mmk>0?ONcP3gg/h0mmJm0>oFaP3gg/h0
kmK60?ONcP3_e/H30?OF_@060?O6]@3gc[D0klJe0>o6[@3W_JD0klJ]0P3W]I`01`3N[I@0eZF40=JL
N`3FW7/0_IAk0<JDJ`2eJe800P2]Le802`2<FT80W6]:058Y601B:AP0@R4H05Xa8@1B8A00YG]J08aJ
@P2mU7/0[G=B0080W6]:00<0e[f]0?ooo`3gmoL0503gmoL5000001`0oooo000I0?ooo`@00000203g
moL0203AdM40GUiN06a/K01kNg/0K6a/079bLP1/K6`0Hf=S0P1MGEd0101fMWH0Ng]k09FEU@3@d=02
0=GEe@030=KFeP3MgMd0gMgM0080hn?S00<0gMgM0>?Sh`3Shn<02@3Shn<30=_Kf`@0emOG00H0clo?
0<k>cP3?cll0a/K60<G5a@30`<020;Rh^0040;2`/02YZJT0Z:RX0:2PX080R8R800D0Ng]k07IfMP1C
De<0>c/k04E5A@02024Q8@0902TY:@2NWYh0Q8B407IfMP22PX80K6a/09fMW@1fMWH0l_;b01H0moOg
1@00000O0?ooo`@00000203gmoL01024DST0S6]B08aSBP2LLe8208aSBP0:08AJ@P24DST0Q58a08AB
<@2LLe80aXA[0>NmW03_a[D0klje0>o>_@80mmJm00<0kmK60?ONcP3gg/h02`3gg/h30>oFaP@0mlje
01<0klJ]0>o6Y@3_aZd0ikfU0>NmW03W]I@0gZfD0=JUS03FYH@0eYak0=JLL`3>U6/0[G=B0;EkFP2L
Le80W6]:07=:<@1[>B40FS4Q0080>AP@00P0@R4H0:EkH`2LJdX0eYac0;EcBP2<HdX0W6]:0?O_maH0
moOg1@00000L0?ooo`006@3oool4000000030?;blP3gmoL0moOg00D0moOg00L0l_;b06a/K01NGUh0
GUiN06YZJP1/K6`0GUiN0080Hf=S00P0GUiN08>3P`28R8P0WYjN0<K6aP3De=@0e]KF0=OGe`80gMgM
00<0fm_K0>?Sh`3Shn<00`3Shn<00`3MgMd0hn?S0>?Sh`020>?Sh`D0fm_K00@0d];B0=OGe`3GemL0
e=CD0`3?cll01036a/H0aLG50<K6aP31`L420;Rh^00;0;2`/02MWId0X:2P09FEU@2FUYH0P82007If
MP1NGUh0De=C0451@@1=CDd00P0Q8B40200k>c/0Ng]k0:RXZ02?Shl0R8R807]kN`1^KVh0];Bd4@3g
moL00`3bl_80moOg0?Ogm`030?Ogm`D000007`3oool4000000030?O_m`3gmoL0moOg00D0moOg0100
S6=:08AB>@24DST0Q58i08ASBP24DST0Q5Y208AB>@24FT80Q58i0;EkFP36U6/0ikFL0>NmY@3_cZd0
mlje0P3ge[d20>oFaP@0mmk>0P3ge[d40?ONcP@0kmK600@0mlJe0?O>]@3gc[D0klj]0`3_aZd04@3W
_JD0ikfL0>NmY@3W]I`0gZf<0=jUQ03FYH@0_IAk0<jDJ`36Q6/0]G]J0:ecDP2LJdX0Q58i07=:<@1c
@RT0@R4H0080>AP@00L0FS4Q0=JLL`2eQ6<0eYak0;EkFP2LLe80cZfD0140moOg00<0mnog0?Ogm`3g
moL00`3gmoL5000001`0oooo000I0?ooo`D000001`3gmoL00`3oool0Ph>306IVIP0207AdM00:06=S
H`1/K6`0GUiN07AdM01/K6`0Ng]k08n?S`2NWYh0a/K60<o?c`<0emOG0P3MgMd20>?Sh`0:0=_Kf`3M
gMd0hn?S0=_Kf`3MgMd0hn?S0=gMg@3Kfm/0gMgM0=_Kf`<0gMgM0`3GemL0203?cll0emOG0<o?c`3>
c/h0a/K60<G5a@36a/H0`<300P2h^;P01@2`/;00WIfM0:2PX02EUID0Shn?0080MWIf00@0IVIV05=C
D`15ADD0;Bd]0P0F5QH01`1LG5`0K6a/08>3P`20P800WYjN0;Fe]@2NWYh05`3gmoL6000001l0oooo
1@0000070?Ogm`0309akJ`1cDT80S5Y20080U6]B00X0S6=:08AB>@1kFT80U6]B08aSBP2eQ6/0aYA[
0=JUS03W_JD0klJ]0P3gc[D30?OF_@030?ONcP3_e/H0mmJm0080mmk>00<0kmK60?ONcP3ge[d00P3_
e/H40?OF_@0B0?O>]@3ge[d0mlje0>o6[@3gc[D0klJ]0>o6Y@3W_JD0ikfL0>NmY@3W]I@0gZfD0=JU
S03FYH@0_IAk0<jDJ`36Q6/0]HAS0P2LJdX0102<FT80LdXa058Q400i610202T@200607]B@P2UNeX0
[G=B0<JLQ036U6/0eZf<5`3gmoL6000001`0oooo000I0?ooo`D000001`3gmoL04@3oool0GUiN08>3
P`1VIVH0K6a/06YZJP1VIVH0Hf=S04e=C@1/K6`0Q8B409JFUP2EUID0aLG50<o?c`3EeMD0emOG0080
gMgM0P3Shn<00`3Kfm/0hn?S0>?Sh`020>?Sh`060=gMg@3Kfm/0hn?S0=gMg@3Kfm/0gMgM0P3Kfm/3
0=gMg@030<o?c`3Bd]80e=CD0080clo?00<0c/k>0<71`@31`L400`2h^;P0502`/;00WIfM0:RXZ02E
UID0Shn?07AdM01SHf<0De=C05iNGP0k>c/08B4Q02l_;`0F5QH0JVYZ07AdM01fMWH0KVi^09jNWP2U
YJD0gmoO5`3gmoL6000001l0oooo1@0000070?Ogm`0@08AB>@2UNf<0YG]J08aJ@P2<HdX0S5Y208AJ
@P2LHcT0Ld8Y08aSBP2mS6<0]Hac0=JUQ03W_I`0klJ]0?O>]@<0mmJm1@3gg/h01@3ge[d0mmk>0>oF
aP3gg/h0mmJm00@0kmK60`3ge[d00`3_aZd0mlJe0>o>[@020>o6[@030>o6Y@3W]I`0ikFL0080gZfD
0140eZF<0=JUQ02mU7/0eYac0;F<L`2LLe80U6]B08AJ@P1cBS40Q58i03TH400Y40P0@RTQ02T@2024
HdX0W6]:09AS@P020<JDJ`030<JLQ03gmoL0moOg01D0moOg1P00000L0?ooo`006@3oool5000000P0
moOg00<0h>3P065QH@1QHF400P1NGUh02P1MGEd0Hf=S06a/K01/K6`0Ph>309FEU@2UYJD0aLG50<o?
c`3EeMD20=gMg@0<0=_Kf`3Shn<0hn?S0=gMg@3Shn<0gMgM0>?Sh`3Kfm/0gMgM0>?Sh`3MgMd0fm_K
103MgMd00`3Kfm/0gMgM0=;BdP020=OGe`<0clo?00<0c/k>0<71`@31`L400`2h^;P03@2`/;00YJFU
0:VYZ@2?Shl0Q8B407]kN`1fMWH0HF5Q04E5A@0k>c/08B4Q02l_;`0Q8B400P1dM7@0101kNg/0Kfm_
0:FUY@2`/;0H0?Ogm`H000007`3oool5000000L0moOg00P0imkN0:EkH`1kFT80NeY208AB>@24DS40
Q5Y208AB>@80S6=:00D0]Hac0<JLQ03FYH`0ikfL0>o6[@020?OF_@030>oFaP3ge[d0mmk>0080mmk>
00H0mmJm0?ONcP3ge[d0kmK60?ONcP3ge[d20>oFaP<0mmJm00<0kmK60?OF_@3ge[d00P3gc[D30>o6
[@040>o6Y@3W]I`0ikFL0=j]U080gZf<00@0eZF40<JLQ03FW7/0]HA[0P2LLe800`2LJdX0NeY206/i
8@0203TH4008048Y8@0i6100U6]B09acDP2LHcT0aYA[0<JLQ03FYH`G0?Ogm`H00000703oool001T0
oooo1P0000070?Ogm`0B0?ooo`1QHF40GUiN05=CD`1MGEd0FUYJ05=CD`1/K6`0MWIf08n?S`2EUID0
ZJVY0<G5a@3?cll0emOG0=;BdP3MgMd0fm_K0`3MgMd0103Kfm/0hn?S0>?Sh`3Shn<20=_Kf`030>?S
h`3MgMd0gMgM00D0gMgM0`3GemL01P3?cll0emOG0<o?c`3>c/h0b<S80<71`@80^;Rh0`2`/;001`2M
WId0Shn?08n?S`1/K6`0IVIV04E5A@0k>c/00P0Y:BT0200W9bL08B4Q08:2PP1dM7@0Kfm_06i^KP2j
^[X0dM7A5`3gmoL7000001l0oooo1P0000060?Ogm`0B0?ooo`2<HdX0NeY208AB>@1cBS40Le9207=:
<@1kFT80S6=:09a[BP2eS7<0eYak0=J]S03W_I`0klJ]0?O6]@3ge[d0kmK60`3ge[d00`3_e/H0mmk>
0?ONcP020?ONcP030>oFaP3gg/h0mmJm00H0mmJm00X0mlJe0?O>]@3gc[D0klJ]0?O>]@3_aZd0klJU
0>nmW03W]I`0gZfD0P3N[H`20=JUQ00A0;fDN`2eQ6/0YG]S08aSBP2<FT80JcTQ05Xa8@128AP0:A08
03TQ600i6100W7]S09aS>@2DHd80aYb40<jeY@3Nc/H05P3gmoL7000001`0oooo000I0?ooo`H00000
203gmoL0101ZJVX0GUiN05iNGP1MGEd305iNGP0607IfMP24Q8@0UIFE0:FUY@36a/H0clo?0P3GemL0
103MgMd0fm_K0>?Sh`3Kfm/40>?Sh`070=_Kf`3Shn<0gMgM0=_Kf`3Shn<0gMgM0=_Kf`050=gMg@03
0=OGe`3Bd]80e=CD0080clo?00@0c/k>0<71`@31`L40^KVi0P2h^;P02`2`/;00X:2P0:2PX02FUYH0
Q8B407]kN`1VIVH0@D5103/k>`0Y:BT0;bl_0080:BTY00D0Q8B408n?S`1VIVH0P8200<G5a@020?Og
m`030?;blP3gmoL0moOg01<0moOg1`00000O0?ooo`H000001`3gmoL00`3>]KD0Q6=:08AB>@0308AB
>@0:07=B@P24DST0W6]:0;F<L`36W8@0gZfL0>NmY@3_aZd0mlje0?OF_@80kmK600<0mmk>0>oFaP3g
g/h00`3gg/h01@3_e/H0mmJm0>oFaP3gg/h0kmK600D0mmJm0P3gc[D01@3ga[D0klj]0>o6[@3_aZd0
klJU0080ikFL00@0gZfL0=j]S03FYH@0eZF<0P3>U6/0202mS6<0YG]J09acDP2<FT80FSTY05Xa8@12
:B40<APH0P128AP01`2UNf<0S5Y20:ecDP36U6/0ikfL0?Ogm`3gkoL05@3gmoL7000001`0oooo000I
0?ooo`L000001`3gmoL03@24Q8@0LW9b05YJFP1SHf<0HF5Q05YJFP1SHf<0M7Ad07]kN`2NWYh0]KFe
0<K6aP3?cll00P3GemL20=gMg@80fm_K0P3Shn<00`3Kfm/0gMgM0=_Kf`030=_Kf`030=gMg@3Kfm/0
gMgM00<0gMgM0P3GemL20=CDe0070<o?c`3>c/h0c/k>0<K6aP35aLD0`<300;^k^`020;Rh^0070;:b
/P2PX:00UIFE08n?S`20P800IVIV05=CD`020451@@0903<c<`0Y:BT08B4Q01HF5P1dM7@0Ng]k07If
MP2FUYH0k^k^01L0moOg2000000O0?ooo`L000001`3gmoL02P2UNf<0S6]B07=B@P1kFT80Le9207]J
@P24FT80U6]B0<JDJ`3F[H`20>NmY@030>o6[@3gc[D0mmJm0080mmJm0P3_e/H0103gg/h0kmK60?OF
_@3ge[d30>oFaP80mmJm00@0kmK60?OF_@3ge[d0mmJm0P3gc[D20>o>[@080>o6[@3_aZD0klJU0>Nm
Y@3W_I`0ikFD0>N]U03N[H`20=jUQ0060<jDJ`2eS7<0]HA[09a[BP2<FT80LdXa0P1J>BT02@128AP0
DRTH03TH400Y40P0U6]B09a[BP2mS6<0gZf<0>o_i`0F0?Ogm`P00000703oool001T0oooo1`000007
0?Ogm`030?ooo`2l_;`0Q8B400<0M7Ad00H0HF5Q07AdM02;Rh/0UIFE0:VYZ@3>c/h20<o?c`030=OG
e`3EeMD0emOG00<0fm_K0P3MgMd00`3Kfm/0gMgM0=_Kf`030=gMg@030=OGe`3MgMd0emOG00<0emOG
00<0d];B0=OGe`3>c/h00`3>c/h01@36a/H0aLG50<30`02h^;P0`<300080/;2`0P2EUID01@24Q8@0
Ph>305iNGP1=CDd0De=C0080>c/k00T0:BTY01@D5011@D40Shn?07]kN`22PX80X:2P0?Ogm`3bl_80
5P3gmoL8000001l0oooo1`0000070?Ogm`030?ooo`3>]KD0YG]S0080U6]B0P1kFT802@2DJe80]Hac
0=JLN`3W]I`0klJU0>o6[@3gc[D0klje0?O>]@030>oFaP80mmJm00<0kmK60?ONcP3ge[d0103ge[d5
0?O>]@030?OF_@3gc[D0klJU00<0klJU00D0ikfU0>NmW03W]I@0gZfD0>NeU0020=JUQ080]Hac0100
YG]S08aSBP24DST0Ld8Y07=:<@1J<B40@R4H03TH400Q40P0FSTY0;F4J`2eLdX0cYA[0<j]U03gmoL0
mnog5@3gmoL8000001`0oooo000I0?ooo`P0000000<0moOg0?;blP3gmoL00`3gmoL20?ooo`0:0>WY
j@1jNWX0M7Ad06=SH`1ZJVX0K6a/0820P02MWId0YJFU0<k>cP80clo?0P3GemL0103MgMd0emOG0=_K
f`3Kfm/50=gMg@030=_Kf`3MgMd0gMgM0080gMgM0`3GemL00`3MgMd0clo?0<o?c`020<o?c`030<k>
cP3?cll0`L710080`L7100<0`<300;Rh^02YZJT00P2MWId01@2FUYH0P82006QXJ01SHf<0CDe=0080
@D5100P0;bl_03<c<`0D51@0Ph>308B4Q01^KVh0R8R809RHV1L0moOg2@00000O0?ooo`L000000P3g
moL00`3gkoL0moOg0?Ogm`020?Ogm`80oooo00/0knOW09A[DP24FT80S6=:08ASBP2<HdX0_IAk0<JL
Q03N[I@0klJU0>o6[@020?O>]@80mmJm00<0mlje0>oFaP3ge[d0103ge[d00`3_e/H0mmJm0?OF_@02
0?OF_@<0mlje00<0mmJm0?O>]@3_aZd00P3_aZd00`3_aZD0klJ]0>NeW0020>NeW0030>NeU03N[H`0
eZF<0080_IAk00D0_HaS0:ecDP24DST0Q5Y207=2:@0205Xi:@08058Y600Q61P08A080:EkFP2UNf<0
]G]J0<J<H`3Wc[dG0?Ogm`P00000703oool001T0oooo200000080?Ogm`040?ooo`2UYJD0GUiN06YZ
JP80K6a/00D0Ph>309JFUP2YZJT0a/K60<?3``020<o?c`040=OGe`3De=@0emOG0=OGe`<0gMgM00L0
emOG0=gMg@3MgMd0emOG0=gMg@3EeMD0e]KF00<0emOG00H0e=CD0<o?c`3?cll0clo?0<k>cP3?cll2
0<k>cP<0`L710P2h^;P20;2`/00409FEU@24Q8@0MWIf06i^KP80Hf=S0P0k>c/02@0c<c<08B4Q08n?
S`22PX80MWIf06i^KP2FUYH0_Kfm0?Ogm`020?;blQ@0moOg2@00000O0?ooo`L000002@3gmoL0103o
ool0Q58i08ASBP1cDT8208aSBP070;f<H`3FW7/0gZfL0>NmY@3_]I`0klJ]0?O>]@020>o>[@80mlje
0P3ge[d0203gc[D0mmJm0?OF_@3gc[D0mmJm0>o>]@3gc[D0kljm0P3gc[D01P3_cZd0klJ]0>o6[@3_
aZd0klJU0>o6[@80klJU0`3W]I`20=j]U0060=JLN`3FYH@0]Hac0:EkH`2LJdX0S5Y20P24FT8205Xa
8@0:03TH400Y40P0]HA[09akH`2LJdX0_HaS0=JeY@3_inL0moOg0?O_maD0moOg2000000L0?ooo`00
6@3oool8000000P0moOg00D0oooo0=3@d015ADD0Hf=S065QH@0208>3P`0=09JFUP2UYJD0aLG50<g=
c@3?cll0c/k>0<o?c`3GemL0gMgM0=OGe`3Fe]H0gMgM0=OGe`040=gMg@<0emOG00H0clo?0=OGe`3?
cll0emOG0<o?c`3>c/h20<o?c`80c/k>01/0aLG50<30`030`<00^KVi0;Rh^02d];@0WIfM0:2PX02?
Shl0Q8B407]kN`1fMWH0De=C05YJFP1dM7@0:BTY024Q8@0W9bL0GUiN08>3P`1fMWH0P82009jNWP36
a/H0moOg0?;blP3oool0503gmoL9000001l0oooo200000080?Ogm`0=0?ooo`1[>B40Q5Y20:EkFP1k
FT80YG]J0;f<H`36W8@0gZfD0>NmW03WaZd0klJU0>o6[@020?O>]@040?OF_@3gc[D0mmJm0?O>]@@0
mmJm0P3gc[D01@3ge[d0mlje0?O>]@3_aZd0mlje00@0klJ]0P3_aZD06P3W_I`0ikFD0>NeU03N[I`0
gZf<0<j]U03FW7/0cYA[0;F4J`2UNf<0W7=B08AJ@P1cBS40Le9209A[DP128AP0>B4H07]J@P24DST0
YG]J09a[BP36U6/0ikfU0?O_m`3gmoL0mnog503gmoL9000001`0oooo000I0?ooo`P00000203gmoL0
4@3oool0^[Zj07]kN`1NGUh0JVYZ08B4Q023Ph<0UYJF0:VYZ@2i^KT0a/K60<o?c`3>c/h0clo?0=;B
dP3MgMd0e=CD00H0emOG00<0gMgM0=;BdP3Bd]800P3?cll00`33`l<0clo?0<k>cP030<k>cP050<o?
c`3>c/h0c/k>0<30`031`L400`2h^;P01`2`/;00WIfM08n?S`20P800Ng]k06i^KP1SHf<00P1NGUh0
2`11@D40De=C0451@@1CDe<0Q8B407]kN`2?Shl0UYJF0;Fe]@32`/80oooo01H0moOg2@00000O0?oo
o`P00000203gmoL04@3oool0W7=B08AB>@24DST0Q6=:0:EkH`2mS6<0eYak0=j]U03N[I`0ikfU0>o6
Y@3_aZd0mlJe0>o6[@3ge[d0klj]00D0mlje00<0mmJm0?O6]@3ga[D00P3_aZd00`3_]I`0klJ]0>o6
Y@030>o6Y@050>o6[@3_aZD0klJU0>NeU03W]I`00P3N[I@0203N[H`0eZF40;fDN`2eQ6/0[G=B09ac
DP2DHd80Q5Y20P24DST02`1J>BT0LdXa07=:<@1c@RT0YG]S09acDP2eQ6<0eZf<0=Jm[@3gmoL0oooo
01D0moOg2@00000L0?ooo`006@3oool:000000L0moOg00/0h>3P0<g=c@0k>c/0MWIf05iNGP1kNg/0
Rh^;09FEU@2h^;P0^KVi0<71`@020<?3``040<k>cP3=cLd0clo?0=GEe@@0clo?00D0c/k>0<o?c`3?
cll0b<S80;Zj^P020;^k^`030<30`032`/80^[Zj0080^[Zj00<0/[:b0;Rh^02k^k/00`2`/;000`2U
YJD0Z:RX09fMW@0208n?S`0@08>3P`1kNg/0IVIV06=SH`1JFUX0LW9b065QH@1CDe<0LW9b08n?S`24
Q8@0UYJF0;2`/035aLD0`/;20?;blP80moOg00<0oooo0?Ogm`3gmoL02@3gmoL00`3bl_80moOg0?Og
m`040?Ogm`/000007`3oool:000000L0moOg00X0g/K605Xa8@1c@RT0W6]:08AB>@2UQ6/0]Hac0=JU
S03N[I@0gZfL0P3_]I`00`3_aZD0klJ]0>O6[@040>o6[@0:0>o6]@3_aZd0klJ]0>o6[@3__I`0ikFL
0>N]S03W[I@0ikFD0>neU0<0ijf<00<0gZF40=j]S03W[I@00`3FYH@00`36W8@0eYac0;fDN`020;F4
H`0?0:EkFP2LLe80S5Y207]J@P1cDT80S6]B07]J@P1cBS40]HA[09AcFP2UNf<0_HaS0=JUQ03F_Jd0
mnog00h0moOg00<0mnog0?Ogm`3gmoL0103gmoL;000001`0oooo000I0?ooo`X00000203gmoL02`2]
[Jd0Ph>306=SH`1dM7@0K6a/07]kN`24Q8@0/;2`0<G5a@2i^KT0_Kfm0080`L710`3?cll01P3=cLd0
a/K60<K6aP36a/H0`L710;Vi^@80^;Rh0P2`/;030:VYZ@050:RXZ02YZJT0Z:RX0:RXZ02MWId00`2P
X:0209FEU@0;09fMW@2EUID0Shn?07IfMP1/K6`0NWYj07AdM01OGel0M7Ad05=CD`1/K6`00P1fMWH0
1P1kNg/0UYJF08n?S`2h^;P0aLG50?3`l1H0moOg2`00000O0?ooo`X000001`3gmoL02`36YI@0W7][
07]J@P24FT80U6]B09acDP2UNf<0_IAk0=JUS03W_I`0e[FU0080ikFL0`3_aZd00`3WaZd0ikfU0>Nm
Y@020>NmY@050=j]W03N[H`0gZfD0=j]U03FYH@00`3FW7/01@3FW7<0gYak0=JLL`3FW7<0_IAk00<0
cYA[00P0aXA[0;F<L`2mU7/0]Hac0;EkFP2LJdX0S6=:09AcFP<0U6]B00T0LdXa08aSBP2LJdX0W7=B
09a[BP2mS6<0]HAS0=j]U03gknL05P3gmoL;000001`0oooo000I0?ooo`/00000203gmoL0302a/K40
Hf=S06a/K01dM7@0Ph>308n?S`2EUID0WIfM0;Rh^02m_Kd0a/K60<k>cP<0a/K60140aLG50;Rh^02h
^;P0^;Rh0<G5a@2`/;00/[:b0;2`/02MWId0YJFU09FEU@2PX:00UYJF0:VYZ@2PX:00R8R809FEU@02
08R8R00:09JFUP2?Shl0Shn?08n?S`24Q8@0UIFE09fMW@2@T900Ph>308B4Q080K6a/00X0Q8B406=S
H`15ADD0GUiN08R8R02?Shl0UYJF0;Bd]02m_Kd0`/;21P3gmoL00`3bl_80moOg0?Ogm`0<0?Ogm`03
0?ooo`000000000000X000007`3oool;000000L0moOg00d0_Jf]09AcFP24FT80S6=:0:EkFP2eQ6/0
YG][0;F<L`2mU7/0e[FU0>NmY@3_aZD0ilJ]0080ikfU0140ikfL0=j]U03N[I@0eZF40=j]U03FYH`0
gZF40=JUQ03FYH`0_IAk0<J4J`3>U6/0_HaS0=JLN`3>Lf<0]G]J0;F<L`020;EkFP0E0;f<H`2eQ6<0
]HA[0;F4J`2UNf<0]Hac0:F4J`2US7<0YG]J0:EkH`2<HdX0U7=J0:EkH`24FT80JcTQ08AB>@2eQ6<0
]G]J0;f<H`3>[I@0e[FU00H0moOg00<0mnog0?Ogm`3gmoL0303gmoL00`3oool000000000000:0000
01`0oooo000I0?ooo``00000203gmoL0202ATI40NWYj065QH@1kNg/0Ph>309FEU@2UYJD0`/;20`3>
c/h01@36a/H0_Kfm0;Vi^@2`/;00];Bd00D0/;2`01`0WYjN09FEU@2EUID0Shn?09FEU@2?Shl0P820
08n?S`1kNg/0MWIf08n?S`1kNg/0Shn?0820P024Q8@0Ph>308B4Q01/K6`0M7Ad0820P01jNWX0Ng]k
07YjNP1kNg/0Hf=S079bLP1fMWH0Ng]k0P23Ph<20;fm_@050:FUY@3gmoL0moOg0?Ogm`3bl_803`3g
moL00`3bl_80moOg0?Ogm`0=000001l0oooo300000070?Ogm`080>oWi`2US7/0U7=J09acDP2UNeX0
S6=:0;F<L`36W8@30>O6]@80ikfU00<0e[FU0=JUQ03>[I@00P3FYH`30=JUQ080aYA[01`0]Hac0;F4
J`2eS7<0]HA[0:ecDP2eQ6/0W7=B09a[BP2eQ6/0W7=B0;F4H`2]Le80YG]S0:EkFP2UNf<0S6=:09Ac
FP2]Le80U7=J09acDP2DLeX0Q58i08AJ@P2<Je80W6]:09acDP2UNeX0aYA[0P3F]JD01@36W8@0moOg
0?Ogm`3gmoL0mnog00h0moOg00<0mnog0?Ogm`3gmoL03@00000L0?ooo`006@3oool<000000P0moOg
00d0TI6A08F5Q@24Q8@0OGem092@T02_[jl0Y:BT0;Vi^@2_[jl0^KVi0<;2`P2i^KT0^;Rh00<0/;2`
00H0WIfM0;2`/02UYJD0WYjN0:FUY@2MWId208n?S`0D07]kN`2MWId0Q8B409fMW@24Q8@0UYJF08>3
P`1fMWH0WIfM08>3P`24Q8@0Ph>308^;R`2@T900JVYZ07AdM022PX80LW9b07YjNP24Q8@206i^KP04
07IfMP1^KVh0Ng]k08n?S`80];Bd00<0]KFe0=CDe03gmoL00P3gmoL00`3oool0moOg0?Ogm`0@0?Og
m`d000007`3oool<000000P0moOg00T0YHak0:EkJ`2LLf<0YHac0<JUU03>YI@0_Ib<0<jUU03N[I`0
0P3F_Jd0:P3N[I`0gZfD0=JUQ03FYH`0_IAk0<JLQ03FYH@0aYA[0<JLQ02mU7/0aXA[0;F4H`2LLe80
_IAk0:EkH`2mU7/0]HAS0;f<H`2UNeX0W6]:0;fDN`2UNeX0YG]S0:EkFP2UQ6/0YHac08ASBP2UNeX0
W7]S08a[DP2DLeX0YG]S09a[BP2DHd80W6]:09AS@P2LLe80eZf40<jeY@3>[I@0eZf<0>O>aP<0moOg
00<0oooo0?Ogm`3gmoL03`3gmoL=000001`0oooo000I0?ooo`h000001`3gmoL01P3oool0Vi^K08F5
Q@24Q8@0YJFU0:f][@@0_Kfm0`2UYJD00`2MWId0YJFU09fMW@0208n?S`0409fMW@2?Shl0Ph>306i^
KP80Rh^;00D0K6a/05=CD`24Q8@0Shn?08>3P`0208B4Q00:06IVIP1fMWH0CDe=05=CD`1_Kfl0IVIV
06=SH`1VIVH0KVi^07IfMP80KVi^00X0GUiN07IfMP2d];@0WIfM0;Fe]@32`/80K6a/08^;R`3Bd]80
oooo1P3gmoL00`3bl_80moOg0?Ogm`0;0?Ogm`l000007`3oool=000000P0moOg00H0oooo0:EkJ`2U
Nf<0_IbD0<JLQ036YI@30=JeY@<0aYb40100_IAk0<JLQ02mU7/0_IAk0;F4J`2mU7/0]HAS0:EkFP2U
Nf<0U6=20:F4J`2<HdX0LdXa0:EkH`24FT80YG]J0P2UNf<02P2<FT80W6]:07=2:@1cBS40W6<i08aJ
@P24FT80W6<i09AS@P2LJdX209AS@P0:09aS>@2LJdX0cZfD0;fDN`3F[H`0S6=:0;fLS02UQ6/0g/k>
0?ooo`D0moOg00<0mnog0?Ogm`3gmoL0303gmoL>000001`0oooo000I0?ooo`h00000203gmoL02@2]
[Jd0S8b<06YZJP1fMWH0Rh^;0:f][@2j^[X0^KVi0;fm_@0209fMW@0709FEU@2MWId0WIfM09FEU@2@
T900UIFE08B4Q00208n?S`0609jNWP23Ph<0K6a/09fMW@1/K6`0Hf=S0P1/K6`0101dM7@0Hf=S06IV
IP1MGEd205iNGP0@06m_K`1NGUh0HF5Q06i^KP1NGUh0F5QH06IVIP1kNg/0Shn?0:FUY@2MWId0aLG5
0;fm_@2;Rh/0Ph>308^;R`L0moOg00<0l_;b0?Ogm`3gmoL02P3gmoL00`3bl_80moOg0000000>0000
01l0oooo3P0000080?Ogm`090:F4L`24HdX0W7=S09a[BP2UQ6/0c[FU0=j]W03F]JD0aZFD00@0_IAk
00@0]Hac0:F4J`2US7<0YG]S0P2eQ6<0302<HdX0aYA[08aSBP2mU7/0S6=:08AJ@P2UNf<0S6=:09A[
DP24FT80S5Y208AB<@80Q58i0100W6<i08AB>@1kFT80S5Y208AB>@24BS40S5Y209acDP2eQ6<0aYb4
0;fDN`3W_I`0e[FU0:EkFP2mW8`0YHA[103gmoL00`3gkoL0moOg0?Ogm`0<0?Ogm`030?O_m`3gmoL0
000000h00000703oool001T0oooo3P0000080?Ogm`0<0?ooo`1OGel0Ph>308F5Q@2;Rh/0Vi^K0;:b
/P2j^[X0/;2`08B4Q02?Shl0Rh^;0P2MWId308n?S`0>08B4Q02EUID0Q8B406=SH`1kNg/0NWYj06a/
K023Ph<0Hf=S06i^KP1SHf<0JVYZ06=SH`1JFUX205iNGP0705=CD`1=CDd0GUiN065QH@1NGUh0GEeM
06a/K00308>3P`070:FUY@2j^[X0PX:208:2PP2;Rh/0[Jf]0>WYj@020?;blP80moOg00<0l_;b0?Og
m`3bl_800P3gmoL01@3oool0moOg0?Ogm`3gmoL0oooo00P0moOg3`00000O0?ooo`h00000203gmoL0
2`1cFTX0W7][0;fLS02UNf/0YHA[0<J]W03>]JD0eZF<0<JUU02UNf<0]HA[0080_IAk0140]HA[09ac
H`2eQ6/0YG]S0;F<L`2UNf<0]HAS08AJ@P2DLeX0S6=:0:EkFP24FT80S6=:08AJ@P24HdX0Q5Y207=B
@P0208AB>@0407=:<@1c@RT0Q58i07]J@P80Q58a00H0S6=:0:EkFP2UNeX0YG]J0<JLQ03>]JD209ak
H`030<JUU02mU7/0knOW0080mnog00L0moOg0?O_m`3gmoL0moOg0?O_m`3gmoL0oooo00`0moOg3`00
000L0?ooo`006@3oool?000000T0moOg00D0Ph>309^KV`2QXJ40Y:BT09^KV`020;fm_@0608>3P`2E
UID0Q8B408B4Q02?Shl0Ph>30P2;Rh/04@1jNWX0Q8B407YjNP1SHf<0Ph>307IfMP1dM7@0FUYJ05=C
D`1JFUX0HF5Q06=SH`1QHF40GEeM05=CD`15ADD0@D5100<0CDe=00`0GEeM06=SH`1/K6`0Rh^;0:FU
Y@2MWId0^[Zj0:BTY02@T900M7Ad0:FUY@1dM7@20?ooo`030?;blP3gmoL0moOg0140moOg4000000O
0?ooo`l00000203gmoL01@2LNf/0LdXa0;FDN`2eW8`0]IAk0080e[FU01T0aZfL0:EkFP2eS7<0YG]S
0;F4H`2UNeX0U7=J0:F4J`2DLeX0YG]S09AcFP2UNf<0Q5Y209a[BP2DJe80Le9207=:<@2UNeX0NeY2
08AJ@P1kFT80Q58a07=:<@1[>B40FSTY00<0Ld8Y00T0W6]:08AJ@P2<HdX0YHA[0<JLQ03W_JD0c[FU
0;fLS02US7<00P2DJe80103_inL0oooo0?ooo`3gkoLB0?Ogma000000703oool001T0oooo40000006
0?Ogm`0L0?;blP3gmoL0oooo04e=C@1kNg/0S8b<09^KV`2j^[X0`/;208>3P`1dM7@0Vi^K08B4Q02E
UID0Vi^K07AdM02;Rh/0Ph>306a/K024Q8@0K6a/07]kN`23Ph<0NWYj079bLP0k>c/0HF5Q08>3P`80
GUiN00D0ADE505iNGP15ADD0>c/k0451@@0203/k>`0<05=CD`2;Rh/0WIfM08n?S`2MWId0^[Zj06YZ
JP20P800Shn?08^;R`1fMWH0[Jf]1@3gmoL00`3bl_80oooo0?Ogm`0=0?Ogma4000007`3oool@0000
00L0moOg0140oooo0:EkJ`1c@RT0U7=S0;FDN`3>]JD0e[f]0<J]W02UNeX0U6]B0:EkH`2eS7<0]IAk
0;F4H`2DJe80YG]J08aSBP020:EkH`0708aSBP2UNeX0U7=J08a[DP1J<B40LdXa0:EkFP0208AB>@05
06/i8@24DST0JcTQ05Xa8@1J>BT00P1J<B402`2<FT80YHA[0;fDN`2eQ6/0_IAk0;FDN`24HdX0U7][
0;F4H`2UQ6/0aZFL00D0moOg00<0mnog0?Ogm`3oool02@3gmoL0103gkoL0moOg0?Ogm`3gmoLA0000
01`0oooo000I0?oooa400000203gmoL02P1]KFd0HF5Q06YZJP2@T900Y:BT0;:b/P2;Rh/0M7Ad08>3
P`2EUID207YjNP0;079bLP1/K6`0OGem07YjNP1bLW80Q8B407YjNP1/K6`0Ph>307]kN`1bLW800P1C
De<01@1ZJVX0GUiN05iNGP1VIVH0MWIf0080GEeM00/0IVIV07IfMP20P800UYJF0:FUY@3;bl/0Vi^K
0:BTY01CDe<0NWYj08^;R`0209^KV`D0moOg00<0oooo0?Ogm`3gmoL0103gmoL00`3oool0moOg0?Og
m`040?Ogm`030?ooo`3gmoL00000014000007`3ooolA000000L0moOg00X0g/k>07][FP1kFT80YHac
0;fLS036[I`0e[FU0:F4J`2DJe80]Hac0P2DLeX03P2UNf<0S6]B09acH`2DLeX0S6]B09A[DP2UNf<0
S6=:0:EkFP2LLe80S6]B08aSBP1cBS40Q6=:0P24DST0402<FT80W6]:08AB<@24DS40U5Xa09a[BP2U
Nf<0_HaS0<JLQ03Na[D0]IAk09akJ`1cBS40U7=J0:F4J`2eU7/50?Ogm`030?ooo`3gmoL0mnog00@0
moOg00<0oooo0?Ogm`3gmoL01@3gmoL00`3oool000000000000@000001`0oooo000I0?oooa<00000
0`3gmoL02`3oool0moOg0?Ogm`3gmoL0/K6a07YjNP1kNg/0OGem08^;R`2UYJD0[Jf]0080LW9b0`2;
Rh/0301NGUh0Hf=S06=SH`1fMWH0Ng]k05iNGP25QHD0Ng]k09FEU@24Q8@0Vi^K07AdM080IVIV0P1k
Ng/00`2?Shl0UYJF09JFUP020;2`/00:0:f][@23Ph<0Ph>306IVIP1=CDd0GUiN08^;R`22PX80WIfM
0?ooo`80moOg0P3oool20?Ogm`030?ooo`3gmoL0moOg00/0moOg5000000O0?oooa800000203gmoL0
202m[Jd0U7=S09acH`2UQ6/0YHak0<JLQ036YI@0S6]B0P2UQ6/03@2DJe80YHA[08AJ@P24FT80W6]:
09A[DP2LLe80YG][09acDP2eS7<0YG]S0;F4J`2DJe800P2<FT8209acDP030;F4H`2mS6<0_HaS0080
eZF400X0YG]S09akJ`2LNf/0S5Y207=2:@2UNf<0YHA[09akH`2mU7/0oooo0P3gmoL20?ooo`030?Og
m`3oool0moOg00d0moOg4`00000L0?ooo`006@3ooolD00000080moOg00<0l_;b0?Ogm`3gmoL00P3g
moL06@2l_;`0Jf][07]kN`2@T900Y:BT0:f][@2b/[80NWYj08^;R`1/K6`0NWYj08B4Q01dM7@0GUiN
05aLG01/K6`0HF5Q07emO@1kNg/0WIfM09FEU@3>c/h0_Kfm0:FUY@2i^KT00P2`/;020<g=c@0<0;Rh
^02j^[X0T92@079bLP1dM7@0Hf=S065QH@1/K6`0Shn?08B4Q025QHD0oooo0P3gmoL00`3oool0moOg
0?Ogm`060?Ogm`80oooo1`3gmoLE000001l0oooo4`0000050?Ogm`0K0?O_m`3gmoL0moOg08ASDP2D
Lf<0YHac0;FDN`2mW8`0aZFD09AcFP2UQ6/0S6=:0:F4L`2DLeX0U6]B08AB>@1kDT80LdXa08aSBP2L
Lf<0W7=B0;fDN`2eS7<0g/Je0=JeY@36W8@0gZfL0080eZF<0P3WaZd03P3N[I@0c[FU0:F<L`2LNf<0
U6]B08AJ@P1kFT80S6=:0;FDN`2UNf<0YG][0?ooo`3gmoL0oooo1P3gmoL0103gkoL0moOg0?Ogm`3o
ool80?Ogma@00000703oool001T0oooo500000050?Ogm`070?ooo`3gmoL0moOg0>o_k`2:RXX0Ng]k
092@T0020;Zj^P0E0;Bd]02<S8`0UIFE096AT@25QHD0WIfM0:f][@23Ph<0LW9b05aLG01jNWX0Vi^K
0:f][@2TY:@0`/;20<?3``32`/80bl_;0=WIf@3De=@0YJFU0080Vi^K00T0S8b<07]kN`1jNWX0FUYJ
05iNGP1jNWX0PX:209fMW@2KVi/00`3gmoL0103bl_80moOg0?;blP3bl_830?Ogm`030?;blP3gmoL0
moOg00<0moOg00<0l_;b0?Ogm`3gmoL00`3gmoLE000001l0oooo500000050?Ogm`0M0?ooo`3gmoL0
knog09b4N`2DLf<0Lf=B0:F<L`3>]JD0cZfD0:F4L`2eS7<0YHAc0:F<N`2mU7/0aZFD09akJ`1kDT80
S6]B09AcFP2eU7/0aZFD0;fLS02US7/0e[fe0=Jm[@3Na[D0imK60>O>aP36W8@00P2eU7/02@2UQ7<0
U7=S09A[DP1cDT80Q58i09AcFP2LNf<0YG]S0;FDN`050?Ogm`80mnog0P3gmoL00`3gkoL0moOg0?Og
m`030?Ogm`030?O_m`3gmoL0moOg00<0moOg5@00000L0?ooo`006@3ooolF000000<0moOg00X0oooo
0?Ogm`3gmoL0moOg0?ooo`23Ph<0RHV9096AT@2b/[80cLg=0P2b/[802`2a/K40d=3@0<?3``2][Jd0
e=CD0?3`l03Xj>P0fm_K0=CDe03Cdm<0`/;200<0bl_;00D0dm?C0;Zj^P2@T900T92@08:2PP0208>3
P`0406a/K01bLW80Q8B4092@T080Rh^;00D0Q8B40?Ogm`3gmoL0oooo0?;blP030?Ogm`030?;blP3g
moL0moOg00@0moOg00L0oooo0?Ogm`3gmoL0l_;b0?Ogm`3bl_80moOg01L000007`3ooolF000000<0
moOg00T0oooo0?Ogm`3gmoL0oooo09akJ`24He80W8Ac0:F<N`3Na/H00P36[I`0303F_KD0_Jf]0=Jm
]@36YI`0ilk60>oFaP3gknL0kmK60>O>aP3Wc[d0e[f]0=k>_@80g/Je00D0iljm0<jeY@2US7<0YHac
09akH`0209akJ`0408aSBP1cFTX0YG]S0:F<L`80YHA[00D0oooo0?Ogm`3gmoL0oooo0?O_m`030?Og
m`050?O_m`3gmoL0moOg0?Ogm`3gkoL0103gmoL0103gkoL0moOg0?Ogm`3gkoLG000001`0oooo000I
0?oooaL000000P3gmoL00`3oool0moOg0?Ogm`030?Ogm`0706][J`1hN7P0Vi^K0:^[Z`33`l<0d=3@
0=7Ad@030=3@d00K0=[JfP3>c/h0dm?C0<k>cP3Kfm/0hN7Q0=[JfP3De=@0^[Zj0:FUY@32`/80Y:BT
0:6QX@1gMgL0Ph>306a/K01bLW80Ph>308b<S02UYJD0UIFE08^;R`2][Jd0moOg0?;blP3gmoL0l_;b
00H0moOg00<0l_;b0?Ogm`3gmoL0203gmoLH000001l0oooo5P0000030?Ogm`030?ooo`3gmoL0moOg
0080moOg00P0imkN08ASDP2<Lf<0_JFL0=Jm]@3Nc[d0imK>0=k>aP80g/jm01/0imK>0=k6]@3Wa[D0
ilJe0>oFaP3_g/h0imK>0=k>_@3>]JD0_IbD0=Jm[@2mW8`0]Ib<08acFP2UNeX0S6=:08a[DP2LNf/0
_Ib<0<JLQ02eS7<0YHA[0<JUW03gmoL0mnog0?Ogm`3gkoL04@3gmoLG000001`0oooo000I0?oooaT0
00001@3gmoL0203bl_80oooo0?Ogm`3gmoL0WIfM08>3P`2<S8`0cLg=0P3Jf]X03`3IfMT0e=CD0=_K
f`3AdM40cLg=0<?3``2b/[80Y:BT0:f][@2b/[80XJ6Q096AT@1_Kfl0QHF5096AT@020;:b/P040;Zj
^P2b/[80TY:B0?;blPD0moOg00<0oooo0?Ogm`3gmoL0103gmoL00`3oool0moOg0?ooo`020?Ogm`03
0?;blP3gmoL0oooo0080moOg6P00000O0?oooaT00000103gmoL06@3gkoL0moOg0?ooo`3gmoL0]IB<
09akJ`2UQ7<0c[Fe0=k6aP3We/h0imK60>O>aP3Na/H0imKF0=k6aP3F_KD0aZfL0;fLS02eU7/0aZfL
0;FLS02US7/0Q6]B0:EkJ`2US7/00P36[I`0103>]JD0aZfL0<J]W03gkoL50?Ogm`050?ooo`3gmoL0
moOg0?Ogm`3gkoL00P3gmoL20?ooo`<0moOg00@0mnog0?ooo`3gmoL0moOg6P00000L0?ooo`006@3o
oolJ00000080moOg00@0l_;b0?ooo`3gmoL0oooo1@3gmoL01P2MWId0^[Zj0;bl_033`l<0fm_K0=[J
fP80fm_K00P0f][J0<?3``33`l<0Zj^[09fMW@2j^[X0d=3@0:FUY@80`l?300@0YJFU09^KV`32`/80
jNWY0P3oool30?Ogm`030?ooo`3gmoL0moOg0080moOg00<0oooo0?Ogm`3gmoL00`3gmoL00`3bl_80
moOg0?Ogm`040?Ogma/000007`3ooolJ000000030?Ogm`3gkoL0oooo0080moOg00<0oooo0?Ogm`3g
moL00P3gmoL0102mW9@0]IB<0<je]@3F_KD20>OFeP030>OFcP3We]H0imK>0080e[fe00D0aZFL0;FD
S03>]JD0g/jm0;fLU0020=Jm]@040;fLU02eU7/0e[f]0>oWi`80oooo3@3gmoL00`3gkoL0moOg0?Og
m`040?Ogma/00000703oool001T0oooo700000060?Ogm`080?ooo`3gmoL0oooo0?Ogm`2a/K40Zj^[
0<?3``2][Jd20=7Ad@0=0=oOg`3Kfm/0j>SX0?3`l03Jf]X0d=3@0=[JfP3AdM40d=3@0:f][@2j^[X0
d=3@0>WYj@020?Ogm`030?ooo`3bl_80moOg00D0moOg00@0l_;b0?Ogm`3gmoL0l_;b0P3gmoL00`3b
l_80moOg0?Ogm`040?Ogmad000007`3ooolK000000H0moOg00<0oooo0?Ogm`3oool00P3gmoL04P2m
YI`0e[fe0<JUW03F_Jd0g/k60>ONeP3We]H0knON0?O_i`3_imh0g/jm0>OFcP3Nc/H0g/jm0<JUW03>
]JD0g/jm0>oWi`80moOg00<0oooo0?O_m`3gmoL01@3gmoL00`3gkoL0moOg0?O_m`030?Ogm`030?O_
m`3gmoL0moOg00<0moOg7@00000L0?ooo`006@3ooolN000000050?Ogm`3bl_80moOg0?Ogm`3oool0
0P3bl_820?Ogm`<0l_;b00P0jNWY0>3Ph03`l?00j>SX0=3@d033`l<0d=3@0=7Ad@80cLg=00<0d];B
0>WYj@3gmoL0103gmoL00`3oool0moOg0?ooo`020?ooo`@0moOg0P3bl_850?Ogm`030?;blP3gmoL0
l_;b01l000007`3ooolM00000080moOg00<0mnog0?Ogm`3oool00P3gkoL20?Ogm`<0mnog0P3_inL0
0`3gknL0knON0=k>_@020=Jm]@050=k>aP3Na/H0g/K60=k>cP3_inL01@3gmoL00`3oool0moOg0?oo
o`020?ooo`@0moOg00<0mnog0?Ogm`3gmoL00`3gmoL0103gkoL0moOg0?ooo`3gkoLN000001`0oooo
000I0?oooal0000000<0moOg0?;blP3gmoL01`3gmoL00`3oool0moOg0?Ogm`020?Ogm`<0l_;b00<0
oooo0?Ogm`3gmoL00`3gmoL20?ooo`L0moOg00D0l_;b0?ooo`3gmoL0moOg0?ooo`020?Ogm`060?oo
o`3gmoL0oooo0?Ogm`3oool0moOg8000000O0?oooal0000000<0moOg0?O_m`3gmoL01P3gmoL00`3o
ool0moOg0?Ogm`020?Ogm`<0mnog00<0oooo0?Ogm`3gmoL00`3gmoL20?ooo`80moOg00<0oooo0?Og
m`3gmoL00`3gmoL0103oool0moOg0?Ogm`3oool20?Ogm`050?ooo`3gmoL0oooo0?ooo`3gmoL08000
000L0?ooo`006@3ooolS00000080moOg00@0l_;b0?Ogm`3gmoL0oooo0P3gmoL0103oool0moOg0?Og
m`3oool20?Ogm`030?;blP3gmoL0moOg00<0moOg00<0l_;b0?Ogm`3oool00P3gmoL02@3oool0moOg
0?Ogm`3gmoL0l_;b0?Ogm`3bl_80moOg0?ooo`030?Ogm`030?ooo`0000000000028000007`3ooolR
000000<0moOg00<0mnog0?Ogm`3oool01@3gmoL0103oool0moOg0?Ogm`3gkoL50?Ogm`040?O_m`3g
moL0oooo0?Ogm`80oooo1@3gmoL00`3gkoL0moOg0?ooo`030?Ogm`030?ooo`000000000002400000
703oool001T0oooo9@000000103gmoL0l_;b0?ooo`3bl_820?Ogm`060?ooo`3gmoL0moOg0?Ogm`3o
ool0l_;b0P3gmoL00`3bl_80moOg0?Ogm`060?Ogm`040?ooo`3gmoL0moOg0?;blP@0moOg00<0l_;b
0?ooo`3oool09P00000O0?ooobD0000000<0moOg0?ooo`3gkoL01P3gmoL01@3oool0moOg0?Ogm`3g
moL0mnog00P0moOg00D0oooo0?Ogm`3gmoL0mnog0?ooo`030?Ogm`030?O_m`3oool0000002D00000
703oool001T0oooo:@000000103gmoL0l_;b0?Ogm`3oool30?Ogm`030?ooo`3gmoL0oooo00D0moOg
00<0l_;b0?Ogm`3oool0203gmoLZ000001l0oooo:0000000103gmoL0oooo0?O_m`3oool50?Ogm`03
0?ooo`3gmoL0moOg00<0moOg00<0mnog0?Ogm`3oool0203gmoLY000001`0oooo000I0?ooob`00000
0P3oool20?Ogm`030?;blP3gmoL0moOg00@0moOg0P3bl_820?Ogm`050?ooo`3gmoL0oooo0?Ogm`3o
ool0;@00000O0?ooob/000000P3oool20?Ogm`030?ooo`3gmoL0moOg00@0moOg0P3gkoL20?Ogm`05
0?O_m`3gmoL0oooo0?Ogm`3oool0;000000L0?ooo`006@3ooom]000001l0ooooJ`00000L0?ooo`00
6@3ooom]000001l0ooooJ`00000L0?ooo`006@3ooom]000001l0ooooJ`00000L0?ooo`006@3ooom]
000001l0ooooJ`00000L0?ooo`00o`3oool]0?ooo`00o`3oool]0?ooo`00o`3oool]0?ooo`00o`3o
ool]0?ooo`00o`3oool]0?ooo`00o`3oool]0?ooo`00o`3oool]0?ooo`00<@3oool2@00000030?oo
od00001000000080oooo0T0000000`3ooom00000@00000020?ooo`03@000003oool0oooo00900000
0P3oool3@00000070?oood0000100000@000003ooom000000?ooo`03@00000<0oooo0T0000001P3o
oom000000?oood000000oooo@0000080oooo0T00001/0?ooo`9000000`3oool2@0000080oooo0d00
00030?ooo`9000000P3oool3@00004P0oooo000a0?ooo`07@000003oool0oooo0?oood000000oooo
@00000020?ooo`03@000003ooom000000080oooo00=000000?oood0000000P3oool00d000000oooo
@00000040?ooo`04@000003oool0oooo@0000080oooo00E000000?ooo`3oool0oooo@00000020?oo
o`90000000H0oooo@000003ooom000000?oood00001]0?ooo`03@000003oool0oooo0080oooo00A0
00000?ooo`3ooom000000P3oool01D000000oooo0?ooo`3ooom000000080oooo00A000000?ooo`3o
oom00000B@3oool00340oooo00M000000?oood000000oooo@000003ooom000000080oooo00=00000
0?oood0000000P3oool00d000000oooo@00000020?ooo`03@000003ooom0000000@0oooo00A00000
0?ooo`3ooom000000P3oool01D000000oooo0?ooo`3ooom000000080oooo0T0000001@3ooom00000
0?oood000000oooo00=00000J`3oool00d000000oooo0?ooo`020?ooo`04@000003oool0oooo@000
0080oooo00E000000?ooo`3oool0oooo@00000020?ooo`04@000003oool0oooo@00004T0oooo000a
0?ooo`90000000<0oooo@000040000000P3oool2@00000030?oood0000100000009000000`3oool2
@0000080oooo0d0000020?ooo`=000000P3oool4@0000080oooo0T0000001@3ooom00000@000003o
oom000000080oooo0d00001[0?ooo`03@000003oool0oooo00<0oooo0T0000030?ooo`03@000003o
ool0oooo0080oooo0T0000020?ooo`A00000A`3oool00340oooo0T0000000`3ooom00000@000000E
0?ooo`03@000003oool0oooo07l0oooo00=000000?oood000000203oool00d000000oooo0?ooo`1A
0?ooo`00<@3oool2@00000030?oood000010000001@0oooo0T0000210?ooo`=000001`3oool2@000
05<0oooo003o0?ooobd0oooo003o0?ooobd0oooo003o0?ooobd0oooo003o0?ooobd0oooo003o0?oo
obd0oooo003o0?ooobd0oooo003o0?ooobd0oooo003o0?ooobd0oooo003o0?ooobd0oooo003o0?oo
obd0oooo003o0?ooobd0oooo003o0?ooobd0oooo000e0?ooo`900000=P3oool3@0000600oooo0d00
001I0?ooo`00=`3oool00d000000oooo0?ooo`0d0?ooo`03@000003oool0oooo0600oooo00=00000
0?ooo`3oool0F03oool002T0oooo0d0000030?ooo`=000000`3oool3@00000D0oooo00=000000?oo
o`3oool02@3oool00d000000oooo0?ooo`020?ooo`03@000003oool0oooo00P0oooo1D0000001P3o
oom000000?ooo`3ooom000000?ooo`E0000000D0oooo@000003ooom000000?ooo`03@0000080oooo
0d0000030?ooo`9000000P3oool2@0000180oooo0T0000020?ooo`=000002P3oool00d000000oooo
@00000020?ooo`=0000000<0oooo@000040000000P3oool00d000000oooo0?ooo`03@0000080oooo
0T0000020?ooo`03@000003ooom0000000l0oooo0T0000020?ooo`=000000`3oool2@0000080oooo
0d0000020?ooo`A000000P3oool2@0000080oooo0d0000030?ooo`90000000<0oooo@00004000000
0P3oool00d000000oooo0?ooo`0b0?ooo`00:P3oool00d000000oooo0?ooo`030?ooo`05@000003o
ool0oooo0?oood0000000P3oool00d000000oooo0?ooo`0>0?ooo`03@000003ooom0000000l0oooo
00A000000?ooo`3ooom000000P3oool2@0000080oooo0d000000203ooom000000?oood000000oooo
@000003ooom000000P3oool014000000oooo0?oood0000030?ooo`03@000003oool0oooo00@0oooo
00=000000?ooo`3oool03P3oool014000000oooo0?oood0000020?ooo`03@000003oool0oooo00P0
oooo00E000000?oood000000oooo@00000020?ooo`05@000003oool0oooo0?oood0000000P3oool0
0d000000oooo@00000020?ooo`03@000003ooom000000080oooo0T000000103ooom000000?oood00
000=0?ooo`06@000003oool0oooo@000003ooom000000P3oool00d000000oooo@00000050?ooo`04
@000003oool0oooo0?ooo`=000000P3oool014000000oooo0?oood0000020?ooo`05@000003oool0
oooo0?oood0000000P3oool00d000000oooo@00000020?ooo`03@000003oool0oooo0380oooo000Z
0?ooo`03@000003oool0oooo00<0oooo00E000000?ooo`3oool0oooo@00000020?ooo`03@000003o
ool0oooo0100oooo00=000000?ooo`3oool03@3oool00d000000oooo0?ooo`030?ooo`900000103o
ool02D000000oooo@000003ooom000000?oood000000oooo@00000020?ooo`04@000003oool0oooo
@00000<0oooo0d0000030?ooo`03@000003oool0oooo00l0oooo00A000000?ooo`3ooom000000P3o
ool00d000000oooo0?ooo`080?ooo`05@000003ooom000000?oood0000000P3oool01D000000oooo
0?ooo`3ooom000000080oooo00=000000?oood0000000P3oool00d000000oooo@00000020?ooo`90
000000@0oooo@000003ooom000003@3oool01T000000oooo0?oood000000oooo@0000080oooo00=0
00000?oood0000000T0000030?ooo`03@000003oool0oooo00<0oooo00A000000?ooo`3ooom00000
1@3oool01D000000oooo0?ooo`3ooom000000080oooo00=000000?oood0000000P3oool00d000000
oooo0?ooo`0b0?ooo`00:P3oool2@00000<0oooo0T0000040?ooo`=00000403oool2@0000100oooo
0T0000030?ooo`04@000003oool0oooo@0000080oooo0T0000001P3ooom00000@000003ooom00000
0?ooo`A000000`3oool014000000oooo0?ooo`3oool3@00000<0oooo0T00000A0?ooo`9000000P3o
ool3@00000T0oooo0T000000103ooom00000@000003oool2@0000080oooo140000030?ooo`=00000
0P3oool2@00000040?oood00001000000?ooo`9000003P3oool2@00000030?oood00001000000090
00000P3oool3@0000080oooo140000020?ooo`90000000<0oooo@000040000000T0000020?ooo`90
0000103oool2@00000030?oood000010000000900000=@3oool002X0oooo00A000000?ooo`3ooom0
00006P3oool00d000000oooo0?ooo`0?0?ooo`04@000003oool0oooo@00001H0oooo00=000000?oo
o`3oool07`3oool00d000000oooo0?ooo`0K0?ooo`03@000003oool0oooo02h0oooo00=000000?oo
o`3oool0A03oool002T0oooo1D0000020?ooo`03@000003oool0oooo01D0oooo0d00000>0?ooo`E0
00005@3oool2@0000280oooo00=000000?ooo`3oool03P3oool00d000000oooo0?ooo`080?ooo`90
0000=P3oool00d000000oooo0?ooo`0n0?ooo`00o`3oool]0?ooo`00o`3oool]0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 299}, {149, 0}} -> {-0.124513, -0.0238147, 
  0.00752183, 0.00752183}, {{16.5, 143.125}, {145.813, 
  19.1875}} -> {-30.3128, -6.32728, 1.18168, 1.18168}, {{155.813, 282.438}, {
  145.813, 19.1875}} -> {-197.425, -7.0035, 1.19304, 1.19304}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["1.7 Summary",
  FontFamily->"Times New Roman",
  FontSize->16,
  FontWeight->"Bold"]], "Section"],

Cell[TextData[{
  StyleBox["\t",
    FontFamily->"Times New Roman",
    FontSize->10.5],
  StyleBox[
  "This chapter has described about the most basic and fundamental part of \
this book. In spite of no knowledge about the programming language \
\[OpenCurlyDoubleQuote]",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"],
  StyleBox["Mathematica",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox[
  "\[CloseCurlyDoubleQuote], every one may be understood how to input and \
draw the images in the ",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"],
  StyleBox["Mathematica",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox[
  " notebook. Also, every one may be revealed that an image processing is not \
the simple try and error processes using the image handling software, but are \
the ",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"],
  StyleBox["Mathematica",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox["l list and matrix operations. One of the best merits using the ",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"],
  StyleBox["Mathematica",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox[
  " is that every one can use the codes described in this textbook only \
setting up their original bitmap image data. ",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell[CellGroupData[{

Cell[TextData[StyleBox["REFERENCES", "Section",
  FontFamily->"Century",
  FontSize->12]], "Subsection"],

Cell[TextData[{
  StyleBox["[1] ",
    FontFamily->"Century",
    FontSize->10.5],
  StyleBox["Stephen Wolfram, ",
    FontFamily->"Century"],
  StyleBox["The Mathematica Book",
    FontFamily->"Century",
    FontSlant->"Italic"],
  StyleBox[
  ", 3rd ed. (Wolfram Media/Cambridge University Press, 1996).\n[2] Yoshifuru \
Saito, ",
    FontFamily->"Century"],
  StyleBox["Introduction to image processing by Mathematica",
    FontFamily->"Century",
    FontSlant->"Italic"],
  StyleBox[" in Japanese ",
    FontFamily->"Century"],
  StyleBox["(Asakura Publishing Co.LTD., Tokyo 1998).",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Century",
    FontSize->10.5],
  StyleBox["  ",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Century"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 723}},
ScreenStyleEnvironment->"Working",
WindowToolbars->{"RulerBar", "EditBar"},
WindowSize->{763, 619},
WindowMargins->{{Automatic, -5}, {Automatic, 5}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic},
PageHeaders->{{Cell[ 
        TextData[ {
          CounterBox[ "Page"]}], "PageNumber"], Inherited, Cell[ 
        TextData[ {
          OptionValueBox[ "FileName"]}], "Header"]}, {Cell[ 
        TextData[ {
          OptionValueBox[ "FileName"]}], "Header"], Inherited, Cell[ 
        TextData[ {
          CounterBox[ "Page"]}], "PageNumber"]}},
PrintingOptions->{"FirstPageHeader"->False,
"FacingPages"->True},
ShowCellLabel->False,
StyleDefinitions -> "Textbook.nb"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 281, 9, 52, "Title"],

Cell[CellGroupData[{
Cell[2045, 64, 160, 4, 84, "Section"],
Cell[2208, 70, 2674, 82, 135, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4919, 157, 186, 6, 85, "Section"],
Cell[5108, 165, 2644, 66, 186, "Text"],
Cell[7755, 233, 203, 6, 92, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7995, 244, 226, 8, 84, "Section"],
Cell[8224, 254, 1843, 39, 144, "Text"],

Cell[CellGroupData[{
Cell[10092, 297, 52, 1, 32, "Input"],
Cell[10147, 300, 537, 10, 100, "Output"]
}, Open  ]],
Cell[10699, 313, 213, 3, 25, "Text"],

Cell[CellGroupData[{
Cell[10937, 320, 71, 1, 32, "Input"],
Cell[11011, 323, 93, 2, 24, "Output"]
}, Open  ]],
Cell[11119, 328, 799, 25, 42, "Text"],

Cell[CellGroupData[{
Cell[11943, 357, 99, 4, 52, "Input"],
Cell[12045, 363, 71, 2, 24, "Output"]
}, Open  ]],
Cell[12131, 368, 1747, 40, 135, "Text"],

Cell[CellGroupData[{
Cell[13903, 412, 609, 17, 312, "Input"],
Cell[14515, 431, 227610, 4154, 158, 108479, 2679, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[242140, 4588, 799, 22, 42, "Text"],

Cell[CellGroupData[{
Cell[242964, 4614, 66, 1, 32, "Input"],
Cell[243033, 4617, 958, 16, 138, "Output"]
}, Open  ]],
Cell[244006, 4636, 1481, 40, 101, "Text"],
Cell[245490, 4678, 88, 4, 52, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[245615, 4687, 244, 9, 84, "Section"],
Cell[245862, 4698, 841, 23, 59, "Text"],
Cell[246706, 4723, 153, 6, 92, "Input"],
Cell[246862, 4731, 755, 14, 42, "Text"],
Cell[247620, 4747, 161, 6, 92, "Input"],
Cell[247784, 4755, 204, 6, 25, "Text"],

Cell[CellGroupData[{
Cell[248013, 4765, 70, 1, 32, "Input"],
Cell[248086, 4768, 63, 2, 24, "Output"]
}, Open  ]],
Cell[248164, 4773, 561, 15, 42, "Text"],

Cell[CellGroupData[{
Cell[248750, 4792, 70, 1, 32, "Input"],
Cell[248823, 4795, 63, 2, 24, "Output"]
}, Open  ]],
Cell[248901, 4800, 536, 15, 42, "Text"],

Cell[CellGroupData[{
Cell[249462, 4819, 142, 4, 52, "Input"],
Cell[249607, 4825, 174922, 2604, 296, 35993, 884, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[424544, 7432, 1294, 23, 152, "Text"],

Cell[CellGroupData[{
Cell[425863, 7459, 644, 11, 230, "Input"],
Cell[426510, 7472, 177350, 3124, 158, 73431, 1837, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[603909, 10602, 125, 3, 83, "Section"],
Cell[604037, 10607, 1548, 35, 101, "Text"],

Cell[CellGroupData[{
Cell[605610, 10646, 369, 7, 92, "Input"],
Cell[605982, 10655, 242758, 3260, 296, 102901, 1528, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[848789, 13921, 301, 11, 83, "Section"],
Cell[849093, 13934, 692, 16, 76, "Text"],
Cell[849788, 13952, 451, 8, 170, "Input"],
Cell[850242, 13962, 1011, 21, 59, "Text"],
Cell[851256, 13985, 68, 1, 32, "Input"],
Cell[851327, 13988, 441, 13, 42, "Text"],
Cell[851771, 14003, 235, 8, 132, "Input"],
Cell[852009, 14013, 411, 13, 42, "Text"],

Cell[CellGroupData[{
Cell[852445, 14030, 527, 11, 192, "Input"],
Cell[852975, 14043, 222281, 3484, 158, 140027, 2465, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[1075305, 17533, 121, 3, 83, "Section"],
Cell[1075429, 17538, 1822, 56, 93, "Text"],

Cell[CellGroupData[{
Cell[1077276, 17598, 104, 2, 38, "Subsection"],
Cell[1077383, 17602, 840, 29, 52, "Text"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

