(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[   7158015,     134823]*)
(*NotebookOutlinePosition[   7159306,     134864]*)
(*  CellTagsIndexPosition[   7159262,     134860]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[StyleBox["Chapter 2. Monochrome Image Processing",
  TextAlignment->Left,
  TextJustification->0,
  FormatType->InputForm,
  FontFamily->"Century",
  FontSize->24,
  FontWeight->"Bold"]], "Title",
  TextAlignment->Left,
  TextJustification->0,
  FormatType->InputForm],

Cell[CellGroupData[{

Cell[TextData[StyleBox["2.1 Introduction",
  FormatType->InputForm,
  FontFamily->"Times New Roman",
  FontWeight->"Bold"]], "Section",
  FormatType->InputForm],

Cell[TextData[{
  StyleBox["\t",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman",
    FontSize->10.5],
  StyleBox[
  "At the beginning of this chapter, we introduce a concept of the gradient \
and curl operations of the classical field theory. Most of the conventional \
computer graphics, space derivatives are often carried out in order to \
extract the edges of a target object in a screen. An introduction of the \
vector operations instead of simple spatial derivatives renders a physical \
meaning to the operations. As an application of the gradient and curl \
operations, we draw the sketch images, even though the sketch drawing is one \
of the art works based on the human emotion. Regarding the numerical values \
representing a monochrome image as a scalar or one component of vector \
potentials, gradient operation to the scalar potentials or curl operations to \
the vector potentials yields one of the vector fields. Depending on the \
magnitude of potentials, a vector distribution takes different form. A vector \
magnitude distribution leads to a sketch image. Further, inner product \
operation among the vectors yields the other type images. \n\tSecond stage of \
the field theory in this chapter is to apply the Laplacian operator to the \
image data when regarding the numerical values representing an image as the \
scalar potentials. The Laplacian operation leads to a static image governing \
equation. A Poisson type partial differential equation is the static image \
governing equation. It is demonstrated that a size or resolution of an image \
can be changed freely. \n\tThe image data in computer graphics are \
essentially discretized quantities so that we have to carry out the vector \
calculus in terms of the discrete mathematical means. In this textbook, the \
gradient and curl operations are carried out by the central finite \
differences, and the Laplacian operation is carried out by the 9 points \
finite difference formula.",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["2.2 Preparation of ",
    FontFamily->"Times New Roman"],
  StyleBox[" ",
    FontFamily->"Times New Roman",
    FontSize->12],
  StyleBox["Mathematica",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"]
}], "Section"],

Cell[TextData[{
  StyleBox["\t",
    FontFamily->"Times New Roman",
    FontSize->10.5],
  StyleBox[
  "Before to move on the practical image processing, we have to install the \
memory conserve utilities and the warning messages suppressing command for \
the similar variable name. In addition, the \
\[OpenCurlyDoubleQuote]LinearAlgebra`MatrixManipulation\
\[CloseCurlyDoubleQuote] and \[OpenCurlyDoubleQuote]Graphic`'PlotField\
\[CloseCurlyDoubleQuote] packages have to be installed. The former is used \
for the list and matrix operations, and the latter is used for plotting the \
vector fields [1]. ",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Mathematica",
    FontFamily->"Century",
    FontSize->10.5,
    FontSlant->"Italic"],
  StyleBox[" packages",
    FontFamily->"Century",
    FontSize->10.5]
}], "Subsubsection"],

Cell["\<\
<<Utilities`MemoryConserve`
$MemoryIncrement=100000;
Off[General::spell1,MemoryConserve::start,MemoryConserve::end];
<< LinearAlgebra`MatrixManipulation`;
<<Graphics`PlotField`\
\>", "Input",
  CellLabel->"In[1]:="]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Mathematica",
    FontFamily->"Century",
    FontSize->10.5,
    FontSlant->"Italic"],
  StyleBox[" function rgbBMP",
    FontFamily->"Century",
    FontSize->10.5]
}], "Subsubsection"],

Cell[TextData[{
  StyleBox["\t",
    FontFamily->"Times New Roman",
    FontSize->10.5],
  StyleBox[
  "Further, we define several functions for image processing and data \
handling. The functions \
\[OpenCurlyDoubleQuote]rgbBMP\[CloseCurlyDoubleQuote], \
\[OpenCurlyDoubleQuote]convertRGB\[CloseCurlyDoubleQuote] and \
\[OpenCurlyDoubleQuote]monoNTSC\[CloseCurlyDoubleQuote] are defined as \
follows. The function \[OpenCurlyDoubleQuote]rgbBMP\[CloseCurlyDoubleQuote] \
works to read in the 24-bits color image data. A parameter \
\[OpenCurlyDoubleQuote]colorFile\[CloseCurlyDoubleQuote] refers to a file \
name.",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell[BoxData[
    \(\(rgbBMP[colorFile_] := \n\t
      Module[{i = 0, j = 0, k = 0, dim = {0}, input = {{{0. }}}}, \n\t\t
        link = Install["\<RGBsplit.exe\>"]; Pause[0.01]; \n\t\t
        input = RGBsplit[colorFile]; \n\t\tUninstall[link]; \n\t\t
        Off[General::spell1]; \n\t\tdim = Dimensions[input]; \n\t\t
        Table[input[\([i, j, k]\)], {k, 3}, \n
          \t\t\t{i, dim[\([1]\)]}, {j, dim[\([2]\)]}]]; \)\)], "Input",
  CellLabel->"In[6]:="]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Mathematica",
    FontFamily->"Century",
    FontSize->10.5,
    FontSlant->"Italic"],
  StyleBox[" function convertRGB",
    FontFamily->"Century",
    FontSize->10.5]
}], "Subsubsection"],

Cell[TextData[{
  StyleBox["\t",
    FontFamily->"Times New Roman",
    FontSize->10.5],
  StyleBox[
  "The function \[OpenCurlyDoubleQuote]convertRGB\[CloseCurlyDoubleQuote] \
converts the numerical data representing a color image into a RGB form in \
order to visualize the image on the ",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"],
  StyleBox["Mathematica",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox[
  " notebook. The parameter \[OpenCurlyDoubleQuote]colorData\
\[CloseCurlyDoubleQuote] refers to a list including the numerical values.",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell[BoxData[
    \(\(convertRGB[colorData_] := \n\t
      Module[{i = 0, j = 0, dim = {0}, out}, \n\t\t
        dim = Dimensions[colorData]; \n\t\ \ 
        Graphics[\n\t\t\t
          RasterArray[\n\t\t\t\t
            Table[RGBColor[colorData[\([1, i, j]\)], \n\t\t\t\t\t
                colorData[\([2, i, j]\)], colorData[\([3, i, j]\)]], \n
              \t\t\t{i, \ dim[\([2]\)]}, \ {j, \ dim[\([3]\)]}]]]]; \)\)], 
  "Input",
  CellLabel->"In[7]:="]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Mathematica",
    FontFamily->"Century",
    FontSize->10.5,
    FontSlant->"Italic"],
  StyleBox[" function monoNTSC",
    FontFamily->"Century",
    FontSize->10.5]
}], "Subsubsection"],

Cell[TextData[{
  StyleBox["\t",
    FontFamily->"Times New Roman",
    FontSize->10.5],
  StyleBox[
  "The function \[OpenCurlyDoubleQuote]monoNTSC\[CloseCurlyDoubleQuote] \
construct a NTSC style monochrome image data from the color image data. The \
parameter \[OpenCurlyDoubleQuote]colorData\[CloseCurlyDoubleQuote] refers to \
a list including the numerical values.",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell[BoxData[
    \(\(\(monoNTSC[colorData_] := \n\t
      Module[{i = 0, j = 0, dim = {0}}, \n\t\tdim = Dimensions[colorData]; \n
        \t\tTable[
          0.3*colorData[\([1, i, j]\)] + 0.59*colorData[\([2, i, j]\)] + \n
            \t\t\t0.11*colorData[\([3, i, j]\)], \n
          \t{i, dim[\([2]\)]}, {j, dim[\([3]\)]}]]; \)\t\t\)\)], "Input",
  CellLabel->"In[8]:="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["2.3 Sample image synthesis",
  FontFamily->"Times New Roman"]], "Section"],

Cell[TextData[{
  StyleBox["\t",
    FontFamily->"Times New Roman",
    FontSize->10.5],
  StyleBox[
  "In this section, we construct a sample monochrome image from a color \
image. At first, we read in a color image file \
\[OpenCurlyDoubleQuote]BF001.bmp\[CloseCurlyDoubleQuote] by means of the \
function \[OpenCurlyDoubleQuote]rgbBMP\[CloseCurlyDoubleQuote].",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell["colorSample=rgbBMP[\"BF001.bmp\"];", "Input",
  CellLabel->"In[9]:="],

Cell[TextData[{
  StyleBox["\t",
    FontFamily->"Times New Roman",
    FontSize->10.5],
  StyleBox[
  "Second, after converting the color image data \
\[OpenCurlyDoubleQuote]colorSample\[CloseCurlyDoubleQuote] into the RGB form \
by the function \[OpenCurlyDoubleQuote]convertRGB\[CloseCurlyDoubleQuote], \
the original color image data is composed.",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell["\<\
colorSampleG=Show[convertRGB[colorSample],
\tPlotLabel->\"Color image\",AspectRatio->1,
\tDisplayFunction->Identity];\
\>", "Input",
  CellLabel->"In[10]:="],

Cell[TextData[{
  StyleBox["\t",
    FontFamily->"Times New Roman",
    FontSize->10.5],
  StyleBox[
  "Third, after composing a monochrome image data \
\[OpenCurlyDoubleQuote]monoSample\[CloseCurlyDoubleQuote] by the function \
\[OpenCurlyDoubleQuote]monoNTSC\[CloseCurlyDoubleQuote], we compute a \
monochrome sample image.",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell["\<\
monoSampleG=
\tListDensityPlot[monoSample=monoNTSC[colorSample],
\t\tMesh->False,Frame->False,PlotLabel->\"Monochrome\",
\t\tDisplayFunction->Identity];\
\>", "Input",
  CellLabel->"In[11]:="],

Cell[TextData[{
  StyleBox["\t",
    FontFamily->"Times New Roman",
    FontSize->10.5],
  StyleBox[
  "Finally, we draw the original and monochrome sample images, which are \
shown in Fig.1. A reason why we use the color image sample \
\[OpenCurlyDoubleQuote]BF001.bmp\[CloseCurlyDoubleQuote] not the monochrome \
image sample \[OpenCurlyDoubleQuote]BF001M.bmp\[CloseCurlyDoubleQuote] is to \
introduce the color handling functions \[OpenCurlyDoubleQuote]rgbBMP\
\[CloseCurlyDoubleQuote] and \[OpenCurlyDoubleQuote]convertRGB\
\[CloseCurlyDoubleQuote] for the later chapters. ",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell[CellGroupData[{

Cell["\<\
Show[GraphicsArray[{colorSampleG,monoSampleG}],
\tPlotLabel->\"Fig.1. Sample images\",ImageSize->{400,200}];\
\>", "Input",
  CellLabel->"In[12]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .47619 
%%ImageSize: 400 200 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0113379 0.47619 [
[.5 .48869 -62 0 ]
[.5 .48869 62 12.5625 ]
[ 0 0 0 0 ]
[ 1 .47619 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .48869 -123 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Fig) show
81.000000 12.812500 moveto
(.1) show
93.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(.) show
105.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Sample) show
147.000000 12.812500 moveto
(images) show
183.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
0 0 m
1 0 L
1 .47619 L
0 .47619 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0113379 0.477324 0.464853 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00744048 0.0238095 0.00744048 [
[.5 1.0125 -35 0 ]
[.5 1.0125 35 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -96 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Color) show
99.000000 12.812500 moveto
(image) show
129.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
384 string
128 128 8 [128 0 0 128 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
EFEFF7F7EFE7F7F7F7F7F7F7EFEFF7F7EFE7EFEFE7EFEFE7F7F7F7EFEFE7F7EFE7EFCEB5EFCEB5\
EFCEB5EFCEBDEFD6C6EFCEBDEFCEBDEFCEBDEFCEBDEFCEBDF7EFE7F7E7DEC6846B
E7C6ADEFCEBDE7C6ADE7C6ADE7BDA5EFC6A5EFC6A5E7BD9CEFC6A5EFC6ADEFC6A5EFC6ADE7BDA5\
E7BDA5EFC6A5EFC6A5EFCEADEFCEADEFC6ADEFC6ADEFC6A5EFC6A5EFC6A5EFC6AD
EFB59CEFC6ADEFC6ADEFC6ADF7CEB5F7CEB5F7CEB5F7CEB5F7CEB5F7CEB5F7CEB5EFCEADF7CEB5\
EFC6ADEFC6ADF7C6B5F7CEB5EFC6ADEFC6ADEFC6ADEFC6ADEFC6ADEFC6A5EFC6A5
EFC6A5EFC6A5EFC6ADEFC6ADE7C6ADEFC6ADEFC6ADEFC6A5EFC6ADEFC6ADEFC6A5F7DECEF7EFE7\
F7DECECE946BE7BDA5E7BDA5EFC6A5EFC6A5E7BDA5E7BDA5E7BDA5E7C6ADE7C6AD
E7C6ADE7C6ADE7C6ADE7C6ADEFCEB5EFCEADEFC6B5EFCEADF7D6BDF7CEB5F7D6BDF7D6BDF7D6BD\
EFCEBDF7D6BDEFCEB5E7C6B5E7C6ADD6BDADD6BDADE7BDA5E7BDA5E7BD9CD6BDAD
EFDECEE7DEDEDEAD8CE7CEBDEFE7E7F7EFF7F7F7F7EFEFF7
EFEFF7F7EFF7F7EFF7EFEFE7F7EFE7F7F7F7F7F7F7EFEFF7EFEFF7F7F7F7F7EFE7EFEFE7EFCEBD\
EFCEBDEFCEBDEFCEBDEFCEBDEFCEBDEFCEBDEFCEB5EFCEB5EFCEB5F7E7DED6A58C
EFC6ADEFCEB5E7C6B5E7C6ADE7C6ADE7BDA5E7BDA5E7BDA5EFBD9CEFC6A5EFC6ADEFC6A5EFC6AD\
EFC6A5EFBD9CEFC6ADEFCEB5EFC6ADEFC6ADEFC6A5EFC6A5EFB59CEFBD9CEFC6A5
EFC6A5E7BDA5EFC6A5EFC6ADEFC6A5EFC6ADEFCEADF7C6B5EFC6ADEFC6ADF7CEB5EFC6ADEFC6AD\
F7CEB5EFC6ADEFC6ADEFC6ADEFC6ADEFC6ADF7C6B5EFC6ADEFC6ADEFC6A5EFC6A5
EFC6ADEFC6ADEFC6ADEFC6ADEFC6ADE7C6ADE7BDA5EFC6ADEFC6ADEFC6A5EFC6ADEFC6A5F7DECE\
F7EFE7D6AD84DE8473EFC6A5EFC6A5EFC6A5E7BDA5E7BDA5E7BDA5E7BDA5E7BDA5
EFC6A5EFC6ADEFC6ADEFC6ADEFCEADEFC6ADEFCEB5EFC6ADEFCEB5EFCEB5EFCEBDEFCEBDEFCEBD\
F7D6BDEFCEBDEFCEBDE7C6ADE7C6B5E7C6ADE7C6ADE7BDA5E7BDA5E7C6ADEFE7DE
EFE7E7E7BD9CE7BD94E7BDA5EFE7E7F7EFF7EFEFF7F7EFE7
EFEFE7EFEFE7EFEFE7F7EFE7EFEFF7EFEFF7EFEFF7F7EFE7EFEFF7EFEFF7F7F7F7F7F7F7F7EFF7\
EFCEBDEFCEB5EFCEB5EFCEB5F7C6B5EFCEB5EFCEB5EFC6B5EFCEB5F7DED6F7E7DE
C67B4AE7C6ADEFC6B5E7C6B5E7BDA5E7B59CE7BDA5EFC6A5EFC6A5EFC6A5EFC6ADEFC6A5EFC6AD\
EFC6A5E7BDA5EFB59CEFCEADEFCEADEFC6ADEFC6A5EFBD9CEFBD9CE7BD9CE7BD9C
E7B59CE7B59CE7B59CEFBD9CEFC6A5EFC6ADEFC6ADEFCEADEFC6ADEFC6ADEFC6ADEFC6ADEFC6A5\
EFC6ADEFC6ADEFCEB5F7CEB5F7CEB5EFCEADF7C6B5F7CEB5EFC6ADEFC6ADEFC6AD
EFC6ADEFC6ADEFC6ADEFC6ADEFC6ADEFC6A5EFC6ADEFC6ADEFC6ADEFC6ADEFC6ADEFC6ADEFC6A5\
EFCEBDF7EFE7F7DECEC68463E7BDA5E7BDA5E7BDA5EFC6A5E7C6ADE7BDA5E7BDA5
EFC6A5E7BDA5E7BDA5EFC6ADEFCEB5EFCEADEFCEB5EFCEADEFCEB5EFCEB5EFCEBDEFD6C6F7D6BD\
EFD6C6EFCEBDE7CEBDEFC6B5E7C6ADEFC6ADE7C6ADE7C6ADE7CEBDE7D6CEE7D6C6
EFE7DEE7D6C6E7BD9CE7BDA5E7DED6EFEFE7F7F7F7F7EFE7
F7EFE7EFEFF7F7EFF7F7F7F7EFEFF7F7F7F7F7F7F7EFEFE7F7F7F7F7F7F7F7EFE7EFEFF7F7EFE7\
EFEFE7EFEFE7F7D6BDEFC6B5EFCEB5EFC6ADEFC6ADEFC6ADEFC6ADEFC6ADF7E7DE
EFD6C6DEAD9CE7C6ADE7C6B5E7C6B5E7BDA5E7BDA5E7BDA5E7BDA5E7BDA5EFC6A5EFC6ADEFC6AD\
EFC6A5E7BDA5E7BDA5EFC6A5EFC6ADEFC6ADEFC6ADEFBD9CEFC6A5E7BD9CE7B59C
E7BD9CE7BD9CE7B59CE7B594E7BDA5EFC6A5EFC6A5EFC6ADEFC6ADEFC6A5EFC6ADEFC6A5EFC6A5\
EFC6A5EFCEADF7D6BDF7CEB5F7CEB5F7CEB5F7D6BDF7CEB5F7CEB5EFCEADF7CEB5
F7CEB5EFC6ADEFC6ADEFC6B5EFC6B5EFC6B5EFC6ADEFC6B5EFC6B5EFC6ADEFC6ADEFC6ADEFC6AD\
EFC6ADEFCEBDF7EFE7F7DECEDE8473EFC6ADEFC6ADEFC6ADEFC6ADEFC6ADEFCEAD
EFC6ADEFC6ADEFC6B5EFC6ADEFCEADEFC6ADEFCEB5EFC6B5EFCEB5EFCEBDF7D6BDEFD6C6EFD6C6\
EFCEBDEFD6C6EFC6B5EFC6B5E7C6B5EFCEB5E7C6B5EFE7E7E7D6CEE7D6C6EFE7DE
E7BD9CE7DED6E7C6ADE7BD9CEFE7E7EFE7E7EFE7E7F7EFE7
EFEFF7F7EFF7EFEFF7F7EFF7F7F7F7F7EFF7F7EFF7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7EFE7\
F7F7F7EFEFF7F7EFE7F7D6BDEFCEB5F7CEB5EFC6ADEFCEADEFC6ADF7CEB5F7E7DE
F7E7DEDEAD9CEFC6ADEFC6B5E7CEBDE7BDA5E7BDA5E7BDA5EFC6A5E7BDA5E7BDA5EFC6A5EFC6A5\
EFC6ADEFC6A5EFC6A5EFC6ADEFC6A5EFBD9CEFBD9CEFBD9CEFC6A5EFC6A5EFC6A5
EFC6A5EFC6A5EFBD9CE7B59CE7BD9CE7BDA5EFC6A5EFB59CEFB59CEFB59CEFC6A5EFC6ADEFC6AD\
EFC6ADEFC6ADEFC6ADF7CEB5EFC6ADEFC6ADF7D6BDF7D6BDEFC6B5F7CEB5F7C6B5
F7CEB5F7C6B5EFC6ADEFCEB5EFCEB5EFC6B5EFC6B5EFCEB5EFCEB5EFCEB5EFC6ADEFCEB5EFC6AD\
EFC6ADEFC6ADEFCEBDF7EFE7DEAD8CE7AD9CEFC6ADEFCEADEFCEADEFCEADEFC6AD
EFC6ADEFC6ADEFCEADEFCEB5EFCEADEFCEB5F7CEB5EFCEB5EFCEB5F7CEB5F7D6BDEFD6C6EFD6C6\
EFD6C6EFCEBDEFCEBDEFCEBDE7C6B5EFD6C6EFEFE7EFE7E7EFE7DEEFE7DEEFEFE7
E7CEBDF7DED6E7BD9CE7BD9CEFE7E7F7F7F7F7EFE7EFEFE7
EFEFF7F7EFF7EFEFE7F7EFF7EFEFF7F7EFE7F7EFF7F7F7F7EFEFE7F7EFF7F7EFF7EFEFE7F7F7F7\
F7F7F7F7EFF7F7F7F7F7EFF7EFDECEEFCEB5F7CEB5EFCEB5EFCEB5EFCEB5EFCEBD
F7E7DEEFE7DEEFC6ADEFCEB5EFCEB5E7C6B5E7C6ADE7BDA5E7BDA5EFC6A5E7C6ADEFC6ADEFC6AD\
E7BDA5E7BDA5EFC6A5E7BDA5E7B59CEFBD9CEFBD9CE7BD9CEFC6A5EFC6A5EFC6A5
EFC6ADEFC6A5EFC6ADEFC6ADEFB59CE7B59CE7B59CEFBD9CE7B59CEFC6A5E7BDA5EFC6A5EFC6AD\
EFC6ADEFC6ADEFC6ADEFC6ADF7C6B5F7CEB5F7CEB5EFC6ADEFCEBDEFCEB5EFCEB5
EFCEB5F7CEB5EFCEB5F7CEB5EFCEB5EFCEBDEFCEB5EFC6B5EFCEB5EFC6B5EFC6B5EFC6B5EFC6AD\
EFCEADEFC6ADEFC6ADEFCEBDF7EFE7E7BDA5E7AD9CEFC6ADEFCEB5EFCEB5EFCEAD
EFC6B5EFCEADEFCEADF7CEB5F7CEB5F7CEB5F7CEB5EFCEB5F7CEB5EFCEBDEFCEBDEFD6C6EFD6C6\
EFD6C6EFCEBDE7C6B5DEC6B5E7BD9CE7D6CEEFE7DEF7EFE7E7C6ADE7D6CEE7C6AD
EFCEBDEFE7E7E7BDA5E7D6CEF7EFF7F7EFF7F7EFF7EFEFE7
EFEFF7F7F7F7F7F7F7F7F7F7EFEFE7F7F7F7EFEFE7F7EFF7F7EFF7F7F7F7EFEFE7F7F7F7F7F7F7\
EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7EFE7EFD6C6EFD6C6F7D6BDEFD6C6F7D6BD
F7D6BDF7EFE7E7D6D6EFC6B5EFCEBDEFCEBDE7CEBDE7C6B5E7C6ADE7BDA5E7BDA5E7BD9CE7BD9C\
E7BDA5E7B594DEAD94E7B594E7B594E7B594E7BD9CE7B594EFC6A5EFC6ADEFCEAD
EFCEADEFCEADEFCEADF7CEB5EFC6A5EFC6A5E7B59CEFBD9CE7BD9CEFBD9CE7B59CE7BD9CE7BDA5\
EFB59CEFC6A5EFC6A5EFC6ADEFC6ADEFCEADEFC6ADEFC6ADEFC6ADEFC6ADEFC6AD
EFC6B5EFC6ADEFC6ADEFCEB5EFCEB5EFC6B5EFC6B5EFC6B5EFC6ADEFC6ADEFC6ADEFC6ADEFC6AD\
E7C6ADEFC6ADEFC6ADE7C6ADEFD6C6F7EFE7F7DECEE7C6ADEFC6ADEFC6ADEFC6AD
EFC6A5EFCEADF7C6B5F7CEB5F7CEB5EFCEB5F7CEB5EFCEB5F7D6BDEFCEBDEFD6C6EFD6C6EFD6C6\
E7C6B5E7C6ADDEAD9CCEAD94E7BDA5EFE7E7E7DED6EFEFE7E7C6B5E7CEBDEFCEB5
E7CEBDE7CEBDE7BD94EFE7E7F7EFF7F7EFE7F7F7F7EFEFF7
EFEFF7F7EFE7F7EFF7F7EFF7F7EFF7F7F7F7F7EFF7F7F7F7EFEFF7EFEFF7EFEFE7EFEFF7EFEFF7\
F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7EFF7EFEFF7F7DED6F7DECEF7DECEF7DECE
EFDECEEFDECEF7EFE7EFD6C6BD947BEFCEBDEFC6B5EFC6ADE7BDA5E7BDA5E7BDA5E7BDA5E7BD9C\
DEAD94DEAD94E7B594E7B594E7B594E7B594E7B594E7B594E7BDA5EFC6A5EFC6AD
EFCEADEFCEADEFCEADF7CEB5EFC6ADEFC6ADEFB59CE7B59CE7B594E7B594E7B59CE7BDA5E7B59C\
E7B594E7B594E7B59CE7BDA5E7BDA5E7BDA5EFC6A5E7BDA5E7BDA5EFBD9CE7BDA5
EFC6A5E7BDA5EFC6A5E7C6ADE7BDA5E7C6ADEFC6A5EFC6A5E7BDA5E7BDA5E7BDA5E7BDA5E7BDA5\
E7BDA5E7BDA5EFC6A5E7BDA5E7BDA5E7D6D6F7E7DEE7C6B5E7C6ADEFC6A5EFC6AD
EFC6ADEFC6ADEFC6ADEFCEB5F7CEB5EFCEB5EFCEB5F7D6BDF7D6BDEFCEBDEFCEBDEFCEBDE7C6AD\
E7BDA5D69C7BD6AD84CEAD94E7C6ADE7D6CEE7C6ADDEAD8CE7BDA5EFC6A5E7BD94
E7D6CEE7C6B5E7BD9CEFE7DEF7EFF7EFEFE7F7EFE7EFEFF7
EFEFF7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7EFEFF7F7EFE7F7EFF7F7EFF7F7F7F7F7EFF7EFEFF7\
EFEFE7F7F7F7F7EFF7F7F7F7F7F7F7EFEFF7F7F7F7EFEFF7F7F7F7F7EFF7F7EFF7
F7F7F7F7F7F7F7EFF7F7EFF7F7EFE7D6BDADE7C6ADEFC6ADE7C6ADE7BDA5E7BDA5E7BDA5E7B59C\
E7BD9CD6B5A5E7BD9CE7BD9CEFBD9CEFC6A5EFC6A5EFBD9CE7B594EFBD9CEFC6A5
EFCEADEFCEADEFCEADEFCEADF7CEB5EFCEADEFC6A5EFB594EFBD9CEFC6A5EFB59CEFBD9CEFBD9C\
E7BDA5E7BDA5E7B594E7B594DEAD8CDEAD94DEAD8CDEA584DEAD94DEAD8CDEAD8C
DEAD8CDEA584DEAD8CDEAD8CDEAD94DEAD94DEAD94DEAD94DEAD94DEAD94DEAD94E7BD9CE7B59C\
E7BD9CE7BD9CE7BD9CE7B59CE7B594E7BD9CDEAD94E7CEC6E7CEC6D6AD8CDE8473
DEAD94E7BDA5E7BDA5EFC6ADEFC6ADEFC6ADEFCEB5EFCEBDEFCEBDEFD6C6EFCEBDE7C6B5CE9463\
D69C73DEAD8CCEB5A5DEAD8CDEAD8CE7C6B5E7C6ADE7BDA5E7BD94E7BD9CE7DED6
E7CEBDE7BD9CE7D6D6EFE7DEEFEFF7F7EFF7EFEFE7EFEFE7
F7F7F7F7EFF7F7F7F7F7EFE7F7F7F7F7F7F7F7F7F7F7EFF7F7EFF7EFEFE7F7EFE7EFEFF7EFEFF7\
F7EFE7F7F7F7EFEFF7EFEFE7F7F7F7EFEFF7F7F7F7F7EFF7F7F7F7F7EFF7EFEFF7
F7F7F7F7EFF7F7EFF7F7EFE7F7F7F7EFEFF7E7BD9CD69C7BE7D6C6E7BDA5DEAD9CE7BDA5E7BDA5\
E7BD9CD6B5A5D6B5A5DEAD94E7B594E7BD9CEFBD9CEFBD9CE7B594E7BD9CEFC6A5
EFC6A5F7CEB5EFCEADF7CEB5EFCEADEFC6ADEFC6ADEFBD9CEFBD9CEFBD9CEFBD9CEFC6A5EFBD9C\
EFC6A5EFC6A5EFC6A5EFBD9CEFC6A5EFBD9CEFBD9CE7BD9CE7B59CE7BD9CE7B59C
E7B59CE7B59CE7BD9CE7B59CE7B59CEFBD9CE7BD9CEFBD9CE7BDA5E7BDA5EFC6A5EFC6A5E7B59C\
EFC6A5EFC6A5EFC6A5E7BDA5EFC6A5E7BDA5E7BDA5EFBD9CEFC6B5E7CEBDE7CEC6
E7BDA5945A31E7B59CDEAD9CE7BDA5E7C6ADE7C6ADE7C6B5D6AD8CC6845AC67B4AC67B4ACE8C5A\
DEAD8CE7BD94E7BDA5DEAD8CE7BD94E7BD9CE7BDA5E7CEBDE7C6ADDEAD8CEFD6C6
E7D6C6DEAD8CEFDECEE7DED6F7EFE7F7EFF7F7F7F7EFEFF7
EFEFE7EFEFF7F7F7F7EFEFF7F7EFF7EFEFE7EFEFF7F7EFF7F7EFF7F7F7F7EFEFE7F7EFF7F7F7F7\
F7F7F7F7EFF7F7EFF7F7EFF7F7F7F7F7EFF7F7F7F7F7EFF7F7F7F7EFEFF7F7EFF7
F7EFF7EFEFF7F7F7F7EFEFF7F7EFF7F7EFF7E7BD9CD69C73DEAD94CEAD94DEAD9CE7BD9CE7BD9C\
E7BD9CE7BD9CE7BDA5D6B5A5E7B594E7BD9CEFBD9CEFBD9CE7B594E7BD94EFC6A5
EFC6ADEFC6A5EFC6ADEFCEADEFCEADEFCEADEFCEADEFC6A5EFBD9CEFBD9CEFC6A5EFC6A5EFC6A5\
EFC6A5EFC6A5EFC6A5EFC6A5EFBD9CEFB59CEFC6A5EFC6A5EFC6A5EFC6A5E7BDA5
E7BD9CEFBD9CEFBD9CEFC6A5EFC6A5EFBD9CEFBD9CEFBD9CE7BDA5EFC6A5EFC6A5EFC6A5EFC6A5\
EFC6A5EFBD9CEFC6A5EFBD9CEFC6A5EFC6A5EFC6ADEFC6A5E7BDA5EFC6ADEFC6A5
E7CEBDDECEBDE7D6D6D6AD8CBD947BBD947BD6A584BD8C63C67B4ACE8C5AC67B4AC6845AD69C73\
D69C73E7BD94DEAD94D6AD84EFE7DEE7BD94E7BD94DEC6B5DEA57BEFCEBDEFDECE
E7BD9CE7DED6E7C6B5EFEFE7EFE7E7EFEFE7EFEFE7F7F7F7
F7F7F7EFEFF7F7EFE7F7F7F7EFEFF7F7F7F7F7F7F7EFEFE7F7EFE7F7EFE7F7F7F7F7EFF7F7F7F7\
EFEFF7F7F7F7EFEFF7F7EFF7F7EFF7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7
EFEFF7EFEFF7EFEFE7EFEFE7F7EFF7EFEFE7E7C6B5E7C6ADCE9463D6AD84D6AD84CE946BE7BD9C\
E7BDA5E7B59CE7BD9CDEAD9CE7BD94E7BD9CE7B594EFBD9CE7BD94E7BD94EFC6A5
EFC6A5EFC6A5EFC6ADEFC6ADEFCEADEFC6A5EFCEADEFC6A5EFC6A5EFBD9CEFBD9CEFC6A5EFC6A5\
EFC6A5EFC6A5EFC6A5EFC6A5EFC6A5EFC6A5EFB59CEFBD9CEFBD9CEFC6A5EFC6A5
EFC6A5E7BD9CEFBD9CE7BDA5EFB59CEFBD9CEFC6A5EFC6A5EFB59CEFC6A5EFC6A5EFC6A5EFC6A5\
EFBD9CEFBD9CEFC6A5E7BDA5EFC6A5E7BD9CEFC6A5EFC6A5EFC6A5EFC6A5E7BDA5
E7BDA5E7BDA5E7CEBDE7CEC6E7CEC6D6BDADAD6331AD6B39C6845AC67B4AC6845ACE9463CE9463\
CE946BCE9463CEAD94D6B5A5E7DED6D69C73DEAD84E7C6ADDEA57BE7C6B5E7D6C6
E7BD94EFEFE7EFE7DEEFEFE7EFEFE7EFEFF7EFEFF7F7F7F7
EFEFF7F7F7F7F7F7F7EFEFF7EFEFF7F7F7F7F7EFE7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7\
F7EFF7F7EFE7F7F7F7F7F7F7F7F7F7F7F7F7F7EFE7F7EFF7F7F7F7F7F7F7F7EFF7
EFEFF7EFEFF7F7EFF7EFEFF7EFEFF7EFEFF7E7CEC6E7C6B5D6AD8CCE9463D6AD84C67B42AD6B39\
DEAD9CE7BD9CE7B59CE7B59CE7BD9CE7B59CE7BD9CEFB594E7B594E7BD9CEFC6A5
EFC6A5EFC6A5EFC6A5EFC6A5EFCEADEFC6A5EFC6A5EFC6A5EFC6A5EFC6A5EFC6A5EFC6A5EFC6A5\
EFC6A5EFC6ADEFC6A5EFC6A5EFC6A5EFC6A5EFBD9CEFBD9CEFBD9CEFC6A5EFBD9C
EFBD9CEFC6A5E7BD9CEFB59CEFBD9CEFBD9CEFBD9CE7BD9CE7BDA5EFC6A5EFC6ADEFC6A5EFC6A5\
EFB59CEFC6A5EFC6A5EFBD9CEFBD9CEFBD9CEFC6A5EFC6A5E7BDA5E7BDA5E7BDA5
E7BD9CDEAD94D6A584D69C7BC67B4AB56B42C67B4AC67B42B57B5AC67B42CE9463CE8C5ACE9463\
CE946BDEAD84DEAD84DEAD8CE7C6ADDEA57BDEAD84E7BD94DEAD84E7D6C6E7C6AD
E7CEBDEFE7DEEFEFE7F7EFF7EFE7DEF7F7F7F7F7F7F7EFF7
F7F7F7F7EFF7EFEFF7F7EFF7F7EFE7F7F7F7EFEFF7F7F7F7EFEFE7F7F7F7EFEFF7F7F7F7F7EFE7\
F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7EFEFF7F7EFF7F7F7F7F7F7F7EFEFF7F7F7F7
F7EFE7EFEFE7EFEFF7F7F7F7F7EFE7EFEFF7EFDECEEFE7DEE7D6C6CE8C5ACE9463C67B42B56B39\
945229E7B59CDEAD9CE7BD9CDEAD94DEAD9CE7B59CE7BD9CE7BD94E7BD9CEFC6A5
EFC6A5EFC6A5EFC6A5EFC6A5EFC6ADEFC6A5EFC6A5EFC6A5EFC6A5EFC6A5EFBD9CEFBD9CEFBD9C\
EFBD9CEFC6A5EFBD9CEFC6A5EFC6A5EFC6A5EFBD9CEFBD9CEFBD9CEFBD9CEFBD9C
E7BD9CE7BD9CE7BD9CEFBD9CEFBD9CEFBD9CEFBD9CE7BD9CEFBD9CEFBD9CEFC6A5E7BD9CEFBD9C\
EFBD9CEFC6A5EFC6A5EFBD9CE7BD9CEFBD9CEFBD9CEFBD9CE7B594E7BD9CDEAD94
DEAD8CD69C7BCE9463B5734AB56B42C67B4ACE8C5ACE8C5AC6946BC6845AC67B42CE9463CE9463\
DEA573DEAD8CDEAD84E7BD9CDEAD8CD69C73DEAD84DEAD84E7C6ADE7C6ADE7C6AD
E7D6C6F7EFF7EFEFE7F7EFE7F7EFE7F7EFF7F7EFF7EFEFE7
EFEFF7F7EFF7F7F7F7F7EFF7EFEFE7F7F7F7F7F7F7F7F7F7F7EFE7F7F7F7F7EFF7EFEFF7F7F7F7\
EFEFF7F7F7F7F7F7F7F7EFE7EFEFF7F7EFF7EFEFF7F7F7F7EFEFE7F7F7F7F7EFF7
F7EFE7F7F7F7F7EFF7F7EFF7EFEFE7F7EFE7E7D6CEF7EFE7E7C6ADCE8C5AC67B4AC67B42B56331\
9452297B3918DEA584DEAD8CDEAD94E7BD9CE7B59CE7BD9CE7B594E7BD94E7BDA5
EFC6A5EFC6A5EFC6A5EFC6A5EFBD9CEFC6A5EFC6A5EFC6A5EFC6A5EFC6A5EFC6A5EFC6A5EFBD9C\
EFC6A5EFBD9CEFBD9CEFBD9CEFC6A5EFC6A5EFC6A5EFC6A5EFB594EFB594EFBD9C
EFBD9CEFBD9CEFBD9CEFB59CEFBD9CE7BD9CEFB594E7BD94E7BD9CEFB59CEFC6A5EFBD9CEFC6A5\
EFBD9CE7BD9CEFC6A5EFC6A5EFBD9CEFBD9CE7BD9CE7B594E7B594DEAD8CDEAD84
D69C73D69C73C67B4AAD6B39C6845ACE8C5AC67B4ACE8C5AD69C7BCE8C5AC6845ACE8C5ADEA573\
CE9463D6AD84D69C73CEAD94DEA57BE7BD94E7BD94E7BD94EFDECEDEAD8CE7C6B5
EFEFE7EFEFE7F7EFF7F7E7DEEFEFF7EFEFE7F7F7F7F7EFF7
F7EFE7EFEFF7EFEFF7F7EFE7EFEFF7F7F7F7EFEFE7F7EFE7EFEFE7F7F7F7F7F7F7F7F7F7F7EFE7\
F7F7F7F7EFE7F7EFE7F7F7F7EFEFF7F7F7F7F7EFF7EFEFF7F7F7F7EFEFF7F7EFE7
F7F7F7F7EFE7F7F7F7F7EFF7F7EFE7EFEFE7EFDECEEFE7DEE7C6B5D6BDADC67B42C6845AB56B39\
9452297B39187B3918DEAD94DEAD94E7B594DEAD94E7BD9CE7BD94E7B594EFC6A5
EFC6A5EFC6A5EFC6A5EFC6A5EFC6A5EFBD9CEFBD9CEFC6A5EFC6A5EFBD9CEFBD9CEFBD9CEFBD9C\
EFB594E7BD9CEFBD9CEFC6A5EFC6A5EFC6A5EFBD9CEFBD9CEFBD9CE7BD9CEFB594
E7BD94E7B594EFBD9CEFBD9CEFBD9CEFB594E7BD9CE7AD8CE7BD9CE7BD94EFBD9CEFBD9CEFBD9C\
EFBD9CEFBD9CEFBD9CE7BD94DEAD84DEAD84DEA57BD69C73D69C73D69C73D69C73
C6845A9C6339945229C67B4AD69C73CE9463AD6B42CE8C5ACE946BD6AD84DEA573DEA573CE8C5A\
CE8C5ACE9463D69C73DEAD8CDEA57BE7BD94E7BD94EFE7DEE7BD9CE7C6ADEFD6C6
EFE7E7EFE7DEEFE7E7F7EFE7F7EFE7EFEFF7F7F7F7F7EFF7
EFEFE7F7F7F7F7EFF7EFEFF7F7F7F7EFEFF7EFEFF7F7EFF7F7F7F7F7EFF7F7EFF7F7F7F7F7EFF7\
F7F7F7F7EFF7F7F7F7F7F7F7F7EFF7F7F7F7F7EFF7F7EFE7F7EFE7F7F7F7F7EFF7
EFEFF7EFEFE7F7EFF7F7EFE7F7EFF7EFEFE7F7EFE7E7DED6E7DED6D6AD84C6845AC67B4AAD6331\
9452298C42217B39186B3118DEAD8CE7B59CCEAD94E7BD94E7B594E7BD94EFBD9C
EFC6A5EFBD9CEFBD9CEFBD9CEFBD9CEFC6A5EFBD9CEFBD9CEFC6A5EFBD9CEFBD9CEFC6A5EFBD9C\
EFBD9CEFB594E7BD94EFBD9CEFBD9CE7BD9CEFC6A5EFBD9CEFB594E7B594EFB594
E7B594E7B594E7B594E7B594E7BD94E7B594E7B594E7AD8CE7AD8CE7AD8CEFB594EFBD9CE7AD8C\
EFBD9CDEAD84E7BD94E7B594E7AD8CDEA57BDEA57BD69C73CE946BC6845AB5734A
945229AD5A31AD6331C6845ACE9463CE9463C68C63D69C73D69C73DEA573D69C73D69C73DEA573\
CE8C5ACE9463DEA57BDEA57BDEAD84E7BD94E7BDA5E7BD9CE7C6ADE7D6C6EFE7DE
EFE7E7E7DED6EFE7E7F7EFF7F7EFF7EFEFF7F7F7F7F7F7F7
F7EFE7EFEFE7F7F7F7F7F7F7F7F7F7EFEFE7F7F7F7F7F7F7F7F7F7F7EFE7EFEFF7F7F7F7F7EFE7\
F7EFF7EFEFE7F7EFF7EFEFF7EFEFF7F7F7F7F7F7F7F7F7F7F7EFF7F7EFF7F7F7F7
EFEFF7EFEFF7F7EFE7F7EFF7F7EFE7EFE7E7EFE7DEE7CEBDEFDECECE8C5AC6845AC67B42AD5A31\
9452299452298C42216B31184A1808D6A584DEAD9CDEAD94E7B594E7B594E7BDA5
E7BD9CEFBD9CEFBD9CEFBD9CEFBD9CEFC6A5EFBD9CEFC6A5EFBD9CEFBD9CEFBD9CEFBD9CE7BD9C\
EFBD9CEFBD9CEFB594EFB594E7BD94EFB594EFBD9CEFBD9CE7BD9CE7BD94EFB594
E7B594EFB594E7AD8CDEAD84E7AD8CEFB594E7AD8CE7AD8CEFB594E7AD8CE7BD94E7B594E7AD8C\
DEAD84E7B594DEAD8CDEAD8CDEAD84DEA57BD69C7BCE8C63B5734AAD6B39AD6331
9C6339AD6B42BD8C63CE946BCE8C5AC68C63CE9463D69C73CE9463C6845AC6845ACE9463CE8C5A\
DEA573DEA57BDEA57BDEA573E7BD94E7BDA5E7BDA5E7C6ADEFE7DEEFE7DEEFDECE
EFE7E7F7EFF7F7EFE7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
EFEFE7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7EFE7F7EFF7F7F7F7F7F7F7F7EFF7EFEFF7EFEFE7\
F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7EFEFF7F7EFF7F7EFF7F7EFF7F7F7F7
F7EFF7F7EFF7F7EFF7EFEFF7F7EFE7F7EFF7EFE7E7E7D6C6E7DED6CE9463C6845AC67B4AAD6331\
9452299452298C42216329106329104A1808DEAD94DEAD94E7BD9CE7B59CE7BD9C
E7BD9CEFBD9CEFBD9CEFBD9CEFBD9CEFBD9CEFC6A5EFC6A5EFBD9CEFBD9CEFBD9CEFBD9CEFBD9C\
EFBD9CEFBD9CE7BD94E7BD94EFBD9CEFB594E7BD9CEFB594EFB59CE7B594E7B594
E7B594E7B594E7AD8CE7AD8CE7AD8CE7AD8CDEAD84DEA57BDEAD84E7AD8CDEAD84E7BD9CDEA57B\
DEAD8CDEAD84DEAD84D69C7BDEA584D69C73C67B4AAD5A31AD6B39844221AD6B42
B5734AC67B4ACE9463CE8C5AC68C63C6946BC68C63DEA573D69C73D69C73D69C73DEA573DEA573\
DEA57BDEAD84D6AD84E7BD94E7BD9CE7BDA5E7BDA5EFCEBDEFD6C6EFDECEEFE7DE
EFEFE7F7EFE7F7F7F7F7EFF7F7F7F7F7EFF7EFEFF7F7F7F7
F7F7F7F7F7F7EFEFE7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7EFF7F7EFF7EFEFE7F7EFF7F7F7F7\
EFEFF7EFEFE7F7EFF7F7EFF7F7F7F7F7F7F7F7EFE7F7EFF7F7F7F7EFEFF7EFEFF7
F7EFF7F7F7F7F7EFF7EFEFF7F7EFE7EFEFE7EFE7DEE7DED6E7CEC6CE9463C6845AB56B42AD6331\
9C63399452297B39186329105221106B3118DEAD94DEAD94E7B594E7BD9CE7BD9C
E7BDA5E7BD9CEFC6A5EFBD9CEFC6A5EFBD9CEFBD9CEFBD9CEFBD9CEFBD9CEFB594EFBD9CEFBD9C\
E7BD94EFBD9CEFB594E7BD9CEFB594E7B594E7B594E7AD8CE7B594E7B594E7B594
E7B594E7AD8CE7AD8CDEAD84DEA584DEA57BDEA57BDEA57BDEAD84E7BD9CDEAD84D69C7BD69C73\
D69C7BDE9C73DE9C73CE8C63CE8C63C67B42C67B4A8C4A31AD5A319C6339AD6B39
9C6339C67B4ACE8C5AC6845AC6845AC68C63D69C73D69C73D6AD84DEAD8CD69C73DEA573E7BD94\
D6AD84DEAD84E7BD94E7BD94E7BDA5E7BD9CEFCEBDEFD6C6EFD6C6F7EFE7F7EFE7
F7F7F7F7F7F7F7EFF7F7EFF7F7F7F7EFEFF7F7F7F7F7F7F7
F7F7F7F7EFF7F7EFE7F7EFE7F7EFF7EFEFF7F7F7F7F7EFE7F7F7F7F7EFE7EFEFF7F7F7F7F7F7F7\
F7EFF7F7F7F7F7EFE7F7F7F7F7EFF7F7EFF7F7EFF7F7F7F7EFEFF7EFEFF7F7F7F7
F7F7F7F7EFF7F7F7F7F7EFE7F7EFF7EFEFE7F7E7DEE7D6C6D6AD84CE9463C6845AB5734AAD5A31\
B56B399452298C4A296B31186B31187B42217B4A29DEAD9CE7BD94E7BD9CEFC6A5
E7BD9CE7BD9CEFC6A5EFBD9CEFBD9CEFBD9CEFBD9CEFBD9CEFBD9CE7BD9CEFBD9CE7BD9CE7B594\
EFB59CEFBD9CE7BD94EFB594EFB594E7BD94E7AD8CE7BD94DEAD84E7B594E7BD94
E7B594E7AD8CE7AD8CDEA584DEA584CE946BD69C73DEAD8CE7BD9CDEAD8CCE8C63CE946BD69C73\
CE946BD69C73CE946BC67B4AC67B42B56331AD6331C67B4AAD6B42C67B4AC67B4A
BD8C63CE9463CE946BC68C63CE8C5AC68C63D69C73CE8C5ACE946BD69C73D69C73DEA57BD69C73\
D69C73E7BD94E7BD94E7BD94E7BD9CE7CEBDEFD6C6EFE7DEEFE7DEF7EFF7F7F7F7
EFEFF7EFEFE7F7F7F7F7F7F7F7EFF7F7EFF7F7F7F7F7EFF7
F7F7F7F7F7F7EFEFF7F7F7F7EFEFF7F7EFF7F7EFF7F7F7F7F7F7F7F7EFE7F7F7F7F7F7F7F7F7F7\
F7F7F7EFEFF7F7EFF7F7F7F7EFEFF7F7EFF7EFEFE7EFEFF7F7F7F7EFEFF7F7EFF7
F7F7F7F7EFE7F7EFF7F7EFE7EFEFE7EFE7DEEFE7E7DECEBDD6AD84C6845AC6845AB56B42B5734A\
AD6B398C4A298C4A297B39188442218C4221632910DEAD94E7BD9CE7BDA5EFC6A5
E7BD9CE7BD9CEFBD9CEFB594E7BD94EFBD9CEFB594E7BD94EFBD9CEFBD9CE7BD94EFB594E7BD94\
EFB594EFB594EFBD9CE7B594E7B594E7B594E7BD94DEAD84EFB594DEAD84E7AD8C
DEAD8CDEAD84DEA584DE9C7BCE946BD69C73D69C73E7BD94E7BD9CCE8C63CE946BD69C73D69C73\
CE8C63B57B5AB56B529C6339C67B42B56B39AD6331AD6B39C67B42C67B4AB56B42
C6845ACE9463CE9463CE8C5AC6845AB5734AD6AD84CE9463D6AD84CE946BE7BD94D69C73DEA57B\
E7BD94E7BD94E7BD94E7BD94E7C6ADE7C6B5EFE7DEEFE7E7EFE7E7F7EFF7F7F7F7
EFEFE7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7
F7F7F7EFEFF7F7F7F7F7EFE7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7\
F7F7F7F7EFF7F7EFE7F7F7F7F7F7F7F7EFF7F7EFF7EFEFE7F7F7F7F7EFF7F7F7F7
EFEFF7EFEFF7F7F7F7F7F7F7F7EFE7EFE7DEEFE7DEDEAD94D6AD84C6845AB5734AAD6B429C6339\
9C63398C42218C4A299452299452297B39184A1808E7BD9CE7B594E7BDA5E7BD9C
EFBD9CE7BD9CEFBD9CEFB594EFB594EFBD9CEFB594EFB594EFB594EFB594EFB594EFB594E7BD94\
E7BD94EFB594E7B594E7BD94E7B594E7B594DEAD84DEAD84DEAD84E7AD8CDEAD84
DEAD8CDEAD8CDE9C7BD69C73CE8C63CE8C63DEAD84DEAD94CE8C63C68463C68463C68C63C68463\
B57B5AAD73528C5A42AD6B42C67B42B56B39B56B39B56B39B56B42AD6B42B56B42
C6845ACE9463CE946BBD8C63BD8C63CE9463D69C7BCE946BD69C73CE946BCE946BDEA573DEA573\
DEA57BE7BD9CE7BD9CE7BDA5EFD6C6F7EFE7EFE7DEEFE7E7EFEFE7F7F7F7F7F7F7
F7EFF7F7F7F7F7F7F7EFEFF7F7EFF7EFEFF7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7EFF7F7F7F7F7EFF7F7F7F7F7EFF7F7F7F7F7F7F7\
F7F7F7F7F7F7F7EFF7F7EFF7F7EFF7F7EFF7F7EFF7F7F7F7F7F7F7F7EFF7F7F7F7
EFEFF7F7F7F7F7F7F7F7F7F7EFEFF7EFE7DEE7D6CED6AD84D69C73BD8C63B57B5AB56B42AD6B42\
8C4A29844221945229945A318C4A296B39216B3118E7BDA5E7B59CEFC6A5E7BDA5
E7B594EFBD9CE7BD9CE7BD9CEFBD9CEFB594EFB59CE7BD94EFB594E7AD8CEFB594EFB594E7AD8C\
E7AD8CE7AD8CE7AD8CEFB594DEAD84E7AD8CDEAD8CDEAD84E7AD8CDEA57BDEA584
DEA57BD69C7BD69C73C6846BCE8C63CE9463D69C73CE946BC6845AC68463C6845AC6845AB57B5A\
9C63399C6B4A9C6B4AAD6B39CE8C5AC67B4AC67B42B56B39AD6B39BD8C63C67B4A
C6845ABD8C63CE8C5AC6946BD6AD84D69C73D69C73C6946BCE946BCE946BCE946BD69C73E7BD94\
E7BDA5EFC6A5E7BDA5EFD6C6EFDECEEFE7DEEFEFE7EFE7DEEFEFE7F7EFE7EFEFE7
F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7EFF7F7EFF7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7\
F7F7F7F7EFF7F7F7F7F7EFF7F7EFF7F7F7F7F7F7F7F7EFF7F7F7F7F7EFF7F7EFF7
F7EFF7F7EFF7F7EFF7F7EFE7EFEFF7EFE7DEE7D6C6D6AD8CCE946BC6845AB5734AAD6B42AD6B39\
945A31945229AD6B399452296B31186B3118632910E7BDA5E7B59CE7BD9CDEAD94
E7BD9CEFBD9CEFBD9CE7AD8CE7AD8CEFB594E7B594E7AD8CE7AD8CE7AD8CDEAD84E7AD8CE7AD8C\
DEAD84DEAD84E7AD8CDEA584E7AD8CDEA584DEA584DEA584DEA584DEA57BDEA57B
D69C73D69C73CE946BCE8C5AC68463D69C7BC68C63B57B5AB56B52C67B4AB5734AB57B5A946342\
B5734A9C7352AD6B39AD6B42C67B4ACE8C5AC6845AB5734AC67B4AB57B5AC67B4A
BD8C63B5734AC68C63C6946BD6AD84D6AD84D6AD84CE9463CE946BD6AD84CE9463D69C73E7BD94\
E7BD9CE7C6ADEFD6C6EFE7DEF7EFE7EFE7DEEFEFE7EFE7DEF7EFE7F7EFE7F7F7F7
F7F7F7F7F7F7F7EFF7EFEFF7F7EFF7EFEFF7F7EFF7F7F7F7
F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7EFF7F7EFF7
F7F7F7F7EFE7EFEFF7F7F7F7F7F7F7EFE7DEE7BDA5D69C73D69C73BD8C63B5734AAD6B42AD6B42\
8C4A299C63399452298442216329106B3921632910E7BD9CE7BD9CE7BD9CE7BD9C
E7BD9CE7B594EFBD9CE7BD94E7AD8CEFB594E7AD8CDEAD84E7AD8CDEAD84DEA584DEAD84DEA584\
DEAD84DEA584DEA584DEA584DEAD8CDEAD84DEA57BDE9C7BD69C7BDEA57BD69C7B
D69C7BD69C73CE946BC6845ACE946BCE8C63B57B5AB56B52B5734AAD6B42AD6B42945A319C6B4A\
9C6B4A9452299C6339B56B42CE8C5ACE8C5ACE8C5ACE946BC67B4AC67B4AB5734A
B5734ABD8C63C6946BC6845AD6A584D6AD84D69C7BC6946BD6AD84DEAD8CD69C73DEAD84E7BD94\
E7BD94EFD6C6F7DECEEFE7DEE7DED6EFE7DEEFEFE7F7EFF7F7EFF7F7EFF7F7F7F7
F7EFF7F7F7F7F7F7F7F7F7F7F7EFF7F7EFF7F7F7F7F7EFF7
F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7EFF7F7F7F7F7EFF7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7\
F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7EFF7EFEFE7
F7EFF7EFEFE7F7F7F7F7EFF7F7EFE7F7EFE7CEAD94D69C73C68C63C6845A9C63399C6B4A945A31\
9C4A319C63399C4A317B42216B39217B42216B3118E7BDA5DEAD9CE7BD9CE7B594
E7BD9CE7B594E7AD8CE7BD94E7AD8CE7AD8CE7AD8CDEAD84DEA584DEA584DEA584DE9C73DE9C7B\
DEA57BDE9C7BDE9C7BDEA584DEA57BDEA57BD69C73DE9C73D69C73D69C73D69C73
D69C73CE8C63CE8C63C6845ACE946BC6845AB5734AAD6B42AD6342AD6342946342AD6B429C6B4A\
945A31945A319C6339B56B39C67B42CE8C5AC6845ACE8C5AC6845ABD8C63B5734A
B5734AB56B42C6845AD69C73D69C7BD69C73D6AD8CD6AD8CD6AD84CE946BD69C73DEAD84E7BD9C\
E7C6B5EFDECEE7DED6EFE7DEF7EFE7EFEFE7EFE7DEF7EFF7F7F7F7F7EFF7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7EFF7
F7F7F7F7EFF7F7EFF7F7F7F7F7EFF7F7EFF7F7F7F7F7F7F7F7F7F7F7EFF7EFEFF7F7F7F7F7F7F7\
F7EFF7F7F7F7F7F7F7F7EFF7F7EFF7F7EFE7EFEFF7F7F7F7F7EFF7F7EFF7F7F7F7
F7F7F7F7EFF7F7F7F7EFEFE7F7EFE7E7D6C6D6AD8CD69C73C6845AB57B5AAD6B42B5734A945229\
9C63399C6339945A315A31216329106B31186B3921E7BD9CDEAD94E7B59CDEAD94
E7B594E7B594E7AD8CE7AD8CE7AD8CDEA584DEAD84DEA57BDE9C7BDEA57BDE9C7BDE9C7BDE9C73\
CE946BCE946BCE946BD69C73D69C73DE9C7BD69C73D69C73CE946BCE946BCE946B
CE8C63CE8C63C68463BD8C63B5734AAD6B42AD6B399C6339AD6342AD6B42AD6B429C63399C6339\
9C6339AD6331B56B39B56B42C67B42CE8C5ADEA573D69C73DEAD84C68C63AD6B39
AD6B39B5734AC68C63C6845AD69C73D6AD84D6AD84D6AD84CE9463CE9463CE9463E7BD94E7C6AD\
E7C6B5E7DED6EFE7DEEFDECEEFEFE7EFE7DEF7F7F7F7EFF7F7F7F7F7F7F7F7F7F7
F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7EFF7
F7EFF7F7F7F7F7F7F7F7EFF7F7EFF7F7EFE7EFEFF7EFEFF7F7EFF7F7F7F7F7F7F7F7F7F7EFEFF7\
F7F7F7F7EFF7F7F7F7F7EFF7F7F7F7F7EFE7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7EFF7EFEFF7F7EFF7F7EFE7F7EFE7E7BDA5D6AD84C6946BBD8C63B5734A9C63399C6B4A945A31\
AD6B398C4A298442215229185229186B31186B3118E7BD9CDEAD94E7B594E7B59C
E7B594E7AD8CE7AD8CDEA584DEA57BDEA57BDEA57BDEA57BDE9C73D69C7BD69C73DE9C73D69C73\
D69C73CE946BCE946BCE946BCE946BD69C73D69C73CE946BCE946BCE946BC68463
C68463C6845AB57B5AC6845AB56B429C6339945A31AD6B429C6339AD6B42AD6B427B42217B4221\
8C4A29B56331C67B42C67B42C67B42C6845ACE9463D69C73CE946BD6AD84BD8C63
B5734AC6845AC6845ACE946BC6845AD6AD8CD6AD8CCE946BCE9463CE946BCE9463E7BD94E7C6AD\
EFE7DEE7DED6EFE7DEEFE7DEEFE7E7EFEFF7F7F7F7EFEFE7F7EFE7F7F7F7F7F7F7
F7EFF7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7EFE7F7EFF7F7F7F7F7EFE7F7F7F7F7EFF7F7F7F7F7EFF7F7F7F7F7EFF7F7EFE7
F7EFF7F7F7F7EFEFE7F7EFF7E7DED6D6B5A5D6AD84BD8C63B57B5AAD6B429C6B4A945A31945A31\
9C63398C4A297B39186B31186B39216B39217B3918DEAD94DEAD94DEAD8CDEAD8C
E7AD8CDEAD8CDEA584DEAD8CDEA584DEA584D69C7BDE9C73DE9C73CE946BCE946BCE946BC6846B\
CE8C63CE8C63C6846BCE946BCE946BC6846BCE946BCE946BCE946BC68463C6845A
C68463C6845AB5734ACE8C5AAD6B428C4A299C6B4A9C6B4A9C6339945A318442217B4221632910\
AD6331C67B42B56331C67B42B56B42C67B4ACE9463DEA573D69C7BDEAD84BD8C63
BD8C63CE9463BD8C63CE946BC6946BD6AD84CE946BCE946BC6845ACE8C5ADEAD84E7C6ADEFD6C6\
EFDECEEFDECEE7DED6EFEFE7F7EFE7F7EFE7F7F7F7F7EFF7F7EFF7F7F7F7F7F7F7
F7F7F7EFEFF7F7F7F7F7EFF7F7F7F7F7EFF7F7F7F7F7F7F7
F7F7F7F7F7F7F7EFF7F7F7F7F7EFF7F7EFF7EFEFF7F7EFF7F7EFF7F7F7F7F7EFF7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7EFEFF7F7EFE7F7EFF7EFEFF7F7F7F7F7F7F7F7EFF7F7F7F7
F7F7F7EFEFF7F7EFF7EFEFE7E7C6B5D6AD8CC69C84B57B5AB57B5A9C6B4AAD63429C6339945A31\
945A316B39216B39216B31186B39216B39216B3921DEAD94DEAD8CDEAD94E7BDA5
E7AD94E7AD94E7A594E7AD94E7A594E7A594DEAD8CDEA584DEA584D69C7BCE8C63C6845ACE8C63\
C67B5AC6845AC6845AC6845AC6845ACE8C63CE8C63C6845AC6845AC6845AB57B5A
B57B5AB56B52B5734AC6845A9C63397B4A299C6339AD6B428C4A297B42217B39187B4A29945229\
AD5A31C67B42C67B42B5734AC67B42AD6B39CE9463D69C73D6AD84CE946BC6946B
C6845AC68C63C68C63BD8C63D6AD84D6AD84CE9463D69C73CE9463D6AD84D6AD84DEC6B5F7EFE7\
EFD6C6E7DED6EFEFE7EFE7E7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7EFF7
F7EFF7F7F7F7F7F7F7EFEFE7EFEFE7F7F7F7F7EFF7F7F7F7F7F7F7F7EFF7F7EFF7F7F7F7F7F7F7\
EFEFF7F7F7F7F7EFF7F7F7F7F7EFE7F7EFF7F7EFE7F7F7F7F7F7F7F7EFF7F7EFF7
EFEFF7EFEFF7EFEFF7EFE7DEDEC6B5D6AD84C6946BB57B5AB5734AAD6B429C6339B5734A9C4A31\
945A315221107342296B39216B39216B3118845231DEAD94E7C6ADEFC6ADEFC6AD
EFC6ADEFC6A5EFC6A5EFB59CEFB59CEFB59CE7AD9CE7AD94E7AD94DEAD8CDEA584D69C7BC67B5A\
C67B5AC67B4AC67B5AC67B5AB57B5AB57B5AB57B5AC6845AC67B5AB57B5AC67B4A
B5734AAD6B42AD6B42C67B4A8C4A298C4A319C63398C5A428442216B31186B3921AD6331844221\
9C6339C67B4AC67B42B5734AAD6B39B5734ACE8C5AD69C7BDEAD84DEAD8CD6AD84
C6946BC6946BB57B5AB56B42D6AD84D6AD84C6946BCE946BD6AD84D6AD84E7BD9CEFEFE7EFE7DE\
EFE7DEEFE7DEEFEFE7F7EFE7F7EFF7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7
F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7EFEFF7
F7F7F7F7EFF7F7EFF7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7EFF7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7EFEFE7F7F7F7F7EFF7F7F7F7F7EFE7
EFEFF7F7EFF7F7EFF7E7CEBDD6B5A5D69C73C68C63B57B5AAD7352945A319C6339945A319C6339\
8442216329107B42217342296B39216B3118B58463EFC6ADEFC6B5F7D6BDF7C6B5
F7C6B5EFC6ADEFC6ADF7C6B5EFC6ADEFC6ADEFB59CEFB59CE7B59CE7AD94DEAD8CDEA584DE9C7B\
CE946BC67B4AB5734AB57B5AC67B4AC67B4AC67B5AB56B52B57B5AC67B4AB57B5A
B5734AAD6B42946342B5734A945A319C6339B5734A8442217B39186B3118734A31B56B398C4221\
9C6339B56B42C67B4AB56B39AD6B39B5734AC6845ACE8C5ADEAD84DEAD8CD6AD84
D69C73C6946BB5734ABD8C63D69C73D69C73D69C73D69C73E7BD94D69C73E7BD9CEFEFE7EFDECE\
E7D6C6F7E7DEEFE7E7F7F7F7F7EFF7F7F7F7EFEFF7F7EFF7EFEFF7F7EFF7F7EFF7
F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7EFF7F7F7F7F7EFE7F7F7F7F7EFF7F7EFE7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7\
F7EFE7F7F7F7F7EFF7F7EFF7F7F7F7F7EFF7F7EFF7F7F7F7F7EFF7EFEFF7EFEFF7
F7EFE7F7EFF7F7EFF7E7CEBDCEAD94C6946BBD8C63AD7352AD6B42AD6B429C6339945A319C6339\
6329106B39217B4A296B39216B3921B58C73EFC6B5F7CEB5F7D6BDF7CEB5F7D6BD
F7C6B5F7D6BDF7C6B5F7CEB5F7C6B5EFC6ADEFC6A5EFC6ADEFB59CEFB59CE7AD94E7AD8CDEA584\
DEA57BD69C73CE946BB5734AB5734AB5734AB5734AC67B4AB5734AB57B5AB5734A
AD63429C6B4A845239844221B5734A945A31C6845A7B39186B3118522110632910AD6B39B56B42\
945229B56B42CE8C5AAD6B39BD8C63B5734AC6845AD69C73DEAD84E7BD94E7BDA5
D6AD8CB56B42BD8C63BD8C63CE946BC68C63D69C73D6AD8CD6AD84DEA57BEFE7E7EFDECEEFCEBD\
EFE7DEF7EFE7F7EFF7F7F7F7F7F7F7F7EFE7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7
F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7
F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7EFF7F7EFE7F7F7F7F7F7F7F7F7F7\
F7EFE7F7EFF7F7F7F7F7EFF7F7EFF7F7EFF7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7
EFEFF7EFE7E7E7D6C6E7C6ADC69C84C6946BB57B5A9C6B4A945A319C63399C6339945A31844A29\
6329107B4A297B4A296B3921E7C6B5F7CEB5EFCEADF7CEB5F7D6BDF7D6BDEFD6C6
F7D6BDEFD6C6F7C6B5F7C6B5F7C6B5F7CEB5EFC6ADEFC6A5EFC6A5EFC6A5E7BD9CDEAD94DEAD8C\
E7AD8CDEA584D69C7BCE946BB56B52AD6B42AD6B42B5734AAD6B42B56B52AD6B42
AD63429C63398442217B4221C6845A844221CE8C639C63396B3921734A31522110844221C67B4A\
8C4221B56B42C67B4AB56B39C6845AC6845AC6845ACE9463D69C73E7BD9CE7BDA5
D6AD84C68C63B57B5ABD8C63C6946BC6946BD6AD84D6AD8CD6AD84E7BD94E7DED6E7D6CEE7DED6\
EFEFE7EFEFE7F7F7F7F7EFE7F7F7F7F7EFF7F7F7F7F7F7F7F7EFF7F7EFF7F7F7F7
F7EFF7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7\
F7EFF7F7EFE7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7
EFEFE7EFE7E7DECEBDD6BDADBD947BBD8C63B57B5AAD6B429463429C6339945A31945A316B3921\
6B31187B42216B3921A5846BEFCEB5F7CEB5EFC6ADF7CEB5F7CEB5F7D6BDF7D6BD
F7D6BDF7D6BDEFD6C6F7D6BDF7C6B5F7C6B5EFC6ADEFC6ADEFC6ADE7BDA5E7B59CE7BD9CE7B594\
E7AD8CDEAD94DEA584D69C7BC6846BCE946BAD6342AD6342AD6B429C6B4AAD6342
9463429C4A31844A31734229C67B4AAD7352B57B5AB5734A6B31185221107B42219C6339C67B4A\
C6845AC67B4AC67B4AC6845AAD6B42C68C63BD8C63C6946BD69C73D6AD84E7BD9C
E7BD94BD8C63B5734ABD8C63C67B4AC6946BD6B5A5E7BD94CEB5A5D6AD8CE7C6ADEFE7DEF7EFE7\
F7EFE7F7EFF7F7F7F7F7EFF7F7F7F7F7EFF7F7F7F7F7EFF7F7EFF7F7F7F7F7F7F7
F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7
EFEFF7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7EFE7F7F7F7F7EFF7F7EFF7F7F7F7F7EFF7F7EFF7\
F7EFF7F7EFE7F7F7F7F7EFF7F7EFF7F7EFE7F7F7F7F7F7F7EFEFE7F7F7F7EFEFF7
EFEFE7E7DED6DECEBDCEAD94BD947BBD8C63B5734A9C6B4A845239945A318C4A29945A31522918\
6B39217342298C5A42EFC6ADEFC6B5F7CEB5F7CEB5F7CEB5F7CEB5F7D6BDF7C6B5
F7D6BDF7C6B5F7C6B5F7D6BDF7C6B5F7C6B5EFC6ADEFC6A5EFC6ADEFC6ADEFC6A5E7B59CE7B59C\
E7B594DEAD94DEAD8CDEA584D69C7BCE946BC6846B9C6339AD6342AD6342945A42
9C6339844A297B4A296329109C6B4AD69C7B8C4A29CE946B946342AD6B426B3118AD63318C4A31\
BD8C63AD6331C67B42C67B4ABD8C63B58463C6946BB57B5AD6AD84CE9463E7BDA5
EFCEB5BD8C63B5734ABD8C63C68C63C69C84D69C73D6AD84D6AD8CE7BD94E7DED6EFE7DEEFE7E7\
F7EFE7EFEFE7F7EFF7F7F7F7F7EFF7F7F7F7F7F7F7F7EFF7F7EFF7F7F7F7F7EFF7
F7EFF7F7F7F7F7EFF7F7EFF7F7F7F7F7EFF7F7F7F7F7F7F7
F7EFF7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7EFF7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7\
F7EFF7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7EFE7E7
EFE7E7E7CEBDDECEBDC69C84C68C63AD7352B5734A946342945A31945A318452316B39216B3118\
844A29845A42EFC6B5EFC6ADEFCEADF7CEB5F7CEB5F7CEB5F7C6B5EFCEADEFC6AD
EFC6ADEFC6ADEFC6ADEFC6ADEFC6A5EFB59CEFB59CE7BDA5EFC6A5E7BD9CEFBD9CE7B59CE7B59C\
DEAD8CE7AD8CDEAD94DEAD8CDEA584D69C73CE946BCE8C639C63399C4A319C6339
8C4A318C4A296B39216B3921845239BD8C63B57B5A9C6B4AC69C848C4221B57B5A945A31AD6342\
B56B42C67B4AAD6B39C67B4ABD8C639C6339BD8C63BD8C63D69C73D69C73CEAD94
DEAD8CE7BD94BD8C63B56B42BD8C63C69C84C6946BD6AD84E7BD94E7D6CEEFEFE7E7DED6EFEFE7\
F7EFE7EFEFE7F7F7F7F7EFF7F7EFF7F7F7F7F7EFF7F7F7F7F7F7F7F7EFF7F7F7F7
F7EFF7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7EFF7F7EFF7F7EFF7F7EFF7F7F7F7\
F7F7F7F7EFF7F7F7F7F7EFF7F7EFE7EFEFF7F7EFF7F7EFF7F7F7F7F7F7F7EFE7E7
E7D6CEE7CEBDCEB5A5BD947BB57B5AAD7352946342945A31945A31945A315A31216B39216B3118\
6B3118EFC6B5EFC6B5F7CEB5EFCEADEFC6ADEFC6ADF7C6B5EFC6ADEFBD9CE7B59C
E7AD94E7AD94DEAD8CDEAD8CDEAD8CDEA584DEAD8CDEAD8CDEAD8CDEAD8CE7B594E7B594E7B594\
E7B59CE7B594DEAD8CDEAD8CDEA584DE9C7BD69C7BD69C73CE8C63B56B52945A31
845231844A317342296B3921734A31946342CE946BBD8C63A57B5AD69C73C67B4AB57B5A844221\
AD6B39C6845AC67B42C67B4AAD6B39B57B5AB57B5AD69C7BC6946BD69C73D6AD84
E7BDA5E7C6B5BD8C63C6946BD69C7BC6946BC68C63CEAD94E7BD9CF7EFE7E7DED6F7EFF7EFEFE7\
F7EFE7EFEFE7F7F7F7F7F7F7F7EFF7F7F7F7EFEFF7F7EFF7F7F7F7F7EFF7F7EFF7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7
F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7EFF7F7EFF7F7EFF7F7F7F7F7F7F7F7EFF7F7EFF7EFE7E7
E7D6C6DECEBDD6AD8CC6946BB5734AB5734AAD63428C4A31945A318452316B31186B3921844A29\
E7C6B5EFCEB5EFCEB5F7CEB5EFCEADEFC6ADEFC6ADEFC6A5E7BDA5E7AD94E7AD8C
DEA584DE9C7BE78C7BE78C7BE78C7BE78C7BE78C7BDEA584DE9C7BDEA584DEAD8CDEA584E7B594\
E7B594E7B59CDEAD94DEAD8CDEA584D6A584D69C7BCE946BCE946BC684638C5A42
8442297B4A296B39215229186B39218C634ACE946BAD7352945A31D6A584C67B4ACE9463B57B5A\
9C6339AD6B42CE8C5AC67B4AB5734ABD8C63B57B5AD69C73C6946BD6AD84D69C73
D6AD84E7C6ADD6AD84D69C73C69C84C69C84D69C73D6AD8CE7BDA5EFE7DEEFE7DEF7EFE7EFEFE7\
F7EFF7F7F7F7F7EFF7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7
F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7EFF7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7EFE7F7EFE7F7F7F7F7EFF7EFEFE7E7D6CE
E7CEBDDECEC6C69C84B57B5AAD73529C6339AD6342845239844A296B39216B39217B39187B4A29\
EFC6B5EFC6B5EFC6ADEFC6ADEFC6ADEFC6ADEFC6A5EFB59CDE7363CE6B5ADE7B6B
DE7B6BDE8473DE8473DE8473DE8473DE8473CE6B5ACE6B5ACE6B5ACE6B5AD69C7BDEAD8CDEAD8C\
E7B594E7B594E7B594DEAD94DEAD8CDEA584D69C7BD69C7BCE946BC6846BC6845A
7B4A296B39216B31185221106B3118845239AD7352D69C7BB58463C6846BD6AD84CE9463D69C73\
C6946BC67B4AB5734AC6845ABD8C63AD6B39B5734ABD8C63D69C73BD8C63DEAD84
D6AD8CE7BD94E7BDA5C69C84D6AD84C6946BD69C73E7BD94DECEBDE7D6CEEFE7E7EFEFE7EFE7E7\
EFEFE7F7EFE7F7F7F7EFEFF7F7EFF7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7EFF7
F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7
F7F7F7F7EFF7F7F7F7F7EFF7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7\
F7EFF7F7EFE7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7EFE7F7F7F7EFE7E7E7DED6
E7D6C6D6AD8CC6946BA57B5A9C6B4A9C6339945A317B4A298452397342296B39217B4A29EFCEBD\
EFC6B5EFC6ADEFC6ADEFC6A5EFCEADEFC6ADE78C7BDE8473DE8473DE8473EFC6B5
EFB59CE78C7BE78C7BE7A594EFB59CDE8473DE8473DE7B6BC6846BCE7363CE6B5AD69C7BDEAD8C\
DEAD94E7B594E7B59CDEAD94DEAD8CDEAD8CD6A584D69C7BCE946BDE8473C68463
B57B5A734A31522918522918522110845239522918D6A584DEAD8C9C6339D6AD8CB57B5ADEA57B\
D6AD84BD8C63C6845ACE9463AD6331C6845AB57B5ABD8C63C6946BCE946BD69C7B
D6AD8CE7BDA5E7C6B5BD947BB58463C6946BD69C73CEAD94EFE7DEEFE7DEEFEFE7EFEFE7EFE7DE\
F7F7F7F7F7F7EFEFF7F7EFF7F7EFF7F7F7F7F7EFF7F7F7F7F7EFF7F7EFF7F7F7F7
F7F7F7F7EFF7F7F7F7F7F7F7F7EFF7F7EFF7F7F7F7F7EFF7
F7EFF7F7F7F7F7EFF7F7F7F7F7EFF7F7F7F7F7EFF7F7F7F7F7EFF7F7EFF7F7F7F7F7EFF7F7EFF7\
F7EFF7F7EFF7F7EFF7F7EFF7F7EFE7F7F7F7F7F7F7EFEFF7F7F7F7E7D6D6DECEBD
CEAD94C6946BB58463A57B5A845239945A318C4A31945A316329106B39216B3921A5846BEFCEB5\
EFCEB5EFCEB5EFC6ADEFC6A5EFC6A5EFC6A5DE7B6BDE8473DE8473DE7B6BDE7363
DE7363DE7363DE8473CE6B5ACE6B5AC65A4AC6634AC6634AE78C7BCE7363CE7363C65A4AD6A58C\
E7AD94E7B594E7B594E7B594E7B594DEAD8CD6A584D69C7BD69C7BCE946BCE946B
C6845AAD73526B39216B39213918106B31188C5A42B58463C6946BB57B5ABD8C63D6AD84C6845A\
DEAD84EFCEADBD8C63B5734AC6845AC6845AAD6B42B57B5ACE9463C6946BD69C73
D69C73E7BDA5E7BDA5C69C84C6946BC69C84BD947BCEAD94EFE7DEEFE7E7F7EFE7EFE7E7EFE7E7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7EFF7F7F7F7F7EFF7F7EFF7F7EFF7F7F7F7F7EFF7F7EFF7\
F7EFF7F7F7F7F7F7F7F7EFF7F7EFF7F7F7F7F7EFF7F7EFF7F7EFF7E7D6CED6C6B5
D69C73C6946BAD73529463428C4A31945A31844A296B31187B42216B3118945A31EFCEBDEFCEBD\
EFCEB5EFC6ADEFC6ADEFC6A5E78C7BDE8473AD73529C4A31AD4A31BD5242AD7352
BD5242BD5242C65A4AB552399C4A319C31219C4229AD4A318C3121AD42319C4229844229945A42\
DE8473E7B594E7B594E7B594DEAD8CDEAD8CDEAD8CD69C7BD69C7BD69C73D69C7B
C68463B57B5A8C5A424A18083918106B3921734A31845A42BD8C63D6A584945A31D6A584B57B5A\
D69C7BE7BD9CEFCEADCE946BCE946BB56B39C6845AB57B5ABD8C63C68C63B57B5A
D6AD84E7BD94E7BDA5D6BDADD69C73D6AD84C69C84D6B5A5E7DED6EFEFE7EFE7DEEFEFE7F7EFF7\
EFEFE7F7F7F7F7F7F7F7EFF7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7EFF7F7F7F7F7F7F7
F7EFF7F7EFF7F7EFF7F7F7F7F7F7F7F7EFF7F7EFF7F7F7F7F7EFF7F7F7F7F7EFF7F7F7F7F7EFF7\
F7F7F7F7EFF7F7EFF7F7EFF7F7EFF7F7EFF7F7EFE7F7EFF7EFE7E7E7D6CED6BDAD
BD947BB57B5A9463428C4A318C5A428C4A297B4A297B4A297B4A29844229EFCEBDEFCEBDEFC6B5\
EFCEB5F7CEB5EFC6ADEFC6A5EFB59CEFC6A5E78C7BCE7363CE6B5AC6634ACE6B5A
C6634ACE6B5ADE7B6BC6634AC6634AC6634AC6634AC6634AC6634AD69C73D6A584D6A58CDEAD8C\
DEAD8CE7B594E7B594E7AD8CE7AD8CDEAD8CE7AD8CDEA584D69C7BD69C7BD69C73
CE946BC684639C73525A39293918103918105A3929845A429C7352D69C7BC6946B9C6B4AD69C73\
B57B5AE7BD9CE7BD9CEFCEB5AD7352C6845AC6845AB57B5ABD8C63BD8C63B57B5A
D6AD84D6AD84E7BDA5E7C6ADC6946BD6AD84D69C73E7D6C6EFE7E7EFE7E7EFE7DEEFE7DEF7EFF7\
F7EFF7F7EFF7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7EFF7
F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7
F7F7F7F7EFF7F7EFF7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7EFF7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7EFE7F7F7F7F7EFF7EFEFE7F7EFE7EFE7DEDECEC6D6AD8C
B584639C6B4A9C6B4A8C5A428C4A29844A297342297B4A29844221845231EFCEB5EFC6ADEFCEB5\
EFCEADEFC6ADEFCEADEFC6A5EFCEADF7CEB5F7CEB5F7D6BDEFD6C6EFC6B5EFC6AD
F7D6BDEFC6ADEFC6A5F7CEB5F7D6BDEFC6B5EFC6ADE7BDA5E7B59CE7BDA5E7B59CE7B594E7B594\
E7B59CE7B594E7B59CE7B594E7AD94DEAD8CDEAD8CDEA584DEA584D69C7BD69C73
CE946BCE946BB57B5A845231423129291008845A42734A31845A429C7352BD8C639C6339C6845A\
AD6B42C6845AE7BD9CE7BD9CD69C73CE946BBD8C63B5734AB5734ABD8C63CE946B
D69C73CE946BE7BDA5E7C6ADC69C84C69C84C68C63E7DED6EFE7DEEFE7DEEFE7E7EFE7DEF7F7F7\
F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7
F7EFF7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7
F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7EFF7\
F7EFF7F7F7F7F7F7F7F7EFF7F7EFE7F7EFF7F7EFF7EFE7E7DEC6B5E7BD9CC69C84
AD7352946342845231845231844A316B31187B4A297B4A297B4221D6B5A5EFCEB5EFCEB5EFCEB5\
F7C6B5F7CEB5EFC6ADF7CEB5EFC6ADF7CEB5F7CEB5F7D6BDF7CEB5F7D6BDF7CEB5
F7D6BDEFC6A5EFC6ADEFC6ADEFC6ADE7B59CE7B59CE7B59CE7B59CE7BD9CE7B59CE7BD9CEFC6A5\
E7B59CE7B594E7BD9CE7B59CE7AD94E7AD94DEAD8CDEA584DEA584D69C7BDE8473
CE946BCE946BB57B5A945A42522110422118734A31845231A5846B9C7352C69C849C6339945A31\
C68C63BD8C63DEAD94E7BD9CEFC6A5D6AD84C6845AC6845AC68C63B5734AB57B5A
B57B5ACE946BE7BDA5E7C6ADD69C73D6AD8CC6946BEFE7DEEFE7E7E7DED6EFE7DEF7EFE7F7F7F7\
F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7EFF7F7EFF7F7EFF7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7
F7EFF7F7F7F7F7EFF7F7EFF7F7EFF7F7EFF7F7F7F7F7EFE7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7\
F7F7F7F7EFF7F7F7F7F7EFF7F7EFF7F7EFE7F7EFF7F7EFF7DECEC6C69C84B57B5A
9C63399C6B4A844A29844A316B39217B4A297B4A297B4A297B4A29EFCEB5EFCEB5EFC6B5EFCEB5\
F7CEB5F7C6B5F7C6B5F7CEB5EFCEB5F7CEB5F7CEB5F7CEB5F7CEB5F7CEB5F7CEB5
EFCEB5EFC6ADEFC6A5EFC6A5EFC6A5E7B59CE7BD9CEFBD9CE7B59CE7BDA5E7B59CEFC6A5E7B59C\
EFC6A5E7B59CE7B59CE7AD94E7AD94E7B594DEAD8CDEA584DE9C7BDEA584D69C73
CE946BCE946BC684639C6B4A7342295A39293918107352428452399463429C6339AD73529C6339\
B57B5AA57B5ACE946BE7BD94E7BD94CE946BD69C73C6845ABD8C63B5734ABD8C63
B5734AD69C73D6AD84E7BDA5CEAD94C6946BD69C7BE7D6CEEFE7DEEFE7DEE7D6C6F7F7F7F7EFF7\
F7F7F7F7F7F7F7EFF7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7
F7F7F7F7F7F7F7EFF7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7EFF7F7F7F7F7EFF7F7EFF7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7EFF7F7EFE7DECEC6D6C6B5BD947BB5734A
9C6B4A844A298C5A426B39217B4A296B31187B4A29844A296B3921EFCEB5EFC6B5EFC6B5EFCEB5\
F7CEB5F7CEB5F7CEB5F7C6B5F7CEB5F7CEB5F7CEB5F7CEB5EFCEB5F7CEB5F7CEB5
EFC6A5EFC6A5E7B59CEFC6A5E7B59CE7AD8CE7B594E7BD9CE7B59CEFB59CEFBD9CEFC6A5EFB59C\
EFB59CEFC6ADEFC6A5E7B59CE7B59CE7AD94E7AD8CDEA584DEA584D69C7BD69C73
DE8473C6846BC68463B5734A734A31522110522918734A318C634A946B529C7352B584639C6B4A\
8C5A42946342BD947BC68C63DEA573EFC6A5D6AD84C67B4AC68C639C6B4AC6946B
BD8C63D69C7BD69C73E7BDA5CEAD94BD8C63E7C6B5E7D6C6EFE7E7EFE7E7EFE7E7F7EFF7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7
F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7\
F7F7F7F7EFF7F7EFF7F7EFF7F7F7F7F7F7F7EFE7E7DEC6B5C6A594BD947B9C6B4A
9C63399463428442297B4A297B4A29734A317B4A296B3921B58463E7C6B5EFC6B5EFC6B5F7CEB5\
F7CEB5F7CEB5F7CEB5F7D6BDF7CEB5EFCEB5F7CEB5F7CEB5F7CEB5EFC6ADEFC6AD
E7B59CDEAD8CDEA584E7AD94DEAD94DEA584DEAD8CE7AD94E7B594E7B59CEFBD9CE7BDA5EFC6A5\
EFC6ADEFC6ADEFB59CEFB59CE7B59CE7AD94DEAD8CDEA584DEA584D69C7BD69C7B
D69C73CE946BC67B5AB56B528C5A425A39296B39215A4239845A428452399C7352946342B5734A\
8452319C6339845239D6AD8CE7BD94D69C73DEA57BC68C63C6946BA57B5AB57B5A
BD8C63C69C84D69C73E7BD9CD6B5A5C6946BE7DED6E7BDA5F7EFF7EFE7E7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7
F7EFF7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7
F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7EFF7F7EFF7F7F7F7F7F7F7F7EFF7\
F7F7F7F7F7F7F7F7F7F7EFE7F7F7F7F7EFF7F7EFF7E7BD9CBD947BAD7352946342
8C4A318C4A317B4A296B39216B39217B4A297B4A296B3118E7C6B5EFC6B5EFC6B5F7C6B5F7CEB5\
F7CEB5F7CEB5F7CEB5F7CEB5F7CEB5EFCEADF7CEB5F7CEB5F7CEB5EFC6ADEFB59C
E7AD9CE7B594DE9C7BDEA584DEA584D69C7BD6A584DEAD8CDEAD8CE7B594E7B59CEFBD9CEFB59C\
EFC6A5EFC6A5EFC6A5EFB59CEFC6A5EFB594E7AD94DEAD8CDEA584D69C7BD69C7B
D69C73C6846BC68463B57B5A945A425A3929291008422921734A318452319C6B4A845239B5734A\
9C63399C63397B4A29D6A584C6845AD69C73EFCEADC6946BC68C63C68C63B57B5A
B58C73C6845AC6946BE7BD9CD6BDADD6BDADDECEBDE7D6CEE7D6CEE7CEC6F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFE7E7D6AD8CB58463946342845231
8C4A316B39217B4A297342297B4A298442296B31185A3121EFC6B5E7C6ADEFC6ADEFC6ADF7CEB5\
F7C6B5F7D6BDF7D6BDF7CEB5F7CEB5F7CEB5F7C6B5EFD6C6DE9C7BDE7B6BEFC6AD
EFC6ADEFB59CE7A594B56342B56342C6846BDE9C7BB57B5AD69C73DEAD8CE7B59CEFC6A5EFC6A5\
EFC6ADEFC6ADEFC6ADEFC6A5EFB59CE7B59CE7AD94E7AD8CDEA584DEA584D69C7B
D69C73CE946BC68463B56B52AD63427342293918104229215A3121734A31845239845A429C6B4A\
9C6B4A8452319C6B4A8C5A42BD8C63DEAD84D69C73DEAD84C6845ABD8C639C6339
B57B5AB57B5AD69C73E7BD94D6BDADEFE7E7CEAD94EFE7E7D6B5A5F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7
F7EFF7F7EFF7F7F7F7F7EFF7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7EFF7F7F7F7F7EFF7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7E7DEDEC6946BAD73529463429C6339
7B4A297B4A296B39217B42217B4A296B39215A3121845239EFC6B5EFC6ADEFCEB5F7CEB5F7D6BD\
F7CEB5F7C6B5F7D6BDF7C6B5F7CEB5EFCEADF7CEB5F7D6BDEFCEB5EFC6B5F7C6B5
F7C6B5EFC6ADE7B594DEAD8CDEAD94E7AD8CE7B594DEA584CE8C63D69C7BE7B59CEFC6ADEFC6AD\
EFC6ADEFC6ADEFC6ADEFB59CEFC6A5EFC6A5EFB594E7AD8CDEAD8CDEA584D69C7B
CE946BCE946BC68463C67B5A9C73528C5A422910083918104229215A42397352428C5A42845239\
9C7352845231945A31522918D6AD84CE8C63CE9463E7BD9CB57B5ABD8C639C6B4A
AD7352BD8C63C6946BCEAD94DEC6B5DEC6B5C6AD9CD6B5A5F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7EFF7F7EFF7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7EFF7F7EFF7F7F7F7F7F7F7\
F7F7F7F7F7F7F7EFE7F7F7F7F7F7F7F7F7F7E7D6CEBD8C63946342945A426B3921
734A31844A317342297B4A29844A31632910632910A57B63E7C6ADF7C6B5F7C6B5F7C6B5EFD6C6\
F7D6BDF7D6BDF7D6BDEFD6C6F7CEB5F7CEB5F7C6B5F7D6BDEFC6B5EFD6C6EFD6C6
EFD6C6F7C6B5EFC6A5E7B594E7AD9CE7AD9CDEAD94DEAD8CDEA584DEA584EFB59CEFC6ADEFC6AD\
F7C6B5EFC6ADEFC6ADEFC6ADEFB59CEFB59CEFB59CE7B594E7AD8CDEAD8CDE9C7B
DE8473DE8473C68463B57B5AAD6B42946342291008422118391810734A31845239946342734229\
9C6B4A845231945A315A3121C6946BBD8C63D6AD84E7BD9CB57B5ABD8C63AD7352
B57B5AB58463BD947BD6AD8CDEC6B5DEC6B5D6BDADDECEBDF7F7F7F7F7F7F7EFF7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7EFF7F7F7F7F7F7F7F7EFF7F7F7F7F7EFF7F7F7F7F7F7F7\
F7EFE7F7F7F7F7EFF7F7EFF7F7F7F7F7EFF7E7CEC6AD73528C5A42945A31845231
7B4A297B4A29844A298C4A317B42215229185A3929E7C6B5EFC6B5F7CEB5F7CEB5F7D6BDF7D6BD\
F7D6BDEFD6C6F7D6BDEFD6C6F7D6BDF7C6B5EFC6ADF7D6BDF7D6BDEFD6C6F7DED6
EFD6C6F7C6B5EFC6ADE7BDA5E7AD94E7A594DEAD94DEAD8CDEA584E7AD94EFB59CEFC6ADEFC6AD\
EFCEADEFC6ADF7C6B5EFC6ADEFC6A5EFC6A5EFB59CEFB59CE7AD94E7AD8CDEA584
DE9C7BCE946BC6846BB57B5AAD6B42945A315229181808084221187342295229189C6339845231\
9C6B4A7B42218452318C5A42AD7352C68C63DEA57BDEA57BD69C73B57B5ABD8C63
AD7352B57B5AB57B5ACEAD94E7C6ADD6B5A5E7CEC6F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7EFF7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7EFF7F7F7F7F7EFF7F7EFF7F7F7F7\
F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7EFE7C6946B9463429463426B3921734229
7342297B4A29844A317B4A29422118632910422118EFC6ADF7C6B5EFCEBDF7C6B5F7D6BDF7D6BD\
EFD6C6F7D6BDF7D6BDF7D6BDF7D6BDF7D6BDF7CEB5F7CEB5F7C6B5EFD6C6EFD6C6
EFD6C6F7CEB5EFC6ADE7AD94D6A58CDEA584DEAD8CD6A58CDEAD94E7B59CEFC6ADEFC6B5EFC6B5\
EFCEB5F7CEB5EFC6ADEFC6ADEFC6A5EFC6ADEFC6A5EFB59CE7AD94E7AD8CDEAD8C
DEA584D69C73C6846BB57B5AAD7352AD6342734A312110083918105A39297B5A428452398C5A42\
9463427B4A29845231734A319C7352C6845ACE946BDEAD8CE7BDA5B5734AB57B5A
9C7352B57B5AC6946BE7BD9CE7C6ADC69C84DECEBDF7F7F7F7EFF7F7F7F7F7EFF7F7EFF7F7EFF7\
F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7EFF7F7EFF7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7\
F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7EFEFF7B5846B946342844A296B3921845239
844A31844A317B4A293918105229185221105A3929EFC6ADF7CEB5F7D6BDEFD6C6EFD6C6EFD6C6\
EFD6C6EFD6C6EFD6C6EFD6C6EFD6C6F7D6BDF7D6BDF7C6B5EFCEBDF7C6B5F7D6BD
F7C6B5EFC6B5EFB59CE7B59CD6A58CDEAD8CDEAD94DEAD94E7B59CEFC6ADEFC6ADEFC6ADEFC6B5\
F7C6B5F7CEB5EFC6B5F7C6B5EFC6ADEFC6A5EFC6ADEFB59CEFB59CE7AD94E7AD8C
D6A584DEA584CE946BC68463AD73529C6B4A8C4A31291008423129522918734229734A31845231\
8452319C6339845231845231A57B5ABD8C63CE9463DEAD8CEFCEADB57B5AB5734A
9C6B4AA57B5AB58463CEAD94DEC6B5DECEBDF7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7
F7F7F7F7F7F7F7EFF7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7\
F7EFF7F7F7F7F7EFF7F7EFF7F7EFF7F7EFF7B5846B945A317B4A297B4A29845239
734A317B4A29844A31522918422118522918CEAD94EFCEB5EFCEB5F7D6BDEFD6C6EFD6C6EFD6C6\
EFD6C6F7DECEF7DECEF7DECEEFD6C6F7D6BDF7D6BDF7D6BDF7CEB5EFC6B5F7D6BD
F7D6BDEFC6ADEFB59CDEAD94DEAD94DEAD8CE7B594E7B59CE7BDA5EFC6ADEFCEB5EFC6B5F7C6B5\
F7C6B5F7D6BDEFCEBDF7C6B5EFC6B5EFC6ADEFC6ADEFB59CE7B59CE7B59CDEAD94
DEA584D69C7BD69C73C68463B56B529C6B4A9463424221182110085A31215229188452398C5A42\
7B4A29945A319C63398452319C7352C69C84D69C73DEAD84EFCEADAD7352C68C63
8C5A42B58463AD7352E7BD94E7CEBDDECEBDF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7
F7EFF7F7EFF7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7EFF7F7EFF7\
F7F7F7F7F7F7F7EFF7F7EFF7F7F7F7DEC6C69C73528C5A42734229845231845231
844A317B4A29522918422118391810EFB59CEFCEBDF7C6B5F7D6BDF7DECEEFD6C6EFD6C6F7DECE\
EFD6C6EFD6C6EFD6C6EFD6C6EFD6C6EFD6C6EFD6C6EFD6C6F7D6BDF7CEB5F7D6BD
F7D6BDF7C6B5EFC6ADE7B59CDEAD94E7B594E7B594E7B59CE7BDA5EFC6B5EFC6B5EFD6C6F7D6BD\
F7C6B5EFD6C6F7C6B5F7D6BDEFCEBDEFCEBDEFC6B5EFC6ADE7C6ADEFB59CE7B594
DEAD8CD6A584D69C7BD69C73B57B5A9C6B4A9C63397342296329106B3921734A31734A31946342\
8452319C63398C5A428C4A319C7352D6A584D69C73D6AD84E7BDA5BD8C63B5734A
845231A57B5AB57B5ADEAD8CE7D6C6EFEFE7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7EFF7F7EFF7F7F7F7F7F7F7F7EFF7F7F7F7
F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7EFF7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7EFF7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F79C7352945A318452315A31217B5A42734A31
734A31844A315229186B39215A3929EFC6ADEFC6B5EFD6C6F7D6BDEFD6C6EFD6C6F7DECEF7DECE\
EFD6C6EFD6C6F7D6BDF7DECEEFD6C6EFD6C6EFD6C6EFD6C6F7D6BDEFCEBDF7D6BD
F7D6BDF7D6BDF7C6B5E7B59CDEAD94E7B59CE7BD9CE7BDA5E7BDA5E7C6ADEFCEB5F7D6BDEFCEBD\
F7D6BDEFD6C6F7D6BDF7C6B5EFCEBDEFCEBDEFCEBDEFC6B5EFC6ADE7BDA5E7B59C
DEAD94DEAD8CD69C7BD69C73C67B5AB56B52945A42734A316B39216B39216B3921845239845231\
9C63399463428C5A4294735AB5846BD69C7BD69C73D69C73D6AD84C68C63AD6B39
844A29A57B5ABD947BD6AD8CE7DED6F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7
F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7
F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7\
F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7AD73529C6339734A316B39218C5A42845239
7B4A297342296B3921522918A58473F7C6B5EFCEBDEFD6C6EFD6C6EFD6C6F7DECEF7DECEEFD6C6\
F7D6BDEFD6C6F7D6BDF7D6BDEFD6C6F7DECEF7DECEEFD6C6EFD6C6F7D6BDF7D6BD
EFD6C6F7C6B5F7C6B5E7B59CDEAD94DEAD94E7BD9CE7BDA5EFC6ADEFC6ADEFCEBDEFCEBDEFCEBD\
EFD6C6EFD6C6F7C6B5F7C6B5F7D6BDF7CEB5EFCEB5EFC6B5EFC6ADEFC6ADE7BDA5
DEAD94DEAD8CD6A584D69C73C68463B56B52945A428C4A315A31215A31216B3921734A31844A31\
9463429C6339946342945A31D69C73D69C73D69C73D69C73D6A584D6AD84AD6B42
AD6B42AD7352B58463DEAD84EFEFE7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7EFF7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7EFF79C73529C7352845239734A31734229845239
844A315A3121734229845239EFC6B5F7CEB5EFCEBDEFD6C6EFD6C6EFD6C6EFD6C6EFD6C6EFD6C6\
EFD6C6F7D6BDEFD6C6EFCEBDEFD6C6EFD6C6EFD6C6EFD6C6F7D6BDF7D6BDEFC6B5
EFD6C6EFD6C6F7D6BDE7BDA5E7AD94DEAD94E7B59CE7BDA5E7BDA5E7C6ADEFC6B5EFCEBDEFCEBD\
EFCEBDEFD6C6EFCEBDF7D6BDEFCEBDEFC6B5EFC6B5EFC6ADEFC6B5E7C6ADE7BDA5
E7BDA5DEAD94D6A584D69C7BCE946BB57B5A9C6B4A8452397342296B31186B39216B3921845239\
945A318C634A845239844A29D6AD8CD69C73C6946BD69C7BC69C84DEAD8C945A31
AD7352AD7352A5846BD6AD84F7EFE7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7EFF7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7EFF7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7EFF7F7F7F7BDADAD945A318C634A8452318C5A428452318C4A31
6B39215A3929734229E7C6ADF7D6BDEFC6B5F7D6BDEFD6C6EFD6C6EFD6C6EFD6C6F7DECEEFD6C6\
EFD6C6F7D6BDEFCEBDEFC6B5EFC6B5EFCEBDEFCEBDF7D6BDF7D6BDF7C6B5F7CEB5
EFD6C6EFD6C6F7D6BDEFC6ADE7AD94DEAD8CDEAD94DEAD9CE7BD9CDEAD9CE7C6B5E7CEBDEFC6B5\
EFD6C6EFCEBDEFCEBDEFCEBDEFC6B5E7C6B5EFC6B5EFC6ADEFC6ADEFC6ADE7BDA5
E7BDA5DEAD9CDEAD8CD6A584DE8473C684639C6B4A945A31734A315229186B39216B3921734A31\
9C6B4A8C5A428C5A428C5A42C69C84C6946BD69C73D69C739C6B4AE7BD94844221
9C6B4ABD8C63C6946BCEAD94F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7EFF7F7F7F7A57B6BB58C739C6B4A734A319C6B4A734A318C4A31
5A3121734A317B4A29E7C6ADF7C6B5E7C6ADEFD6C6EFD6C6F7DECEEFD6C6EFD6C6F7D6BDEFD6C6\
EFCEBDEFCEBDEFB59CE7C6ADEFC6ADEFC6ADEFC6B5EFCEBDF7D6BDEFCEB5F7CEB5
F7D6BDEFD6C6F7D6BDEFC6ADE7A594DEAD8CD6A58CDEAD94DEAD94E7BDA5E7C6B5EFC6B5EFCEBD\
E7C6ADE7C6ADE7BDA5E7C6ADE7C6ADE7C6ADE7C6ADEFC6ADEFC6B5E7C6ADE7C6AD
D6B5A5E7BD9CDEAD8CD6A584D69C73C68463AD7352945A31844A315229185221106B3921734A31\
8C5A429C63398C5A428C5A42C69C84CE946BCE946BD69C73844A31DEAD84945A42
8C5A42B5846BD6A584E7C6ADF7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7EFF7F7EFF7\
F7EFF7F7EFF7F7F7F7F7F7F78C4A29B5947B8C5A42946B52845A428C5A42734A31
5229189C6339E7AD8CEFC6ADE7AD94EFC6B5F7D6BDEFD6C6EFD6C6EFD6C6EFD6C6EFCEBDE7CEBD\
EFC6B5EFC6B5EFC6ADDEAD9CDEAD94E7BDA5E7C6ADEFC6B5EFCEBDE7C6ADEFC6B5
EFD6C6EFD6C6F7D6BDEFB59CDEAD94DE9C7BD6AD8CD6A58CCEAD94D6B5A5E7C6ADE7C6B5E7BDA5\
E7BDA5D6B5A5E7AD9CDEAD8CDEAD8CD6A58CDEAD9CDEAD9CE7BDA5E7BDA5E7BDA5
E7BD9CE7BD9CDEAD94D6A584CE946BC6846BB56B529C6B4A8452397342293918106329106B3921\
8C5A428C5A429C6B4A845239BD947BD69C7BB57B5ABD8C63844A29E7BD949C6B4A
8C4A31C6946BD6AD84E7D6C6F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7EFF7F7F7F7\
F7F7F7F7F7F7F7F7F7FFFFFF9C6B4AA57B638452398C5A42845239945A42522110
845231844A31F7C6B5CE946BDEA584EFCEB5F7D6BDEFD6C6EFD6C6EFD6C6EFCEBDE7C6B5DEAD9C\
BD947BB58C73D6A58CCEA594BD947BDEAD9CDEAD9CEFCEBDEFCEBDEFC6B5EFC6B5
F7D6BDF7D6BDF7D6BDEFC6ADDEAD94D69C7BC69C84D69C7BE7BD9CDEAD9CE7C6B5E7AD9CDEAD9C\
C6A59CBD9C8CB5846BB58C73C69C84C69C84C69C84CEA594E7BD9CE7BDA5DEAD9C
DEAD9CDEAD9CDEAD8CD6A584C69C84C6846BB57B5A945A42845239734A316B39215A31215A3121\
8452398452318C634A8C5A42B5846BBD8C63B57B5AB57B5A945A31E7BD94945A31
8C4A31C69C84D69C73E7D6CEFFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7BD9C94A57B5A9C7352734A31845239734A31945A425A3121
945A31EFB594EFB59CE78C7BD6A58CEFCEB5EFCEBDEFD6C6EFD6C6EFC6B5E7AD9CB58463BD8C63\
DEAD9CBDADAD736B6373736BA58473C69C84DE8473DE8473EFC6B5EFC6B5E7C6AD
F7D6BDF7D6BDF7D6BDEFC6A5E7B59CD69C7BD6A584BD947BD6A5849C4A31C65A4AC6846BD6A58C\
DEC6C6947B73735A4AA57B6BA57B63A57B5AA57B63B5846BD6A58CDEAD94DEAD94
DEAD9CDEAD9CD6A58CD6A58CCE946BC6846BB56B529C6B4A8C5A42734A31845239522918522918\
8452398452398C5A429C6B4AB58463BD947BB5734AB57B5A945229E7BD9C9C6339
9C7352D6AD84D6AD84EFE7E7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7\
F7F7F7F7F7F7F7F7F7B5846BBD9C8C9C73528C634A5A3121845239945A426B3118
522918F7C6B5E7AD8CE7A594DEAD94EFCEBDF7D6BDEFCEBDE7C6ADE7AD9CB5846BC6846BD6BDB5\
E7D6CE7B7373736B63635A52847B73A57B6BC69C84BD947BE7AD9CDEAD94EFC6A5
F7D6BDF7D6BDEFCEB5EFC6ADE7B59CDEA584BD947BB5846BC6846BC69C84AD4231DEC6C6EFE7E7\
8C736394735A7B6B5A948C846B635ABD9C949C73528C6B52B5846BD6A584D6A584
DEAD94DEAD8CD6A58CD69C7BD69C73B5846BAD73529C6B4A845231734A315A3121291008422118\
8452398C5A427342299C6B4AB5846BB584639C6B4AA57B5AAD6342DEAD8C844A29
BD947BD6AD8CD6AD8CF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7FFFFFFF7EFF7A5846B8452317B4A295A3121845239845239845239
945A42F7C6B5DEA584E78C7BDEAD94E7C6B5EFCEB5EFC6ADDEAD9CBD947B94735A5A3929B5948C\
C6B5B5947B6BB5B5BD21181884736B5A4A4294735AB5846BBD947BE7B59CEFCEAD
F7D6BDF7D6BDF7CEB5EFC6ADE7BD9CE7B594BD947BB58C739C7352B58C73BD947B9C6B4ACEC6BD\
635A52B5BDCE21181873736B635A52BD9C94423129735242A57B63B58C73BD947B
D6A584D6A58CD6A584BD947BC6946BC68463AD7352945A42845239844A31422118391810422118\
522918845239734A31AD73529C7352A57B5AA57B5AB57B5AAD6342D6AD84844A29
BD8C63D69C7BDEC6B5F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7B5947BD6C6C6A58C7394735A7B5242734A31845239845239945A42
CE7363EFB59CE78C7BD69C7BDEAD8CEFC6B5EFCEB5E7B59CCEA594C6846B734A31846352846352\
5A42394229215A39298452398C6B52846352A57B63BD947BE7AD94EFBD9CF7CEB5
F7CEB5F7D6BDF7CEB5EFC6ADEFBD9CE7B59CDEA584BD947BC6846BAD735294735AA58C84A58C84\
5A39295229185A39295A3929734A315A4239735A4A7B5242A57B63B58463B5846B
CE946BD69C7BD69C7BBD947BB5846BB57B5A945A428C5A428C5A42734A316B39214221185A3929\
6B39216B3921734A319C6B4AAD73529C6B4A9C6339B57B5AAD7352D6AD84946342
BD8C63D69C73EFE7DEF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7AD7352BD9C94B59C8C8C5A42734A318C634A845239734A318C4A31
C68463E7A594D69C7BD69C7BDEAD8CEFC6B5E7C6B5E7C6ADE7BDA5DEAD94BD947BB56B528C634A\
7B52427B52427B524284523994735AC6846BD6A584E7B59CEFC6ADEFC6ADF7CEB5
F7D6BDF7D6BDF7CEB5EFC6ADEFC6ADEFC6A5E7B594DEA584D69C7BBD947BB5846B84634AA57B63\
A584739C7B6B846352634A425A4239734A319C7352BD8C63B58C73C6846BCE946B
D69C7BD69C7BBD947BCE946BBD8C63B56B52945A428C5A428452398452397342295229185A3929\
5A31215A31217342299C7352B57B5A9C73529C6339B57B5ABD8C63D6AD849C6B4A
BD8C63D6A584EFEFE7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7\
F7F7F7F7F7F7EFE7DEA58C7B946B52734A31734229734A31734A316B39219C6B4A
C68463CE946BC69C84BD947BD6A58CE7C6B5EFCEB5EFCEB5F7D6BDEFCEBDEFC6ADEFC6B5E7BDA5\
E7B59CE7AD9CE7B59CE7BDA5E7B59CD69C7BDEA584E7AD94EFC6A5F7D6BDF7CEB5
EFD6C6EFD6C6F7D6BDF7CEB5EFCEADEFC6ADE7B594D69C73DE9C7BBD947BD6A584D6A58CD6A584\
BD947BBD947BBD947BCE946BD69C7BD6A584D6A584DEAD8CE7AD8CDEAD94D6A58C
D6A584D69C7BCE946BC6846BBD8C63B57B5A945A428C634A8452396B39216B39215229185A3929\
734A317342296B39219C6B4ABD8C639C6B4A9C6339C6845ABD947BDEAD949C7352
BD947BEFDECEFFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7
F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7\
F7F7F7FFFFFFFFFFFF7342298C5A425A31216B39216B39219463425A31219C4A31
B56B52DE8473CE946BB58C73D6A584EFCEB5E7BDA5F7CEB5F7D6BDF7D6BDEFD6C6F7D6BDF7D6BD\
EFD6C6E7A594C6846BA57B639C7352B56B52E7B59CEFC6A5F7D6BDF7D6BDF7D6BD
F7DECEEFD6C6F7D6BDEFD6C6F7CEB5F7D6BDEFBD9CE7AD94C6846BAD63429C7352B56B52B58C73\
E7BDA5E7C6ADEFC6ADE7C6ADE7BDA5E7BDA5E7B59CE7B59CE7B59CDEAD94D6A584
C6946BB58463CE946BBD8C63B57B5AAD73529C6B4A8C5A42845231845239632910522918522918\
5A3929522110734A318C5A42AD73529C6B4A946342C68C63C6946BE7BD9CA57B5A
C69C84EFE7E7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7EFE7E7FFFFFF6B39217B4A295A31216B3921734A31845239734A319C6339
B56342B57B5ABD8C63C6846BC69C84EFC6ADDEC6B5E7BD9CEFC6B5F7D6BDEFD6C6EFD6C6F7C6B5\
B5846BA57B6394735AB56B52D6A584EFC6A5F7CEB5F7CEB5F7D6BDF7DECEF7D6BD
F7DECEEFD6C6F7D6BDF7D6BDF7D6BDF7CEB5F7CEB5EFC6A5E7AD94BD8C63945A42845239945A42\
B56B52DEA584E7AD9CE7C6ADEFC6ADEFC6ADEFB59CE7BDA5DEAD94DEA584BD947B
A57B5ACE946BB58C73B5846BAD73529C6B4A9C6B4A8C5A426B39216B39215229185A3121522918\
522110735242845A42946B52A57B5A9C7352945A31BD8C63BD8C63D6AD8CBD947B
C69C84F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7\
FFFFFFBDADADFFFFFF845231734229734A31734A315A31218452397B4A29945A31
945A42945A42A57B63B5846BC69C84E7C6B5EFCEBDBD947BC69C84D6A584D69C7BDE8473B56B52\
AD7352D69C7BF7CEB5F7D6BDF7D6BDF7DECEF7DECEF7DECEF7DECEF7DECEF7DECE
EFD6C6EFD6C6EFD6C6EFD6C6F7D6BDEFD6C6F7CEB5F7CEB5F7CEB5EFCEADE7B59CD6A584B58C73\
94735A8C5A429C7352AD6342CE6B5AB58C73C6846BB58463A57B63A57B5AB5846B
BD947BBD947BDE8473BD8C63AD73529C6B4A9C6B4A8452399C6B4A4221187342297342296B3921\
52291842292184634A9C6B4AAD73529C6B4A946342BD8C63D69C73B5846BAD6B42
DECEBDF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7\
F7F7F7C6A5949C7352734A31734A3184634A845239734A31734A31734A31845239
945A318C634A9C7352A57B5AD6A584E7C6B5EFCEB5EFCEB5EFC6ADD6A584BD9C8CDE8473DEAD9C\
EFD6C6F7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DED6
EFD6C6EFD6C6F7DECEF7DECEF7DECEF7D6BDF7D6BDEFD6C6F7D6BDF7CEB5F7C6B5EFC6ADEFC6AD\
EFC6ADE7C6ADE7C6ADC69C84A57B63AD7352A57B63A57B63BD947BC69C84BD947B
CE946BD69C73CE946BBD8C63AD73529C7352AD73528452396B3921734A316B39215A3121391810\
3918104221188C634A94735A8C5A42A57B5AAD6342C6946BC69C849C6B4ABD8C63
EFE7E7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7D6C6C69C6B4A7B5A42734A319C7B6B8C6B527B5A42845239734A318C5A42
8C5A428C634AAD7352AD7352D69C7BEFC6ADEFC6B5EFCEB5EFCEB5F7D6BDF7D6BDEFD6C6EFD6C6\
EFD6C6F7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DED6F7DECEF7DECE
EFD6C6F7DECEF7DECEF7DECEEFD6C6EFD6C6EFD6C6EFD6C6EFD6C6F7D6BDEFCEB5EFCEB5F7CEB5\
EFC6ADEFC6ADEFC6ADE7BDA5E7C6ADE7C6ADE7B59CDEAD94DEAD8CD6A58CD69C7B
D6A584BD947BB58C73B57B5AAD7352A57B5AAD73529C6B4A734A316B3921522110391810391810\
391810422118B58C738C634A8C5A42D69C739C6B4AB57B5AD6AD849C6B4AC69C84
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7CEB5A5844A29735242845A42A58C73946B52845239845A427B5A42845A42
845A428C5A42A57B5A9C7352D69C7BE7C6ADEFCEB5EFCEB5EFCEBDF7D6BDF7D6BDEFD6C6F7DECE\
F7DECEEFD6C6F7D6BDF7DECEF7DECEF7DECEF7D6BDF7DECEF7DECEF7DECEF7DECE
F7D6BDEFD6C6F7DECEEFD6C6EFD6C6F7DECEEFD6C6F7D6BDF7D6BDF7D6BDF7D6BDF7C6B5F7CEB5\
EFC6B5EFC6ADE7C6ADE7BDA5EFC6ADE7B59CE7B59CDEAD94D6A584D6A584D69C7B
D69C7BBD947BC6946BBD8C63B56B52AD7352AD73528C5A429C6B4A734229522918522918422118\
5A3121522110BD947BA57B5A8C5A42BD947BAD73529C6B4AD6AD8C9C6B4AD6BDAD
FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7DECEC68452398C6B528C634A9C73528C634A8C6B528C634A845A42845239
8452318452319C6B4A9C7352C6846BE7BD9CEFC6B5EFCEB5EFCEB5EFCEBDF7D6BDF7D6BDEFD6C6\
F7DECEF7DECEF7D6BDF7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECE
F7DECEF7DECEF7DECEF7DECEF7DECEEFD6C6EFD6C6EFD6C6F7CEB5F7CEB5F7CEB5F7CEB5F7CEB5\
EFC6ADEFC6A5E7C6ADEFC6ADE7BDA5E7BD9CE7B594DEAD94DEAD8CD6A58CD6A584
D69C7BD69C73CE946BB57B5AAD7352B57B5A9C73529C6B4A734A315A31216B39215A3121391810\
391810422118C6946BA57B639C6B4AD69C73B5734A8C634ABD947B9C6B4AF7EFF7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7EFF78C634A84523984523984523984634A8C634A845239845A42845239
845A42845239A57B5AB57B5AC6946BE7B59CE7BDA5EFCEADEFCEBDF7CEB5F7D6BDF7D6BDEFD6C6\
EFD6C6F7DECEF7DECEF7DECEF7DECEF7DECEF7D6BDF7D6BDF7DECEF7DECEF7DECE
F7DECEF7DECEEFD6C6EFD6C6EFD6C6EFD6C6EFD6C6F7C6B5F7CEB5F7CEB5F7CEB5EFCEADEFC6AD\
EFC6ADEFC6ADEFB59CE7BDA5E7BD9CE7BDA5E7B59CDEAD8CDEAD94DEA584D6A584
BD947BCE946BC6846BBD8C63B57B5AAD73529C6B4A845239734A315A3929734229422118391810\
3918105A31219C7352D69C73B58463D69C7BB57B5A9C7352946342CEAD94F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7FFFFFF7B52428C6B528452398C634A8C6B52946B528C634A845A42845A42
8452398C634A9C7352BD8C63BD947BDEAD8CE7BDA5EFCEB5EFCEBDF7D6BDF7D6BDF7D6BDF7D6BD\
F7DECEF7DECEF7D6BDF7D6BDF7DECEF7DECEF7D6BDF7DECEF7DECEEFD6C6F7DECE
F7DECEF7DECEEFD6C6EFD6C6EFD6C6F7D6BDF7D6BDF7D6BDF7D6BDF7CEB5F7CEB5EFCEADEFC6AD\
EFC6ADEFC6ADEFB59CE7B59CE7B59CE7B59CE7B59CE7AD94DEAD8CD6A58CD6A584
D69C7BCE946BB58C73B58463B58463A57B639C6B4A8C5A426B3921734A31522110422118422118\
39181042292194735ABD947B9C7352C6946BBD8C63A5846B946342E7CEC6F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7FFFFFF9C7B6B7352428C5A42946B52946B52845A428C634A8452397B5A42
946B528C634A9C7352B5846BC6946BD6A58CE7BDA5EFC6ADF7CEB5F7CEB5F7CEB5F7D6BDF7D6BD\
F7D6BDF7DECEF7DECEEFD6C6F7D6BDF7DECEF7DECEEFD6C6F7D6BDF7DECEF7D6BD
EFD6C6EFD6C6F7D6BDEFD6C6F7D6BDF7D6BDF7D6BDF7CEB5F7D6BDF7CEB5F7CEB5EFC6ADF7CEB5\
EFC6ADEFC6A5EFC6A5E7BDA5E7BD9CE7BDA5E7B594DEAD94DEAD8CD6A58CD6A584
BD947BCE946BC6846BB58463B584639C6B4A9C6B4A8C5A42734A316B3921522110391810291008\
2910087B52428C634AA57B5AAD7352C69C84C6946BD6AD8CC6946BF7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7FFFFFF845239A57B63A57B5A8C5A428C634A84634A8C5A42845A429C6339
7342298C634AA57B63BD8C63B58C73D6A584E7BD9CEFC6ADEFCEB5F7CEB5F7D6BDF7D6BDF7D6BD\
F7DECEF7DECEEFD6C6F7DECEF7DECEF7DECEF7D6BDF7DECEF7D6BDEFD6C6F7DECE
F7D6BDEFD6C6EFD6C6F7D6BDEFD6C6EFD6C6F7D6BDF7D6BDF7D6BDF7D6BDEFC6ADF7C6B5EFCEAD\
EFC6ADEFC6ADEFB59CEFC6A5E7B59CE7B59CDEAD94DEAD94DEAD8CD6A58CD6A584
BD947BD69C73B58C73B5846B9C7352946B52845A42734A318452395A3121391810291008422921\
29100884634A946B529C6B4A946342C6946BC6946BC69C84E7DED6F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7EFF7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7E7DEDEA57B637B5A427B5A42845239845239845231845A42845239
8C634A8C634AA57B5AB58C73C69C84D6A58CE7BD9CEFC6ADEFCEB5F7D6BDF7D6BDEFD6C6F7D6BD\
F7DECEF7DECEF7D6BDF7DECEF7D6BDF7DECEF7D6BDEFD6C6F7D6BDF7DECEF7D6BD
EFD6C6EFD6C6F7D6BDF7D6BDF7D6BDF7D6BDEFD6C6F7D6BDF7D6BDF7C6B5F7CEB5F7CEB5EFC6AD\
EFC6ADEFC6ADEFB59CEFC6A5E7B59CE7B59CDEAD94DEAD8CDEAD8CDEAD8CD6A584
C69C84D69C7BB5846BA57B639C73529C73529C6B4A7B5A426B39215A3121391810391810422921\
391810946B52946B529C73529C6339C6946BC69C84D6A58CF7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7FFFFFF8C634A7B5A42845239734A31845231735242734A317B5A42
8C634A9C6B4AB58463B58C73D69C7BD6AD8CE7BD9CEFC6ADF7CEB5F7C6B5F7D6BDEFD6C6F7D6BD\
F7D6BDF7D6BDF7D6BDEFD6C6F7DECEF7DECEF7DECEF7DECEEFD6C6EFD6C6F7DECE
F7D6BDF7D6BDF7D6BDF7D6BDF7D6BDF7D6BDF7D6BDF7D6BDF7C6B5F7CEB5F7CEB5F7CEB5EFC6AD\
F7CEB5EFC6ADEFC6A5EFC6A5EFBD9CE7B59CDEAD94DEAD8CD6A58CDEAD8CD6A584
D6A584BD947BB5846BB5846BA57B638C634A8C5A426B39215A3121422118422118291008392118\
3918109C7B63946B529C6339946342C69C84CEB5A5DECEC6F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7CEB5B584634A845239845239845231845239845239735242
8452399C6B4AA57B63B58C73C69C84DEAD9CE7BDA5EFC6ADF7CEB5F7CEB5F7D6BDEFD6C6EFD6C6\
F7DECEEFD6C6F7DECEF7DECEF7DECEF7DECEF7DECEEFD6C6F7DECEF7D6BDEFD6C6
F7DECEEFD6C6F7D6BDEFD6C6F7D6BDF7D6BDF7D6BDF7D6BDF7CEB5F7D6BDF7CEB5F7C6B5EFCEAD\
EFC6ADEFC6ADEFC6A5EFC6A5E7B59CE7B59CDEAD9CDEAD8CDEAD8CD6A584D6A58C
CE946BCE946BBD8C63A57B63A57B5A9C73528C5A425A39295A3121422118422921311818422118\
422118A57B63B5846B8C5A42AD7352C6946BE7BD9CF7F7F7F7F7F7F7EFF7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7EFF78C6B52734A31734A317352427352428452397B5A42
735242946B52B58463BD947BD6A584DEAD94EFC6A5EFC6ADEFC6B5EFCEB5F7CEB5F7D6BDF7D6BD\
F7D6BDF7D6BDF7D6BDF7DECEF7D6BDF7DECEEFD6C6F7D6BDF7D6BDEFD6C6F7D6BD
EFD6C6EFD6C6F7D6BDF7D6BDF7D6BDEFD6C6F7D6BDF7D6BDF7CEB5F7CEB5EFCEADF7CEB5F7C6B5\
EFC6ADEFC6ADEFC6ADE7BDA5E7BDA5E7BD9CE7B594DEAD8CDEAD8CD6A58CD69C7B
D69C7BB58C73BD8C63A57B639C73528C634A8452395A39295A3121422921422118522918522918\
3918109C6B4AB584639C6B4AC6845AD6A584DECECEF7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7A57B638C6B52735242845A427B5A427352427B5A42
845A42946B529C7352C6946BD6AD8CE7BDA5E7BDA5EFC6ADF7CEB5F7CEB5F7D6BDF7D6BDF7D6BD\
EFD6C6EFD6C6F7DECEF7DECEEFD6C6F7D6BDF7D6BDEFD6C6EFD6C6EFD6C6EFD6C6
F7D6BDF7D6BDEFD6C6F7D6BDF7D6BDF7D6BDF7D6BDF7CEB5F7CEB5F7CEB5EFCEADEFCEADEFC6AD\
EFC6A5EFC6A5EFC6ADE7BDA5E7BD9CE7B594E7AD94DEAD8CDEAD8CDEA584DEA584
CE946BB58C73B5846BAD73529C6B4A8C5A42734A315A39295A3929522918422118522918391810\
291008946B529C73529C6B4ABD8C63DEAD8CEFEFE7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFCEB5B5A57B63946B52946B52946B527B5A42
7B5A42946B52A5846BB58C73D69C7BE7B59CEFC6A5EFC6ADEFC6ADF7CEB5EFCEB5F7CEB5EFD6C6\
EFD6C6EFD6C6EFD6C6F7D6BDF7D6BDEFD6C6F7DECEF7D6BDEFD6C6F7D6BDF7D6BD
F7D6BDF7D6BDF7CEB5F7D6BDF7CEB5F7CEB5F7CEB5F7CEB5F7D6BDF7C6B5F7CEB5EFC6A5EFC6A5\
EFC6A5EFC6A5EFB59CE7BDA5E7BD9CE7B594DEAD94E7B594D6A584D6A584D6A584
B58C73B58C73A57B63A57B5A8C634A845239734229734A315A31215A3121422118391810211008\
5A3929B5846B9C7352B5734ACE946BCEAD94F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFFFFFFFEFE7E794735A946B52845A428C634A
84634A8C634AAD7352BD947BC69C84DEAD94EFC6A5EFC6ADEFC6ADF7CEB5F7CEB5F7D6BDF7D6BD\
F7CEB5EFD6C6EFD6C6F7D6BDF7D6BDF7D6BDF7D6BDF7D6BDF7D6BDEFD6C6F7D6BD
F7D6BDF7D6BDF7D6BDF7D6BDF7CEB5F7CEB5F7CEB5F7D6BDF7CEB5EFC6ADEFC6ADEFC6ADEFC6AD\
EFC6A5EFC6ADEFBD9CE7B59CE7B59CE7B59CE7B594DEAD8CD69C7BD6A58CBD947B
BD947BBD8C63AD7352945A42845239845A427342295A39295A3929422921522918211818211008\
A57B5AA57B63946342B57B5AC68C63E7CEBDF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFBD9C9484523984634A735242
8C634A8C634AA57B5ABD8C63D69C7BDEAD9CE7BDA5EFB59CEFC6ADEFC6ADF7CEB5EFCEADEFCEAD\
F7CEB5F7CEB5F7D6BDF7D6BDF7D6BDF7CEB5F7D6BDF7D6BDF7D6BDF7CEB5F7D6BD
EFCEB5F7CEB5EFCEBDF7CEB5F7CEB5F7CEB5EFCEADEFC6ADEFC6ADEFC6ADEFC6ADEFC6A5EFC6AD\
EFC6A5EFC6A5EFB59CE7B59CE7B59CE7B59CDEAD94DEAD94D6A58CD69C7BD6A584
B58C73A57B639C6B4A9463428C5A42845A42845A425A31215A3121522918391810291008B5846B\
9C7B639C6B4A946342BD8C63D6B5A5EFE7E7F7F7F7F7EFF7F7EFF7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFDECEBD6B3921845A42A57B5A
7B5A42A57B5AA57B5ABD8C63C69C84DEAD94E7BD9CE7C6ADEFC6ADEFC6A5EFC6ADF7CEB5F7CEB5\
F7D6BDF7CEB5EFCEBDF7D6BDF7CEB5F7D6BDF7D6BDF7D6BDF7D6BDF7D6BDF7CEB5
F7CEB5F7D6BDF7CEB5EFC6ADF7CEB5EFC6ADF7CEB5EFC6ADEFC6ADEFC6A5EFC6ADEFC6ADEFC6A5\
EFC6A5E7BD9CEFBD9CE7B594E7B594DEAD9CDEAD8CCEAD94BD947BD69C7BCE946B
B5846BA57B639C73529C6B4A845A42734A31735242946B524221183918103921187B5A42845239\
A57B5A9C6B4AAD7352C6946BE7BDA5F7EFF7F7F7F7F7EFF7FFFFFFF7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFCEB5A59C7352845239845239
84634AA57B63A57B5ABD8C63D69C7BDEAD94DEAD9CE7BDA5EFC6ADEFC6A5EFC6ADF7C6B5EFC6AD\
F7D6BDEFCEADF7CEB5F7CEB5F7CEB5F7CEB5F7CEB5F7CEB5F7CEB5F7D6BDF7C6B5
F7C6B5EFC6ADEFC6ADEFC6ADEFB59CEFC6ADEFC6A5EFC6A5EFC6A5EFC6A5EFC6A5EFC6ADEFC6A5\
EFC6A5E7B594E7B594E7B59CDEAD94DEAD94DEAD8CD6A584BD947BBD947BB5846B
AD73529C7352946342845A42845A428452398452395A3929734A315A3929734A31734229A57B63\
9C7352B58463BD8C63D6AD8CD6BDADF7F7F7FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFC6A594C69C84734229845231
7B5A428C5A429C7352B58463BD947BC69C84D6B5A5E7B59CE7BDA5EFC6A5EFB59CF7C6B5F7C6B5\
EFCEB5EFCEB5EFC6B5EFC6ADF7C6B5F7CEB5F7CEB5F7D6BDEFC6B5EFCEB5EFC6AD
EFC6ADEFC6A5EFB59CE7B59CE7B59CEFB594EFC6A5EFC6A5EFBD9CEFB59CEFBD9CEFB594E7B59C\
E7B59CDEAD8CE7AD94DEAD94D6A58CD6A58CD69C7BBD947BBD947BB58C73B5846B
AD7352A57B5A9C6B4A735242735242734A31734A315A42397342295A3121A5846B946B529C7352\
9C6B4AD69C7BC6946BE7BD9CF7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7FFFFFF
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E7DEDEDEC6C65A3121734229
9C6B4A8452399C7352A5846BB58C73D6A58CDEAD94DEAD9CE7B59CEFB59CEFB59CEFC6A5EFC6AD\
E7C6ADEFC6ADEFCEB5EFC6ADEFC6ADEFC6ADEFC6B5EFC6ADEFC6A5EFC6ADEFC6AD
EFBD9CE7B59CE7AD8CE7AD94E7AD94E7B594EFB594E7AD8CE7AD8CE7AD8CE7AD8CDEA584DEAD8C\
E7AD94D6A584DEAD8CD6A584D6A584C69C84D69C73BD947BB5846BB58463B58463
A57B5A9C73528C5A42845A427B5A427352428C6B527B5A42734A318C6B52B5846B94735AA57B63\
BD8C63D6A584E7BD9CD6BDADF7EFF7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7C6A5949C7B6B7B5A42
845A42946B528C634A9C7352A57B63BD947BD6A58CE7BD9CDEAD9CD6B5A5E7B59CE7B59CEFC6AD\
EFC6ADEFC6ADEFC6ADE7C6ADE7BDA5E7BDA5E7BDA5E7BDA5E7B59CDEAD9CDEAD8C
DEAD94DEAD94D6A584D6A584D69C7BD69C7BD69C7BD69C73DE9C7BD69C7BD69C73D69C73BD947B\
CE946BCE946BCE946BCE946BC6846BB58C73BD947BB58C73B5846BB57B5A9C6B4A
8C634A94735A946B52735A4A946B52946B52734A318C634A9C6B4A9C6B4A9C73529C6B4ABD8C63\
B58463DEAD94E7BD9CF7EFE7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7BDADAD94735A
845A428C634A946B52A57B5AB5846BA57B6BB58C73BD947BDEAD94D6B5A5E7BDA5EFC6A5E7C6AD\
E7BDA5E7BDA5E7BDA5E7BD9CDEAD94DEAD94D6A584DEAD94E7BD9CD6A58CDEA584
D6A584D6A58CBD947BC69C84C6846BCE946BBD8C63D69C7BCE7363CE946BB57B5AB58C73B57B5A\
B57B5ABD8C63B58463B58463B5846BB5846BA57B63B58C73BD947BA5846BA58C73
A57B5AA57B638C634A8C634A94735AA57B63845A426B3921845239B57B5AB58463B57B5ABD8C63\
CEAD94D6B5A5D6BDADF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFE7E7
A58C7B94735A7B5A429C7352A57B5A8C634AB58C73C69C84D6BDADE7C6B5E7C6B5E7C6B5E7BDA5\
E7BDA5D6B5A5DEAD9CD6A584CEAD94D6A58CD6A58CD6A584D6A58CD6A584D6A584
C6946BC6946BB58C73B58C73B5846BB58C73B5846BAD7352B5846BB584639C73529C6B4AB5846B\
9C7352B584639C7352AD7352A57B63A57B5AA57B638C634A946B5294735AAD7352
94735A9C735294735A9C7352845239845A428C6B529C6B4A9C7352A57B5AA57B5AC6946BD6B5A5\
D6B5A5C69C84F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
A58C7BA57B6BA57B639C7363A58C73C6A594CEA594BD9C8CDEAD9CCEA594DEAD9CD6BDADD6BDAD\
DEAD9CDEAD94D6A58CD6A584D6A58CBD947BC69C84D6A584C69C84C6946BC69C84
BD947BC6846BB58463B5846B9C7352BD947BA57B63BD947BB58463A57B63BD8C63A57B5A9C6B4A\
BD947BA57B5AB5846BA57B63A57B5AA5846BA58C7384634A946B52A57B5A9C7B63
8C6B5294735AA57B639463429C6B4A9463429C6B4A9463429C7352B58463D6AD84CEB5A5CEAD94\
D6AD8CE7CEC6F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
FFFFFF94735AA584739C7363946B52A5846BB58C73B58C73BD9C8CDEAD9CD6B5A5DEAD94CEAD94\
D6A58CD6AD8CC69C84C69C84C69C84B58C73BD947BB58C73BD947BB58C73BD947B
B5846BBD947BA57B5A9C7352A57B6B946342A5846BA57B5AB58C739C7352A57B63A57B5AA57B63\
C6946B8C634A9C73529C7352B5846BA57B5A946B52946B52845A427B5A42734A31
7352428C634A8452398452397B5A427B5A42946342B5734AC6946BD6AD84E7C6ADBD9C8CD6AD8C\
B58463F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7FFFFFFB5947BA57B6BA57B63BD9C94C69C84C6A594D6B5A5D6B5A5D6B5A5D6B5A5C69C84\
C69C84C69C84C69C84BD947BC69C84BD947BBD947BB5846BB5846BBD947BB58463
A57B5AA57B63946342A5846BA5846B8C634A734A31A57B63845A42B58463A57B5AA57B63A57B63\
8C5A429C6B4AA57B5A734229734A319C63398C5A42845A428C5A429C6339946342
9C6B4A9463429463428452399C63399C6B4ACEAD94BD947BD6AD8CD6BDAD8C634ABD9C8CA5846B\
DECECEFFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7C6A59CA5847384634A9C73639C6B4AA5846BC6A59CCEB5A5DEAD9CD6B5A5C6A594\
BD947BBD947BB58C73BD947BBD947BB58C73A5846BA58C73B58C73A57B63B58463
B584638C634AC6946BA57B5A8C634ABD947B8C634A845A42A57B638C634A8C634A946B52845A42\
8C5A428452317342298452398452399C63398452397B5A429463428C5A42845239
844A318C5A429C7352B58463B58463C69C84BD947BE7BD9CD6B5A5A5846BA57B5ABD9C8CA5846B\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7\
F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7FFFFFF735A4A9C7B6BBD9C8CA57B6BA5846BB5947BC6AD9CCEB5A5D6A58CC6A594\
A57B63B5846BA5846BBD947BBD947BB5846B9C7363B5846BB58463A57B63B58C73
A57B63B58463845A429C735294735A8C634AA57B5A845A428C634A946342845A4284634A845A42\
735242845239845239845239734A317342298452397B5A42845239845231845231
8C634AA57B5AA57B5AA57B5AA57B5AC69C84CEB5A59C7B639C7B63A5846BC6A594BD947BEFE7E7\
F7EFF7F7EFF7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7FFFFFF
F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F79C7B6B734A31B5947BB59C8CBD9C8CB5947BD6B5A5D6B5A5C6AD9C\
A57B5AB58C73A57B63A57B63B58463A57B5A94735AA5846BA5846B94735AA57B63
94735AA57B63845A42A57B5A9C6B4A946B52735242734A31A57B5A7352427B5A42845A427B5A42\
845231734A31734A316B39215A39297342297342297342298452319C6B4A845A42
8C634AA5846BC69C84BD947BE7BDA5CEB5A5BD9C8CA58C73946B52C69C84946B52EFE7E7FFFFFF\
FFFFFFF7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7EFF7F7F7F7FFFFFFA57B6B734229947363A58473B5947BCEB5A5D6BDADC6AD9C\
A57B5A946B52B5947BA57B63B58C73B5947BB58463946B52A5846BA57B5A8C634A
A57B63A57B638C634A9C7352A57B5A94735A8C6B525A3121734A317B5A42A57B5A845239845239\
6B39218452397342296B39215A31215A39295A31215A3121734A318C5A42A5846B
BD947BB5846BBD947BCEB5A5B5947B84634A947B6BB58463A5846B9C6B4AC6A59CF7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7DECECE7B6B5A7B5A4284634AA58C73BD9C8CC6AD9CD6B5A5\
A5846B946B52A57B5AB58C7394735A94735AA57B638C6B528C634A9C736394735A
8C6B52946B52A57B6394735A8C634AA57B5A9C73528C6B528C634A734A31734A3184634A845239\
8452398C5A428452319C6B4A845231845231945A319C6B4AAD7352A57B63BD8C63
C69C84DEC6B5B5947BBD9C8C9C7B6B734A3194735AA5846BB5947BB5947BF7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7D6BDB5947B6B8C735A84635284634AA58473A58C84\
D6B5A58C634A8C6B529C7B63B5846394735A946B52845A427B5A427B5A428C634A
8C634A946B5294735A8C634A8C634AA57B5AA5846B9C735294735A7B5A42A57B5A845239845231\
94735A946B528C634A9463429C6B4AA57B5AB58463C69C84B58C73BD947BD6B5A5
BD9C8CB59C8CA58C73A58C737B5A429C7363A58C73A5846BA57B6BFFFFFFF7F7F7FFFFFFFFFFFF\
F7F7F7F7EFF7FFFFFFF7EFF7FFFFFFF7F7F7F7EFF7F7F7F7FFFFFFF7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7BDADAD94735A9473639C7363A5846BA58C7B\
C69C84C6A5948C6B528C6B52A5846BA5846B946B52A5846B845239845A42845A42
9C6B4A946B529C7352845239A57B6B9C7352B58C73A57B63B5846BB5947B946B528C5A428C5A42\
9C73529C7352B58463B58463BD8C63BD8C63D6A584D6A584C6A594A57B639C7B6B
9C7B6B8C5A42734229845239A57B63A5846B9C7B63BD947BFFFFFFF7F7F7F7F7F7F7F7F7FFFFFF\
FFFFFFF7F7F7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7CEB5B5846352947363A58C73B5947B\
BD9C8CC6A594C6AD9C94735AA5846B8C634AA5847394735AA57B63946B52845239
7B5242734A318C634A7B5A429C73639C7352BD947BB58C73DEC6B5E7C6B5D6B5A5C69C84DEAD9C\
D6A58CD6A58CD6A58CE7C6ADE7C6ADDEAD94CEB5A5A58C738C6B529C7B63946B52
845A427B5A428C634AB58463B5947BA57B63A57B6BFFFFFFF7F7F7F7F7F7FFFFFFF7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7FFFFFFFFFFFFF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7EFEFF79C847B947363736352\
A58C73CEB5A5CEB5A5CEAD94A58473B58C73A58473A58C7BA57B6BBD947BC6A594
9C7B6B7B52428C6B527B524294735AB5947BC6A594BD9C8CA58C7BD6BDADD6BDB5D6BDADDEC6B5\
E7D6C6E7CEC6D6BDADC69C84B5947BB5947BA5847394736394735A946B52735242
84523994735A9C7B63BD947BA57B63B5947BF7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7EFF7\
F7EFF7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7FFFFFF9C7B6B846352\
9C8473A58C7BC6AD9CDEC6C6C6AD9CC6AD9CD6BDB5BDADADDECEBDD6BDB5C6A59C
E7CEC6EFD6C6F7EFE7EFE7DEEFD6C6E7CEC6E7CEBDD6BDADDECEBDDEC6B5DEC6B5DEC6B5E7CEBD\
CEB5A5A58C73C6A594A58C739C7B639C7B6B9C7B6B8C634A8C6B52735A4AA57B63
A58C73A5846BA5846BA57B63FFFFFFF7F7F7F7F7F7FFFFFFF7EFF7F7F7F7F7F7F7F7F7F7F7F7F7\
F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7
F7EFF7F7F7F7F7F7F7F7EFF7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E7DEDE\
8463528C7363B5947BBDA59CD6BDB5DECEBDE7D6CEDECEC6DECEBDDECEBDDECEBD
E7D6CEDEC6B5E7C6B5E7CEBDE7C6B5EFD6C6EFDECEE7D6CEDECEBDE7CEC6CEB5A5BD9C94D6BDAD\
BD9C8CB59C8CBD9C948C735AA57B5A8C634A8C6B529C7B6BA58473BD9C8CC69C84
B58C73A5846BC6A59CF7F7F7F7F7F7F7EFF7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7FFFFFFF7F7F7F7F7F7FFFFFFF7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7FFFFFFFFFFFFF7F7F7FFFFFFF7F7F7F7F7F7FFFFFF\
EFE7E7A584739C8473A58C84CEB5A5CEB5A5D6BDB5D6C6B5DECEBDE7D6CEE7D6CE
E7D6CEE7D6CEEFE7DEE7DED6E7D6D6E7D6CEEFDECEE7CEC6DECEBDD6BDB5CEC6BDB59C8CA58C84\
BD9C949C7B639C7B6B94735AA58C73846352A58C7BBD9C8CC69C84B59C8CA58C7B
C69C84E7DEDEF7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7FFFFFFF7F7F7\
F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7\
FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7\
FFFFFFF7F7F7F7F7F7B5948C9C7B6BA58473CEB5B5DEC6C6E7D6CEE7D6CEE7D6C6
E7CEC6DEC6C6E7D6D6DECEC6DEC6C6D6BDB5C6AD9CBD9C8CB5947BC6A594C6AD9CB59C8CA58C7B\
846B52A57B6BB59C8CA58C7BC6AD9CC6AD9CCEB5A5C6AD9CA58C84C6AD9CF7EFF7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7\
F7F7F7FFFFFFF7F7F7FFFFFFF7F7F7F7F7F7F7F7F7F7EFF7F7F7F7FFFFFFF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7FFFFFFFFFFFFFFFFFFF7EFF7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7FFFFFFF7F7F7F7F7F7\
FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7BD9C94B5948CC6B5B5CEB5B5D6BDB5
E7D6D6E7D6D6E7D6CEE7D6D6E7D6D6E7D6CED6BDB5D6BDB5C6A59CBDA59CB5948CCEB5A5DECEBD\
BD9C94D6BDB5DEC6C6D6BDB5BD9C94B5947BD6BDADEFE7E7FFFFFFFFFFFFFFFFFF
F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
FFFFFFF7F7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFF\
F7F7F7F7F7F7F7F7F7FFFFFFFFFFFFF7F7F7FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7FFFFFFF7F7F7F7F7F7BDADADBDA59CD6BDB5
C6A59CD6BDADDECEC6DECEC6E7DED6E7D6D6EFE7DEF7EFE7EFE7DEE7D6CEDECEBDE7D6CEDECEC6\
DECEBDC6A59CBD9C8CCEB5A5DECEBDEFE7E7F7F7F7F7F7F7FFFFFFFFFFFFF7EFF7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7\
F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7FFFFFFF7EFF7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7EFF7F7F7F7F7F7F7FFFFFFF7EFF7F7EFF7F7F7F7F7F7F7F7F7F7F7EFF7F7EFF7
F7EFF7EFE7E7EFE7E7E7DEDEF7EFE7EFE7DEDECEBDD6BDB5D6BDB5DECEBDDECEC6DEC6C6DEC6C6\
DECECEEFE7E7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFFFFFFFF7F7F7
FFFFFFFFFFFFFFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7EFF7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7FFFFFFF7EFF7F7F7F7F7F7F7F7F7F7FFFFFF
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7FFFFFFF7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7EFF7F7F7F7F7F7F7F7F7F7\
F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7EFF7F7EFF7F7EFF7FFFFFFF7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFFFFFFFF7F7F7F7F7F7F7F7F7FFFFFFF7F7F7
F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7FFFFFFF7F7F7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7FFFFFF\
F7F7F7FFFFFFF7F7F7FFFFFFF7F7F7F7EFF7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7FFFFFF\
F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7EFF7F7F7F7F7F7F7F7EFF7FFFFFFF7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7EFF7
F7F7F7F7F7F7FFFFFFF7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7\
F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7FFFFFFF7F7F7
F7F7F7F7F7F7F7EFF7FFFFFFF7F7F7FFFFFFFFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7FFFFFFF7EFF7F7EFF7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFF\
F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7FFFFFFFFFFFFF7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7F7EFF7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7FFFFFFFFFFFFF7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7FFFFFF
F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7FFFFFFF7F7F7F7F7F7FFFFFFFFFFFF
F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7EFF7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7\
FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFF
F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7FFFFFFF7F7F7F7F7F7F7EFF7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7EFF7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7FFFFFF\
F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7FFFFFFF7EFF7
F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7FFFFFFF7F7F7F7EFF7F7F7F7F7F7F7F7EFF7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFF
F7F7F7F7F7F7F7EFF7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7F7EFF7FFFFFFFFFFFFF7F7F7F7F7F7\
F7EFF7FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7FFFFFF
F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7FFFFFFF7F7F7F7F7F7FFFFFFFFFFFFF7F7F7F7F7F7\
FFFFFFF7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7
F7F7F7FFFFFFF7EFF7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7FFFFFFF7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7FFFFFFF7EFF7FFFFFFF7F7F7F7F7F7FFFFFF
F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7EFF7FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7EFF7F7F7F7
F7F7F7F7F7F7F7F7F7F7EFF7FFFFFFFFFFFFF7F7F7F7F7F7FFFFFFF7EFF7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7FFFFFFF7F7F7F7EFF7F7EFF7F7F7F7F7F7F7FFFFFFF7EFF7F7F7F7
FFFFFFF7F7F7FFFFFFF7F7F7F7F7F7FFFFFFF7F7F7FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7FFFFFFF7F7F7F7F7F7
F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7FFFFFFF7F7F7FFFFFFF7F7F7F7F7F7FFFFFFF7EFF7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7EFF7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7\
F7F7F7F7EFF7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFF
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7FFFFFFF7F7F7
FFFFFFF7F7F7F7F7F7F7F7F7F7EFF7FFFFFFF7EFF7FFFFFFF7F7F7F7F7F7F7F7F7F7EFF7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7EFF7F7EFF7F7F7F7
F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7FFFFFFF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7FFFFFFF7F7F7F7F7F7F7EFF7\
F7F7F7F7F7F7F7EFF7F7EFF7F7F7F7F7F7F7F7F7F7FFFFFFFFFFFFF7F7F7F7F7F7
F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7FFFFFFF7F7F7F7EFF7FFFFFF\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7FFFFFFF7F7F7F7EFF7FFFFFF
F7F7F7F7EFF7F7F7F7F7EFF7F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7F7EFF7F7F7F7F7F7F7FFFFFF\
F7EFF7FFFFFFF7F7F7F7EFF7F7F7F7F7EFF7FFFFFFF7F7F7FFFFFFF7F7F7F7F7F7
F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFF\
F7F7F7FFFFFFF7F7F7F7EFF7FFFFFFFFFFFFF7F7F7F7EFF7FFFFFFF7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFFFFFFFF7F7F7F7F7F7F7F7F7F7F7F7FFFFFF\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7FFFFFFFFFFFFFFFFFFFFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7FFFFFFF7F7F7\
F7F7F7F7F7F7FFFFFFFFFFFFFFFFFFFFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7FFFFFFFFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7
FFFFFFF7F7F7FFFFFFF7F7F7F7F7F7FFFFFFF7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7FFFFFFF7F7F7F7F7F7F7EFF7
F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7EFF7F7F7F7F7EFF7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7\
F7F7F7FFFFFFF7EFF7F7F7F7FFFFFFFFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7FFFFFFF7F7F7F7F7F7
F7EFF7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7EFF7F7F7F7F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7FFFFFFF7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFF7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7FFFFFFF7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFFFFFFFF7F7F7F7F7F7F7F7F7\
F7EFF7F7F7F7F7F7F7FFFFFFFFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFFFFFFFFFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFFFFFFFFFFFFFF7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
FFFFFFF7F7F7F7EFF7F7F7F7F7EFF7F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7FFFFFF
F7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0113379 0.97619 0.464853 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00751202 0.0192308 0.00751202 [
[.5 1.0125 -32 0 ]
[.5 1.0125 32 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -93 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Monochrome) show
123.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
128 string
128 128 8 [128 0 0 128 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
F0F1F7F7F0F1EFEFF7EFF1D5D5D5D6DCD6D6D6D6D6F1EB95
CDD6CDCDC7CFCFC6CFD0CFD0C7C7CFCFD5D5D0D0CFCFCFD0
C4D0D0D0D8D8D8D8D8D8D8D5D8D0D0D3D8D0D0D0D0D0CFCF
CFCFD0D0CDD0D0CFD0D0CFE4F1E4A1C7C7CFCFC7C7C7CDCD
CDCDCDCDD5D5D1D5DED8DEDEDED6DED5CECDC3C3C7C7C6C3
E2E1B8D4EAF3F7F0
F0F3F3EFF1F7F7F0F0F7F1EFD6D6D6D6D6D6D6D5D5D5EBB1
D0D5CECDCDC7C7C7C9CFD0CFD0CFC9D0D5D0D0CFCFC4C9CF
CFC7CFD0CFD0D5D3D0D0D8D0D0D8D0D0D0D0D0D3D0D0CFCF
D0D0D0D0D0CDC7D0D0CFD0CFE4F1B59DCFCFCFC7C7C7C7C7
CFD0D0D0D5D0D5D0D5D5D6D6D6DED6D6CDCECDCDC7C7CDE9
EAC6C5C7EAF3F0F1
EFEFEFF1F0F0F0F1F0F0F7F7F3D6D5D5D5D3D5D5D1D5E5EB
8CCDD1CEC7C2C7CFCFCFD0CFD0CFC7C4D5D5D0CFC9C9C6C6
C2C2C2C9CFD0D0D5D0D0D0D0CFD0D0D5D8D8D5D3D8D0D0D0
D0D0D0D0D0CFD0D0D0D0D0D0CFD6F1E494C7C7C7CFCDC7C7
CFC7C7D0D5D5D5D5D5D5D6DCDEDCD6D4D1CDD0CDCDD4DBDA
E9DAC6C7E0EFF7F1
F1F0F3F7F0F7F7EFF7F7F1F0F1EFEFDED1D5D0D0D0D0D0EB
DCBACDCECEC7C7C7C7C7CFD0D0CFC7C7CFD0D0D0C9CFC6C2
C6C6C2C1C7CFCFD0D0CFD0CFCFCFD5DED8D8D8DED8D8D5D8
D8D0D0D1D1D1D0D1D1D0D0D0D0D0D6F1E49DD0D0D0D0D0D5
D0D0D1D0D5D0D5D1D5D6DEDCDCD6DCD1D1CED5CEEADBDAE9
C6E0CDC6EAEAEAF1
F0F3F0F3F7F3F3F0F7F7F7F7F1F7F0F1DED5D8D0D5D0D8EB
EBBAD0D1D4C7C7C7CFC7C7CFCFD0CFCFD0CFC9C9C9CFCFCF
CFCFC9C2C6C7CFC4C4C4CFD0D0D0D0D0D8D0D0DEDED1D8D3
D8D3D0D5D5D1D1D5D5D5D0D5D0D0D0D6F1B8BDD0D5D5D5D0
D0D0D5D5D5D5D8D5D5D8DEDCDCDCD6D6D6CEDCEFEAE9E9EF
D4E5C6C6EAF7F1EF
F0F3EFF3F0F1F3F7EFF3F3EFF7F7F3F7F3E2D5D8D5D5D5D6
EBE9D0D5D5CECDC7C7CFCDD0D0C7C7CFC7C2C9C9C6CFCFCF
D0CFD0D0C4C2C2C9C2CFC7CFD0D0D0D0D0D3D8D8D0D6D5D5
D5D8D5D8D5D6D5D1D5D1D1D1D0D5D0D0D6F1C7BDD0D5D5D5
D1D5D5D8D8D8D8D5D8D6D6DCDCDCD6CECCC6DBE9F1CDDBCD
D6EAC7DBF3F3F3EF
F0F7F7F7EFF7EFF3F3F7EFF7F7F0F7F7F7F7F1DCDCDEDCDE
DEF1DBD1D6D6D4CECDC7C7C6C6C7C1B9C1C1C1C6C1CFD0D5
D5D5D5D8CFCFC2C9C6C9C2C6C7C4CFCFD0D0D5D0D0D0D0D0
D1D0D0D5D5D1D1D1D0D0D0D0D0CDD0D0CDDCF1E4CDD0D0D0
CFD5D3D8D8D5D8D5DED6DCDCDCCECDBAB4C7EAE0EFCED4D5
D4D4C5EAF3F1F7F0
F0F1F3F3F3F7F3F7F0F0EFF0F0F7F3F7F7F7F3F0E5E4E4E4
E2E2F1DC9ED6D1D0C7C7C7C7C6B9B9C1C1C1C1C1C1C7CFD0
D5D5D5D8D0D0C4C2C1C1C2C7C2C1C1C2C7C7C7CFC7C7C9C7
CFC7CFCDC7CDCFCFC7C7C7C7C7C7C7CFC7C7DBEBCECDCFD0
D0D0D0D5D8D5D5DEDED6D6D6CDC7AAB5B4CDDBCDB8C7CFC5
DBCEC6E9F3EFF1F0
F0F7F0F7F7F7F0F1F3F3F7F3F0EFF7F3F7F7F0F7F0F7F3F3
F7F7F3F3F1C3CDD0CDC7C7C7C2C6BDC6C6C9CFCFC9C1C9CF
D5D5D5D5D8D5CFC3C9CFC4C9C9C7C7C1C1B8B9B8B3B9B8B8
B8B3B8B8B9B9B9B9B9B9B9C6C2C6C6C6C2C1C6B9D5D5B69D
B9C7C7D0D0D0D5D6D6DCD6CEA0A9B8BBB8B8CECDC7C5C6E0
D4C6DBE9F0F3EFEF
F7F3F7F1F7F7F7F3F3EFF1F0F0F1F7F0EFF7F0F7F3F7F3F0
F7F3F3F1F7F0C6AADAC7BAC7C7C6BDBDB9C1C6C9C9C1C6CF
CFD8D5D8D5D0D0C9C9C9C9CFC9CFCFCFC9CFC9C9C6C2C6C2
C2C2C6C2C2C9C6C9C7C7CFCFC2CFCFCFC7CFC7C7C9D1D4D5
C767C2BAC7CDCDCEB6938C8C9AB8C5C7B8C5C6C7D4CDB8DC
DAB8E2E0F1F3F7F0
EFF0F7F0F3EFF0F3F3F7EFF3F7F7F3F3F3F7F3F7F3F7F0F3
F3F0F7F0F3F3C6A9B9B4BAC6C6C6C6C7BDC1C6C9C9C1C5CF
D0CFD0D5D5D5D5CFC9C9CFCFCFCFCFCFCFC9C4CFCFCFCFC7
C6C9C9CFCFC9C9C9C7CFCFCFCFCFC9CFC9CFCFD0CFC7D0CF
D4D1DBB69E9EB0968C9A8C93A9A9C5B9B5E9C5C5CCB2D6E2
C6E0CEEFEAEFEFF7
F7F0F1F7F0F7F7EFF1F1F7F3F7F0F7F0F3F3F7F0F7F7F7F7
F0F0EFEFF3EFCECDA0B5B5A1C6C7C2C6BAC5C6C1C9C5C5CF
CFCFD0D0D5CFD5CFCFC9C9CFCFCFCFCFCFCFCFC4C9C9CFCF
CFC6C9C7C4C9CFCFC4CFCFCFCFC9C9CFC7CFC6CFCFCFCFC7
C7C7D4D5D5C37479938C93A0A0A1A0B4BDE0A9B7CDB2CEDA
C5EFE9EFEFF0F0F7
F0F7F7F0F0F7F1F7F7F7F0F7F7F3F1F7F7F7F7F1F3F7F7F3
F0F0F3F0F0F0D5CEB6A0B58B79BAC6C2C2C6C2C6C3C1C6CF
CFCFCFCFD5CFCFCFCFCFCFCFCFCFD0CFCFCFCFC9C9C9CFC9
C9CFC6C4C9C9C9C6C7CFD0CFCFC4CFCFC9C9C9CFCFC7C7C7
C6B9B0AA8C7D8C8B898BA09AA0A1B7B7B8CDB2B7C5B7DACD
D4E9EFF3E9F7F7F3
F7F3F0F3F1F7F0F7EFF7F0F7F1F7F0F7F7F7F0F3F7F7F0F7
F1EFF0F7F1F0E2E9DA9AA08B7C61C2BAC6B9BAC2C6C5C6CF
CFCFCFCFD0CFCFCFCFCFC9C9C9C9CFC9CFCFCFC9C9C9C9C9
C6C6C6C9C9C9C9C6C9C9CFC6C9C9CFCFC9C6C9C9C9C1C6B9
B8AAA0827D8C9A9A9F938BA0A0B1B8B7C6B8A9B7B7CDCDCD
DAF3EFF1F1F3F3EF
F0F3F7F3EFF7F7F7F1F7F3F0F7F0F7F7F1F0F3F0F7EFF7F3
F1F7F3F3EFF1DBF1CD9A8C8B766149B3B8B9C6C2C6C1C5C7
CFCFCFCFC9CFCFCFCFCFCFCFC9CFC9C9C9CFCFCFCFC3C3C9
C9C9C9C4C9C6C3C5C6C4CFC9CFC9C6CFCFC9C9C6C1C1B8B7
A9A98C79939A8C9AAA9A939AB1A0B5A9B4B2C5C5C5E2B8CE
EFEFF3EBF0EFF7F3
F1F0F0F1F0F7EFF1EFF7F7F7F1F7F1F1F7F0F7F3F0F7F0F1
F7F1F7F3F1EFE2E9CEC38B937C614949B9B9C1B9C6C5C1CF
CFCFCFCFCFC9C9CFCFC9C9C9C9C3C6C9CFCFCFC9C9C9C6C3
C5C1C9C9C9C3C6BBC6C5C9C9C9C9C9C9C5B7B7B2A9A9A9A9
936F618CA9A07A9AA1B5B1B19A9AA0A9B8B2C5C5E9C6CDDC
EAE9EAF1F1F0F7F3
EFF7F3F0F7F0F0F3F7F3F3F7F3F7F3F7F7F3F7F3F1F1F7F3
F0EFF3F1F3EFF1E0E0B5938C746154493FB8C2B4C5C1C5C9
CFC9C9C9C9CFC9C9CFC9C9CFC9C9C3C5C9C9C6CFC9C3C1C3
C1C1C1C1C5C1C1BBBBBBC3C9BBC9B7C5C1BBB2B2A9A19382
616E7493A0A099A9A9B1A9A9B19AA0B2B2B7C5C7C6CDDAE9
EAE0EAF3F3F0F7F7
F1EFF7F7F7EFF7F7F7F1F0F7F1F3EFF3F0F0F7F7F7F3F3F7
F0F0F1F3F1EAE9D4E29A938B6E6161543F25B0BAB9C1C1C7
C6C9C9C9C9CFC9CFC9C9C9C9C6C9C9C3C3C5C3C9C9C6C5C3
C1C3BBB7BBC3BBBBC3BBC5C1BBB7C1B8B8B7B2AA9B827974
6F7A96A19A99A0A9A09393A09AB1B2B2B1C5C7C7CDE9E9E2
EAF3F1F7F7F7F7F7
EFF7F3F7F7F7F1F3F7F7F3F0EFF3F7F7F7F7F3F0F3F3F3F7
F3F3F3F0F1F3EADAE0A0938C74616154373725B9B9C6C2C6
C6C9C9C9C9C9CFCFC9C9C9C9C9C9C9C5C5C9C3C6C3C4C1C1
C1C1BBBBBBBBB7B2B7BBB7C6B2B8B7B7AAB3A98C6E79527A
828CA09A999F99B1A9A9A9B1B1B2B7B5C5C6C7C7D6DCE2E9
EFF1F7F3F7F3F0F7
F7F7EFF7F3F7F7F7F3F3EFF3F7F0EFF3F3F7F7F1F3F7F0F0
F3F7F3F0F1EFE9E0D5A0937D746F6149372E3FB9B9C1C6C6
C7C6CFC9CFC9C9C9C9C9C3C9C9C5C9C3C6C3C1C1BBC1C1C1
C1BBBBB7B3B2B2B2B7C6B7AAA9AAABAB9B9B8B8C5B6E6F79
6F8C9A939399A9A9B5B8A9B1C5B5B7C5C5C7C6D6DCDCF1F1
F7F7F3F3F7F0F7F7
F7F3F1F1F3F0F7F1F7F1F0F7F7F3F7F1F7F3F3F3F7F0F0F7
F7F3F7F1F3EFEBDAB5A093826E7C615A3F3F4F55BAC5C6CF
C6C6CFC9C9C9C9C9C9C6C9C6C1C4C9C5C3C3C5BBC5B7C1C5
C1BBBBB3B3A1A9B8C6B89BA1A9A1A9A18C8B76748C7A8C8C
96A0A1999A99A99AA1A9A9B2A9A9C5C5C5C6D4DCE9E9F3F7
F0EFF7F7F3F3F7F3
F7F7F0F7F0F3F3F7F7F1F7F7F7F7F0F3F7F0F3EFF0F7F0F3
F7F1F3F1EFE9EAD1B593937D82795A5A49525437B9C6C7CF
C6C6C9C3C5C9C3C5C9C9C5C3C5C3C3C9C1C1C1C5B7C3B7BB
B8B7B3ACA1A9A9C5C69BA1A9A99B897E6F8B7C74798B8C7D
93A0A09A9382B5A0B5A1C5A9B2C5C5C5C5CDCEE9EAEAF3F7
EFF7F7F7F0F7F7F7
F7F0F7F1F7F7F7F7F7F3F7F7F7F7F3F1F7F7F3F3EFF7F3F7
F0F0F7F7F1E9E9B9B593827A6F6F545A61614925C6C1C7C6
C9C6C9C3C3C9C3C3C3C3C3C3C5C5C3C1C5C1C1B7B7B7BBB7
B8B8ACA99B9BB7B99B949499948981667A8B7C7C7C7D7A7D
93A0A19696A0AAA1A9A1A1B1B1B2C6C6C7DCF1E9EAEFF7F7
F3F7F7F0F3F0F7F7
F7F7F7F0F7F7F3F7F3F7F3F7F7F7F7F3F3F3F3F3F7F7F3F7
F0F7F7F7F0E9DBB5A996897D7A5A5261675A453FC7C2CFC7
C1C9C6C6C9C3C4C5C3BBC3C3BBBBBBBBC3B7BBB8B7BBB2B3
B2AAA9959BA0A9A193949393896F7676799A8C8B7C79968C
93969A9FB5A9A99FA1A1A1A9C5C7CFC7DCE2E9EFE9EFF1EF
F7F7F3F7F7F7F7F7
F7F3F7F7F7F3F3F7F7F3F7F7F7F7F3F7F3F3F7F7F3F7F3F3
F3F3F3F1F0E9DAB6A193827A79676179613F3F37C7C2C6B9
C6C9C9BBBBC3C1BBBBBBB7BBBBB7B7BBB3BBB3B3B3B3B2B2
A9A9A19A94AA99897E8C82896E827C797A8C9A93828C898C
9682999FB5B5B5A0A1B5A0A9C5C6CDDCE9F1E9EFE9F1F1F7
F7F7F3F0F3F0F3F7
F7F7F7F3F7F7F3F7F7F7F3F7F7F7F7F7F7F7F7F7F3F7F3F3
F7F1F0F7F7E9C7A9A996827A7A5A6F6152374537C6C6C6C6
C6C1C9C5BBC3BBB7BBB7B3B7B3B7B3B3B3B8B7B2ACAAB2AA
AAA9A193A19B897E827A7A677676616F7D9A9A9AA18C8C82
82969F93B0B5AA9FB5B8A9B7C5C5DCE4E9E0E9EFF3F3F3F7
F3F7F7F7F3F3F7F3
F7F7F7F7F3F3F7F3F0F7F7F7F7F3F7F7F7F7F7F3F7F7F3EF
F3EFF7F3F1F1B4A999936F7667606F604F454F3FC7BAC6C1
C6C1BBC5BBBBBBB7B3B3B3ABACB2ACACB3B2B2A9ABA9A9A9
A99B9B93A193827A76766E7A7667676F7C8B9A939A939682
827D93A9AAA9B6B6B5A1A9B7C6CEE2E0E9F1EFE9F3F7F3F7
F7F7F7F7F3F7F7F3
F7F3F3F7F3F3F7F7F7F3F0F7F7F3F7F7F3F3F1F0F7F3F3F7
F7F3F7EFF1DAB6A993897A82616F6F673B373F45C6B9C2B9
C1C1BBBBBBB3B7B2ACB2ACACABA1A1A1A9A9ACA9A9A1A1A1
9B9B9496827A796F767A7A6F6F6F747C7D8B9AB1A9B79979
79829993A9B5B5B5A0A0A0C5CDCEE0E9E2EFE9F7F3F7F7F7
F7F3F7F7F7F0F7F3
F3F7F7F3F3F1F0F0F3F7F7F7F0F7F3F7F3F7F1F7F7F7F7F7
F3F0F3F1F1C7B59F96826F7667795A5233333F3FC6B9C1C2
C1BBBBB3B2B2B2B2ABAAA9ABA9A9A1A1A1A1A9A9A1A1A194
949389937D6F677A6F7A7A4F4F5A768B8B8B93A0A9A1B596
829393A193B6B6A1A0A1A0C5CDE9E0E9E9EAF0F7EFF1F7F7
F3F7F7F7F3F7F7F7
F7F7F7F7F3F7F7F7F7F7F7F7F7F1F3F7F1F7F3F7F3F7F3F1
F3F7EFF3E0BDB596897A7667676F5A493F454549B9B9B8B8
BBB8B3B8B3B3AAABABA1A1A1959B9B95A1A195A1A1A19493
9493829A7A5A76766F67524F37748B768B7D8CA0B1AAB796
96A096A19FB5A1A1939AB7CDDCE2E2E0EFF1F1F7F3F3F7F7
F7F0F7F3F7F3F7F7
F7F7F3F7F3F3F0F3F3F7F3F7F7F7F7F7F0F1F3F0F7F7F3F7
F7F0F3EFCEB6A6898976766F676745453F454545B9B8B9C7
BCBCB7BCB7B7B8B3B3AA9B939B8E939393939B9B93939389
897E82936F556F7A5A4F4955616E8B8B828B79A0A9B5A19F
93999996B5B5A0A9A0B5B5CCF1DCE0EFEAF7F7F7F7F3F7F7
F7F7F7F7F7F3F7F3
F3F7F7EFEFF7F3F7F7F3F3F7F7F0F7F3F7F1F3F1F7F7F3F3
F0F0F0E9CCB59F89827A6F8260672E4E45453F5DB9CDD0D0
D0CFCFC4C4C4BDBCBCB8B3AA8E8E8C8E8E898989938E898C
827A7A8C5A5B6F66523F4574526F8C8B8279829AAAB7B8B5
9F9F897DB5B59FA1B5B5C6EFE9E9E9EFF1F3F7F3F7F7F7F7
F3F7F7F7F7F7F3F0
F7F3F3F7F7F7F3F7F7F7F7F7F7F3F7F7F3F7F7EFF7F3F7F1
F0F3F3D4BDA9998981676F676F52374F4E453F8FD0D1DED3
D3D0D0D3D0D0C4C4C2BCB8B3ACA18C82898C8C8E7E898C89
827A6E82676F8252493F537C546F7D8C7C7982939AB7B8B5
A99F8296A9A9A9A9C5A9C6EFE2DAEBEAF7F3F7F0F3F0F3F3
F7F7F3F7F7F7F7F7
F3F7F1F7F3F1F7F0F7F7F7F7F3F1F7F3F3F7F3F3F7F3F0F0
F1F3F3D4B49F96817A7A6F676F374555454596D1D8DED8DE
D3DED3D8D3D0CFD0C4C4BCBBB3B2A9A1828282828C828982
76765E52826793493F2E37797D617D9A79968293A9B7C5C7
B67D9696A199A9B6B5B2EAE2D6E9F1F3F7F7F1F7F7F7F7F3
F3F7F7F7F7F3F7F7
F7F3F7F7F7F7F7F0F3F1F7F7F7F1F3F7F3F3F3F3F7F7F7F7
F0EADACDA69F8976676F6F675837555545CED8D5D8DEDEDC
DEDCD3D3D3D8D0CFCFCFC6B9B8BBB3AAA17E7A7A827A7E7A
766F524F93529B6F45532E528C547D8C7C939393A0A9C6C7
B59989969F9FB5B6B5C5E0DBE0EFEFF7F1F7F3F7F7F3F3F7
F3F3F7F7F7F7F7F7
F7F7F7F7F0F7F7F7F7F7F7F7F0F3F1F7F7F3F7F7F7F7F7F3
EFEAD1C39E96897A6E6F6767453F4F458BD5D8D0D8D8DEDE
DEDEDCDED3D3D0D0D0C7C2C6C1BBB9B3AA95A176767A7676
6E60584E8C8189823F2E4F6F8C938C8C937A99969FA9B5C6
C59682968C9FBDC5BBB6CDE9F1F1F3F7F3F7F3F7F3F3F7F7
F7F7F3F7F7F7F3F7
F0F7F3F7F7F7F1F7F3F3F7F3F3F3F1F7F3F3F1F7F7EFF7F0
EFE0D1B49E9682765E675A6733454E66D0D1D8D8D8D8DED3
DED3D3DED3D3D0CFD0D0CFC2C2C1B9B8B3AAA1956F767669
6F58553776AA5AA16E7A3F745B96748B8C968F9F89B5A0C7
D596829699A6A9B5B6C5E0E9EAF1EFF3F7F3F7F7F3F3F7F3
F3F7F3F3F7F3F7F7
F3F7F3F7F7F7F3F3F7F7F7F7F3F3F7F3F7F7F7F7F7F7F3EA
EAD4D1A69981826E67675D453F5864D1D0D5D8D8D8D3D5D0
D0D0D0D0CFC4C4C7CFC6C9C2C2B8BBB9B8B3A9A19B6F606F
5B5A45455E968976A6548967767D8C798C966F9696A9A9B4
B8C5967D96A69FB5C5DBEFE0EFF1EFF7F3F3F7F3F7F7F3F7
F3F7F7F7F3F7F7F7
F7F7F3F7F7F7F3F7F3F3F3F3F7F7F3F7F3F1F0F3F3F7F7EA
DBD4BB9E89816E6767673B453F3FD1D1D8D5D0D0D3D0C9C2
BCBCB8B8B8B3B8B8B8B8C1C1C1C2C1B8B8B3ACAAA99B7E67
5D584E45536EA19684A98C895279938B8C798989AA9FA9B5
C7CE969FAA9F99B4C6F1E0F3EFF1EFF7F7F3F7F0F3F7F3F3
F7F7F7F7F7F7F7F3
F7F3F7F7F7F3F7F7F7F7F3F7F7F7F7F7F3F3F3F7F7F3F3EA
DAD1B69F8282765B675D3F4558CED5D5D8D5D0D0CFC7BCBB
B3ACA6A6A6A6A6B3ACB3B8B3C1C1C2B9B8B3B0AAA1A19466
53554533456CA18167B08CA0896F7A9A8C829689A99FB5A9
B5CDB5A9A6A6A9B6C7E9E9F1EFF3F7F3F7F7F0F7F7F7F3F7
F7F3F7F7F7F7F7F7
F7F3F7F7F3F7F7F7F7F7F3F7F7F7F7F7F7F3F1F1F7F3EFDB
D4D2A689816F765E5845454955D1D1D0D0D0D0CFC4918797
979D9D9D9D9D87878787AAB8B8C1C1C1B9B8B3AAAAA19593
55453F2E3F5E81AA8F95B5A0A99F8C829396798296A996B7
B6C5C7A6B59FA9C5D1DBEAEFEAEFF1F7F0F3F7F3F7F7F7F3
F7F7F3F7F7F3F7F7
F7F3F7F3F7F3F7F7F7F7F3F7F7F3F1F7F7F3F7F7F1F7EAE0
DAB69F84766F67555E4E4555D6D1D0D0CFD5D0A69D9D9DD1
C4A6A6B7C49D9D97958D87AAB8B9C1C2B9B8B8B0AAA19D94
895333332E5E33B0B86FB689B2B59693A0749389969FA1AA
B6C7CE9E8F9FA9B4E9E9EFEFE9F7F7F0F3F3F7F3F7F3F3F7
F7F3F7F7F3F3F7F3
F3F7F3F7F3F7F3F7F3F3F7F3F3F3F3F3F3F1F7F7F0F7DBD1
B49F8F845E675B673745458BD5D5D5D0CFCFCF979D9D9791
91919D8787797E7EA68D8D79B1BCC1C1C1C1B8B0AAAAA1A1
93814545213F668F9F8996B593B7D5968293937A89A09FA9
A9C7C7A69FA69EB4E9EAF1EAEAF7F7F7F7F7F7F7F3F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F3F3F7F3F3F3F7F3F3F3F7F7F3F3F7F3F3F3DBC9
A99F816E5B67583F4F3F67D6D6D5D0D0CFA69D8160657081
7070796D604F5A654A605A53699DC1C1C1B8B8B8AAAAA9AA
948966252145536496B067B089AAC6D5A1A17C9389969989
B5C5C7C3A9B5A6BDE0EFE9EFF3EFF7F7F3F7F3F7F7F7F7F7
F7F7F7F3F7F3F7F7
F3F3F3F7F7F3F3F7F3F7F3F7F3F7F3F3F3F3F3F1F3EADBC3
9E896E5B665A55555553D6D6D1D5D8D0CFC4CFA68D877E87
7E87977E7E7E7E7E7EA9B0B1B8B8C1C1BBBBB8BBB3AAAAA9
A1947C41212141647CAA9F76A989C6C6D581939389969689
B5B5C7CD9FB5A9DAEAEAE9E9F3F3F3F3F7F7F7F7F3F7F7F3
F7F7F3F7F7F3F7F7
F7F3F3F7F3F7F7F7F3F7F3F7F7F7F7F7F1F7F3EFF1E9D2B6
8F7676665A584E55525DD5D0D5D5D0D5CFD5D8D8DEDCD1D0
DED0CFD8DED1D0C7C2C7C2C1C1C2C1C2C1BCB8B8B3B3AAA9
A1A1895D35166453647C966F937A93C6C6A9A196828296A1
A9A1C7CDA6A699E0E9E9EAE9F7F7F7F3F7F7F7F7F7F7F3F7
F3F7F7F7F3F7F7F7
F3F7F7F7F7F7F3F7F7F7F3F7F3F3F7F7F3F1F3F3EACCC6A6
816E5D5D583F55554FBDD5D5D5D3D8D0D8D0D8D8DED8DED8
DECFD0D0D0C2C2C2C2C6C2C6CFC2C1C6C2BCBCB8B3B3AA9D
A1A189692E2A535D8B7CA66F679996B9C6CFB59393998289
89A1C7CDA9B69FE9EAE0E9F1F7F7F7F3F7F7F3F3F3F7F7F7
F7F7F7F7F7F7F7F3
F3F7F3F3F3F3F7F1F7F7F7F7F3F7F3F7F3F3F1F3F3D2A689
6F7658584555555555D5D5D1D5D8D3D3D8D5D8D8D8D8D8D8
D5D0CFCFCFC2C6C9C2C7C2CFC2CFC2C2BCBCC1B8B3ACB3A9
A1A194764E41215A5E6E6F816F8984A1C5C5A1A993968296
82A9B5C7B49FAADBE9E9DAF7F3F7F7F3F7F3F7F7F7F7F3F7
F7F7F3F3F7F7F7F7
F7F3F7F3F3F7F7F7F3F7F7F7F7F7F7F7F7F3F3F1D2C99E82
76586645553F555845D5D1D1D5D8D8D8D3D8D8D8D8D5D8D8
CFCFC2CFC2BBC1C6C2C4C9CFC4C4D0CFC2C2BCBBB3B3AAA9
9D959482532E33536C757C8F76666E9E99B1CFB58C99769F
96AAA9C7B496CEDAEAEAEAF3F7F7F7F7F7F7F3F7F7F7F3F7
F3F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F3F7F7F7F7F3F3F3F7F7EACCAD9E76
6F6E5355555355458FCED1D1D8D8D8D8DED8D5D8D8D8D0D0
C2B8B3BCB9B3B8BCC1C2C9C7CFD0D0C4C4C2BCB8B3B3AAAA
A9A18E7E66414548645E7C6E825D6F5EB6C5A9B2999F8489
96A6A9C6BD9FE0C7F3EAF7F7F7F7F7F7F3F7F7F7F7F7F7F3
F3F7F7F3F7F7F7F7
F3F7F7F7F7F7F3F7F3F3F7F7F3F7F7F7F1F7F3F3C69E816E
5B5B55454555553FCED1D1D3D8D8D8D8D8D8D5D8D8D8D0C4
BDC1ACB3B3AAB0B8B8C1C2C9C4CFCFCFC4CFC3BCB8B3AAAA
A99594896941162F535D765E826F6F55B093A9D59F999989
96939FC6C3C3D1DBDBD5F7F7F7F7F7F7F3F7F7F7F7F7F7F7
F7F7F7F3F7F7F7F7
F7F7F7F7F7F7F7F3F7F7F7F3F7F7F7F7F7F7F7EAB68F6E5D
5B45554E55533F3BD1CDD0D0D8D3DEDED8D8D8D3DCAC97D0
D0C4B7787895AC89A9B8C2CFCFD0D0D0CFC4C2BCBBB3B3AA
A9A1947E764E212F3B535E6476765D766696B7A9B793966F
8989A9C5C3EAB4EABDF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F3F7
F3F3F7F3F3F7F7F7F7F3F3F7F3F7F7F7F7F7F3E19F816E6F
5555454F55453B5ED1D0D5D8DED8D3DED3D8D5D8DED5D1D3
D3D0C1B8B9BBC1B39BAAC2D0D0D0D0D0C4CFCFC3BBB8B3AA
A1A1948E7C6616212F485A665E7C5D6733B59BA0C6899676
81969FB4CCCCB3BDF7F7F3F7F7F7F7F7F3F7F7F7F7F3F7F7
F7F7F7F3F3F7F7F7
F7F7F7F7F7F7F3F7F7F3F3F7F7F7F7F1F7F7F7DB966E6945
53584E5558373785CDD3D3D3DCDEDEDEDCD8D8D3DED1DCDC
DCD3CFC1BDBDB9B8B3B3C4D0D0D3D0D0D0C4C4C4C1BBB8AC
9D9D94897A6E162A21535E6E4E765D673B9F96B5C6899681
898F9EB6CCCCC3D1F7F7F3F7F7F7F7F7F7F7F3F7F7F7F7F7
F7F7F7F7F3F7F7F7
F7F7F7F3F7F3F7F7F3F7F3F7F7F1F7F3F3F7F3D58166675D
5555585B4F3341CED1D8D8DEDEDEDCDEDCDED3D0DEDEDCE5
DCD3D0C7BCB7B9B8B3BCC4D0D0D5D0D3D0CFCFC4C4BCBBB3
ACA195897A67330C2A4E336F5D764F5D668199B2B2A98996
818989B4CDBDD5F3F7F7F7F7F7F7F7F3F3F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F3F3F7F3F3F7F7F3F7F7F7F19F6E6E454E
4E5558552A372AD0D3D6D3DEDEDCDEDEDEDEDED8D8D3DCDC
DCD8D0BCB1B3B8B1B9C2D0D1D1D5D8D0D0CFD0CFC4BCBBB8
B3A99589817653142141615E666E555D537C93A1B8C78289
7C899FC6CDA6D1F7F3F7F3F3F3F7F7F7F3F7F7F7F7F7F7F7
F7F7F3F7F7F7F7F7
F3F3F7F7F7F3F7F7F7F7F7F7F3F7F3F7F7F7F0906E58455E
58585521332E41D0D8DEDCDCDCDCDCDCDCDCDEDED3D6D3DE
D3D1C4C2B1B8B9B9C2D0D0D0D1D3D8D1D3D0CFD0C4C4BCBB
B0B3A19481765B1635334E535D5D6F5D5D8496A0B8D58982
76848FB4CCD1F3F7F7F7F7F7F7F7F7F7F7F7F7F7F7F3F7F7
F7F7F3F3F7F7F7F7
F7F7F7F7F3F7F7F7F7F7F7F3F7F3F7F3F3F3F3906755555E
535558332A33B4D5D5DEDCDCDCDCE4E4E4DCDEDEDED8D1DE
DED0C4B9B9B8C1C2C7D0D5D1D3D3DED6D3D1D0D0C4C2C2B9
B3AAA9947E766E2A143B335E6655676F5D7CA6A9B7D58199
668F81C5D4D1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F3F7
F3F3F3F7F7F7F7F7F7F7F3F3F3F7F7F3F3F7CE7C664E5D5D
5855332A21C4D6D3DEE4DCDCE4DCDCDCDCDCDCDCDCDED8DE
DED3D0C2B9C1C1C2C7D1D1DCDED3DCD3DED6D6D1D0CDC4C1
B8B0AAA989766F4E374553536E5D6F665B7CB0A9B5C79682
5D8489B8DAEFF7F7F7F7F7F7F7F7F7F3F7F7F3F3F7F7F3F7
F3F7F7F7F7F7F7F7
F3F7F3F7F7F7F7F7F7F3F7F7F3F7F7F7F7F77C675D3B6153
5358334541D0D1DCDEDCDCE4E4DCDCDEE4DCDCDCDCDED6DE
DEDED3C2B9C2C6C7C7CDD5DED6DEDCDED3D6D6D6D1D0C7C2
B9B8AAA98E7E69534545455E5D6F6E667A90AAA9A9B59979
58849EB6E0F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F3
F7F7F7F3F7F7F7F7
F3F7F7F7F7F7F7F7F7F7F7F7F3F7F7F7F3F7816F5345665E
554E45338CD3D6DCDCDCE4E4DCDEDCDEDEDCE4E4DCDCDEDE
DCD3D3C2B9B9C6C7D0D0D6D6D6DCDCD3D3DED8D5D1D0D0C7
B9B8B0A9947E695B3B3B4553586E6F6E67A9A9A9A9B0B57A
7A818FB7EFF7F7F7F7F7F7F7F7F7F7F7F7F7F3F7F3F7F7F7
F7F7F7F7F7F7F7F7
F7F7F3F7F3F7F7F7F3F7F7F7F7F7F7F7F7F37C7C5E534E5E
583B4E5ED1D8D6DCDCDCDCDCDCDCDEDCD6DCDCDCDCDEDED1
DCDCDEC7BCB9C2C7C7CDD1D6D6D6DCD6DED6D1D1D0D1CDC7
C7B9B0AAA189765E4E3F45455E676C5E58B6A99FAAA6B867
81818BB5F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F3F7
F7F7F7F7F7F7F7F7
F3F7F7F7F3F7F3F7F3F7F7F7F7F7F7F3F7B2676C5D665D5B
45414ECDDED1DEDCDCDCDCE4DCDCDED6D1D1D6D6DEDED3D8
DCDCDED0BCB8B9BAC6BACED4D1DCD6D6D6D1CED1D0D0D0C7
C7BAB8B09D947667533345455376666666A69FA9A976C552
76969FB4F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F3F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F3F7F7F3F7F7F7F7F7F7F7F7F3F78696765376535B
3B5355CDD3CDDCDCE4DCDCDEDCD6D6C4CDD0D0D1D6DED5D8
DEDCDED0B7B8B1B9B9C7CED1D6CDCDC7CDCDCDCDD0D1CDCD
BDC6B8B0A994816758332E4553666F6666A6A1A1A958B769
6690B0CDF7F7F7F3F7F7F7F7F7F7F7F7F7F7F7F7F3F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F3F7F7F7F3F7F7F7F3F3F3F3F7F75A9B6675646653
336FBBD0BCD1DEDCDCDCDCD6D4D1D1D0BAB9C7CDD1D6CDD1
DCDCDEC4B9ACB6B1B4BDCDCEC7C7BDBDB8B8B1BABAC7C7C7
C6C6B9B0A1957E765E4E2137456666765E9EAA899658C576
5B9FB5DAF7F7F7F7F7F7F7F7F3F7F7F7F7F7F7F7F7F7F7F7
F3F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F3F7F3F7F7F7F7FF76855E665E692E
5D58D3A1B3D5DEDCDCDCD6CEBA9E96B1B09EBABAD6D6D1D1
DEDEDED0B9AAA6AAC6BACEBDBAAEA49096A6A6A6B0C6C7BA
BABAB8B0A69589695E53453B3B5E5D6C669096898967C567
5BA6A9DBFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F3F7F7F7F7F3F7F3F7F7F7F7F7F7F7F7A5847C535E53693B
67C3C4A6B1D5D6DCDCD1BD8F96BAB26C728CA69D9DD1D1CD
DEDEDECFC2AAB09EB0607995B1CE82608685848590B1B9B9
BABAB1B1A1957E7666535E33335E5E66768F9E828961C66F
7CB5B5EAF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F3F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F3F7F7F7F790A47C6C3B5E693F
33D3BBB7B9D6DED6CDBD9095C4DB756C5C7D86A69EBDB9CF
DEDED5D0C2B39E9095A660CEEA797A6E8E64A57C7290B0B0
B9B8B1AAA99081765D533B162A5E664E76908F768476B858
9EB6B6F7F7F7F7F7F7F7F7F7F7F7F7F7F3F7F7F7F3F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F3F7F7F7F7F7F7FFF38B5D553B5E5E5E
69D3B3A6B9CED5D0BA9E7A419DBA81B61A774E7A909EC2D5
DEDED8D0C6C19E967C969E76C85CBD1A725CA5355A85969E
B0B1B09E9F9481695E582A212A335E53817C84848976B558
96AACCF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F79BCB917A5C535E5E69
8DC4A6AAB8D1D5C2B095536B6B482F415E726B859EBCC9D8
D8DED8D0C9C2B39E95817A9393413341415348605C858F90
A1AAAA9E908969666653452A414545537681766F8981B56E
96A9E9F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F3F7F7F7F7F7F7F7
F7F7F7F7F3F7F7F7F3F7F7F7F7F7F781A5A266536C5E535B
94B7AAAAB8D1CECDC7B99E7E6C5C5C5C5E7A95B0C2D0D0D8
DEDED8D0D0CFC1B3AA9E906A858C836B5048537C969695A1
AAAA9EA1967E69665E5E4E33413B3B4E7C897C6F8996B576
96B0EFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F3F7F7E99275534E53534576
94A1A69EB1CED5D5DED6D0D1C7C2BDC2C7C2AAB3BCCFDED8
DCDCDED8D5D0C1A9AC9EB0B1B09E9E9EA1AAB0B0B8BBB9B1
B0AAA1959689696C5E45453341534E457696766F939EB97C
9EE2FFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F3F7
F7F7F3F7F7F3F7F7F7F7F7F3F7F7FFFF4E663B45456E3B60
7E9DA196B0D5C7D8DEDEDCDEDEDCB795857C7EC2CFDEDEDE
E4DCDEDCD8DEC9BC95767C7E96C7CDD0CDC7C7C2C2C2B9B0
9F8FA196898176665D5E373333412E536681766E999FC684
A6EAF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7EAFF45553B45535E536F
78899695A6D0CCC6D1DEDCDCD390857A7EB0CFD8D8DEE4DE
E4DCDEDEDED8D8CFBC96695E697EB3BDCDD0D0C4C7B9B39E
84A19690817676664545333B332E5A6475847C679696B69E
A6F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F3F7FFB2FF5D4E53533B5E5567
69698590A6CED69EA6B0AA9D7E81AAD8DEDEE4E4E4E4E4E4
DCDCDCDCDEDCD8D8D8D5C2B0967A667C768796958F858490
9E9E9D968176765E762A4E4E45332F6A7681766E96A9907A
D1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F3F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F3F7F7AD7C53536A5E5353535E
676C7C84B0CED5D5D0B0A49DBADCE4E4E4E4E4E4E4E4E4E5
DCDCE4E4E4DEDEDCDED8D3D0D0D0CDCDA6858185859EA69E
A1A9A196817C815E4553453B21212A6C7A6684769FA67696
EAF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F3F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F3F7F7F7F3F7F7F7F7F7CB7661538372615E5366
666C8181AAD0D1D5D5DEDEDCDCDCE4E4E4E4E4E4E4E5E4E4
DCE4E4E4DCDCDCDCDCDED5D5D8D0D0D0C7CDCDC2B9B8B1AA
B09E96898184817653452E2121212A966C66A97689B576A6
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F3F7F7F7F7F3F7F7F7F7F7F7BB585A6491755E646164
6466847CAACDD5D5D6DEDEDCE4E4DCDEE4E4E4DEE4E4E4E4
DEDCE4DCDCE4DCDEDEDEDED3D8D1D0CDC7D0C2C2B9B0B0AA
AA9E9F967E818166764E33332A3B2E9E84669E8176B676C3
FFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7D25E726C7C6C726C645E
5D5D767C95C6D1D5D5D6DEDEDCE4E4DEE4E4E4E4E4E4E4E4
E4E4E4E4E4DCDCDCD8D8D8D8D8D0CFCDD0C7C6C1B9B8B1B0
AAA9A18981897C76533B453B21212A9F8576A9826C9E76F3
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F3F7F7F7F7F7F7F7F7F36C5E5E5E6A6C5E645E
645E84899FC2C7D5D6D8DEDEDCDCE4E4E4E4E4DEDEE4E4E4
E4E4DCDCDCDCDCD3D8D8D8D5D0D0D0C4C7C6C7C2B8B9B3B0
9EA195968981765E53414E2A21213B7CA98FAA897C6EB4F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F3F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7FF5C725E6C72756C6464
5E6C7C969EB8C7D5D6DEDEDEDEE4E4DEDEE4E4DEE4E4DCE4
E4E4DCDCDCDEDEDEDED8D8D5D0D0D0C4C2C2C2C2BCB8B1B0
AAA1968F8F85766645532E2A2A212F7A9E7C9F968B6ED5F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7FF835A667575646C5E61
756C7C909FB1C7D0D8D8D8DEDEDEE4E4DCDEE4E4DCDEE4DE
DCDCDEDCDEDEDED8DED8D8D0D8D0CFCFC7C6C7C1B9B8B1B0
9EA1958F8F76766653452E2116165C6C8481A69FB69FF7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7FF5E8584666C6A66646F
4E6C859696B0C6D0D5D8DEDEDEE4E4DCE4E4E4DEE4DEDCE4
DEDCDCDEDCDCDEDEDEDED0D3D5D0D0C4CFC2C2B9B9B8B1B0
9EA996907C7564535E3B21162F166A75766E9F9FA6E0F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F3F7F3F7F7F7F7F7F7F7F7F7F7E18561615E5E5D645E
6C6C8496A6B1C6D0D5DEDEDCDEE4E4DEE4DEE4DEDCDEE4DE
DCDCDEDEDEDEDCDEDED3D8D8D0D0D0C4CFC2C2B9B8B8B8B0
A6AA90857C7C7661453B21212F2175757C6F9FA6B1F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FF6C615E535D5A5361
6C768F96AAB6C6D0D8D3DEDCDEDEDEDEDCE4E4E4E4DCDCE4
DEDEDEDEDEDEDEDED3D8D8D8D0D8D0CFCFC9C2B9B8B1B8B0
B09E9090856C66453B2A2A16272182756F6EA6BBD2F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7BD6A5E5E5D5E5E5A
5E768596A6BAC7D0D8D8DEDCDCE4DCE4E4E4E4E4DCE4DEDC
E4DCDEDCDEDEDEDED8DED8D3D5D0D0CFCFC2C2BAB8B8B0B1
A1A19685847C66413B2A2F1F2A2A859066819FC6F7F7F3F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F3F7F7F7F7F7F7F7F7F7F7F7F7F7F7F37253535A5A5E61
5A758F9EB0B9CFD0D1D5D8DEDEDEDEDEE4DEE4DCDEDEDCDE
DCDCDEDEDEDCDEDED8D8D5D8D3D0D0D0C7C7C6C1B8B8B1AA
AA9696857C6C5E413B2F2A333321768F7693B0D3F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F785725A64615A61
64757C9FB6C7C7D0D8D8DEDEDEDCDCE4E4DCDEDEDCDCDCDC
DEDEDCDEDEDEDED8D8D8D5D5D0CFCFD0C7C6C1BCB8B8B3B3
A19690817666534141332A332116757C7696B8EFF7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFBD8575757561
61758B96AAC2CFD0D0D8D5D8DCDCDCDCDEDEDCE4DEDCDEDE
DEDED8DED8D8D8D8DED3D8CFCFCFCFC4C7C6C1B9C1B0B0B0
969685846C5E4E533B3B2A211441907C82A1B4F7F3F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F3F7F7F7F7F7F7F7F7F7F3F7F7F7F7F7FFFFEA7A75646C
6A6C819EA6B9CFD0D0D8D8DEDED8DCDCDEDEDEDEDEDEDCDE
DEDEDEDED8D8D8DED8D0D0D0D0CFD0C9C2C2C2C1B8AAB19E
9E9681695E644E41412F331A1484856E8999D4F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFA55E6A5A
6C6C8496AABAC7C4D0D0D8D5D5D8D8DEDEDED8DEDEDED8DE
D5D8D6D8D8D8D5D0D0D0D0CFD0CFCFC4C2C2C2B9B9B1AAB0
9685766E6664643B3B3321169082766E96BDEAF7F3F3F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFD1456484
61848496A6B9C6CDD0CFD0D8D8DED8D6DED8DEDEDEDEDED8
D8DED8D0D8D0D8D0D0CFD0D0CFCFC6C9C1C1BAB8B49EAAA1
90857C7664535A752A2127615E8476819FC7F3F7F3FFF7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFBB7C5E5E
6A858496AAB9BAC7D0CFD0D3D0DED5D8D8D8D8D8D8D8DED3
D3D0D0D0C4D0CFCFCFCFCFD0CFCFC1C1C2B9B9B8B09E9E90
817C6E64645E5E415341534E857C8F96B6C3F7FFF7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFADA64E5D
61667C8F9EA6BDC2C7CFC4D3D3D5D5D1D0D3D8D8DED1D5D0
D0CFC4C2C2C3CFCFC9C4C9C3C2C2B8BCB9B1B1AA9E9E9690
8184765A5A5353484E3B8B757C76AA9FC6F7F7F7F3F7F7FF
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFF7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E1CE3B4E
765E7C8B96B1B9BAC2C4C4CFD0CDD0D5D0D0D0D1D0CFD0D0
C9C2BBBCBCC1C3BBBBBBBBB3B8BCB0B8B0B0A6A99E908F8F
847C6664615A72615372907A8596B0C6C3F3F7F7F7FFF7F7
F7F7F7F7F7F7F7F7F7F7F7F3F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7AD8361
64756C7C859EB1C6BABDC2C2D0D0D0D0CDC7C7C7C7C2BAB8
B9B9B0B0AAAAAAA9ACAAA9A99EA1A1A1A195969E96908976
6C7A75607575536C76767C76968FB9C6F1F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7B27A
646C75849086969EB9BDC7CFCDC7C7C7C6B9B9B0B9C6B1B3
B0B19EA695A196AA8DA189968989968F8F909085969E8B91
84856C6C7A8564455E898F8996B4BDC3F7F7F7F7F7F7F7F3
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFF7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EA
927A617C846C96A6C3CECECEC7C7BDBAB0B4B1B1B0B1B0B0
9F9F969690969081908F7C76907C8F7C818584856C757A81
7A7C7A7C5E6472767C84849FBDBDA6F7F7F7F7F3F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F3F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F3F7F3F7F7F7F7F7F7F7F7F7F7F7F7F7F7
9286857E91ADB0A4BAB0BAC3C3BAB9B1B0B19EA6B0A69FA6
9E958F907C9E859E8F859684769E849085848B916A758482
727A856E766E766E7C8FB5BBB4B6D5F7F7F7F7FFF7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F3F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
FF7A8C7E758B9696A4BABDB9B4B1B6A6A6A6969E969E969E
909E847C866E8B84967C8584859F6C7C7C90847575646153
5A6C5E5E61616E829FB5CDA4B68FF7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7FF9B8685A5A6ADBDBDBDBDA6A6A6A69EA69E9E90909E8F
84856E8B8B6C5385648F8485856676844E536F6664666F6E
766E6E5E6F76B49EB6C36CA48BD3FFF7F7F7F7F7F7F7F3F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7AE8C6A7E768BAEBBBABDAD9E9E969E9E968B9196858F
8F6C9F846C9E6C64856C6C7564665D4E5E5E6F5E616E665E
58667C8F8FA69EC6BD8B84A48BF7F7F7F7F7F3F7F7F3F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F3F7F7FFF7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7FF6083A4868B9BB3BBB1AD85908B9E9E907E908F8596
858F647C7A6C84646C6E646A645A5E5E5E534E5E615E5D5D
6C84848484A6BB82828BAD9EEAF3F3F7F7F3F7F7F3F7F7FF
F7F7F7F7FFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F783539BA2A49BBDBDB3849685858F847A8B8B7A85
7A85648476755A53845A6164615D535345414E4E4E5D7664
6C8BA69EC7BBA49175A675EAFFFFF3F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F3F7FF864E7B8C9BBBC3B384759B85969B8F758B846C
85856C7C847A723B5361845E5E455E4E453B413B3B53668B
9E909EBB9B6A818F8B76AEF7F7F7F7F7F7F3F7FFF7F7F7F7
F7F7F7F7F7F7F7F3F7F7F7F7F7F7F7F7F7FFF7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F3F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7D36E616A91A4B3BD8B7584967A7A85726C7E7A
7275857A6C847C726C53536A5E5E665D765D5D6776818596
A6CC9BA483537A8B9B9BF7F7F7F7F7F7FFF7F3F7F7F7F7F7
FFF7F7F7F7F7F7F7F7FFF7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7C481786B6A8C93BD6C72828F7A756461616C
6C757A6C6C848B7C7A61845E5D7A756C6E76848FA6969EBD
A4A29191617E918B86FFF7FFFFF7F3FFF3FFF7F3F7FFF7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFF7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7FFF7F7F7F7B27A7B7E8B92A6AD72728B8B758B5E6464
76757C5E867C9685909B7566667C7C8F8F9696B0B0AD8583
83664E5E858B829EFFF7F7F7FFFFF7F7FFF7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F3F7F7F3F7F7BD6B7B919BA4ADB37A8B6C8C7A85755E
5C536C617E7C9E96CCCEBDA6BAB1B1B1CDCDB9BB91728275
64616C8F9B8586FFF7F7FFF7F7F7F7F7F7F7F3F7F7FFFFF7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7FFF7F7F08A7B6691BBBBB48C968C92869EAD
835C725C7A9BADA492C3C4C3CCDAD5C3A69B9B8C7B7A755A
5E7A829E859BF7F7F7F3F7F7F3F3F7F7F7F3F7F7F7F7F7F7
F3F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7FFF7F7F7FF836B8992B3CEB3B3C4B2D1C4AE
D5DCF1E9DCD5D4C3D1CCCCCCD4BB91AD918283836C726085
918B8B85FFF7F7FFF3F7F7F7F7F3F7F7F7F7F3F7F7FFF7F7
F3F7F7F3F7FFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFF7F7F7
F7F7F7F7F7F7FFF7F7F7F7F7E16B799BABC4D1DBD2D1D1D1
DBCCCED4CEDCE2DBD1D5BBA5C3A4A2A578846C72838CA4A6
968BAEF7F7F3F7F3F7F7F7F7F7F7F7F3F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFF7F7FFF7F3F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7FFF7FFFFF7FFF7F7FFEA8C8993BBBBC4C9D1DBDB
DBDBE9E0DBDBE2D5D1C4C8A293A582837A916B92A4A6A292
A6E1F7F7F7F3F7F7F7FFF7FFF7F7F3F7F7F7F7F7F7F7F7F7
FFF7F7F7F7F7F7F7FFF7F7F7F7FFF7F7F7F7FFF7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F3F7FFF7F79D838CBDCEDBDBDA
D5CEDBD2CEC4B3A49BADB3A2927086A292B3B3BBB393B3F3
F7F7F7F7F7F7FFF7F7F7F7F3F7F7FFF7FFF7F7F7F3F7FFF7
F7F7F7F7FFF7F7F7F7F7F7F7F7F7F7F7FFFFFFF3F7F7F7F7
F7F7FFF7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFF7F7F7F7
F7F7F7F7F7F7F7F7F7F3FFF7F7FFF7F7F7F7F7A59DBABDC4
DBDBDBDBDBDBC4C4AEAB9DBBD1A5C4CEC4A59BC3EAFFFFFF
F7F7F7FFF7F7F7F7F7FFF7F7F7F7F7F7F3F7F7F7F7F7F7F7
FFF7FFFFFFFFFFF7F7F7F7F7FFF7F7F7FFFFF7FFF7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F3F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFF7FFF7F7B2ABC4
AEC3D2D2E0DBE9F1E9DBD1DBD2D1AEA4BBD1EAF7F7FFFFF3
F7F7F7F7F7F7F7F3F7F7F3F7F7F7F3F7F7F7F7F7F7F7F3F7
F7F7F7F7F7F7F3F7FFF3F7F7F7F7F7F3F7F7F7F7F3F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFF7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F3F7F7FFF3F3F7F7F7F3F3
F3EAEAE1F1E9D1C4C4D1D2CECED3EAF3F7F7F7F7F7FFFFF7
FFFFFFF7F7F7F7F7F3F3F7F7F7F7F7F7F3F7FFF3F7F7F7FF
F7F7F7F7F7F7F7F7F7FFF7FFF7F7F7F7F7F7F7F7FFF7F7F7
F7F7F7F7FFF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F3F7F7F7
F7F7F7F7F7F7F7F7FFF3F7F7F7F7F3F7F7F7F7F7F7F7F7F7
FFF7F7F7F7F7F3F3F3F3FFF7F7F7F7F7F7FFFFF7F7F7FFF7
F7F7F7F3F7FFF7F7FFF7F7F7FFF7FFF7FFF7F3F7F7F3F7F7
F7F7F7F7F7F7F7F7F7F3F7F7FFF7F7F7F7FFF7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F3F7F7F3FFF7F7F7F3F7F3
F7F7FFF3F7F7F7F7F7F7FFF7F7F3F7F7F7F7F7F7FFF7FFF7
F7F7F3FFF7FFFFF7F7F7F7F7F7F7F7F7FFF3F3F7F3F7F7F7
F7F7F7F7F7FFF7F7F7F7F7F7FFF7F7F7F3F7FFFFF7F7F7F7
F7F7F7F7FFF7F3F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFF7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFF7F7F7F3F7F7FF
F7F7F7FFF7F7FFF7F7F7F3F7F7F7F7F7F7F3F7FFF7F7FFFF
F7F7F7F3F7F7F3F7FFF7F7F7F7FFF7F7F7F7F7F7F7F7F7FF
F3F7F7F7F7FFF7F7FFF7F7F3F7F7F7F7F7F7F3FFF7F7F7F7
F7F7F7F7F7F7FFF7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFF7F7F3F7F7F3
F7F7F7F7F7F7F7F7F7F7F7F3FFF7F7F7F3F7F7F7F7F3FFF3
F7F7F7FFF7F7F7FFF7F3F7F7F3F7F7F7F7F7F7F7F7F7F7FF
F7F7F3F7FFF7F7F7F3FFFFF7F7F3FFF7F7F7F7FFF7F7F7FF
F7F7F7FFF7F7FFF7F7FFFFF7F7FFF7F7F7F3F7F7F7F7F7F7
F7F7FFF7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFF7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F3F7F7
F7FFF3F7FFF7F7F7F7FFF7FFF7F7F7F7F7F7F3F7FFF7F7F7
F7F7F7F7F7F7F7F7F7F7F3F7F7F7F7F7F7F3FFF3FFF7F7FF
F7F7F3F7F7F7F7F7F7F7F7F7F7F7F7F3F7F7F7F7F7F7F7F7
F7F3FFF7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFF7F7F7
F7F7F7F7F7F7F7F7F7F7F3F7F7F7F7F7F7F7F7F7F7F3F3F7
F7F7F7F3FFFFF7F7FFF3F7F7F7F7F7FFF7F3F3F7F7FFF3F7
FFF7FFF7F7FFF7FFF7F7F7F7F7FFF7F7F7F7F7F3F7FFF7F7
F7FFF7F7F7FFF7FFF7F7FFF3F7F7F7F7F7FFF7F7FFF7F7F7
F7F7F7F7F7F7F3F3
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFF7
F7F7F7F7F7F7F7F7F7F7F7FFF7F7F3F7F3F7F7F7F7F7F7FF
F7F7F7F7F7F7F7F3FFF7F7F7F7F7F7F7F7F7F7F7F3F7FFF7
FFF7F7F7F3FFF3FFF7F7F7F3F7F7F7F7F7F7F7F7FFF3F3F7
F7F7F3F7F7F7F7FFF7F7F7F7F7F7F7FFF7F7F7F7F7F7F7F7
F7F7F7F7F3F7FFF7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F3
F7F7F7F7F7F7F7F7F3FFF7F7F3F7F7F3F3F7F7F7FFFFF7F7
F7F3F7F7F7F7F3F7F7FFF7F3FFF7F7F7F7F7FFF7FFF7F3FF
F7F3F7F3F7F7FFF7F7F3F7F7FFF3FFF7F3F7F3FFF7FFF7F7
F7F3F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F3F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7FFF7FFF7F3FFFFF7F3FFF7F7
F7F7F7F7F7F7FFFFF7F7F7F7FFF7F7F7F7F7F7FFF7F7F7F7
F7FFFFFFFFF7F7F7F7F3F7FFF7F7F7FFFFFFFFF7F7F7F7F7
F7FFFFF7F7F7F7F3F7F7F7F7F7F7FFF7F7F7F7FFF7F7F7F7
FFF7FFF7F7FFF7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFF7FFF7F7F3
F7F3F7F7F7F7F7FFF7F7F7F7F7F7F3F7F3F7F3F7F7F7F7F7
F7F7F3F7F7F7F7F7F7FFF7F7F7F7FFF3F7FFFFF7F7F7F7F7
F7F7F7F7F7F7FFF7F7F7F7F7F3F7F7F7F7F7F7FFF7FFF7F7
F3F7FFF7F7F7FFF7F7F7F7F7F7F7F7F3F7F3F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFF7F7FFF7F7
F7F7F7F7F7F7F7F7F7F7F7F7F3F7F7F7F7F7F7FFF7FFF7F7
F7F7F7F7F7F7F7F7FFFFF7F7F7F3F7F7FFFFF7F7F7F7F7F7
F7F7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7FFF7F3F7F3F7F7FFF7F7FF
F3F7F7F7F7F7F7F7
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[12]:=",
  ImageSize->{400, 190.438},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0000_R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00f@3oool00`3`l?00lO7a0?Ogm`020?Ogm`070?3`
l03alO40kno_0>o_k`3gmoL0kno_0?7al@040=GEe@030=KFeP3Lg=`0e]KF00D0e]KF00D0lO7a0>_[
j`2EUID0cLg=0=KFeP030<g=c@070<O7a`3?cll0clo?0<K6aP3?cll0d=3@0<o?c`020=3@d080alO7
0P3?cll20=GEe@<0d=3@0`3?cll00`3@d=00a<C40=3@d0030=3@d0L0f=SH0P3EeMD01@3Hf=P0d=3@
0=3@d03Cdm<0f=SH00H0d=3@103?cll30=3@d0040<g=c@3@d=00d=3@0<o?c`80d=3@00H0clo?0>CT
i03Ti>@0lO7a0>CTi02QXJ420<O7a`80clo?1037alL70<g=c@80eMGE00@0dM7A0=GEe@3Ng]h0f=SH
103Ng]h01@3Fe]H0g]kN0=GEe@3>c/h0cLg=00<0`l?30P37alL01@36a/H0`l?30>;RhP3QhN40^;Rh
0080e=CD00@0j^[Z0??cl`3gmoL0l?3`9`3oool002D0oooo00@0knog0?O_i`3gmoL0moOg0P3_koL0
1P3gknL0knoW0>o_i`3gmoL0knoW0?O_i`@0klje00<0kljm0>oFaP3_c[d0103_c[d20?O_i`040?OW
gP36Q6/0ilJ]0>o>_@80ilJ]00T0ikfU0>o6Y@3_aZD0klJU0>NmW03_aZD0klJ]0>o6Y@3_aZd00P3W
_JD30>o6Y@80klj]0P3_aZd40>o6Y@030>o6[@3_]I`0klJ]0080klJ]203gc[D0103_cZd0mlje0>o6
[@3_aZd20?O6]@030?O>]@3_aZd0klJ]00<0klJ]1@3_aZD20>o6[@040>O6[@3_aZd0klJ]0>o6Y@<0
klJ]00D0klJU0?ONcP3gknL0mmk>0<jDJ`020>NmY@<0klJU0`3W_JD70>O6[@060>o>]@3_cZd0klJe
0>o>[@3ge[d0mlje103ge[d01@3_c[d0mmJm0>o>]@3Wa[D0ilJ]00<0e[f]0P3W_JD01@3W_I`0e[f]
0>oNcP3Wg]h0gZf<0080iljm00@0knOW0?O_m`3gmoL0knog9@3oool00`3`l?00lo?c0??cl`020>o_
k`030?7al@3gmoL0moOg0080l?3`00@0moOg0?7al@3_knl0kno_1`3Fe]H40=GEe@050>_[j`2a/K40
d=3@0=GEe@3>c/h00`3=cLd30<O7a`030<W9b@3?cll0d=3@0080clo?00D0d=3@0<o?c`39bLT0d=3@
0=GEe@020=3@d0<0clo?00H0a<C40<W9b@3?cll0clo?0<O7a`3?cll20=3@d0040<o?c`3@d=00eMGE
0=?Cd`80d=3@00D0f=SH0=3@d03@d=00d=3@0=SHf0050=3@d080dm?C0P3@d=020<o?c`H0d=3@00H0
cLg=0<O7a`3@d=00d=3@0<o?c`3@d=020<o?c`040>CTi03alO40]KFe09fMW@<0clo?1P37alL00`3?
cll0d=3@0=3@d0020=3@d0040=GEe@3@d=00eMGE0=3@d080eMGE103Fe]H01@3Ng]h0e]KF0=KFeP3=
cLd0c/k>00<0cLg=0P37alL01@3=cLd0jNWY0>[ZjP36a/H0aLG50080alO700@0j^[Z0??cl`3`l?00
lO7a9`3oool002D0oooo00@0knog0?O_m`3gkoL0knoW0P3gknL20?Ogm`80knog00<0moOg0?O_i`3_
knL0203_c[d40>o>]@050?OWgP3FYH`0klJ]0>o>]@3Wa[D00P3WaZd40>NmY@060>nmW03_aZD0klJ]
0>o6Y@3_aZd0klJU0P3__I`0103_aZd0klje0>o6[@3_aZd20>o6Y@030>neW03__I`0kkfL0080klJU
00H0ikfU0>o6Y@3_aZd0klJU0>o6[@3_cZd20?O6]@80klJ]00@0mlje0>o6[@3_aZd0mlje1P3_aZd0
0`3ga[D0klJ]0>o6[@020>o6Y@H0klJ]00@0ilJ]0>NmY@3_aZd0klJ]0P3_aZD01P3_aZd0klJU0?ON
cP3gknL0eZf40=j4L`@0klJU1@3W_JD00`3_aZD0klJ]0>o6[@020>o6[@040>o>[@3_aZd0klje0>o6
[@80klje103_c[d01@3ge[d0kljm0>o>_@3WaZd0ilJe00<0ilJ]0P3W_JD01@3WaZd0knON0>oWi`3W
_I`0ikfD0080ikfU00@0knOW0?O_m`3_koL0mnoW9@3oool30>o_k`80lO7a0`3`l?000`3alO40l?3`
0?3`l0030?Ogm`030??cl`3Fe]H0eMGE0080eMGE00/0dm?C0=GEe@3EeMD0eMGE0=7Ad@3EeMD0iNGU
0>_[j`2<S8`0cLg=0=7Ad@020<k>cP030<O7a`32`/80alO700<0clo?00L0d=3@0<o?c`3?cll0d=3@
0<o?c`37alL0a<C40080eMGE00<0d=3@0<o?c`3?cll00P39bLT20<K6aP<0`/;20P39bLT0103?cll0
d=3@0=3@d03EeMD50=3@d0040<o?c`3@d=00d=3@0=GEe@80f=SH00@0eMGE0=?Cd`3Cdm<0f=SH2@3@
d=000`3?cll0d=3@0=3@d0050=3@d0050<o?c`3Fe]H0lO7a0>CTi02DU9@01037alL01@3?cll0cLg=
0<O7a`37alL0clo?0080alO70P3@d=060=GEe@0:0=KFeP3Lg=`0g=cL0=kNgP3Lg=`0e]KF0=CDe03A
dM40cLg=0=3@d0<0cLg=00H0e=CD0=_Kf`3Jf]X0jNWY0=[JfP36a/H20<O7a`040>3Ph03_knl0moOg
0?7alBL0oooo000U0?ooo`<0knoW00<0mnoW0>o_m`3_koL00P3_koL00`3gknL0knog0>o_m`020?Og
m`80mnog00D0kljm0>o>]@3_c[D0klje0?O6]@020>o>]@0:0>o6]@3_c[D0klje0?ONeP3gimh0aW]:
0>O6[@3_a[D0ilJe0>NmY@80ikFL00P0ikfU0>o6Y@3_aZD0klJU0>o6[@3_aZD0klJ]0>o6Y@80ikfU
00D0kkFL0>o>[@3_cZd0klJ]0>o6Y@020>nmW0<0ikfL0`3W]I`0103__I`0klJU0>o6[@3_aZd20>o>
[@@0klJ]00<0klJU0>o6[@3_aZd00P3_c[D20?O>]@030>o>[@3ga[D0mlje00T0klJ]00<0klJU0>o6
[@3_aZd01@3_aZd01@3_aZD0kljm0?O_i`3gg/h0aXAS00@0ikfU00D0klJU0>O6[@3W_JD0ikfU0>o6
Y@030>NmY@050>o6[@3_c[D0klj]0>o>]@3_cZd00P3_c[D20>o>_@080>oFaP3ge[d0kmK60>o>_@3W
c[d0klJe0>O6[@3_aZd30>O6[@060>O>_@3We/h0imK60>oWgP3We/H0ikfL0P3W_JD0103Wg]H0knoW
0?Ogm`3gknLU0?ooo`030?7al@3`l?00lo?c0080moOg00@0l?3`0?Ogm`3gmoL0kno_0P3gmoL0103a
lO40l?3`0?3`l03alO420>o_k`030=kNgP3AdM40eMGE00H0d=3@00@0jn_[0=cLg02j^[X0cLg=0`3>
c/h50<O7a`050<o?c`3@d=00d=3@0=3@d03?cll00P37alL00`3?cll0d=3@0=3@d0020=3@d0040<W9
b@3?cll0a/K60<;2`P80a/K600@0`/;20<71`@31`L40alO70P3?cll20=3@d0030<o?c`3@d=00clo?
00<0clo?00<0eMGE0=kNgP3Hf=P00P3Hf=P20=kNgP80f=SH00<0eMGE0=SHf03Hf=P00P3@d=040=7A
d@030=3@d03AdM40dM7A00H0d=3@00@0e]KF0?7al@3Ti>@0WIfM1P3@d=00103EeMD0d=3@0=3@d03A
dM420=3@d0070=GEe@3@d=00eMGE0=7Ad@3EeMD0e]KF0=kNgP030=cLg0060=KFeP3Lg=`0dM7A0=7A
d@3>c/h0eMGE0P3>c/h01`3Zj^X0fm_K0=[JfP3YjNT0a/K60>3Ph03=cLd00P36a/H30>[ZjP030?7a
l@3oool0oooo02D0oooo000U0?ooo`040?O_i`3_koL0mnog0?Ogm`80knog0P3gmoL01@3_knL0moOg
0?Ogm`3gknL0knog0080mnoW0P3_knL00`3ge[d0klJe0>o>]@060>o6[@040?OWgP3_e/H0gZfL0>O6
[@80ilJe1P3W_JD0103_aZD0klJ]0>o6[@3_aZD30>NmY@060>o6Y@3_aZd0klJ]0>o6[@3__I`0klJU
0P3W_I`01P3W]I`0ikfL0>NmW03W]I`0ikFD0>NmY@80klJU0`3_aZd00`3_aZD0klJ]0>o6Y@020>o6
Y@030>o>[@3ge[d0mmJm00<0mlje00@0mmJm0?O>]@3gc[D0klj]0`3gc[D20>o6[@<0klJe00<0klJ]
0>o6]@3_a[D01P3_aZd00`3_c[d0mnoW0?ONcP020=j4L`D0klJ]00<0klj]0>o6[@3_aZd00P3_a[D0
1`3_aZd0klj]0>o6[@3_c[D0klJe0>o>]@3_c[d00P3ge[d20>oFaP060>o>_@3_e/H0klJe0>o6]@3W
a[D0klje0P3Wa[D01`3_inL0imK>0>OFaP3_imh0ikfL0>ONeP3WaZd00P3W_I`30>oWi`030?O_i`3o
ool0oooo02<0oooo00<0lO7a0?3`l03clo<00P3gmoL0103`l?00moOg0?Ogm`3_knl20?Ogm`040?7a
l@3`l?00l?3`0?7al@80kno_00<0g]kN0=7Ad@3EeMD01P3@d=00103[jn/0g=cL0;Zj^P3=cLd30<k>
cPD0alO700D0clo?0=3@d03@d=00d=3@0<o?c`020<O7a`030<o?c`3@d=00d=3@0080d=3@00@0bLW9
0<o?c`36a/H0`/;20P36a/H01032`/80`L710<71`@37alL20<o?c`80d=3@00<0clo?0=3@d03?cll0
0`3?cll00`3EeMD0g]kN0=SHf0020=SHf080g]kN0P3Hf=P00`3EeMD0f=SH0=SHf0020=3@d0@0dM7A
00<0d=3@0=7Ad@3AdM401P3@d=00103Fe]H0lO7a0>CTi02MWId60=3@d0040=GEe@3@d=00d=3@0=7A
d@80d=3@00L0eMGE0=3@d03EeMD0dM7A0=GEe@3Fe]H0g]kN00<0g=cL00H0e]KF0=cLg03AdM40dM7A
0<k>cP3EeMD20<k>cP070>[ZjP3Kfm/0f][J0>WYj@36a/H0h>3P0<g=c@020<K6aP<0j^[Z00<0lO7a
0?ooo`3oool09@3oool002D0oooo00@0knog0?O_m`3_koL0mnog0P3gmoL20?O_m`030>o_m`3gmoL0
moOg0080moOg0P3gknL0203gmoL0knog0?O_i`3ge[d0klje0?O>]@3_aZd0klj]0P3_aZd01`3gc[D0
mnON0?OWgP3N[I`0klJ]0>o6]@3Wc[d0103W_JD00`3_aZD0ikfU0>NmY@020>o6Y@060>o6[@3_aZD0
klJU0>o6Y@3_aZd0klJU0`3__I`60>o6Y@050>nmW03W]I`0ikfL0>NmY@3_aZD0103_]I`00`3_aZD0
klJ]0>o6[@040>o6[@030?O>]@3_aZd0klJ]0080mmJm00<0klJe0?O>]@3ga[D00P3gc[D0103ga[D0
klJ]0>o>]@3_c[D20>o6]@@0klje00<0klJ]0>o>]@3_aZd00P3_aZd01P3_c[d0mnoW0=j]S03N[H`0
ijfL0>o6[@<0klj]0`3_aZd20>o>[@040>o>]@3_cZd0klje0?O>]@80klje00<0mlje0?OF_@3ge[d0
0`3_e/H30>o>_@050>O6]@3_e/H0knoW0>o_i`3_inL00P3_imh00`3_knL0iljm0?ONeP030>NmW004
0>oWi`3gmoL0mnoW0>o_ibD0oooo00<0l?3`0??cl`3`l?000P3clo<0103gmoL0lo?c0??cl`3`l?05
0?Ogm`070?7al@3gmoL0l?3`0?7al@3Ng]h0eMGE0=SHf0020=3@d0030=GEe@3@d=00f=SH0080jn_[
00D0^[Zj0=3@d03AdM40dM7A0=CDe0030<O7a`030<o?c`37alL0alO700<0clo?00D0d=3@0<o?c`3?
cll0d=3@0<o?c`040<W9b@D0clo?00H0bLW90<;2`P32`/80a/K60<O7a`3?cll30<C4a0030<o?c`3@
d=00d=3@00@0d=3@00<0f=SH0=3@d03@d=000`3Ng]h01P3AdM40f=SH0=?Cd`3Hf=P0dm?C0=3@d0<0
eMGE0P3AdM430=GEe@030=3@d03EeMD0eMGE00<0d=3@00@0e]KF0?7al@2h^;P0_Kfm0P3@d=030=GE
e@<0d=3@1@3EeMD01@3Hf=P0eMGE0=GEe@3Hf=P0g]kN00@0g=cL0`3Fe]H01@3>c/h0g=cL0>o_k`3_
knl0j^[Z0080jNWY00<0kno_0=CDe03UiND00`36a/H0103Zj^X0moOg0?7al@3_knlW0?ooo`009@3o
ool0103_koL0mnog0>o_m`3gkoL20?Ogm`80mnog00<0knog0?Ogm`3gmoL00P3gmoL20?O_i`080?Og
m`3_koL0mnoW0?OF_@3_c[D0mlje0>o6[@3_cZd20>o6[@070?O>]@3gimh0mnON0=j]W03_aZd0klJe
0>O>_@040>NmY@030>o6Y@3W_JD0ikfU0080klJU00H0klJ]0>o6Y@3_aZD0klJU0>o6[@3_aZD30>nm
W0H0klJU00D0kkfL0>NeW03W_I`0ikfU0>o6Y@040>neW0030>o6Y@3_aZd0klJ]00@0klJ]00<0mlje
0>o6[@3_aZd00P3ge[d00`3_a[D0mlje0?O6]@020?O>]@040?O6]@3_aZd0klje0>o>]@80klJe103_
c[D00`3_aZd0klje0>o6[@020>o6[@060>o>_@3gknL0gZf<0=j]S03W[I`0klJ]0`3_cZd30>o6[@80
klj]00@0klje0>o>[@3_c[D0mlje0P3_c[D00`3gc[D0mmJm0?OF_@030>oFaP<0kljm00D0ilJe0>oF
aP3_knL0knoW0>oWi`020>oWgP030>o_i`3Wc[d0mmkF00<0ikfL00@0knOW0?Ogm`3gknL0knoW9@3o
ool00`3`l?00lo?c0>o_k`020??cl`050?3`l03alO40lo?c0?Ogm`3_knl00P3clo<20>o_k`80moOg
00D0lo?c0?Ogm`3clo<0h^;R0=GEe@020=SHf0<0eMGE00@0e]KF0>_[j`3YjNT0d=3@0`3EeMD01P3>
c/h0cLg=0<O7a`37alL0clo?0<g=c@<0d=3@0P37alL00`3?cll0alO70<;2`P030<W9b@060<K6aP3?
cll0clo?0<o?c`3@d=00clo?0`3@d=001`34a<@0`/;20<;2`P39bLT0`/;20<o?c`37alL00P3?cll5
0=3@d0060=?Cd`3Hf=P0f=SH0=SHf03@d=00e]KF0`3EeMD02@3Hf=P0eMGE0=SHf03Hf=P0eMGE0=KF
eP3EeMD0dM7A0=GEe@040=7Ad@070=3@d03EeMD0d=3@0=3@d03Fe]H0lO7a0<O7a`020;fm_@050=3@
d03EeMD0eMGE0=GEe@3AdM400P3EeMD50=SHf0040=GEe@3Hf=P0e]KF0=KFeP@0g=cL00D0e]KF0<k>
cP3<c<`0a/K60=_Kf`020>WYj@070?7al@3=cLd0fm_K0<g=c@3Fe]H0j^[Z0<O7a`020=_Kf`<0lo?c
00<0kno_0?ooo`3oool09@3oool002D0oooo00@0knog0?O_m`3_knL0mnog0P3_koL0103gknL0mnog
0?Ogm`3_knL20?O_m`0:0>o_i`3gmoL0moOg0?Ogm`3gkoL0moOg0?O_m`3_g/h0klje0?O>]@@0klje
00@0kljm0?OWgP3_imh0klJ]0P3_c[D20>O6]@050>O6[@3W_JD0ikfU0>o6Y@3WaZd00P3_aZd30>Nm
Y@030>o6Y@3W_JD0ikFL0080kkfL00<0ikfL0>o6Y@3_aZD00P3_aZD01@3_aZd0klJU0>o6[@3_aZd0
kkFL0080ikFL0P3__I`0103W]I`0klJU0>NmY@3_aZD60>o6[@050?O6]@3gc[D0mlje0>o6[@3_c[d0
103_c[D0203gc[D0klje0?O>]@3_c[D0kljm0>o>]@3_a[D0klje103_a[D01@3_aZd0klj]0>o6[@3_
aZd0kljm0080mnoW00<0ikfU0>N]W03_aZd00P3_c[D00`3_cZd0klJe0>o>[@020>o>[@@0mlje00<0
klje0?O>]@3_c[d00P3_c[d30>oFaP050>o>_@3Wa[D0g/Je0>NmW03We/h00P3_imh01`3gknL0ilJ]
0>OFcP3WaZd0kljm0>oWi`3W_JD00P3We/h30?O_m`030>o_i`3oool0oooo02<0oooo00<0l?3`0?Og
m`3gmoL00P3gmoL00`3_knl0moOg0>o_k`020??cl`030?Ogm`3_knl0moOg0080moOg00<0l?3`0?Og
m`3gmoL00P3gmoL01P3alO40g=cL0=cLg03Lg=`0g]kN0=cLg080g]kN00@0lO7a0=_Kf`3AdM40dM7A
0P3Fe]H00`3De=@0c/k>0<g=c@020<O7a`<0a/K600<0alO70<71`@2i^KT00`31`L420<K6aP030<71
`@3?cll0d=3@00@0eMGE0P3Hf=P20<o?c`050<;2`P39bLT0a/K60<W9b@32`/800P36a/H01037alL0
a<C40<o?c`3?cll20=3@d0030=GEe@3@d=00d=3@00@0d=3@00<0dM7A0=3@d03@d=000`3EeMD30=7A
d@H0d=3@00H0cLg=0=3@d03@d=00cLg=0=cLg03alO420>CTi0070<g=c@3@d=00d=3@0=3@d03?cll0
eMGE0=?Cd`030=SHf0050=GEe@3Hf=P0eMGE0=kNgP3Fe]H0103Lg=`01P3>c/h0cLg=0;Zj^P2d];@0
alO70>[ZjP80h>3P00@0kno_0<k>cP3De=@0eMGE0P3De=@01`35aLD0j^[Z0>[ZjP3clo<0lO7a0?Og
m`3`l?009`3oool002D0oooo00@0knog0?Ogm`3gmoL0moOg0P3_knL01P3gmoL0knoW0?O_m`3gkoL0
moOg0>o_i`<0moOg00<0knog0?Ogm`3gmoL00P3gmoL00`3gknL0kmK60>oFaP020?OF_@060>oFaP3g
e[d0mmJm0?O_i`3We]H0klJe0`3_c[d00`3Wc[d0ilJe0>O6[@020>NmY@80ikfL00@0ikfU0>NeU03W
]I@0gZfD0`3W]I@00`3W_I`0ikFD0>o6Y@020>o6[@@0klj]00@0mlje0>o6Y@3_aZD0ikFL0P3__I`0
1P3W_I`0kkfL0>NeW03W_I`0ikfU0>neW0<0klJU0P3_aZd00`3_cZd0klJ]0>o6[@030>o6[@80klJe
0P3_aZd20>o>]@<0klJe1P3_aZd0103WaZd0klJ]0>o6[@3WaZd20>oFaP030?O_i`3gg/h0ilJ]00<0
klJ]00@0klJU0>o>[@3ga[D0mlJe0P3gc[D01@3_c[D0mlje0>o>]@3ge[d0kljm00@0kmK600H0ilJe
0>O6[@3N[I`0cZfD0>NmY@3_inL20>ONeP040>o_i`3Wa[D0iljm0>o>]@80iljm00L0ikfD0>oWi`3_
inL0mnog0?O_i`3gmoL0knog02D0oooo00<0l?3`0?7al@3clo<00`3clo<00`3gmoL0lo?c0?Ogm`02
0?3`l0060>o_k`3`l?00l?3`0?3`l03gmoL0lo?c0`3gmoL0103clo<0l?3`0?3`l03UiND30>CTi080
h^;R00L0lO7a0=cLg03Lg=`0WYjN0=KFeP3AdM40d=3@00D0alO700<0a/K60;Vi^@2i^KT01`31`L40
0`37alL0clo?0=3@d0030=GEe@80f=SH0P3@d=001@34a<@0`/;20<71`@31`L40`/;20080alO700@0
`/;20<71`@31`L40`/;20`37alL20<o?c`80alO700D0bLW90<O7a`3?cll0alO70<o?c`020<g=c@04
0<O7a`3=cLd0clo?0<o?c`P0alO700@0clo?0<O7a`37alL0fm_K0P3[jn/00`3>c/h0cLg=0<o?c`04
0=3@d080eMGE00<0f=SH0=GEe@3EeMD00P3Ng]h40=KFeP070<g=c@37alL0ZZZZ0;Fe]@2d];@0cLg=
0=_Kf`020<g=c@070;Rh^037alL0clo?0<G5a@3Kfm/0c/k>0<K6aP020>WYj@040??cl`3_knl0lO7a
0?3`l2L0oooo000U0?ooo`030>o_m`3gknL0mnog00<0mnog00<0moOg0?O_m`3gmoL00P3_koL01P3_
knL0knog0>o_m`3_koL0moOg0?O_m`<0moOg00<0mnog0>o_m`3gg]H0103gg/h20>oNcP030?O_i`3_
e/H0_IAk0080kljm00<0klJe0>o6[@3W_JD00`3W_JD0103W_I`0gZfD0=j]U03N[I@60>NeU0040>Nm
Y@3_aZD0klJU0>o6[@<0klj]00@0mlje0>o6[@3_aZd0kkFL0P3W]I`20>NeU0030>NeW03W_JD0ikFL
0080ikFD0P3W]I`30>NmY@050>o6Y@3W_JD0ikfU0>nmW03W_JD00P3_aZD01@3W_JD0klJU0>O6[@3W
_JD0ilJ]0080klJU203W_JD02@3_aZD0ikfU0>NmY@3W_JD0imKF0?OWgP3Wa[D0ilJ]0>o6Y@050>o6
[@040>o>]@3gc[D0klje0>o>]@80mmJm103_c[d01`3WaZd0ikfU0=JLN`3F[H@0cZfD0>O6[@3We/h0
0P3WaZd01`3N[H`0ikfU0>o6Y@3W_I@0imK>0>O6]@3W_I`00P3_imh0103gkoL0knoW0?O_i`3_koLU
0?ooo`030?3`l03gmoL0l?3`00@0moOg00D0l?3`0?7al@3clo<0lo?c0?Ogm`020??cl`040?3`l03_
knl0moOg0??cl`80moOg00D0l?3`0?Ogm`3gmoL0l?3`0?Ogm`020??cl`80moOg0`3clo<01@3alO40
`l?30<g=c@3@d=00cLg=00@0alO700<0`/;20<K6aP2m_Kd00P36a/H02039bLT0clo?0<o?c`3?cll0
bLW90<71`@39bLT0clo?1@3EeMD01`3Hf=P0eMGE0<o?c`33`l<0bLW90<o?c`34a<@00`39bLT20<O7
a`80`L7100H0^;Rh0;Vi^@2h^;P0^;Rh0;>c/`2i^KT30;Rh^0040;>c/`2h^;P0^;Rh0;Rh^0L0^KVi
0P36a/H01`32`/80a/K60<K6aP36a/H0`/;20<71`@36a/H00P2i^KT20=GEe@030;Jf]P2MWId0^KVi
0080alO7103@d=001@3EeMD0e]KF0=KFeP3Lg=`0e]KF0080c/k>00@0X:2P0:VYZ@2h^;P0^k^k0P2h
^;P02P3>c/h0cLg=0<g=c@37alL0aLG50<K6aP3Ph>00e=CD0<K6aP3Kfm/20>WYj@040?3`l03clo<0
kno_0>o_kbL0oooo000U0?ooo`030>o_m`3gmoL0knog00@0moOg00H0knog0?O_i`3gkoL0mnog0?Og
m`3gkoL20>o_m`030>o_i`3gmoL0mnog0080moOg00<0knog0?Ogm`3_koL00P3gmoL20?O_m`80moOg
0P3gkoL01P3gknL0e[f]0=Jm[@3WaZd0klJ]0>O6[@<0ikfU00@0ikFL0>NmW03F]JD0e[FU0P3W_I`0
1@3__I`0klJU0>o6Y@3__I`0ikFD0080kkfL00<0klJU0>o>[@3_cZd00P3_cZd00`3gc[D0klj]0>o6
Y@020>neU0030>nmW03_aZD0kkFL0080kkfL0P3W_JD30>NeU0050=j]S03N[I@0gZf<0=jUQ03N[I@0
103N[H`00`3NYH@0gZf<0=j]S0080=j]U0030>NmW03W]I`0ikfL0080ikfL00D0ikFL0>NeU03W]I@0
ikfL0=j]U0020>O>aP030=J]S03NQ7<0gZfD00<0ikfU0`3_aZd0103_c[D0kljm0>o>_@3_e/H20>o>
_@050>O6]@3>U6<0eYac0=j]S03>]JD00P3N[H`02P3Wa[D0ilJ]0>O6[@3W_JD0ikfD0>NmW03Wg]H0
iljm0>NmW03We]H20>oWgP040>o_m`3gkoL0knoW0>o_ibD0oooo00<0moOg0??cl`3gmoL00P3alO43
0?Ogm`80lo?c00<0kno_0?7al@3`l?000P3`l?001P3alO40moOg0?3`l03_knl0moOg0?3`l080moOg
00D0lo?c0?Ogm`3clo<0l?3`0?Ogm`020??cl`80lO7a00L0moOg0?3`l036a/H0ZZZZ0=[JfP37alL0
^[Zj00<0alO700H0a/K60;fm_@2m_Kd0^KVi0<71`@36a/H30<W9b@060<71`@36a/H0clo?0<o?c`3H
f=P0eMGE0P3Hf=P00`3EeMD0d=3@0=3@d0040<W9b@80clo?00H0bLW90<o?c`3?cll0clo?0<W9b@3?
cll30<W9b@030<K6aP32`/80a/K600<0`/;200L0a/K60<;2`P32`/80`/;20<W9b@36a/H0bLW90080
alO70`3?cll01P32`/80clo?0<o?c`3?cll0alO70<o?c`<0alO700L0bLW90=7Ad@3De=@0eMGE0<O7
a`1WIfL0`/;20080^[Zj00H0alO70<g=c@3=cLd0c/k>0;Jf]P2CTi<308b<S00709ZJVP2h^;P0aLG5
0<O7a`2h^;P0aLG50<K6aP020<O7a`070=CDe03=cLd0^;Rh0=cLg03Jf]X0^;Rh0>;RhP020>3Ph004
0?7al@3clo<0moOg0?3`l2L0oooo000U0?ooo`040?Ogm`3gkoL0moOg0?O_i`@0moOg0P3gkoL00`3_
knL0mnoW0>o_m`020>o_m`080?O_i`3gmoL0knog0>o_i`3gmoL0knog0?Ogm`3gkoL20?Ogm`030?O_
m`3_koL0moOg0080mnog00T0mnoW0?Ogm`3_koL0knog0>NmW03FW7/0imK60>NmY@3N[I`00P3W_JD0
1`3W_I`0e[FU0=JeY@3F]JD0gZfD0>NeU03W_I`00P3__I`00`3W]I@0ikfL0>NmW0020>o6Y@040?O>
]@3_cZd0mlje0>o>[@80klJ]1@3__I`00`3_aZD0kkfL0>o6Y@030>o6Y@070>nmW03_aZD0kkfL0>nm
W03W_I`0ikFL0>NmW0040>NeW0060>NmW03W]I`0ikFL0>nmW03W_I`0kkfL0`3W_JD20>o6Y@050>Ne
W03_aZD0klJU0>o6Y@3W_JD00P3_aZD20>NmY@060>nmW03_a[D0iljm0>O>aP3W_JD0U5Xa0P3W]I`0
1`3N[I`0ikfU0>O6[@3WaZd0ilJe0=J]S036Q5X00`36NdX01`3>S5X0gZf<0>NmU03W_JD0gZf<0>Nm
U03W_I`00P3W_JD01`3Wc[d0ilJ]0=j]S03_e/H0imK60=j]S03_g/h00P3Wg]H0103gknL0mnog0?Og
m`3_koLU0?ooo`030>o_k`3`l?00moOg0080l?3`00<0lo?c0>o_k`3`l?000P3clo<0103gmoL0kno_
0??cl`3clo<20?Ogm`<0lo?c00L0moOg0??cl`3gmoL0moOg0??cl`3gmoL0l?3`0080lo?c00@0l?3`
0?Ogm`3`l?00l?3`0P3clo<01@36a/H0ZJVY0;Vi^@2d];@0^[Zj00D0a/K600@0alO70;fm_@31`L40
a/K60`39bLT01P31`L40aLG50<o?c`3@d=00clo?0=3@d0D0eMGE00<0clo?0<W9b@39bLT0203?cll0
0`39bLT0a<C40<o?c`040<o?c`040<O7a`36a/H0bLW90<W9b@<0clo?0`39bLT00`37alL0clo?0<o?
c`040<o?c`030<W9b@3?cll0bLW90080clo?0P3@d=001`3?cll0alO70=3@d03?cll0e=CD0=7Ad@3K
fm/00P2f][H209jNWP050;2`/02FUYH0S8b<09ZJVP2<S8`00P2CTi<20:VYZ@040<G5a@2i^KT0]KFe
0>WYj@<0aLG500L0c<c<0;:b/P3Fe]H0h^;R0<K6aP3Ph>00c/k>0080kno_00@0j^[Z0>o_k`3_knl0
moOg9`3oool002D0oooo00@0knoW0>o_m`3gmoL0knog0P3gkoL01`3_knL0knog0?O_m`3gkoL0moOg
0>o_i`3gkoL00`3gmoL30?O_m`040?Ogm`3gkoL0moOg0?O_m`80moOg00H0knog0?O_m`3gkoL0knog
0?Ogm`3_koL30?O_m`050>NmW03FW7<0gZfD0<j]U03N[I`01@3W_I`0103W_JD0e[FU0>NeU03W_I`2
0>nmW0070>NeU03W_I@0ikfD0>o6Y@3_aZd0klJU0>o6[@040>o>[@80klJU0P3__I`80>o6Y@030>nm
W03_]I`0klJU00<0klJU00<0ikfU0>NmW03W_I`00P3__I`20>o6Y@<0kkfL00<0ikfU0>o6Y@3_aZD0
103_aZD00`3__I`0klJU0>nmW0030>o6Y@070>o6[@3_aZD0ikfU0>o6[@3_aZD0iljm0=k>_@020>OF
eP070=J]S02mU7/0_IAk0=JUQ02mS6<0aW]:0<j<FP020<IkBP070<J4FP3FW7<0eYac0>NmU03N[I@0
eZf40>oWgP030>NmU0070=k6]@3NYG/0kljm0>oNcP3W_I`0imkF0>O6]@020>o_i`040>oWi`3_knL0
knoW0?OgmbD0oooo00<0moOg0?3`l03alO400P3gmoL0103`l?00moOg0?Ogm`3_knl20?7al@070?Og
m`3clo<0lo?c0?Ogm`3`l?00moOg0?3`l0020??cl`030?Ogm`3`l?00l?3`00@0moOg0P3`l?030>o_
k`050??cl`3_knl0c/k>0<g=c@2PX:000P2e]KD20:6QX@070<K6aP37alL0`/;20<K6aP2j^[X0aLG5
0<K6aP020<71`@030<W9b@35aLD0aLG500<0clo?0`3@d=000`3EeMD0clo?0=GEe@020<o?c`80bLW9
2@3?cll20<C4a080bLW90`3?cll01P36a/H0bLW90<O7a`37alL0a<C40<W9b@80clo?00<0a<C40<o?
c`3?cll00`3?cll20<W9b@040<o?c`37alL0clo?0<K6aPD0clo?0`37alL02P3De=@0eMGE0=GEe@3E
eMD0`l?307AdM01iNGT0Ti>C08b<S02CTi<30:2PX0060:6QX@2PX:00];Bd0;fm_@3Ph>00ZJVY0P2g
]kL01`3=cLd0/[:b0<k>cP3Jf]X0aLG50>o_k`3YjNT00`3_knl20?3`l0030?Ogm`3oool0oooo02D0
oooo000U0?ooo`040?Ogm`3_koL0mnoW0?Ogm`80knog0P3gmoL01@3_knL0mnoW0?O_i`3gmoL0mnog
0080moOg00<0knog0?Ogm`3_koL00P3gkoL00`3gmoL0knog0?Ogm`040?Ogm`80knog0P3_knL01P3g
koL0knoW0>o_i`3Wa[D0ilJ]0<jDH`80eZf400<0cYA[0>NmW03W_JD00P3W]I`01P3W_I`0gZfL0>Nm
U03W_I`0ikFD0>nmW0<0ikfD0`3_aZD20>o6[@030>o>[@3_aZD0klj]00<0klJU0P3__I`90>o6Y@03
0>neW03__I`0kkfL00@0klJU00D0ikfL0>nmW03W_JD0kkFL0>nmW0020>o6Y@030>neW03_aZD0klJU
00<0klJU0P3__I`01@3_aZD0ikfU0>o6Y@3_aZD0ikfL00@0klJU0`3W_JD20>O>_@80ilk600D0e[f]
0:eS<@2]JcT0aXAJ0<IkBP020<J4FP80cYAS00H0cYA[0<jDH`3>[I@0e[FU0>ONeP3FW7<20=j]Q007
0>O6[@3NYG/0ilJe0>OFaP3W_I@0knoW0>oWgP030>o_i`80knog00<0moOg0?ooo`3oool08`3oool0
0`3gmoL0l?3`0?7al@020?Ogm`040?3`l03gmoL0moOg0>o_k`80lO7a00L0moOg0??cl`3clo<0moOg
0?3`l03gmoL0l?3`0080lo?c00<0moOg0?3`l03`l?00103gmoL20?3`l0<0kno_00D0lo?c0>o_k`3>
c/h0cLg=0:2PX0020;Fe]@80XJ6Q00L0a/K60<O7a`32`/80a/K60;Zj^P35aLD0a/K60080`L7100<0
bLW90<G5a@35aLD00`3?cll30=3@d0030=GEe@3?cll0eMGE0080clo?0P39bLT90<o?c`80a<C40P39
bLT30<o?c`060<K6aP39bLT0alO70<O7a`34a<@0bLW90P3?cll00`34a<@0clo?0<o?c`030<o?c`80
bLW900@0clo?0<O7a`3?cll0a/K61@3?cll30<O7a`0:0=CDe03EeMD0eMGE0=GEe@33`l<0M7Ad07Ui
N@2CTi<0S8b<09>CT`<0X:2P00H0XJ6Q0:2PX02d];@0_Kfm0>3Ph02YZJT20;Ng]`070<g=c@2b/[80
c/k>0=[JfP35aLD0kno_0>WYj@030>o_k`80l?3`00<0moOg0?ooo`3oool09@3oool002D0oooo00<0
knog0?Ogm`3gmoL00`3_koL00`3gmoL0mnoW0?Ogm`020?Ogm`060>o_m`3gmoL0moOg0?Ogm`3gkoL0
mnoW103gmoL00`3gknL0mnog0?Ogm`020?Ogm`040?O_m`3_koL0knog0?O_m`@0knog00P0ilk60>O6
]@3F[H`0cYAS0=J]Q036Nd80[F/i0=j]W080ikfL0P3W]I`01@3W_I`0ikFL0>NmW03_]I@0ikFD0080
ikfL1@3_aZD00`3_cZd0klJU0>o6Y@080>o6Y@030>o6[@3_aZD0klJU00<0klJU0`3__I`01`3_aZD0
kkfL0>nmW03__I`0klJU0>NmW03_]I`00`3__I`01@3W_I`0ikfU0>o6Y@3_aZD0klJ]0080klJU00<0
kkFL0>o6Y@3_aZD0103__I`20>o6Y@<0ikfU00/0ikfL0=j]U03FYH@0eZF40=JLN`36NdX0]F]20<Ik
BP36Nd80]G]J0<Ik@P020<jDH`030<j<FP3>U6<0cYA[0080gZf400<0gZf<0>O6[@3NYG/00P3N[H@0
1`3W_I@0gZf40>OFaP3WaZd0iljm0>oWgP3_knL00P3gkoL0103_imh0moOg0?Ogm`3gkoLU0?ooo`03
0?3`l03gmoL0moOg00<0l?3`00<0moOg0?7al@3gmoL00P3gmoL01P3`l?00moOg0?Ogm`3gmoL0lo?c
0?7al@@0moOg0P3alO40103clo<0moOg0?Ogm`3clo<20?3`l0030??cl`3`l?00l?3`0080l?3`00D0
eMGE0<k>cP2f][H0X:2P0;Fe]@0208^;R`0307UiN@2j^[X0a/K60080`/;200L0a/K60<;2`P36a/H0
a/K60<?3``31`L40a/K600H0clo?00<0eMGE0<o?c`3?cll0203?cll00`3@d=00clo?0<o?c`020<o?
c`@0bLW900D0clo?0<W9b@39bLT0clo?0<K6aP020<C4a0<0bLW900@0a/K60<O7a`3?cll0d=3@0`3?
cll00`34a<@0clo?0<o?c`030<W9b@<0clo?0`37alL00`36a/H0^KVi0;2`/0020:ZZZP0708b<S01m
OGd0S8b<08^;R`29RHT0Rh^;0:2PX00209ZJVP070:2PX02QXJ40]kNg0;Ng]`2h^;P0cLg=0;:b/P02
0;Ng]`070<G5a@2g]kL0f][J0<g=c@3De=@0jNWY0>o_k`020??cl`040>WYj@3gmoL0moOg0??clbL0
oooo000U0?ooo`040?Ogm`3gkoL0knog0?O_m`80mnoW00L0moOg0>o_m`3gmoL0knoW0?Ogm`3_koL0
moOg0080mnoW00<0moOg0>o_m`3gmoL00P3gmoL00`3_koL0mnog0?Ogm`020?Ogm`070>o_m`3gmoL0
mnoW0>o_i`3_koL0moOg0?O_i`020>o_m`080>oNcP3_imh0imK60<j<FP3>U6<0aW]20;E[>@2DDRT2
0>NeW0070=j]W03W_I`0gZfD0=j]W03W]I`0ikfL0>NmU0020>NmW0D0klJU00<0klJ]0>o6Y@3_aZD0
103_aZD40>nmW0030>o6Y@3__I`0kkfL00<0klJU1@3__I`40>NmW0@0kkfL00H0ikfL0>nmW03__I`0
kkfL0>o6Y@3W_I`20>nmW080klJU00<0kkfL0>NmW03W_I`00`3__I`01@3W]I@0ikfL0=j]U03N[H`0
eYak0080cYAS00<0]G=:0;E[@P36NdX00P3>S5X01036U6/0aXAJ0<Ik@P36Nd820<jDH`060=jUL`3N
[H`0gZf40>NmW03N[H`0eYac0`3N[H@30>O6[@030>OFaP3gkoL0knoW00<0mnoW0P3gkoL00`3_knL0
oooo0?ooo`0S0?ooo`030?Ogm`3clo<0l?3`0080lo?c00L0lO7a0?Ogm`3`l?00moOg0>o_k`3gmoL0
l?3`0080moOg00<0lO7a0?Ogm`3`l?000`3gmoL00`3`l?00lo?c0??cl`020?Ogm`050?3`l03gmoL0
lO7a0>o_k`3`l?000P3gmoL01`3alO40l?3`0>;RhP3YjNT0f][J09ZJVP2PX:000P2;Rh/01`1lO7`0
HF5Q0<;2`P2j^[X0a/K60;Vi^@2j^[X00P32`/800`36a/H0aLG50<K6aP060<o?c`030=3@d03?cll0
clo?00<0clo?1@39bLT00`3?cll0bLW90<o?c`020<o?c`H0bLW90`36a/H50<W9b@040<K6aP39bLT0
bLW90<o?c`80a/K60P39bLT20<o?c`030<W9b@36a/H0bLW900<0bLW900H0`L710<K6aP2i^KT0^;Rh
0:ZZZP2PX:0208:2PP0707emO@2<S8`0VYZJ09ZJVP2OWil0Ti>C08^;R`030:2PX0060;6a/@2h^;P0
]kNg0<K6aP2h^;P0ZJVY0`2g]kL30<g=c@030=[JfP3clo<0kno_00<0lO7a0P3clo<00`3_knl0oooo
0?ooo`0U0?ooo`009@3oool0103gmoL0mnog0>o_m`3gkoL20?O_i`070?Ogm`3_koL0moOg0>o_i`3g
moL0knog0?Ogm`020?O_i`030?Ogm`3_koL0moOg0080moOg00<0knog0?O_m`3gmoL00P3gmoL01`3_
koL0moOg0?O_i`3_knL0knog0?Ogm`3gknL00P3_koL0203_g/h0knON0>OFaP3>S5X0cYAS0<Ik@P2e
JcT0U58Y0P3W]I`01`3N[I`0ikfL0=j]U03N[I`0ikFL0>NmW03W_I@00P3W_I`50>o6Y@030>o6[@3_
aZD0klJU00@0klJU103__I`00`3_aZD0kkfL0>nmW0030>o6Y@D0kkfL103W_I`40>nmW0060>NmW03_
_I`0kkfL0>nmW03_aZD0ikfL0P3__I`20>o6Y@030>nmW03W_I`0ikfL00<0kkfL00D0ikFD0>NmW03N
[I@0gZf<0=JLN`020<jDH`030;EcBP2eJd80aW]:0080cXaJ00@0aYA[0<J4FP36Nd80aW]20P3>U6<0
1P3NYG<0gZf<0=j]Q03W_I`0gZf<0=JLL`<0gZf40`3WaZd00`3We/H0mnog0>o_i`030?O_i`80mnog
00<0knoW0?ooo`3oool08`3oool00`3`l?00lo?c0?Ogm`020??cl`070>o_k`3gmoL0moOg0?Ogm`3a
lO40moOg0??cl`020?3`l0070?Ogm`3`l?00moOg0?Ogm`3alO40l?3`0??cl`020?3`l0060?Ogm`3_
knl0moOg0??cl`3alO40moOg0`3clo<01`3_knl0lO7a0=_Kf`3alO40cLg=09ZJVP2<S8`00P2;Rh/0
1`1fMWH0HF5Q04U9B@2c/k<0^;Rh0;Vi^@36a/H00P32`/801036a/H0`L710<G5a@37alL50<o?c`03
0<W9b@3?cll0clo?00H0clo?00<0bLW90<o?c`39bLT00P39bLT50<o?c`80`l?31039bLT20<C4a007
0<W9b@36a/H0`l?30<G5a@36a/H0a<C40<o?c`020<W9b@030<o?c`39bLT0a/K60080clo?0P39bLT2
0<K6aP80`L7100D0^;Rh0;Ng]`2YZJT0ZJVY08b<S00207UiN@0709>CT`2JVYX0S8b<09ZJVP2ZZZX0
VYZJ09>CT`0209ZJVP060;6a/@2PX:00]KFe0:VYZ@2d];@0/[:b1035aLD00`3Rh^80^;Rh0<k>cP02
0>o_k`070??cl`3[jn/0jn_[0?3`l03_knl0moOg0??cl`0W0?ooo`009@3oool0103_koL0mnog0?Og
m`3gkoL20>o_i`<0moOg00@0mnoW0?Ogm`3gkoL0knog0P3gmoL0203_koL0moOg0?Ogm`3gknL0knog
0?O_m`3_koL0moOg0P3_knL0103gmoL0mnog0?O_i`3gmoL20?O_m`0;0>o_i`3gknL0mnoW0>OFcP3g
knL0ilJ]0<j<FP36NdX0aW]20;ES<@2DDRT00P1k>AP01`3NYH@0gZf<0=j]U03W_I`0ikFL0>NmW03W
]I@00P3W_I@00`3W_JD0klJU0>o6Y@020>o6Y@030>nmW03_aZD0klJU00H0klJU00<0kkfL0>o6Y@3_
_I`00`3__I`40>o6Y@80kkFD1@3__I`01P3_]I`0kkfL0>NmW03_]I@0ikfD0>NmW080kkFL00D0klJU
0>nmW03_aZD0kkfL0>NmW0020>o6Y@<0kkfL00D0ikfL0>NeU03W]I@0gZf<0=j]Q0020=JLL`80aW]:
00L0[F/i0<J4FP3>S5X0aW]:0<j<FP3FW7/0cXaJ0080aXAJ00L0cXaJ0=jUL`3>U6<0eZf40=JLL`3>
[I@0gZEk00@0ikfD00<0kmk>0=j]S03Wa[D00P3_knL01`3gkoL0mnON0?OWgP3_koL0knoW0?Ogm`3g
koL09@3oool00`3alO40l?3`0?3`l0020?7al@050?3`l03gmoL0kno_0?7al@3_knl0103gmoL01`3a
lO40moOg0?7al@3alO40moOg0?3`l03gmoL00P3clo<01`3`l?00moOg0?3`l03alO40moOg0?7al@3g
moL00P3clo<01`3alO40kno_0>;RhP3YjNT0c/k>0<?3``2;Rh/00P2CTi<0101lO7`0HF5Q04U9B@19
BDT20;Vi^@060<71`@2i^KT0^KVi0<K6aP35aLD0`L711`3?cll20<W9b@80clo?1@39bLT00`33`l<0
a/K60<W9b@030<o?c`@0bLW900@0a/K60<?3``35aLD0`L711039bLT01@33`l<0a/K60;^k^`36a/H0
aLG500L0bLW900<0aLG50;Ng]`2g]kL00P2b/[840:VYZ@0309>CT`1_Kfl0HF5Q0080S8b<00H0ZJVY
0:2PX01jNWX0VYZJ0:6QX@2e]KD30;6a/@80VYZJ00@0X:2P0:VYZ@2h^;P0/[:b0`35aLD01`3YjNT0
a/K60<g=c@3Lg=`0j^[Z0>WYj@3Zj^X00`3alO400`3`l?00moOg0??cl`0W0?ooo`009@3oool0103g
knL0knog0>o_m`3gknL20>o_m`040?Ogm`3_knL0mnoW0>o_i`<0moOg0P3gknL0203gmoL0mnoW0?O_
i`3gmoL0knog0?Ogm`3gkoL0knog0P3gmoL01`3_koL0mnoW0?Ogm`3gknL0moOg0?O_m`3gknL00P3_
knL0203_g/h0knON0>O6]@3F_Jd0aW]20<J4FP2eJcT0U58Y0`1k>AP20=j]U0040>NeU03N[I@0ikfL
0>NmU080ikFD1P3_aZD20>nmW0<0klJU103__I`0103_]I@0ikfL0>nmW03__I`30>o6Y@<0kkfL00D0
ikfL0>neU03W_I@0ikfD0>NeU0030>nmW0040>neU03W_I`0ijf<0>NmW080ikfD1P3__I`01@3W_I@0
gZf40=j]Q03N[H@0gZEk00@0eYac00/0aXAJ09aS>@2DDRT0U58Y0<IkBP3FW7<0cYAS0:e[@P3>S5X0
cYA[0=J]Q0030=jUL`80cXaJ00@0cYAS0=JLL`3N[H`0gZEk0`3W_I@01`3_imh0ikfL0>O6[@3_e/H0
knOW0>oWgP3_inL00`3gknL00`3_koL0moOg0?O_m`0U0?ooo`030>o_k`3gmoL0lo?c0080l?3`00D0
moOg0?3`l03`l?00lo?c0?Ogm`020??cl`80moOg00<0lo?c0?Ogm`3clo<00P3gmoL0103clo<0moOg
0??cl`3clo<20?7al@050?Ogm`3clo<0l?3`0>o_k`3clo<00P3alO400`3clo<0kno_0?7al@020>3P
h00;0;Fe]@2CTi<0S8b<08b<S01dM7@0HF5Q05ADE019BDT0?clo0;Rh^032`/800P2d];@01@35aLD0
`L710<G5a@39bLT0clo?00D0bLW900@0clo?0<W9b@39bLT0clo?0P39bLT20<o?c`80bLW900D0`l?3
0<G5a@39bLT0bLW90<K6aP020<o?c`040<W9b@33`l<0`L710<?3``D0`L7100<0aLG50<71`@31`L40
0`2k^k/02@33`l<0bLW90<W9b@2k^k/0bLW90;Ng]`35aLD0`L710;^k^`030;:b/P070:VYZ@2QXJ40
Ti>C08:2PP1QHF40KVi^07AdM00209>CT`80X:2P00@0VIVI0:VYZ@2YZJT0/K6a0`2YZJT00`2a/K40
VYZJ0:2PX0020;:b/P0;0;Ng]`35aLD0alO70<O7a`36a/H0cLg=0=[JfP3YjNT0j^[Z0>3Ph03Zj^X0
0`3clo<00`3`l?00moOg0?Ogm`0W0?ooo`009@3oool0103_knL0moOg0?O_m`3_koL20?Ogm`80knog
00D0mnog0?Ogm`3gkoL0mnog0?Ogm`020?O_m`070?Ogm`3gkoL0moOg0?Ogm`3gkoL0moOg0?O_m`03
0?O_i`070?Ogm`3gkoL0knog0>o_i`3gkoL0mnoW0?O_m`020>o_i`080?O_i`3Wg]H0imkF0=J]Q036
Q5X0aW]:0:eS<@2DDRT208a28@0707/i601[<AP0gZf<0>NeW03>[I@0ikfD0>NeU0020>NmU0030>nm
W03_aZD0kkfL00<0kkfL00D0klJU0>nmW03__I`0kkfL0>o6Y@020>nmW0040>o6Y@3__I`0kkfL0>ne
U080ikfD0P3__I`01P3W_I`0klJU0>nmW03_]I@0ikFD0>neU0D0ikFD00<0ikfD0>NeU03W]I@0103W
[H`01`3_]I@0kkfL0>N]S03__I`0gZf40>NmU03W]I@00P3W[H`20=jUN`060=JLL`3>U6/0aXAJ0;Ec
BP2DDRT0[EXa0P2]Hc401036Q5X0cYAS0<jDH`36S6<20=JLL`070=jUL`3FW7<0eYac0=JLL`3NYG<0
cXaJ0<jDH`020=jUN`0;0=j]Q03W_I@0ikfU0>NmY@3W_I`0ilJ]0>OFaP3_imh0knOW0>ONeP3_inL0
0`3gkoL00`3_koL0moOg0?Ogm`0U0?ooo`030?7al@3_knl0moOg00<0moOg00H0kno_0?Ogm`3gmoL0
moOg0?7al@3`l?020?Ogm`040?7al@3clo<0kno_0??cl`80l?3`103gmoL20??cl`040?Ogm`3`l?00
l?3`0?7al@80lo?c00L0lO7a0>[ZjP3YjNT0e=CD0>;RhP2JVYX0Ti>C0080Rh^;00L0KVi^065QH@1Q
HF40E5AD03lo?`0U9BD0/;2`0080^[Zj00D0^KVi0<71`@31`L40alO70<K6aP050<W9b@030<o?c`39
bLT0clo?00D0bLW900<0a/K60<W9b@39bLT00P33`l<00`35aLD0`l?30<W9b@020<W9b@060<K6aP35
aLD0`l?30<71`@33`l<0^k^k0P2g]kL01`2k^k/0`l?30;^k^`2k^k/0`l?30;^k^`35aLD00P31`L40
0`2k^k/0]kNg0<71`@020;Rh^00;0;Ng]`2b/[80ZZZZ0:ZZZP2KVi/0PX:207UiN@1dM7@0Kfm_07Yj
NP2FUYH00P2QXJ401@2JVYX0VIVI0:2PX02YZJT0X:2P0080Ti>C0P2PX:001P2JVYX0/K6a0;:b/P2b
/[80/K6a0<G5a@<0alO700L0cLg=0>WYj@3YjNT0h^;R0>[ZjP3clo<0lO7a00H0moOg9`3oool002D0
oooo00<0mnoW0>o_i`3gmoL00`3gmoL01`3_knL0moOg0?Ogm`3gmoL0mnoW0>o_m`3gmoL00P3gknL0
0`3gkoL0knoW0?O_m`020>o_m`<0moOg0`3gkoL01P3gmoL0knog0>o_m`3gknL0mnog0?O_i`80knOW
00L0knON0>O>_@3_g/h0cXaJ0<J4FP36Nd80[EXa00<0U58Y00H0S48Q06/a601:60P0eZF40=j]W03N
[I@30>NeU0030>NmY@3W_I`0kkfL00<0kkfL00@0klJU0>nmW03_aZD0klJU103__I`00`3W_I`0kkfL
0>nmW0030>neU0070>NmU03_]I@0kkfL0>nmW03W_I`0ikfD0>neU0020>NeU0050>neU03W[H`0gZf4
0>N]S03_]I@00P3W[H`0203_]I@0ijf<0>N]S03W_I@0ikFD0>N]S03N[H@0ikFD0P3N[H`20=j]Q008
0=jUN`3FW7/0cXaS0;EcBP2]JcT0[F<a09aS>@2]Jd820;f<H`060<jDJ`3>S5X0aXaS0<jDH`3FW7<0
cYAS0`36Q5X00`3>U6<0cXaJ0=jUL`020=jUN`030=jUL`3W_I@0ikfU0080ikfU00L0ilJ]0>oWgP3_
imh0kmk>0>oWi`3gkoL0mnoW00H0moOg9@3oool00`3_knl0moOg0??cl`040?Ogm`050?7al@3clo<0
moOg0?Ogm`3clo<00P3`l?000`3_knl0lo?c0?Ogm`030?Ogm`030??cl`3`l?00l?3`00<0lo?c00@0
moOg0??cl`3clo<0lo?c0P3`l?001`3alO40lo?c0>[ZjP3Jf]X0h>3P0:2PX02CTi<00P2<S8`0101d
M7@0HF5Q065QH@1DE5@203Lg=`0602DU9@2i^KT0^KVi0;Vi^@36a/H0`/;20P36a/H60<W9b@80clo?
2039bLT20<G5a@060<W9b@33`l<0a/K60<K6aP33`l<0a<C41031`L450;^k^`050;Ng]`2b/[80]kNg
0;^k^`2g]kL00P36a/H01`2b/[80^;Rh0;Ng]`2g]kL0ZZZZ0;>c/`2YZJT00P2<S8`01`1^KVh0NGUi
059BDP1jNWX0PX:208b<S02PX:000P2JVYX0102IVIT0WinO09VIV@2a/K430:VYZ@<0/K6a00D0/[:b
0;Ng]`2e]KD0aLG50<K6aP030<O7a`070=KFeP3Lg=`0h^;R0>WYj@3_knl0lO7a0?Ogm`020??cl`04
0?Ogm`3clo<0l?3`0?OgmbL0oooo000U0?ooo`030>o_i`3gmoL0mnog00@0moOg00H0mnoW0?O_m`3g
moL0moOg0?O_m`3_koL20>o_i`030?O_m`3gmoL0moOg0080moOg00<0mnog0>o_m`3gkoL00`3gkoL0
1P3gmoL0mnog0?O_m`3gkoL0knog0?O_i`80mnog00L0knOW0>OFaP3Wg]H0cYAS0<J4FP36NdX0[F<a
00<0U58Y00@0S48Q06<Y401S:A00BQP80P3N[I@00`3W_I`0ikFL0>NeW0020>NmW0D0kkfL0`3_aZD7
0>nmW0<0ikfD00D0kkfL0>neU03W_I`0kkFD0>neW0050>NeU0@0ijf<00<0gZf40=jUN`3N[H@00P3W
[H`0103N[H@0ikfL0=jUN`3N[H`20=j]Q00;0=JLN`3NYH@0gZF40=JLL`36NdX0[EXa0:e[>@24@R40
[F]20;EcBP36NdX00P3>U6<01@3>S5X0aXaS0<JDJ`36S6<0gZEc00@0eYac0P3NYG<01@3NYG/0gZf4
0=J]Q03W_I@0ikfL00<0ikfU00L0kljm0>oFaP3_g/h0knON0>o_i`3gknL0moOg0080mnog00@0moOg
0?O_m`3_koL0moOg9@3oool20?Ogm`040>o_k`3gmoL0moOg0??cl`<0moOg0P3clo<01P3_knl0lo?c
0??cl`3gmoL0l?3`0>o_k`80lo?c0P3gmoL20?7al@070??cl`3gmoL0l?3`0?3`l03clo<0moOg0??c
l`020?3`l0070?7al@3_knl0jNWY0>3Ph03EeMD0X:2P09>CT`0207emO@0707AdM01_Kfl0HF5Q04U9
B@0g=cL0;Rh^03lo?`030;Vi^@060<71`@36a/H0a/K60<O7a`36a/H0clo?0P39bLT00`3?cll0bLW9
0<W9b@030<W9b@090<?3``39bLT0bLW90<W9b@35aLD0bLW90<?3``36a/H0`l?300<0`L7100<0^k^k
0<71`@31`L400P31`L420;^k^`80]kNg00L0/k>c0;:b/P2b/[80/[:b0;Ng]`36a/H0]kNg0080ZZZZ
00@0ZJVY0:ZZZP2[Zj/0Zj^[0P2KVi/02P2;Rh/0S8b<08b<S01KFe/0KVi^06m_K`1iNGT0Kfm_08b<
S02JVYX309>CT`0609VIV@2YZJT0ZJVY0;Fe]@2h^;P0ZJVY0P2a/K400`35aLD0]KFe0;Ng]`020<G5
a@040<O7a`36a/H0e]KF0=KFeP80g=cL0P3alO420?Ogm`<0lo?c00@0moOg0?3`l03gmoL0moOg9`3o
ool002D0oooo0P3gmoL0103_knL0moOg0?O_m`3gkoL30?Ogm`80mnog00H0knoW0?O_m`3gmoL0moOg
0>o_m`3_knL20?O_m`80moOg00@0mnoW0?O_m`3gmoL0moOg0P3_koL01@3gkoL0moOg0?O_m`3_koL0
mnoW0080knoW00P0knON0>ONeP3Wc/H0cYAS0<J4FP2eJd80[F<a09aS>@80U58Y00@0NcTH06<Y401B
8A00Jc4H0P3N[I@02@3W]I@0ikfL0>NmW03W_I`0ikfU0>NmW03_aZD0kkfL0>o6Y@060>nmW0050>ne
U03__I`0kkfL0>NmU03__I`00P3_]I@01@3W_I`0kkFD0>NeU03W]I@0ijf<00D0ikFD0P3W[H`00`3N
[H@0gZF40=jUN`020=jUN`070=j]Q03W_I`0ikfL0=j]Q03FW7/0eYac0=JLN`020=jLL`<0cXaS00P0
aW]20<IkBP2<BS40[EXa09aS>@2]JcT0W6<i0<IkBP80cXaJ0P36Q5X01@36S6<0eYac0=JLL`3F[H@0
gZf<0080eYac00@0gZEc0>NmU03F[H@0gZf40P3W_I@0103W_JD0ikfL0>o>_@3_c[d20>oFaP80mnoW
0P3gmoL30?O_m`040?Ogm`3_koL0moOg0?OgmbD0oooo0P3gmoL0103_knl0moOg0?Ogm`3clo<30?Og
m`80lo?c00H0kno_0??cl`3clo<0moOg0?3`l03_knl20??cl`80moOg0P3alO401`3clo<0moOg0?3`
l03`l?00lo?c0?Ogm`3clo<00P3`l?001`3alO40kno_0>WYj@3Ph>00eMGE0:2PX02CTi<00P1mOGd0
1`1dM7@0Kfm_065QH@19BDT0=cLg02h^;P0o?cl00`2i^KT01P31`L40a/K60<K6aP37alL0a/K60<o?
c`80bLW900<0clo?0<W9b@39bLT00`39bLT02@33`l<0bLW90<W9b@39bLT0aLG50<W9b@33`l<0a/K6
0<?3``030<71`@030;^k^`31`L40`L710080`L710P2k^k/20;Ng]`070;>c/`2b/[80/[:b0;:b/P2g
]kL0a/K60;Ng]`020:ZZZP040:VYZ@2ZZZX0Zj^[0:^[Z`80Vi^K00X0Rh^;08b<S02<S8`0Fe]K06i^
KP1_Kfl0NGUi06m_K`2<S8`0VYZJ0`2CTi<01P2IVIT0ZJVY0:VYZ@2e]KD0^;Rh0:VYZ@80/K6a00<0
aLG50;Fe]@2g]kL00P35aLD01037alL0a/K60=KFeP3Fe]H20=cLg080lO7a0P3gmoL30??cl`040?Og
m`3`l?00moOg0?OgmbL0oooo000U0?ooo`040?Ogm`3gkoL0mnoW0?O_i`80mnog00H0knog0?Ogm`3g
knL0moOg0?O_i`3_koL30?Ogm`040?O_m`3gmoL0mnoW0?Ogm`<0mnog00@0moOg0>o_m`3_koL0knog
0P3gmoL0103gkoL0moOg0?O_i`3gkoL20>o_i`080?OWgP3We/H0eZf40<jDH`36Q5X0]G=:0:eJ<@2e
JcT209AB:@0708a::@1[<AP0Jc4H07]28@1kBRT0gZfL0>NmU0020>NmW0040>o6Y@3W_I`0ikfL0>o6
Y@L0kkfL00H0ikfL0>nmW03W_I`0ikFD0>neW03__I`20>NmU080kkFD00H0ikfD0>N]S03W_I@0gZf4
0>NeU03W_I@20>NeU080ijf<0P3NYH@0103>U6/0eYac0=j]S03W_I`20=j]S0070<j<H`3>U6/0eYac
0<jDJ`3FW7<0cYA[0<IkBP020<Ik@P040;ES<@2]Hc40aW]:0:e[@P80aW]:00X0_HaS0<jDH`3>U6/0
cYA[0<J<H`3>S5X0aXaS0=JLL`3>S5X0cYA[0`3FW7<00`3NYG/0eYac0=JLL`030>NmU0040>NmW03W
c[d0kmK60>oFaP80knON00@0mnog0?Ogm`3_koL0knoW0`3gmoL20?O_m`030?Ogm`3gkoL0oooo02@0
oooo00<0moOg0??cl`3alO400P3alO401`3clo<0l?3`0?Ogm`3alO40moOg0?7al@3`l?000`3gmoL0
103clo<0moOg0?7al@3gmoL40??cl`030?Ogm`3`l?00l?3`0080moOg00/0lo?c0?Ogm`3alO40lO7a
0??cl`3_knl0jn_[0=[JfP2e]KD0X:2P09>CT`0208:2PP0406i^KP1lO7`0HF5Q05YJFP80?clo00L0
Cdm?05EEE@1EEED0^[Zj0<G5a@36a/H0clo?0080a/K600<0clo?0<W9b@39bLT01@39bLT02036a/H0
bLW90<K6aP36a/H0`L710<C4a039bLT0aLG50P33`l<02035aLD0^k^k0;^k^`35aLD0]kNg0<71`@35
aLD0`L710P2k^k/30;>c/`060:6QX@2YZJT0^;Rh0<K6aP2h^;P0Vi^K0P2QXJ401`2YZJT0XJ6Q0:VY
Z@2QXJ40S8b<08^;R`1fMWH00P1dM7@01`2<S8`0NWYj08b<S02<S8`0UYJF0:2PX02QXJ400P2IVIT0
1@2JVYX0VIVI0:VYZ@2JVYX0XJ6Q0080ZJVY0P2b/[820:VYZ@<0aLG500@0a/K60=CDe03Lg=`0g=cL
0P3YjNT0103clo<0moOg0?3`l03_knl30?Ogm`80lo?c00<0moOg0??cl`3oool09P3oool002D0oooo
0P3gmoL0103_koL0moOg0>o_m`3_koL20?O_m`80moOg00<0mnoW0?Ogm`3gmoL00`3gmoL01`3_koL0
mnog0?Ogm`3_koL0mnog0>o_i`3_koL00P3gmoL01`3_koL0mnog0?Ogm`3gknL0mnog0?O_i`3_knL0
0P3_imh00`3_inL0g/jm0=J]Q0020<J4FP030;E[@P2eLdX0[F/i00<0S4XY00H0NcTH08A28@2<@R40
HbT@0=j]U03W_I`20>NmY@080>o6Y@3W_I`0ikfL0>nmW03_]I@0ikfD0>nmW03_]I@20>NmU080kkfL
00<0ikfD0>neU03W_I@00P3_]I@20>nmW0<0ikFD00D0ikfD0=j]Q03_]I@0gZf40>N]S0020=j]S004
0=j]Q03NYH@0gYak0<jDJ`80eYac00D0ikfD0>NmW03>S6<0cXaS0<jDJ`020=JLL`040<j<H`2eNeX0
]F]B09aS>@80aW]200L0]F/i0:eS<@2]JcT0aW]20<IkBP2eJd80aXAJ00<0cYAS00L0cXaJ0<J4FP2e
LdX0eZf40<jDH`3F[H@0cYA[0080ikfD00<0eYac0=jUN`3W_I@00`3W_I@0103WaZd0ilJe0>oWgP3_
imh20>oWi`030?O_m`3gmoL0knoW00@0moOg00@0knog0?Ogm`3gmoL0moOg9@3oool20?Ogm`040?3`
l03gmoL0moOg0?3`l080lo?c0P3gmoL00`3alO40moOg0?Ogm`030?Ogm`050?3`l03clo<0moOg0?3`
l03clo<00P3_knl01`3`l?00moOg0?3`l03clo<0moOg0?7al@3clo<00P3alO401@3_knl0jNWY0>[Z
jP3AdM40]KFe0080Ti>C0P1mOGd01`22PX80NGUi05YJFP1JFUX0BDU9059BDP1DE5@00P0g=cL0102i
^KT0a/K60<O7a`3?cll20<K6aP070<W9b@33`l<0`l?30<G5a@39bLT0`l?30<G5a@020<W9b@040<G5
a@33`l<0`l?30<G5a@80`l?300@0bLW90<71`@31`L40`L710P35aLD01`2g]kL0`l?30;Ng]`2k^k/0
^;Rh0;Ng]`2c/k<00P2/[:`01`2QXJ40ZJVY0:VYZ@35aLD0a/K609^KV`2QXJ400`2YZJT01P2KVi/0
RHV907inOP1_Kfl0Rh^;07alO080M7Ad00D0NGUi08^;R`2<S8`0OGem09>CT`020:2PX080VYZJ00L0
Ti>C08:2PP2e]KD0X:2P0;Fe]@2QXJ40aLG50080ZJVY00<0/[:b0<G5a@35aLD00P35aLD0103=cLd0
c/k>0>WYj@3YjNT20>[ZjP030??cl`3gmoL0kno_00@0moOg00@0l?3`0?Ogm`3gmoL0moOg9`3oool0
02D0oooo00@0moOg0>o_m`3gmoL0mnoW1P3gmoL00`3gkoL0moOg0?Ogm`030?Ogm`040?O_m`3gknL0
moOg0?Ogm`80mnog00D0knoW0?Ogm`3gmoL0mnog0?Ogm`020>o_m`80moOg00T0mnoW0>oWgP3_imh0
knON0=j]U03F[H@0aXAJ0;EcBP2]Jd800P2LHcT208a28@0708a::@2DDRT0U58Y07/i601:60P0ikfL
0>NeU0020>NmY@040>NmW03__I`0ikfL0>nmW080kkFD00<0kkfL0>neU03_]I@01@3_]I@20>NmU004
0>neU03W]I@0ikFD0>NmU080ikFD0`3N[H@00`3W[H`0gZf40=j]S0020=j]S0070=jLN`3FW7<0cXaS
0<j<H`3N[H@0gZfD0<j<H`030<J4H`060<J<H`36Q6<0]G]J0:ecDP2<FT80[F]20P36Nd830;E[>@05
0;E[@P2]Jd80]F]20<J4FP3>U6<00P3>U6/20;f<H`040<jDH`3FW7/0cYA[0=JLL`<0cYA[0P3NYG<0
1P3NYG/0ikfL0>NmW03W_JD0kmK60?O_i`80knON00D0knOW0>o_i`3gmoL0moOg0?O_m`020?Ogm`80
knog00@0mnog0>o_m`3gmoL0moOg9@3oool00`3gmoL0l?3`0?Ogm`020?7al@D0moOg00<0lo?c0?Og
m`3gmoL00`3gmoL0103clo<0lO7a0?Ogm`3gmoL30??cl`040>o_k`3gmoL0lo?c0?Ogm`80l?3`0`3g
moL01`3alO40jNWY0>WYj@2i^KT0]KFe09>CT`22PX800P1jNWX206m_K`0505ADE01JFUX0HF5Q065Q
H@19BDT00P0U9BD01`36a/H0`L710<O7a`36a/H0bLW90<K6aP39bLT00`33`l<00`39bLT0`l?30<?3
``050<?3``80aLG500<0`l?30<71`@35aLD00P31`L440;Ng]`050;^k^`2g]kL0^;Rh0;Rh^02/[:`0
0P2YZJT209^KV`030;Ng]`2i^KT0Vi^K0080U9BD0P2IVIT01P2DU9@0RHV90861P@1VIVH0NWYj08^;
R`@0O7al00H0OGem07YjNP1mOGd0Ti>C0:2PX02QXJ4309JFUP040:2PX02ZZZX0XJ6Q0:VYZ@80XJ6Q
0`2a/K401P2b/[80a/K60<K6aP37alL0g=cL0?7al@80jNWY00D0j^[Z0>o_k`3gmoL0moOg0??cl`02
0?Ogm`80l?3`00@0lo?c0?3`l03gmoL0moOg9`3oool002D0oooo00@0moOg0>o_m`3gmoL0mnoW1P3g
moL00`3gkoL0moOg0?Ogm`030?Ogm`040?O_m`3gknL0moOg0?Ogm`80mnog00D0knoW0?Ogm`3gmoL0
mnog0?Ogm`020>o_m`80moOg00T0mnoW0>oWgP3_imh0knON0=j]U03F[H@0aXAJ0;EcBP2]Jd800P2L
HcT208a28@0708a::@2DDRT0U58Y07/i601:60P0ikfL0>NeU0020>NmY@040>NmW03__I`0ikfL0>nm
W080kkFD00<0kkfL0>neU03_]I@01@3_]I@20>NmU0040>neU03W]I@0ikFD0>NmU080ikFD0`3N[H@0
0`3W[H`0gZf40=j]S0020=j]S0070=jLN`3FW7<0cXaS0<j<H`3N[H@0gZfD0<j<H`030<J4H`060<J<
H`36Q6<0]G]J0:ecDP2<FT80[F]20P36Nd830;E[>@050;E[@P2]Jd80]F]20<J4FP3>U6<00P3>U6/2
0;f<H`040<jDH`3FW7/0cYA[0=JLL`<0cYA[0P3NYG<01P3NYG/0ikfL0>NmW03W_JD0kmK60?O_i`80
knON00D0knOW0>o_i`3gmoL0moOg0?O_m`020?Ogm`80knog00@0mnog0>o_m`3gmoL0moOg9@3oool3
0?Ogm`80l?3`0P3gmoL01@3clo<0moOg0??cl`3gmoL0lo?c00D0moOg1P3clo<20?Ogm`030??cl`3g
moL0l?3`00@0moOg00L0l?3`0>WYj@3Kfm/0]KFe0:VYZ@2FUYH0RHV90080OGem00L0NWYj05YJFP1B
DU80HF5Q06MWI`1JFUX0ADE50080?clo00H0alO70<;2`P3?cll0alO70<71`@39bLT30<K6aP060<W9
b@33`l<0a<C40<G5a@33`l<0^k^k0`33`l<40;^k^`030<?3``2g]kL0^k^k0080^;Rh00L0]kNg0;^k
^`2b/[80/k>c0;:b/P2ZZZX0ZJVY0080UIFE00H0Vi^K0:2PX02YZJT0XJ6Q09>CT`2DU9@309>CT`07
08V9R@1_Kfl0MWIf07IfMP1iNGT0VYZJ08b<S00208^;R`0707alO01iNGT0UYJF08b<S02CTi<0UYJF
09ZJVP0209nOW`040;Fe]@2YZJT0ZJVY09nOW`<0XJ6Q0P2YZJT01`35aLD0alO70<o?c`37alL0g=cL
0>;RhP3YjNT00P3_knl0103YjNT0kno_0?7al@3_knl20?Ogm`030??cl`3gmoL0moOg00@0moOg9`3o
ool002D0oooo0`3gmoL02@3_koL0moOg0?Ogm`3gmoL0mnog0?Ogm`3gkoL0moOg0?O_m`050?Ogm`D0
mnog0`3gmoL00`3gkoL0moOg0>o_m`030?Ogm`0;0>o_m`3_imh0knON0>OFcP3F[H@0eYac0;f<H`2e
NeX0]F]20:e[@P2<BRT00P24@R401`2DDRT0U5Xa08a::@1[>B40Jc4H0>NmY@3W]I`00P3_aZD00`3W
_JD0ikFD0>nmW0020>NmW0030>nmW03_]I@0kkFL0080ikfD00@0kkFD0>N]S03_]I@0kkFD1@3W[H`0
203_]I@0gZf40>N]S03N[H`0gZf40>N]S03NYG/0gZF40P3NYG/0203FW7/0eYac0<J4J`3>S6<0cYAS
0=JLL`3>U6/0aXAJ0P36Q6<20<J4FP050;EkFP2LHcT0W6]:09a[BP2]JcT00P3>S5X02036NdX0aW]2
0;E[>@2]JcT0_HaS0<IkBP36Q5X0_HaS0P3>S5X01@36U6/0eZf40=JLL`3FW7<0aYA[00@0cYA[00P0
eYac0>NmU03W_JD0klJU0>NmY@3_e/H0kmk>0>oWgP80knoW00@0knON0>o_i`3gknL0knoW0P3gmoL0
0`3gkoL0moOg0?Ogm`040?OgmbD0oooo00<0moOg0??cl`3gmoL00`3gmoL20??cl`80moOg00<0lo?c
0?Ogm`3gmoL00`3gmoL0103clo<0moOg0??cl`3clo<30?Ogm`030??cl`3gmoL0lo?c00@0lo?c0P3a
lO401`3`l?00jNWY0=[JfP2f][H0XJ6Q09>CT`22PX800P1jNWX01@1iNGT0IfMW065QH@1iNGT0HF5Q
0080?clo0P0g=cL01@37alL0`/;20<K6aP2i^KT0a/K60080bLW90`2k^k/00`33`l<0`L710;^k^`02
0;^k^`040;Ng]`2k^k/0^k^k0;^k^`80]kNg00<0^k^k0;>c/`2k^k/01@2c/k<20;:b/P80ZJVY00X0
XJ6Q09ZJVP2JVYX0U9BD0:ZZZP2IVIT0RHV907inOP2<S8`0PX:20P29RHT01`1^KVh0PX:207alO01i
NGT0NWYj08b<S02JVYX00P2CTi<01`22PX80S8b<08V9R@2<S8`0UYJF08:2PP2IVIT00P2OWil30;Fe
]@040:2PX02QXJ40]KFe0:2PX080ZJVY00L0aLG50<K6aP3=cLd0g=cL0>WYj@3alO40jNWY0080kno_
00<0jNWY0?7al@3alO400`3gmoL01`3clo<0l?3`0?3`l03clo<0l?3`0??cl`3gmoL09`3oool002D0
oooo00<0moOg0?O_m`3gmoL00`3gmoL20?O_m`80moOg00<0mnog0?Ogm`3gmoL00`3gmoL0103gkoL0
moOg0?O_m`3gkoL20?Ogm`030?O_m`3gmoL0moOg00D0mnog00`0mnoW0>o_m`3_imh0knON0>OFaP3F
[H`0cYA[0<J4FP2eLdX0[F]20:e[>@2DFS4209AB:@070:e[>@2DDRT0Jc4H06/a601S:A00ikfU0>Ne
W0020>NmW0040=j]U03W_I`0kkfL0>nmW080ijf<00<0kkFD0>NeU03W[H`00`3W[H`00`3N[H@0ijf<
0>N]S0020=j]Q080ijf<00<0gZF40>N]S03NYH@00`3NYH@20=jUN`<0eYac00L0cYA[0<j<FP36Q6<0
eYak0<J<H`2eNeX0]F]B0080aW]:00L0]G=:0;EkFP2DHd80]G=:09acDP2]JcT0[F]20080aW]:00P0
cXaJ0<J4FP2eLdX0aW]:0;EkFP36NdX0_HaS0;EcBP80aXaS00L0aYA[0=J]Q03F[H@0eZf40<jDH`3>
U6/0eZf40080cYAS00P0eYac0>NmU03W_I`0ilJ]0>oFaP3_imh0mnoW0>oWgP80knoW00<0knON0?O_
i`3gknL00`3gmoL01`3gkoL0knog0>o_m`3gkoL0knog0?O_m`3gmoL09@3oool30?Ogm`80lo?c0P3g
moL01@3clo<0moOg0?Ogm`3gmoL0lo?c00/0moOg00L0lo?c0?Ogm`3clo<0lo?c0?Ogm`3alO40l?3`
00<0moOg00H0jNWY0<O7a`2YZJT0ZJVY09JFUP22PX8307YjNP0605YJFP1_Kfl0HF5Q059BDP0g=cL0
ADE50P0g=cL50<K6aP0;0<71`@39bLT0aLG50<G5a@2k^k/0`l?30;^k^`2g]kL0^k^k0;Ng]`2c/k<0
0P2g]kL00`2c/k<0]kNg0;>c/`020;>c/`070;Rh^02g]kL0/[:b0;:b/P2/[:`0ZZZZ0;:b/P020:ZZ
ZP090:VYZ@2QXJ40Ti>C09>CT`2QXJ40Vi^K08V9R@1nOWh0PX:20080NWYj0P1WIfL207IfMP03065Q
H@1_Kfl0OGem00@0VYZJ00<0XJ6Q08b<S02<S8`00P22PX802`2FUYH0WinO09>CT`2CTi<0/;2`0;Fe
]@2ZZZX0WinO0;Fe]@2h^;P0ZJVY0080]kNg0P35aLD01@3Lg=`0i>CT0>WYj@3Ph>00jNWY0080kno_
0`3clo<00`3gmoL0lo?c0?Ogm`030?Ogm`80lo?c00<0moOg0??cl`3oool09P3oool002D0oooo0`3g
moL01@3gkoL0moOg0?Ogm`3gmoL0mnog00<0moOg00<0mnog0?Ogm`3gmoL0203gmoL00`3gkoL0moOg
0?Ogm`020?O_m`030?Ogm`3gknL0knog0080moOg0P3_imh01@3W_JD0eYac0=JLL`2mS6<0]G=:0080
[F]200P0S4XY09aS>@2LHcT0U58Y08A28@1S:A00JcTQ06<Y40H0ikfL00H0ikFD0>nmW03W_I@0ijf<
0>neU03W[H`20=j]Q0060>N]S03N[H@0gZF40=j]Q03NYH@0gZf4103NYH@01P3N[H`0gZf40=jUN`3N
W7/0eYak0=jUN`<0eYak00P0eYac0<jDJ`36Q5X0cYA[0<j<H`2eNeX0]F]B0;EcBP<0[F]200H0U5Xa
09a[BP2LJdX0U58Y09aS>@2eJd840<j<FP030<jDJ`36NdX0aW]:0080]G=:00X0_HaS0<JDJ`36U6/0
aXAJ0=JUQ03F[H@0eYak0<JDJ`3F[H@0gZf<0P3FW7<0203N[H@0ikfD0>NmU03_e/H0mmk>0>oWgP3W
g]H0knON0P3_knL30?O_m`030?Ogm`3gkoL0moOg00<0moOg0P3gkoL00`3gmoL0mnog0?ooo`0T0?oo
o`D0moOg0P3clo<00`3gmoL0lo?c0?3`l0050?Ogm`030??cl`3gmoL0moOg00<0moOg0P3clo<20?Og
m`050??cl`3_knl0lo?c0>o_k`3gmoL00P3clo<20?7al@050;Bd]02YZJT0VIVI09>CT`1_Kfl00P1f
MWH01`1WIfL0H61P06m_K`1PH600Cdm?04E5A@1?Cdl00P0o?cl01`37alL0^[Zj0<K6aP31`L40a/K6
0<71`@2k^k/00P35aLD30;^k^`040;Ng]`2c/k<0/k>c0;>c/`80Zj^[00D0[:b/0;:b/P2/[:`0[:b/
0;>c/`020;:b/P80ZJVY00<0Zj^[0:VYZ@2YZJT00P2YZJT209^KV`80Ti>C00@0XJ6Q09>CT`22PX80
NWYj0P1fMWH0101^KVh0NWYj07YjNP1fMWH206MWI`0406m_K`1lO7`0Rh^;09ZJVP80Ti>C00<0VYZJ
09>CT`2FUYH00P22PX801P1mOGd0Ti>C0:VYZ@2YZJT0ZZZZ0:VYZ@80][Jf00<0]KFe0:6QX@2YZJT0
0P2g]kL01`36a/H0c/k>0>;RhP3Ph>00jNWY0?7al@3_knl00P3YjNT00`3clo<0moOg0??cl`060?Og
m`040??cl`3gmoL0moOg0??clbL0oooo000U0?ooo`@0moOg0`3gkoL00`3gmoL0mnog0>o_m`050?Og
m`030?O_m`3gmoL0moOg00<0moOg00X0mnog0?Ogm`3gmoL0moOg0?O_m`3_knL0mnog0>o_i`3gmoL0
mnog0`3gknL0203>[I@0eYac0<J<H`36Q5X0W6<i09a[BP2DFS40W4Xa0P2LHcT01`2LBS40Nd8Q06/i
8@1k@R40Jc4H0>NmY@3N[I`00P3W_I`01@3W]I@0ikfL0>NeU03W[H`0ikfD00<0ijf<0P3N[H@30=jU
Q0030=jLL`3NW7/0gZEk00<0gYak00D0gZF40=jUN`3NYG/0eYac0=jLL`050=JLL`80cXaS00D0aXAJ
0<jDJ`36Q5X0]G=:0:e[@P030:eS@P0309AS@P2]Jd80W6]:0080U5Xa00T0W6<i0;E[>@36Nd80aW]2
0<j<FP36Q5X0cXaJ0<J4FP2mS6<00P2eLdX01P2eJd80aXAJ0<J4FP3FW7<0eYak0=JLL`80eZf<00`0
eZf40<jDJ`3FW7<0eYac0=j]Q03W_I`0ilJe0>oNcP3Wg]H0knON0?O_i`3_knL20>oWgP030?O_m`3g
moL0mnog00H0moOg00@0mnog0?Ogm`3gmoL0mnog9@3oool00`3gmoL0lo?c0??cl`020?Ogm`80lo?c
0`3gmoL00`3clo<0l?3`0?Ogm`020?Ogm`030??cl`3gmoL0moOg0080lo?c00@0lO7a0?3`l03`l?00
moOg0P3clo<20?Ogm`0;0??cl`3gmoL0kno_0>o_k`3alO40f][J0;Jf]P2YZJT0Ti>C08V9R@1jNWX0
0P22PX801`1QHF40Kfm_06m_K`1WIfL0>c/k03Lg=`0o?cl00P15ADD01036a/H0^KVi0<;2`P2i^KT2
0<71`@@0^k^k00D0/k>c0;Ng]`2b/[80[:b/0;:b/P030:b/[0040:^[Z`2QXJ40XJ6Q0:6QX@80ZJVY
00@0[:b/0:VYZ@2YZJT0ZJVY0`2QXJ4209^KV`0809BDU02FUYH0UYJF08:2PP1jNWX0NGUi06m_K`1f
MWH207YjNP@0Kfm_00D0M7Ad07alO01mOGd0Rh^;09ZJVP020;6a/@030:VYZ@2g]kL0VIVI0080NGUi
00D0PX:209VIV@2CTi<0Ti>C0:VYZ@030;Fe]@<0X:2P0P35aLD01`3=cLd0c/k>0>3Ph03YjNT0h^;R
0>o_k`3YjNT00P3gmoL00`3clo<0moOg0?Ogm`020?Ogm`030??cl`3gmoL0moOg0080moOg00<0l?3`
0?Ogm`3clo<09`3oool002D0oooo00@0moOg0?O_m`3gkoL0moOg0`3gkoL30?Ogm`030?O_m`3_koL0
moOg0080moOg00<0mnog0?Ogm`3gmoL00P3gkoL00`3gknL0knog0?Ogm`030?O_m`80moOg00@0mnog
0?Ogm`3_knL0mnoW0P3We/H01`3F[H`0eYac0<J4FP2eNeX0[F]20;EcBP2DDRT00`2LHcT01`2DFS40
FS4Q06<Y401[<AP0JcTQ0>NmW03N[I@00P3W]I`00`3N[I@0ikFD0>NeU0030>N]S0060=jUQ03N[H@0
gZEk0=jUN`3NW7/0gZEk0P3NW7/00`3NW7<0cYA[0<jDJ`020<jDJ`80eYac00<0gYak0=JLL`3FW7<0
0`3>U6/30<j<H`070<J4H`2mS6<0]G=:0:e[@P2]JcT0W6<i0:eS@P030:e[@P<0W6<i00<0[F<a0;E[
>@2eJd800P36Nd801@3>S5X0gZEc0=JLL`3N[H@0aXaS0080[F/i00D0]G=:0<J<H`36S6<0aXAJ0=JL
L`030=J]Q0@0cYAS00P0ikfD0>O6[@3Wa[D0imkF0>oWgP3_g/h0knoW0>oWgP80moOg00<0mnog0?Og
m`3gmoL00P3gmoL00`3gkoL0moOg0?Ogm`020?Ogm`030>o_m`3gmoL0mnog02D0oooo00<0moOg0??c
l`3clo<00P3gmoL20??cl`<0moOg00<0lo?c0?3`l03gmoL00P3gmoL00`3clo<0moOg0?Ogm`020??c
l`040?7al@3`l?00l?3`0?Ogm`80lo?c0P3gmoL02`3clo<0moOg0>o_k`3_knl0lO7a0=[JfP2f][H0
ZJVY09>CT`29RHT0NWYj0080PX:200L0HF5Q06m_K`1_Kfl0IfMW03/k>`0g=cL0?clo0080ADE500@0
a/K60;Vi^@32`/80^KVi0P31`L440;^k^`050;>c/`2g]kL0/[:b0:b/[02b/[800`2/[:`0102[Zj/0
XJ6Q0:6QX@2QXJ420:VYZ@040:b/[02YZJT0ZJVY0:VYZ@<0XJ6Q0P2KVi/0202DU9@0UYJF09JFUP22
PX80NWYj07UiN@1_Kfl0MWIf0P1jNWX406m_K`0507AdM01lO7`0OGem08^;R`2JVYX00P2a/K400`2Y
ZJT0]kNg09VIV@0207UiN@0508:2PP2IVIT0Ti>C09>CT`2YZJT00`2e]KD30:2PX080aLG500L0cLg=
0<k>cP3Ph>00jNWY0>;RhP3_knl0jNWY0080moOg00<0lo?c0?Ogm`3gmoL00P3gmoL00`3clo<0moOg
0?Ogm`020?Ogm`030?3`l03gmoL0lo?c02L0oooo000U0?ooo`030?O_m`3gmoL0moOg00<0mnog00@0
mnoW0>o_m`3_koL0mnog0`3gmoL20>o_m`060?Ogm`3gkoL0moOg0?O_m`3gmoL0mnoW1P3gmoL00`3g
koL0knog0?O_m`020?O_i`80ikfU00P0eZf40<JDJ`2mS6<0]G=:09aS>@2LJdX0U5Xa0:e[>@80S4XY
00<0Q48Q058Y601B:AP00P1[<AP01P3W_I`0gZfD0>NeU03W]I@0ikFL0>NeU080ijf<00<0gZF40=jU
N`3NYG/00`3NYG/0103NW7<0eYak0=JLL`3NW7<20=JLL`D0cYA[0P3FW7<30<jDJ`<0aXAS00P0aXAJ
0;EkFP36Q5X0]F]209aS>@2DFS40[F]209aS>@<0[F]20P1k@R400`2<BRT0]F<a0<Ik@P030<Ik@P07
0<J4FP3>U6<0eYac0<jDJ`3F[H@0_HaS0;EcBP030<J4FP070<jDJ`36Q5X0eZf<0=J]S03>U6/0cYAS
0<jDJ`020<jDH`040>NmU03WaZd0knON0>ONeP80knON00H0knOW0>o_m`3gmoL0moOg0>o_i`3gknL2
0?Ogm`030?O_m`3gmoL0moOg0080moOg00@0mnog0?Ogm`3gmoL0moOg9@3oool00`3clo<0moOg0?Og
m`030??cl`040?7al@3`l?00l?3`0??cl`@0moOg00L0l?3`0?Ogm`3clo<0moOg0??cl`3gmoL0lO7a
00H0moOg00<0lo?c0?3`l03clo<00`3alO401P37alL0]KFe09nOW`2FUYH0PX:206m_K`80MWIf00@0
IfMW07UiN@1JFUX0DU9B0P0c<c<303lo?`050<K6aP2i^KT0`L710<;2`P31`L400P2k^k/20;>c/`@0
/[:b00<0Zj^[0:ZZZP2YZJT00P2[Zj/20:VYZ@@0XJ6Q0`2YZJT30:6QX@80U9BD00T0Ti>C08V9R@2C
Ti<0Ti>C07emO@1_Kfl0IfMW07YjNP1_Kfl00P1jNWX304m?C`0305YJFP1fMWH0Rh^;0080Rh^;00P0
Ti>C0:2PX02PX:00ZJVY0:6QX@2e]KD0UYJF08:2PP80Ti>C0P2QXJ401`2CTi<0][Jf0;Jf]P2QXJ40
X:2P0:6QX@2PX:000P35aLD00`3=cLd0jNWY0>3Ph0020>WYj@060>[ZjP3`l?00moOg0?Ogm`3_knl0
lO7a0P3gmoL00`3clo<0moOg0?Ogm`020?Ogm`040??cl`3gmoL0moOg0?OgmbL0oooo000U0?ooo`@0
moOg0P3gkoL90?Ogm`080?O_i`3gkoL0moOg0?O_i`3gmoL0mnog0?Ogm`3gkoL20?Ogm`070?O_m`3g
knL0mnog0?Ogm`3_knL0mnog0>ONeP020=JeY@050=J]Q02mS6<0]G]J0:e[@P2LJdX00P2DFS401@2L
HcT0S4XY08a::@1k>AP0Jc4H0080JcTQ00<0NcTH0=j]U03N[I@00`3N[H`0103W[H`0gZf<0=jUQ03N
[H`20=jUQ0040=JLN`3NW7<0gYac0=jLL`<0cYA[00<0aXA[0<j<H`3>S6<00P36Q6/20<jDJ`060<J4
J`3>U6/0cYA[0<jDJ`36Q6<0aXAJ0P36Q6<01@36Q5X0]G=:0<j<FP2]Jd80S4XY0080W6]:00X0W6<i
09AJ<@2DFS40Q48Q07]28@1S:A00[F<a0<Ik@P2eHc40aW]20P2eJd801@36NdX0cYAS0=jUL`3FW7/0
gZf40080_HaS00H0cYAS0;f<H`2mS6<0cYA[0<JDJ`3F[H@20<jDJ`060<J4FP3>S5X0gZf40=j]Q03W
aZd0kmK60P3_g/h0103Wg]H0knoW0?O_i`3gknL20?Ogm`80mnog0`3gmoL01P3_koL0moOg0?O_m`3g
koL0moOg0?O_m`80moOg9@3oool50?Ogm`030??cl`3gmoL0moOg00L0moOg00H0lO7a0??cl`3gmoL0
lO7a0?Ogm`3clo<20?Ogm`070??cl`3gmoL0lo?c0?7al@3clo<0moOg0>o_k`020??cl`070>3Ph02m
_Kd0]KFe09JFUP29RHT0NWYj07IfMP0306MWI`0406m_K`1JFUX0BDU903lo?`80ADE50P19BDT20;Vi
^@80^;Rh00<0^k^k0;Rh^02c/k<00P2h^;P20;>c/`030:ZZZP2[Zj/0Zj^[00@0XJ6Q00@0UIFE09^K
V`2KVi/0UIFE0P2QXJ400`2EUID0XJ6Q0:6QX@020:6QX@0509BDU02CTi<0U9BD09>CT`22PX800P2J
VYX01`1jNWX0FUYJ07IfMP1fMWH0Kfm_06MWI`1BDU800P1?Cdl01`0g=cL0M7Ad08^;R`1fMWH0Rh^;
07emO@2<S8`00P2PX:000`2a/K40ZZZZ0;Ng]`0209JFUP060:2PX02FUYH0XJ6Q0:6QX@2OWil0]KFe
0P2QXJ400`2CTi<0VYZJ0;Ng]`020<g=c@050=cLg03Rh^80h^;R0>3Ph03_knl00P3alO420?Ogm`80
lo?c0`3gmoL01P3`l?00moOg0??cl`3clo<0moOg0??cl`80moOg9`3oool002D0oooo0P3gmoL00`3g
koL0moOg0?O_m`020?O_m`050>o_m`3gkoL0mnog0?Ogm`3gkoL01P3gmoL0103_koL0mnoW0?O_m`3_
koL30?Ogm`070?O_m`3gmoL0moOg0>o_m`3gkoL0knoW0>O6]@020=J]S0060<JLQ02eNeX0]G]J09a[
BP2]Hd80W6<i0P2DFS4306/i8@0606/a601[>B40JcTQ06/i8@3N[I@0gZf<0P3N[I@01@3W_JD0ijfD
0>N]U03WYI@0ijfD0080ijFD00T0gZf<0=jUQ03NYH@0gZF40=JLN`3>S6<0aXAJ0<j<H`36NeX01@36
Q5X20<j<H`<0aXAJ0`2eNeX0202eJe80]G=:0<J4FP2LHcT0NdXY09aS>@2]Jd80S4XY0P1k@R40101k
>AP0NdXY09AB:@2]FS420<Ik@P0:0;EcBP36Nd80aW]20:e[>@3>U6<0eYac0=J]Q03>U6/0aYA[0<J4
FP<0aXaS00H0_HaS0=J]Q03F[H@0cYAS0=JLL`3>U6<30=J]Q0060=k6]@3gknL0kmK60>ONeP3_knL0
knOW1@3gmoL00`3gkoL0moOg0?Ogm`060?Ogm`030?O_m`3gmoL0mnog02D0oooo0P3gmoL00`3clo<0
moOg0?Ogm`020??cl`050?3`l03clo<0lo?c0?Ogm`3clo<01P3gmoL00`3`l?00lO7a0??cl`020?3`
l080moOg00D0lo?c0?Ogm`3gmoL0l?3`0??cl`020>o_k`030<k>cP2f][H0YZJV0080RHV90P1fMWH2
06m_K`80IfMW0P15ADD00`0o?cl0ADE504E5A@0204E5A@040;Vi^@2h^;P0^KVi0<O7a`80_;bl00<0
]kNg0;bl_02l_;`00P2g]kL01@2h^;P0/k>c0;>c/`2ZZZX0Vi^K0080Ti>C00<0Vi^K08j>SP2CTi<0
0`2CTi<309^KV`<0Ti>C0P29RHT02`1nOWh0PX:209>CT`2CTi<0Kfm_05EEE@1_Kfl0NWYj05YJFP1?
Cdl0BDU90080EEEE00L0HF5Q06i^KP2;Rh/0Rh^;08:2PP2;Rh/0NGUi0080X:2P00D0ZJVY0;Fe]@2Q
XJ40WinO09>CT`0209VIV@80UYJF0P2e]KD00`2PX:00ZJVY0:2PX0020;Fe]@80c<c<00D0lO7a0=cL
g03Ph>00kno_0>[ZjP050?Ogm`030??cl`3gmoL0moOg00H0moOg00<0lo?c0?Ogm`3clo<09`3oool0
02D0oooo00<0mnog0?Ogm`3gmoL00`3_knL0103gmoL0mnog0?Ogm`3gmoL20?O_m`<0moOg00L0knog
0?Ogm`3gkoL0moOg0?O_i`3gkoL0mnoW00<0moOg0P3gkoL30>o_m`0<0>oWgP3Na[D0eZf40=J]Q036
U6/0]G]J0;EcBP2]Jd80W6<i0;EcBP2LBS40U5Xa0P1B8A001`1c@RT0JcTQ06/i8@1[<AP0Q58a0=j]
U03WaZd0103_aZd20>o6Y@<0kkFL00L0ijfL0>N]U03W[I@0ijfD0=j]S03NYH@0eYak0080aW]J00@0
aW]:0<IkFP36NeX0aW]J0`2eNeX01036Q5X0aW]J0;EkFP36NdX20;EcBP80[F]200H0aW]:08a::@2<
BS40W6<i08aJ@P24@R4206/a600706/i8@2]Hc40Q48Q09aS>@36NdX0aW]20;EcBP020:e[>@060;Ec
BP3>S5X0eYak0=j]Q03N[H`0eZf40P36U6/20;EkFP050;E[@P3F[H@0eZf40<JDJ`3>U6/00P3F[H@2
0>NmW0080>o_i`3_imh0knON0>oWgP3_knL0mnoW0?O_m`3gmoL20?O_m`@0moOg00<0mnog0?Ogm`3g
moL0103gmoL00`3gkoL0knog0?ooo`0T0?ooo`030??cl`3gmoL0moOg00<0kno_00@0moOg0??cl`3g
moL0moOg0P3clo<30?Ogm`060?3`l03gmoL0lo?c0?Ogm`3alO40lo?c0P3alO420?Ogm`80lo?c0`3`
l?020>WYj@070<c<c02e]KD0WinO08V9R@22PX80NWYj06m_K`0208:2PP04061PH01WIfL0;Rh^04i>
CP80ADE500D0?clo05eMG@1MGEd0^KVi0<g=c@030=3@d080clo?1034a<@01@2m_Kd0_;bl0;bl_02h
^;P0/k>c0080ZZZZ0P2>SXh00`2<S8`0SXj>08j>SP0408V9R@0509>CT`2>SXh0RHV908b<S022PX80
0P1jNWX208b<S00705YJFP1KFe/0Kfm_06IVIP1BDU80?clo04E5A@0207AdM007059BDP1_Kfl0S8b<
08^;R`22PX80NGUi08:2PP0209ZJVP040:ZZZP2g]kL0^;Rh0;Fe]@80WinO00<0RHV907emO@1mOGd0
0P2e]KD01@2OWil0XJ6Q0;Fe]@2e]KD0a/K60080kno_0`3YjNT0103_knl0lO7a0??cl`3gmoL20??c
l`@0moOg00<0lo?c0?Ogm`3gmoL0103gmoL00`3clo<0l?3`0?ooo`0V0?ooo`009@3oool00`3gkoL0
moOg0?Ogm`030>o_i`040?Ogm`3gkoL0moOg0?Ogm`80mnog0`3gmoL01`3_koL0moOg0?O_m`3gmoL0
mnoW0?O_m`3gknL00`3gmoL20?O_m`<0knog00`0knON0=k6]@3F[H@0eZf40<JDJ`2eNeX0]G=:0:e[
@P2LHcT0]G=:09a:<@2DFS42058Q400707=2:@1[>B40JcTQ06/a6024DS40gZfD0>O6[@040>o6[@80
klJU0`3_]I`01`3W[I`0ijfD0>N]U03W[I@0gZf<0=jUQ03FW7/00P36NeX01036NdX0aW]J0<IkFP36
NeX30;EkFP040<J4FP36NeX0]G]J0<IkBP80]G=:0P2]Jd801P36NdX0S4XY08a:<@2LHcT0S5Y208A2
8@80Jc4H00L0JcTQ0:eS<@24@R40W6<i0<IkBP36Nd80]G=:0080[F/i00H0]G=:0<j<FP3FW7/0gZf4
0=j]S03F[H@20<JDJ`80]G]J00D0]F]20=J]Q03F[H@0aYA[0<jDJ`020=J]Q080ikfL00P0knoW0>oW
gP3_imh0knON0>o_i`3gknL0mnog0?Ogm`80mnog103gmoL00`3gkoL0moOg0?Ogm`040?Ogm`030?O_
m`3_koL0oooo02@0oooo00<0moOg0??cl`3clo<0103gmoL00`3clo<0moOg0?Ogm`050?Ogm`040??c
l`3gmoL0moOg0??cl`80moOg0P3_knl01@3gmoL0lo?c0?Ogm`3alO40l?3`0080lo?c0P3De=@01`2m
_Kd0ZJVY09VIV@29RHT0PH6106MWI`1_Kfl00P1WIfL01`1_Kfl0DU9B03Lg=`1?Cdl0CTi>04E5A@0o
?cl00P2?Shl00`3@d=00dM7A0=kNgP020=?Cd`80d=3@0P3Cdm<20=3@d080a<C400<0`/;20;bl_02h
^;P00P2c/k<01@2/[:`0XJ6Q08b<S022PX80RHV90080S8b<0P2>SXh01`1nOWh0RHV908b<S029RHT0
PX:207YjNP1^KVh00P22PX801`1WIfL0Kfm_08:2PP1BDU80BDU903lo?`1CDe<00P1lO7`01`1DE5@0
Kfm_07emO@2<S8`0O7al07UiN@22PX800P2CTi<01`2JVYX0]kNg0;Rh^02e]KD0ZJVY09nOW`22PX80
0P2FUYH40:VYZ@030<G5a@2YZJT0a/K60080kno_00L0h^;R0=[JfP3[jn/0j^[Z0?Ogm`3clo<0moOg
0080l?3`00@0lo?c0?3`l03clo<0lo?c0P3gmoL00`3clo<0moOg0?Ogm`040?OgmbL0oooo000U0?oo
o`030?Ogm`3gkoL0mnog00@0moOg00<0mnog0?Ogm`3gmoL01@3gmoL0103gkoL0moOg0?Ogm`3gkoL2
0?Ogm`070>o_i`3gmoL0mnog0?O_m`3gmoL0mnoW0>o_m`020?O_m`0<0>O>_@3F]JD0eYac0=JLL`36
S6<0]G]J0:ecDP2DFS40W6<i09AJ<@2LHcT0Q48Q0P1S:A001`1k@R40Ld8Y06/i8@1[<AP0]HAS0>o6
[@3_a[D00P3ge[d20?O6]@80klJ]00<0mlJe0>o6[@3_aZd00`3_]I`01`3W]I`0ijfD0=j]S03NYH@0
gYak0<jDJ`36NdX00P2eLdX0202eNeX0aW]:0<IkBP36NeX0]F]B0;EkFP36NdX0]G]J0P2eLdX0202]
Jd80U6=20;EcBP2DFS40W6<i0;EcBP24@R40NcTH0P1[<AP01`1cBS40]F/i08a28@2LHcT0]F]20<Ik
BP2eJcT00P2]JcT0202eLdX0aXAJ0<j<FP3N[H@0gZf<0=J]Q03FW7<0aYA[0P2eLdX00`2mS6<0eYac
0=JLL`020=JLL`0<0>NmU03FW7<0ikfL0>NmW03_knL0kmk>0>OFaP3gimh0knOW0?Ogm`3gkoL0moOg
0P3_koL0103gkoL0knog0?O_m`3gkoL20?Ogm`030?O_m`3gmoL0moOg00@0moOg9@3oool00`3clo<0
moOg0?7al@020?Ogm`040??cl`3alO40moOg0?3`l0D0moOg00<0lo?c0?7al@3gmoL00P3clo<01P3g
moL0lo?c0??cl`3clo<0moOg0??cl`80l?3`00<0lO7a0??cl`3clo<00P3De=@0102d];@0WinO09JF
UP21PH4207YjNP0706m_K`1WIfL0IfMW06m_K`0g=cL0ADE505EEE@0204E5A@0:09JFUP3AdM40dM7A
0=SHf03Ng]h0f=SH0=kNgP3Cdm<0g]kN0=?Cd`80f=SH00@0dm?C0=3@d03?cll0d=3@0P34a<@01`2l
_;`0^k^k0;^k^`2c/k<0/[:b0:VYZ@2QXJ401@22PX80102<S8`0PX:208V9R@22PX8207IfMP0:05iN
GP1BDU80DU9B08:2PP1WIfL0Ti>C04U9B@0o?cl0;Rh^03Lg=`80NGUi00L0OGem065QH@1mOGd0VYZJ
07UiN@2FUYH0PX:20080Ti>C00H0ZJVY0;Ng]`35aLD0alO70;Jf]P1mOGd309JFUP070:6QX@2IVIT0
ZJVY0;Jf]P2e]KD0/[:b0>[ZjP020>;RhP040=KFeP3YjNT0lO7a0??cl`80moOg00<0lO7a0?Ogm`3g
moL00`3gmoL20??cl`D0moOg00<0lo?c0?Ogm`3gmoL09`3oool002D0oooo00@0mnog0?Ogm`3gknL0
moOg0P3gkoL00`3gknL0moOg0>o_m`040?Ogm`80mnog00D0mnoW0?Ogm`3gkoL0mnog0?Ogm`020?O_
m`030?Ogm`3gkoL0mnog0080knog00D0mnoW0?O_m`3gkoL0iljm0<j]U0020<JDJ`080;f<H`2]Le80
[F]20:e[@P2LHcT0U5Xa09aS>@1S:A0206/i8@0707]::@1[>B40JcTQ0;F<L`3_a[D0mlje0?OF_@02
0?O>]@080?OF_@3ga[D0mmJm0?O6]@3gc[D0mlJe0>o6[@3_aZD20>o6[@80kkFL00D0ijfD0>N]S03N
YH@0gZEk0=JLL`020<jDJ`@0]G=:00@0aW]:0;EcBP2eNeX0]G=:0P2]Hd80202LJdX0Q58i08A28@2e
LdX0U5Xa0<J4FP1k>AP0Jc4H0P1B8A001`1S:A00[F/i0;E[@P2DDRT0]F]20<j<FP2]JcT00P2mS6<0
202eLdX0aXAJ0=JLL`3N[H@0ikfD0>NmY@3F[H`0]F]20`2mS6<01P3>U6/0aXaS0=JLL`3F[H`0eZf4
0=jUN`80knOW00D0kmk>0>o>_@3_imh0mnoW0?O_m`020?Ogm`030?O_i`3gmoL0moOg00<0moOg0P3g
koL50?Ogm`030?O_m`3gmoL0moOg02D0oooo00<0moOg0??cl`3gmoL01@3gmoL00`3`l?00lo?c0?7a
l@040?Ogm`030?7al@3clo<0moOg00D0lo?c103gmoL00`3`l?00j^[Z0=[JfP020<g=c@050:JVYP2O
Wil0RHV907IfMP1WIfL00P1_Kfl206MWI`0705QHF00g=cL0EEEE05EEE@15ADD0c/k>0=SHf0020=GE
e@060=SHf03Ng]h0g]kN0=cLg03Ng]h0g=cL103Cdm<00`3Hf=P0d=3@0<o?c`020<o?c`090<K6aP2i
^KT0^KVi0;Rh^02k^k/0/k>c0:ZZZP2QXJ40OWin00<0NWYj00L0PX:207YjNP1nOWh0NWYj07IfMP1_
Kfl0DU9B0080Cdm?00L0Ti>C059BDP2KVi/0Kfm_04E5A@1CDe<0;Rh^0080DU9B00D0S8b<05ADE01m
OGd0S8b<07alO00409>CT`070:2PX02YZJT0a/K60<O7a`2e]KD0VIVI08V9R@0209JFUP80WinO00D0
]KFe0;Jf]P2e]KD0aLG50>3Ph0020=_Kf`070>3Ph03_knl0kno_0?Ogm`3alO40moOg0??cl`030?Og
m`80lo?c00<0moOg0??cl`3clo<01`3gmoLW0?ooo`009@3oool00`3gmoL0mnog0?Ogm`050?Ogm`03
0>o_m`3gkoL0mnoW00@0moOg00<0mnoW0?O_m`3gmoL0103gkoL50?Ogm`050>o_m`3_inL0imK60>O6
[@36W8@00P36U6/00`2eNeX0W6]:09AJ<@0209aS>@0309AJ<@24BRT0HbT@00<0NdXY00D0JcTQ0>O6
]@3gc[D0klj]0?O>]@030?OF_@030>oFaP3ge[d0kmK600<0mlJe00<0mlje0>o6[@3_aZD00`3_aZD0
1@3W_I`0gZfD0=j]S03W[H`0gZF40080eYak00P0cYA[0;E[DP2]Jd80[F]20;EcBP2]Jd80]F]B0:e[
@P80[F=200P0W6<i08A28@1k@R40aXAJ08A28@3>S6<0W6<i06/i8@80LdXa00L0DR4@08A28@36NdX0
S48Q0;E[@P36NdX0]F/i00@0aXAJ00H0cYAS0=JLL`3W_I`0ikfU0=J]Q036S6<20;EkFP070;f<H`36
U6/0aYA[0=J]Q03F[H`0eZf40>NmU0020>ONeP080>OFcP3Wg]H0knoW0>o_i`3gmoL0mnoW0?Ogm`3g
koL30?Ogm`80mnog00<0moOg0?O_m`3gkoL01`3gmoLU0?ooo`D0moOg00<0l?3`0?Ogm`3gmoL01P3g
moL00`3`l?00lo?c0?7al@020?Ogm`030??cl`3gmoL0moOg00@0moOg00@0lo?c0>o_k`3Zj^X0dM7A
0P33`l<01P2NWYh0UYJF08V9R@1jNWX0KVi^06m_K`<0IfMW00L0ADE503lo?`1?Cdl0ADE508^;R`3E
eMD0f=SH0080d=3@0P3Hf=P40=kNgP030=cLg03Ng]h0g]kN0080dm?C0`3@d=002`37alL0`/;20<K6
aP36a/H0`L710;^k^`2i^KT0/k>c0:ZZZP2EUID0XJ6Q00<0MWIf00H0NWYj07IfMP1fMWH0KVi^061P
H01HF5P204i>CP0708b<S021PH40RHV908:2PP0o?cl0;Rh^04m?C`0206m_K`0708b<S02CTi<0S8b<
08b<S02CTi<0NWYj09VIV@0209JFUP0709nOW`2YZJT0]KFe0<K6aP35aLD0UYJF08:2PP0209JFUP07
08b<S02OWil0_Kfm0<G5a@2k^k/0][Jf0<g=c@020>WYj@80lO7a00D0lo?c0?Ogm`3clo<0moOg0??c
l`020?Ogm`80lo?c103gmoL00`3clo<0moOg0?Ogm`020?Ogm`030??cl`3gmoL0oooo02H0oooo000U
0?ooo`@0moOg0P3_koL70?Ogm`80knog00D0mnog0?O_i`3gmoL0moOg0?O_m`060?Ogm`060?O_m`3_
knL0knOW0=k>_@3F_Jd0_IAk0P2mS6<0102eNeX0[F]209AS@P2LHcT209AJ<@0906/i8@1[<AP0Nd8Q
07]28@1[>B40YHA[0>o>]@3gc[D0klJ]0080mlje1@3ge[d0103_e/H0mmJm0?O6]@3ga[D40>o6[@06
0>NmY@3W]I`0ikfL0>NeU03W[H`0gZfD0P3NYH@00`3FW7/0aXA[0<jDJ`020:eS@P030:e[@P2LJdX0
[F=20080U6=200P0W4Xa08A:<@1c@RT0aW]:0:ecDP2eNeX0]G=:06/a6080DR4@00@0Nd8Q09aS>@36
NdX0aXAJ0P36NdX02`36Q5X0[F]20:e[@P36S6<0_HaS0<JDJ`3FW7<0eZf40>NmW03W_I@0_HaS0080
]G=:00L0_HaS0<IkBP36U6/0e[FU0>NmU03>]JD0eZf<0080ilJ]00P0knON0?O_i`3gknL0mnog0?Og
m`3gkoL0moOg0?O_m`80moOg0P3gkoL40?Ogm`030?O_m`3gmoL0moOg0080moOg00<0mnog0?Ogm`3o
ool0903oool50?Ogm`030?3`l03gmoL0moOg00H0moOg00<0l?3`0??cl`3alO400P3gmoL00`3clo<0
moOg0?Ogm`040?Ogm`040??cl`3_knl0j^[Z0=7Ad@80`l?300H0WYjN09JFUP29RHT0NWYj06i^KP1_
Kfl306MWI`0704E5A@0o?cl0Cdm?04E5A@2;Rh/0eMGE0=SHf0020=3@d080f=SH103Ng]h00`3Lg=`0
g]kN0=kNgP020=?Cd`<0d=3@00/0alO70<;2`P36a/H0a/K60<71`@2k^k/0^KVi0;>c/`2ZZZX0UIFE
0:6QX@0307IfMP0607YjNP1fMWH0MWIf06i^KP1PH600F5QH0P1>CTh01`2<S8`0PH6108V9R@22PX80
?clo02h^;P1?Cdl00P1_Kfl01`2<S8`0Ti>C08b<S02<S8`0Ti>C07YjNP2IVIT00P2FUYH01`2OWil0
ZJVY0;Fe]@36a/H0aLG509JFUP22PX800P2FUYH01`2<S8`0WinO0;fm_@35aLD0^k^k0;Jf]P3=cLd0
0P3YjNT20?7al@050??cl`3gmoL0lo?c0?Ogm`3clo<00P3gmoL20??cl`@0moOg00<0lo?c0?Ogm`3g
moL00P3gmoL00`3clo<0moOg0?ooo`0V0?ooo`009@3oool00`3_koL0moOg0?O_m`040?Ogm`050?O_
i`3gmoL0mnog0?O_m`3gmoL0103gkoL01@3gknL0moOg0?O_m`3gkoL0mnoW0080moOg0P3_knL01`3g
moL0knog0>o_i`3Wg]H0g/jm0<j]U02mU7/00P2mS6<0202eLdX0W6]:08AB>@2DFS40S4XY09AJ<@1B
:AP0JcTQ0P1c@RT00`2<FT80klJ]0>o6]@040?O>]@80mmJm00D0mlJe0?OF_@3ga[D0mlJe0?OF_@02
0?O6]@030>o6[@3_aZD0klJU0080klJ]00D0klJU0>NeW03W]I`0ikFD0=j]U0020=j]S0050=jUQ03F
W7/0cYA[0<J4J`2LHcT00P2]Hd802`2DFT80W6<i09aS>@24BRT0NdXY06<Y402LJdX0eYak08a::@3>
U6/0U6=20080[F]200L0Jc4H0:eS<@2<BS40_HaS0:eS<@36Nd80aW]:0080_HaS00P0]HAS0<JDJ`2e
NeX0eZf40<jDH`3W_JD0klje0;f<H`80]G=:00L0_HaS0<J<H`36W8@0eYac0=J]Q03F[H`0ikfD0080
imkF00L0knON0>oWi`3gknL0knoW0?O_m`3gmoL0mnog00<0moOg0P3gkoL0103gmoL0mnog0?O_m`3g
moL30?O_m`040?Ogm`3gkoL0moOg0?OgmbD0oooo00<0l?3`0?Ogm`3clo<0103gmoL01@3alO40moOg
0??cl`3clo<0moOg00@0lo?c00D0lO7a0?Ogm`3clo<0lo?c0?7al@030?Ogm`060>o_k`3gmoL0l?3`
0>o_k`3Ph>00dM7A0P2d];@01`2NWYh0UYJF08:2PP1fMWH0GUiN06MWI`1JFUX00P1WIfL01P0c<c<0
ADE504i>CP1VIVH0d=3@0=7Ad@D0f=SH00<0g]kN0=?Cd`3Ng]h00P3Cdm<20=kNgP80dm?C00D0d=3@
0<o?c`3@d=00d=3@0<o?c`030<;2`P060<71`@2i^KT0^;Rh0;>c/`2ZZZX0XJ6Q0P2EUID01`1_Kfl0
MWIf07IfMP1YJFT0Kfm_05QHF01EEED00P0g=cL01`1fMWH0ZZZZ05YJFP2QXJ40KVi^07YjNP0o?cl0
0P1dM7@01`1KFe/0UYJF07AdM02;Rh/0S8b<09JFUP2?Shl00P2OWil01`29RHT0]KFe0:2PX037alL0
eMGE09JFUP22PX800P2FUYH01`2IVIT0YZJV0:VYZ@2e]KD0][Jf0<G5a@3Ph>000P3YjNT01P3Zj^X0
lO7a0>o_k`3clo<0moOg0??cl`<0moOg0P3clo<0103gmoL0lo?c0??cl`3gmoL30??cl`040?Ogm`3c
lo<0moOg0?OgmbL0oooo000U0?ooo`030?O_m`3gmoL0mnog00@0moOg0P3gkoL40?Ogm`<0mnog00<0
moOg0?O_m`3gmoL01P3gmoL01`3gkoL0knOW0>oWi`3Wc[d0g/jm0<JLQ036S6<00P2]Le80202eLdX0
U6=209AJ<@2DFS40Q58a06/i8@1[<AP0Q4XY0P24FT800`3_a[D0klJ]0>o>[@030?O>]@030?O6]@3_
cZd0klj]00D0klJ]00<0klJU0>neW03_]I`00P3W_JD00`3_aZD0ikfL0>nmW0020>NeW00<0=j]S03W
[H`0gZfD0=j]U03N[H`0gZF40=JLL`3>U6/0cXaS09aS>@2LBS40W6<i0P2<BS40202<BRT0JcTQ06/i
8@24DST0_HaS0;EkFP2LJdX0aYb40P2<@R401`2eNeX0U5Xa0:eS@P2eJd80aW]:0:e[>@36NdX00P2m
S6<00`2LHcT0_HaS0;f<H`020=JLL`030<j]U03N[H`0ikfD0080_HaS00L0]F]20;f<H`36W8@0aYA[
0=J]Q03W_I@0imK>0080knoW00D0imkF0>o_i`3gknL0knoW0?Ogm`020?O_m`030?Ogm`3gkoL0mnog
0080moOg00<0mnog0?Ogm`3gkoL0103gmoL0103gkoL0moOg0?Ogm`3gmoLU0?ooo`030??cl`3gmoL0
lo?c00@0moOg0P3clo<50?Ogm`80lo?c00<0moOg0??cl`3gmoL01P3gmoL01@3clo<0j^[Z0>[ZjP3D
e=@0dM7A0080YZJV00@0VIVI0861P@22PX80KVi^0P1WIfL02@1MGEd0ADE504E5A@0o?cl0F5QH06AT
I03AdM40d=3@0=GEe@040=SHf0030=?Cd`3EeMD0d=3@00D0d=3@00L0clo?0<C4a034a<@0alO70<o?
c`36a/H0bLW900<0`/;200H0^;Rh0;^k^`2i^KT0^;Rh0;>c/`2YZJT20:6QX@0609^KV`1_Kfl0H61P
06m_K`1KFe/0FUYJ0`15ADD01`1NGUh0UYJF08V9R@1fMWH0YZJV05ADE029RHT00P1WIfL01`1fMWH0
OGem08b<S01iNGT0S8b<09JFUP1_Kfl00`2FUYH20:VYZ@040;Bd]02h^;P0aLG509JFUP80OGem00L0
UYJF0:JVYP2OWil0]KFe0<G5a@3Kfm/0kno_0080h>3P00@0kno_0?7al@3_knl0moOg0P3clo<00`3g
moL0lo?c0??cl`020?Ogm`030??cl`3gmoL0lo?c00@0moOg00@0lo?c0?Ogm`3gmoL0moOg9`3oool0
02D0oooo0P3gmoL00`3gkoL0moOg0?Ogm`020?Ogm`030?O_m`3gmoL0mnog00<0mnog0`3gmoL01@3g
koL0moOg0?O_m`3gknL0knog0080mnog0`3gmoL01P3_inL0imK>0>O>_@3>]JD0_IAk0;EkFP80[G=B
00H0U6=209AJ<@2DFS40U5Xa05Xa8@1[>B4206/a60<0klJe00H0mlje0>o>[@3_aZd0klJ]0?O6]@3_
aZd20>nmW0030>NeW03W[I@0ijfD00<0gZf<00<0gZF40=j]S03N[H`00`3N[H`30>NeU0030>NeW03W
]I@0gZf<0080gZf<00L0gZF40=jLN`3FW7/0eYac0<j<H`2eJe80U5Xa0080Q58a00P0Q4Xa07=2:@1[
>B40LdXa09AS@P3>U6/0_HaS0:EkFP80eYac00L0aW]:0;EkFP24@R40[F/i0<J4FP36Nd80aW]:0080
[F/i0P2eNeX01P3FW7/0aYA[0=JLL`3F[H@0ikfU0>O6]@80_HaS00L0aYA[0=JLN`36U6/0aXaS0<j]
U03W_I`0mnoW0080imkF00@0mnog0>o_i`3gknL0knoW0P3gmoL01P3gkoL0moOg0>o_m`3_koL0mnog
0?Ogm`80mnog203gmoL00`3gkoL0oooo0?ooo`0S0?ooo`80moOg00<0lo?c0?Ogm`3gmoL00P3gmoL0
0`3clo<0moOg0??cl`040??cl`80moOg00D0lo?c0?Ogm`3clo<0lO7a0?3`l0030??cl`80moOg00@0
j^[Z0=_Kf`3De=@0^k^k0P2NWYh00`29RHT0PH6106i^KP0306MWI`0303/k>`15ADD0ADE50080?clo
0P3AdM400`3Hf=P0eMGE0=3@d0020=3@d0040=?Cd`3@d=00bLW90<;2`P80_;bl102h^;P00`2c/k<0
^;Rh0;Rh^0020;Rh^0@0`L7100H0`/;20<71`@2h^;P0^;Rh0;>c/`2/[:`20:ZZZP070:VYZ@2KVi/0
OWin06MWI`1MGEd0F5QH04i>CP0204E5A@0705=CD`1^KVh0XJ6Q09JFUP24Q8@0ZJVY08b<S00208V9
R@06059BDP1iNGT0Ti>C08^;R`2<S8`0NGUi0`29RHT01`2ZZZX0WinO0:VYZ@2e]KD0alO70<k>cP2F
UYH00P2OWil01`2ZZZX0WinO09VIV@2d];@0a/K60?7al@3Ph>000P3clo<00`3_knl0lO7a0>o_k`02
0?Ogm`060??cl`3gmoL0l?3`0?3`l03clo<0moOg0P3clo<80?Ogm`030??cl`3oool0oooo02D0oooo
000U0?ooo`030?Ogm`3gkoL0moOg00<0moOg00<0mnog0?Ogm`3gmoL00P3gmoL00`3gkoL0moOg0?Og
m`040?Ogm`<0mnog0P3gmoL30?O_m`050>oWi`3We/H0g/jm0=J]S036U6/00`2eLdX0202]Hd80S4Xa
09AJ<@24DS40Jc4H06/i8@24BRT0ilJe0`3_c[D01P3gc[D0klj]0>o6[@3_aZd0klJU0>NmY@80ijfD
00<0ijf<0=jUQ03NW7/01@3WS7/20=jUQ0040=jLN`3NYH@0gZf<0=jUQ080ikFD00L0ikFL0=j]U03N
[I@0gZf<0=jUQ03FYH@0eYak0080cYA[00`0aXAS08aJ@P24@RT0Q48Y07]::@1[>B40DRTH06/i8@2<
HdX0cYA[0:ecDP2DFS420=JUQ0070<IkBP3>U6<0]G]J09aS>@2]Jd80cXaJ0<IkBP020;EcBP080;f<
H`2eNeX0eYac0<JDJ`3F[H@0eYac0=J]Q03WaZd20=J]Q0060=JLL`36W8@0aYb40=JLL`3F[H`0ikfU
0`3_imh01@3gknL0knoW0?O_m`3gmoL0mnog0080moOg00<0knog0?Ogm`3gmoL00P3gmoL0103gkoL0
moOg0?Ogm`3gkoL70?OgmbD0oooo00<0moOg0??cl`3gmoL00`3gmoL00`3clo<0moOg0?Ogm`020?Og
m`030??cl`3gmoL0moOg00@0moOg0`3clo<30?Ogm`80lo?c00@0j^[Z0=[JfP3AdM40][Jf0P2OWil2
08:2PP0507IfMP1KFe/0IfMW05eMG@0o?cl00P15ADD01P1HF5P0c/k>0=GEe@3EeMD0f=SH0=GEe@<0
d=3@00H0clo?0<O7a`2l_;`0^k^k0;>c/`2/[:`60:JVYP040;>c/`2/[:`0/k>c0;Rh^080/k>c0P31
`L401@32`/80^KVi0;Rh^02c/k<0/;2`0080ZZZZ0P2QXJ401@2DU9@0IVIV05=CD`1EEED0ADE50080
<c<c00L0ADE506a/K02QXJ40PH6106MWI`2`/;00S8b<0080X:2P00L0RHV906m_K`1jNWX0VYZJ08b<
S022PX80UYJF0080RHV900L0ZJVY09nOW`2e]KD0ZJVY0;Fe]@3=cLd0]KFe0080ZJVY0P2VYZH00`2Y
ZJT0][Jf0<O7a`020>WYj@80lO7a00@0kno_0??cl`3gmoL0lo?c0P3gmoL00`3`l?00moOg0?Ogm`02
0?Ogm`040??cl`3gmoL0moOg0??cl`L0moOg9`3oool002D0oooo00@0moOg0?O_m`3gmoL0moOg0P3g
koL50?Ogm`030?O_m`3gmoL0moOg00D0moOg00@0mnog0?O_i`3gknL0moOg0P3gkoL01`3_knL0imK>
0>O>_@3Nc/H0aYb40;EkFP2]Le800P2LHcT00`2]Hd80Q58i08A::@0206/i8@0307/i601kBRT0klJe
0080klJe103_aZd00`3_aZD0kkFL0=icH`020<i[FP80gW][1@3NQ7<50<i[FP030=JLN`3N[H`0gZf<
00@0ikFD00<0gZfD0=j]S03NYH@00P3FW7/00`3>U6/0aXA[0<J4FP0207]::@0806/i8@1[<AP0DR4@
06/a6024DST0[G=B0=JLN`2eQ6<20<J4J`070=J]Q03>U6<0eYac0<JDJ`36NdX0]G=:0<J4FP020;f<
H`080:e[>@2eLdX0_HaS0=JLL`2mS6<0gZf40=J]S03W_I@20>NmY@070<JLQ03F[H@0aYA[0=JLL`3W
_I@0g/jm0>OFcP020>oWi`080>o_i`3_inL0knoW0?O_i`3gmoL0knog0?O_m`3gmoL20?O_m`<0moOg
00@0mnog0?Ogm`3gmoL0mnog0`3gmoL00`3gkoL0moOg0?Ogm`0U0?ooo`030?Ogm`3clo<0moOg0080
moOg00<0lo?c0?Ogm`3gmoL00`3gmoL00`3clo<0moOg0?Ogm`050?Ogm`0;0??cl`3alO40lO7a0?7a
l@3gmoL0lo?c0>o_k`3Kfm/0e=CD0=;BdP2VYZH00P29RHT01@21PH40Kfm_07IfMP1NGUh0F5QH0080
ADE50P19BDT00`1EEED0dM7A0=7Ad@040=3@d080clo?00<0a<C4096AT@27QhL00P2GUiL609fMW@@0
QhN700@0ZZZZ0;Rh^02h^;P0^;Rh0`31`L400`2i^KT0^;Rh0;>c/`030:ZZZP060:6QX@2EUID0Ti>C
05EEE@15ADD0?clo0P0^;Rh01`0o?cl0GUiN0861P@2ZZZX0Shn?09FEU@2e]KD00P2PX:001`2YZJT0
WinO08b<S022PX80Ti>C09JFUP1iNGT00P22PX801`2FUYH0ZJVY09JFUP2g]kL0][Jf0<G5a@37alL0
0P2VYZH01`2e]KD0WinO0:VYZ@35aLD0dM7A0=_Kf`3Zj^X00P3_knl01`3Zj^X0kno_0?7al@3gmoL0
l?3`0??cl`3gmoL00P3clo<30?Ogm`040??cl`3gmoL0moOg0??cl`<0moOg00<0lo?c0?Ogm`3gmoL0
9`3oool002D0oooo00@0moOg0?O_m`3gmoL0mnog0P3gmoL00`3gkoL0moOg0?Ogm`020?Ogm`060?O_
m`3gmoL0moOg0?Ogm`3gkoL0mnoW0P3gmoL0103gkoL0moOg0?Ogm`3gknL20?Ogm`070>oWi`3Wg]H0
imK60=J]S036U6/0YG]J09a[BP0209aS>@0809AJ<@1kBRT0Q58i07=2:@1[>B40NdXY0>o>_@3_a[D3
0>o6[@040>o6Y@3_cZd0klJ]0>N<N`@0gXAc00H0klJe0>neW03WS7/0ihak0>NUU03_]I`20=j4L`80
gW][00L0aXA[0<icH`3>JeX0eYak0=j]S03N[I@0ikFD0080ikFL00P0gZfD0=j]S03N[H`0eZF40=JL
N`3>U6/0gXAc0<J4H`80]G]J00P0LdXa058Y601B:AP0DR4@08AB>@1B:AP0eZF40=j]S080W6<i00L0
eZf<0;EkFP3NYG/0eZf40;f<H`36Q5X0cYAS0080[F<a00P0aXAJ0;EkFP2mS6<0aYA[0<jDJ`3FW7/0
eZf<0>NmY@80ilJe00D0_IAk0;F4H`36U6/0eYac0<j]U0020>oWgP<0knoW00@0knON0?Ogm`3gmoL0
knog0P3gkoL0103gmoL0mnog0?O_m`3gmoL20?O_m`80moOg00@0mnog0?Ogm`3gmoL0moOg0P3gkoL0
0`3gmoL0mnog0?ooo`0T0?ooo`030?Ogm`3clo<0moOg0080lo?c00<0moOg0??cl`3gmoL00`3gmoL0
1P3clo<0moOg0?Ogm`3gmoL0lo?c0?7al@80moOg00/0lo?c0?Ogm`3gmoL0moOg0?7al@3gmoL0j^[Z
0>3Ph03Jf]X0][Jf09nOW`0208B4Q00707IfMP1_Kfl0IfMW05EEE@1NGUh0CTi>04E5A@0205EEE@07
0=KFeP3AdM40d=3@0=3@d03?cll0eMGE0=3@d0020:JVYP<0WIfM00@0dM7A0<C4a02VYZH0YZJV0P2g
]kL01`34a<@0WIfM09fMW@2GUiL0UIFE08f=S@27QhL00P2ZZZX01@2h^;P0^KVi0<71`@32`/80^KVi
0080^;Rh0P2`/;001P2ZZZX0XJ6Q09fMW@2DU9@0RHV905=CD`<0<c<c00L0;Rh^05iNGP0c<c<0/;2`
0;Rh^01_Kfl0][Jf0080RHV900L0/[:b0;Fe]@2FUYH0Ti>C0:2PX01dM7@0Ti>C0080RHV900L0UYJF
09nOW`2QXJ40ZZZZ0;Jf]P37alL0c/k>0080WYjN00@0Shn?09nOW`2YZJT0];Bd0P3YjNT30>o_k`04
0>WYj@3gmoL0moOg0?3`l080lo?c00@0moOg0??cl`3clo<0moOg0P3clo<20?Ogm`040??cl`3gmoL0
moOg0?Ogm`80lo?c00<0moOg0??cl`3oool09P3oool002D0oooo00@0moOg0?O_m`3gmoL0mnog0P3g
moL00`3gkoL0moOg0?Ogm`020?Ogm`060?O_m`3gmoL0moOg0?Ogm`3gkoL0mnoW0P3gmoL0103gkoL0
moOg0?Ogm`3gknL20?Ogm`070>oWi`3Wg]H0imK60=J]S036U6/0YG]J09a[BP0209aS>@0809AJ<@1k
BRT0Q58i07=2:@1[>B40NdXY0>o>_@3_a[D30>o6[@040>o6Y@3_cZd0klJ]0>N<N`@0gXAc00H0klJe
0>neW03WS7/0ihak0>NUU03_]I`20=j4L`80gW][00L0aXA[0<icH`3>JeX0eYak0=j]S03N[I@0ikFD
0080ikFL00P0gZfD0=j]S03N[H`0eZF40=JLN`3>U6/0gXAc0<J4H`80]G]J00P0LdXa058Y601B:AP0
DR4@08AB>@1B:AP0eZF40=j]S080W6<i00L0eZf<0;EkFP3NYG/0eZf40;f<H`36Q5X0cYAS0080[F<a
00P0aXAJ0;EkFP2mS6<0aYA[0<jDJ`3FW7/0eZf<0>NmY@80ilJe00D0_IAk0;F4H`36U6/0eYac0<j]
U0020>oWgP<0knoW00@0knON0?Ogm`3gmoL0knog0P3gkoL0103gmoL0mnog0?O_m`3gmoL20?O_m`80
moOg00@0mnog0?Ogm`3gmoL0moOg0P3gkoL00`3gmoL0mnog0?ooo`0T0?ooo`030??cl`3gmoL0lo?c
0080moOg00@0lo?c0?Ogm`3clo<0moOg0P3clo<00`3gmoL0lo?c0??cl`050??cl`0;0?7al@3gmoL0
moOg0?Ogm`3`l?00moOg0=_Kf`3AdM40];Bd09nOW`2?Shl00P24Q8@01@1NGUh0IfMW05]KF`1WIfL0
=cLg0080ADE50P2;Rh/30=GEe@040=3@d03?cll0clo?0<o?c`80UiNG0P2MWId01@2GUiL0TI6A096A
T@2ATI40WIfM00<0QhN700@0NGUi07inOP1nOWh0YZJV0P2=SHd207UiN@030;6a/@2l_;`0`L7100<0
`L7100<0^;Rh0;2`/02`/;000P2ZZZX20:6QX@0309>CT`21PH40ADE50080ADE500L08B4Q03lo?`1V
IVH0Shn?09nOW`29RHT0UYJF0080]KFe00D0Ti>C0;Ng]`3EeMD0UYJF08:2PP0209>CT`80NWYj00<0
RHV90:2PX02OWil00P2YZJT20<O7a`80YZJV00L0WinO0:JVYP2NWYh0];Bd0>WYj@3Zj^X0lO7a00<0
j^[Z203gmoL00`3clo<0moOg0?Ogm`0:0?OgmbL0oooo000U0?ooo`040?O_m`3gmoL0mnog0?Ogm`80
mnog00<0moOg0?O_m`3gmoL00P3gkoL00`3gmoL0mnog0?O_m`050?O_m`040?O_i`3gmoL0moOg0>o_
m`80moOg00L0imKF0=k>_@3>[I@0aYA[0;F4H`2UNeX0Q58i0080U5Xa00<0S4Xa09AJ<@1S:A000P1[
>B400`2UQ6/0klje0>o>]@020>o>]@050>o6[@3_aZD0klJU0>o6Y@3NNf/00P3NQ7<20=ikJ`<0gW=S
00@0gXAc0<i[FP3>JeX0aUY:0`36HdX01P3WS7/0cW=S0<icH`36FTX0eZF<0>N]U0D0ikFD00@0gZf<
0=JUQ03FW7/0eYak0P3>U6/20<J4FP080:ecDP1[>B40JcTQ03TH401[<AP0S5Y20;F4H`36U6/20;Ek
FP070;f<H`3F[H@0aXAJ0=j]Q03_cZd0_HaS0;EcBP030<J4FP040:e[@P2eNeX0cYAS0<JDJ`80eYac
0`3W_JD01`36W8@0aYA[0<JLQ02mU7/0cZfD0>oWgP3_inL00P3gknL20>oWi`P0moOg00<0mnog0?Og
m`3gmoL02P3gmoLU0?ooo`D0moOg0P3clo<01@3gmoL0lo?c0??cl`3clo<0moOg00@0lo?c0P3gmoL2
0??cl`030?Ogm`3clo<0lo?c0080lo?c00D0fm_K0<W9b@2YZJT0WinO0861P@0206i^KP0705]KF`1W
IfL0F5QH03lo?`1?Cdl0?clo06MWI`030=KFeP060=GEe@3@d=00d=3@0<o?c`2VYZH0WIfM0P21PH40
101PH600IFEU071`L021PH42071`L00:07UiN@1]KFd0KFe]061PH01?Cdl0FUYJ06EUI@1:BTX0H61P
05YJFP80De=C00<0JFUY09fMW@31`L400P31`L440;Rh^080ZZZZ00D0ZJVY0:ZZZP2DU9@0RHV906IV
IP0202DU9@07024Q8@15ADD0De=C06ATI02FUYH0/;2`06MWI`020;2`/00408V9R@2ZZZX0a/K60=GE
e@80XJ6Q00X0O7al09>CT`2CTi<0RHV909JFUP2IVIT0RHV90;Fe]@35aLD0alO70P33`l<01`2YZJT0
]KFe0:JVYP2m_Kd0h>3P0>o_k`3YjNT00P3_knl01`3clo<0kno_0?Ogm`3gmoL0lo?c0?Ogm`3clo<0
2@3gmoL20??cl`040?Ogm`3clo<0moOg0?OgmbL0oooo000U0?ooo`@0moOg0`3gkoL01@3gmoL0mnog
0?O_m`3gkoL0moOg00@0mnog0P3gmoL20?O_m`030?Ogm`3gkoL0mnog0080mnog00L0imK>0=K6]@3F
W7<0aYA[0:ecDP2DHd80S4Xa0080U5Xa00D0Q4XY06/a601k@R40Jc4H09AJ<@020>o>_@0:0>o>]@3_
aZd0klJ]0>o6[@3_aZD0ihak0=j4L`2]Le80W4Xa0:e:<@80_E9200P0[G=B0;eB@P2mDT80aUY:0;EB
>@2LBS40W34Q09a2:@80[DXa00H0S34Q0:e2<@2L@RT0Q48Y09AJ@P3NQ7<40>NeU0<0gZf<0P3FW7/0
303FW7<0eYak0<J4H`36Q6<0]G]J08aJ@P1:60P0>AP@06/i8@1cBS40Q5Y20;f<H`80eZF400H0U5Xa
0=JUQ02eNeX0eYak0>NmW03_cZd30<jDJ`080;E[>@36Q5X0]G]J0;f<H`36S6<0]G]J0=J]Q03W_I@2
0>NmY@070=Jm[@3FW7<0eZf40<JLQ03F]JD0imkF0>o_i`020>oWgP030>o_i`3gkoL0knoW0080moOg
00<0mnog0?Ogm`3gkoL02@3gmoL20?O_m`040?Ogm`3gkoL0moOg0?OgmbD0oooo1@3gmoL20??cl`05
0?Ogm`3clo<0lo?c0??cl`3gmoL0103clo<20?Ogm`80lo?c00<0moOg0??cl`3clo<00P3clo<01@3K
fm/0bLW90:VYZ@2OWil0PH610080KVi^00L0Fe]K06MWI`1HF5P0?clo04m?C`0o?cl0IfMW00<0e]KF
00H0eMGE0=3@d03@d=00clo?0:JVYP2MWId20861P@04061PH01UIFD0L71`0861P@80L71`00X0NGUi
06e]K@1]KFd0H61P04m?C`1JFUX0IFEU04Y:BP1PH600FUYJ0P1CDe<00`1YJFT0WIfM0<71`@020<71
`@@0^;Rh0P2ZZZX01@2YZJT0ZZZZ09BDU029RHT0IVIV00809BDU00L08B4Q04E5A@1CDe<0I6AT09JF
UP2`/;00IfMW0080/;2`00@0RHV90:ZZZP36a/H0eMGE0P2QXJ402P1lO7`0Ti>C09>CT`29RHT0UYJF
09VIV@29RHT0]KFe0<G5a@37alL20<?3``070:VYZ@2e]KD0YZJV0;fm_@3Ph>00kno_0>WYj@020>o_
k`070??cl`3_knl0moOg0?Ogm`3clo<0moOg0??cl`090?Ogm`80lo?c00@0moOg0??cl`3gmoL0moOg
9`3oool002D0oooo0`3gkoL30?Ogm`80mnog00D0moOg0?O_m`3gmoL0mnog0?Ogm`020?O_m`030?Og
m`3gkoL0mnog00<0mnog00/0mnoW0?O_m`3_inL0knOW0>OFcP3F_Jd0_IAk0;EkFP2DHd80S4Xa08aJ
@P0208a::@<0NdXY00D0Q48Y0>o>_@3_c[d0klJe0>o>]@020?O>]@070>o6[@3_aZD0kkFL0>o6Y@3W
S7/0cW=S0<i[FP020<ISBP040<i[FP36HdX0cV]J0=ikJ`L0aV=:00<0eYac0=JUQ03FYH`00P3N[H`3
0>NeU080ijf<00<0gZf<0>N]S03NYH@00P3FW7/01P3FW7<0cYA[0<jDJ`36Q6<0W7=B05Xi:@80>AP@
00<0FSTY08AJ@P2LLe800P3FW7/01036U6/0W6]:0=JLL`2eNeX20>NmW0030>o>]@2]Le80[G=B0080
aXAJ00@0]G]J0;f<H`2mS6<0]G]J0P3F[H@20>NmY@050>O6[@36U6/0eZf40=JLL`3We/H00P3_inL3
0>oWgP@0mnog1@3gmoL0103gkoL0moOg0?Ogm`3gkoL20?Ogm`050?O_m`3gmoL0moOg0?Ogm`3gkoL0
0P3gmoLU0?ooo`<0lo?c0`3gmoL20??cl`040?Ogm`3clo<0moOg0??cl`80moOg00<0lo?c0?Ogm`3c
lo<0103clo<20?7al@070??cl`3Zj^X0fm_K0<?3``2NWYh0RHV906i^KP0205]KF`0306IVIP1JFUX0
EEEE0080EEEE00/0De=C0=KFeP3Fe]H0e]KF0=7Ad@3EeMD0f=SH0=3@d03?cll0a<C40<o?c`020:JV
YP0708f=S@27QhL0OWin08N7Q`1nOWh0QhN709NGU`0707inOP040:VYZ@2`/;00/K6a0;6a/@80^;Rh
0P31`L420;^k^`040;Rh^02k^k/0^k^k0;>c/`80ZZZZ00@0ZJVY0:6QX@2DU9@0O7al0P11@D42024Q
8@050451@@1TI6@0O7al0:ZZZP2OWil00P1fMWH01P2YZJT0RHV90<K6aP36a/H0eMGE0861P@<0Ti>C
00@0RHV909JFUP2FUYH0RHV90P2e]KD01`37alL0cLg=0<g=c@2OWil0]KFe0:VYZ@3Jf]X00P3Zj^X3
0>WYj@@0lo?c1@3gmoL0103clo<0moOg0?Ogm`3clo<20?Ogm`050??cl`3gmoL0moOg0?Ogm`3clo<0
0P3gmoLW0?ooo`009@3oool0103gmoL0mnog0?O_m`3gmoL20?O_m`<0moOg00<0mnog0?Ogm`3gkoL0
1P3gmoL01@3gknL0moOg0?O_m`3_knL0mnoW0080knON00<0g/k60=J]S02eQ6<00P2LJdX0302<FT80
S4XY08A::@24BRT0Ld8Y07]::@24@R40Q58a0>o>]@3_aZd0klje0>o>[@80klJ]00<0klj]0>o6Y@3_
cZd00P3gc[D0303ge[d0kmK60>o6]@3_a[D0klJ]0?OF_@3_aZd0klJU0?O>]@3ge[d0klJe0>o6[@80
ikfU00<0ikFL0>NmY@3W]I`00P3W]I@01P3W]I`0ikFD0>NeW03W]I`0ikFD0>N]U080gZf<0P3NYH@0
0`3FW7/0eYac0<jDJ`020<jDJ`070;EkFP24DS40@S4Y02T@2024FT80LdXa08AJ@P0209acDP050;f<
H`2LHcT0aXAJ0:e[@P36Q5X00P3W_I`20=JLL`080<jDJ`2mS6<0]G=:0;EcBP2mS6<0cYA[0=JLL`3>
U6/20>NmY@050>O6[@36W8@0aYb40<J<H`3Wg]H00P3_imh20>oWi`050>oWgP3gmoL0moOg0?Ogm`3g
koL01`3gmoL00`3gkoL0moOg0?O_m`040?Ogm`040?O_m`3gmoL0moOg0?OgmbD0oooo00<0moOg0??c
l`3clo<00P3gmoL01`3clo<0moOg0?Ogm`3gmoL0lo?c0?Ogm`3clo<01P3gmoL00`3alO40moOg0??c
l`020>o_k`050?7al@3YjNT0d];B0;Jf]P2?Shl00P1fMWH206IVIP0705YJFP1HF5P0CTi>05EEE@1B
DU80GEeM0=GEe@020=3@d080eMGE00@0d=3@0=GEe@3?cll0eMGE0`3Hf=P01`3Ng]h0g=cL0=7Ad@3@
d=00g]kN0=3@d03?cll00P3Hf=P01`3Ng]h0dM7A0=3@d037alL0`/;20<O7a`32`/800`31`L401@32
`/80`L710<;2`P31`L40_;bl00<0^;Rh0P2c/k<01@2ZZZX0ZJVY0:6QX@2QXJ40RHV90080GEeM00L0
=CDe01HF5P1TI6@0De=C06ATI01lO7`0UYJF0080Kfm_00<0Ti>C07YjNP2CTi<00P36a/H0102YZJT0
XJ6Q09JFUP2FUYH208:2PP0509JFUP2QXJ40ZJVY0:6QX@37alL00P3=cLd20:JVYP0509VIV@3Ph>00
jNWY0>WYj@3Zj^X00P3YjNT30?Ogm`030??cl`3gmoL0moOg00D0moOg00<0lo?c0?Ogm`3clo<0103g
moL0103clo<0moOg0?Ogm`3gmoLW0?ooo`009@3oool00`3gkoL0moOg0?Ogm`040?Ogm`060?O_m`3g
moL0moOg0?Ogm`3gkoL0moOg0`3gkoL20?Ogm`050?O_m`3gknL0mnog0?O_m`3_inL00P3Na[D0103W
_I`0aYb40:ecDP2DHd8208AB<@0308A:<@1[<AP0Jc4H0080NdXY00<0Nd8Q0=JeY@3_c[D00P3_c[D0
1P3ga[D0mlje0?O>]@3_aZd0mlje0>o6[@80mlje00L0mmJm0?O>]@3ge[d0mmJm0?O>]@3ge[d0klJU
00<0klJ]1@3W]I`01P3W_I`0ikFL0>NmW03_aZD0ikFL0>NeU080ikfL00@0ikFL0>N]U03W[I@0gZf<
0P3NYH@00`3FW7/0gXAc0<jDJ`020<jDJ`070;EkFP2DFT80DR4@048Q601cBS40Q58a0:F4J`0209ac
DP070<JLQ02LHcT0U5Xa0<J<H`2mS6<0gZfD0>NmW0020>o6Y@050=J]Q036Q5X0aXAJ0<J<H`2eLdX0
0P2eNeX02P3>U6/0ikfU0>NmY@3WaZd0eYac0=J]S036U6/0knON0>oWi`3Wg]H20>oWgP050?O_i`3g
moL0moOg0?Ogm`3gkoL00P3gmoL40?O_m`/0moOg00<0mnog0?ooo`3oool08`3oool00`3clo<0moOg
0?Ogm`040?Ogm`050??cl`3gmoL0moOg0?Ogm`3clo<00P3gmoL20??cl`80moOg00<0lo?c0?7al@3c
lo<00P3clo<01P3Zj^X0c<c<0<K6aP2VYZH0PH6106i^KP<0GEeM00H0F5QH03lo?`1EEED0EEEE04m?
C`2m_Kd40=GEe@050=?Cd`3Hf=P0d=3@0=SHf03@d=000`3Hf=P01P3Ng]h0f=SH0=kNgP3Hf=P0g]kN
0<o?c`@0d=3@1032`/802@36a/H0`/;20<K6aP36a/H0clo?0<;2`P31`L40a/K60<;2`P020;bl_080
^;Rh0P2c/k<01@2ZZZX0WIfM0:6QX@2QXJ40RHV90080JFUY00L0;Rh^02XZ:P1CDe<0GEeM08^;R`1l
O7`0YZJV0080Kfm_00L0IfMW09VIV@2FUYH0^KVi0<K6aP3?cll0]KFe00<0Ti>C00H0VIVI08:2PP29
RHT0RHV90:6QX@37alL20<g=c@070:VYZ@2f][H0WinO0>WYj@3Zj^X0h>3P0>WYj@020?7al@<0moOg
00<0lo?c0?Ogm`3gmoL0103clo<;0?Ogm`030??cl`3oool0oooo02D0oooo000U0?ooo`030?O_m`3g
moL0mnog00@0mnog00<0moOg0?O_i`3gmoL00`3gmoL20?O_m`030?Ogm`3gkoL0moOg0080mnog00<0
mnoW0?O_m`3gkoL00P3Nc/H01`36W8@0]G]J09aS>@2LJdX0Q4XY08A:<@1[>B401@1kBRT20>o>]@03
0>o6]@3_c[D0mlje00<0mlJe00<0mlje0>o>]@3gc[D01P3gc[D00`3_c[D0klJ]0>o6Y@020>o6Y@0:
0>NeW03W_I`0kkfL0>nmW03W]I`0ikfU0>NeW03_aZD0ikFL0>o6Y@<0ikFL0P3W[I@01P3W]I@0gZf<
0=jUQ03NW7/0gZF40=JLL`<0cYA[00L0aXAS09a[BP1c@RT0FSTY03TH401cDT80Q58i0080U6=200H0
W6<i0:ecDP2LHcT0]G]J0:EkFP3>U6/30>NmU0080<jDJ`3FW7<0aXAJ0;f<H`2eLdX0_HaS0;EcBP3F
W7<20=J]Q0050>NmY@3>[I@0aYA[0=JLN`3We/h00P3_imh20>OFaP070?Ogm`3gkoL0moOg0?Ogm`3g
koL0moOg0?O_m`050?Ogm`040?O_m`3gmoL0moOg0?Ogm`<0mnog103gmoLU0?ooo`030??cl`3gmoL0
lo?c00@0lo?c00<0moOg0?7al@3gmoL0103gmoL0103clo<0moOg0??cl`3gmoL20??cl`090?7al@3c
lo<0lo?c0??cl`3Bd]80YZJV08V9R@1_Kfl0MWIf00<0F5QH00<0ADE505EEE@1EEED00P1EEED20=GE
e@80dM7A00H0eMGE0=SHf03Cdm<0dm?C0=SHf03EeMD70=SHf0030=GEe@3@d=00clo?00<0clo?00H0
`/;20<K6aP39bLT0`/;20<O7a`32`/820<o?c`040<;2`P3?cll0`/;20<;2`P80_;bl00L0`L710;Rh
^02h^;P0/k>c0:b/[02c/k<0ZJVY0080XJ6Q00X0U9BD07IfMP1fMWH0CTi>0451@@0Q8B40FUYJ05iN
GP1^KVh0Kfm_0P21PH40101_Kfl0RHV908B4Q02QXJ420<G5a@0:0:6QX@2YZJT0ZJVY09>CT`2FUYH0
PX:209JFUP22PX80ZJVY0;Fe]@80alO700@0];Bd09nOW`2ZZZX0fm_K0P3YjNT0103Jf]X0moOg0?Og
m`3clo<20?Ogm`030??cl`3gmoL0lo?c00D0moOg00@0lo?c0?Ogm`3gmoL0moOg0`3clo<40?OgmbL0
oooo000U0?ooo`030?Ogm`3gkoL0moOg00<0mnog0`3gmoL00`3gkoL0moOg0?Ogm`070?Ogm`80mnog
00/0mnoW0=k>aP3Fa[D0e/Je0;fDN`2eLdX0W6]:08A::@2<FT80JcTQ07]::@0206/a600407]::@24
BRT0JcTQ0>o>]@80klJe00<0klje0?O>]@3gc[D00P3gc[D00`3ga[D0mlje0?O>]@020?O>]@040>o>
]@3gc[D0mlje0?O>]@80klJU00D0ikFL0>o6Y@3W]I`0ijf<0>NeU0020>NmW0040>NeW03_]I`0kkfL
0>o6Y@80kkFL00<0klJ]0>o6Y@3_aZD00P3W]I`01P3W[I@0ijf<0=jUQ03NYH@0eYak0=JLL`80gXAc
00P0aXA[0<J4H`2eLdX0LdXa058Q401B:AP0LdXa08aSBP80U6]B00L0W7=B0;F4H`2LJdX0S5Y209AS
@P2mU7/0aXaS0080gZEc00P0klJU0=J]Q036NdX0aXaS09a[BP36U6/0_HaS0=JLN`80eYac00D0ikfU
0<j]U02mS6<0ilJe0>OFaP040>oWi`030?O_m`3gmoL0moOg00@0moOg00<0mnog0?Ogm`3gmoL00P3g
moL00`3gkoL0moOg0?O_m`080?OgmbD0oooo00<0moOg0??cl`3gmoL00`3clo<30?Ogm`030??cl`3g
moL0moOg00L0moOg0P3clo<20?7al@070=;BdP39bLT0WYjN08:2PP1fMWH0F5QH06IVIP0204E5A@06
05EEE@0o?cl0EEEE05QHF015ADD0eMGE0`3AdM401@3EeMD0f=SH0=SHf03Hf=P0dm?C00D0f=SH00<0
eMGE0=SHf03Hf=P00P3?cll02P32`/80clo?0<o?c`32`/80^k^k0<71`@36a/H0`/;20<C4a039bLT2
0<o?c`80a<C400D0d=3@0<o?c`32`/80`/;20;bl_0020;^k^`80/k>c00D0ZZZZ0:VYZ@2MWId0UIFE
09BDU00208:2PP0705=CD`0^;Rh0<c<c05=CD`1/K6`0MGEe07alO00208n?S`0707IfMP1VIVH0KVi^
09jNWP2IVIT0/K6a0<o?c`020;Fe]@0708b<S02IVIT0MWIf09nOW`2FUYH0ZZZZ0:VYZ@020<O7a`04
0;Bd]02FUYH0c/k>0=[JfP<0j^[Z0P3clo<60?Ogm`030??cl`3gmoL0moOg0080moOg00<0lo?c0?Og
m`3clo<0203gmoLW0?ooo`009@3oool:0?Ogm`030?O_m`3gmoL0moOg00<0moOg0`3gkoL20?Ogm`09
0>oWi`3Na[D0aZFD0<JUU02mU7/0W6]:09aS>@2DHd80Q48Y0080NdXY0P1cBS40101kBRT0JcTQ0;F4
H`3Wa[D20>o6]@D0mlje00<0mmJm0?O>]@3_c[D00`3gc[D30>o6[@070>NeW03N[H`0gZF40>N]U03N
[I@0gZF40=j]S0020>N]U0050>NeU03W]I`0kkfL0>NmY@3_aZD00P3_aZd30>neW0030>NeW03W[I@0
gZf<0080gZF40P3FW7/20=JLL`080<jDJ`36NeX0]F]B08aJ@P1J>BT0JcTQ05Y2>@24FT8208AB>@07
09acDP2DHd80]G=:08AB<@2LHcT0Q58i0=J]S0020>NmU0080=JLL`3NYG/0aXaS0<JDJ`2UNeX0]G]J
0;f<H`36W8@20=JLL`070>NmW03F]JD0aYA[0>ONeP3W_JD0mnog0>oWi`070?Ogm`030?O_m`3gmoL0
moOg00D0moOg0P3gkoL20?Ogm`80mnog103gmoLU0?ooo`X0moOg00<0lo?c0?Ogm`3gmoL00`3gmoL3
0??cl`80moOg0P3Zj^X01`3<c<`0[Jf]09jNWP1fMWH0Kfm_06i^KP1CDe<00`1EEED01@1CDe<0EEEE
04E5A@2?Shl0c/k>00<0dM7A103Hf=P00`3Ng]h0f=SH0=GEe@040=SHf080d=3@00<0`/;20;Rh^02c
/k<00P2l_;`01`2i^KT0/k>c0;Rh^02l_;`0`L710<;2`P39bLT00P37alL00`3?cll0d=3@0=3@d002
0<C4a0040<;2`P2l_;`0^;Rh0;Rh^080/k>c0P2ZZZX00`2YZJT0XJ6Q08j>SP0207inOP0706IVIP11
@D40ADE504Q8B01TI6@0GUiN07alO00206i^KP0708:2PP1MGEd0Kfm_05iNGP2f][H0aLG50:VYZ@02
0;:b/P0709VIV@2OWil0Q8B408V9R@2FUYH0YZJV0:VYZ@020<K6aP060;fm_@2OWil0h>3P0<O7a`3c
lo<0j^[Z1`3gmoL00`3clo<0moOg0?Ogm`050?Ogm`80lo?c0P3gmoL20??cl`@0moOg9`3oool002D0
oooo00<0mnog0?Ogm`3gmoL0103gmoL0103gkoL0moOg0?O_m`3gkoL20?Ogm`80mnog0`3gmoL01@3g
knL0moOg0?O_m`3gkoL0ikfL0080_IAk00D0[G=B09AS@P2<BS40S4Xa07]::@0206/i8@<0NdXY00D0
Jc4H0>O6]@3_a[D0klJe0?O6]@070?O>]@040>o>[@3gc[D0mlje0?O>]@80klJ]00@0kkFL0>N]W03W
]I@0gYak0P3NYH@00`3FW7/0eZF40=j]S0020=j]S0040>NeU03W]I`0kkfL0>neW0@0klJU00H0kkFL
0>o6Y@3_]I@0ijfD0=j]S03NYH@20=JLN`80eYac00P0aXA[0<J4H`2eNeX0U5Y205Xi:@0Y40P0@RTQ
07=:<@80Q58a00<0W6]:08AB>@2eLdX00P2LHcT01`1kBRT0eZF40<J4FP36Q5X0eYac0>o>[@36U6/0
0P36S6<00`2eNeX0]Hac0<J4FP020<JDJ`040>NmW03F_Jd0e[f]0=k>_@80imK>00<0ilk60?Ogm`3g
moL01@3gmoL00`3gkoL0moOg0?Ogm`090?Ogm`80mnog103gmoLU0?ooo`030??cl`3gmoL0moOg00@0
moOg00@0lo?c0?Ogm`3clo<0lo?c0`3gmoL01P3clo<0moOg0?Ogm`3gmoL0lO7a0?Ogm`<0lo?c00@0
a/K609jNWP21PH40KVi^0P1KFe/0101EEED0ADE504E5A@15ADD205EEE@0403lo?`3>c/h0dM7A0=7A
d@80dm?C1P3Hf=P00`3EeMD0f=SH0=SHf0020=SHf0050=3@d034a<@0_Kfm0<71`@2/[:`00`2c/k<0
1P2ZZZX0/;2`0;Rh^02h^;P0`L710<;2`P80bLW900L0a<C40<o?c`3?cll0clo?0<C4a03?cll0`l?3
0080_;bl00L0^;Rh0;>c/`2ZZZX0ZZZZ0:VYZ@2EUID0U9BD0080RHV900L0JFUY0451@@0F5QH0;bl_
05=CD`1MGEd0MWIf0080GUiN00L0PX:206m_K`1_Kfl0EEEE0;2`/02CTi<0ZJVY0080eMGE00L0WinO
09VIV@2IVIT0RHV909JFUP2CTi<0WinO0080a/K60P33`l<0103AdM40fm_K0=_Kf`3EeMD70?Ogm`03
0??cl`3gmoL0moOg00T0moOg0P3clo<40?OgmbL0oooo000U0?ooo`030?O_m`3gmoL0moOg00@0moOg
00@0mnog0?Ogm`3gkoL0mnog0P3gmoL20?O_m`<0moOg00D0mnoW0?Ogm`3gkoL0mnog0>NmW0020;fD
N`050:ecDP2DHd80S4Xa08a:<@1kBRT00P1[>B4307]::@0506/a603Wa[D0klJe0>o6]@3ga[D01`3g
c[D0103_cZd0mlje0?O>]@3gc[D20>o6[@040>neW03W[I`0ikFD0=jLN`80gZF400<0eYak0=JUQ03N
[H`00P3N[H`0103W]I@0ikFL0>nmW03_]I`40>o6Y@060>neW03_aZD0kkFD0>N]U03N[H`0gZF40P3F
W7/20=JLL`080<J4J`36Q6<0]G]J09AJ@P1J>BT0:A08048Y8@1cBS4208AB<@0309a[BP24DST0]G=:
0080W6<i00L0NdXY0=JUQ036Q5X0aXAJ0=JLL`3_cZd0aYA[0080aXaS00<0]G]J0;F<L`36Q5X00P36
U6/0103W_I`0e[f]0=Jm[@3Nc[d20>OFcP030>O>aP3gmoL0moOg00D0moOg00<0mnog0?Ogm`3gmoL0
2@3gmoL20?O_m`@0moOg9@3oool80?Ogm`040??cl`3gmoL0moOg0?Ogm`80lo?c1`3gmoL20>[ZjP07
0;Jf]P2?Shl0KVi^05eMG@1KFe/0ADE505EEE@0204i>CP0605EEE@1CDe<0?clo03/k>`3AdM40cLg=
0`3@d=00103Hf=P0dm?C0=kNgP3Ng]h30=SHf080dm?C00<0g=cL0:b/[02GUiL00P3@d=000`34a<@0
]kNg07QhN00207QhN00609FEU@2/[:`0RHV90:VYZ@2h^;P0`/;20`3?cll30=3@d0030<o?c`34a<@0
`/;20080_;bl00L0^k^k0;>c/`2c/k<0ZZZZ0:VYZ@2QXJ40U9BD0080OWin00L0MWIf04i>CP0Q8B40
;bl_03/k>`1CDe<0GUiN0080I6AT0P1fMWH01@1MGEd0MWIf06IVIP2FUYH0]kNg0080ZJVY00@0]kNg
09>CT`2FUYH0Kfm_0P29RHT0202YZJT0aLG50<G5a@33`l<0j^[Z0;Bd]03Zj^X0_Kfm603gmoL00`3c
lo<0moOg0?ooo`0V0?ooo`009@3oool80?Ogm`050?O_m`3gmoL0moOg0?Ogm`3gkoL0203gmoL02`3_
inL0eZf<0;F4H`2eQ6<0U6=208AB<@2<BS40JcTQ07]::@1c@RT0NdXY0080Q48Y00@0Jc4H05Xa8@3_
a[D0ilJ]0P3_aZd00`3gc[D0mlJe0?OF_@020?OF_@<0mlje00<0mlJe0>oFaP3NW7/00P3NNf/20>o6
[@060>neW03WYI@0]F=20;ES@P36Q6/0gYak0P2eNeX00`3FW7<0gZf<0>NeW0020>o6Y@@0klJ]00D0
klJU0>neW03W]I`0ijfD0>N]S0020=jUQ00;0=JLN`3FW7<0eYac0<jDJ`36Q6<0]F]B0:eS@P1c@RT0
>AP@048Y8@1J<B400P1cBS401`24DST0Q5Y209a[BP2LJdX0Q58a09a[BP2<FT800P2mS6<01P3N[H@0
eYac0=j]Q036Q5X0_HaS09aS>@80]G]J0P3FW7<01P3W_I@0e[f]0>oWi`3>[I@0knOW0=JeYAP0moOg
00<0mnog0?Ogm`3oool0903oool80?Ogm`040??cl`3gmoL0moOg0?Ogm`80lo?c1`3gmoL20>[ZjP07
0;Jf]P2?Shl0KVi^05eMG@1KFe/0ADE505EEE@0204i>CP0605EEE@1CDe<0?clo03/k>`3AdM40cLg=
0`3@d=00103Hf=P0dm?C0=kNgP3Ng]h30=SHf080dm?C00<0g=cL0:b/[02GUiL00P3@d=000`34a<@0
]kNg07QhN00207QhN00609FEU@2/[:`0RHV90:VYZ@2h^;P0`/;20`3?cll30=3@d0030<o?c`34a<@0
`/;20080_;bl00L0^k^k0;>c/`2c/k<0ZZZZ0:VYZ@2QXJ40U9BD0080OWin00L0MWIf04i>CP0Q8B40
;bl_03/k>`1CDe<0GUiN0080I6AT0P1fMWH01@1MGEd0MWIf06IVIP2FUYH0]kNg0080ZJVY00@0]kNg
09>CT`2FUYH0Kfm_0P29RHT0202YZJT0aLG50<G5a@33`l<0j^[Z0;Bd]03Zj^X0_Kfm603gmoL00`3c
lo<0moOg0?ooo`0V0?ooo`009@3oool20?O_m`040?Ogm`3gkoL0mnog0?O_m`@0moOg0P3gkoL00`3g
moL0mnog0?O_m`050?Ogm`030?O_m`3Wg]h0aYA[0080[G=B00L0U6=209aS>@1kBRT0NdXY06/i8@1k
@R40NdXY0080JcTQ00P0FS4Q08AB>@3_a[D0klJ]0>o>]@3gc[D0mmJm0?O>]@80mlJe00L0mmJm0?O6
]@3gc[D0klj]0?O>]@3ge[d0klje0080klJe0P3ga[D01P3_aZd0ikFD0=j]S03N[I@0ijf<0>NeU080
gZF400<0cXaS0=JLN`3W]I`01P3_aZd0203_]I`0klJU0>o6Y@3_]I@0ijf<0=j]S03NYH@0eYak0`3>
U6/01`36Q6<0aW]J09acDP2<FT80:A0803TH4012:B400P1J@ST01`1cDT80S5Y208AB>@2LLe80Q58a
09AJ<@1B:AP00P3F[H@0203>S6<0cYAS0>NmW02eNeX0_HaS09a[BP2]Le80_HaS0P36U6/01@3>[I@0
g/Je0=k6]@36[I`0e[FU0080moOg0P3gkoL50?Ogm`030?O_m`3gmoL0moOg00<0moOg00<0mnog0?Og
m`3gmoL00`3gmoL30?O_m`<0moOg9@3oool20??cl`040?Ogm`3clo<0lo?c0??cl`@0moOg0P3clo<2
0?Ogm`030??cl`3gmoL0moOg00<0moOg00L0lo?c0>7Qh@3QhN40WinO0861P@1^KVh0Kfm_0080EEEE
00X0ADE504m?C`1?Cdl0EEEE04E5A@0k>c/0GUiN0=7Ad@3@d=00eMGE0P3Hf=P01`3Ng]h0f=SH0=?C
d`3Ng]h0dm?C0=SHf03EeMD00P3Hf=P00`3Ng]h0eMGE0=7Ad@020=?Cd`0;0=3@d031`L40^;Rh0;Rh
^02i^KT0^k^k0<71`@2c/k<0Vi^K0:ZZZP32`/801P3@d=000`34a<@0clo?0<o?c`020<?3``040;^k
^`2h^;P0/k>c0:ZZZP80XJ6Q00X0U9BD08j>SP2>SXh0O7al06IVIP0F5QH08B4Q02l_;`18B4P0FUYJ
0P1VIVH01`1NGUh0O7al05eMG@1WIfL0<c<c0;Fe]@2KVi/00P2PX:001`36a/H0RHV909JFUP1fMWH0
PH6109JFUP2OWil00P2d];@20<c<c0050;>c/`2m_Kd0moOg0?Ogm`3clo<01P3gmoL00`3clo<0moOg
0?Ogm`030?Ogm`030??cl`3gmoL0moOg00<0moOg0`3clo<30?OgmbL0oooo000U0?ooo`L0moOg00<0
mnog0?Ogm`3gmoL00P3gkoL50?Ogm`060?O_i`3gmoL0moOg0?Ogm`3We/h0_HaS0P2DHd801`2DFT80
JcTQ07=:<@24BS40Ld8Y07]::@24BS400`1S:A000`2UNf<0ilJ]0?O6]@020?O6]@030>oFaP3ge[d0
mmJm0080mmJm00H0kmK60?O>]@3gc[D0mlJe0?OF_@3_a[D40>oFaP030?O6]@3_aZD0ikFD0080ijfL
00<0gZfD0=j]S03N[H`00P3NYH@0103_]I`0klJ]0>o6[@3ga[D40>o6[@<0kkFL00@0ikFD0>N]S03N
[H`0gYak0`3NQ7<01`36Q6<0]G]J0:e[@P2DHd80:A08048Q600i61000P1cBS401`24DST0U6=207=2
:@2LJdX0Q58a09AJ<@1J<B400P36U6/0202mS6<0eZf40>NmW02eNeX0_HaS0:ecDP2eNeX0]HAS0P2m
U7/01@3F[H`0g/Je0=k6]@3F_Jd0g/jm0080moOg0P3gkoL70?Ogm`030?O_m`3gmoL0moOg00T0moOg
00@0mnog0?Ogm`3gmoL0moOg9@3oool70?Ogm`030??cl`3gmoL0moOg0080lo?c1@3gmoL0103alO40
moOg0?Ogm`3gmoL20=_Kf`0709JFUP1^KVh0JFUY04E5A@1CDe<0F5QH04i>CP0205EEE@0505QHF00g
=cL0=cLg08F5Q@3=cLd0103Cdm<01@3Lg=`0g]kN0=kNgP3Ng]h0g=cL0080f=SH0P3Cdm<00`3Ng]h0
dM7A0=cLg0020=cLg0040=?Cd`3?cll0`L710<71`@80_Kfm00D0^KVi0;Rh^02c/k<0/k>c0<C4a003
0=3@d0040=?Cd`3@d=00d=3@0=3@d0@0a<C400@0`L710;^k^`2h^;P0[:b/0P2MWId02P2DU9@0RHV9
08V9R@1jNWX0KVi^01HF5P0Z:RX08B4Q05=CD`1NGUh206i^KP0704i>CP1fMWH0GEeM06MWI`0k>c/0
WinO09JFUP020;Fe]@070<K6aP29RHT0UYJF0861P@29RHT0Shn?09jNWP020;Jf]P80c<c<00D0`l?3
0=7Ad@3gmoL0moOg0??cl`080?Ogm`030??cl`3gmoL0moOg00T0moOg00@0lo?c0?Ogm`3gmoL0moOg
9`3oool002D0oooo0`3gmoL0103gkoL0moOg0?Ogm`3gkoL20?Ogm`030?O_m`3gmoL0mnog00<0moOg
00P0mnoW0?Ogm`3gkoL0mnog0?Ogm`3gkoL0ilk60:ecDP80S5Y200L0U5Xa08AB<@1kBRT0NdXY08A:
:@2<BS40Nd8Q0080DRTH00<0FSTY0>O6]@3_a[D00P3gc[D30?OF_@80kmK600D0mmJm0>oFaP3ge[d0
mlJe0>o6[@020?OF_@80kmK600P0mmkF0>oFaP3ga[D0klJ]0>NmY@3W[I@0ijFD0=j]U080gZf<00<0
gZF40>N]U03_]I`00P3_aZd01@3_cZd0klJ]0?O6]@3ga[D0klJ]0080klJU0P3_]I`00`3W[I@0ijf<
0=jUQ0020=jLN`080<jDJ`36Q6/0]G]J0:e[@P2DFS40DRTH01P820128AP207=2:@07058Y602LHcT0
Q58a09a[BP1k@R40Q58a08aJ@P020:ecDP070<J<H`3NYG/0gZEk0=JLL`2eNeX0_HaS0:ecDP030;Ek
FP050<j]U03WaZd0e[FU0>O>aP3gkoL0203gmoL20?O_ma40moOg9@3oool30?Ogm`80lo?c00L0moOg
0??cl`3gmoL0moOg0??cl`3gmoL0lo?c00<0moOg00H0lO7a0?Ogm`3clo<0lo?c0?Ogm`3clo<20=GE
e@040861P@1VIVH0IfMW05eMG@80EEEE00P0F5QH05]KF`1KFe/0Cdm?03<c<`11@D40c/k>0=7Ad@80
f=SH103Ng]h01@3Lg=`0g]kN0=cLg03Ng]h0dm?C0080d=3@0P3Ng]h01@3Lg=`0iNGU0=cLg03Cdm<0
d=3@0080alO700L0_;bl0;Ng]`2i^KT0^;Rh0;>c/`2l_;`0a<C400<0d=3@00@0eMGE0=3@d03Cdm<0
d=3@0P3?cll30<C4a0060;bl_02k^k/0/k>c0:b/[02QXJ40UIFE0P29RHT01`1jNWX0IfMW03<c<`0<
30`0:RXZ04i>CP0c<c<00P1_Kfl01`1MGEd0MWIf04m?C`1MGEd0IVIV0861P@2IVIT00`2b/[80102Y
ZJT0RHV909JFUP21PH4208V9R@80];Bd00@0cLg=0;fm_@3EeMD0lo?c203gmoL20??cla40moOg9`3o
ool002D0oooo203gmoL20?O_m`030?Ogm`3gkoL0mnog00<0moOg00H0mnog0?Ogm`3gmoL0moOg0?O_
i`36U6/309AS@P0706/i8@1c@RT0Ld8Y07]::@24BS40NdXY048Q600206<Y4005048Q603_aZd0mlJe
0>o>_@3ga[D00P3ge[d00`3_e/H0mmJm0?OF_@040?OF_@80mlje00<0mlJe0>oFaP3_e/H00P3_e/H0
1P3gc[D0klJ]0>N]U03FYH`0gZF40=j]S080eZF<00<0gZfD0>NeW03_aZd00P3_a[D00`3_c[D0mlje
0>o6[@020>o6[@070>o6Y@3_aZd0klJU0>neW03W[I@0ijf<0=j]S0020=jUQ0080=JLL`36Q6/0]G]J
0:ecDP2]Hd80LdXa024@200i610205Xi:@0707]J@P24DST0S5Y209AS@P1kBRT0Q58a07=:<@0209ac
DP080<J4FP3>U6/0gZf<0>NmY@2eLdX0]G]J09acDP2eNeX20<JDJ`070>NmW03WaZd0aYb40=k>_@3g
moL0mnog0?Ogm`040?O_m`<0moOg00<0mnog0?Ogm`3gmoL0203gmoL00`3gkoL0moOg0?Ogm`040?Og
mbD0oooo203gmoL20??cl`040?Ogm`3clo<0lo?c0??cl`80moOg00D0lo?c0?Ogm`3gmoL0moOg0?7a
l@0209nOW`80KVi^00D0ADE504i>CP1>CTh0EEEE05QHF00205EEE@0702XZ:P0g=cL0:RXZ0=3@d03C
dm<0e]KF0=?Cd`030=kNgP030=cLg03Ng]h0g]kN00<0g]kN0`3Hf=P01P3Cdm<0g=cL0=cLg03Lg=`0
f=SH0=3@d080_;bl00L0/K6a0;>c/`2h^;P0/K6a0;Vi^@32`/80d=3@00<0dM7A00H0eMGE0=SHf03@
d=00d=3@0<o?c`3@d=020<o?c`070<C4a02l_;`0^k^k0;Rh^02c/k<0ZJVY09FEU@0208V9R@070861
P@1fMWH0De=C01@D500Q8B40@D51065QH@0205iNGP0706IVIP1^KVh0EEEE05eMG@1CDe<0O7al09>C
T`020:6QX@070;Rh^037alL0PX:208V9R@1lO7`0RHV909nOW`020<K6aP060<g=c@2VYZH0dM7A0?Og
m`3clo<0moOg103clo<30?Ogm`030??cl`3gmoL0moOg00P0moOg00<0lo?c0?Ogm`3gmoL0103gmoLW
0?ooo`009@3oool20?O_m`@0moOg00<0mnog0?Ogm`3gmoL0103gmoL20?O_m`030?Ogm`3gkoL0moOg
0080moOg00<0knog0;F4J`2DHd800P24BRT01`1[>B40Q58i08A:<@24BS40NdXY03TH401B:AP00P1B
8A00101J>BT0klJ]0?O>]@3ge[d90>oFaP80mmJm00/0mlJe0>o>_@3ga[D0mlJe0?OF_@3ga[D0klJe
0>neW03W]I`0eZF<0=j]S0030=j]U0070>NeW03_aZd0klJ]0>o6[@3_a[D0mlJe0?O>]@020>o6]@04
0?O6]@3_aZd0klJU0>o6[@80kkFL00`0ijfD0>N]S03FYH@0eZF40=jUQ03>U6/0aXAS0:ecDP2LJdX0
S4Xa02T@2012<BT2058Y600507=2:@1cBS40Q58a08AB<@2LHcT00P24DS420:EkFP080;f<H`3>U6<0
gZf<0>o>[@2eNeX0]G=:09a[BP2UNeX20;F4H`040<j]U03Na[D0g/jm0?O_ma00moOg00<0mnog0?Og
m`3gmoL00P3gmoL30?O_m`@0moOg9@3oool20??cl`@0moOg00<0lo?c0?Ogm`3gmoL01@3gmoL00`3c
lo<0moOg0??cl`030?Ogm`070?3`l02@T900T92@06i^KP1HF5P0ADE505iNGP0205QHF00905EEE@0Q
8B408B4Q03<c<`0^;Rh0@D510=3@d03Hf=P0g]kN00T0g=cL0`3Ng]h01`3Cdm<0e]KF0=?Cd`3Ng]h0
dm?C0=7Ad@34a<@00P32`/801@2a/K40^;Rh0;Vi^@2i^KT0`/;200@0d=3@00L0dM7A0=?Cd`3Hf=P0
dM7A0=?Cd`3@d=00clo?0080d=3@0P34a<@01@2l_;`0^k^k0;2`/02c/k<0XJ6Q0080U9BD00L0PH61
07IfMP1KFe/05QHF03De=@0c<c<0CTi>0080De=C0P1MGEd01@1_Kfl0GEeM05eMG@24Q8@0UYJF0080
X:2P00L0^;Rh0=GEe@29RHT0PX:207IfMP24Q8@0Shn?0080];Bd00<0c<c<0=7Ad@3clo<0403gmoL0
0`3clo<0moOg0?Ogm`020?Ogm`<0lo?c103gmoLW0?ooo`009@3oool40?Ogm`80mnog1P3gmoL01@3g
koL0moOg0?Ogm`3gkoL0moOg00@0mnog00<0]HA[09AJ<@1kBRT00P1kBRT01P24DST0LdXa07]::@24
BS40DRTH048Q6080DRTH00@0cZfD0>o>]@3_c[D0mmJm103_e/H40?ONcP050>oFaP3ge[d0mmJm0?OF
_@3gc[D00P3_a[D20?OF_@060>o6[@3_]I`0gZfD0=j]U03N[H`0ikFD0P3W]I`0103W_JD0klJ]0>o>
]@3_a[D20?O6]@050?OF_@3_c[d0kljm0?O6]@3_a[D00P3_aZd0103_]I`0ikFL0>NeW03N[I@20=jU
Q0080=JLN`3FW7<0aXAS0;E[DP2LJdX0U6=2048Q600Q40P205Xa8@07058Y6024DST0S5Y207]::@2D
FS40W6<i08AB<@0209acDP080<JLQ03FW7<0gZf40>o>[@2]Le80aXaS08aJ@P2eQ6<20:ecDP030>Nm
U03Wc[d0g/jm01/0moOg00<0mnog0?Ogm`3oool0903oool50?Ogm`030??cl`3gmoL0moOg00@0moOg
0P3clo<00`3gmoL0lo?c0?Ogm`040??cl`80T92@00L0IfMW05EEE@1EEED0GUiN05=CD`1EEED0F5QH
0080<c<c00<0:RXZ03<c<`2d];@00P3EeMD00`3Ng]h0g=cL0=cLg0030=cLg0<0i>CT00<0g=cL0=kN
gP3Ng]h00P3Ng]h01P3Hf=P0dM7A0=kNgP3Ng]h0d=3@0<C4a0<0^KVi00H0^;Rh0<71`@32`/80alO7
0=3@d03EeMD20=7Ad@80dm?C00@0g]kN0=KFeP3Cdm<0dM7A0`3@d=001`34a<@0`/;20<;2`P2i^KT0
/k>c0:ZZZP2YZJT00P2DU9@01`1nOWh0MWIf06i^KP0Z:RX051@D03/k>`0c<c<00P1NGUh01`1VIVH0
EEEE06MWI`1_Kfl0GEeM07alO02VYZH00P2YZJT01`2g]kL0eMGE0861P@2IVIT0IVIV08n?S`21PH40
0P35aLD00`3De=@0dM7A0?Ogm`0J0?Ogm`030??cl`3gmoL0oooo02H0oooo000U0?ooo`<0mnog203g
moL40?O_m`80moOg0P3gkoL0103gmoL0g/K609acDP2<FT8207=2:@80Q58a00D0Q4Xa07]::@1B:AP0
@R4H03TH40020>neW0040>o>_@3ga[D0mmJm0?ONcP80kmK600<0mmk>0>oFaP3_e/H01`3_e/H00`3g
e[d0mlje0?O>]@020?OF_@040?O6]@3_aZd0ikFL0=j]U080ikFD0P3W]I`01`3W_JD0klJe0>o6]@3_
e/H0mmJm0?O6]@3_e/H00P3ga[D0203ge[d0kljm0>o>_@3_a[D0klJ]0>O6[@3_]I`0ikFD0P3N[H`0
203FYH@0eYak0=JLL`2eNeX0W6]:09aS>@1c@RT0HbT@0P1[>B4207=:<@0509AS@P24DS40W6<i08aJ
@P2<BS400P2LLe80203FYH@0eYac0=J]Q03W_JD0_HaS0;EcBP24DS40YG]J0P2eNeX00`3N[H`0imK6
0>o_i`0:0?Ogm`030?O_m`3gmoL0moOg00<0mnog0P3gmoL00`3gkoL0moOg0?O_m`080?OgmbD0oooo
0`3clo<80?Ogm`@0lo?c0P3gmoL20??cl`060?Ogm`3>c/h0O7al07alO01VIVH0CTi>0P1MGEd00`1H
F5P0EEEE03<c<`0202XZ:P06024Q8@34a<@0e]KF0=?Cd`3Ng]h0i>CT0`3Lg=`00`3Ti>@0g=cL0=cL
g0070=cLg0060=kNgP3Hf=P0g]kN0=kNgP3Cdm<0d=3@0P32`/801@2i^KT0`L710<71`@32`/80alO7
0080dM7A0P3Lg=`01@3Ng]h0dm?C0=cLg03Cdm<0g]kN0080e]KF0P3AdM401`3@d=00cLg=0<C4a031
`L40^;Rh0;2`/02ZZZX00P2YZJT01P29RHT0MWIf06m_K`1>CTh0=cLg04E5A@<0De=C00L0KVi^05eM
G@1_Kfl0IVIV05]KF`1lO7`0/;2`0080ZJVY00L0]KFe0<O7a`2FUYH0PX:205eMG@24Q8@0RHV90080
^;Rh00<0f][J0>o_k`3gmoL02@3gmoL00`3clo<0moOg0?Ogm`030??cl`80moOg00<0lo?c0?Ogm`3c
lo<0203gmoLW0?ooo`009@3oool00`3gkoL0moOg0?O_m`070?Ogm`030?O_m`3gmoL0moOg0080mnog
1@3gmoL00`2LLe80U5Xa08AB<@0205Xa8@0707]J@P1cBS40LdXa08A:<@1B:AP0JcTQ05Xi:@020>o6
[@030>o6]@3_e/H0mmJm0080kmK60P3gg/h30>oFaP030?OF_@3gg/h0kmK600<0kmK600<0mmJm0>o>
_@3_c[d00`3ge[d01@3ga[D0ikFL0=j]U03W]I`0ikfL00<0ikfU00H0ilJ]0>o>]@3ge[d0kljm0?OF
_@3_e/H20?OF_@080?O6]@3_c[d0kljm0>o>_@3_a[D0klJ]0>NmY@3W]I`20=j]U0070=j]S03FW7/0
eYac0<IkFP2eJe80U5Y207=:<@0406/i8@0608AB>@24DS40W6<i09AS@P2<FT80U7=J0P2eQ6/0203F
W7/0eYac0=JLL`3F[H@0aXaS0:e[>@24BRT0YG]J0P2mU7/00`3F[H`0imkF0?Ogm`0C0?Ogm`040?O_
m`3gmoL0moOg0?Ogm`80mnog103gmoLU0?ooo`030??cl`3gmoL0lo?c00L0moOg00D0lo?c0?Ogm`3g
moL0moOg0??cl`050?Ogm`0607alO01WIfL0IfMW05eMG@0k>c/0HF5Q0P1CDe<02@1HF5P0<c<c04E5
A@15ADD0@D510=3@d03AdM40g=cL0=kNgP020=cLg0<0i>CT0P3Lg=`00`3Ng]h0i>CT0=cLg0040=cL
g0030=kNgP3Fe]H0g]kN0080g]kN00H0dm?C0<;2`P32`/80^KVi0<;2`P36a/H20<O7a`090<g=c@3E
eMD0g]kN0=kNgP3Fe]H0g]kN0=cLg03Ng]h0dm?C00@0e]KF00L0dM7A0=3@d037alL0`/;20;Vi^@2h
^;P0ZZZZ0080ZJVY00@0SXj>07inOP1YJFT0De=C0`15ADD205iNGP0705eMG@1_Kfl0KVi^06IVIP1j
NWX0T92@0:ZZZP030:VYZ@060;Fe]@2IVIT0NGUi05QHF024Q8@0WYjN0P2f][H00`3Ph>00moOg0?Og
m`0B0?Ogm`040??cl`3gmoL0moOg0?Ogm`80lo?c103gmoLW0?ooo`009@3oool00`3gkoL0moOg0?O_
m`070?Ogm`030?O_m`3gmoL0moOg0080mnog1@3gmoL00`2LLe80U5Xa08AB<@0205Xa8@0707]J@P1c
BS40LdXa08A:<@1B:AP0JcTQ05Xi:@020>o6[@030>o6]@3_e/H0mmJm0080kmK60P3gg/h30>oFaP03
0?OF_@3gg/h0kmK600<0kmK600<0mmJm0>o>_@3_c[d00`3ge[d01@3ga[D0ikFL0=j]U03W]I`0ikfL
00<0ikfU00H0ilJ]0>o>]@3ge[d0kljm0?OF_@3_e/H20?OF_@080?O6]@3_c[d0kljm0>o>_@3_a[D0
klJ]0>NmY@3W]I`20=j]U0070=j]S03FW7/0eYac0<IkFP2eJe80U5Y207=:<@0406/i8@0608AB>@24
DS40W6<i09AS@P2<FT80U7=J0P2eQ6/0203FW7/0eYac0=JLL`3F[H@0aXaS0:e[>@24BRT0YG]J0P2m
U7/00`3F[H`0imkF0?Ogm`0C0?Ogm`040?O_m`3gmoL0moOg0?Ogm`80mnog103gmoLU0?ooo`030??c
l`3gmoL0lo?c00L0moOg00D0lo?c0?Ogm`3gmoL0moOg0??cl`050?Ogm`0607alO01WIfL0IfMW05eM
G@0k>c/0HF5Q0P1CDe<02@1HF5P0<c<c04E5A@15ADD0@D510=3@d03AdM40g=cL0=kNgP020=cLg0<0
i>CT0P3Lg=`00`3Ng]h0i>CT0=cLg0040=cLg0030=kNgP3Fe]H0g]kN0080g]kN00H0dm?C0<;2`P32
`/80^KVi0<;2`P36a/H20<O7a`090<g=c@3EeMD0g]kN0=kNgP3Fe]H0g]kN0=cLg03Ng]h0dm?C00@0
e]KF00L0dM7A0=3@d037alL0`/;20;Vi^@2h^;P0ZZZZ0080ZJVY00@0SXj>07inOP1YJFT0De=C0`15
ADD205iNGP0705eMG@1_Kfl0KVi^06IVIP1jNWX0T92@0:ZZZP030:VYZ@060;Fe]@2IVIT0NGUi05QH
F024Q8@0WYjN0P2f][H00`3Ph>00moOg0?Ogm`0B0?Ogm`040??cl`3gmoL0moOg0?Ogm`80lo?c103g
moLW0?ooo`009@3oool00`3gkoL0moOg0?Ogm`0:0?Ogm`80mnog0`3gmoL01@3gkoL0moOg0:ecDP2L
HcT0LdXa0080JcTQ00L0S5Y208AB>@1kBRT0Ld8Y06/i8@1B:AP0YHAc0080mlJe00@0kljm0>oFaP3_
e/H0kmK60P3gg/h0103_e/H0mmJm0>oFaP3_e/H20?OF_@030>oFaP3gg/h0mmk>0080kmK60`3ge[d0
103_e/H0mlJe0?O6]@3W]I`20=j]U0030>NmW03W_JD0ikfU0080klJ]0`3_c[d20>oFaP<0mlJe00@0
mmJm0?O>]@3_c[D0klJe0P3_aZd02P3W_JD0gZfD0=j]U03N[H`0eZF40=JLL`36Q6<0]F]B09AJ@P2<
BS4305Xa8@0706/i8@1cBS40Q4Xa09AS@P2LHcT0U6=209AJ<@050=JLL`050=JUQ03F[H@0[F]20:e[
@P2]Le800P2eQ6<00`3N[H@0knoW0?Ogm`0=0?Ogm`040?O_m`3gmoL0moOg0?O_m``0moOg9@3oool0
0`3clo<0moOg0?Ogm`0;0?Ogm`070??cl`3gmoL0moOg0?Ogm`3clo<0moOg0861P@0206m_K`0705=C
D`15ADD0IVIV05iNGP1EEED0CTi>04E5A@0203<c<`0308b<S03Cdm<0e]KF00<0g=cL0`3Ti>@00`3L
g=`0g]kN0=cLg0020=kNgP040=cLg03Ti>@0i>CT0>CTi080g=cL0P3Ng]h00`3Lg=`0dm?C0=?Cd`02
0<;2`P80^KVi00@0a/K60<O7a`3@d=00d=3@103Fe]H20=cLg080dm?C00D0g]kN0=SHf03EeMD0eMGE
0=7Ad@020=3@d0040<O7a`2i^KT0^;Rh0;2`/080ZJVY00@0U9BD07inOP1YJFT0Fe]K0P0k>c/02015
ADD0De=C05=CD`1HF5P0KVi^06m_K`1^KVh0IfMW1@2YZJT01P2`/;00]KFe07YjNP1jNWX0PH6108n?
S`80]kNg00<0kno_0?Ogm`3gmoL0303gmoL0103clo<0moOg0?Ogm`3clo<<0?OgmbL0oooo000U0?oo
o`80moOg00@0mnog0?Ogm`3gkoL0mnog0`3gmoL00`3gkoL0moOg0?Ogm`070?Ogm`040?O_m`2LLe80
W7=B08AB>@80LdXa00L0Ld8Y08AB>@24BS40FS4Q07=2:@24DST0klJe0080mlje00<0kljm0>oFaP3_
e/H01@3_e/H20?OF_@030>oFaP3_c[d0kmK600<0kmK60`3ge[d0203_a[D0kmK60>oFaP3ge[d0ikfU
0>N]U03N[I@0ikFL0`3W_JD00`3WaZd0klJe0>o>_@020>o>_@050>oFaP3_c[d0kljm0?OF_@3_c[d0
0P3_a[D00`3_aZd0klJe0>O6[@030>NmY@080=j]U03FYH@0eYak0<jDJ`2eNeX0W6]:08AB>@1c@RT2
06/a6080JcTQ00D0Q58i09AJ<@2<HdX0Q58i08A::@020=J]S0060=JLL`36U6/0eYak0<JLQ03N[H`0
U5Xa0P2]Le820:F4J`030=J]Q03gknL0moOg0180moOg00<0mnog0?Ogm`3gmoL0203gmoLU0?ooo`80
moOg00@0lo?c0?Ogm`3gmoL0lo?c0`3gmoL00`3clo<0moOg0?Ogm`070?Ogm`0;0??cl`1lO7`0O7al
07alO01NGUh0De=C04i>CP1NGUh0F5QH03/k>`1>CTh00P1NGUh00`3AdM40f=SH0=KFeP080=cLg003
0=kNgP3Lg=`0e]KF00D0g=cL0P3Ng]h0103AdM40g=cL0=cLg03Ng]h20<O7a`030;bl_02i^KT0`/;2
0080alO700<0cLg=0=7Ad@3Fe]H00`3Fe]H0103Lg=`0e]KF0=kNgP3Fe]H30=7Ad@030=3@d03AdM40
cLg=0080alO700X0^KVi0;2`/02ZZZX0ZZZZ0:6QX@29RHT0MWIf05iNGP1>CTh0?clo0`15ADD01`1N
GUh0IfMW06a/K01NGUh0F5QH0;Jf]P2YZJT00P2OWil0102ZZZX0YZJV0;Rh^01WIfL20861P@0408^;
R`2e]KD0]KFe0?7alA<0moOg00<0lo?c0?Ogm`3gmoL0203gmoLW0?ooo`009@3oool0103gkoL0moOg
0?Ogm`3gmoL20?O_m`040?Ogm`3gkoL0moOg0?O_m`L0moOg00H0mnog0?Ogm`2m[Jd0U5Xa08aSBP24
DS4208aJ@P0708AB<@2<BS40JcTQ05Xi:@1c@RT0ilJ]0?OF_@020>o6]@030?OF_@3_e/H0kmK60080
kmK600<0mmk>0>oFaP3_e/H00P3ge[d00`3_c[d0klJe0>o6]@020>o>_@80mmJm0P3ga[D0203gc[D0
kmK60>oFaP3ge[d0klJ]0>N]U03N[H`0gZfD0P3N[I`01P3W_I`0gZfL0>O6]@3Wc[d0klJe0>oFaP@0
kljm00<0klJe0>O6]@3_a[D00`3_aZd30>NmY@080=j]W03N[H`0eZF40=j4L`36Q6<0W6]:09AJ<@1c
BS42058Y6080JcTQ00<0LdXa09a[BP2<FT800P2<FT820<JLQ0080<JDJ`3FW7<0eYac09a[BP3W_I@0
Q48Q09a[BP2mS6<20<JDJ`030<j]U03gmoL0moOg0100moOg00<0mnog0?Ogm`3gmoL02P3gmoLU0?oo
o`030??cl`3gmoL0moOg0080moOg00D0lo?c0?Ogm`3clo<0moOg0??cl`070?Ogm`040??cl`3gmoL0
/[:b06MWI`80K6a/00L0GEeM06IVIP1MGEd0Fe]K04E5A@11@D40CTi>0080cLg=00<0g]kN0=7Ad@3N
g]h0103Lg=`20>CTi080g=cL00@0g]kN0=KFeP3AdM40dM7A0`3Fe]H20=kNgP050=?Cd`3Hf=P0g=cL
0=cLg03Ng]h00P3@d=001`2l_;`0^;Rh0;Vi^@2j^[X0a/K60;Zj^P3>c/h00P3De=@00`3AdM40g=cL
0=KFeP020=KFeP040=7Ad@3>c/h0dM7A0=7Ad@<0d=3@0P37alL02P2j^[X0^;Rh0;2`/02`/;00WIfM
09BDU01fMWH0IfMW05=CD`0c<c<304E5A@0305=CD`1fMWH0IVIV0080IVIV00<0YZJV09nOW`2YZJT0
0P2YZJT01P1fMWH0aLG5059BDP1fMWH0UYJF09nOW`80];Bd4P3gmoL00`3clo<0moOg0?Ogm`0:0?Og
mbL0oooo000U0?ooo`<0moOg00D0mnog0?Ogm`3gmoL0moOg0?O_m`090?Ogm`060?O_m`3gmoL0YG][
0;F<L`2LJdX0LdXa0P2LJdX01`1cBS40S4Xa05Xa8@1cBS40NdXY0>O6[@3ga[D00P3WaZd20>oFaP05
0?ONcP3_e/H0kmK60?OF_@3_e/H00`3_c[d01`3_]I`0ilJ]0>o6[@3_aZd0klJe0>o>_@3ge[d00P3_
c[D0203gc[D0mmJm0>oFaP3ge[d0klJ]0>NUU03N[H`0eZF<0`3N[I@0103W_JD0ilJe0>o6]@3_c[d2
0>O6[@80ikfU103WaZd0103_aZd0klJe0>O6[@3WaZd20=JeY@080>NmW03N[H`0eZF40=JLL`36Q6<0
[G=B09AJ<@24BS42058Y6005058Q401[>B40LdXa08aJ@P2LHcT00P2<FT820<JLQ080cYA[00H0eYac
08A:<@3N[H@0U5Y208aJ@P2eQ6/20=JUQ0050>O6[@3gmoL0moOg0?Ogm`3gkoL03P3gmoL00`3gkoL0
moOg0?Ogm`0:0?OgmbD0oooo0`3gmoL20??cl`80moOg00<0lo?c0?Ogm`3gmoL01`3gmoL0103clo<0
moOg08J6QP2FUYH207IfMP0705=CD`1fMWH0De=C05]KF`0k>c/0De=C05EEE@020<g=c@050=?Cd`3=
cLd0g=cL0=cLg03Ti>@00P3Lg=`20=kNgP050=cLg03Fe]H0e]KF0<C4a03=cLd00P3@d=020=7Ad@07
0=KFeP3Ng]h0eMGE0=SHf03Ng]h0g=cL0=kNgP020=3@d0030;Ng]`2h^;P0/K6a0080^KVi00D0alO7
0<k>cP3AdM40dM7A0=KFeP020<g=c@030<O7a`3=cLd0cLg=00<0cLg=00L0d=3@0=7Ad@3=cLd0cLg=
0;fm_@36a/H0^;Rh0080/;2`00L0ZJVY09BDU021PH40IfMW05QHF00c<c<0;Rh^0080ADE500<0De=C
06IVIP1_Kfl00P1VIVH02`2VYZH0XJ6Q0:6QX@2QXJ40ZJVY05QHF02g]kL0JFUY06IVIP2@T900/;2`
0080cLg=0`3gmoL00`3clo<0moOg0?Ogm`0<0?Ogm`030??cl`3gmoL0moOg00X0moOg9`3oool002D0
oooo0`3gmoL00`3gkoL0moOg0?Ogm`020?Ogm`040?O_m`3gmoL0moOg0?Ogm`D0mnog0P3gmoL0102<
BRT0]IAk08aJ@P2DJe8208AJ@P0708aJ@P1cBS40DRTH09aS>@3W[H`0klJ]0>N]U0020>o6]@030?OF
_@3_e/H0kmK60080kmK600<0kljm0>O>_@3_a[D00P3_a[D01`3_aZd0gZfL0=j]U03W_JD0ilJ]0>o6
]@3_c[d00P3WaZd0203_a[D0kmK60>oFaP3ge[d0kkFL0=j]U03NW7/0eZf<0P3FYH`0103>[I@0e[FU
0>O6[@3Wa[D20>NmY@030=JeY@3W[I`0ijfL0080gZf<00<0eZF<0=j]W03N[I`00`3W_JD30>NmW007
0=j]U03FYH@0cYA[0<J4J`2eJe80W6]:08AB>@0207=2:@0303TH401S:A00JcTQ0080S5Y200`0W6]:
08AB>@2mU7/0_IAk0=JLN`2eNeX0_HaS08A::@3W_I@0W6]:08a:<@36U6/20=J]Q0030>OFaP3gmoL0
moOg00L0moOg00<0mnog0?Ogm`3gmoL02P3gmoL00`3gkoL0moOg0?Ogm`060?OgmbD0oooo0`3gmoL2
0??cl`<0moOg00@0lo?c0?Ogm`3gmoL0moOg1@3clo<20?Ogm`0;05YJFP2KVi/0IVIV06IVIP1eMGD0
I6AT06IVIP1CDe<0<c<c06m_K`2k^k/00P3@d=000`2l_;`0dM7A0=kNgP040=cLg080e]KF00L0e=CD
0=7Ad@3AdM40d=3@0;Zj^P2i^KT0alO70080cLg=00@0dM7A0=KFeP3=cLd0dM7A0P3Lg=`02P3Ng]h0
a<C40<C4a02i^KT0[:b/0;Jf]P2a/K40];Bd0;fm_@3=cLd20<k>cP80alO70P2m_Kd20;Rh^0040;6a
/@2j^[X0^[Zj0;Zj^P<0alO70P36a/H02P2i^KT0/;2`0;2`/02QXJ40UIFE07inOP1fMWH0GUiN04i>
CP0Q8B4203Lg=`0704E5A@1VIVH0IVIV07IfMP1NGUh0WYjN0:ZZZP0208V9R@0709JFUP1HF5P0aLG5
07IfMP1KFe/0WinO0;Fe]@020=[JfPT0moOg00<0lo?c0?Ogm`3gmoL02P3gmoL00`3clo<0moOg0?Og
m`060?OgmbL0oooo000U0?ooo`X0moOg00<0mnog0?Ogm`3gkoL01@3gmoL01@3oool0W6]:0:EkH`24
DST0S5Y20080Q58i00L0U5Y2058Q4024DS40Q4Xa0?O6]@3>U6/0gZF40080klje00P0mmJm0>oFaP3_
e/H0kmK60>o>_@3Wa[D0gZfL0;fDN`80]Hac00<0eZF<0<jUU02mU7/00P3N[I`20>o>_@<0klJe0`3g
e[d0103_aZd0gZfD0=JLN`36W8@20=JLN`070>NmW03N[I`0ilJe0>N]W03N[I`0aZFL0;fLS0020;F4
J`070;F<L`36W8@0aYb40<JLQ03>YI@0ikfL0>NmY@040=j]W0070=j]S03FYH@0aYb40<J4J`2eNeX0
U5Y208AB>@0207=:<@0706/i8@1J<B40FS4Q08AB>@24DS40S6=:08aJ@P020;F4J`080;f<H`2eNeX0
]G]J09AJ<@3W_I@0U5Xa08a:<@36W8@20=JLL`030>OFcP3oool0moOg01d0moOg9@3oool:0?Ogm`04
0??cl`3gmoL0lo?c0??cl`@0moOg00<0oooo07IfMP25QHD00P1NGUh01`1VIVH0GUiN06UYJ@0^;Rh0
GEeM05QHF03Cdm<00P2QXJ400`2c/k<0eMGE0=kNgP030=cLg0090=KFeP3>c/h0c/k>0;Zj^P2NWYh0
UYJF0;6a/@2`/;00WYjN00<0^[Zj0P3Fe]H20=7Ad@<0g]kN0P3@d=001`2i^KT0ZZZZ0:JVYP2ZZZX0
a/K60;Zj^P3>c/h00P2m_Kd01@2j^[X0[Zj^0:BTY02@T900UYJF00@0YZJV00<0/;2`0<K6aP37alL0
0`2j^[X02P2h^;P0/;2`0;2`/02VYZH0UIFE08V9R@1YJFT0GUiN05=CD`15ADD303/k>`0605iNGP1M
GEd0K6a/06IVIP2@T900UYJF0`29RHT01P1WIfL0aLG506MWI`1KFe/0YZJV0:VYZ@80fm_K00<0oooo
0?Ogm`3gmoL0703gmoLW0?ooo`009@3oool00`3gkoL0moOg0?Ogm`030?Ogm`030?O_m`3gmoL0mnog
00T0moOg00D0_IbD0:EkFP2LLe80LdXa08AB>@0207=:<@0709AJ@P1J<B40U5Xa0>neU03_]I`0ihak
0=JUS0020>o>]@080>o>_@3_e/H0kmK60>o6]@3W[I`0]HAS0;f<H`3N[I`20;f][@0407=[H`1cLf/0
YHAc0<JLQ080gXAc0`3_a[D0203WaZd0mmJm0?OF_@3ge[d0klJU0>NeW03FW7/0eZF40P2mU7/01`3F
YH@0W4Xa0<IJBP36Q6/0eZF<0=k6aP2DNg<00P1cFTX01P2UNf/0YG]S0:EkFP2UNf<0]HA[0=JUS080
gZfD0`3N[I`20=JUS0050<jDJ`36Q6/0]F]B09a[BP2<FT800P1cBS400`24DST0DRTH058Y600208AB
>@0;08aJ@P2LJdX0]HAS0;F4H`2mU7/0]G=:0;EkFP2DDRT0ikfL09aS>@2LLe800`3F[H@00`3_inL0
moOg0?Ogm`0>0?Ogm`80mnog3@3gmoLU0?ooo`030??cl`3gmoL0moOg00<0moOg00<0lo?c0?Ogm`3c
lo<02@3gmoL00`2UYJD0Q8B407alO00205=CD`0705iNGP1CDe<0JFUY03/k>`1WIfL0`l?30<C4a002
0:JVYP030;6a/@3EeMD0e]KF0080g=cL00/0dM7A0;fm_@2?Shl0Shn?09JFUP2j^[X0/[:b06a/K01b
LW80S8b<0:JVYP0309fMW@80dM7A00@0cLg=0=kNgP3Ng]h0g]kN0P3?cll01`32`/80ZZZZ0;2`/02N
WYh0/;2`061PH01iNGT00P2EUID01`2a/K40c/k>08:2PP1PH600QXJ608F5Q@24Q8@00P25QHD0102@
T900/K6a0;Vi^@2i^KT20;Zj^P<0/K6a00L0XJ6Q09FEU@1nOWh0MWIf06IVIP1CDe<0GUiN00<0<c<c
0P1NGUh0101VIVH0MWIf08n?S`2NWYh208:2PP0508V9R@1QHF40a/K606m_K`1lO7`00P2e]KD20>[Z
jQ00moOg0P3clo<=0?OgmbL0oooo000U0?ooo``0moOg00<0mnog0?Ogm`3gmoL00`3gmoL01@2eQ6/0
_Ib<09acDP2<HdX0FS4Q0080Q58i00L0U5Y206/a601B:AP0mlJe0>N]S03WYI@0gZfD0080kljm00P0
mmJm0>o>_@3WaZd0ijfL0;F4J`36Q6/0e[fe0>OFcP80Ng=c00L0Lf]S06=JDP24Ng<0YG][0<JLQ02m
U7/0ijfL0080gZfD00P0klJU0?OF_@3ge[d0klje0>o6[@3W]I`0gZF40;fDN`80]HA[00L0aXA[0<JL
Q02]@S40g/K60>oWi`2<Lf<0U7=J0080Nf]J00H0U8b406]SFP2mW9@0W7=B08a[DP2eQ6/20=JUQ080
gZfD00P0gZf<0=JUS03FW7/0eYac0;F4J`2]Le80W6]:08AB<@80LdXa00L0FS4Q02T@20128AP0Q58i
08aJ@P1c@RT0W6]:0080]HA[00L0]HAS09a[BP2UNeX0[F=20=j]S024BRT0_IAk00<0eZf<3P3gmoL0
0`3gkoL0moOg0?Ogm`020?Ogm`030?O_m`3gmoL0moOg00X0moOg9@3oool<0?Ogm`80lo?c103gmoL0
0`2@T900Y:BT07alO00206a/K00703/k>`1NGUh0JFUY03lo?`0c<c<0dm?C0;^k^`020;Ng]`070;Vi
^@3Fe]H0g]kN0=KFeP3=cLd0_Kfm092@T00209FEU@070<C4a03Kfm/0MGEe06a/K01LG5`0OGem08J6
QP020:JVYP0409jNWP2m_Kd0^KVi0<o?c`80g]kN00X0eMGE0=3@d03@d=00`/;20;>c/`2NWYh0T92@
09FEU@2VYZH0H61P0P3>c/h01`3Zj^X0NGUi07YjNP1^KVh0SXj>06ATI02UYJD00P1lO7`01`1bLW80
T92@0;2`/02`/;00^KVi0;Rh^02a/K400P2ZZZX01`2YZJT0T92@0861P@1fMWH0GEeM05=CD`0k>c/0
0P0F5QH01`0Z:RX0GUiN06IVIP1>CTh0MWIf092@T02?Shl00P1fMWH01@24Q8@0MWIf0;Rh^01HF5P0
WYjN0080][Jf3`3gmoL00`3clo<0moOg0?Ogm`020?Ogm`030??cl`3gmoL0moOg00X0moOg9`3oool0
02D0oooo2@3gmoL00`3gkoL0moOg0?Ogm`050?Ogm`060?ooo`3gkoL0YHA[08AB<@1kBRT0FS4Q1024
DST01@2DFT80mlJe0=jUQ03WS7/0gZfD0080ilJe00P0klje0>o6[@3N[I`0_IAk09AcFP1J>BT0]IB<
0<Je]@80U7][00L0]KFm024H6024Lf/0FTY209AcFP2eQ6/0_IAk0080ikFL00P0klj]0?OF_@3ge[d0
mlje0>o6[@3W_I`0ikFD0;fDN`80]Hac00L0W7=B0;F<L`2mU7/0W6]:0<k6_@1SFU80]Kg>00808APH
00P0Lg=[06=JDP2mW9@0@S4Y07=B@P2UNf<0]Hac0;fDN`80eZF400P0eZF<0=JUQ02mU7/0aYA[0<J4
H`2]Le80U5Y208AB>@80Q4Xa00L0@R4H03TH40128AP0DRTH08AB>@1cBS40[G=B0080W7=B0P2UNeX0
1P2eNeX0[F=20=J]Q024BRT0_HaS0=JLN`80g/Je803gmoLU0?ooo``0moOg0P3clo<40?Ogm`03092@
T02TY:@0O7al0080K6a/00L0>c/k05iNGP1YJFT0?clo03<c<`3Cdm<0^k^k0080]kNg00L0^KVi0=KF
eP3Ng]h0e]KF0<g=c@2m_Kd0T92@0080UIFE00L0a<C40=_Kf`1eMGD0K6a/05aLG01mOGd0QXJ60080
YZJV00@0WYjN0;fm_@2i^KT0clo?0P3Ng]h02P3EeMD0d=3@0=3@d032`/80/k>c09jNWP2@T900UIFE
0:JVYP1PH6020<k>cP070>[ZjP1iNGT0NWYj06i^KP2>SXh0I6AT0:FUY@0207alO007079bLP2@T900
/;2`0;2`/02i^KT0^;Rh0;6a/@020:ZZZP070:VYZ@2@T900PH6107IfMP1MGEd0De=C03/k>`0201HF
5P0702XZ:P1NGUh0IVIV04i>CP1fMWH0T92@08n?S`0207IfMP0508B4Q01fMWH0^;Rh05QHF02NWYh0
0P2f][H?0?Ogm`030??cl`3gmoL0moOg0080moOg00<0lo?c0?Ogm`3gmoL02P3gmoLW0?ooo`009@3o
ool90?Ogm`030?O_m`3gmoL0moOg00D0moOg00H0oooo0?O_m`2UQ6/0Q58a07]::@1J<B4408AB>@05
09AJ@P3ga[D0gZF40>N<N`3N[I@00P3Wa[D0203_c[D0klJ]0=j]W02mU7/0U7=J05Xi:@2eU8`0a[Fe
0P2DNf/01`2e]Kd08APH08AcJ`1JBT80U7=J0;F4J`2mU7/00P3W]I`0203_cZd0mmJm0?OF_@3gc[D0
klJ]0>NmW03W]I@0_IAk0P2eS7<01`2LLe80]Hac0;fDN`2LJdX0c/Jm06=JDP2e_Lh00P0Q61P0201c
Lf/0HeYB0;fLU012<BT0Le920:EkH`2eS7<0_IAk0P3FYH@0203FYH`0eZF40;fDN`36U6/0aXAS0:ec
DP2DFT80Q58i0P24BS401`128AP0>AP@048Q601B:AP0Q58i07=:<@2]Le800P2LLe820:EkFP060;Ek
FP2]Hd80eZf408A::@2mS6<0eYak0P3Na[DP0?OgmbD0oooo2@3gmoL00`3clo<0moOg0?Ogm`050?Og
m`040?ooo`3clo<0Rh^;05eMG@80EEEE00L0>c/k05iNGP1NGUh0GUiN06UYJ@3Cdm<0/k>c0080YZJV
00L0^KVi0<k>cP3EeMD0d=3@0;Zj^P2NWYh0NWYj0080@D5100L0WIfM0;Zj^P21PH40][Jf01XJ6P1g
MgL0CTi>0080NWYj00@0T92@09jNWP32`/80eMGE0P3Ng]h02P3Hf=P0d=3@0=3@d036a/H0`L7109jN
WP2FUYH0O7al09JFUP2NWYh207IfMP070<S8b01LG5`0_Kfm01XJ6P1bLW80G5aL0:FUY@0203De=@07
05YJFP25QHD0UYJF09jNWP2`/;00/K6a0;2`/00209jNWP0709nOW`2DU9@0PH6106UYJ@1NGUh0F5QH
02XZ:P02024Q8@0602XZ:P0c<c<0GUiN05=CD`21PH40O7al0`24Q8@01`29RHT0MWIf0;Fe]@1HF5P0
UYJF0:ZZZP3<c<`08@3gmoLW0?ooo`009@3ooolA0?Ogm`060;FDN`3Fa/H0YHac09AcFP1kDT80LdXa
0`24DST01P2DFT80cW=S0>neW03WS7/0eYak0=j]S080klJe00D0klje0>NeW03>YI@0aXA[07=:<@02
08ASDP0:05Y2>@12:B40@RTQ05Xi:@24DST0S6]B08ASDP2UNf<0_IAk0>N]U080kkfL0P3gc[D01P3g
e[d0mlje0>o6[@3__I`0ikFL0=jUQ080_IAk00<0aXA[0:ecDP2DLeX00P2US8@00`1J>BT0DRTH05Xi
:@0205Xi:@0707=:<@1J@ST0LeY:07]B@P2UNf<0]HAS0;F4J`020<jDJ`80eYak00@0_IAk0;F4J`2e
NeX0U5Y20P2<FT8207=:<@0306/i8@128AP0FSTY0080JcTQ00`0LdXa09a[BP2]Le80[G=B09a[BP2L
HcT0]G]J0:ecDP3F[H@0U6=20;f<H`3FW7<20>oWgQL0moOg00<0mnog0?Ogm`3gmoL01P3gmoLU0?oo
oa40moOg00@0Vi^K0<_;b`2ATI40NWYj0P1LG5`01`1CDe<0GUiN05iNGP1YJFT0SHf=0<C4a02VYZH0
0P2ZZZX01`2h^;P0dM7A0=GEe@32`/80/;2`09FEU@1CDe<00`1[Jf/01P18B4P0;bl_0451@@1NGUh0
LW9b06][J`80QHF500<0WYjN0;bl_039bLT00P3Hf=P02`3Ng]h0f=SH0=3@d03@d=00bLW90<;2`P2c
/k<0WYjN09FEU@21PH40NWYj00<0Ti>C00H0@D5103<c<`11@D40@D5105=CD`18B4P2061PH00505aL
G025QHD0Shn?092@T02QXJ400P2ZZZX209jNWP03092@T029RHT0JFUY0080IVIV00D0De=C04E5A@0Z
:RX0:RXZ0451@@0204E5A@0405=CD`1fMWH0PH6107IfMP80Kfm_00L0RHV90861P@2e]KD0KVi^09JF
UP2YZJT0jNWY01P0moOg00<0lo?c0?Ogm`3gmoL01P3gmoLW0?ooo`009@3oool40?Ogm`80mnog0`3g
moL00`3gkoL0moOg0?Ogm`050?Ogm`060:ecDP2mW9@0]Ib<08aJ@P1cBS40S6=:0P24DST0101cBS40
S4Xa0<J4H`3WYI@20=JLN`0:0=j]S03_a[D0klJe0>O6]@3WaZd0ikfU0=j]U02mU7/0]F]B08aSBP@0
Ne9200D0Q58i09AcFP36Q6/0eZF40>NeW0030>o6[@040?O>]@3ge[d0mmJm0?O>]@80klJ]00/0klJU
0>NeU03NYH@0gZF40=JLN`2mU7/0]HA[08ASBP2UNf<0YHAc09akJ`0208ASDP0806=:@P1J@ST0LdXa
09acDP2mS6<0]Hac0<J4J`3>U6/30=JLN`060;fDN`3>U6/0_HaS0;E[DP2DFT80S5Y20`24DST00`1c
@RT0DRTH05Xi:@0205Xa8@0<07=2:@2LLe80]G]J0;EkFP2LLe80W6<i0;EkFP2mS6<0eZf409a[BP2m
S6<0eZF40P3_knLP0?OgmbD0oooo1@3gmoL01@3clo<0moOg0?Ogm`3gmoL0lo?c00L0moOg00@0PH61
0:FUY@2RXZ80IVIV0P1CDe<01P1/K6`0GUiN05=CD`1KFe/0U9BD0;Ng]`<0ZZZZ00L0^;Rh0=7Ad@3>
c/h0cLg=0<O7a`2i^KT0WYjN0080OWin00L0K6a/05aLG01LG5`0G5aL05iNGP1jNWX0UIFE0080/;2`
00@0`/;20=3@d03@d=00f=SH0P3Ng]h02P3Hf=P0d=3@0=3@d03@d=00clo?0<71`@2c/k<0ZZZZ09jN
WP2@T90206YZJP0708F5Q@2<S8`0Ph>306][J`1@D500B4Q805=CD`0207alO080UYJF00D0UIFE0:6Q
X@2ZZZX0ZZZZ09jNWP020:6QX@0409JFUP1nOWh0JFUY06IVIP80GUiN00@0CTi>03<c<`0c<c<0@D51
0P0k>c/0101>CTh0O7al08V9R@1lO7`206m_K`0708V9R@2FUYH0]KFe07IfMP2FUYH0/;2`0>o_k`0Q
0?OgmbL0oooo000U0?ooo`d0moOg0P3gkoL20?Ogm`050>oWgP2US7/0U6]B07=:<@1c@RT00`1cBS40
1`1[>B40W6]:0<J4H`3>U6/0aYb40;fDN`3FYH`00P3Wa[D20>o>]@060?OF_@3_c[d0klJ]0>o6]@3W
_JD0ikFL0P3W[I`01`3W]I`0ikfU0>NeW03FW7/0gZF40>N]U03_aZD00P3ge[d0203gc[D0kmK60>oF
aP3ge[d0mlje0>o>[@3_aZd0ikFD0P3FW7<01@3NW7/0_IAk0=JUQ03FYH`0eZF400@0_IAk00P0cYA[
0=JLN`3FYH@0eZF40=j]S03W[H`0gZfD0=JUS080eZF400P0eYak0<jDJ`36Q6/0_HaS0;EkFP2DFT80
S6=:08AB>@<0JcTQ00H0DRTH05Xi:@1cBS40Ld8Y06/i8@2LJdX20;f<H`0809a[BP2LHcT0aXAJ0;fD
N`3N[I@0W7=B0;fDN`3_g/h20?oooah0moOg00<0mnog0?Ogm`3oool0903oool>0?Ogm`070??cl`3g
moL0moOg0>WYj@2BTY80MGEe05=CD`0204i>CP80De=C00D0ADE507IfMP2DU9@0XJ6Q0:JVYP0209jN
WP070;6a/@3>c/h0eMGE0=GEe@3Ng]h0e]KF0=3@d0020=7Ad@070<O7a`32`/80_Kfm0<;2`P37alL0
`/;20:ZZZP020;>c/`040;bl_03?cll0g]kN0=SHf080g=cL00X0g]kN0=SHf03Hf=P0eMGE0=3@d031
`L40ZJVY0:b/[02NWYh0/;2`0P2a/K401P2`/;00WYjN09jNWP2NWYh0XJ6Q0:ZZZP<0/;2`00L0^;Rh
0;^k^`2i^KT0/K6a0;2`/02ZZZX0XJ6Q0080UIFE00D0UYJF08V9R@1YJFT0K6a/05iNGP0204E5A@80
<c<c00L0@D5105=CD`1>CTh0ADE507IfMP2FUYH0MWIf0080Kfm_00L0Ti>C09jNWP2i^KT0O7al09jN
WP3Rh^80oooo01l0moOg00<0lo?c0?Ogm`3oool09P3oool002D0oooo0P3gmoL01@3gkoL0moOg0?Og
m`3gmoL0mnog00D0moOg00@0mnog0?Ogm`3gmoL0moOg0P3oool00`1c@RT0S5Y205Xa8@0206/i8@80
U6=200L0FS4Q09a:<@2eJe80gXAc0<jDJ`2eS7<0eZF40080klje00D0ikfU0?O>]@3ge[d0mmJm0>oF
aP020?OF_@090>oFaP3WYI@0ijFD0<J4J`2UNf<0W7=B0;E[DP3W]I`0klJU00@0mmJm00L0mmk>0>oF
aP3ge[d0kmK60?O>]@3ge[d0kkfL0080ijfD00L0aXA[0:eS@P2LLe80]F]B0;F<L`3W_JD0ilJ]0080
klJ]00<0ilJ]0>NmY@3W_JD00`3W]I`0303N[I@0eZF40<JDJ`36U6/0]HAS0<jDJ`2mS6<0]G]J0:ec
DP2LJdX0S5Y208AB<@80Q58i00L0HbT@058Y601B:AP0FSTY058Q401cBS40S5Y20080[G=B00P0W6]:
09AS@P36S6<0aYA[0>NmW02UNeX0aYb40>oWib80moOg9@3oool20?Ogm`050??cl`3gmoL0moOg0?Og
m`3clo<01@3gmoL20??cl`80moOg0P3oool00`1>CTh0IVIV03/k>`0304E5A@0606i^KP0k>c/0H61P
07inOP2MWId0XJ6Q0P2FUYH0102`/;00eMGE0<O7a`3Hf=P20=kNgP0:0=cLg03Ng]h0g]kN0=kNgP3L
g=`0]kNg09FEU@25QHD0O7al07inOP80`/;200L0clo?0=kNgP3Ng]h0g]kN0>CTi03Lg=`0g]kN0080
g=cL00L0f=SH0=kNgP39bLT0_;bl09FEU@1fMWH0O7al0080OWin00D0UYJF0<O7a`3=cLd0d=3@0<g=
c@020<O7a`@0`/;200D0^KVi0;2`/02OWil0Shn?0:6QX@0209JFUP0708V9R@21PH40MWIf06IVIP1M
GEd0GUiN03Lg=`0303<c<`060451@@0^;Rh0De=C06IVIP21PH40MWIf0P1^KVh01P2IVIT0WinO0<K6
aP24Q8@0YZJV0>[ZjR80moOg9`3oool002D0oooo403gmoL01`3_inL0oooo06/i8@1kBRT0FS4Q06/i
8@1cBS400P24DST01`1cBS40W6<i0;ES@P2eNeX0_HaS0<J4J`36W8@00P3_aZd0103Na[D0ikfL0>o6
]@3ge[d20>oFaP080?O6]@2eQ6/0YG]S0:EkH`2DLeX0]F]B0=JUQ03_aZD20?O>]@060?OF_@3gg/h0
mmk>0?OF_@3gg/h0kmK60`3ge[d20?O>]@80klJU00L0ijfD0;f<H`2DFT80Q58i09AJ@P2eJe80gZF4
0080ijfL00P0ilJ]0>o6[@3_aZd0kkFL0>NmY@3N[I@0gZF40;fDN`80YG]J00@0cYA[0;F<L`2eQ6/0
[G=B0P2LJdX02`2<FT80JcTQ06/i8@1[>B40DRTH05Xa8@1B:AP0DR4@07=B@P24FT80U6]B0080YG]J
00L0W7=B09AJ<@2mS6<0_HaS0=J]S02mU7/0aYb402<0moOg9@3oool@0?Ogm`050>[ZjP3oool0ADE5
05EEE@0k>c/00P15ADD01`1CDe<0GUiN05=CD`1_Kfl0N7Qh08V9R@2FUYH00P2EUID01P2VYZH0d=3@
0<c<c036a/H0dM7A0=kNgP<0g=cL00L0dm?C092@T025QHD0NWYj07inOP2`/;00clo?00<0f=SH00D0
g]kN0>CTi03Ng]h0i>CT0=cLg0040=kNgP80f=SH00@0clo?0;bl_02FUYH0JFUY0P1NGUh01@1YJFT0
OWin0;>c/`2m_Kd0cLg=0080d=3@0P34a<@01`37alL0^KVi0;>c/`2NWYh0Q8B40:6QX@2FUYH00P2@
T9001021PH40MWIf07IfMP1VIVH204E5A@0:03<c<`0k>c/0>c/k03<c<`0^;Rh0FUYJ06ATI01eMGD0
Q8B407alO080IfMW0P2FUYH00`2f][H0WYjN0:JVYP0S0?OgmbL0oooo000U0?ooo``0moOg00P0mnog
0?Ogm`3gmoL0oooo0;f][@3oool0Q58a07=2:@80LdXa00D0FS4Q08AB>@24DST0NdXY09AJ<@0209AJ
@P030:EkH`2eQ6/0aYb40080ilJe00P0kljm0;fDN`36W8@0eZF40=JLN`3NQ7<0]F]B0:ecDP80eYak
00<0mlje0?OF_@3ge[d01`3gg/h40>oFaP030?OF_@3_e/H0mlje00<0mlje00H0klj]0>NeW03FYH@0
]Hac09AcFP2<FT8209acDP080:eS@P3>JeX0]Hac0<J4J`2eQ6<0YG]S0:EkFP2eQ6/30;fDN`030=j4
L`2mS6<0[G=B0080W6]:00@0Q58i09a[BP128AP0@R4H0P1c@RT01@1[>B40DRTH048Y8@24HdX0W6]:
0080[G=B00L0W6]:09AS@P2mS6<0eYac0;F4J`2]Jd80g/jm01<0moOg00<0mnog0?Ogm`3gmoL03@3g
moLU0?ooo``0moOg0P3clo<01P3gmoL0oooo0;:b/P3oool0GEeM04i>CP<0De=C00@0>c/k05iNGP1E
EED0IfMW0P1YJFT02P25QHD0T92@092@T02VYZH0c/k>0=KFeP2NWYh0YZJV0;2`/02ZZZX209fMW@04
07inOP21PH40ZZZZ0=SHf080g]kN1`3Ti>@50=cLg0030=kNgP3Lg=`0f=SH0080f=SH00/0eMGE0<;2
`P2`/;00/;2`09JFUP1jNWX0IVIV07alO01fMWH0QhN709JFUP0209FEU@0408n?S`25QHD0Q8B4092@
T080WYjN00@0WIfM09JFUP2FUYH0PH610P1fMWH00`1NGUh0MWIf02XZ:P0304i>CP0704E5A@0c<c<0
;bl_06YZJP1fMWH0PH6107IfMP0206i^KP0509JFUP2YZJT0T92@07YjNP3AdM404`3gmoL00`3clo<0
moOg0?Ogm`0=0?OgmbL0oooo000U0?ooo``0moOg00H0mnog0?Ogm`3gmoL0moOg0<JUU02LLe8207=:
<@0308ASBP24DST0LdXa00<0LdXa00H0Q58i09AJ<@2<HdX0W7=B0:EkFP3FYH@20>O6]@80klje00H0
klJ]0=JUQ02mW8`0gXAc0=j]W03_e/H;0?ONcP030?ONeP3_e/H0kmK600<0mmk>0P3ge[d20>oFaP03
0?OF_@3gc[D0mlJe00<0klJ]0`3WaZd00`36W8@0YG]S0:ecDP020:EkH`030;fDN`36W8@0_IAk0080
cYA[00P0eYac0<jDJ`2mS6<0[G=B09acDP2]Le80Q58i06/i8@80LdXa00L0JcTQ05Xa8@0i6100>AP@
048Q602<HdX0U7=J0080S5Y200L0YG]J0:eS@P36U6/0aYb409a[BP2mS6<0knOW01H0moOg00<0mnog
0?Ogm`3gmoL02P3gmoLU0?ooo``0moOg0P3clo<20?Ogm`050:f][@1lO7`0De=C05=CD`1ZJVX00P1N
GUh305=CD`0405iNGP1WIfL0K6a/07alO080Q8B400L0/;2`0<k>cP3EeMD0eMGE0=3@d02`/;00Y:BT
0080WIfM00<0^[Zj0=cLg03Ti>@02@3Ti>@00`3UiND0g=cL0=cLg0040>CTi080g]kN00@0g=cL0=kN
gP3Hf=P0dm?C103@d=020<g=c@030:JVYP25QHD0PH6100<0QHF500H0WYjN0:JVYP2NWYh0XJ6Q0:VY
Z@2QXJ4209JFUP070861P@1lO7`0PH6105iNGP15ADD0De=C04E5A@0203/k>`808B4Q00D0:RXZ06a/
K01jNWX0IVIV08B4Q00207IfMP0509nOW`2VYZH0MWIf09JFUP3Zj^X05P3gmoL00`3clo<0moOg0?Og
m`0:0?OgmbL0oooo000U0?ooo`@0moOg0P3gkoL30?Ogm`030?O_m`3gmoL0moOg00@0moOg00L0e/K6
09a[BP1kFT80LdXa09akJ`2<Je80NeY20080Q58i00@0LdXa08aJ@P2<FT80S6=:0P2]Le80103FW7/0
klJ]0>o6[@3_a[D20>o>]@80mmJm0`3_e/H80?ONcP050?ONeP3gg/h0mmk>0?ONcP3_e/H00`3gg/h6
0>oFaP040?OF_@3_c[D0klje0?O>]@@0klJ]00P0ikfU0>O6[@3WaZd0ikFL0=j]U03N[H`0eZF<0=JL
N`80eZF400P0_IAk0;F<L`2eNeX0[G=B0:EkFP2]Le80W6]:07=:<@80JcTQ00L0DR4@03TH400i6100
>AP@048Q602eS7<0S6=:0080S5Y200H0eYac09a[BP2eNeX0eZf409a[BP36W8@T0?OgmbD0oooo303g
moL20??cl`80moOg00D0[Jf]07alO01CDe<0De=C06YZJP0205iNGP<0De=C00@0GUiN06MWI`1/K6`0
O7al0P24Q8@01`2`/;00c/k>0=GEe@3EeMD0d=3@0;2`/02TY:@00P2MWId00`2j^[X0g=cL0>CTi009
0>CTi0030>GUi@3Lg=`0g=cL00@0i>CT0P3Ng]h0103Lg=`0g]kN0=SHf03Cdm<40=3@d080cLg=00<0
YZJV08F5Q@21PH400`25QHD01P2NWYh0YZJV09jNWP2QXJ40ZJVY0:6QX@80UYJF00L0PH6107alO021
PH40GUiN04E5A@1CDe<0ADE50080>c/k0P0Q8B401@0Z:RX0K6a/07YjNP1VIVH0Q8B40080MWIf00D0
WinO0:JVYP1fMWH0UYJF0>[ZjP0F0?Ogm`030??cl`3gmoL0moOg00X0moOg9`3oool002D0oooo0P3g
moL00`3gkoL0moOg0?Ogm`030?Ogm`030?O_m`3gmoL0moOg00D0moOg00L0c[FU08A::@1cDT80Q5Y2
0:F<L`2DJe80Q58i0080Q5Y200L0NeY208AJ@P24FT80S5Y20:EkFP2LLe80eYak0080ilJ]0P3_c[D0
103_c[d0mmJm0?OF_@3_e/H20?ONcP80kmK600D0mmJm0?ONcP3gg/h0mmk>0?OF_@050?ONcP030?OF
_@3_e/H0mmk>0080kmK600<0mmk>0>oFaP3ge[d0103ge[d0103ga[D0mlje0>o6]@3_aZd20>O6[@05
0>NmY@3_aZd0ikFL0>NeW03N[I@00P3FYH@30=JLN`040;fDN`36U6/0_HaS0;E[DP80[G=B00@0S5Y2
09a[BP1c@RT0Ld8Y0P1B:AP01@128AP0FS4Q058Q402mU7/0YG]J0080S5Y200L0_IAk0:ecDP2LJdX0
eZf<09a[BP3F_Jd0oooo02<0moOg9@3oool50?Ogm`050??cl`3gmoL0moOg0?Ogm`3clo<01P3gmoL0
1@3;bl/0MWIf065QH@1CDe<0Ph>30080LW9b00<0HF5Q05iNGP1CDe<00P1VIVH01`1/K6`0PH610861
P@21PH40ZZZZ0=3@d03AdM400P3EeMD20=kNgP@0g=cL203Ti>@0103UiND0i>CT0>CTi03Lg=`40>CT
i0D0g=cL00D0g]kN0=GEe@3EeMD0eMGE0=SHf0030=3@d0030<O7a`3=cLd0cLg=0080`/;200L0^KVi
0;Rh^02a/K40ZZZZ0;2`/02NWYh0UYJF0080RHV900L0PH6108B4Q021PH40MWIf05=CD`15ADD0;Rh^
00@08B4Q00D0:RXZ09JFUP1/K6`0IVIV0:VYZ@0207IfMP0408V9R@2e]KD0MWIf0:JVYR@0moOg9`3o
ool002D0oooo0P3gmoL00`3gkoL0moOg0?Ogm`030?Ogm`030?O_m`3gmoL0moOg00D0moOg00L0c[FU
08A::@1cDT80Q5Y20:F<L`2DJe80Q58i0080Q5Y200L0NeY208AJ@P24FT80S5Y20:EkFP2LLe80eYak
0080ilJ]0P3_c[D0103_c[d0mmJm0?OF_@3_e/H20?ONcP80kmK600D0mmJm0?ONcP3gg/h0mmk>0?OF
_@050?ONcP030?OF_@3_e/H0mmk>0080kmK600<0mmk>0>oFaP3ge[d0103ge[d0103ga[D0mlje0>o6
]@3_aZd20>O6[@050>NmY@3_aZd0ikFL0>NeW03N[I@00P3FYH@30=JLN`040;fDN`36U6/0_HaS0;E[
DP80[G=B00@0S5Y209a[BP1c@RT0Ld8Y0P1B:AP01@128AP0FS4Q058Q402mU7/0YG]J0080S5Y200L0
_IAk0:ecDP2LJdX0eZf<09a[BP3F_Jd0oooo02<0moOg9@3oool20?Ogm`030??cl`3gmoL0moOg00<0
moOg00<0lo?c0?Ogm`3gmoL01@3gmoL01@2k^k/0F5QH05YJFP1TI6@0TI6A0080MGEe00<0GUiN06AT
I01QHF400P1TI6@01P1VIVH0Q8B407alO01lO7`0ZZZZ0<g=c@80eMGE00<0e]KF0=kNgP3Ng]h00P3L
g=`20>CTi0030=cLg03Ng]h0i>CT0080i>CT0P3Ng]h40>CTi0030=kNgP3Lg=`0i>CT00<0g=cL00<0
i>CT0=cLg03Ng]h00`3Ng]h20=?Cd`060=SHf03AdM40d=3@0<g=c@37alL0d=3@0`32`/800`2i^KT0
/;2`0;2`/0020:ZZZP0509jNWP2OWil0UYJF09JFUP1nOWh00P21PH400`1VIVH0MWIf04i>CP0303<c
<`0702XZ:P0k>c/0;Rh^09jNWP24Q8@0IVIV09jNWP020861P@0507IfMP2f][H0MWIf0<?3``3oool0
8`3gmoLW0?ooo`009@3oool@0?Ogm`070=k>aP24DST0S6]B08aSBP2LLe80S6=:08a[DP0208aSBP07
08AJ@P24DST0Q58a08AB<@2LJdX0W7=B0<J4J`020>NmW0040>o6]@3_c[D0klje0>o>_@80mmJm00D0
kmK60?ONcP3gg/h0mmk>0?OF_@0>0?ONcP@0kmK61@3gc[D0303_aZd0klJU0>O6[@3WaZd0klJ]0>Nm
Y@3W_I`0ikFD0=j]U03N[H`0eZF<0=JUQ080eYak00P0eYac0<jDJ`2eNeX0[G=B0;EkFP2LLe80W6]:
07=:<@80FS4Q00L0JcTQ05Xa8@0i6100>AP@048Q6036U6/0YG]S0080W6]:00H0eYac0;EcBP2<HdX0
_IAk09a[BP3gkoLT0?OgmbD0oooo403gmoL01@3Bd]80GUiN079bLP1/K6`0O7al0080K6a/00@0LW9b
06a/K01TI6@0GUiN0P1MGEd01P1fMWH0O7al07alO02EUID0a/K60=7Ad@80eMGE00D0e]KF0=kNgP3N
g]h0g]kN0=cLg0020>CTi0030=kNgP3Ti>@0i>CT00d0i>CT0`3Lg=`60=SHf0060=3@d03?cll0cLg=
0=3@d037alL0a/K60P31`L401`2i^KT0^;Rh0;6a/@2`/;00ZZZZ0:VYZ@2QXJ400P29RHT01`21PH40
RHV907alO01fMWH0De=C03/k>`15ADD00P0k>c/2024Q8@0502XZ:P2OWil0QHF507IfMP2YZJT00P22
PX80101/K6`0WYjN07IfMP3clo<T0?OgmbL0oooo000U0?ooo`H0moOg00<0mnog0?Ogm`3gmoL01`3g
moL00`3gkoL0S6=:08AB>@0208AB>@0;08ASBP2<HdX0Q58i08AB>@24FT80Q58i08AJ@P24DST0YG]J
0;EkFP36U6/00P3W]I`0103W_JD0klj]0>o>_@3gc[D20?OF_@80kmK61P3gg/h20?OF_@H0mmk>1@3_
e/H20?O6]@<0mlje00@0klj]0>o6[@3_aZd0klJ]0P3_]I`0203W_JD0ikfL0>NmY@3W]I`0gZf<0=j]
U03NYH@0eZF40P2mU7/0203>U6/0aXA[0;f<H`2eNeX0[G=B09a[BP24DST0LdXa0P1J>BT01`1c@RT0
@R4H03TH400i6100FS4Q09acDP3FW7<00P2eQ6<01@3FW7/0]G]J09acDP2DHd80cZfD01H0moOg0P3g
koL=0?OgmbD0oooo1P3gmoL00`3clo<0moOg0?Ogm`070?Ogm`030??cl`1/K6`0GUiN0080GUiN0P1Z
JVX01`1/K6`0GUiN06ATI01NGUh0I6AT05iNGP24Q8@00P29RHT01P2OWil0`/;20<O7a`3EeMD0e]KF
0=SHf0<0g]kN0P3Lg=`50>CTi0<0g]kN1@3Ti>@60=cLg0040=?Cd`3Hf=P0f=SH0=SHf080eMGE0`3@
d=001034a<@0alO70<K6aP37alL20<;2`P070;Rh^02i^KT0/k>c0;2`/02NWYh0XJ6Q09FEU@0209JF
UP0708V9R@21PH40MWIf05iNGP1CDe<0@D5104i>CP0202XZ:P808B4Q00D0>c/k07alO02YZJT0Shn?
0:ZZZP0208V9R@0307alO01^KVh0];Bd01H0moOg0P3clo<=0?OgmbL0oooo000U0?oooa00moOg00L0
oooo07]B@P2<Je80Q58i08aSBP2<Je80U6]B0080S6=:0P24FT801@24DST0S6=:09acDP2mS6<0_IAk
0080gZf<00<0ikfU0>o>]@3_c[d0103ge[d30?ONcP80mmJm0P3gg/h00`3ge[d0mmk>0?ONcP020>oF
aP<0mmk>0`3_e/H50?OF_@80mlje00@0klj]0>o6[@3_aZd0klJ]0P3_]I`40>NeW0040>N]U03N[H`0
eZF<0=JUQ080eYak00P0cYA[0;F<L`2eQ6<0]HAS0:EkH`2LJdX0S5Y206/i8@80LdXa00L0DR4@048Q
60128AP0>AP@048Y8@2DLeX0_IAk0080W7=B00D0aYA[0;f<H`2UQ6/0U6=20>O>aP0U0?OgmbD0oooo
403gmoL01@3oool0G5aL079bLP1NGUh0K6a/0080LW9b00L0MGEe06a/K01TI6@0I6AT05iNGP1/K6`0
O7al0080UYJF00D0WYjN0;Rh^037alL0eMGE0=KFeP050=kNgP80i>CT0P3Ng]h20>CTi080g]kN0P3T
i>@0103Lg=`0i>CT0>CTi03Ti>@40=cLg0@0g]kN0P3Hf=P20=GEe@<0d=3@00<0a<C40<;2`P32`/80
0`32`/801`2l_;`0^;Rh0;6a/@2`/;00ZZZZ0:6QX@2FUYH00`2?Shl01P25QHD0MWIf06IVIP15ADD0
De=C02h^;P<0:RXZ00H08B4Q02l_;`1jNWX0WYjN07alO02OWil209JFUP0308^;R`1^KVh0eMGE02D0
moOg9`3oool002D0oooo403gmoL0103oool0W7][07=B@P2<FT8209A[DP0:08AJ@P2<HdX0S6=:08AB
>@1kFT80U6]B08aSBP2LLe80]HA[0<JDJ`80eZF<00<0ikfU0>o6[@3gc[D00P3gc[D30?OF_@<0mmk>
00H0kmK60?OF_@3gg/h0mmk>0>oFaP3ge[d20?ONcP050?OF_@3_e/H0kmK60?OF_@3_e/H00`3ge[d2
0?O>]@060?OF_@3gc[D0mlje0>o6[@3gc[D0klJ]0`3_aZD0203W_JD0ikfL0>NmY@3W]I@0gZfD0=j]
S03FYH`0eZF40P2mU7/0103>U6/0aXA[0;F4H`2eQ6<209a[BP0608aJ@P1cBS40JcTQ06/i8@1B8A00
>AP@0P0Y40P00`1kDT80S6=:0:EkFP020:ecDP040<JLQ036U6/0eZf<0<JDJbH0moOg9@3oool@0?Og
m`040?ooo`23Ph<0FUYJ06IVIP<0MGEe00L0I6AT06a/K01NGUh0HF5Q07EeM@1/K6`0O7al0080T92@
00@0WinO0;6a/@37alL0d=3@0`3Hf=P40=kNgP80i>CT00<0g=cL0=kNgP3Ti>@00P3Ti>@0103Lg=`0
g]kN0>CTi03Ng]h20=cLg0030=kNgP3Lg=`0g=cL00<0g]kN00@0f=SH0=kNgP3Hf=P0f=SH0P3@d=00
1`3Hf=P0d=3@0<o?c`3?cll0alO70<K6aP37alL00P31`L401`2i^KT0^;Rh0;6a/@2`/;00WYjN0:6Q
X@2EUID00`2?Shl207IfMP0406IVIP1CDe<0ADE502h^;P808B4Q0P0F5QH01@1LG5`0K6a/08B4Q021
PH40YZJV0080WinO00<0][Jf09nOW`3gmoL09@3gmoLW0?ooo`009@3oool@0?Ogm`070?ooo`24DST0
YG]S0:EkFP2<FT80S6=:08ASBP0208aJ@P0708AJ@P2LHcT0Ld8Y08aSBP2UNf<0_HaS0;F<L`020=JU
Q0040>NmW03_aZd0klje0?O>]@<0mmJm0`3gg/h01`3_e/H0mmk>0?ONcP3gg/h0mmJm0?ONcP3ge[d0
0P3_e/H01@3gg/h0mmJm0>oFaP3_e/H0mmJm0080kmK61@3ge[d00`3_aZd0mlJe0>o>[@020>o6[@80
kkFL00<0klJU0>NeW03W]I`00P3N[I@00`3N[H`0eZF<0=JUQ0020;fDN`080=JLL`2eS7<0]HA[09ac
DP2DJe80Q5Y207=:<@24DST205Xa8@0703TH400Y40P0@RTQ02T@2024HdX0U6]B09a[BP0209AS@P80
aYA[00<0aYb40>ONeP3gmoL09@3gmoLU0?oooa00moOg00D0oooo05iNGP25QHD0Q8B406IVIP0206a/
K00706YZJP1VIVH0I6AT06m_K`1>CTh0K6a/08F5Q@0309JFUP050;2`/036a/H0d=3@0=GEe@3Hf=P0
103Ng]h20>CTi0040=cLg03Ti>@0i>CT0>CTi080g]kN00D0i>CT0=kNgP3Lg=`0i>CT0=kNgP020=cL
g080g]kN0P3Lg=`40=kNgP040=3@d03Cdm<0dm?C0=GEe@80d=3@00@0a<C40<o?c`32`/80`/;20`2i
^KT01P2h^;P0/K6a0;2`/02NWYh0ZJVY09JFUP80T92@00L0O7al07EeM@1TI6@0De=C05iNGP0k>c/0
8B4Q00805QHF00H0;bl_01HF5P1ZJVX0MGEe07IfMP1^KVh309nOW`030:JVYP3Ph>00moOg02D0moOg
9`3oool002D0oooo0P3gmoL0103gkoL0moOg0?O_m`3gkoL;0?Ogm`040>ONgP2UNf<0NeY207]J@P80
Q58i0P24DS401`24FT80Q58i08aSBP2<HdX0YG]J0;F<L`36W8@00P3FYH`00`3W_I`0klJ]0>o>]@02
0?OF_@030>oFaP3ge[d0mmk>0080mmk>00L0mmJm0?ONcP3ge[d0mmk>0?OF_@3_e/H0mmJm0080mmk>
00<0mmJm0>oFaP3_e/H0103ge[d01@3_e/H0mmJm0?OF_@3ge[d0mlJe0080mlje0`3_aZd20>neW004
0>o6Y@3W]I`0ikFL0=j]U0<0gZf<00H0eZF40<JLQ036W8@0eYak0;F4J`2UNf<209acDP0309a[BP1k
FT80JcTQ0080FS4Q0P0i61001@12:B40>AP@09A[DP2DJe80W7=B0080W6<i00<0aYA[0<JLQ03FYH`0
9`3gmoLU0?ooo`80moOg00@0lo?c0?Ogm`3gmoL0lo?c2`3gmoL0103QhN40QHF5065QH@1QHF4305iN
GP0305eMG@1TI6@0GUiN0080K6a/00P0Q8B409JFUP2FUYH0YZJV0;6a/@36a/H0d=3@0=GEe@80g]kN
0P3Lg=`01`3Ng]h0i>CT0>CTi03Ng]h0i>CT0=kNgP3Ti>@00P3Ng]h0103Lg=`0g]kN0>CTi03Ng]h2
0=cLg0D0g]kN00@0g=cL0=kNgP3Ng]h0dm?C0`3Hf=P30=3@d0040<C4a03?cll0`/;20<;2`P80^KVi
0`2h^;P0102`/;00YZJV0:ZZZP2@T90208F5Q@80O7al00@0MWIf065QH@15ADD0>c/k0`0Q8B401`0_
;bl08B4Q07EeM@1eMGD0O7al06m_K`2OWil00P2VYZH00`2a/K40moOg0?Ogm`0U0?OgmbL0oooo000U
0?oooa40moOg00H0oooo08aSBP1kFT80Q58i07=:<@24DS4207=B@P0707=:<@1kFT80S6=:09a[BP2e
Q6<0]Hac0=JLN`020=J]S0060>NmW03_aZd0mlje0?O6]@3ge[d0kmK61@3ge[d00`3_e/H0mmk>0?ON
cP020?ONcP<0kmK600<0mmk>0?OF_@3ge[d01`3ge[d01`3ga[D0mlje0?O>]@3gc[D0klJ]0?O>]@3_
aZd00`3_aZD01P3__I`0ikFL0=j]U03N[H`0eZF<0=j]S0<0eZF400P0_IAk0;F4J`2eQ6/0YG]S08aS
BP2<FT80JcTQ05Xa8@<0@R4H00H0:A0803TQ600i6100W7]S09A[DP2LHcT209AS@P030<JLQ03>]JD0
g/k602L0moOg9@3oool20?Ogm`040??cl`3gmoL0moOg0??cl`/0moOg00@0hN7Q08F5Q@1QHF40HF5Q
0`1NGUh00`1MGEd0I6AT05iNGP0206a/K00808B4Q02FUYH0UYJF0:JVYP2a/K40a/K60=3@d03EeMD2
0=kNgP80g=cL00L0g]kN0>CTi03Ti>@0g]kN0>CTi03Ng]h0i>CT0080g]kN00@0g=cL0=kNgP3Ti>@0
g]kN0P3Lg=`50=kNgP040=cLg03Ng]h0g]kN0=?Cd`<0f=SH0`3@d=001034a<@0clo?0<;2`P32`/82
0;Vi^@<0^;Rh00@0/;2`0:JVYP2ZZZX0T92@0P25QHD207alO00407IfMP1QHF40ADE503/k>`<08B4Q
00L0;bl_024Q8@1eMGD0MGEe07alO01_Kfl0WinO0080YZJV00<0/K6a0?Ogm`3gmoL09@3gmoLW0?oo
o`009@3ooolB0?Ogm`050<je]@24HdX0Q58i08AB>@24DS400`24DST01P1cDT80Q58i09a[BP2UNf<0
]Hac0<JLQ080gZfL00D0ikfU0>o6[@3gc[D0mlje0?OF_@020>oFaP030?ONcP3_e/H0kmK600D0mmk>
00T0kmK60?ONcP3ge[d0mmJm0>oFaP3gg/h0kmK60?OF_@3_e/H01@3ge[d01@3gc[D0mmJm0?O>]@3g
a[D0klj]0080klJ]0`3_aZD20>NeW0050=j]W03N[H`0gZf<0=JUQ03FYH`00`3>U6/01`2mS6<0YG]S
0:EkFP2LLe80S5Y205Xi:@1J<B400P128AP01`12:B40<APH048Q60128AP0YG]S0;F4J`2<FT800P2]
Le801@36U6/0ikfL0?Ogm`3gmoL0mnog02D0moOg9@3ooolA0?Ogm`040?ooo`1/K6`0HF5Q05iNGP80
De=C00L0GEeM05YJFP1CDe<0HF5Q06a/K01fMWH0Shn?0080UYJF00L0ZZZZ0;Jf]P36a/H0d=3@0=SH
f03Cdm<0g]kN0080g=cL103Ng]h00`3Lg=`0i>CT0>CTi0030>CTi080g=cL00<0i>CT0=kNgP3Ng]h0
1`3Ng]h00`3Cdm<0f=SH0=SHf0020=SHf0030=3@d03Hf=P0d=3@0080clo?00L0bLW90<;2`P2i^KT0
^KVi0;Rh^02a/K40^;Rh0080/;2`00T0WYjN092@T02@T900T92@08F5Q@1/K6`0IVIV04E5A@0k>c/0
0P0Z:RX201HF5P0702LW9`0Q8B40PX:207EeM@1_Kfl0KVi^0:JVYP020;^k^`030=;BdP3gmoL0moOg
02D0moOg9`3oool002D0oooo00<0moOg0?O_m`3gmoL03`3gmoL0103gkoL0S6]B07=:<@1cBS4307=B
@P0708AB>@1kFT80Le9209A[DP2eQ6<0_IAk0=JUQ0020=j]U0050>o6Y@3_aZd0klJe0>o>]@3gc[D0
1P3ge[d0103gg/h0mmJm0?ONcP3_e/H20?OF_@80kmK600<0mmJm0>oFaP3_e/H00`3ge[d0103_e/H0
mmJm0?OF_@3ge[d20?O>]@030>o>[@3gc[D0mlJe00@0klJ]0P3W_JD01@3W_I`0ikFD0=j]S03N[H`0
eZF<00<0eYak00P0]Hac0;f<H`2UNf<0W7=B08aSBP24DST0FSTY05Xa8@80@RTQ00L0@R4H058Y601B
:AP0>AP@09a[BP2eQ6<0W6]:0080aXAJ00<0eZF40=k>cP3gmoL09`3gmoLU0?oooa80moOg00<0_Kfm
06YZJP1NGUh00P1NGUh01`1MGEd0GUiN05iNGP1JFUX0GUiN07IfMP25QHD00P2FUYH0102VYZH0^[Zj
0<O7a`3@d=020=SHf0060=kNgP3Lg=`0g=cL0=cLg03Ti>@0g=cL1P3Ti>@01`3Lg=`0i>CT0=kNgP3L
g=`0i>CT0=cLg03Ng]h00P3Lg=`40=kNgP030=SHf03Ng]h0f=SH0080dm?C00<0eMGE0=3@d03@d=00
0P3?cll20<;2`P80^[Zj0P2h^;P01@2`/;00/K6a0:6QX@2QXJ40UYJF0080QHF500L0Q8B407alO01V
IVH0@D5103/k>`0Z:RX0;bl_00807alO0P0Z:RX01@25QHD0T92@06IVIP21PH40WinO0080a/K60P3g
moL00`3clo<0moOg0?Ogm`0S0?OgmbL0oooo000U0?ooo`030?Ogm`3gkoL0moOg00l0moOg00@0mnog
08a[DP1cBS40LdXa0`1cDT801`24DST0NeY207=B@P2DJe80]HAS0;fDN`3FYH@00P3N[I@01@3_aZD0
klJ]0>o6]@3_c[D0mlje00H0mmJm00@0mmk>0?OF_@3gg/h0kmK60P3ge[d20>oFaP030?OF_@3_e/H0
kmK600<0mmJm00@0kmK60?OF_@3ge[d0mmJm0P3gc[D00`3_cZd0mlje0?O6]@040>o6[@80ikfU00D0
ikfL0>NeU03N[H`0gZf<0=JUS0030=JLN`080;F<L`2mS6<0YG]S09acDP2<HdX0Q58i05Xi:@1J<B42
048Y8@07048Q601B:AP0DRTH03TH402LJdX0]HAS09a[BP020<J4FP030=JUQ03Nc/h0moOg02L0moOg
9@3oool00`3gmoL0lo?c0?Ogm`0?0?Ogm`030??cl`1bLW80De=C0080De=C0P1JFUX01@1NGUh0HF5Q
05YJFP1eMGD0Shn?0080WYjN00L0/;2`0;Vi^@3?cll0d=3@0=7Ad@3EeMD0f=SH00H0g]kN00<0i>CT
0=kNgP3Ti>@00P3Lg=`20=kNgP040=cLg03Ng]h0g=cL0=cLg0@0g]kN00<0g=cL0=kNgP3Ng]h00P3H
f=P0103EeMD0f=SH0=SHf03Cdm<30=3@d080alO700<0a/K60<71`@31`L400P2h^;P00`2a/K40ZZZZ
0:ZZZP0209JFUP80QHF500L0O7al06a/K01NGUh0@D5103/k>`0_;bl0:RXZ00<0<c<c00H08B4Q07If
MP2?Shl0MWIf09>CT`2`/;020=?CdbP0moOg9`3oool002D0oooo4`3gmoL0102UNf<0S6]B07=B@P24
FT8207]J@P0707=B@P1kFT80Q5Y209A[DP2LLe80aYA[0=J]S0030>NmY@030>o6[@3gc[D0mlje00<0
mmJm0`3_e/H20?ONcP030>oFaP3ge[d0mmJm00D0kmK60P3ge[d00`3_e/H0mmJm0?OF_@020?OF_@@0
mlje0P3_cZd00`3_aZd0klJU0>o6Y@020>o6[@040>NmY@3W_I`0ikFD0>N]U080gZf<0P3NYH@20<jD
J`060;F<L`2eQ6/0[G=B09a[BP2<FT80LdXa0P1J>BT2058Y6007048Q601B:AP0>AP@02T@202DJe80
W7=B09a[BP020;f<H`030=j]S03_knL0moOg02L0moOg9@3ooolC0?Ogm`0;08F5Q@1bLW80FUYJ05YJ
FP1TI6@0HF5Q05YJFP1QHF40I6AT07EeM@1lO7`00P2OWil0102f][H0alO70<O7a`3@d=020=SHf0@0
g]kN0P3Lg=`20>CTi0040=cLg03Ng]h0g]kN0=kNgP@0g=cL0P3Ng]h00`3Lg=`0g]kN0=kNgP030=kN
gP<0f=SH0`3EeMD01`3@d=00clo?0<o?c`3@d=00alO70<K6aP31`L400P2l_;`20;Rh^080/k>c00<0
XJ6Q09JFUP2@T9000P21PH400`1fMWH0IVIV05=CD`020451@@0;03<c<`0Z:RX0<c<c03<c<`0Q8B40
5QHF07EeM@1lO7`0MWIf09JFUP2h^;P00P3_knlX0?OgmbL0oooo000U0?oooa<0moOg00<0oooo0<je
]@2UNf<0102DJe8207]J@P0409A[DP2UQ6/0]Hac0=JLN`80ikFL00H0klJU0>o6[@3_aZd0mlje0>o>
]@3gc[D50>oFaP80mmJm00@0kmK60?ONcP3ge[d0kmK61@3ge[d00`3gc[D0mmJm0?O>]@040?O>]@03
0?OF_@3ga[D0mlje00@0klJU0P3_]I`01@3W_JD0ikfL0>NeU03N[I@0ikFD00<0eZF40`2eS7<01P2U
Nf<0YG]J08aSBP24DST0Ld8Y07=:<@<0FS4Q00L0@R4H03TH400Q40P0FSTY0;F4J`2LLe80]G=:0080
cYA[00<0cZfD0?Ogm`3gkoL09`3gmoLU0?oooa<0moOg00@0oooo0;fm_@25QHD0QHF50`1eMGD2065Q
H@0707EeM@2;Rh/0UYJF09JFUP2ZZZX0`/;20<o?c`020=3@d0040=SHf03EeMD0f=SH0=SHf0@0g=cL
0P3Ng]h01@3Lg=`0i>CT0>CTi03Ng]h0g=cL00@0g]kN00<0f=SH0=kNgP3Ng]h0103Hf=P00`3Ng]h0
dm?C0=SHf0050<o?c`040<C4a037alL0a/K60<71`@80^KVi00@0`L710;2`/02`/;00/;2`0P2FUYH0
1`25QHD0Q8B408B4Q01/K6`0GUiN04i>CP1CDe<00P0k>c/02P0Z:RX08B4Q024Q8@0D51@0@D51092@
T01lO7`0PX:20:6QX@2d];@20?Ogm`030??cl`3gmoL0moOg02D0moOg9`3oool002D0oooo00<0moOg
0?O_m`3gmoL02@3gmoL00`3gkoL0moOg0?Ogm`040?Ogm`80oooo00/0knOW09AcFP2DJe80U6]B08AJ
@P2<HdX0Q6=:08aSBP2]Le80_IAk0<JLQ0020=j]U0030>o6Y@3_aZd0klJ]0080mlje0P3ge[d0103g
c[D0kmK60>oFaP3_e/H60?OF_@80kmK61@3ge[d30?O>]@80mmJm00<0mlje0>o6[@3_aZd00P3_aZd0
103_aZD0klJ]0>nmW03__I`30>NeW0040>NeU03N[H`0eYak0=JUS0<0_IAk00H0_HaS0:ecDP2DFT80
Q58i08AJ@P1c@RT205Xi:@80@RTQ00L0DRTH024H600Q40P0YG]J0:EkH`2DHd80]G]J0080aXaS00<0
iljm0?Ogm`3gmoL09`3gmoLU0?ooo`030?Ogm`3clo<0moOg00T0moOg0P3clo<50?Ogm`80oooo0P3Z
j^X01`1jNWX0MGEe06ATI01/K6`0JVYZ06a/K021PH400P2NWYh00`2VYZH0^KVi0<o?c`020=3@d080
f=SH0`3Ng]h00`3Hf=P0g=cL0=cLg0070=kNgP030=cLg03Ng]h0g]kN00@0g]kN0`3Hf=P00`3Ng]h0
f=SH0=3@d0040=3@d0030<o?c`3@d=00bLW900<0`/;20P31`L400`2h^;P0ZZZZ0;6a/@0209jNWP07
09JFUP21PH40JFUY06UYJ@1NGUh0I6AT04i>CP020451@@0;02l_;`0c<c<06QXJ01XJ6P0D51@0Q8B4
08F5Q@1^KVh0RHV909VIV@3De=@0:P3gmoLW0?ooo`009@3ooolE0?Ogm`060?ooo`2mW9@0Q58i08AB
>@24HdX0Le920P2<HdX00`2UNeX0_HaS0=JLN`020=j]W0050>NmY@3_]I`0klJ]0>o6[@3gc[D00P3_
cZd30?O>]@<0mmJm00@0mlje0?OF_@3ge[d0mmJm0P3gc[D0103ge[d0klje0?O>]@3_c[d30?O>]@03
0>o>[@3_aZd0klJ]00<0klJ]00@0klJU0>o6[@3_aZD0klJU0P3_]I`30>NeW080gZfD00<0eZF<0=JL
N`3FYH@00P2eS7<0102UNf<0W6]:09AS@P2<FT8208AJ@P80FS4Q0P1B:AP01`0i6100:A080;F4J`2L
Nf<0W6]:09AS@P2mS6<00P3F]JD0103_inL0moOg0?O_m`3gkoLV0?OgmbD0oooo5@3gmoL20?ooo`04
0:FUY@1NGUh0JVYZ05YJFP80K6a/00L0Q8B409JFUP2FUYH0ZZZZ0;Zj^P37alL0a<C40080d=3@00@0
f=SH0=GEe@3EeMD0eMGE0P3Hf=P30=kNgP030=SHf03Ng]h0g]kN0080g]kN00D0f=SH0=kNgP3EeMD0
f=SH0=KFeP040=SHf0030=GEe@3@d=00d=3@0080d=3@0P3?cll0103@d=00clo?0<o?c`34a<@30<;2
`P<0^KVi00H0/K6a0:ZZZP2`/;00UYJF08F5Q@1fMWH206i^KP0306IVIP1TI6@0I6AT0080>c/k00/0
<c<c024Q8@0F5QH05QHF092@T022PX80MWIf06i^KP2FUYH0_Kfm0>[ZjP020?Ogm`80lo?c9P3gmoLW
0?ooo`009@3ooolE0?Ogm`070?ooo`3Nc[d0JcTQ06/i8@24FT80YG]J07]J@P020:EkFP090;f<H`36
W8@0gZfD0=j]U03W_I`0ilJ]0>o6[@3_aZD0klJ]0080mlje00H0mmJm0?O>]@3gc[D0kljm0?OF_@3g
c[D60?OF_@80mlje00H0mmJm0?O>]@3_aZd0mlje0>o6[@3gc[D30>o6[@030>o6Y@3_aZd0klJ]0080
klJU00<0ikfL0>nmW03__I`00P3W]I@01P3N[I`0gZf<0<j]U02mU7/0eYak0<jDJ`80]HA[00P0YG]S
09acDP2LJdX0Q5Y207=:<@1cDT80U6]B048Q6080>AP@00L0>B4H07]J@P24DST0YG]J09a[BP2]Le80
aYA[0080ikfU00@0mnog0?Ogm`3gkoL0oooo9P3gmoLU0?oooaD0moOg0P3oool01@3AdM40ADE506AT
I024Q8@0HF5Q0080Q8B40P2FUYH01`2VYZH0^KVi0<K6aP3=cLd0d=3@0<o?c`3@d=000`3Hf=P01@3N
g]h0f=SH0=KFeP3Ng]h0f=SH00H0g]kN0P3Hf=P01`3Ng]h0f=SH0=3@d03@d=00f=SH0=3@d03Hf=P0
0P3@d=00103?cll0d=3@0=3@d03@d=020<o?c`050<K6aP39bLT0`L710<71`@2j^[X00P2h^;P01`2d
];@0WYjN0:ZZZP2QXJ40T92@08F5Q@1lO7`00P1fMWH01`1TI6@0De=C05YJFP1eMGD0:RXZ024Q8@0W
9bL00P1QHF401`1NGUh0Q8B407IfMP21PH40WinO0<O7a`3clo<00P3gmoL00`3clo<0oooo0?Ogm`0U
0?OgmbL0oooo000U0?oooaD0moOg00@0oooo0<jeY@2LLe80W7=B0P24DST01@24HdX0YG]S0:EkFP2m
S6<0eYak0080gZfD00P0gZfL0>NmY@3_aZd0klJU0>o6[@3ga[D0klJ]0?OF_@80klj]1`3gc[D20?OF
_@80mlJe0`3_aZd00`3_]I`0klJ]0>o6Y@050>o6Y@030>o6[@3_aZD0klJU00<0ikFD00D0ikFL0=j]
U03N[I@0gZf<0=JUQ0020;fDN`050;F4J`2]Le80[G=B09acDP2DHd800P24FT8208AB>@0;05Xi:@1c
BS40FSTY05Xi:@1cBS40Ld8Y0:EkH`2LLe80]HAS0;f<H`3F[H`00P3F_Jd00`3gmoL0oooo0?Ogm`0W
0?OgmbD0oooo5@3gmoL20?ooo`050=7Ad@15ADD0I6AT08B4Q01QHF400P24Q8@209JFUP070:JVYP2i
^KT0a/K60<g=c@3@d=00clo?0=3@d0030=SHf0050=kNgP3Hf=P0e]KF0=kNgP3Hf=P01P3Ng]h20=SH
f0070=kNgP3Hf=P0d=3@0=3@d03Hf=P0d=3@0=SHf0020=3@d0040<o?c`3@d=00d=3@0=3@d080clo?
00D0a/K60<W9b@31`L40`L710;Zj^P020;Rh^0070;Bd]02NWYh0ZZZZ0:6QX@2@T900QHF507alO002
07IfMP0706ATI01CDe<0FUYJ07EeM@0Z:RX08B4Q02LW9`02065QH@0705iNGP24Q8@0MWIf0861P@2O
Wil0alO70??cl`020?Ogm`030??cl`3oool0moOg02D0moOg9`3oool002D0oooo5@3gmoL02`3oool0
aZFD0<JLQ036W8@0Ld8Y08AB<@1kFT80S5Y209acDP2eQ6<0_IAk0080aYb400D0e[FU0>NeW03W_JD0
klJU0>neW0020?O6]@<0klje00<0klJe0>o6[@3ga[D00P3gc[D0103ge[d0klJe0>o>]@3_c[D20>o6
[@050>o6Y@3_]I`0ikFL0>NeW03_]I@00`3_aZD0103__I`0kkFL0>nmW03_]I@20>NeW0040=j]S03W
[I@0ijfD0=j]U080eZF<00D0eYak0;fDN`2mU7/0]Hac0;F4J`020:ecDP040:EkFP2LJdX0Le9207=B
@P80LdXa00/0FT8i07=2:@1J<B40FS4Q0:F4J`2DJe80W7=B09a[BP3FW7/0aYA[0>NmW0040?Ogm`04
0?O_m`3gmoL0moOg0?oooa<0moOg00<0oooo0?Ogm`3gmoL03P3gmoLU0?oooaD0moOg0P3oool01`2k
^k/0O7al05iNGP1NGUh0JVYZ08F5Q@24Q8@00P2FUYH01`2ZZZX0^KVi0;Zj^P37alL0d=3@0<o?c`3@
d=000P3Cdm<00`3@d=00g]kN0=GEe@080=SHf0030=kNgP3Cdm<0dm?C00@0d=3@00<0a<C40=3@d03?
cll0103?cll20=3@d080clo?0P31`L400`32`/80^KVi0;Vi^@020;Rh^0070;2`/02NWYh0WYjN092@
T021PH40O7al06i^KP0306ATI080GUiN00@0@D5105=CD`11@D40De=C0P1>CTh01`25QHD0O7al08n?
S`2FUYH0][Jf0<?3``3gmoL00P3ooolX0?OgmbL0oooo000U0?oooaH0moOg00X0imkN0=k6aP3Na/H0
FS4Q07=2:@2LJdX0Q58i09acDP2UQ6/0]Hac0P3FYH`00`3N[I@0gZfL0>NeW0020>neW0030>o6Y@3_
aZd0ilJ]0080klJ]00L0klje0>o6[@3_aZd0klJ]0>o6]@3_aZd0klJU00<0klJ]00<0kkfL0>NeW03W
[H`00P3W[I@00`3W]I@0kkFD0>N]S0040>N]S0040=jUQ03N[H`0ijfD0=JUQ080gZf<0P3FYH@01036
W8@0eYac0;fDN`2eQ6/20;F4H`80YG]J00P0W7=B08aJ@P24FT80NeY207=B@P2<Je80NeY207=:<@80
S6]B00L0]HA[09AcFP2UNf<0_HaS0=JUQ03W_I`0e[f]0080mnog0`3gmoL00`3oool0moOg0?Ogm`0=
0?Ogm`030?O_m`3gmoL0moOg01@0moOg9@3ooolE0?Ogm`80oooo00L0[Jf]0:JVYP1>CTh0GEeM065Q
H@1VIVH0O7al0080Shn?00L0WYjN0:JVYP2m_Kd0`/;20<O7a`3?cll0a<C400<0dm?C0P3EeMD00`3A
dM40d=3@0=?Cd`030=SHf0030=kNgP3AdM40eMGE0080d=3@00<0clo?0<C4a032`/800P32`/801P33
`l<0clo?0<o?c`39bLT0a<C40<W9b@80`l?30P32`/800`2h^;P0_;bl0;Vi^@020;6a/@80ZZZZ0P2N
WYh01@2FUYH0T92@0861P@24Q8@0MWIf00<0FUYJ0P1CDe<01018B4P0CTi>03/k>`2;Rh/207EeM@05
07alO01fMWH0ZZZZ09nOW`36a/H0103gmoL0103clo<0moOg0?Ogm`3ooolC0?Ogm`030?ooo`3gmoL0
moOg00h0moOg9`3oool002D0oooo5`3gmoL20<JUU00709akJ`1kFT80Q5Y209A[DP2<HdX0W7=B0:Ek
H`020;fDN`040=JUS03W_I`0gZfL0=JeY@80ikFL1@3_aZd00`3WaZd0ikfU0>NmY@020>NmY@040>Ne
W03N[I`0gZfL0=j]S080gZfD0P3FYH@30=JLN`80eYac00D0gYak0=JLN`3FW7<0eYac0;fDN`050<jD
J`070<J4J`2eS7<0_IAk0;F<L`2eQ6/0]G]J09a[BP0208aSBP0309AcFP2DJe80LeY:0080U6]B00<0
LdXa08aSBP2LJdX00P2LJdX01`2LLe80W6]:0;f<H`2eQ6<0gZfD0>NmW03gknL0;03gmoLU0?oooaL0
moOg00L0hN7Q0<k>cP0k>c/0CTi>07IfMP1NGUh0O7al0080Rh^;00D0UYJF0;6a/@2i^KT0^[Zj0<;2
`P020<C4a080clo?00@0d=3@0<g=c@3@d=00eMGE0`3@d=020=7Ad@070=3@d03?cll0d=3@0=3@d039
bLT0`/;20;^k^`030;bl_0030<71`@33`l<0^k^k00<0^k^k0P2c/k<0102h^;P0_;bl0;2`/02h^;P2
0;2`/0050:JVYP2YZJT0ZJVY09jNWP2@T9000P2?Shl00`24Q8@0O7al06IVIP0206ATI007065QH@1J
FUX0LW9b065QH@1CDe<0LW9b092@T00207YjNP0608F5Q@2FUYH0/;2`0<K6aP33`l<0lo?c103gmoL0
0`3oool0moOg0?Ogm`0<0?Ogm`80lo?c5P3gmoLW0?ooo`009@3ooolG0?Ogm`80aZFD00L0W7][07]J
@P24FT80U6]B08aSBP2LLe80YG]S0080_IAk00@0eZF<0>NmW03N[I`0e[FU0P3W]I`50>o6[@030>O6
[@3W_JD0ikfU0080ikfU00@0ikFL0=j]W03N[I`0gZf<0P3N[I@20=JUQ0<0eYak0P3FW7<01@3NW7/0
eYak0=JLL`3FW7<0_IAk00D0cYA[00L0aXA[0;F<L`2mU7/0]Hac0;F4J`2eNeX0W6]:0080S6=:00<0
U7=J09A[DP1cFTX00P2DJe800`1cBS40S6=:09a[BP0209a[BP0709acDP2LJdX0_HaS0;F4H`3N[I@0
ikfL0?O_i`0/0?OgmbD0oooo603gmoL01P2][Jd0Ph>3065QH@1TI6@0MGEe06a/K080O7al00H0QHF5
09jNWP2a/K40a/K60;Zj^P2m_Kd30<;2`P@0d=3@00<0cLg=0<O7a`37alL00`37alL00`32`/80^[Zj
0;Rh^0020;Vi^@<0/;2`0`2ZZZX00`2YZJT0[:b/0:ZZZP030:VYZ@0309jNWP2QXJ40XJ6Q0080XJ6Q
00/0UIFE09JFUP2NWYh0WYjN09JFUP2@T900RHV907IfMP1/K6`0NWYj07EeM@02061PH080MGEe00D0
De=C06a/K01fMWH0MWIf07alO00207IfMP0509JFUP2?Shl0^KVi0<K6aP3alO40;03gmoLW0?ooo`00
9@3ooolI0?Ogm`070;f][@2DLeX0Q5Y208aSBP2DJe80YG]J0;F4J`020:EkJ`070;F<L`2mU7/0gZfD
0=JeY@3W_JD0klJU0>O6[@040>NmY@060>NmW03N[I@0gZfD0=JUQ03N[I@0ikfL0P3FYH`0203NYH@0
eZF40=JUS02mU7/0aYb40<J4J`3>U6/0_HaS0P3FW7/0103>Lf<0cYA[0;EkFP2eS7<20;EkFP040;f<
H`2eQ6<0]HAS0;F4H`80]HA[00D0YG]S0;F<L`2mU7/0YHA[0:F<L`020:EkFP080:EkH`2<HdX0S6=:
09AcFP2UNf<0Q5Y206/i8@24DST20;EkFP060;F4H`2eNeX0_HaS0<j]U03F]JD0e[f]203gmoL00`3g
koL0moOg0?Ogm`0A0?Ogm`030?ooo`3gmoL0moOg00h0moOg9@3ooolI0?Ogm`050;:b/P1jNWX0I6AT
06a/K01eMGD00P24Q8@01`2@T900QXJ609JFUP2NWYh0^KVi0;fm_@37alL00P3?cll01@3=cLd0alO7
0<O7a`37alL0a/K60080^KVi0P2`/;001`2i^KT0a/K60;6a/@2c/k<0/;2`0;6a/@2NWYh00P2VYZH0
1`2EUID0XJ6Q09JFUP2ZZZX0SHf=0:6QX@29RHT00P2FUYH208V9R@0309JFUP2?Shl0Shn?0080T92@
0P25QHD01P2FUYH0WYjN08^;R`2ATI40Q8B408F5Q@<0K6a/00L0NWYj08F5Q@1TI6@0ADE505iNGP29
RHT0Shn?0080RHV900@0UYJF0;Bd]02m_Kd0`l?3203gmoL00`3clo<0moOg0?Ogm`0A0?Ogm`030?oo
o`3gmoL0moOg00h0moOg9`3oool002D0oooo6P3gmoL01P3_inL0YHak09AcFP1kFT80W7=B0:EkFP80
S6=:00<0]Hac0<JLQ03F_Jd00`3Wa[D20>NmY@80e[FU00<0gZfL0=JUQ03>[I@00P3FYH`00`3FYH@0
eZF<0=JUQ0020=JUQ080aYA[0P2eS7<00`2eQ6/0]Hac0;F4J`020:ecDP070;F4J`2eQ6<0W7=B09a[
BP2eQ6/0W7=B0;F4H`0209acDP080:ecDP2UNf<0YG]J0:EkH`2<HdX0U6]B09AcFP2]Le8209AcFP08
09acDP2DLeX0W7=B08AB>@24FT80S6]B09a[BP2LLe830:EkFP040<JDJ`3F]JD0e[FU0<JLQ0D0moOg
00<0mnog0?Ogm`3gmoL04@3gmoL00`3gkoL0moOg0?Ogm`0B0?OgmbD0oooo6P3gmoL0103Zj^X0TY:B
07YjNP1QHF4207alO00508B4Q01/K6`0UYJF0:JVYP33`l<0103>c/h20<O7a`040;fm_@2j^[X0/;2`
0;Bd]0<0/K6a00@0/;2`0;6a/@2`/;00/;2`0P2OWil309JFUP07092@T02FUYH0T92@0861P@2@T900
Shn?07alO00207IfMP07092@T01lO7`0Shn?07alO021PH40QHF508B4Q00208F5Q@0706a/K01eMGD0
NWYj0861P@1jNWX0O7al07YjNP0207alO00505iNGP1TI6@0LW9b07IfMP1lO7`00P24Q8@209nOW`80
_Kfm00<0YZJV0?Ogm`3gmoL00P3gmoL20??cla<0moOg00<0lo?c0?Ogm`3gmoL04P3gmoLW0?ooo`00
9@3oool80?Ogm`030?O_m`3gmoL0mnog0100moOg00D0YHak0:EkJ`2UNf<0W7=S0:F<L`020<JUU005
0<jUU02mW8`0gZfL0<jUU03N[I`00P3F_Jd02P3N[I`0gZfD0=j]U03FYH`0eZF40=JUS02mU7/0aYb4
0=JUQ036W8@20<JDJ`080<JLQ02mU7/0aXA[0;F4H`2eQ6/0W7=B0;fDN`2UNf<20;fDN`070;F4H`2U
Nf<0_HaS0:EkFP2LJdX0_IAk0:EkFP020;F4J`080:EkH`2UNeX0YHA[0:F<L`24HdX0U6]B0:EkFP2L
Nf<208a[DP0809AcFP2UNf<0U6=209a[BP2DHd80W6]:09AS@P2LLe820;F4H`050=J]Q03>]JD0cZfD
0=J]S03Wc/H01@3gmoL00`3oool0moOg0?Ogm`0V0?OgmbD0oooo203gmoL00`3clo<0moOg0??cl`0@
0?Ogm`0309:BTP26QXH0QHF50080OWin00L0TI6A0:f][@2`/;00Y:BT0;Zj^P2`/;00^[Zj00<0`l?3
00H0^[Zj0;Vi^@2a/K40/;2`0;6a/@2NWYh20:JVYP070;2`/02VYZH0WinO0:JVYP2NWYh0UIFE08n?
S`02092@T00707alO02NWYh0QHF509jNWP2?Shl0QHF509JFUP0208B4Q00707IfMP2NWYh0Q8B4092@
T025QHD0Q8B408^;R`02096AT@0706YZJP1eMGD0Q8B408:2PP1bLW80NWYj08F5Q@0206i^KP0707If
MP1^KVh0MWIf06i^KP1lO7`0Shn?0;Fe]@020;^k^`030;Bd]02f][H0eMGE00@0moOg0P3ooolX0?Og
mbL0oooo000U0?ooo`80moOg00<0mnog0?Ogm`3gmoL05P3gmoL01@3oool0U7=J0:F4L`2LLf<0U6]B
0080YHA[0P2eS7<01P2mW8`0gZfL0=JeY@3N[I@0cZfD0=JUS080eZf<0`36W8@0102eS7<0_IAk0;F<
L`2mU7/20;F<L`080;fDN`2eQ6/0_IAk0:EkFP2LLe80YG][09AS@P2UQ6/20:EkFP070;F<L`2LLe80
YG]S0:EkFP2UNf<0aYA[08aSBP0309acDP070;F4J`2UNeX0U6]B09A[DP24FT80NeY207=:<@0207=B
@P0308aSBP24DST0Q58i0080NeY200<0U6=20;EcBP36U6/00P3F[H@0103WaZd0_Ib<0=J]S02eQ6<_
0?OgmbD0oooo0P3gmoL00`3clo<0moOg0?Ogm`0F0?Ogm`030?ooo`1jNWX0S8b<0080OWin00L0MGEe
08^;R`2FUYH0UYJF0:BTY02j^[X0_Kfm0080^KVi00<0];Bd0;6a/@2f][H00`2VYZH02P2FUYH0WYjN
09jNWP2FUYH0WYjN09JFUP2NWYh0T92@09jNWP24Q8@207alO00708J6QP1^KVh0Rh^;08B4Q02FUYH0
O7al08F5Q@0208B4Q00308F5Q@2OWil0K6a/0080O7al00<0T92@08B4Q01eMGD00P1eMGD01@1TI6@0
HF5Q05=CD`1JFUX0K6a/00<0GUiN0P1QHF401@1^KVh0PX:209nOW`2e]KD0cLg=0080Y:BT00<0][Jf
08n?S`3gmoL0;P3gmoLW0?ooo`009@3ooolL0?Ogm`040?ooo`2eU7/0YG][0:EkH`80_IbD00<0aYb4
0<JUU03F]JD00`3F]JD50<JLQ0040;fDN`36W8@0_IAk0;fDN`80]HA[0P2mU7/0102eQ6<0YG]J0:Ek
H`2DHd820:F4J`0708aSBP1cBS40YG]S0:EkH`24FT80]HAS0:EkFP020:EkH`0<08aJ@P2LJdX0YG]J
0:EkFP1c@RT0LdXa09aS>@2<FT80Q5Y208aJ@P2LHcT0U6=20P2LJdX209AS@P0608AB>@2LHcT0W6]:
0<j]U02mU7/0eZf<0P3F_Jd01@2<HdX0_Ib<0:F4J`3Nc/h0oooo00P0moOg00<0mnog0?Ogm`3gmoL0
8`3gmoLU0?ooo`80moOg00<0lo?c0?Ogm`3gmoL05P3gmoL00`3oool0NWYj08b<S00207inOP0707Ee
M@2;Rh/0UYJF09JFUP2TY:@0^[Zj0;fm_@020;Vi^@030;Bd]02a/K40][Jf00<0YZJV00X0UYJF09jN
WP2NWYh0UYJF09jNWP2FUYH0WYjN092@T02NWYh0Q8B40P1lO7`01`26QXH0KVi^08^;R`24Q8@0UYJF
07alO025QHD00P24Q8@00`25QHD0WinO06a/K00207alO003092@T024Q8@0MGEe0080MGEe00D0I6AT
065QH@1CDe<0FUYJ06a/K00305iNGP80HF5Q00D0KVi^08:2PP2OWil0]KFe0<g=c@020:BTY0030;Jf
]P2?Shl0moOg02h0moOg9`3oool002D0oooo7@3gmoL00`36YI`0YHAc08ASBP0209acH`0709a[BP2U
Q6/0aZFL0<jeY@3N[I`0e[FU0<JUU0030;fDN`070;F<L`2mU7/0_IAk0;F<L`2UQ6/0YHac0;F<L`02
0:EkH`80]HAS00H0S6=:0<JDJ`2UNeX0S6=:0;fDN`2<HdX208AJ@P070:EkH`2<HdX0S6=:09A[DP24
FT80S5Y208AB<@0207=2:@80Q58i00H0W6<i08AB>@1kFT80U6=208aJ@P24DST208A:<@0808aJ@P2L
Le80]HAS0;F4H`36W8@0_IAk0>NmW03F]JD20:F4J`030:EkFP2mW8`0YHA[00H0moOg00@0mnog0?Og
m`3gmoL0mnog403gmoL0103gkoL0moOg0?Ogm`3ooolB0?OgmbD0oooo703gmoL0203oool0Vi^K08J6
QP26QXH0QHF50:FUY@2VYZH0[Jf]1@2m_Kd40:JVYP0309jNWP2VYZH0WYjN0080WYjN0P2@T9001@2N
WYh0Shn?08B4Q025QHD0KVi^00<0Rh^;00H0K6a/05=CD`25QHD0I6AT08n?S`24Q8@308F5Q@0606IV
IP1fMWH0Q8B404i>CP1CDe<0Kfm_0P1VIVH01@1TI6@0IVIV06m_K`1^KVh0MWIf0080KVi^0P1NGUh0
1`1_Kfl0MWIf0;Bd]02NWYh0][Jf0<?3``1/K6`00P2TY:@00`2;Rh/0dm?C0?ooo`080?Ogm`030??c
l`3gmoL0moOg02<0moOg9`3oool002D0oooo7@3gmoL00`3oool0LeY:09akJ`020;fLS0080:EkJ`2U
Q6/0]IAk0<J]W03>]JD0eZF<0<JUU02UNf<20;F4J`070:F4J`2mU7/0_IAk0;F4J`2LLf<0]HA[0;F4
H`020:EkH`080;F<L`2UNf<0]HAS08AJ@P2LLe80U7=J08aSBP2UNeX208AJ@P0608aSBP2DHd80Q5Y2
08ASBP24FT80Le921024DST01@1cBS40Ld8Y08AB>@1kFT80Q58i0080Q58a0P2<HdX40:EkFP040<JL
Q03>]JD0W7]S09akH`80YHA[00<0aZFD0;fDN`3_inL00P3gkoL20?Ogm`80mnog0P3gmoL0103gkoL0
moOg0?Ogm`3oool50?Ogm`030?ooo`3gmoL0moOg01`0moOg9@3ooolM0?Ogm`0:0:j^[P2<S8`0S8b<
06YZJP1nOWh0MWIf08^;R`2^[Zh0^k^k0;Zj^P80_Kfm00@0[Jf]09jNWP2NWYh0UYJF0P2NWYh01P2F
UYH0Rh^;08^;R`2ATI40UYJF08F5Q@80Shn?00T0K6a/09nOW`24Q8@0Q8B406a/K02NWYh0K6a/06AT
I025QHD00P1/K6`207EeM@0406ATI01VIVH0GEeM04i>CP80GUiN00X0Kfm_05iNGP1NGUh0HF5Q06i^
KP1VIVH0GUiN05QHF01VIVH0O7al0`2?Shl01P2VYZH0WYjN0<K6aP2m_Kd0Rh^;08B4Q080Y:BT00<0
Rh^;0?Ogm`3gmoL00`3gmoL01@3clo<0moOg0?Ogm`3gmoL0lo?c0100moOg00@0lo?c0?Ogm`3gmoL0
oooo4P3gmoLW0?ooo`009@3ooolO0?Ogm`0709akJ`1cBS40LdXa0;FDN`2eW8`0_Ib<0;FDN`020=Je
Y@040<J]W02UNeX0]Hac0;F<L`80YG]S00<0]HAS0:EkFP2DLeX00P2UQ6/209AcFP080:EkH`2DLeX0
YG]S08AJ@P2UNeX0W6]:09A[DP1cDT8207=:<@060:EkFP1cDT80NeY208AJ@P1kFT80Q58a0`1cBS40
0`1[>B40FSTY07=2:@0207=2:@0308AB<@2LJdX0Q5Y20080S6=:00P0YHA[0<JLQ02mU7/0ikfU0<je
Y@2mW8`0YHac09A[DP80aYb400D0U6]B0>oWi`3oool0oooo0?O_m`0^0?OgmbD0oooo7@3gmoL02P3o
ool0H61P061PH023Ph<0Y:BT08J6QP2;Rh/0Vi^K0;>c/`2k^k/20;6a/@040:f][@25QHD0T92@08^;
R`80WYjN00X0T92@07inOP1nOWh0T92@08n?S`25QHD0UYJF08F5Q@2?Shl0I6AT0P1lO7`01`1jNWX0
K6a/08B4Q01TI6@0K6a/06i^KP1TI6@00P1ZJVX00`1TI6@0FUYJ05iNGP0205iNGP0605=CD`1>CTh0
GUiN05iNGP1QHF40GUiN0P1MGEd00`1/K6`0Q8B408B4Q00308B4Q0060:JVYP2k^k/0PX:208:2PP2;
Rh/0[Jf]0P2NWYh00`3Zj^X0lo?c0??cl`020?Ogm`050??cl`3gmoL0moOg0?Ogm`3clo<00P3gmoL0
0`3oool0moOg0?Ogm`030?Ogm`030?ooo`3gmoL0moOg01`0moOg9`3oool002D0oooo7@3gmoL00`3g
koL0moOg0?ooo`020:EkJ`0807=2:@2DLf<0YHAc0;FDN`3>]JD0e[f]0<J]W02UNeX209A[DP070;FD
N`2UNf<0]Hac0;FDN`2eQ6<0U6]B0:F4J`020:EkFP0808aSBP2UNf<0YG]S08aSBP2LLe80YG]J09Ac
FP2<Je8205Xa8@0307=:<@1kFT80YG]J0080Q58i00L0JcTQ08AB>@1c@RT0Ld8Y06/i8@1J<B40FSTY
0080FS4Q00<0LdXa08aJ@P2UQ6/00P2mU7/0202eQ6/0_IAk0<jeY@2eU7/0Q6=:09AkJ`2eQ6<0YHA[
0P2LJdX00`36YI`0moOg0?Ogm`040?Ogm`80mnog00<0moOg0?ooo`3gmoL02`3gmoL00`3gkoL0moOg
0?Ogm`080?Ogm`030?ooo`3gmoL0moOg00h0moOg9@3ooolP0?Ogm`0608>3P`1CDe<0Vi^K0::RXP2T
Y:@0Vi^K0`2m_Kd00`2c/k<0Q8B409JFUP0208F5Q@0408n?S`24Q8@0NWYj07YjNP80Rh^;00D0NWYj
08F5Q@1jNWX0QHF506ATI00208B4Q00707IfMP1eMGD0FUYJ05=CD`24Q8@0FUYJ065QH@0206ATI006
065QH@1MGEd0De=C05=CD`15ADD0@D51101>CTh01P1MGEd0MWIf06ATI01/K6`0Rh^;0:JVYP80WYjN
00L0alO70;^k^`2TY:@0TI6A07EeM@2VYZH0MGEe0080j^[Z0P3oool00`3clo<0moOg0?Ogm`0/0?Og
mbL0oooo000U0?ooo`H0moOg00<0mnog0?Ogm`3gmoL05`3gmoL20=k>cP0807][FP1kFT80Q6=:0:F<
L`2mW8`0aZfL0=JeY@2UQ6/209A[DP070:EkFP2eS7<0U7=J09AcFP2UNf<0S6]B08aSBP0209acH`08
09AcFP2<Je80U6]B0:EkH`2DLeX0S6=:0:EkFP2LLe8208a[DP0408aSBP1cBS40LdXa08ASBP80Q58i
00@0S5Y208AB<@24DS40W6]:0P24DS401@2DFS40W6]:0:ecDP2UNf<0_HaS0080aYb400L0g/Je0;FD
N`2mW8`0W7][07=:<@2DLeX0YHA[00<0]IAk1P3gmoL0103oool0moOg0?Ogm`3gkoL50?Ogm`030?oo
o`3gmoL0moOg00L0moOg00<0oooo0?Ogm`3gmoL05`3gmoLU0?oooad0moOg00X0lo?c0?Ogm`3gmoL0
oooo08J6QP1>CTh0Ng]k08b<S02KVi/0^k^k0P33`l<01`2c/k<0Q8B407EeM@2KVi/0QHF509JFUP2K
Vi/00P2?Shl0101eMGD0Rh^;08B4Q01/K6`208F5Q@0:06a/K01lO7`0O7al08B4Q01jNWX0LW9b03/k
>`1CDe<0HF5Q08B4Q0<0GUiN00H0ADE505iNGP1>CTh0ADE503/k>`11@D4303/k>`0605=CD`1VIVH0
Rh^;09jNWP2@T900WYjN0P2k^k/01`2KVi/0JVYZ0861P@2?Shl0Rh^;07IfMP2^[Zh01`3gmoL0103c
lo<0moOg0?ooo`3oool<0?Ogm`030??cl`3gmoL0moOg00P0moOg00<0oooo0?Ogm`3gmoL03P3gmoLW
0?ooo`009@3oool60?Ogm`030?O_m`3gmoL0moOg01L0moOg0P3Nc/h0201kJeX0NeY208ASBP2US7<0
_Ib<0<J]W03F]JD0YHA[0P2DJe801`2UNeX0]Hac09AcFP2DLeX0YG]S08a[DP2<HdX00P2LLf<0202D
LeX0S6]B09A[DP2UNf<0U7=J08aSBP2UNeX0W7=B0P2<Je80102<HdX0LdXa07=:<@24HdX208AB>@04
08aJ@P24DS40Q58a09a[BP80Q58a00D0U5Xa09a[BP2]Le80YG]S0;f<H`020<JLQ0070=k6]@2eU7/0
_Ib<09akJ`1cBS40U7=J0:F4J`030;FDN`H0moOg00@0oooo0?Ogm`3gmoL0mnog1@3gmoL00`3oool0
moOg0?Ogm`070?Ogm`030?ooo`3gmoL0moOg01L0moOg9@3oool60?Ogm`030??cl`3gmoL0moOg01P0
moOg00H0dm?C06i^KP1QHF40JVYZ096AT@2TY:@20;>c/`050;fm_@2;Rh/0MGEe08B4Q02FUYH00P1j
NWX208F5Q@07079bLP1/K6`0OWin07YjNP1bLW80MGEe08F5Q@0207YjNP0506a/K024Q8@0O7al079b
LP1/K6`00P1CDe<206YZJP80GUiN00<0IVIV05eMG@1fMWH00P1MGEd206MWI`0707IfMP21PH40QHF5
09JFUP2VYZH0c<c<09^KV`020:BTY00408>3P`1CDe<0NWYj08^;R`80Vi^K1`3gmoL00`3oool0moOg
0??cl`060?Ogm`030?ooo`3gmoL0moOg00L0moOg00<0oooo0?Ogm`3gmoL05`3gmoLW0?ooo`009@3o
oolR0?Ogm`080=Jm]@2DNf/0S7=J08ASDP24HdX0YHAc0:F<Q03F]JD208aSBP0608a[DP2LNf<0]HAS
09AcFP2DJe80Q5Y20`1kFT8208aSBP0609A[DP2DLeX0S6=:08aSBP2UNeX0YHA[0P2LLe801`2DLeX0
NeY20:EkFP24DST0Q58a09AcFP2DJe800P2<HdX0202DHd80W6]:0:EkFP2eQ6<0aYb40;F<L`2mU7/0
e[FU0P2mW8`0202eW8`0YHac0:F<L`1kFT80W7=S0:F<L`2UQ6/0YG][0P3oool01`3gmoL0oooo0?oo
o`3gmoL0mnog0?ooo`3gkoL00P3oool0103gmoL0mnog0?Ogm`3ooolB0?Ogm`030?ooo`3gmoL0moOg
0140moOg9@3ooolR0?Ogm`050<C4a021PH40N7Qh06][J`1ZJVX00P2<S8`01`2CTi<0_Kfm06a/K01b
LW80PX:208n?S`1jNWX00P1eMGD00`1TI6@0HF5Q065QH@0206a/K00307EeM@1jNWX0K6a/0080K6a/
00H0Q8B408^;R`1lO7`0NWYj065QH@24Q8@205iNGP0705eMG@1jNWX0MGEe06a/K01^KVh0MWIf08B4
Q00208n?S`060:JVYP2FUYH0WYjN0;fm_@2TY:@0XZ:R0`2ATI401`1QHF40OWin096AT@2;Rh/0QXJ6
0?ooo`3gmoL00`3oool01P3gmoL0lo?c0?ooo`3clo<0oooo0?Ogm`80lo?c00<0moOg0?ooo`3gmoL0
4@3gmoL00`3oool0moOg0?Ogm`0A0?OgmbL0oooo000U0?oooad0moOg00<0oooo0?Ogm`3gmoL00`3g
moL01`2m[Jd0U7=J09AcH`2LLf<0YHA[0:F<N`36W8@00P36YI@208a[DP80YHA[00<0U6]B0:F4J`24
DST00`24FT801`2LJdX0U6]B09acDP24DST0YG][09acDP2eS7<00P2UNf<00`2eQ6/0]IAk09A[DP02
08aJ@P80W7=B0`2eQ6<20;f<H`80eZF400<0aZFD0:EkH`2LNf/00P2LNf/0202<FT80Ld8Y08AB>@2U
Nf<0YHA[09akH`2mU7/0oooo103gmoL20?ooo`80moOg00<0oooo0?Ogm`3gmoL0:P3gmoLU0?oooad0
moOg00<0oooo0?Ogm`3gmoL00`3gmoL0102b/[80NWYj07]kN`1nOWh208^;R`0309:BTP2VYZH0[Jf]
0080LW9b0P2;Rh/207EeM@0708^;R`1NGUh0I6AT06ATI01fMWH0MGEe07alO00205iNGP0708J6QP1l
O7`0UYJF08F5Q@2@T900Vi^K07EeM@0306IVIP80O7al0P2?Shl209JFUP<0/;2`00H0[Jf]08F5Q@23
Ph<0Ph>306IVIP1>CTh205iNGP0508F5Q@2;Rh/0PX:209jNWP3oool0103gmoL20?ooo`80moOg00<0
oooo0?Ogm`3gmoL0:P3gmoLW0?ooo`009@3ooolM0?Ogm`030?O_m`3gmoL0moOg0080mnog0P3gmoL0
1P3>]KD0Q6=B09AcH`2US7<0]IAk0;fLS080aZFD00L0aZfL09AcFP2UQ6/0S6=:0:F4L`2DLeX0YG]S
0080U6]B00P0Q58i07]B@P1cBS40S6=:07]J@P2LLf<0W7=B0;fDN`80]Hac00D0g/Je0>O6]@3F]JD0
aYb40=j]W0040=JUS080ilJ]00H0gZfD0<jeY@2US7<0S6]B09akH`2DJe8208AJ@P0707]J@P2<HdX0
]HAS0;FDN`2UNf<0YG][0?ooo`030?Ogm`030?ooo`3gmoL0moOg00H0moOg00<0mnog0?Ogm`3gmoL0
0P3ooolU0?OgmbD0oooo7@3gmoL00`3oool0moOg0?Ogm`030?Ogm`040;:b/P1jNWX0Ng]k07inOP80
Rh^;00<0TY:B0:JVYP2][Jd00P1bLW8208^;R`80MGEe00L0Rh^;05iNGP1TI6@0I6AT07IfMP1eMGD0
O7al0080GUiN00L0QXJ607alO02FUYH0QHF5092@T02KVi/0MGEe00<0IVIV0P1lO7`208n?S`80UYJF
0`2`/;001P2][Jd0QHF508>3P`23Ph<0IVIV04i>CP80GUiN00D0QHF508^;R`22PX80WYjN0?ooo`04
0?Ogm`80oooo0P3gmoL00`3oool0moOg0?Ogm`0Z0?OgmbL0oooo000U0?ooob80moOg00P0oooo0?Og
m`3gmoL0knog09b4N`2DLf<0Lf=B0:F<L`<0c[FU00H0cZfD0:F4L`2eS7<0YHAc0:F<N`2UNf/20;fD
N`080<JUU02LNf/0Ne9208a[DP1kDT80U7=J0;FDN`36YI@20;fLS0070:F<N`3F_Jd0e[fe0=Jm[@3N
a[D0imK60>O>aP020=Jm[@080<JLQ02eU7/0]IAk0:F4L`2DLf<0U7=J09A[DP1cDT8208AB>@0509Ac
FP2LNf<0_IAk0:EkH`2eU7/00`3gmoL20?O_m`80moOg0P3gkoL30?Ogm`80mnog1P3gmoL00`3gkoL0
moOg0?Ogm`0Q0?OgmbD0oooo7@3gmoL01@3clo<0moOg0?Ogm`3gmoL0lo?c0080moOg00<0_Kfm06][
J`1kNg/00P2ATI401`2KVi/0Y:BT0:f][@2c/k<0NWYj08^;R`1/K6`00P2<S8`01`1jNWX0QHF507Ee
M@1NGUh0G5aL05=CD`1/K6`00P1QHF401`1nOWh0O7al09jNWP2FUYH0c<c<0<k>cP2m_Kd00P2VYZH0
102j^[X0/K6a0;6a/@2a/K420<g=c@0:0;Vi^@2k^k/0^k^k096AT@1bLW80PX:207EeM@1TI6@0HF5Q
06a/K080Shn?00@0Vi^K08F5Q@26QXH0oooo0P3gmoL00`3oool0moOg0?Ogm`060?Ogm`040??cl`3g
moL0moOg0?Ogm`80oooo9@3gmoLW0?ooo`009@3ooolR0?Ogm`080?ooo`3gmoL0moOg0?Ogm`3oool0
W7][08ASDP2LQ7<20:F<N`070<J]W03Na/H0aZfL0<J]W03F_KD0_Jf]0=k>_@020=Jm]@080<JUW03W
c/H0kmK60?O_i`3_imh0kmK60>O>aP3Wc[d20=Jm[@070=k>_@3Na[D0g/Je0=k6]@3Wc[d0c[FU0:F<
L`020<JUU0080:F<L`2LNf<0W7][09akJ`2<HdX0S6]B07=JBP2UNf<20:F<L`80YHA[00H0YG]S0?oo
o`3gmoL0moOg0?ooo`3gkoL50?Ogm`030?O_m`3gmoL0moOg00<0moOg00@0mnog0?Ogm`3gmoL0oooo
0P3gmoL01`3gkoL0moOg0?Ogm`3gmoL0mnog0?Ogm`3oool07@3gmoLU0?ooob80moOg00D0oooo0?Og
m`3gmoL0l?3`08Z:RP0207]kN`0706IVIP2ATI40^k^k0;^k^`2d];@0S8b<09JFUP0208b<S00709:B
TP26QXH0WYjN0:f][@23Ph<0G5aL079bLP0205aLG00707YjNP2KVi/0[Jf]0:BTY02BTY80`l?30<C4
a0020<?3``050<c<c03Jf]X0eMGE0<?3``2VYZH00P2KVi/208b<S00707]kN`1jNWX0MGEe05YJFP1N
GUh0NWYj08:2PP0209jNWP0308F5Q@2KVi/0moOg0080moOg00@0lo?c0?Ogm`3gmoL0moOg0P3clo<3
0?Ogm`030??cl`3gmoL0moOg00D0moOg00<0lo?c0?Ogm`3gmoL08@3gmoLW0?ooo`009@3ooolF0?Og
m`030?ooo`3gmoL0moOg00T0moOg00<0oooo0?Ogm`3gmoL00`3gmoL02P3Wg]h0Q6=B08acH`2<Lf<0
]IAk0;fUW03F_KD0g/jm0>OFcP3Nc/H40=k>_@070>OFcP3Na[D0ilJe0>O>_@3Wa[D0kmK60>oNcP02
0>OFcP070=k>_@3Wc/H0c[FU0;fLU03F_Jd0_Ib<0;FLS0020;fLU00808acFP2UNeX0S6=:08a[DP2L
Nf/0YHAc0;fLS036W8@20;F<L`070:F4J`36YI`0moOg0?Ogm`3gkoL0moOg0?O_m`080?Ogm`030?O_
m`3gmoL0moOg01L0moOg00D0oooo0?Ogm`3gmoL0oooo0?Ogm`020?O_m`d0moOg9@3ooolR0?Ogm`05
0?ooo`3gmoL0moOg0?Ogm`3oool00P23Ph<01@1[Jf/0RHV909:BTP2c/k<0c/k>0080/k>c0P34a<@0
1`2b/[80dM7A0<C4a02^[Zh0eMGE0=cLg03alO400P3YjNT01@3Lg=`0eMGE0=CDe033`l<0dM7A00@0
c<c<00H0e=CD0;^k^`2ATI40[Jf]096AT@22PX8308>3P`0506a/K01bLW80H61P08F5Q@2ATI400P2;
Rh/208F5Q@050?ooo`3gmoL0moOg0?ooo`3clo<01@3gmoL00`3clo<0moOg0?Ogm`020?Ogm`050??c
l`3gmoL0moOg0?Ogm`3oool00P3gmoL00`3clo<0moOg0?Ogm`020??cl`030?Ogm`3oool0moOg01`0
moOg9`3oool002D0oooo7`3gmoL00`3oool0moOg0?Ogm`020?ooo`060?Ogm`3oool0moOg0?Ogm`3o
ool0knOW0P2UQ7<01`2LQ7<0YHb40<jeY@3>]JD0e[fe0=K6]@3Nc[d01@3We/h01@3_imh0imkF0>OF
eP3We/h0kmk>0080ilk600L0g/jm0=Jm]@3>a[d0]Ib<0:F<Q02mW9@0W7]S0080W7][00P0U7=J0:F<
L`24He80YHak0;fLS036W8@0]Ib<0:F<N`80aYb400D0imkN0?Ogm`3gmoL0moOg0?O_m`030?Ogm`80
oooo00D0moOg0?ooo`3gmoL0moOg0?O_m`0:0?Ogm`030?ooo`3gmoL0moOg00H0moOg00<0oooo0?Og
m`3gmoL00`3gmoL00`3oool0moOg0?Ogm`020?Ogm`030?ooo`3gmoL0moOg00d0moOg9@3ooolG0?Og
m`030?ooo`3gmoL0moOg00P0moOg00<0oooo0?Ogm`3gmoL0103gmoL01`3QhN40Jf][07UiN@2KVi/0
Zj^[0<C4a03AdM400P3Kfm/01`3Bd]80dM7A0=7Ad@3AdM40fm_K0<c<c03>c/h00P3De=@01`3>c/h0
g=cL0>;RhP3Kfm/0dM7A0=GEe@2k^k/00P2UYJD01`33`l<0Y:BT0::RXP2UYJD0N7Qh08B4Q01/K6`0
0P1bLW801`23Ph<0S8b<0:BTY02VYZH0UYJF08^;R`2^[Zh00`3gmoL00`3clo<0moOg0??cl`080?Og
m`030??cl`3gmoL0moOg01L0moOg00D0oooo0?Ogm`3gmoL0oooo0?Ogm`020??cl`d0moOg9`3oool0
02D0oooo9`3gmoL00`3gkoL0moOg0?ooo`030?Ogm`050;FDS02LNf/0YHAc0<je]@3Na/H00`3We/h0
203We/H0ilk60=k6aP3We]H0g/k60=k6aP3F_KD0aZfL0P2mW8`01`2eU7/0aZFD0<J]W02eW8`0YHak
08A[DP2UNf/00P2eW8`0202US7/0aZfL0<J]W03>]JD0aZfL0:F<Q036[I`0mnog1`3gmoL00`3oool0
moOg0?Ogm`030?Ogm`060?O_m`3gmoL0moOg0?ooo`3gmoL0oooo103gmoL00`3gkoL0moOg0?ooo`06
0?Ogm`030?ooo`3gmoL0moOg00X0moOg0`3oool20?O_m`H0moOg00<0oooo0?Ogm`3gmoL0103gmoLU
0?ooob00moOg00H0oooo0?Ogm`3oool0oooo0?Ogm`3oool30?Ogm`050?ooo`3Zj^X0S8b<08V9R@2C
Ti<00P2k^k/20<C4a0030<W9b@3AdM40fm_K00<0fm_K00<0jNWY0>3Ph03Ph>000P3Kfm/01@3Rh^80
eMGE0=7Ad@34a<@0b<S80080XZ:R00L0Ti>C0:FUY@22PX80Ph>307YjNP2ATI40Jf][0080TY:B00H0
Y:BT0:JVYP2RXZ80TY:B0:JVYP3QhN440?Ogm`060??cl`3gmoL0moOg0?Ogm`3oool0moOg0P3oool2
0?Ogm`030??cl`3gmoL0moOg00P0moOg00<0oooo0?Ogm`3gmoL01P3gmoL00`3oool0moOg0?Ogm`03
0?Ogm`030?ooo`3gmoL0moOg0080moOg00<0oooo0?Ogm`3gmoL03@3gmoLW0?ooo`009@3ooolE0?Og
m`030?ooo`3gmoL0moOg00d0moOg00D0mnog0?ooo`3gmoL0moOg0?ooo`060?Ogm`030;fLU02eU8`0
a[Fe0080c[Fe00@0e[fe0>OFeP3We]H0imK>0P3We]H02`3We/h0e[fe0=Jm]@3F_KD0aZFL0;fUW02e
U8`0c[FU0=k>_@2mW9@0e[fe0080g/K600D0e[fe0;fLU02eU7/0e[f]0>oWi`030?ooo`@0moOg00<0
oooo0?Ogm`3gmoL00`3gmoL20?ooo`H0moOg00<0mnog0?Ogm`3gmoL01P3gmoL00`3oool0moOg0?oo
o`050?ooo`H0moOg00@0oooo0?Ogm`3gmoL0moOg0P3oool00`3gmoL0oooo0?ooo`0=0?OgmbD0oooo
9`3gmoL20??cl`070?Ogm`3oool0moOg0?Ogm`2MWId0Ph>308b<S0020;fm_@070<k>cP3Kfm/0fm_K
0=[JfP3EeMD0c/k>0=_Kf`020=;BdP070<k>cP34a<@0/k>c0:BTY02KVi/0[Jf]0;>c/`020::RXP05
09:BTP1`L700QXJ60::RXP2BTY800P2c/k<20;^k^`040;>c/`2CTi<0/k>c0??cl`L0moOg00<0oooo
0?Ogm`3gmoL00P3gmoL20??cl`80moOg00<0oooo0?Ogm`3oool0103gmoL00`3clo<0moOg0?ooo`06
0?Ogm`030?ooo`3gmoL0moOg00X0moOg0`3oool20??cl`H0moOg00<0oooo0?Ogm`3gmoL0103gmoLW
0?ooo`009@3ooolE0?Ogm`030?ooo`3gmoL0moOg00d0moOg00D0mnog0?ooo`3gmoL0moOg0?ooo`06
0?Ogm`030;fLU02eU8`0a[Fe0080c[Fe00@0e[fe0>OFeP3We]H0imK>0P3We]H02`3We/h0e[fe0=Jm
]@3F_KD0aZFL0;fUW02eU8`0c[FU0=k>_@2mW9@0e[fe0080g/K600D0e[fe0;fLU02eU7/0e[f]0>oW
i`030?ooo`@0moOg00<0oooo0?Ogm`3gmoL00`3gmoL20?ooo`H0moOg00<0mnog0?Ogm`3gmoL01P3g
moL00`3oool0moOg0?ooo`050?ooo`H0moOg00@0oooo0?Ogm`3gmoL0moOg0P3oool00`3gmoL0oooo
0?ooo`0=0?OgmbD0oooo5@3gmoL20?ooo`h0moOg00<0lo?c0?ooo`3gmoL00P3gmoL00`3oool0moOg
0?Ogm`030?Ogm`80YJFU00@0WIfM0;Zj^P2m_Kd0a<C41`3Kfm/20<C4a0030:j^[P2[Zj/0WIfM0080
^k^k00L0dM7A0:FUY@34a<@0c/k>0<C4a02UYJD0Vi^K0080`l?300@0j^[Z0?ooo`3oool0oooo0`3g
moL20?ooo`D0moOg00<0oooo0?Ogm`3gmoL01@3gmoL00`3clo<0moOg0?Ogm`060?Ogm`030?ooo`3g
moL0oooo00D0oooo1P3gmoL0103oool0moOg0?Ogm`3gmoL20?ooo`030?Ogm`3oool0oooo00d0moOg
9`3oool002D0oooo503gmoL00`3gkoL0moOg0?Ogm`0F0?Ogm`030?ooo`3gmoL0oooo0080moOg00H0
_Jf]0;fUW02mYI`0e[fe0<JUW03F_Jd20=k>aP030>ONeP3We]H0knON0080mnoW00L0knON0>OFcP3N
c[d0imK>0=k>aP3Nc[d0aZFL0080_Ib<00<0c[FU0=k>_@3_inL00P3gmoL20?ooo`030?O_m`3gmoL0
moOg00H0moOg00D0mnog0?Ogm`3gmoL0moOg0?O_m`030?Ogm`030?O_m`3gmoL0moOg00H0moOg00<0
mnog0?Ogm`3gmoL01P3gmoL0103gkoL0moOg0?ooo`3gkoL60?Ogm`030?O_m`3gmoL0moOg00<0moOg
00<0mnog0?Ogm`3gmoL02P3gmoLU0?oooa@0moOg00<0lo?c0?Ogm`3gmoL05P3gmoL00`3oool0moOg
0?ooo`030?Ogm`050;:b/P2[Zj/0a<C40:j^[P33`l<00`3Bd]801`3Ph>00fm_K0>WYj@3alO40jNWY
0=_Kf`3AdM400P3Kfm/01`3Bd]80dM7A0:j^[P2TY:@0^k^k0=7Ad@3Zj^X00`3gmoL20?ooo`030??c
l`3gmoL0moOg00H0moOg00@0lo?c0?Ogm`3gmoL0lo?c103gmoL00`3clo<0moOg0?Ogm`060?Ogm`03
0??cl`3gmoL0moOg00H0moOg00@0lo?c0?Ogm`3oool0lo?c1P3gmoL00`3clo<0moOg0?Ogm`030?Og
m`030??cl`3gmoL0moOg00X0moOg9`3oool002D0oooo5@3gmoL00`3oool0moOg0?Ogm`0A0?Ogm`05
0?O_m`3gmoL0moOg0?Ogm`3oool00P3gkoL30?Ogm`@0mnog0P3_inL0103Wg]h0mnoW0>oWgP3Nc[d3
0=Jm]@060=k>_@3Nc/H0g/K60=k6aP3Nc/h0knOW0P3gkoL50?Ogm`80oooo00<0moOg0?ooo`3oool0
0P3oool50?Ogm`<0mnog1P3gmoL01@3gkoL0moOg0?Ogm`3oool0mnog00<0moOg00<0oooo0?Ogm`3g
moL0203gmoL0103oool0moOg0?Ogm`3oool90?Ogm`030?ooo`3gmoL0moOg00H0moOg00@0oooo0?Og
m`3gmoL0moOg9@3ooolD0?Ogm`030??cl`3gmoL0moOg01H0moOg00<0oooo0?Ogm`3oool00`3gmoL0
1@2b/[80Zj^[0<C4a02^[Zh0`l?300<0d];B00L0h>3P0=_Kf`3YjNT0lO7a0>WYj@3Kfm/0dM7A0080
fm_K00L0d];B0=7Ad@2^[Zh0Y:BT0;^k^`3AdM40j^[Z00<0moOg0P3oool00`3clo<0moOg0?Ogm`06
0?Ogm`040??cl`3gmoL0moOg0??cl`@0moOg00<0lo?c0?Ogm`3gmoL01P3gmoL00`3clo<0moOg0?Og
m`060?Ogm`040??cl`3gmoL0oooo0??cl`H0moOg00<0lo?c0?Ogm`3gmoL00`3gmoL00`3clo<0moOg
0?Ogm`0:0?OgmbL0oooo000U0?oooaH0moOg00<0mnog0?Ogm`3gmoL02`3gmoL00`3oool0mnog0?Og
m`030?Ogm`80mnog2P3gmoL00`3oool0moOg0?Ogm`030?Ogm`D0mnog00<0oooo0?Ogm`3gmoL01@3g
moL20?ooo`<0moOg00<0oooo0?Ogm`3gmoL00`3gmoL00`3gkoL0moOg0?ooo`020?Ogm`030?ooo`3g
moL0moOg0080moOg00D0oooo0?Ogm`3oool0moOg0?ooo`020?Ogm`040?O_m`3gmoL0moOg0?O_m``0
moOg00D0mnog0?Ogm`3gmoL0moOg0?ooo`040?Ogm`030?ooo`3gmoL0moOg00h0moOg9@3ooolE0?Og
m`80oooo4`3gmoL0103clo<0moOg0?Ogm`3oool20??cl`@0moOg0`3clo<20>[ZjP80hN7Q00<0lO7a
0>WYj@3AdM400P34a<@00`3AdM40d];B0<k>cP020<k>cP030=?Cd`3Zj^X0lo?c00H0moOg0P3oool0
103gmoL0oooo0?ooo`3oool60?Ogm`80lo?c1`3gmoL00`3clo<0moOg0?ooo`020??cl`<0moOg00<0
oooo0?Ogm`3gmoL0203gmoL0103oool0moOg0?ooo`3oool90?Ogm`030?ooo`3gmoL0moOg00H0moOg
00@0oooo0?Ogm`3gmoL0moOg9`3oool002D0oooo:@3gmoL01P3gkoL0moOg0?Ogm`3gmoL0mnog0?oo
o`<0moOg00@0mnog0?Ogm`3gmoL0mnog0P3gmoL00`3oool0mnog0?Ogm`060?Ogm`040?ooo`3gmoL0
moOg0?O_m`L0moOg00<0oooo0?Ogm`3oool0103gmoL00`3gkoL0oooo0?Ogm`020?ooo`X0moOg00H0
oooo0?O_m`3gkoL0mnog0?Ogm`3gkoL90?Ogm`030?ooo`3gmoL0moOg00D0moOg00H0oooo0?Ogm`3g
moL0moOg0?O_m`3gmoL30?ooo`T0moOg00@0oooo0?Ogm`3gkoL0moOg9@3ooolG0?Ogm`030??cl`3g
moL0moOg00X0moOg00<0oooo0??cl`3gmoL0103gmoL00`3clo<0moOg0?Ogm`080?Ogm`030?ooo`3g
moL0moOg00@0moOg103clo<00`3oool0moOg0?Ogm`050?Ogm`80oooo103gmoL00`3oool0moOg0?Og
m`020?Ogm`80lo?c00D0moOg0?ooo`3gmoL0moOg0?ooo`040?Ogm`070?ooo`3gmoL0oooo0?Ogm`3o
ool0moOg0??cl`030?Ogm`030??cl`3gmoL0moOg00X0moOg00D0lo?c0?Ogm`3gmoL0moOg0?ooo`04
0?Ogm`030?ooo`3gmoL0moOg00h0moOg9`3oool002D0oooo5`3gmoL20?oooa<0moOg0P3oool30?Og
m`050?O_m`3gmoL0moOg0?Ogm`3oool00`3gmoL0103oool0moOg0?Ogm`3oool40?Ogm`030?O_m`3g
moL0moOg00D0moOg00<0mnog0?Ogm`3oool00P3gmoL20?ooo`@0moOg00H0mnog0?Ogm`3gmoL0mnog
0?Ogm`3oool50?Ogm`030?ooo`3gmoL0moOg00P0moOg00<0oooo0?O_m`3gmoL0103gmoL0103oool0
moOg0?Ogm`3oool30?Ogm`030?O_m`3gmoL0moOg00@0moOg00<0mnog0?ooo`3oool02`3gmoL00`3o
ool0moOg0?ooo`0T0?ooobX0moOg00D0lo?c0?Ogm`3gmoL0lo?c0?ooo`040?Ogm`030??cl`3gmoL0
lo?c0080moOg00<0oooo0??cl`3clo<01P3gmoL01@3oool0moOg0?Ogm`3gmoL0lo?c00L0moOg00<0
oooo0?Ogm`3oool00`3gmoL0103clo<0oooo0?ooo`3gmoL20?ooo`X0moOg00<0oooo0??cl`3clo<0
0P3gmoL00`3clo<0moOg0?Ogm`070?Ogm`030?ooo`3gmoL0moOg00D0moOg00H0oooo0?Ogm`3gmoL0
moOg0??cl`3gmoL30?ooo`T0moOg00@0oooo0?Ogm`3clo<0moOg9`3oool002D0oooo4`3gmoL0103o
ool0moOg0?Ogm`3gkoL30?Ogm`030?O_m`3gmoL0moOg00X0moOg00<0mnog0?ooo`3gmoL00`3gmoL0
0`3gkoL0moOg0?Ogm`020?Ogm`040?O_m`3oool0oooo0?O_m`<0moOg00@0oooo0?Ogm`3gmoL0moOg
0P3oool01@3gmoL0mnog0?Ogm`3gmoL0mnog00/0moOg00L0oooo0?Ogm`3gmoL0moOg0?O_m`3gmoL0
oooo00<0moOg00@0mnog0?ooo`3oool0oooo0P3gmoL00`3gkoL0oooo0?Ogm`040?Ogm`050?ooo`3g
moL0moOg0?Ogm`3oool0103gmoL0103oool0moOg0?Ogm`3oool20?Ogm`<0oooo0P3gmoL01@3oool0
moOg0?Ogm`3gmoL0mnog00T0moOg00<0oooo0?Ogm`3gmoL0103gmoLU0?oooaP0moOg00<0oooo0?Og
m`3gmoL04@3gmoL20?ooo`@0moOg00@0lo?c0?Ogm`3gmoL0oooo0`3gmoL20?ooo`80moOg00D0oooo
0?Ogm`3gmoL0moOg0??cl`070?Ogm`040??cl`3gmoL0oooo0?ooo`80moOg0P3oool30?Ogm`80lo?c
0P3gmoL00`3clo<0moOg0?ooo`050?Ogm`030?ooo`3gmoL0moOg00P0moOg00<0oooo0??cl`3gmoL0
103gmoL0103oool0moOg0?Ogm`3oool20?Ogm`80lo?c1P3gmoL00`3clo<0oooo0?ooo`0;0?Ogm`03
0?ooo`3gmoL0oooo02H0oooo000U0?oooaT0moOg00<0oooo0?Ogm`3gmoL05P3gmoL00`3gkoL0moOg
0?Ogm`020?Ogm`040?ooo`3gkoL0moOg0?ooo`D0moOg00<0oooo0?Ogm`3oool01`3gmoL00`3gkoL0
moOg0?ooo`0?0?Ogm`030?O_m`3gmoL0moOg00@0moOg0P3gkoL00`3oool0mnog0?ooo`020?Ogm`03
0?ooo`3gmoL0moOg0080mnog3@3gmoL00`3gkoL0moOg0?Ogm`080?Ogm`030?O_m`3oool0moOg00D0
moOg9@3ooolC0?Ogm`050?ooo`3gmoL0moOg0?Ogm`3clo<00P3gmoL00`3clo<0moOg0?Ogm`0:0?Og
m`80lo?c00D0oooo0?Ogm`3gmoL0moOg0??cl`050?Ogm`030??cl`3oool0lo?c00<0moOg0P3oool3
0?Ogm`030?ooo`3gmoL0lo?c00<0moOg00<0lo?c0?Ogm`3gmoL02@3gmoL0103oool0moOg0?Ogm`3c
lo<20?Ogm`050?ooo`3gmoL0moOg0?Ogm`3clo<00P3oool30?Ogm`030??cl`3oool0moOg00<0moOg
0P3oool30?Ogm`040?ooo`3gmoL0moOg0?Ogm`80oooo0P3gmoL00`3oool0moOg0?Ogm`020?ooo`<0
moOg00D0oooo0?Ogm`3gmoL0moOg0??cl`090?Ogm`030?ooo`3gmoL0moOg00@0moOg9`3oool002D0
oooo5P3gmoL00`3oool0moOg0?Ogm`0=0?Ogm`030?O_m`3gmoL0moOg00T0moOg0`3gkoL40?Ogm`03
0?O_m`3oool0oooo00<0moOg00<0oooo0?O_m`3gmoL0103gmoL20?ooo`030?Ogm`3gkoL0mnog0080
moOg00<0oooo0?O_m`3gmoL00P3oool01`3gmoL0oooo0?Ogm`3gmoL0oooo0?Ogm`3oool01P3gmoL0
0`3oool0moOg0?Ogm`040?Ogm`030?O_m`3gmoL0oooo00<0moOg00<0oooo0?Ogm`3gmoL00P3gmoL0
0`3oool0moOg0?ooo`020?Ogm`80oooo00<0mnog0?Ogm`3gmoL00`3gmoL01@3oool0moOg0?Ogm`3g
moL0oooo00X0moOg0P3gkoLU0?oooaT0moOg00<0oooo0?Ogm`3gmoL05`3gmoL01P3clo<0moOg0?Og
m`3gmoL0oooo0??cl`80moOg00<0oooo0?Ogm`3gmoL00P3gmoL0103oool0moOg0?ooo`3oool60?Og
m`040??cl`3gmoL0moOg0?ooo`h0moOg00<0lo?c0?Ogm`3gmoL01@3gmoL01@3clo<0oooo0??cl`3c
lo<0oooo0080moOg00@0oooo0?Ogm`3gmoL0lo?c3P3gmoL00`3clo<0moOg0?Ogm`080?Ogm`030??c
l`3oool0moOg00D0moOg9`3oool002D0oooo6@3gmoL00`3oool0moOg0?Ogm`0;0?Ogm`030?ooo`3g
moL0moOg0080mnog00<0moOg0?O_m`3gmoL01P3gmoL00`3oool0moOg0?Ogm`050?Ogm`80mnog00<0
oooo0?Ogm`3gmoL02P3gmoL0103gkoL0moOg0?ooo`3gmoL20?ooo`<0moOg00@0mnog0?ooo`3gkoL0
oooo103gmoL00`3gkoL0moOg0?Ogm`070?Ogm`030?ooo`3gkoL0mnog00<0moOg0P3gkoL40?Ogm`03
0?ooo`3gmoL0moOg00H0moOg00<0oooo0?Ogm`3gmoL0303gmoL0103gkoL0moOg0?ooo`3gmoLU0?oo
oaL0moOg00<0oooo0?Ogm`3gmoL0303gmoL00`3clo<0moOg0?Ogm`0:0?Ogm`80lo?c103gmoL20??c
l`80oooo0P3gmoL00`3oool0lo?c0?Ogm`050?Ogm`040?ooo`3gmoL0lo?c0??cl`<0moOg00H0oooo
0??cl`3gmoL0oooo0?Ogm`3oool30?Ogm`030?ooo`3gmoL0oooo00H0moOg00<0oooo0?Ogm`3gmoL0
0`3gmoL20??cl`030?Ogm`3oool0moOg0080moOg00<0oooo0?Ogm`3gmoL00P3gmoL00`3oool0moOg
0?ooo`020?Ogm`030?ooo`3clo<0lo?c00D0moOg00D0oooo0?Ogm`3gmoL0moOg0?ooo`0:0?Ogm`80
lo?c9`3oool002D0oooo6@3gmoL00`3oool0moOg0?Ogm`0;0?Ogm`030?ooo`3gmoL0moOg0080mnog
00<0moOg0?O_m`3gmoL01P3gmoL00`3oool0moOg0?Ogm`050?Ogm`80mnog00<0oooo0?Ogm`3gmoL0
2P3gmoL0103gkoL0moOg0?ooo`3gmoL20?ooo`<0moOg00@0mnog0?ooo`3gkoL0oooo103gmoL00`3g
koL0moOg0?Ogm`070?Ogm`030?ooo`3gkoL0mnog00<0moOg0P3gkoL40?Ogm`030?ooo`3gmoL0moOg
00H0moOg00<0oooo0?Ogm`3gmoL0303gmoL0103gkoL0moOg0?ooo`3gmoLU0?oooaT0moOg00<0oooo
0?Ogm`3gmoL02`3gmoL20?ooo`80moOg00<0lo?c0?Ogm`3clo<01`3gmoL00`3oool0moOg0?Ogm`06
0?Ogm`030??cl`3oool0moOg00`0moOg00D0lo?c0?Ogm`3oool0moOg0?ooo`040?Ogm`040??cl`3o
ool0lo?c0?ooo`<0moOg0P3clo<90?Ogm`030?ooo`3clo<0lo?c00<0moOg00<0lo?c0?Ogm`3gmoL0
0`3gmoL00`3oool0moOg0?Ogm`060?Ogm`030?ooo`3gmoL0moOg00`0moOg00@0lo?c0?Ogm`3oool0
moOg9`3oool002D0oooo6P3gmoL00`3gkoL0moOg0?Ogm`070?Ogm`050?O_m`3oool0moOg0?Ogm`3g
koL00`3gmoL20?O_m`<0moOg0P3oool40?Ogm`030?O_m`3gmoL0moOg0080moOg00P0mnog0?Ogm`3g
moL0moOg0?ooo`3gmoL0mnog0?ooo`H0moOg00H0oooo0?Ogm`3oool0moOg0?O_m`3oool20?Ogm`03
0?O_m`3gmoL0mnog0080moOg00<0oooo0?Ogm`3gmoL00P3gkoL20?Ogm`050?ooo`3gkoL0oooo0?Og
m`3gkoL00P3gmoL0103gkoL0oooo0?Ogm`3oool30?Ogm`030?O_m`3gmoL0moOg00l0moOg00<0mnog
0?Ogm`3gmoL03P3gmoLU0?oooaT0moOg00<0oooo0?Ogm`3gmoL02`3gmoL20?ooo`80moOg00<0lo?c
0?Ogm`3clo<01`3gmoL00`3oool0moOg0?Ogm`060?Ogm`030??cl`3oool0moOg00`0moOg00D0lo?c
0?Ogm`3oool0moOg0?ooo`040?Ogm`040??cl`3oool0lo?c0?ooo`<0moOg0P3clo<90?Ogm`030?oo
o`3clo<0lo?c00<0moOg00<0lo?c0?Ogm`3gmoL00`3gmoL00`3oool0moOg0?Ogm`060?Ogm`030?oo
o`3gmoL0moOg00`0moOg00@0lo?c0?Ogm`3oool0moOg9`3oool002D0oooo:03gmoL01P3oool0moOg
0?ooo`3oool0moOg0?O_m`80oooo00<0moOg0?O_m`3oool02@3gmoL30?ooo`@0moOg00<0oooo0?Og
m`3gmoL01@3gmoL00`3oool0moOg0?Ogm`040?Ogm`@0oooo103gmoL20?O_m`030?Ogm`3oool0moOg
0080moOg1@3oool60?Ogm`<0oooo103gmoL00`3gkoL0moOg0?Ogm`050?Ogm`030?ooo`3gmoL0moOg
0080moOg0P3oool40?Ogm`030?ooo`3gmoL0oooo00<0moOg00<0oooo0?Ogm`3gmoL09@3ooolJ0?Og
m`030??cl`3gmoL0moOg00L0moOg00<0lo?c0?ooo`3gmoL00P3gmoL00`3clo<0moOg0?Ogm`020??c
l`@0moOg0P3oool30?Ogm`030??cl`3gmoL0moOg00<0moOg00D0lo?c0?Ogm`3gmoL0oooo0?Ogm`02
0??cl`030?ooo`3gmoL0moOg00<0moOg00X0oooo0?Ogm`3gmoL0oooo0?Ogm`3clo<0oooo0?Ogm`3c
lo<0moOg0P3clo<20?Ogm`040?ooo`3gmoL0moOg0??cl`<0moOg00L0oooo0??cl`3oool0moOg0??c
l`3gmoL0lo?c0080oooo00<0moOg0?ooo`3gmoL00P3gmoL00`3clo<0moOg0?Ogm`0?0?Ogm`030??c
l`3gmoL0moOg00h0moOg9`3oool002D0oooo503gmoL00`3oool0moOg0?ooo`030?Ogm`030?O_m`3g
moL0mnog00H0moOg00<0oooo0?Ogm`3gmoL0103gmoL20?O_m`040?Ogm`3gkoL0moOg0?O_m`P0moOg
00<0mnog0?Ogm`3gmoL01@3gmoL00`3oool0moOg0?Ogm`020?Ogm`040?ooo`3gkoL0mnog0?Ogm`80
oooo303gmoL00`3oool0moOg0?Ogm`040?Ogm`030?O_m`3gmoL0moOg00D0moOg00<0oooo0?Ogm`3o
ool00P3gmoL0103gkoL0moOg0?ooo`3oool30?Ogm`030?ooo`3gmoL0moOg00L0moOg00<0mnog0?Og
m`3gkoL0403gmoLU0?ooobT0moOg00D0oooo0?Ogm`3oool0moOg0??cl`020?ooo`80moOg00<0lo?c
0?ooo`3gmoL0203gmoL20?ooo`D0moOg00<0oooo0?Ogm`3gmoL0103gmoL20?ooo`D0moOg1@3oool4
0?Ogm`040??cl`3gmoL0oooo0?ooo`<0moOg103oool70?Ogm`80oooo1@3gmoL00`3clo<0moOg0?Og
m`050?Ogm`030?ooo`3gmoL0moOg0080moOg0P3oool40?Ogm`030?ooo`3gmoL0oooo00<0moOg00<0
oooo0?Ogm`3gmoL09`3oool002D0oooo503gmoL00`3oool0moOg0?Ogm`020?ooo`l0moOg00<0mnog
0?Ogm`3gmoL01@3gmoL00`3oool0moOg0?ooo`0<0?Ogm`80oooo0`3gmoL0103gkoL0moOg0?Ogm`3g
moL20?ooo``0moOg0`3oool=0?Ogm`<0oooo4@3gmoL01@3oool0moOg0?O_m`3gmoL0mnog00<0moOg
00D0oooo0?Ogm`3gmoL0oooo0?O_m`080?OgmbD0oooo503gmoL0103oool0moOg0?Ogm`3oool20?Og
m`030??cl`3gmoL0lo?c00H0moOg00<0oooo0?Ogm`3gmoL01@3gmoL01@3clo<0moOg0??cl`3gmoL0
lo?c00P0moOg00<0lo?c0?Ogm`3gmoL01@3gmoL00`3oool0moOg0?Ogm`030?Ogm`030?ooo`3clo<0
moOg0080oooo3@3gmoL00`3oool0moOg0?Ogm`040?Ogm`030??cl`3gmoL0moOg00@0moOg0P3oool0
1`3gmoL0oooo0?Ogm`3gmoL0lo?c0?Ogm`3oool0103gmoL00`3oool0moOg0?Ogm`070?Ogm`030??c
l`3gmoL0lo?c0100moOg9`3oool00=T0oooo503gmoL01@3oool0moOg0?Ogm`3gmoL0oooo0100moOg
00<0lo?c0?Ogm`3gmoL0103gmoL20?ooo`030?Ogm`3oool0moOg00X0moOg0P3oool40?Ogm`030??c
l`3gmoL0moOg0080oooo3@3gmoL30?ooo``0moOg103ooolA0?Ogm`050?ooo`3gmoL0lo?c0?Ogm`3c
lo<00`3gmoL01@3oool0moOg0?Ogm`3oool0lo?c00P0moOg9`3oool00?l0ooooT@3oool00?l0oooo
T@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00840oooo
0T00003o0?ooo`h0oooo00230?ooo`03@000003oool0oooo0?l0oooo2`3oool004h0oooo0T000003
0?ooo`9000000P3oool3@00000<0oooo0T0000020?ooo`=000003@3oool3@00000070?oood000000
oooo@000003ooom000000?ooo`04@0000080oooo0d0000020?ooo`900000N`3oool2@00000030?oo
od00001000000080oooo0T0000000`3ooom00000@00000020?ooo`03@000003oool0oooo00900000
0P3oool3@00000070?oood0000100000@000003ooom000000?ooo`03@00000<0oooo0T0000001P3o
oom000000?oood000000oooo@0000080oooo0T00001L0?ooo`00C@3oool00d000000oooo0?ooo`02
0?ooo`04@000003oool0oooo@0000080oooo00E000000?ooo`3oool0oooo@00000020?ooo`04@000
003oool0oooo@00000l0oooo00U000000?ooo`3ooom000000?oood000000oooo@000003oool00d00
00020?ooo`06@000003oool0oooo@000003ooom00000O@3oool01d000000oooo0?ooo`3ooom00000
0?oood0000000P3oool00d000000oooo@00000020?ooo`03@000003ooom000000080oooo00=00000
0?oood000000103oool014000000oooo0?oood0000020?ooo`05@000003oool0oooo0?oood000000
0P3oool2@00000060?oood000000oooo@000003ooom00000GP3oool004d0oooo00=000000?ooo`3o
ool00P3oool014000000oooo0?oood0000020?ooo`05@000003oool0oooo0?oood0000000P3oool0
14000000oooo0?oood00000?0?ooo`08@000003oool0oooo@000003ooom000000?oood0000030?oo
o`04@000003oool0oooo@0000080oooo00=000000?oood0000000T00001k0?ooo`07@000003ooom0
00000?oood000000oooo@00000020?ooo`03@000003ooom000000080oooo00=000000?oood000000
0P3oool00d000000oooo@00000040?ooo`04@000003oool0oooo@0000080oooo00E000000?ooo`3o
ool0oooo@00000020?ooo`90000000D0oooo@000003ooom000000?ooo`03@00005`0oooo001=0?oo
o`03@000003oool0oooo00<0oooo0T0000030?ooo`03@000003oool0oooo0080oooo0T0000020?oo
o`A00000303oool2@0000080oooo0T0000000`3ooom000000?ooo`020?ooo`9000000`3oool3@000
00040?oood0000100000@00007/0oooo0T0000000`3ooom00000@00000020?ooo`90000000<0oooo
@000040000000T0000030?ooo`9000000P3oool3@0000080oooo0d0000020?ooo`A000000P3oool2
@00000050?oood00001000000?oood0000000P3oool3@00005`0oooo001=0?ooo`03@000003ooom0
000000P0oooo00=000000?ooo`3oool0Z03oool2@00000030?oood000010000001D0oooo00=00000
0?ooo`3oool0L03oool004d0oooo0d0000070?ooo`9000006@3oool00d000000oooo0?ooo`2>0?oo
o`90000000<0oooo@00004000000503oool2@0000780oooo003o0?oooi40oooo003o0?oooi40oooo
003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo
003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo
003o0?oooi40oooo003o0?oooi40oooo002G0?ooo`900000:`3oool3@00002T0oooo0T00002N0?oo
o`00V@3oool00d000000oooo0?ooo`0Y0?ooo`03@000003oool0oooo02X0oooo00=000000?ooo`3o
ool0V`3oool008/0oooo0d0000030?ooo`=000000`3oool3@00000D0oooo00=000000?ooo`3oool0
1D0000040?ooo`03@000003oool0oooo00P0oooo0d0000020?ooo`E0000000D0oooo@000003ooom0
00000?ooo`03@0000080oooo0d0000030?ooo`9000003P3oool3@00000070?oood000000oooo@000
003ooom000000?ooo`04@0000080oooo0d0000020?ooo`9000000P3oool2@00009D0oooo002<0?oo
o`03@000003oool0oooo00<0oooo00E000000?ooo`3oool0oooo@00000020?ooo`03@000003oool0
oooo00P0oooo00=000000?ooo`3oool03`3oool00d000000oooo@00000020?ooo`=0000000P0oooo
@000003ooom000000?oood000000oooo@0000080oooo00A000000?ooo`3ooom000000`3oool00d00
0000oooo0?ooo`0?0?ooo`09@000003oool0oooo@000003ooom000000?oood000000oooo00=00000
0P3oool01T000000oooo0?oood000000oooo@00000H0oooo00=000000?ooo`3oool0TP3oool008`0
oooo00=000000?ooo`3oool00`3oool01D000000oooo0?ooo`3ooom000000080oooo00=000000?oo
o`3oool0203oool00d000000oooo0?ooo`0A0?ooo`03@000003oool0oooo0080oooo00U000000?oo
od000000oooo@000003ooom000000?oood0000000P3oool014000000oooo0?oood0000030?ooo`=0
00003`3oool024000000oooo0?oood000000oooo@000003ooom000000`3oool014000000oooo0?oo
od0000020?ooo`03@000003ooom00000009000000`3oool00d000000oooo0?ooo`2C0?ooo`00S03o
ool2@00000<0oooo0T0000040?ooo`=000002P3oool00d000000oooo0?ooo`0@0?ooo`03@000003o
ool0oooo0080oooo0T0000001P3ooom00000@000003ooom000000?ooo`A000000`3oool014000000
oooo0?ooo`3oool3@00000h0oooo0T0000020?ooo`90000000<0oooo@000003oool00P3oool2@000
00<0oooo0d000000103ooom00000@000040000030?ooo`900000U03oool008`0oooo00A000000?oo
o`3ooom00000503oool00d000000oooo0?ooo`0?0?ooo`03@000003ooom000000180oooo00=00000
0?ooo`3oool0`P3oool008/0oooo1D0000020?ooo`03@000003oool0oooo00h0oooo0T00000A0?oo
o`=000004@3oool2@00001D0oooo00=000000?ooo`3oool0[03oool00?l0ooooT@3oool00?l0oooo
T@3oool00001\
\>"],
  ImageRangeCache->{{{0, 399}, {189.438, 0}} -> {-0.157534, -0.0238147, 
  0.00580218, 0.00580218}, {{27.125, 191.25}, {185.313, 
  21.1875}} -> {-34.0347, -6.90433, 0.897856, 0.897856}, {{207.688, 
  371.813}, {185.313, 21.1875}} -> {-193.676, -6.22906, 0.889305, 0.889305}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["2.4 Characteristic vector distribution",
  FontFamily->"Times New Roman"]], "Section"],

Cell[TextData[{
  StyleBox["\t",
    FontFamily->"Times New Roman"],
  StyleBox[
  "The list \[OpenCurlyDoubleQuote]monoSample\[CloseCurlyDoubleQuote] is a \
simple two-dimensional array that contains the numerical values representing \
the NTSC style monochrome image. When we regard the numerical values in the \
list \[OpenCurlyDoubleQuote]monoSample\[CloseCurlyDoubleQuote] as one of the \
scalar potentials, then it is possible to obtain a set of divergent fields by \
gradient operation. On the other side, when we regard the numerical values in \
the list \[OpenCurlyDoubleQuote]monoSample\[CloseCurlyDoubleQuote] as one of \
the vector potential components, a set of rotational vector fields can be \
computed by curl operation. In order to derive the divergent as well as \
rotational vector of the sample monochrome image shown in Fig.1, we define \
the \[OpenCurlyDoubleQuote]grad2D\[CloseCurlyDoubleQuote] and \
\[OpenCurlyDoubleQuote]curl2D\[CloseCurlyDoubleQuote] functions. The former \
and latter functions derive the divergent and rotational vectors, \
respectively. The \[OpenCurlyDoubleQuote]grad2D\[CloseCurlyDoubleQuote] \
function is defined by a following function, where a parameter \
\[OpenCurlyDoubleQuote]darta2D\[CloseCurlyDoubleQuote] refers to a list \
containing two-dimensional scalar potentials.",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Mathematica",
    FontFamily->"Century",
    FontSize->10.5,
    FontSlant->"Italic"],
  StyleBox[" function grad2D",
    FontFamily->"Century",
    FontSize->10.5]
}], "Subsubsection"],

Cell[TextData[{
  StyleBox["Gradient operation",
    FontWeight->"Bold"],
  ":\n\n",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox["V",
            FontWeight->"Bold"], "div"], TraditionalForm]]],
  " = - \[Del]U = -",
  Cell[BoxData[
      \(TraditionalForm\`\(\ \[PartialD]U\)\/\(\ \[PartialD]x\)\)]],
  StyleBox["i - ",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`\(\ \[PartialD]U\)\/\(\ \[PartialD]y\)\)]],
  StyleBox["j,\t\t\t\t\t\t\t\t\t",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  "(1)",
  StyleBox["\n\n",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  StyleBox["Where ",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"],
  StyleBox["V",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman",
    FontWeight->"Bold"],
  StyleBox["div",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman",
    FontVariations->{"CompatibilityType"->"Subscript"}],
  StyleBox[", ",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"],
  StyleBox["U",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox[", ",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"],
  StyleBox["i",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman",
    FontWeight->"Bold"],
  StyleBox[" and ",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"],
  StyleBox["j",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman",
    FontWeight->"Bold"],
  StyleBox[
  " are the divergent vector to be evaluated, input scalar potential and unit \
directional vectors in the direction of x- and y-axes, respectively.",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"]
}], "NumberedEquation",
  TextAlignment->Left,
  TextJustification->1],

Cell["\<\
grad2D=Compile[{{data2D,_Real,2}},
\tModule[{i=0,j=0,dim=Dimensions[data2D],
\t\tc1={Table[data2D[[1,j]],{j,dim[[2]]}]},
\t\tc2=Transpose[{Join[{data2D[[1,1]]},
\t\t\tTable[data2D[[i,1]],{i,dim[[1]]}]]}],
\t\te2D=AppendRows[c2,AppendColumns[c1,data2D]]},
\tTable[{-0.5(e2D[[i,j]]+e2D[[i+1,j]])+
\t\t\t0.5(e2D[[i,j+1]]+e2D[[i+1,j+1]]),
\t\t\t-0.5(e2D[[i,j]]+e2D[[i,j+1]])+
\t\t\t0.5(e2D[[i+1,j]]+e2D[[i+1,j+1]])},
\t\t\t{i,dim[[1]],1,-1},{j,dim[[2]]}]]];\
\>", "Input",
  CellLabel->"In[13]:="]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Mathematica",
    FontFamily->"Century",
    FontSize->10.5,
    FontSlant->"Italic"],
  StyleBox[" function curl2D",
    FontFamily->"Century",
    FontSize->10.5]
}], "Subsubsection"],

Cell[TextData[{
  StyleBox[" \t",
    FontFamily->"Times New Roman",
    FontSize->10.5],
  StyleBox[
  "Similarly, the \[OpenCurlyDoubleQuote]curl2D\[CloseCurlyDoubleQuote] \
function is defined by a following way, where a parameter \
\[OpenCurlyDoubleQuote]darta2D\[CloseCurlyDoubleQuote] refers to a list \
containing one of the vector potential components arraigned in a \
two-dimensional form. Both of the gradient and curl operations have been \
carried out by the central finite differences.",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell[TextData[{
  StyleBox["Curl operation",
    FontWeight->"Bold"],
  ":\n\n",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox["V",
            FontFamily->"Times New Roman",
            FontWeight->"Bold"], "rot"], TraditionalForm]]],
  " = - ",
  Cell[BoxData[
      \(TraditionalForm\`\[Del]\(\[Times]U\)\_z\)]],
  " = ",
  Cell[BoxData[
      \(TraditionalForm\`\(\ \[PartialD]U\_z\)\/\(\ \[PartialD]y\)\)]],
  StyleBox["i - ",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`\(\ \[PartialD]U\_z\)\/\(\ \[PartialD]x\)\)]],
  StyleBox["j,\t\t\t\t\t\t\t\t",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  "(2)",
  StyleBox["\n\n",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  StyleBox["Where ",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"],
  StyleBox["V",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman",
    FontWeight->"Bold"],
  StyleBox["rot",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman",
    FontVariations->{"CompatibilityType"->"Subscript"}],
  StyleBox[", ",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"],
  StyleBox["U",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox["z",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman",
    FontSlant->"Italic",
    FontVariations->{"CompatibilityType"->"Subscript"}],
  StyleBox[", ",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"],
  StyleBox["i",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman",
    FontWeight->"Bold"],
  StyleBox[" and ",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"],
  StyleBox["j",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman",
    FontWeight->"Bold"],
  StyleBox[
  " are the rotational vector to be evaluated, input z-component of vector \
potential and unit directional vectors in the direction of x- and y-axes, \
respectively.",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"]
}], "NumberedEquation",
  TextAlignment->Left,
  TextJustification->1],

Cell["\<\
curl2D=Compile[{{data2D,_Real,2}},
\tModule[{i=0,j=0,dim=Dimensions[data2D],
\t\tc1={Table[data2D[[1,j]],{j,dim[[2]]}]},
\t\tc2=Transpose[{Join[{data2D[[1,1]]},
\t\t\tTable[data2D[[i,1]],{i,dim[[1]]}]]}],
\t\te2D=AppendRows[c2,AppendColumns[c1,data2D]]},
\tTable[{-0.5(e2D[[i,j]]+e2D[[i,j+1]])+
\t\t0.5(e2D[[i+1,j]]+e2D[[i+1,j+1]]),
\t\t0.5(e2D[[i,j]]+e2D[[i+1,j]])-
\t\t0.5(e2D[[i,j+1]]+e2D[[i+1,j+1]])},
\t{i,dim[[1]],1,-1},{j,dim[[2]]}]]];\
\>", "Input",
  CellLabel->"In[14]:="],

Cell[TextData[{
  StyleBox["\t",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman",
    FontSize->10.5],
  StyleBox[
  "Let us compute the divergent as well as rotational vectors from the sample \
monochrome image. We apply the functions \[OpenCurlyDoubleQuote]grad2D\
\[CloseCurlyDoubleQuote] and \[OpenCurlyDoubleQuote] curl2D\
\[CloseCurlyDoubleQuote] to the list \[OpenCurlyDoubleQuote]monoSample\
\[CloseCurlyDoubleQuote]. After computing the divergent and rotational \
vectors, we plot the vector distributions. Figure 2 shows both of the \
divergent and rotational vector distributions, where the vectors are \
periodically sampled with 4 pixels.",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell[CellGroupData[{

Cell["\<\
divV=-grad2D[monoSample];
rotV=curl2D[monoSample];
dim=Dimensions[divV];
divVG=ListPlotVectorField[
\tTable[divV[[i,j,k]],{i,1,dim[[1]],4},
\t\t{j,1,dim[[1]],4},{k,dim[[3]]}],
\t\tFrame->False,PlotLabel->\"Div. vectors\",
\t\tDisplayFunction->Identity];
rotVG=ListPlotVectorField[
\tTable[rotV[[i,j,k]],{i,1,dim[[1]],4},
\t\t{j,1,dim[[1]],4},{k,dim[[3]]}],
\t\tFrame->False,PlotLabel->\"Rot. vectors\",
\t\tDisplayFunction->Identity];
Show[GraphicsArray[{divVG,rotVG}],ImageSize->{400,200},
\tPlotLabel->\"Fig.2. Vector distributions\"];\
\>", "Input",
  CellLabel->"In[15]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .47907 
%%ImageSize: 400 200 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0114064 0.47619 [
[.5 .49157 -83 0 ]
[.5 .49157 83 12.5625 ]
[ 0 0 0 0 ]
[ 1 .47907 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .49157 -144 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Fig) show
81.000000 12.812500 moveto
(.2) show
93.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(.) show
105.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Vector) show
147.000000 12.812500 moveto
(distributions) show
225.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
0 0 m
1 0 L
1 .47907 L
0 .47907 L
closepath
clip
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-0.02 0.005 moveto 0 0 lineto
-0.02 -0.005 lineto fill
-0.02 0.005 moveto 0 0 lineto
-0.02 -0.005 lineto
-0.02 0.005 lineto stroke
} ifelse
grestore
} def
/MAarrowzero1 {
gsave
mathtops translate
0 0 Mdot
grestore
} def
% End of user PostScript
% Start of sub-graphic
p
0.0238095 0.0114064 0.477324 0.467664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.00690327 0.0307128 -0.00119787 0.0307128 [
[.5 1.01855 -38 0 ]
[.5 1.01855 38 12.5625 ]
[ 0 0 0 0 ]
[ 1 1.00605 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.01855 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Div) show
81.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(.) show
93.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(vectors) show
135.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.0001 w
.02381 .02951 m
.02381 .02923 L
s
% Start of user PostScript
1. 1. 1. 0.990588 MAarrowhead1
% End of user PostScript
.05452 .02951 m
.05499 .02912 L
s
% Start of user PostScript
2. 1. 2.01522 0.987294 MAarrowhead1
% End of user PostScript
.08524 .02951 m
.08474 .02923 L
s
% Start of user PostScript
3. 1. 2.98384 0.990745 MAarrowhead1
% End of user PostScript
.11595 .02951 m
.11619 .03005 L
s
% Start of user PostScript
4. 1. 4.008 1.01741 MAarrowhead1
% End of user PostScript
.14666 .02951 m
.14743 .02932 L
s
% Start of user PostScript
5. 1. 5.02494 0.993569 MAarrowhead1
% End of user PostScript
.17737 .02951 m
.17766 .02991 L
s
% Start of user PostScript
6. 1. 6.00925 1.01271 MAarrowhead1
% End of user PostScript
.20809 .02951 m
.2147 .02472 L
s
% Start of user PostScript
7. 1. 7.21524 0.843863 MAarrowhead1
% End of user PostScript
.2388 .02951 m
.23922 .02909 L
s
% Start of user PostScript
8. 1. 8.01386 0.986137 MAarrowhead1
% End of user PostScript
.26951 .02951 m
.26951 .03044 L
s
% Start of user PostScript
9. 1. 9. 1.03024 MAarrowhead1
% End of user PostScript
.30022 .02951 m
.30017 .02946 L
s
% Start of user PostScript
10. 1. 9.99827 0.998275 MAarrowhead1
% End of user PostScript
.33094 .02951 m
.32947 .02965 L
s
% Start of user PostScript
11. 1. 10.9523 1.00449 MAarrowhead1
% End of user PostScript
.36165 .02951 m
.36246 .02946 L
s
% Start of user PostScript
12. 1. 12.0264 0.998275 MAarrowhead1
% End of user PostScript
.39236 .02951 m
.39236 .02951 L
s
% Start of user PostScript
13. 1. MAarrowzero1
% End of user PostScript
.42308 .02951 m
.4223 .03046 L
s
% Start of user PostScript
14. 1. 13.9747 1.0308 MAarrowhead1
% End of user PostScript
.45379 .02951 m
.45407 .0298 L
s
% Start of user PostScript
15. 1. 15.0093 1.00925 MAarrowhead1
% End of user PostScript
.4845 .02951 m
.48455 .02957 L
s
% Start of user PostScript
16. 1. 16.0017 1.00173 MAarrowhead1
% End of user PostScript
.51521 .02951 m
.51541 .02903 L
s
% Start of user PostScript
17. 1. 17.0063 0.984314 MAarrowhead1
% End of user PostScript
.54593 .02951 m
.54598 .02889 L
s
% Start of user PostScript
18. 1. 18.0017 0.979765 MAarrowhead1
% End of user PostScript
.57664 .02951 m
.57664 .02855 L
s
% Start of user PostScript
19. 1. 19. 0.968627 MAarrowhead1
% End of user PostScript
.60735 .02951 m
.60735 .02941 L
s
% Start of user PostScript
20. 1. 20. 0.996549 MAarrowhead1
% End of user PostScript
.63807 .02951 m
.63807 .02941 L
s
% Start of user PostScript
21. 1. 21. 0.996549 MAarrowhead1
% End of user PostScript
.66878 .02951 m
.66883 .02946 L
s
% Start of user PostScript
22. 1. 22.0017 0.998275 MAarrowhead1
% End of user PostScript
.69949 .02951 m
.70505 .02395 L
s
% Start of user PostScript
23. 1. 23.1811 0.818922 MAarrowhead1
% End of user PostScript
.7302 .02951 m
.72974 .02894 L
s
% Start of user PostScript
24. 1. 23.9849 0.981431 MAarrowhead1
% End of user PostScript
.76092 .02951 m
.76074 .02866 L
s
% Start of user PostScript
25. 1. 24.9941 0.972176 MAarrowhead1
% End of user PostScript
.79163 .02951 m
.79101 .02957 L
s
% Start of user PostScript
26. 1. 25.9798 1.00173 MAarrowhead1
% End of user PostScript
.82234 .02951 m
.82201 .02975 L
s
% Start of user PostScript
27. 1. 26.989 1.00753 MAarrowhead1
% End of user PostScript
.85306 .02951 m
.85297 .0296 L
s
% Start of user PostScript
28. 1. 27.9972 1.00276 MAarrowhead1
% End of user PostScript
.88377 .02951 m
.88396 .02971 L
s
% Start of user PostScript
29. 1. 29.0063 1.00627 MAarrowhead1
% End of user PostScript
.91448 .02951 m
.91283 .02776 L
s
% Start of user PostScript
30. 1. 29.9463 0.942882 MAarrowhead1
% End of user PostScript
.94519 .02951 m
.94636 .03068 L
s
% Start of user PostScript
31. 1. 31.038 1.03798 MAarrowhead1
% End of user PostScript
.97591 .02951 m
.97228 .029 L
s
% Start of user PostScript
32. 1. 31.8818 0.983157 MAarrowhead1
% End of user PostScript
.02381 .06023 m
.02381 .06023 L
s
% Start of user PostScript
1. 2. MAarrowzero1
% End of user PostScript
.05452 .06023 m
.05506 .06026 L
s
% Start of user PostScript
2. 2. 2.01741 2.0011 MAarrowhead1
% End of user PostScript
.08524 .06023 m
.08566 .06009 L
s
% Start of user PostScript
3. 2. 3.01396 1.99545 MAarrowhead1
% End of user PostScript
.11595 .06023 m
.11595 .06109 L
s
% Start of user PostScript
4. 2. 4. 2.02792 MAarrowhead1
% End of user PostScript
.14666 .06023 m
.14666 .06023 L
s
% Start of user PostScript
5. 2. MAarrowzero1
% End of user PostScript
.17737 .06023 m
.17805 .05848 L
s
% Start of user PostScript
6. 2. 6.02208 1.9431 MAarrowhead1
% End of user PostScript
.20809 .06023 m
.20823 .05958 L
s
% Start of user PostScript
7. 2. 7.00471 1.97886 MAarrowhead1
% End of user PostScript
.2388 .06023 m
.24221 .06295 L
s
% Start of user PostScript
8. 2. 8.11096 2.08857 MAarrowhead1
% End of user PostScript
.26951 .06023 m
.27008 .06051 L
s
% Start of user PostScript
9. 2. 9.01857 2.00916 MAarrowhead1
% End of user PostScript
.30022 .06023 m
.30028 .06017 L
s
% Start of user PostScript
10. 2. 10.0019 1.99806 MAarrowhead1
% End of user PostScript
.33094 .06023 m
.33049 .05978 L
s
% Start of user PostScript
11. 2. 10.9855 1.98545 MAarrowhead1
% End of user PostScript
.36165 .06023 m
.36199 .06056 L
s
% Start of user PostScript
12. 2. 12.011 2.01098 MAarrowhead1
% End of user PostScript
.39236 .06023 m
.39208 .06051 L
s
% Start of user PostScript
13. 2. 12.9907 2.00925 MAarrowhead1
% End of user PostScript
.42308 .06023 m
.42409 .06017 L
s
% Start of user PostScript
14. 2. 14.0331 1.99827 MAarrowhead1
% End of user PostScript
.45379 .06023 m
.45399 .06099 L
s
% Start of user PostScript
15. 2. 15.0064 2.02494 MAarrowhead1
% End of user PostScript
.4845 .06023 m
.48479 .06051 L
s
% Start of user PostScript
16. 2. 16.0093 2.00925 MAarrowhead1
% End of user PostScript
.51521 .06023 m
.51482 .06155 L
s
% Start of user PostScript
17. 2. 16.9871 2.04316 MAarrowhead1
% End of user PostScript
.54593 .06023 m
.54639 .0608 L
s
% Start of user PostScript
18. 2. 18.0151 2.01857 MAarrowhead1
% End of user PostScript
.57664 .06023 m
.57612 .06085 L
s
% Start of user PostScript
19. 2. 18.9832 2.02029 MAarrowhead1
% End of user PostScript
.60735 .06023 m
.60773 .06156 L
s
% Start of user PostScript
20. 2. 20.0121 2.04351 MAarrowhead1
% End of user PostScript
.63807 .06023 m
.63858 .06085 L
s
% Start of user PostScript
21. 2. 21.0168 2.02029 MAarrowhead1
% End of user PostScript
.66878 .06023 m
.66878 .06126 L
s
% Start of user PostScript
22. 2. 22. 2.03369 MAarrowhead1
% End of user PostScript
.69949 .06023 m
.7001 .06065 L
s
% Start of user PostScript
23. 2. 23.0198 2.01386 MAarrowhead1
% End of user PostScript
.7302 .06023 m
.7333 .05975 L
s
% Start of user PostScript
24. 2. 24.1007 1.98441 MAarrowhead1
% End of user PostScript
.76092 .06023 m
.76097 .06017 L
s
% Start of user PostScript
25. 2. 25.0017 1.99827 MAarrowhead1
% End of user PostScript
.79163 .06023 m
.79148 .06037 L
s
% Start of user PostScript
26. 2. 25.9953 2.00471 MAarrowhead1
% End of user PostScript
.82234 .06023 m
.82186 .05975 L
s
% Start of user PostScript
27. 2. 26.9843 1.98431 MAarrowhead1
% End of user PostScript
.85306 .06023 m
.85359 .06145 L
s
% Start of user PostScript
28. 2. 28.0174 2.0398 MAarrowhead1
% End of user PostScript
.88377 .06023 m
.88415 .06053 L
s
% Start of user PostScript
29. 2. 29.0124 2.00988 MAarrowhead1
% End of user PostScript
.91448 .06023 m
.91489 .06461 L
s
% Start of user PostScript
30. 2. 30.0133 2.14259 MAarrowhead1
% End of user PostScript
.94519 .06023 m
.94401 .0608 L
s
% Start of user PostScript
31. 2. 30.9615 2.01857 MAarrowhead1
% End of user PostScript
.97591 .06023 m
.97478 .06029 L
s
% Start of user PostScript
32. 2. 31.9632 2.00194 MAarrowhead1
% End of user PostScript
.02381 .09094 m
.02381 .08987 L
s
% Start of user PostScript
1. 3. 1. 2.96518 MAarrowhead1
% End of user PostScript
.05452 .09094 m
.05481 .09066 L
s
% Start of user PostScript
2. 3. 2.00925 2.99075 MAarrowhead1
% End of user PostScript
.08524 .09094 m
.08509 .0913 L
s
% Start of user PostScript
3. 3. 2.99529 3.01161 MAarrowhead1
% End of user PostScript
.11595 .09094 m
.11538 .09094 L
s
% Start of user PostScript
4. 3. 3.98149 3. MAarrowhead1
% End of user PostScript
.14666 .09094 m
.14652 .09109 L
s
% Start of user PostScript
5. 3. 4.99529 3.00471 MAarrowhead1
% End of user PostScript
.17737 .09094 m
.17723 .09109 L
s
% Start of user PostScript
6. 3. 5.99529 3.00471 MAarrowhead1
% End of user PostScript
.20809 .09094 m
.20852 .0908 L
s
% Start of user PostScript
7. 3. 7.01396 2.99545 MAarrowhead1
% End of user PostScript
.2388 .09094 m
.2384 .09105 L
s
% Start of user PostScript
8. 3. 7.98714 3.00345 MAarrowhead1
% End of user PostScript
.26951 .09094 m
.27126 .09026 L
s
% Start of user PostScript
9. 3. 9.05702 2.9778 MAarrowhead1
% End of user PostScript
.30022 .09094 m
.29799 .09317 L
s
% Start of user PostScript
10. 3. 9.92729 3.07271 MAarrowhead1
% End of user PostScript
.33094 .09094 m
.33226 .0912 L
s
% Start of user PostScript
11. 3. 11.0431 3.00843 MAarrowhead1
% End of user PostScript
.36165 .09094 m
.36117 .09142 L
s
% Start of user PostScript
12. 3. 11.9843 3.01569 MAarrowhead1
% End of user PostScript
.39236 .09094 m
.39231 .09099 L
s
% Start of user PostScript
13. 3. 12.9983 3.00173 MAarrowhead1
% End of user PostScript
.42308 .09094 m
.42279 .09122 L
s
% Start of user PostScript
14. 3. 13.9907 3.00925 MAarrowhead1
% End of user PostScript
.45379 .09094 m
.45417 .09056 L
s
% Start of user PostScript
15. 3. 15.0124 2.98765 MAarrowhead1
% End of user PostScript
.4845 .09094 m
.4845 .09094 L
s
% Start of user PostScript
16. 3. MAarrowzero1
% End of user PostScript
.51521 .09094 m
.51521 .09094 L
s
% Start of user PostScript
17. 3. MAarrowzero1
% End of user PostScript
.54593 .09094 m
.54564 .09198 L
s
% Start of user PostScript
18. 3. 17.9907 3.03396 MAarrowhead1
% End of user PostScript
.57664 .09094 m
.5767 .08995 L
s
% Start of user PostScript
19. 3. 19.0019 2.96782 MAarrowhead1
% End of user PostScript
.60735 .09094 m
.60755 .09207 L
s
% Start of user PostScript
20. 3. 20.0065 3.03673 MAarrowhead1
% End of user PostScript
.63807 .09094 m
.63881 .09076 L
s
% Start of user PostScript
21. 3. 21.0244 2.99414 MAarrowhead1
% End of user PostScript
.66878 .09094 m
.66878 .09094 L
s
% Start of user PostScript
22. 3. MAarrowzero1
% End of user PostScript
.69949 .09094 m
.70033 .09103 L
s
% Start of user PostScript
23. 3. 23.0275 3.00276 MAarrowhead1
% End of user PostScript
.7302 .09094 m
.73026 .09099 L
s
% Start of user PostScript
24. 3. 24.0017 3.00173 MAarrowhead1
% End of user PostScript
.76092 .09094 m
.76062 .09217 L
s
% Start of user PostScript
25. 3. 24.9903 3.03996 MAarrowhead1
% End of user PostScript
.79163 .09094 m
.79308 .08576 L
s
% Start of user PostScript
26. 3. 26.0473 2.83133 MAarrowhead1
% End of user PostScript
.82234 .09094 m
.82139 .09225 L
s
% Start of user PostScript
27. 3. 26.969 3.04278 MAarrowhead1
% End of user PostScript
.85306 .09094 m
.85175 .0907 L
s
% Start of user PostScript
28. 3. 27.9574 2.99225 MAarrowhead1
% End of user PostScript
.88377 .09094 m
.88348 .09073 L
s
% Start of user PostScript
29. 3. 28.9905 2.99304 MAarrowhead1
% End of user PostScript
.91448 .09094 m
.91278 .09167 L
s
% Start of user PostScript
30. 3. 29.9447 3.02369 MAarrowhead1
% End of user PostScript
.94519 .09094 m
.94806 .09148 L
s
% Start of user PostScript
31. 3. 31.0934 3.01741 MAarrowhead1
% End of user PostScript
.97591 .09094 m
.97619 .09066 L
s
% Start of user PostScript
32. 3. 32.0093 2.99075 MAarrowhead1
% End of user PostScript
.02381 .12165 m
.02381 .12158 L
s
% Start of user PostScript
1. 4. 1. 3.99749 MAarrowhead1
% End of user PostScript
.05452 .12165 m
.05481 .12165 L
s
% Start of user PostScript
2. 4. 2.00941 4. MAarrowhead1
% End of user PostScript
.08524 .12165 m
.08577 .12219 L
s
% Start of user PostScript
3. 4. 3.01741 4.01741 MAarrowhead1
% End of user PostScript
.11595 .12165 m
.11591 .12161 L
s
% Start of user PostScript
4. 4. 3.99875 3.99875 MAarrowhead1
% End of user PostScript
.14666 .12165 m
.14666 .12165 L
s
% Start of user PostScript
5. 4. MAarrowzero1
% End of user PostScript
.17737 .12165 m
.17709 .12194 L
s
% Start of user PostScript
6. 4. 5.99075 4.00925 MAarrowhead1
% End of user PostScript
.20809 .12165 m
.2078 .12137 L
s
% Start of user PostScript
7. 4. 6.99075 3.99075 MAarrowhead1
% End of user PostScript
.2388 .12165 m
.23916 .12151 L
s
% Start of user PostScript
8. 4. 8.01161 3.99529 MAarrowhead1
% End of user PostScript
.26951 .12165 m
.27323 .12209 L
s
% Start of user PostScript
9. 4. 9.12108 4.01418 MAarrowhead1
% End of user PostScript
.30022 .12165 m
.30291 .12084 L
s
% Start of user PostScript
10. 4. 10.0875 3.97343 MAarrowhead1
% End of user PostScript
.33094 .12165 m
.32387 .12794 L
s
% Start of user PostScript
11. 4. 10.7698 4.20475 MAarrowhead1
% End of user PostScript
.36165 .12165 m
.36058 .12215 L
s
% Start of user PostScript
12. 4. 11.9652 4.01627 MAarrowhead1
% End of user PostScript
.39236 .12165 m
.3919 .12119 L
s
% Start of user PostScript
13. 4. 12.9849 3.98488 MAarrowhead1
% End of user PostScript
.42308 .12165 m
.42346 .12127 L
s
% Start of user PostScript
14. 4. 14.0124 3.98765 MAarrowhead1
% End of user PostScript
.45379 .12165 m
.45379 .12165 L
s
% Start of user PostScript
15. 4. MAarrowzero1
% End of user PostScript
.4845 .12165 m
.48488 .12203 L
s
% Start of user PostScript
16. 4. 16.0124 4.01235 MAarrowhead1
% End of user PostScript
.51521 .12165 m
.51483 .12127 L
s
% Start of user PostScript
17. 4. 16.9876 3.98765 MAarrowhead1
% End of user PostScript
.54593 .12165 m
.54593 .12241 L
s
% Start of user PostScript
18. 4. 18. 4.02471 MAarrowhead1
% End of user PostScript
.57664 .12165 m
.5765 .12219 L
s
% Start of user PostScript
19. 4. 18.9955 4.01741 MAarrowhead1
% End of user PostScript
.60735 .12165 m
.60707 .12137 L
s
% Start of user PostScript
20. 4. 19.9907 3.99075 MAarrowhead1
% End of user PostScript
.63807 .12165 m
.63734 .12227 L
s
% Start of user PostScript
21. 4. 20.9763 4.02024 MAarrowhead1
% End of user PostScript
.66878 .12165 m
.6684 .12203 L
s
% Start of user PostScript
22. 4. 21.9876 4.01235 MAarrowhead1
% End of user PostScript
.69949 .12165 m
.69969 .12261 L
s
% Start of user PostScript
23. 4. 23.0064 4.03114 MAarrowhead1
% End of user PostScript
.7302 .12165 m
.73106 .1243 L
s
% Start of user PostScript
24. 4. 24.0278 4.08622 MAarrowhead1
% End of user PostScript
.76092 .12165 m
.76309 .12382 L
s
% Start of user PostScript
25. 4. 25.0706 4.07061 MAarrowhead1
% End of user PostScript
.79163 .12165 m
.78834 .11921 L
s
% Start of user PostScript
26. 4. 25.8928 3.92055 MAarrowhead1
% End of user PostScript
.82234 .12165 m
.82101 .12219 L
s
% Start of user PostScript
27. 4. 26.9567 4.01741 MAarrowhead1
% End of user PostScript
.85306 .12165 m
.85306 .12165 L
s
% Start of user PostScript
28. 4. MAarrowzero1
% End of user PostScript
.88377 .12165 m
.88218 .12142 L
s
% Start of user PostScript
29. 4. 28.9482 3.99231 MAarrowhead1
% End of user PostScript
.91448 .12165 m
.91235 .11953 L
s
% Start of user PostScript
30. 4. 29.9307 3.93075 MAarrowhead1
% End of user PostScript
.94519 .12165 m
.94244 .12111 L
s
% Start of user PostScript
31. 4. 30.9103 3.98237 MAarrowhead1
% End of user PostScript
.97591 .12165 m
.9756 .12127 L
s
% Start of user PostScript
32. 4. 31.9901 3.98755 MAarrowhead1
% End of user PostScript
.02381 .15237 m
.02381 .1513 L
s
% Start of user PostScript
1. 5. 1. 4.96518 MAarrowhead1
% End of user PostScript
.05452 .15237 m
.05481 .15265 L
s
% Start of user PostScript
2. 5. 2.00925 5.00925 MAarrowhead1
% End of user PostScript
.08524 .15237 m
.08524 .15237 L
s
% Start of user PostScript
3. 5. MAarrowzero1
% End of user PostScript
.11595 .15237 m
.11577 .15169 L
s
% Start of user PostScript
4. 5. 3.9942 4.97788 MAarrowhead1
% End of user PostScript
.14666 .15237 m
.14666 .15293 L
s
% Start of user PostScript
5. 5. 5. 5.01851 MAarrowhead1
% End of user PostScript
.17737 .15237 m
.17712 .15233 L
s
% Start of user PostScript
6. 5. 5.99184 4.99875 MAarrowhead1
% End of user PostScript
.20809 .15237 m
.20823 .15279 L
s
% Start of user PostScript
7. 5. 7.00455 5.01396 MAarrowhead1
% End of user PostScript
.2388 .15237 m
.23872 .15237 L
s
% Start of user PostScript
8. 5. 7.99749 5. MAarrowhead1
% End of user PostScript
.26951 .15237 m
.2698 .15265 L
s
% Start of user PostScript
9. 5. 9.00925 5.00925 MAarrowhead1
% End of user PostScript
.30022 .15237 m
.30224 .15329 L
s
% Start of user PostScript
10. 5. 10.0655 5.03024 MAarrowhead1
% End of user PostScript
.33094 .15237 m
.33373 .15305 L
s
% Start of user PostScript
11. 5. 11.0911 5.02235 MAarrowhead1
% End of user PostScript
.36165 .15237 m
.36165 .15237 L
s
% Start of user PostScript
12. 5. MAarrowzero1
% End of user PostScript
.39236 .15237 m
.3923 .15231 L
s
% Start of user PostScript
13. 5. 12.9981 4.99806 MAarrowhead1
% End of user PostScript
.42308 .15237 m
.4227 .15199 L
s
% Start of user PostScript
14. 5. 13.9876 4.98765 MAarrowhead1
% End of user PostScript
.45379 .15237 m
.45417 .15275 L
s
% Start of user PostScript
15. 5. 15.0124 5.01235 MAarrowhead1
% End of user PostScript
.4845 .15237 m
.4845 .15237 L
s
% Start of user PostScript
16. 5. MAarrowzero1
% End of user PostScript
.51521 .15237 m
.51502 .15245 L
s
% Start of user PostScript
17. 5. 16.9937 5.00282 MAarrowhead1
% End of user PostScript
.54593 .15237 m
.54646 .15319 L
s
% Start of user PostScript
18. 5. 18.0173 5.02667 MAarrowhead1
% End of user PostScript
.57664 .15237 m
.57664 .15237 L
s
% Start of user PostScript
19. 5. MAarrowzero1
% End of user PostScript
.60735 .15237 m
.60764 .15308 L
s
% Start of user PostScript
20. 5. 20.0093 5.02329 MAarrowhead1
% End of user PostScript
.63807 .15237 m
.63738 .15237 L
s
% Start of user PostScript
21. 5. 20.9776 5. MAarrowhead1
% End of user PostScript
.66878 .15237 m
.67007 .15458 L
s
% Start of user PostScript
22. 5. 22.0419 5.07214 MAarrowhead1
% End of user PostScript
.69949 .15237 m
.70126 .15395 L
s
% Start of user PostScript
23. 5. 23.0577 5.05173 MAarrowhead1
% End of user PostScript
.7302 .15237 m
.73495 .15353 L
s
% Start of user PostScript
24. 5. 24.1545 5.03792 MAarrowhead1
% End of user PostScript
.76092 .15237 m
.76103 .15356 L
s
% Start of user PostScript
25. 5. 25.0036 5.03882 MAarrowhead1
% End of user PostScript
.79163 .15237 m
.79171 .15314 L
s
% Start of user PostScript
26. 5. 26.0028 5.02516 MAarrowhead1
% End of user PostScript
.82234 .15237 m
.82209 .15211 L
s
% Start of user PostScript
27. 5. 26.9918 4.99178 MAarrowhead1
% End of user PostScript
.85306 .15237 m
.85182 .15113 L
s
% Start of user PostScript
28. 5. 27.9598 4.95982 MAarrowhead1
% End of user PostScript
.88377 .15237 m
.88279 .15138 L
s
% Start of user PostScript
29. 5. 28.968 4.96804 MAarrowhead1
% End of user PostScript
.91448 .15237 m
.91323 .15111 L
s
% Start of user PostScript
30. 5. 29.9593 4.95925 MAarrowhead1
% End of user PostScript
.94519 .15237 m
.94446 .15134 L
s
% Start of user PostScript
31. 5. 30.9761 4.96669 MAarrowhead1
% End of user PostScript
.97591 .15237 m
.97534 .15237 L
s
% Start of user PostScript
32. 5. 31.9815 5. MAarrowhead1
% End of user PostScript
.02381 .18308 m
.02381 .18308 L
s
% Start of user PostScript
1. 6. MAarrowzero1
% End of user PostScript
.05452 .18308 m
.0537 .18312 L
s
% Start of user PostScript
2. 6. 1.97333 6.00125 MAarrowhead1
% End of user PostScript
.08524 .18308 m
.08552 .18336 L
s
% Start of user PostScript
3. 6. 3.00925 6.00925 MAarrowhead1
% End of user PostScript
.11595 .18308 m
.11595 .18308 L
s
% Start of user PostScript
4. 6. MAarrowzero1
% End of user PostScript
.14666 .18308 m
.14627 .18326 L
s
% Start of user PostScript
5. 6. 4.98729 6.0058 MAarrowhead1
% End of user PostScript
.17737 .18308 m
.17734 .18254 L
s
% Start of user PostScript
6. 6. 5.9989 5.98259 MAarrowhead1
% End of user PostScript
.20809 .18308 m
.20894 .18308 L
s
% Start of user PostScript
7. 6. 7.02792 6. MAarrowhead1
% End of user PostScript
.2388 .18308 m
.23962 .18312 L
s
% Start of user PostScript
8. 6. 8.02667 6.00125 MAarrowhead1
% End of user PostScript
.26951 .18308 m
.27048 .18405 L
s
% Start of user PostScript
9. 6. 9.03149 6.03149 MAarrowhead1
% End of user PostScript
.30022 .18308 m
.30102 .18228 L
s
% Start of user PostScript
10. 6. 10.0259 5.9741 MAarrowhead1
% End of user PostScript
.33094 .18308 m
.33017 .18231 L
s
% Start of user PostScript
11. 6. 10.9751 5.97506 MAarrowhead1
% End of user PostScript
.36165 .18308 m
.34382 .18143 L
s
% Start of user PostScript
12. 6. 11.4195 5.94627 MAarrowhead1
% End of user PostScript
.39236 .18308 m
.39262 .1835 L
s
% Start of user PostScript
13. 6. 13.0082 6.01375 MAarrowhead1
% End of user PostScript
.42308 .18308 m
.42293 .18255 L
s
% Start of user PostScript
14. 6. 13.9953 5.98275 MAarrowhead1
% End of user PostScript
.45379 .18308 m
.45393 .18294 L
s
% Start of user PostScript
15. 6. 15.0045 5.99545 MAarrowhead1
% End of user PostScript
.4845 .18308 m
.48484 .1837 L
s
% Start of user PostScript
16. 6. 16.0111 6.02024 MAarrowhead1
% End of user PostScript
.51521 .18308 m
.51445 .18356 L
s
% Start of user PostScript
17. 6. 16.9751 6.01553 MAarrowhead1
% End of user PostScript
.54593 .18308 m
.54598 .18303 L
s
% Start of user PostScript
18. 6. 18.0017 5.99827 MAarrowhead1
% End of user PostScript
.57664 .18308 m
.57665 .18376 L
s
% Start of user PostScript
19. 6. 19.0002 6.02218 MAarrowhead1
% End of user PostScript
.60735 .18308 m
.6078 .18427 L
s
% Start of user PostScript
20. 6. 20.0144 6.0389 MAarrowhead1
% End of user PostScript
.63807 .18308 m
.64068 .18502 L
s
% Start of user PostScript
21. 6. 21.085 6.06308 MAarrowhead1
% End of user PostScript
.66878 .18308 m
.66969 .18411 L
s
% Start of user PostScript
22. 6. 22.0297 6.03355 MAarrowhead1
% End of user PostScript
.69949 .18308 m
.6981 .18219 L
s
% Start of user PostScript
23. 6. 22.9546 5.97114 MAarrowhead1
% End of user PostScript
.7302 .18308 m
.73114 .18214 L
s
% Start of user PostScript
24. 6. 24.0305 5.96955 MAarrowhead1
% End of user PostScript
.76092 .18308 m
.75914 .18215 L
s
% Start of user PostScript
25. 6. 24.942 5.96976 MAarrowhead1
% End of user PostScript
.79163 .18308 m
.79029 .18074 L
s
% Start of user PostScript
26. 6. 25.9563 5.92373 MAarrowhead1
% End of user PostScript
.82234 .18308 m
.82172 .18371 L
s
% Start of user PostScript
27. 6. 26.9796 6.02039 MAarrowhead1
% End of user PostScript
.85306 .18308 m
.85136 .18231 L
s
% Start of user PostScript
28. 6. 27.9447 5.97494 MAarrowhead1
% End of user PostScript
.88377 .18308 m
.88246 .18177 L
s
% Start of user PostScript
29. 6. 28.9573 5.95731 MAarrowhead1
% End of user PostScript
.91448 .18308 m
.91476 .18279 L
s
% Start of user PostScript
30. 6. 30.0093 5.99075 MAarrowhead1
% End of user PostScript
.94519 .18308 m
.94494 .18333 L
s
% Start of user PostScript
31. 6. 30.9918 6.00816 MAarrowhead1
% End of user PostScript
.97591 .18308 m
.97576 .18237 L
s
% Start of user PostScript
32. 6. 31.9953 5.97678 MAarrowhead1
% End of user PostScript
.02381 .21379 m
.02381 .21379 L
s
% Start of user PostScript
1. 7. MAarrowzero1
% End of user PostScript
.05452 .21379 m
.05509 .21379 L
s
% Start of user PostScript
2. 7. 2.01851 7. MAarrowhead1
% End of user PostScript
.08524 .21379 m
.08538 .21308 L
s
% Start of user PostScript
3. 7. 3.00471 6.97678 MAarrowhead1
% End of user PostScript
.11595 .21379 m
.11595 .21379 L
s
% Start of user PostScript
4. 7. MAarrowzero1
% End of user PostScript
.14666 .21379 m
.14694 .21408 L
s
% Start of user PostScript
5. 7. 5.00925 7.00925 MAarrowhead1
% End of user PostScript
.17737 .21379 m
.17666 .21394 L
s
% Start of user PostScript
6. 7. 5.97678 7.00471 MAarrowhead1
% End of user PostScript
.20809 .21379 m
.20784 .21297 L
s
% Start of user PostScript
7. 7. 6.99184 6.97333 MAarrowhead1
% End of user PostScript
.2388 .21379 m
.23876 .21404 L
s
% Start of user PostScript
8. 7. 7.99875 7.00816 MAarrowhead1
% End of user PostScript
.26951 .21379 m
.27178 .21414 L
s
% Start of user PostScript
9. 7. 9.07394 7.0112 MAarrowhead1
% End of user PostScript
.30022 .21379 m
.30313 .21339 L
s
% Start of user PostScript
10. 7. 10.0945 6.98702 MAarrowhead1
% End of user PostScript
.33094 .21379 m
.33453 .21457 L
s
% Start of user PostScript
11. 7. 11.1171 7.02527 MAarrowhead1
% End of user PostScript
.36165 .21379 m
.34576 .21351 L
s
% Start of user PostScript
12. 7. 11.4825 6.99075 MAarrowhead1
% End of user PostScript
.39236 .21379 m
.39158 .21458 L
s
% Start of user PostScript
13. 7. 12.9745 7.02553 MAarrowhead1
% End of user PostScript
.42308 .21379 m
.4237 .21441 L
s
% Start of user PostScript
14. 7. 14.0202 7.02024 MAarrowhead1
% End of user PostScript
.45379 .21379 m
.45439 .21451 L
s
% Start of user PostScript
15. 7. 15.0197 7.02355 MAarrowhead1
% End of user PostScript
.4845 .21379 m
.4845 .21379 L
s
% Start of user PostScript
16. 7. MAarrowzero1
% End of user PostScript
.51521 .21379 m
.51435 .21505 L
s
% Start of user PostScript
17. 7. 16.972 7.0409 MAarrowhead1
% End of user PostScript
.54593 .21379 m
.54578 .21394 L
s
% Start of user PostScript
18. 7. 17.9953 7.00471 MAarrowhead1
% End of user PostScript
.57664 .21379 m
.57698 .21509 L
s
% Start of user PostScript
19. 7. 19.011 7.04235 MAarrowhead1
% End of user PostScript
.60735 .21379 m
.60773 .21545 L
s
% Start of user PostScript
20. 7. 20.0121 7.0541 MAarrowhead1
% End of user PostScript
.63807 .21379 m
.63798 .21444 L
s
% Start of user PostScript
21. 7. 20.9973 7.0212 MAarrowhead1
% End of user PostScript
.66878 .21379 m
.66903 .21484 L
s
% Start of user PostScript
22. 7. 22.0083 7.03412 MAarrowhead1
% End of user PostScript
.69949 .21379 m
.6987 .213 L
s
% Start of user PostScript
23. 7. 22.9741 6.9741 MAarrowhead1
% End of user PostScript
.7302 .21379 m
.73024 .21114 L
s
% Start of user PostScript
24. 7. 24.0012 6.91371 MAarrowhead1
% End of user PostScript
.76092 .21379 m
.76092 .21487 L
s
% Start of user PostScript
25. 7. 25. 7.03525 MAarrowhead1
% End of user PostScript
.79163 .21379 m
.79027 .21515 L
s
% Start of user PostScript
26. 7. 25.9557 7.04429 MAarrowhead1
% End of user PostScript
.82234 .21379 m
.82365 .2151 L
s
% Start of user PostScript
27. 7. 27.0425 7.04247 MAarrowhead1
% End of user PostScript
.85306 .21379 m
.85168 .21252 L
s
% Start of user PostScript
28. 7. 27.9552 6.95867 MAarrowhead1
% End of user PostScript
.88377 .21379 m
.88368 .2137 L
s
% Start of user PostScript
29. 7. 28.997 6.99702 MAarrowhead1
% End of user PostScript
.91448 .21379 m
.91417 .21291 L
s
% Start of user PostScript
30. 7. 29.9899 6.97139 MAarrowhead1
% End of user PostScript
.94519 .21379 m
.94519 .21379 L
s
% Start of user PostScript
31. 7. MAarrowzero1
% End of user PostScript
.97591 .21379 m
.97619 .21351 L
s
% Start of user PostScript
32. 7. 32.0093 6.99075 MAarrowhead1
% End of user PostScript
.02381 .2445 m
.02381 .24507 L
s
% Start of user PostScript
1. 8. 1. 8.01851 MAarrowhead1
% End of user PostScript
.05452 .2445 m
.05481 .24529 L
s
% Start of user PostScript
2. 8. 2.00925 8.02557 MAarrowhead1
% End of user PostScript
.08524 .2445 m
.08524 .24394 L
s
% Start of user PostScript
3. 8. 3. 7.98149 MAarrowhead1
% End of user PostScript
.11595 .2445 m
.11595 .2445 L
s
% Start of user PostScript
4. 8. MAarrowzero1
% End of user PostScript
.14666 .2445 m
.14681 .24436 L
s
% Start of user PostScript
5. 8. 5.00471 7.99529 MAarrowhead1
% End of user PostScript
.17737 .2445 m
.17655 .24447 L
s
% Start of user PostScript
6. 8. 5.97333 7.99875 MAarrowhead1
% End of user PostScript
.20809 .2445 m
.20823 .24522 L
s
% Start of user PostScript
7. 8. 7.00471 8.02322 MAarrowhead1
% End of user PostScript
.2388 .2445 m
.24248 .24501 L
s
% Start of user PostScript
8. 8. 8.11994 8.01649 MAarrowhead1
% End of user PostScript
.26951 .2445 m
.2699 .24489 L
s
% Start of user PostScript
9. 8. 9.01271 8.01271 MAarrowhead1
% End of user PostScript
.30022 .2445 m
.30282 .2438 L
s
% Start of user PostScript
10. 8. 10.0844 7.97692 MAarrowhead1
% End of user PostScript
.33094 .2445 m
.3318 .24364 L
s
% Start of user PostScript
11. 8. 11.028 7.97196 MAarrowhead1
% End of user PostScript
.36165 .2445 m
.34917 .24306 L
s
% Start of user PostScript
12. 8. 11.5938 7.95292 MAarrowhead1
% End of user PostScript
.39236 .2445 m
.39304 .24279 L
s
% Start of user PostScript
13. 8. 13.0222 7.94414 MAarrowhead1
% End of user PostScript
.42308 .2445 m
.42336 .24326 L
s
% Start of user PostScript
14. 8. 14.0093 7.95937 MAarrowhead1
% End of user PostScript
.45379 .2445 m
.45379 .2434 L
s
% Start of user PostScript
15. 8. 15. 7.964 MAarrowhead1
% End of user PostScript
.4845 .2445 m
.48569 .24395 L
s
% Start of user PostScript
16. 8. 16.0388 7.98202 MAarrowhead1
% End of user PostScript
.51521 .2445 m
.51521 .24514 L
s
% Start of user PostScript
17. 8. 17. 8.02082 MAarrowhead1
% End of user PostScript
.54593 .2445 m
.54579 .24562 L
s
% Start of user PostScript
18. 8. 17.9955 8.03631 MAarrowhead1
% End of user PostScript
.57664 .2445 m
.57723 .24469 L
s
% Start of user PostScript
19. 8. 19.0193 8.00616 MAarrowhead1
% End of user PostScript
.60735 .2445 m
.61251 .24621 L
s
% Start of user PostScript
20. 8. 20.1679 8.05565 MAarrowhead1
% End of user PostScript
.63807 .2445 m
.64122 .24619 L
s
% Start of user PostScript
21. 8. 21.1026 8.05476 MAarrowhead1
% End of user PostScript
.66878 .2445 m
.67006 .24357 L
s
% Start of user PostScript
22. 8. 22.0418 7.96959 MAarrowhead1
% End of user PostScript
.69949 .2445 m
.70057 .2445 L
s
% Start of user PostScript
23. 8. 23.0351 8. MAarrowhead1
% End of user PostScript
.7302 .2445 m
.72874 .2448 L
s
% Start of user PostScript
24. 8. 23.9523 8.00947 MAarrowhead1
% End of user PostScript
.76092 .2445 m
.76294 .24248 L
s
% Start of user PostScript
25. 8. 25.0659 7.9341 MAarrowhead1
% End of user PostScript
.79163 .2445 m
.78641 .24604 L
s
% Start of user PostScript
26. 8. 25.83 8.05 MAarrowhead1
% End of user PostScript
.82234 .2445 m
.82168 .24373 L
s
% Start of user PostScript
27. 8. 26.9784 7.97494 MAarrowhead1
% End of user PostScript
.85306 .2445 m
.85116 .2429 L
s
% Start of user PostScript
28. 8. 27.9383 7.94769 MAarrowhead1
% End of user PostScript
.88377 .2445 m
.88391 .24408 L
s
% Start of user PostScript
29. 8. 29.0045 7.98604 MAarrowhead1
% End of user PostScript
.91448 .2445 m
.9142 .24479 L
s
% Start of user PostScript
30. 8. 29.9907 8.00925 MAarrowhead1
% End of user PostScript
.94519 .2445 m
.94548 .24479 L
s
% Start of user PostScript
31. 8. 31.0093 8.00925 MAarrowhead1
% End of user PostScript
.97591 .2445 m
.97591 .2445 L
s
% Start of user PostScript
32. 8. MAarrowzero1
% End of user PostScript
.02381 .27522 m
.02381 .27522 L
s
% Start of user PostScript
1. 9. MAarrowzero1
% End of user PostScript
.05452 .27522 m
.05495 .27565 L
s
% Start of user PostScript
2. 9. 2.01396 9.01396 MAarrowhead1
% End of user PostScript
.08524 .27522 m
.08509 .2745 L
s
% Start of user PostScript
3. 9. 2.99529 8.97678 MAarrowhead1
% End of user PostScript
.11595 .27522 m
.11638 .27565 L
s
% Start of user PostScript
4. 9. 4.01396 9.01396 MAarrowhead1
% End of user PostScript
.14666 .27522 m
.14694 .27493 L
s
% Start of user PostScript
5. 9. 5.00925 8.99075 MAarrowhead1
% End of user PostScript
.17737 .27522 m
.17709 .27493 L
s
% Start of user PostScript
6. 9. 5.99075 8.99075 MAarrowhead1
% End of user PostScript
.20809 .27522 m
.20877 .27561 L
s
% Start of user PostScript
7. 9. 7.02212 9.01271 MAarrowhead1
% End of user PostScript
.2388 .27522 m
.2434 .27635 L
s
% Start of user PostScript
8. 9. 8.14976 9.0369 MAarrowhead1
% End of user PostScript
.26951 .27522 m
.27116 .27453 L
s
% Start of user PostScript
9. 9. 9.05373 8.97765 MAarrowhead1
% End of user PostScript
.30022 .27522 m
.30315 .27633 L
s
% Start of user PostScript
10. 9. 10.0954 9.0361 MAarrowhead1
% End of user PostScript
.33094 .27522 m
.32768 .27196 L
s
% Start of user PostScript
11. 9. 10.894 8.89396 MAarrowhead1
% End of user PostScript
.36165 .27522 m
.36097 .2755 L
s
% Start of user PostScript
12. 9. 11.9779 9.00925 MAarrowhead1
% End of user PostScript
.39236 .27522 m
.39228 .27513 L
s
% Start of user PostScript
13. 9. 12.9972 8.99724 MAarrowhead1
% End of user PostScript
.42308 .27522 m
.4237 .2746 L
s
% Start of user PostScript
14. 9. 14.0202 8.97976 MAarrowhead1
% End of user PostScript
.45379 .27522 m
.45379 .27511 L
s
% Start of user PostScript
15. 9. 15. 8.99655 MAarrowhead1
% End of user PostScript
.4845 .27522 m
.48489 .27393 L
s
% Start of user PostScript
16. 9. 16.0127 8.9582 MAarrowhead1
% End of user PostScript
.51521 .27522 m
.51627 .27416 L
s
% Start of user PostScript
17. 9. 17.0345 8.96553 MAarrowhead1
% End of user PostScript
.54593 .27522 m
.54545 .27627 L
s
% Start of user PostScript
18. 9. 17.9843 9.0342 MAarrowhead1
% End of user PostScript
.57664 .27522 m
.57738 .27595 L
s
% Start of user PostScript
19. 9. 19.024 9.02396 MAarrowhead1
% End of user PostScript
.60735 .27522 m
.59953 .27573 L
s
% Start of user PostScript
20. 9. 19.7454 9.01684 MAarrowhead1
% End of user PostScript
.63807 .27522 m
.64462 .27443 L
s
% Start of user PostScript
21. 9. 21.2133 8.97431 MAarrowhead1
% End of user PostScript
.66878 .27522 m
.66356 .27345 L
s
% Start of user PostScript
22. 9. 21.8303 8.94253 MAarrowhead1
% End of user PostScript
.69949 .27522 m
.70005 .2738 L
s
% Start of user PostScript
23. 9. 23.0183 8.95396 MAarrowhead1
% End of user PostScript
.7302 .27522 m
.72893 .27513 L
s
% Start of user PostScript
24. 9. 23.9586 8.99708 MAarrowhead1
% End of user PostScript
.76092 .27522 m
.76206 .2743 L
s
% Start of user PostScript
25. 9. 25.0374 8.96998 MAarrowhead1
% End of user PostScript
.79163 .27522 m
.79174 .27632 L
s
% Start of user PostScript
26. 9. 26.0035 9.03604 MAarrowhead1
% End of user PostScript
.82234 .27522 m
.82302 .27393 L
s
% Start of user PostScript
27. 9. 27.022 8.9581 MAarrowhead1
% End of user PostScript
.85306 .27522 m
.85223 .27336 L
s
% Start of user PostScript
28. 9. 27.9731 8.93943 MAarrowhead1
% End of user PostScript
.88377 .27522 m
.88444 .27511 L
s
% Start of user PostScript
29. 9. 29.022 8.99655 MAarrowhead1
% End of user PostScript
.91448 .27522 m
.91476 .2755 L
s
% Start of user PostScript
30. 9. 30.0093 9.00925 MAarrowhead1
% End of user PostScript
.94519 .27522 m
.94548 .27493 L
s
% Start of user PostScript
31. 9. 31.0093 8.99075 MAarrowhead1
% End of user PostScript
.97591 .27522 m
.97591 .27522 L
s
% Start of user PostScript
32. 9. MAarrowzero1
% End of user PostScript
.02381 .30593 m
.02381 .30593 L
s
% Start of user PostScript
1. 10. MAarrowzero1
% End of user PostScript
.05452 .30593 m
.05452 .30593 L
s
% Start of user PostScript
2. 10. MAarrowzero1
% End of user PostScript
.08524 .30593 m
.08552 .30565 L
s
% Start of user PostScript
3. 10. 3.00925 9.99075 MAarrowhead1
% End of user PostScript
.11595 .30593 m
.11566 .30565 L
s
% Start of user PostScript
4. 10. 3.99075 9.99075 MAarrowhead1
% End of user PostScript
.14666 .30593 m
.14723 .30593 L
s
% Start of user PostScript
5. 10. 5.01851 10. MAarrowhead1
% End of user PostScript
.17737 .30593 m
.17737 .30536 L
s
% Start of user PostScript
6. 10. 6. 9.98149 MAarrowhead1
% End of user PostScript
.20809 .30593 m
.20997 .30598 L
s
% Start of user PostScript
7. 10. 7.06125 10.0017 MAarrowhead1
% End of user PostScript
.2388 .30593 m
.24175 .30626 L
s
% Start of user PostScript
8. 10. 8.09604 10.0109 MAarrowhead1
% End of user PostScript
.26951 .30593 m
.2688 .30664 L
s
% Start of user PostScript
9. 10. 8.97678 10.0232 MAarrowhead1
% End of user PostScript
.30022 .30593 m
.29946 .30448 L
s
% Start of user PostScript
10. 10. 9.9751 9.95271 MAarrowhead1
% End of user PostScript
.33094 .30593 m
.33036 .30565 L
s
% Start of user PostScript
11. 10. 10.9813 9.99075 MAarrowhead1
% End of user PostScript
.36165 .30593 m
.36151 .30618 L
s
% Start of user PostScript
12. 10. 11.9953 10.0082 MAarrowhead1
% End of user PostScript
.39236 .30593 m
.3932 .30687 L
s
% Start of user PostScript
13. 10. 13.0273 10.0307 MAarrowhead1
% End of user PostScript
.42308 .30593 m
.42308 .30818 L
s
% Start of user PostScript
14. 10. 14. 10.0731 MAarrowhead1
% End of user PostScript
.45379 .30593 m
.45417 .30698 L
s
% Start of user PostScript
15. 10. 15.0124 10.0343 MAarrowhead1
% End of user PostScript
.4845 .30593 m
.48366 .30677 L
s
% Start of user PostScript
16. 10. 15.9727 10.0273 MAarrowhead1
% End of user PostScript
.51521 .30593 m
.51527 .30588 L
s
% Start of user PostScript
17. 10. 17.0017 9.99827 MAarrowhead1
% End of user PostScript
.54593 .30593 m
.54651 .30641 L
s
% Start of user PostScript
18. 10. 18.0191 10.0157 MAarrowhead1
% End of user PostScript
.57664 .30593 m
.57838 .30658 L
s
% Start of user PostScript
19. 10. 19.0565 10.0213 MAarrowhead1
% End of user PostScript
.60735 .30593 m
.60542 .30786 L
s
% Start of user PostScript
20. 10. 19.937 10.063 MAarrowhead1
% End of user PostScript
.63807 .30593 m
.64072 .30897 L
s
% Start of user PostScript
21. 10. 21.0865 10.099 MAarrowhead1
% End of user PostScript
.66878 .30593 m
.67347 .30124 L
s
% Start of user PostScript
22. 10. 22.1526 9.84737 MAarrowhead1
% End of user PostScript
.69949 .30593 m
.70029 .30502 L
s
% Start of user PostScript
23. 10. 23.0261 9.97045 MAarrowhead1
% End of user PostScript
.7302 .30593 m
.72628 .30598 L
s
% Start of user PostScript
24. 10. 23.8723 10.0017 MAarrowhead1
% End of user PostScript
.76092 .30593 m
.75911 .30774 L
s
% Start of user PostScript
25. 10. 24.941 10.059 MAarrowhead1
% End of user PostScript
.79163 .30593 m
.79113 .30553 L
s
% Start of user PostScript
26. 10. 25.9836 9.98708 MAarrowhead1
% End of user PostScript
.82234 .30593 m
.82023 .30578 L
s
% Start of user PostScript
27. 10. 26.9312 9.99508 MAarrowhead1
% End of user PostScript
.85306 .30593 m
.85345 .30604 L
s
% Start of user PostScript
28. 10. 28.0129 10.0035 MAarrowhead1
% End of user PostScript
.88377 .30593 m
.88348 .30621 L
s
% Start of user PostScript
29. 10. 28.9907 10.0093 MAarrowhead1
% End of user PostScript
.91448 .30593 m
.91434 .30522 L
s
% Start of user PostScript
30. 10. 29.9953 9.97678 MAarrowhead1
% End of user PostScript
.94519 .30593 m
.94491 .30565 L
s
% Start of user PostScript
31. 10. 30.9907 9.99075 MAarrowhead1
% End of user PostScript
.97591 .30593 m
.97591 .30593 L
s
% Start of user PostScript
32. 10. MAarrowzero1
% End of user PostScript
.02381 .33664 m
.02381 .33607 L
s
% Start of user PostScript
1. 11. 1. 10.9815 MAarrowhead1
% End of user PostScript
.05452 .33664 m
.05509 .33664 L
s
% Start of user PostScript
2. 11. 2.01851 11. MAarrowhead1
% End of user PostScript
.08524 .33664 m
.08552 .33693 L
s
% Start of user PostScript
3. 11. 3.00925 11.0093 MAarrowhead1
% End of user PostScript
.11595 .33664 m
.11595 .33664 L
s
% Start of user PostScript
4. 11. MAarrowzero1
% End of user PostScript
.14666 .33664 m
.14694 .33636 L
s
% Start of user PostScript
5. 11. 5.00925 10.9907 MAarrowhead1
% End of user PostScript
.17737 .33664 m
.1778 .33678 L
s
% Start of user PostScript
6. 11. 6.01396 11.0045 MAarrowhead1
% End of user PostScript
.20809 .33664 m
.21175 .3378 L
s
% Start of user PostScript
7. 11. 7.11925 11.0378 MAarrowhead1
% End of user PostScript
.2388 .33664 m
.24222 .33815 L
s
% Start of user PostScript
8. 11. 8.11125 11.0492 MAarrowhead1
% End of user PostScript
.26951 .33664 m
.2714 .33757 L
s
% Start of user PostScript
9. 11. 9.06161 11.0302 MAarrowhead1
% End of user PostScript
.30022 .33664 m
.29577 .33208 L
s
% Start of user PostScript
10. 11. 9.8549 10.8515 MAarrowhead1
% End of user PostScript
.33094 .33664 m
.33104 .33664 L
s
% Start of user PostScript
11. 11. 11.0035 11. MAarrowhead1
% End of user PostScript
.36165 .33664 m
.36326 .34167 L
s
% Start of user PostScript
12. 11. 12.0524 11.1636 MAarrowhead1
% End of user PostScript
.39236 .33664 m
.39335 .33963 L
s
% Start of user PostScript
13. 11. 13.0322 11.0972 MAarrowhead1
% End of user PostScript
.42308 .33664 m
.42386 .34055 L
s
% Start of user PostScript
14. 11. 14.0257 11.1272 MAarrowhead1
% End of user PostScript
.45379 .33664 m
.453 .34362 L
s
% Start of user PostScript
15. 11. 14.9744 11.2272 MAarrowhead1
% End of user PostScript
.4845 .33664 m
.4798 .34325 L
s
% Start of user PostScript
16. 11. 15.847 11.2153 MAarrowhead1
% End of user PostScript
.51521 .33664 m
.51521 .33664 L
s
% Start of user PostScript
17. 11. MAarrowzero1
% End of user PostScript
.54593 .33664 m
.54717 .33616 L
s
% Start of user PostScript
18. 11. 18.0404 10.9843 MAarrowhead1
% End of user PostScript
.57664 .33664 m
.57877 .33605 L
s
% Start of user PostScript
19. 11. 19.0692 10.9806 MAarrowhead1
% End of user PostScript
.60735 .33664 m
.6098 .33858 L
s
% Start of user PostScript
20. 11. 20.0795 11.063 MAarrowhead1
% End of user PostScript
.63807 .33664 m
.63411 .33974 L
s
% Start of user PostScript
21. 11. 20.8713 11.1008 MAarrowhead1
% End of user PostScript
.66878 .33664 m
.67317 .33755 L
s
% Start of user PostScript
22. 11. 22.143 11.0297 MAarrowhead1
% End of user PostScript
.69949 .33664 m
.70378 .33106 L
s
% Start of user PostScript
23. 11. 23.1398 10.8183 MAarrowhead1
% End of user PostScript
.7302 .33664 m
.72996 .33514 L
s
% Start of user PostScript
24. 11. 23.992 10.9512 MAarrowhead1
% End of user PostScript
.76092 .33664 m
.75827 .33786 L
s
% Start of user PostScript
25. 11. 24.9137 11.0396 MAarrowhead1
% End of user PostScript
.79163 .33664 m
.79364 .33428 L
s
% Start of user PostScript
26. 11. 26.0653 10.9232 MAarrowhead1
% End of user PostScript
.82234 .33664 m
.81711 .33662 L
s
% Start of user PostScript
27. 11. 26.8295 10.9992 MAarrowhead1
% End of user PostScript
.85306 .33664 m
.8528 .33582 L
s
% Start of user PostScript
28. 11. 27.9918 10.9733 MAarrowhead1
% End of user PostScript
.88377 .33664 m
.88405 .33693 L
s
% Start of user PostScript
29. 11. 29.0093 11.0093 MAarrowhead1
% End of user PostScript
.91448 .33664 m
.91476 .33636 L
s
% Start of user PostScript
30. 11. 30.0093 10.9907 MAarrowhead1
% End of user PostScript
.94519 .33664 m
.94519 .33664 L
s
% Start of user PostScript
31. 11. MAarrowzero1
% End of user PostScript
.97591 .33664 m
.97562 .33693 L
s
% Start of user PostScript
32. 11. 31.9907 11.0093 MAarrowhead1
% End of user PostScript
.02381 .36736 m
.02381 .36736 L
s
% Start of user PostScript
1. 12. MAarrowzero1
% End of user PostScript
.05452 .36736 m
.05452 .36792 L
s
% Start of user PostScript
2. 12. 2. 12.0185 MAarrowhead1
% End of user PostScript
.08524 .36736 m
.08484 .36775 L
s
% Start of user PostScript
3. 12. 2.98729 12.0127 MAarrowhead1
% End of user PostScript
.11595 .36736 m
.11652 .36736 L
s
% Start of user PostScript
4. 12. 4.01851 12. MAarrowhead1
% End of user PostScript
.14666 .36736 m
.14723 .36736 L
s
% Start of user PostScript
5. 12. 5.01851 12. MAarrowhead1
% End of user PostScript
.17737 .36736 m
.17791 .36682 L
s
% Start of user PostScript
6. 12. 6.01741 11.9826 MAarrowhead1
% End of user PostScript
.20809 .36736 m
.21185 .37015 L
s
% Start of user PostScript
7. 12. 7.12251 12.0911 MAarrowhead1
% End of user PostScript
.2388 .36736 m
.24025 .3688 L
s
% Start of user PostScript
8. 12. 8.04708 12.0471 MAarrowhead1
% End of user PostScript
.26951 .36736 m
.26985 .36702 L
s
% Start of user PostScript
9. 12. 9.01098 11.989 MAarrowhead1
% End of user PostScript
.30022 .36736 m
.29994 .36764 L
s
% Start of user PostScript
10. 12. 9.99075 12.0093 MAarrowhead1
% End of user PostScript
.33094 .36736 m
.33017 .36716 L
s
% Start of user PostScript
11. 12. 10.9751 11.9936 MAarrowhead1
% End of user PostScript
.36165 .36736 m
.36131 .36769 L
s
% Start of user PostScript
12. 12. 11.989 12.011 MAarrowhead1
% End of user PostScript
.39236 .36736 m
.39217 .36784 L
s
% Start of user PostScript
13. 12. 12.9937 12.0157 MAarrowhead1
% End of user PostScript
.42308 .36736 m
.42308 .36746 L
s
% Start of user PostScript
14. 12. 14. 12.0035 MAarrowhead1
% End of user PostScript
.45379 .36736 m
.45422 .36693 L
s
% Start of user PostScript
15. 12. 15.014 11.986 MAarrowhead1
% End of user PostScript
.4845 .36736 m
.48479 .36764 L
s
% Start of user PostScript
16. 12. 16.0093 12.0093 MAarrowhead1
% End of user PostScript
.51521 .36736 m
.51584 .36798 L
s
% Start of user PostScript
17. 12. 17.0202 12.0202 MAarrowhead1
% End of user PostScript
.54593 .36736 m
.5466 .36736 L
s
% Start of user PostScript
18. 12. 18.022 12. MAarrowhead1
% End of user PostScript
.57664 .36736 m
.5769 .36665 L
s
% Start of user PostScript
19. 12. 19.0083 11.9769 MAarrowhead1
% End of user PostScript
.60735 .36736 m
.61332 .36462 L
s
% Start of user PostScript
20. 12. 20.1942 11.9109 MAarrowhead1
% End of user PostScript
.63807 .36736 m
.63506 .37025 L
s
% Start of user PostScript
21. 12. 20.9022 12.0944 MAarrowhead1
% End of user PostScript
.66878 .36736 m
.67034 .3658 L
s
% Start of user PostScript
22. 12. 22.0507 11.9493 MAarrowhead1
% End of user PostScript
.69949 .36736 m
.69653 .36886 L
s
% Start of user PostScript
23. 12. 22.9035 12.0489 MAarrowhead1
% End of user PostScript
.7302 .36736 m
.73151 .36605 L
s
% Start of user PostScript
24. 12. 24.0426 11.9574 MAarrowhead1
% End of user PostScript
.76092 .36736 m
.76212 .36694 L
s
% Start of user PostScript
25. 12. 25.039 11.9864 MAarrowhead1
% End of user PostScript
.79163 .36736 m
.79495 .36705 L
s
% Start of user PostScript
26. 12. 26.108 11.9901 MAarrowhead1
% End of user PostScript
.82234 .36736 m
.82143 .36827 L
s
% Start of user PostScript
27. 12. 26.9702 12.0298 MAarrowhead1
% End of user PostScript
.85306 .36736 m
.85295 .36725 L
s
% Start of user PostScript
28. 12. 27.9965 11.9965 MAarrowhead1
% End of user PostScript
.88377 .36736 m
.8832 .36736 L
s
% Start of user PostScript
29. 12. 28.9815 12. MAarrowhead1
% End of user PostScript
.91448 .36736 m
.91448 .36679 L
s
% Start of user PostScript
30. 12. 30. 11.9815 MAarrowhead1
% End of user PostScript
.94519 .36736 m
.94519 .36736 L
s
% Start of user PostScript
31. 12. MAarrowzero1
% End of user PostScript
.97591 .36736 m
.97562 .36764 L
s
% Start of user PostScript
32. 12. 31.9907 12.0093 MAarrowhead1
% End of user PostScript
.02381 .39807 m
.02381 .3975 L
s
% Start of user PostScript
1. 13. 1. 12.9815 MAarrowhead1
% End of user PostScript
.05452 .39807 m
.05452 .39807 L
s
% Start of user PostScript
2. 13. MAarrowzero1
% End of user PostScript
.08524 .39807 m
.08524 .39807 L
s
% Start of user PostScript
3. 13. MAarrowzero1
% End of user PostScript
.11595 .39807 m
.11595 .39807 L
s
% Start of user PostScript
4. 13. MAarrowzero1
% End of user PostScript
.14666 .39807 m
.14705 .39768 L
s
% Start of user PostScript
5. 13. 5.01271 12.9873 MAarrowhead1
% End of user PostScript
.17737 .39807 m
.18316 .39958 L
s
% Start of user PostScript
6. 13. 6.18831 13.0494 MAarrowhead1
% End of user PostScript
.20809 .39807 m
.20937 .39907 L
s
% Start of user PostScript
7. 13. 7.04184 13.0327 MAarrowhead1
% End of user PostScript
.2388 .39807 m
.23837 .39661 L
s
% Start of user PostScript
8. 13. 7.98604 12.9524 MAarrowhead1
% End of user PostScript
.26951 .39807 m
.25197 .39817 L
s
% Start of user PostScript
9. 13. 8.42888 13.0034 MAarrowhead1
% End of user PostScript
.30022 .39807 m
.29946 .39827 L
s
% Start of user PostScript
10. 13. 9.97506 13.0064 MAarrowhead1
% End of user PostScript
.33094 .39807 m
.33127 .39773 L
s
% Start of user PostScript
11. 13. 11.011 12.989 MAarrowhead1
% End of user PostScript
.36165 .39807 m
.36111 .3981 L
s
% Start of user PostScript
12. 13. 11.9825 13.001 MAarrowhead1
% End of user PostScript
.39236 .39807 m
.39279 .39621 L
s
% Start of user PostScript
13. 13. 13.014 12.9394 MAarrowhead1
% End of user PostScript
.42308 .39807 m
.42308 .40511 L
s
% Start of user PostScript
14. 13. 14. 13.2294 MAarrowhead1
% End of user PostScript
.45379 .39807 m
.45185 .40183 L
s
% Start of user PostScript
15. 13. 14.937 13.1225 MAarrowhead1
% End of user PostScript
.4845 .39807 m
.48479 .39703 L
s
% Start of user PostScript
16. 13. 16.0093 12.966 MAarrowhead1
% End of user PostScript
.51521 .39807 m
.51593 .39735 L
s
% Start of user PostScript
17. 13. 17.0233 12.9767 MAarrowhead1
% End of user PostScript
.54593 .39807 m
.5462 .39791 L
s
% Start of user PostScript
18. 13. 18.0087 12.9947 MAarrowhead1
% End of user PostScript
.57664 .39807 m
.57675 .39807 L
s
% Start of user PostScript
19. 13. 19.0035 13. MAarrowhead1
% End of user PostScript
.60735 .39807 m
.60982 .39792 L
s
% Start of user PostScript
20. 13. 20.0802 12.9951 MAarrowhead1
% End of user PostScript
.63807 .39807 m
.63518 .39951 L
s
% Start of user PostScript
21. 13. 20.9062 13.0471 MAarrowhead1
% End of user PostScript
.66878 .39807 m
.66552 .39846 L
s
% Start of user PostScript
22. 13. 21.8938 13.0128 MAarrowhead1
% End of user PostScript
.69949 .39807 m
.69496 .40052 L
s
% Start of user PostScript
23. 13. 22.8524 13.0798 MAarrowhead1
% End of user PostScript
.7302 .39807 m
.73258 .39919 L
s
% Start of user PostScript
24. 13. 24.0774 13.0366 MAarrowhead1
% End of user PostScript
.76092 .39807 m
.75862 .40036 L
s
% Start of user PostScript
25. 13. 24.9254 13.0746 MAarrowhead1
% End of user PostScript
.79163 .39807 m
.79197 .39812 L
s
% Start of user PostScript
26. 13. 26.0109 13.0017 MAarrowhead1
% End of user PostScript
.82234 .39807 m
.82501 .39891 L
s
% Start of user PostScript
27. 13. 27.0868 13.0273 MAarrowhead1
% End of user PostScript
.85306 .39807 m
.85306 .39807 L
s
% Start of user PostScript
28. 13. MAarrowzero1
% End of user PostScript
.88377 .39807 m
.88405 .39778 L
s
% Start of user PostScript
29. 13. 29.0093 12.9907 MAarrowhead1
% End of user PostScript
.91448 .39807 m
.91448 .39807 L
s
% Start of user PostScript
30. 13. MAarrowzero1
% End of user PostScript
.94519 .39807 m
.94519 .39807 L
s
% Start of user PostScript
31. 13. MAarrowzero1
% End of user PostScript
.97591 .39807 m
.97562 .39778 L
s
% Start of user PostScript
32. 13. 31.9907 12.9907 MAarrowhead1
% End of user PostScript
.02381 .42878 m
.02381 .42878 L
s
% Start of user PostScript
1. 14. MAarrowzero1
% End of user PostScript
.05452 .42878 m
.05424 .4285 L
s
% Start of user PostScript
2. 14. 1.99075 13.9907 MAarrowhead1
% End of user PostScript
.08524 .42878 m
.08552 .42907 L
s
% Start of user PostScript
3. 14. 3.00925 14.0093 MAarrowhead1
% End of user PostScript
.11595 .42878 m
.11566 .42907 L
s
% Start of user PostScript
4. 14. 3.99075 14.0093 MAarrowhead1
% End of user PostScript
.14666 .42878 m
.14666 .42821 L
s
% Start of user PostScript
5. 14. 5. 13.9815 MAarrowhead1
% End of user PostScript
.17737 .42878 m
.18534 .43317 L
s
% Start of user PostScript
6. 14. 6.25935 14.1428 MAarrowhead1
% End of user PostScript
.20809 .42878 m
.20859 .43014 L
s
% Start of user PostScript
7. 14. 7.01627 14.0442 MAarrowhead1
% End of user PostScript
.2388 .42878 m
.2421 .4314 L
s
% Start of user PostScript
8. 14. 8.10733 14.0854 MAarrowhead1
% End of user PostScript
.26951 .42878 m
.26917 .42855 L
s
% Start of user PostScript
9. 14. 8.98886 13.9923 MAarrowhead1
% End of user PostScript
.30022 .42878 m
.30022 .42878 L
s
% Start of user PostScript
10. 14. MAarrowzero1
% End of user PostScript
.33094 .42878 m
.33102 .4287 L
s
% Start of user PostScript
11. 14. 11.0028 13.9972 MAarrowhead1
% End of user PostScript
.36165 .42878 m
.36083 .42864 L
s
% Start of user PostScript
12. 14. 11.9733 13.9953 MAarrowhead1
% End of user PostScript
.39236 .42878 m
.3929 .42932 L
s
% Start of user PostScript
13. 14. 13.0174 14.0174 MAarrowhead1
% End of user PostScript
.42308 .42878 m
.4244 .43011 L
s
% Start of user PostScript
14. 14. 14.0432 14.0432 MAarrowhead1
% End of user PostScript
.45379 .42878 m
.45364 .42882 L
s
% Start of user PostScript
15. 14. 14.9953 14.0013 MAarrowhead1
% End of user PostScript
.4845 .42878 m
.4845 .42868 L
s
% Start of user PostScript
16. 14. 16. 13.9965 MAarrowhead1
% End of user PostScript
.51521 .42878 m
.51541 .42898 L
s
% Start of user PostScript
17. 14. 17.0064 14.0064 MAarrowhead1
% End of user PostScript
.54593 .42878 m
.54659 .42812 L
s
% Start of user PostScript
18. 14. 18.0216 13.9784 MAarrowhead1
% End of user PostScript
.57664 .42878 m
.57736 .42806 L
s
% Start of user PostScript
19. 14. 19.0233 13.9767 MAarrowhead1
% End of user PostScript
.60735 .42878 m
.60871 .42839 L
s
% Start of user PostScript
20. 14. 20.0441 13.9873 MAarrowhead1
% End of user PostScript
.63807 .42878 m
.63554 .42887 L
s
% Start of user PostScript
21. 14. 20.9178 14.0029 MAarrowhead1
% End of user PostScript
.66878 .42878 m
.66938 .42928 L
s
% Start of user PostScript
22. 14. 22.0196 14.0162 MAarrowhead1
% End of user PostScript
.69949 .42878 m
.69954 .42991 L
s
% Start of user PostScript
23. 14. 23.0016 14.0369 MAarrowhead1
% End of user PostScript
.7302 .42878 m
.72881 .42938 L
s
% Start of user PostScript
24. 14. 23.9545 14.0196 MAarrowhead1
% End of user PostScript
.76092 .42878 m
.763 .4299 L
s
% Start of user PostScript
25. 14. 25.0677 14.0363 MAarrowhead1
% End of user PostScript
.79163 .42878 m
.78969 .42771 L
s
% Start of user PostScript
26. 14. 25.9369 13.9651 MAarrowhead1
% End of user PostScript
.82234 .42878 m
.82234 .42878 L
s
% Start of user PostScript
27. 14. MAarrowzero1
% End of user PostScript
.85306 .42878 m
.85306 .42935 L
s
% Start of user PostScript
28. 14. 28. 14.0185 MAarrowhead1
% End of user PostScript
.88377 .42878 m
.88405 .4285 L
s
% Start of user PostScript
29. 14. 29.0093 13.9907 MAarrowhead1
% End of user PostScript
.91448 .42878 m
.91448 .42878 L
s
% Start of user PostScript
30. 14. MAarrowzero1
% End of user PostScript
.94519 .42878 m
.94519 .42878 L
s
% Start of user PostScript
31. 14. MAarrowzero1
% End of user PostScript
.97591 .42878 m
.97591 .42878 L
s
% Start of user PostScript
32. 14. MAarrowzero1
% End of user PostScript
.02381 .45949 m
.02381 .45949 L
s
% Start of user PostScript
1. 15. MAarrowzero1
% End of user PostScript
.05452 .45949 m
.05452 .45949 L
s
% Start of user PostScript
2. 15. MAarrowzero1
% End of user PostScript
.08524 .45949 m
.08524 .45949 L
s
% Start of user PostScript
3. 15. MAarrowzero1
% End of user PostScript
.11595 .45949 m
.11623 .45921 L
s
% Start of user PostScript
4. 15. 4.00925 14.9907 MAarrowhead1
% End of user PostScript
.14666 .45949 m
.14666 .45893 L
s
% Start of user PostScript
5. 15. 5. 14.9815 MAarrowhead1
% End of user PostScript
.17737 .45949 m
.17923 .46129 L
s
% Start of user PostScript
6. 15. 6.06045 15.0584 MAarrowhead1
% End of user PostScript
.20809 .45949 m
.20837 .46039 L
s
% Start of user PostScript
7. 15. 7.00925 15.0293 MAarrowhead1
% End of user PostScript
.2388 .45949 m
.23959 .45591 L
s
% Start of user PostScript
8. 15. 8.02571 14.8832 MAarrowhead1
% End of user PostScript
.26951 .45949 m
.26881 .45896 L
s
% Start of user PostScript
9. 15. 8.977 14.9825 MAarrowhead1
% End of user PostScript
.30022 .45949 m
.29974 .45901 L
s
% Start of user PostScript
10. 15. 9.98431 14.9843 MAarrowhead1
% End of user PostScript
.33094 .45949 m
.33054 .45893 L
s
% Start of user PostScript
11. 15. 10.9871 14.9815 MAarrowhead1
% End of user PostScript
.36165 .45949 m
.36165 .45949 L
s
% Start of user PostScript
12. 15. MAarrowzero1
% End of user PostScript
.39236 .45949 m
.39236 .45949 L
s
% Start of user PostScript
13. 15. MAarrowzero1
% End of user PostScript
.42308 .45949 m
.42408 .45949 L
s
% Start of user PostScript
14. 15. 14.0325 15. MAarrowhead1
% End of user PostScript
.45379 .45949 m
.45344 .45915 L
s
% Start of user PostScript
15. 15. 14.9888 14.9888 MAarrowhead1
% End of user PostScript
.4845 .45949 m
.48485 .45984 L
s
% Start of user PostScript
16. 15. 16.0112 15.0112 MAarrowhead1
% End of user PostScript
.51521 .45949 m
.51521 .45949 L
s
% Start of user PostScript
17. 15. MAarrowzero1
% End of user PostScript
.54593 .45949 m
.54632 .4591 L
s
% Start of user PostScript
18. 15. 18.0127 14.9873 MAarrowhead1
% End of user PostScript
.57664 .45949 m
.57764 .45939 L
s
% Start of user PostScript
19. 15. 19.0325 14.9965 MAarrowhead1
% End of user PostScript
.60735 .45949 m
.61091 .45919 L
s
% Start of user PostScript
20. 15. 20.116 14.99 MAarrowhead1
% End of user PostScript
.63807 .45949 m
.64026 .45833 L
s
% Start of user PostScript
21. 15. 21.0715 14.9621 MAarrowhead1
% End of user PostScript
.66878 .45949 m
.66723 .45986 L
s
% Start of user PostScript
22. 15. 21.9497 15.0118 MAarrowhead1
% End of user PostScript
.69949 .45949 m
.69898 .45762 L
s
% Start of user PostScript
23. 15. 22.9834 14.939 MAarrowhead1
% End of user PostScript
.7302 .45949 m
.72949 .46021 L
s
% Start of user PostScript
24. 15. 23.9767 15.0233 MAarrowhead1
% End of user PostScript
.76092 .45949 m
.76516 .46037 L
s
% Start of user PostScript
25. 15. 25.1381 15.0286 MAarrowhead1
% End of user PostScript
.79163 .45949 m
.78709 .45925 L
s
% Start of user PostScript
26. 15. 25.8521 14.992 MAarrowhead1
% End of user PostScript
.82234 .45949 m
.82234 .45949 L
s
% Start of user PostScript
27. 15. MAarrowzero1
% End of user PostScript
.85306 .45949 m
.85306 .45949 L
s
% Start of user PostScript
28. 15. MAarrowzero1
% End of user PostScript
.88377 .45949 m
.88348 .45921 L
s
% Start of user PostScript
29. 15. 28.9907 14.9907 MAarrowhead1
% End of user PostScript
.91448 .45949 m
.9142 .45921 L
s
% Start of user PostScript
30. 15. 29.9907 14.9907 MAarrowhead1
% End of user PostScript
.94519 .45949 m
.94519 .45949 L
s
% Start of user PostScript
31. 15. MAarrowzero1
% End of user PostScript
.97591 .45949 m
.97562 .45978 L
s
% Start of user PostScript
32. 15. 31.9907 15.0093 MAarrowhead1
% End of user PostScript
.02381 .49021 m
.02381 .48964 L
s
% Start of user PostScript
1. 16. 1. 15.9815 MAarrowhead1
% End of user PostScript
.05452 .49021 m
.05452 .49021 L
s
% Start of user PostScript
2. 16. MAarrowzero1
% End of user PostScript
.08524 .49021 m
.08552 .48992 L
s
% Start of user PostScript
3. 16. 3.00925 15.9907 MAarrowhead1
% End of user PostScript
.11595 .49021 m
.11595 .49021 L
s
% Start of user PostScript
4. 16. MAarrowzero1
% End of user PostScript
.14666 .49021 m
.14609 .49021 L
s
% Start of user PostScript
5. 16. 4.98149 16. MAarrowhead1
% End of user PostScript
.17737 .49021 m
.18037 .49022 L
s
% Start of user PostScript
6. 16. 6.09745 16.0006 MAarrowhead1
% End of user PostScript
.20809 .49021 m
.21129 .4908 L
s
% Start of user PostScript
7. 16. 7.10431 16.0193 MAarrowhead1
% End of user PostScript
.2388 .49021 m
.23749 .49083 L
s
% Start of user PostScript
8. 16. 7.95749 16.0202 MAarrowhead1
% End of user PostScript
.26951 .49021 m
.26903 .48973 L
s
% Start of user PostScript
9. 16. 8.98431 15.9843 MAarrowhead1
% End of user PostScript
.30022 .49021 m
.30079 .4906 L
s
% Start of user PostScript
10. 16. 10.0185 16.0129 MAarrowhead1
% End of user PostScript
.33094 .49021 m
.3307 .49151 L
s
% Start of user PostScript
11. 16. 10.9924 16.0425 MAarrowhead1
% End of user PostScript
.36165 .49021 m
.36088 .49097 L
s
% Start of user PostScript
12. 16. 11.9751 16.0249 MAarrowhead1
% End of user PostScript
.39236 .49021 m
.39177 .49012 L
s
% Start of user PostScript
13. 16. 12.9808 15.9972 MAarrowhead1
% End of user PostScript
.42308 .49021 m
.42576 .49049 L
s
% Start of user PostScript
14. 16. 14.0873 16.0093 MAarrowhead1
% End of user PostScript
.45379 .49021 m
.45306 .49104 L
s
% Start of user PostScript
15. 16. 14.9762 16.0273 MAarrowhead1
% End of user PostScript
.4845 .49021 m
.48436 .49006 L
s
% Start of user PostScript
16. 16. 15.9953 15.9953 MAarrowhead1
% End of user PostScript
.51521 .49021 m
.51484 .49165 L
s
% Start of user PostScript
17. 16. 16.9879 16.047 MAarrowhead1
% End of user PostScript
.54593 .49021 m
.54584 .4904 L
s
% Start of user PostScript
18. 16. 17.997 16.0064 MAarrowhead1
% End of user PostScript
.57664 .49021 m
.5776 .49043 L
s
% Start of user PostScript
19. 16. 19.0314 16.0071 MAarrowhead1
% End of user PostScript
.60735 .49021 m
.60893 .4895 L
s
% Start of user PostScript
20. 16. 20.0512 15.9769 MAarrowhead1
% End of user PostScript
.63807 .49021 m
.64009 .4899 L
s
% Start of user PostScript
21. 16. 21.0658 15.99 MAarrowhead1
% End of user PostScript
.66878 .49021 m
.66707 .49021 L
s
% Start of user PostScript
22. 16. 21.9444 16. MAarrowhead1
% End of user PostScript
.69949 .49021 m
.69949 .49021 L
s
% Start of user PostScript
23. 16. MAarrowzero1
% End of user PostScript
.7302 .49021 m
.72972 .49069 L
s
% Start of user PostScript
24. 16. 23.9843 16.0157 MAarrowhead1
% End of user PostScript
.76092 .49021 m
.7589 .48979 L
s
% Start of user PostScript
25. 16. 24.9343 15.9865 MAarrowhead1
% End of user PostScript
.79163 .49021 m
.78508 .4887 L
s
% Start of user PostScript
26. 16. 25.7869 15.951 MAarrowhead1
% End of user PostScript
.82234 .49021 m
.82206 .49049 L
s
% Start of user PostScript
27. 16. 26.9907 16.0093 MAarrowhead1
% End of user PostScript
.85306 .49021 m
.85306 .49021 L
s
% Start of user PostScript
28. 16. MAarrowzero1
% End of user PostScript
.88377 .49021 m
.88377 .49021 L
s
% Start of user PostScript
29. 16. MAarrowzero1
% End of user PostScript
.91448 .49021 m
.91505 .49021 L
s
% Start of user PostScript
30. 16. 30.0185 16. MAarrowhead1
% End of user PostScript
.94519 .49021 m
.94519 .49021 L
s
% Start of user PostScript
31. 16. MAarrowzero1
% End of user PostScript
.97591 .49021 m
.97591 .49021 L
s
% Start of user PostScript
32. 16. MAarrowzero1
% End of user PostScript
.02381 .52092 m
.02381 .52035 L
s
% Start of user PostScript
1. 17. 1. 16.9815 MAarrowhead1
% End of user PostScript
.05452 .52092 m
.05452 .52092 L
s
% Start of user PostScript
2. 17. MAarrowzero1
% End of user PostScript
.08524 .52092 m
.08495 .52064 L
s
% Start of user PostScript
3. 17. 2.99075 16.9907 MAarrowhead1
% End of user PostScript
.11595 .52092 m
.11566 .5212 L
s
% Start of user PostScript
4. 17. 3.99075 17.0093 MAarrowhead1
% End of user PostScript
.14666 .52092 m
.1578 .52219 L
s
% Start of user PostScript
5. 17. 5.3628 17.0413 MAarrowhead1
% End of user PostScript
.17737 .52092 m
.17968 .5215 L
s
% Start of user PostScript
6. 17. 6.07512 17.019 MAarrowhead1
% End of user PostScript
.20809 .52092 m
.20621 .52377 L
s
% Start of user PostScript
7. 17. 6.93896 17.0928 MAarrowhead1
% End of user PostScript
.2388 .52092 m
.23798 .51938 L
s
% Start of user PostScript
8. 17. 7.97345 16.95 MAarrowhead1
% End of user PostScript
.26951 .52092 m
.27005 .52214 L
s
% Start of user PostScript
9. 17. 9.01741 17.0398 MAarrowhead1
% End of user PostScript
.30022 .52092 m
.29699 .51782 L
s
% Start of user PostScript
10. 17. 9.89473 16.8992 MAarrowhead1
% End of user PostScript
.33094 .52092 m
.33161 .52226 L
s
% Start of user PostScript
11. 17. 11.0218 17.0437 MAarrowhead1
% End of user PostScript
.36165 .52092 m
.36216 .52036 L
s
% Start of user PostScript
12. 17. 12.0165 16.9819 MAarrowhead1
% End of user PostScript
.39236 .52092 m
.39053 .52083 L
s
% Start of user PostScript
13. 17. 12.9402 16.997 MAarrowhead1
% End of user PostScript
.42308 .52092 m
.42475 .52087 L
s
% Start of user PostScript
14. 17. 14.0544 16.9983 MAarrowhead1
% End of user PostScript
.45379 .52092 m
.45237 .52337 L
s
% Start of user PostScript
15. 17. 14.9537 17.0796 MAarrowhead1
% End of user PostScript
.4845 .52092 m
.48112 .51414 L
s
% Start of user PostScript
16. 17. 15.89 16.7792 MAarrowhead1
% End of user PostScript
.51521 .52092 m
.51102 .5196 L
s
% Start of user PostScript
17. 17. 16.8634 16.9571 MAarrowhead1
% End of user PostScript
.54593 .52092 m
.54584 .52327 L
s
% Start of user PostScript
18. 17. 17.9971 17.0766 MAarrowhead1
% End of user PostScript
.57664 .52092 m
.57605 .52151 L
s
% Start of user PostScript
19. 17. 18.9809 17.0191 MAarrowhead1
% End of user PostScript
.60735 .52092 m
.60837 .52087 L
s
% Start of user PostScript
20. 17. 20.0332 16.9984 MAarrowhead1
% End of user PostScript
.63807 .52092 m
.6405 .52146 L
s
% Start of user PostScript
21. 17. 21.0792 17.0176 MAarrowhead1
% End of user PostScript
.66878 .52092 m
.66762 .52323 L
s
% Start of user PostScript
22. 17. 21.9622 17.0752 MAarrowhead1
% End of user PostScript
.69949 .52092 m
.69613 .52239 L
s
% Start of user PostScript
23. 17. 22.8905 17.0479 MAarrowhead1
% End of user PostScript
.7302 .52092 m
.72898 .52194 L
s
% Start of user PostScript
24. 17. 23.96 17.0334 MAarrowhead1
% End of user PostScript
.76092 .52092 m
.75598 .52031 L
s
% Start of user PostScript
25. 17. 24.8393 16.9801 MAarrowhead1
% End of user PostScript
.79163 .52092 m
.79081 .5201 L
s
% Start of user PostScript
26. 17. 25.9733 16.9733 MAarrowhead1
% End of user PostScript
.82234 .52092 m
.82234 .52092 L
s
% Start of user PostScript
27. 17. MAarrowzero1
% End of user PostScript
.85306 .52092 m
.85306 .52092 L
s
% Start of user PostScript
28. 17. MAarrowzero1
% End of user PostScript
.88377 .52092 m
.88405 .5212 L
s
% Start of user PostScript
29. 17. 29.0093 17.0093 MAarrowhead1
% End of user PostScript
.91448 .52092 m
.91448 .52092 L
s
% Start of user PostScript
30. 17. MAarrowzero1
% End of user PostScript
.94519 .52092 m
.94519 .52092 L
s
% Start of user PostScript
31. 17. MAarrowzero1
% End of user PostScript
.97591 .52092 m
.97591 .52092 L
s
% Start of user PostScript
32. 17. MAarrowzero1
% End of user PostScript
.02381 .55163 m
.02381 .55163 L
s
% Start of user PostScript
1. 18. MAarrowzero1
% End of user PostScript
.05452 .55163 m
.05481 .55135 L
s
% Start of user PostScript
2. 18. 2.00925 17.9907 MAarrowhead1
% End of user PostScript
.08524 .55163 m
.08552 .55135 L
s
% Start of user PostScript
3. 18. 3.00925 17.9907 MAarrowhead1
% End of user PostScript
.11595 .55163 m
.11623 .55192 L
s
% Start of user PostScript
4. 18. 4.00925 18.0093 MAarrowhead1
% End of user PostScript
.14666 .55163 m
.1497 .54656 L
s
% Start of user PostScript
5. 18. 5.09908 17.8348 MAarrowhead1
% End of user PostScript
.17737 .55163 m
.17553 .55348 L
s
% Start of user PostScript
6. 18. 5.94 18.06 MAarrowhead1
% End of user PostScript
.20809 .55163 m
.20283 .55001 L
s
% Start of user PostScript
7. 18. 6.82898 17.947 MAarrowhead1
% End of user PostScript
.2388 .55163 m
.23677 .5528 L
s
% Start of user PostScript
8. 18. 7.93392 18.0379 MAarrowhead1
% End of user PostScript
.26951 .55163 m
.2694 .54981 L
s
% Start of user PostScript
9. 18. 8.99645 17.9408 MAarrowhead1
% End of user PostScript
.30022 .55163 m
.30187 .54125 L
s
% Start of user PostScript
10. 18. 10.0537 17.662 MAarrowhead1
% End of user PostScript
.33094 .55163 m
.33049 .53926 L
s
% Start of user PostScript
11. 18. 10.9855 17.5972 MAarrowhead1
% End of user PostScript
.36165 .55163 m
.36006 .55183 L
s
% Start of user PostScript
12. 18. 11.9483 18.0063 MAarrowhead1
% End of user PostScript
.39236 .55163 m
.39177 .55172 L
s
% Start of user PostScript
13. 18. 12.9808 18.0028 MAarrowhead1
% End of user PostScript
.42308 .55163 m
.42327 .55087 L
s
% Start of user PostScript
14. 18. 14.0064 17.9751 MAarrowhead1
% End of user PostScript
.45379 .55163 m
.45412 .55206 L
s
% Start of user PostScript
15. 18. 15.0106 18.0141 MAarrowhead1
% End of user PostScript
.4845 .55163 m
.48294 .54477 L
s
% Start of user PostScript
16. 18. 15.9492 17.7766 MAarrowhead1
% End of user PostScript
.51521 .55163 m
.5166 .54376 L
s
% Start of user PostScript
17. 18. 17.0452 17.7435 MAarrowhead1
% End of user PostScript
.54593 .55163 m
.54385 .54644 L
s
% Start of user PostScript
18. 18. 17.9323 17.8308 MAarrowhead1
% End of user PostScript
.57664 .55163 m
.57616 .55029 L
s
% Start of user PostScript
19. 18. 18.9843 17.9562 MAarrowhead1
% End of user PostScript
.60735 .55163 m
.60793 .55235 L
s
% Start of user PostScript
20. 18. 20.0187 18.0232 MAarrowhead1
% End of user PostScript
.63807 .55163 m
.63942 .55126 L
s
% Start of user PostScript
21. 18. 21.0439 17.9879 MAarrowhead1
% End of user PostScript
.66878 .55163 m
.66713 .55163 L
s
% Start of user PostScript
22. 18. 21.9462 18. MAarrowhead1
% End of user PostScript
.69949 .55163 m
.6938 .55249 L
s
% Start of user PostScript
23. 18. 22.8148 18.0278 MAarrowhead1
% End of user PostScript
.7302 .55163 m
.72653 .55101 L
s
% Start of user PostScript
24. 18. 23.8804 17.9796 MAarrowhead1
% End of user PostScript
.76092 .55163 m
.75694 .55085 L
s
% Start of user PostScript
25. 18. 24.8706 17.9746 MAarrowhead1
% End of user PostScript
.79163 .55163 m
.79163 .55163 L
s
% Start of user PostScript
26. 18. MAarrowzero1
% End of user PostScript
.82234 .55163 m
.82234 .55163 L
s
% Start of user PostScript
27. 18. MAarrowzero1
% End of user PostScript
.85306 .55163 m
.85306 .55163 L
s
% Start of user PostScript
28. 18. MAarrowzero1
% End of user PostScript
.88377 .55163 m
.88377 .55163 L
s
% Start of user PostScript
29. 18. MAarrowzero1
% End of user PostScript
.91448 .55163 m
.91448 .55163 L
s
% Start of user PostScript
30. 18. MAarrowzero1
% End of user PostScript
.94519 .55163 m
.94519 .55163 L
s
% Start of user PostScript
31. 18. MAarrowzero1
% End of user PostScript
.97591 .55163 m
.97591 .55163 L
s
% Start of user PostScript
32. 18. MAarrowzero1
% End of user PostScript
.02381 .58235 m
.02381 .58235 L
s
% Start of user PostScript
1. 19. MAarrowzero1
% End of user PostScript
.05452 .58235 m
.05452 .58235 L
s
% Start of user PostScript
2. 19. MAarrowzero1
% End of user PostScript
.08524 .58235 m
.08524 .58235 L
s
% Start of user PostScript
3. 19. MAarrowzero1
% End of user PostScript
.11595 .58235 m
.11538 .58235 L
s
% Start of user PostScript
4. 19. 3.98149 19. MAarrowhead1
% End of user PostScript
.14666 .58235 m
.15881 .59085 L
s
% Start of user PostScript
5. 19. 5.39559 19.2768 MAarrowhead1
% End of user PostScript
.17737 .58235 m
.17946 .58025 L
s
% Start of user PostScript
6. 19. 6.06806 18.9319 MAarrowhead1
% End of user PostScript
.20809 .58235 m
.20745 .58298 L
s
% Start of user PostScript
7. 19. 6.97939 19.0206 MAarrowhead1
% End of user PostScript
.2388 .58235 m
.23482 .58246 L
s
% Start of user PostScript
8. 19. 7.87037 19.0037 MAarrowhead1
% End of user PostScript
.26951 .58235 m
.26934 .57649 L
s
% Start of user PostScript
9. 19. 8.99449 18.8094 MAarrowhead1
% End of user PostScript
.30022 .58235 m
.30034 .57877 L
s
% Start of user PostScript
10. 19. 10.0039 18.8836 MAarrowhead1
% End of user PostScript
.33094 .58235 m
.3306 .58121 L
s
% Start of user PostScript
11. 19. 10.989 18.9632 MAarrowhead1
% End of user PostScript
.36165 .58235 m
.36165 .58235 L
s
% Start of user PostScript
12. 19. MAarrowzero1
% End of user PostScript
.39236 .58235 m
.39338 .58229 L
s
% Start of user PostScript
13. 19. 13.0331 18.9983 MAarrowhead1
% End of user PostScript
.42308 .58235 m
.42299 .58147 L
s
% Start of user PostScript
14. 19. 13.9972 18.9714 MAarrowhead1
% End of user PostScript
.45379 .58235 m
.4537 .58176 L
s
% Start of user PostScript
15. 19. 14.9972 18.9808 MAarrowhead1
% End of user PostScript
.4845 .58235 m
.4861 .57696 L
s
% Start of user PostScript
16. 19. 16.052 18.8245 MAarrowhead1
% End of user PostScript
.51521 .58235 m
.51794 .57452 L
s
% Start of user PostScript
17. 19. 17.0888 18.7454 MAarrowhead1
% End of user PostScript
.54593 .58235 m
.54629 .58392 L
s
% Start of user PostScript
18. 19. 18.0117 19.0514 MAarrowhead1
% End of user PostScript
.57664 .58235 m
.57562 .58133 L
s
% Start of user PostScript
19. 19. 18.9668 18.9668 MAarrowhead1
% End of user PostScript
.60735 .58235 m
.60993 .58235 L
s
% Start of user PostScript
20. 19. 20.084 19. MAarrowhead1
% End of user PostScript
.63807 .58235 m
.63813 .58528 L
s
% Start of user PostScript
21. 19. 21.0021 19.0955 MAarrowhead1
% End of user PostScript
.66878 .58235 m
.67089 .58564 L
s
% Start of user PostScript
22. 19. 22.0688 19.1074 MAarrowhead1
% End of user PostScript
.69949 .58235 m
.69795 .58196 L
s
% Start of user PostScript
23. 19. 22.95 18.9873 MAarrowhead1
% End of user PostScript
.7302 .58235 m
.72532 .58139 L
s
% Start of user PostScript
24. 19. 23.8411 18.969 MAarrowhead1
% End of user PostScript
.76092 .58235 m
.75069 .57919 L
s
% Start of user PostScript
25. 19. 24.667 18.8973 MAarrowhead1
% End of user PostScript
.79163 .58235 m
.79163 .58235 L
s
% Start of user PostScript
26. 19. MAarrowzero1
% End of user PostScript
.82234 .58235 m
.82234 .58235 L
s
% Start of user PostScript
27. 19. MAarrowzero1
% End of user PostScript
.85306 .58235 m
.85306 .58235 L
s
% Start of user PostScript
28. 19. MAarrowzero1
% End of user PostScript
.88377 .58235 m
.88377 .58235 L
s
% Start of user PostScript
29. 19. MAarrowzero1
% End of user PostScript
.91448 .58235 m
.91476 .58263 L
s
% Start of user PostScript
30. 19. 30.0093 19.0093 MAarrowhead1
% End of user PostScript
.94519 .58235 m
.94519 .58235 L
s
% Start of user PostScript
31. 19. MAarrowzero1
% End of user PostScript
.97591 .58235 m
.97591 .58235 L
s
% Start of user PostScript
32. 19. MAarrowzero1
% End of user PostScript
.02381 .61306 m
.02381 .61306 L
s
% Start of user PostScript
1. 20. MAarrowzero1
% End of user PostScript
.05452 .61306 m
.05452 .61306 L
s
% Start of user PostScript
2. 20. MAarrowzero1
% End of user PostScript
.08524 .61306 m
.08524 .61306 L
s
% Start of user PostScript
3. 20. MAarrowzero1
% End of user PostScript
.11595 .61306 m
.11595 .61306 L
s
% Start of user PostScript
4. 20. MAarrowzero1
% End of user PostScript
.14666 .61306 m
.14632 .6134 L
s
% Start of user PostScript
5. 20. 4.98902 20.011 MAarrowhead1
% End of user PostScript
.17737 .61306 m
.17689 .61354 L
s
% Start of user PostScript
6. 20. 5.98431 20.0157 MAarrowhead1
% End of user PostScript
.20809 .61306 m
.2078 .61266 L
s
% Start of user PostScript
7. 20. 6.99053 19.9871 MAarrowhead1
% End of user PostScript
.2388 .61306 m
.23596 .6117 L
s
% Start of user PostScript
8. 20. 7.90765 19.9558 MAarrowhead1
% End of user PostScript
.26951 .61306 m
.26941 .61306 L
s
% Start of user PostScript
9. 20. 8.99655 20. MAarrowhead1
% End of user PostScript
.30022 .61306 m
.30039 .61306 L
s
% Start of user PostScript
10. 20. 10.0055 20. MAarrowhead1
% End of user PostScript
.33094 .61306 m
.33054 .61266 L
s
% Start of user PostScript
11. 20. 10.9871 19.9871 MAarrowhead1
% End of user PostScript
.36165 .61306 m
.36165 .61385 L
s
% Start of user PostScript
12. 20. 12. 20.0258 MAarrowhead1
% End of user PostScript
.39236 .61306 m
.39236 .61306 L
s
% Start of user PostScript
13. 20. MAarrowzero1
% End of user PostScript
.42308 .61306 m
.42308 .61402 L
s
% Start of user PostScript
14. 20. 14. 20.0314 MAarrowhead1
% End of user PostScript
.45379 .61306 m
.45376 .61359 L
s
% Start of user PostScript
15. 20. 14.999 20.0175 MAarrowhead1
% End of user PostScript
.4845 .61306 m
.48479 .61374 L
s
% Start of user PostScript
16. 20. 16.0093 20.0221 MAarrowhead1
% End of user PostScript
.51521 .61306 m
.51487 .61415 L
s
% Start of user PostScript
17. 20. 16.9888 20.0355 MAarrowhead1
% End of user PostScript
.54593 .61306 m
.54693 .61306 L
s
% Start of user PostScript
18. 20. 18.0325 20. MAarrowhead1
% End of user PostScript
.57664 .61306 m
.57813 .61379 L
s
% Start of user PostScript
19. 20. 19.0487 20.024 MAarrowhead1
% End of user PostScript
.60735 .61306 m
.60864 .61177 L
s
% Start of user PostScript
20. 20. 20.042 19.958 MAarrowhead1
% End of user PostScript
.63807 .61306 m
.64079 .61449 L
s
% Start of user PostScript
21. 20. 21.0887 20.0467 MAarrowhead1
% End of user PostScript
.66878 .61306 m
.67091 .61412 L
s
% Start of user PostScript
22. 20. 22.0694 20.0346 MAarrowhead1
% End of user PostScript
.69949 .61306 m
.69831 .61299 L
s
% Start of user PostScript
23. 20. 22.9614 19.9978 MAarrowhead1
% End of user PostScript
.7302 .61306 m
.7323 .61176 L
s
% Start of user PostScript
24. 20. 24.0683 19.9576 MAarrowhead1
% End of user PostScript
.76092 .61306 m
.76063 .61277 L
s
% Start of user PostScript
25. 20. 24.9907 19.9907 MAarrowhead1
% End of user PostScript
.79163 .61306 m
.79163 .61306 L
s
% Start of user PostScript
26. 20. MAarrowzero1
% End of user PostScript
.82234 .61306 m
.82234 .61306 L
s
% Start of user PostScript
27. 20. MAarrowzero1
% End of user PostScript
.85306 .61306 m
.85306 .61306 L
s
% Start of user PostScript
28. 20. MAarrowzero1
% End of user PostScript
.88377 .61306 m
.88377 .61306 L
s
% Start of user PostScript
29. 20. MAarrowzero1
% End of user PostScript
.91448 .61306 m
.9142 .61334 L
s
% Start of user PostScript
30. 20. 29.9907 20.0093 MAarrowhead1
% End of user PostScript
.94519 .61306 m
.94519 .61306 L
s
% Start of user PostScript
31. 20. MAarrowzero1
% End of user PostScript
.97591 .61306 m
.97591 .61306 L
s
% Start of user PostScript
32. 20. MAarrowzero1
% End of user PostScript
.02381 .64377 m
.02381 .64377 L
s
% Start of user PostScript
1. 21. MAarrowzero1
% End of user PostScript
.05452 .64377 m
.05481 .64406 L
s
% Start of user PostScript
2. 21. 2.00925 21.0093 MAarrowhead1
% End of user PostScript
.08524 .64377 m
.08524 .64377 L
s
% Start of user PostScript
3. 21. MAarrowzero1
% End of user PostScript
.11595 .64377 m
.11595 .64377 L
s
% Start of user PostScript
4. 21. MAarrowzero1
% End of user PostScript
.14666 .64377 m
.14985 .63592 L
s
% Start of user PostScript
5. 21. 5.10398 20.7442 MAarrowhead1
% End of user PostScript
.17737 .64377 m
.17752 .64535 L
s
% Start of user PostScript
6. 21. 6.00471 21.0514 MAarrowhead1
% End of user PostScript
.20809 .64377 m
.20924 .64297 L
s
% Start of user PostScript
7. 21. 7.03771 20.9738 MAarrowhead1
% End of user PostScript
.2388 .64377 m
.23785 .64282 L
s
% Start of user PostScript
8. 21. 7.96908 20.9691 MAarrowhead1
% End of user PostScript
.26951 .64377 m
.26884 .64377 L
s
% Start of user PostScript
9. 21. 8.97804 21. MAarrowhead1
% End of user PostScript
.30022 .64377 m
.30014 .64386 L
s
% Start of user PostScript
10. 21. 9.99724 21.0028 MAarrowhead1
% End of user PostScript
.33094 .64377 m
.33006 .64369 L
s
% Start of user PostScript
11. 21. 10.9714 20.9972 MAarrowhead1
% End of user PostScript
.36165 .64377 m
.36134 .64425 L
s
% Start of user PostScript
12. 21. 11.9898 21.0157 MAarrowhead1
% End of user PostScript
.39236 .64377 m
.39284 .64425 L
s
% Start of user PostScript
13. 21. 13.0157 21.0157 MAarrowhead1
% End of user PostScript
.42308 .64377 m
.42316 .64369 L
s
% Start of user PostScript
14. 21. 14.0028 20.9972 MAarrowhead1
% End of user PostScript
.45379 .64377 m
.45379 .64377 L
s
% Start of user PostScript
15. 21. MAarrowzero1
% End of user PostScript
.4845 .64377 m
.4849 .64377 L
s
% Start of user PostScript
16. 21. 16.0129 21. MAarrowhead1
% End of user PostScript
.51521 .64377 m
.51389 .64377 L
s
% Start of user PostScript
17. 21. 16.9568 21. MAarrowhead1
% End of user PostScript
.54593 .64377 m
.54598 .64382 L
s
% Start of user PostScript
18. 21. 18.0017 21.0017 MAarrowhead1
% End of user PostScript
.57664 .64377 m
.57836 .64326 L
s
% Start of user PostScript
19. 21. 19.0561 20.9835 MAarrowhead1
% End of user PostScript
.60735 .64377 m
.60913 .64443 L
s
% Start of user PostScript
20. 21. 20.058 21.0215 MAarrowhead1
% End of user PostScript
.63807 .64377 m
.6391 .64444 L
s
% Start of user PostScript
21. 21. 21.0337 21.0219 MAarrowhead1
% End of user PostScript
.66878 .64377 m
.66639 .64314 L
s
% Start of user PostScript
22. 21. 21.9224 20.9796 MAarrowhead1
% End of user PostScript
.69949 .64377 m
.69897 .64343 L
s
% Start of user PostScript
23. 21. 22.9831 20.989 MAarrowhead1
% End of user PostScript
.7302 .64377 m
.72909 .64266 L
s
% Start of user PostScript
24. 21. 23.9638 20.9638 MAarrowhead1
% End of user PostScript
.76092 .64377 m
.76092 .64377 L
s
% Start of user PostScript
25. 21. MAarrowzero1
% End of user PostScript
.79163 .64377 m
.79163 .64377 L
s
% Start of user PostScript
26. 21. MAarrowzero1
% End of user PostScript
.82234 .64377 m
.82234 .64377 L
s
% Start of user PostScript
27. 21. MAarrowzero1
% End of user PostScript
.85306 .64377 m
.85306 .64377 L
s
% Start of user PostScript
28. 21. MAarrowzero1
% End of user PostScript
.88377 .64377 m
.88377 .64377 L
s
% Start of user PostScript
29. 21. MAarrowzero1
% End of user PostScript
.91448 .64377 m
.91448 .64377 L
s
% Start of user PostScript
30. 21. MAarrowzero1
% End of user PostScript
.94519 .64377 m
.94519 .64377 L
s
% Start of user PostScript
31. 21. MAarrowzero1
% End of user PostScript
.97591 .64377 m
.97591 .64377 L
s
% Start of user PostScript
32. 21. MAarrowzero1
% End of user PostScript
.02381 .67448 m
.02381 .67448 L
s
% Start of user PostScript
1. 22. MAarrowzero1
% End of user PostScript
.05452 .67448 m
.05452 .67448 L
s
% Start of user PostScript
2. 22. MAarrowzero1
% End of user PostScript
.08524 .67448 m
.08524 .67448 L
s
% Start of user PostScript
3. 22. MAarrowzero1
% End of user PostScript
.11595 .67448 m
.11595 .67448 L
s
% Start of user PostScript
4. 22. MAarrowzero1
% End of user PostScript
.14666 .67448 m
.14694 .6742 L
s
% Start of user PostScript
5. 22. 5.00925 21.9907 MAarrowhead1
% End of user PostScript
.17737 .67448 m
.17639 .6735 L
s
% Start of user PostScript
6. 22. 5.96782 21.9678 MAarrowhead1
% End of user PostScript
.20809 .67448 m
.20835 .67389 L
s
% Start of user PostScript
7. 22. 7.00867 21.9807 MAarrowhead1
% End of user PostScript
.2388 .67448 m
.23629 .67409 L
s
% Start of user PostScript
8. 22. 7.91824 21.9872 MAarrowhead1
% End of user PostScript
.26951 .67448 m
.26898 .67405 L
s
% Start of user PostScript
9. 22. 8.98259 21.986 MAarrowhead1
% End of user PostScript
.30022 .67448 m
.30022 .67448 L
s
% Start of user PostScript
10. 22. MAarrowzero1
% End of user PostScript
.33094 .67448 m
.33054 .67409 L
s
% Start of user PostScript
11. 22. 10.9871 21.9871 MAarrowhead1
% End of user PostScript
.36165 .67448 m
.36165 .67448 L
s
% Start of user PostScript
12. 22. MAarrowzero1
% End of user PostScript
.39236 .67448 m
.39236 .67448 L
s
% Start of user PostScript
13. 22. MAarrowzero1
% End of user PostScript
.42308 .67448 m
.42308 .67448 L
s
% Start of user PostScript
14. 22. MAarrowzero1
% End of user PostScript
.45379 .67448 m
.45413 .67482 L
s
% Start of user PostScript
15. 22. 15.011 22.011 MAarrowhead1
% End of user PostScript
.4845 .67448 m
.48507 .67488 L
s
% Start of user PostScript
16. 22. 16.0185 22.0129 MAarrowhead1
% End of user PostScript
.51521 .67448 m
.51625 .67448 L
s
% Start of user PostScript
17. 22. 17.0337 22. MAarrowhead1
% End of user PostScript
.54593 .67448 m
.54664 .67477 L
s
% Start of user PostScript
18. 22. 18.0233 22.0093 MAarrowhead1
% End of user PostScript
.57664 .67448 m
.5777 .67449 L
s
% Start of user PostScript
19. 22. 19.0345 22.0004 MAarrowhead1
% End of user PostScript
.60735 .67448 m
.60856 .67507 L
s
% Start of user PostScript
20. 22. 20.0392 22.0192 MAarrowhead1
% End of user PostScript
.63807 .67448 m
.6384 .67415 L
s
% Start of user PostScript
21. 22. 21.011 21.989 MAarrowhead1
% End of user PostScript
.66878 .67448 m
.66989 .67559 L
s
% Start of user PostScript
22. 22. 22.0361 22.0361 MAarrowhead1
% End of user PostScript
.69949 .67448 m
.70133 .67565 L
s
% Start of user PostScript
23. 22. 23.06 22.038 MAarrowhead1
% End of user PostScript
.7302 .67448 m
.72749 .67284 L
s
% Start of user PostScript
24. 22. 23.9116 21.9464 MAarrowhead1
% End of user PostScript
.76092 .67448 m
.76092 .67448 L
s
% Start of user PostScript
25. 22. MAarrowzero1
% End of user PostScript
.79163 .67448 m
.79163 .67448 L
s
% Start of user PostScript
26. 22. MAarrowzero1
% End of user PostScript
.82234 .67448 m
.82234 .67448 L
s
% Start of user PostScript
27. 22. MAarrowzero1
% End of user PostScript
.85306 .67448 m
.85306 .67448 L
s
% Start of user PostScript
28. 22. MAarrowzero1
% End of user PostScript
.88377 .67448 m
.88377 .67448 L
s
% Start of user PostScript
29. 22. MAarrowzero1
% End of user PostScript
.91448 .67448 m
.91448 .67448 L
s
% Start of user PostScript
30. 22. MAarrowzero1
% End of user PostScript
.94519 .67448 m
.94519 .67448 L
s
% Start of user PostScript
31. 22. MAarrowzero1
% End of user PostScript
.97591 .67448 m
.97591 .67448 L
s
% Start of user PostScript
32. 22. MAarrowzero1
% End of user PostScript
.02381 .7052 m
.02381 .7052 L
s
% Start of user PostScript
1. 23. MAarrowzero1
% End of user PostScript
.05452 .7052 m
.05452 .7052 L
s
% Start of user PostScript
2. 23. MAarrowzero1
% End of user PostScript
.08524 .7052 m
.08524 .7052 L
s
% Start of user PostScript
3. 23. MAarrowzero1
% End of user PostScript
.11595 .7052 m
.11595 .7052 L
s
% Start of user PostScript
4. 23. MAarrowzero1
% End of user PostScript
.14666 .7052 m
.14666 .7052 L
s
% Start of user PostScript
5. 23. MAarrowzero1
% End of user PostScript
.17737 .7052 m
.18557 .70255 L
s
% Start of user PostScript
6. 23. 6.26676 22.9139 MAarrowhead1
% End of user PostScript
.20809 .7052 m
.20907 .70336 L
s
% Start of user PostScript
7. 23. 7.03196 22.9401 MAarrowhead1
% End of user PostScript
.2388 .7052 m
.23667 .70543 L
s
% Start of user PostScript
8. 23. 7.93069 23.0075 MAarrowhead1
% End of user PostScript
.26951 .7052 m
.26865 .70462 L
s
% Start of user PostScript
9. 23. 8.97196 22.9814 MAarrowhead1
% End of user PostScript
.30022 .7052 m
.30022 .7048 L
s
% Start of user PostScript
10. 23. 10. 22.9871 MAarrowhead1
% End of user PostScript
.33094 .7052 m
.33051 .70563 L
s
% Start of user PostScript
11. 23. 10.986 23.014 MAarrowhead1
% End of user PostScript
.36165 .7052 m
.36165 .7052 L
s
% Start of user PostScript
12. 23. MAarrowzero1
% End of user PostScript
.39236 .7052 m
.39284 .70539 L
s
% Start of user PostScript
13. 23. 13.0157 23.0063 MAarrowhead1
% End of user PostScript
.42308 .7052 m
.42259 .70568 L
s
% Start of user PostScript
14. 23. 13.9843 23.0157 MAarrowhead1
% End of user PostScript
.45379 .7052 m
.45379 .7052 L
s
% Start of user PostScript
15. 23. MAarrowzero1
% End of user PostScript
.4845 .7052 m
.4845 .7052 L
s
% Start of user PostScript
16. 23. MAarrowzero1
% End of user PostScript
.51521 .7052 m
.51584 .70497 L
s
% Start of user PostScript
17. 23. 17.0204 22.9925 MAarrowhead1
% End of user PostScript
.54593 .7052 m
.54616 .70554 L
s
% Start of user PostScript
18. 23. 18.0077 23.0111 MAarrowhead1
% End of user PostScript
.57664 .7052 m
.57926 .70645 L
s
% Start of user PostScript
19. 23. 19.0852 23.0407 MAarrowhead1
% End of user PostScript
.60735 .7052 m
.60891 .70486 L
s
% Start of user PostScript
20. 23. 20.0506 22.989 MAarrowhead1
% End of user PostScript
.63807 .7052 m
.64256 .70282 L
s
% Start of user PostScript
21. 23. 21.1464 22.9228 MAarrowhead1
% End of user PostScript
.66878 .7052 m
.66165 .70369 L
s
% Start of user PostScript
22. 23. 21.768 22.9511 MAarrowhead1
% End of user PostScript
.69949 .7052 m
.69529 .70357 L
s
% Start of user PostScript
23. 23. 22.8631 22.9471 MAarrowhead1
% End of user PostScript
.7302 .7052 m
.73077 .7052 L
s
% Start of user PostScript
24. 23. 24.0185 23. MAarrowhead1
% End of user PostScript
.76092 .7052 m
.76092 .7052 L
s
% Start of user PostScript
25. 23. MAarrowzero1
% End of user PostScript
.79163 .7052 m
.79163 .7052 L
s
% Start of user PostScript
26. 23. MAarrowzero1
% End of user PostScript
.82234 .7052 m
.82234 .7052 L
s
% Start of user PostScript
27. 23. MAarrowzero1
% End of user PostScript
.85306 .7052 m
.85306 .7052 L
s
% Start of user PostScript
28. 23. MAarrowzero1
% End of user PostScript
.88377 .7052 m
.88377 .7052 L
s
% Start of user PostScript
29. 23. MAarrowzero1
% End of user PostScript
.91448 .7052 m
.91448 .7052 L
s
% Start of user PostScript
30. 23. MAarrowzero1
% End of user PostScript
.94519 .7052 m
.94519 .7052 L
s
% Start of user PostScript
31. 23. MAarrowzero1
% End of user PostScript
.97591 .7052 m
.97591 .7052 L
s
% Start of user PostScript
32. 23. MAarrowzero1
% End of user PostScript
.02381 .73591 m
.02381 .73591 L
s
% Start of user PostScript
1. 24. MAarrowzero1
% End of user PostScript
.05452 .73591 m
.05452 .73591 L
s
% Start of user PostScript
2. 24. MAarrowzero1
% End of user PostScript
.08524 .73591 m
.08524 .73591 L
s
% Start of user PostScript
3. 24. MAarrowzero1
% End of user PostScript
.11595 .73591 m
.11595 .73591 L
s
% Start of user PostScript
4. 24. MAarrowzero1
% End of user PostScript
.14666 .73591 m
.14666 .73591 L
s
% Start of user PostScript
5. 24. MAarrowzero1
% End of user PostScript
.17737 .73591 m
.17872 .73457 L
s
% Start of user PostScript
6. 24. 6.04373 23.9563 MAarrowhead1
% End of user PostScript
.20809 .73591 m
.20551 .73584 L
s
% Start of user PostScript
7. 24. 6.91604 23.9976 MAarrowhead1
% End of user PostScript
.2388 .73591 m
.23761 .73784 L
s
% Start of user PostScript
8. 24. 7.96139 24.0629 MAarrowhead1
% End of user PostScript
.26951 .73591 m
.2698 .73563 L
s
% Start of user PostScript
9. 24. 9.00925 23.9907 MAarrowhead1
% End of user PostScript
.30022 .73591 m
.29931 .73672 L
s
% Start of user PostScript
10. 24. 9.97024 24.0263 MAarrowhead1
% End of user PostScript
.33094 .73591 m
.33142 .73639 L
s
% Start of user PostScript
11. 24. 11.0157 24.0157 MAarrowhead1
% End of user PostScript
.36165 .73591 m
.3617 .737 L
s
% Start of user PostScript
12. 24. 12.0017 24.0354 MAarrowhead1
% End of user PostScript
.39236 .73591 m
.39274 .73825 L
s
% Start of user PostScript
13. 24. 13.0124 24.0763 MAarrowhead1
% End of user PostScript
.42308 .73591 m
.42346 .73768 L
s
% Start of user PostScript
14. 24. 14.0124 24.0578 MAarrowhead1
% End of user PostScript
.45379 .73591 m
.45359 .73787 L
s
% Start of user PostScript
15. 24. 14.9936 24.0637 MAarrowhead1
% End of user PostScript
.4845 .73591 m
.48485 .73808 L
s
% Start of user PostScript
16. 24. 16.0113 24.0708 MAarrowhead1
% End of user PostScript
.51521 .73591 m
.5157 .73822 L
s
% Start of user PostScript
17. 24. 17.0157 24.0752 MAarrowhead1
% End of user PostScript
.54593 .73591 m
.54709 .73707 L
s
% Start of user PostScript
18. 24. 18.0379 24.0379 MAarrowhead1
% End of user PostScript
.57664 .73591 m
.57788 .73883 L
s
% Start of user PostScript
19. 24. 19.0404 24.0949 MAarrowhead1
% End of user PostScript
.60735 .73591 m
.60626 .735 L
s
% Start of user PostScript
20. 24. 19.9645 23.9705 MAarrowhead1
% End of user PostScript
.63807 .73591 m
.63832 .73315 L
s
% Start of user PostScript
21. 24. 21.0082 23.9102 MAarrowhead1
% End of user PostScript
.66878 .73591 m
.66619 .73512 L
s
% Start of user PostScript
22. 24. 21.9158 23.9742 MAarrowhead1
% End of user PostScript
.69949 .73591 m
.69712 .73315 L
s
% Start of user PostScript
23. 24. 22.9229 23.9102 MAarrowhead1
% End of user PostScript
.7302 .73591 m
.7302 .73591 L
s
% Start of user PostScript
24. 24. MAarrowzero1
% End of user PostScript
.76092 .73591 m
.76092 .73591 L
s
% Start of user PostScript
25. 24. MAarrowzero1
% End of user PostScript
.79163 .73591 m
.79163 .73591 L
s
% Start of user PostScript
26. 24. MAarrowzero1
% End of user PostScript
.82234 .73591 m
.82234 .73591 L
s
% Start of user PostScript
27. 24. MAarrowzero1
% End of user PostScript
.85306 .73591 m
.85277 .73563 L
s
% Start of user PostScript
28. 24. 27.9907 23.9907 MAarrowhead1
% End of user PostScript
.88377 .73591 m
.88377 .73591 L
s
% Start of user PostScript
29. 24. MAarrowzero1
% End of user PostScript
.91448 .73591 m
.91448 .73591 L
s
% Start of user PostScript
30. 24. MAarrowzero1
% End of user PostScript
.94519 .73591 m
.94519 .73591 L
s
% Start of user PostScript
31. 24. MAarrowzero1
% End of user PostScript
.97591 .73591 m
.97591 .73591 L
s
% Start of user PostScript
32. 24. MAarrowzero1
% End of user PostScript
.02381 .76662 m
.02381 .76662 L
s
% Start of user PostScript
1. 25. MAarrowzero1
% End of user PostScript
.05452 .76662 m
.05452 .76662 L
s
% Start of user PostScript
2. 25. MAarrowzero1
% End of user PostScript
.08524 .76662 m
.08495 .76634 L
s
% Start of user PostScript
3. 25. 2.99075 24.9907 MAarrowhead1
% End of user PostScript
.11595 .76662 m
.11595 .76662 L
s
% Start of user PostScript
4. 25. MAarrowzero1
% End of user PostScript
.14666 .76662 m
.14666 .76662 L
s
% Start of user PostScript
5. 25. MAarrowzero1
% End of user PostScript
.17737 .76662 m
.17737 .76662 L
s
% Start of user PostScript
6. 25. MAarrowzero1
% End of user PostScript
.20809 .76662 m
.21371 .76004 L
s
% Start of user PostScript
7. 25. 7.18308 24.7855 MAarrowhead1
% End of user PostScript
.2388 .76662 m
.23818 .76832 L
s
% Start of user PostScript
8. 25. 7.97996 25.0553 MAarrowhead1
% End of user PostScript
.26951 .76662 m
.26733 .76881 L
s
% Start of user PostScript
9. 25. 8.92886 25.0711 MAarrowhead1
% End of user PostScript
.30022 .76662 m
.30051 .76809 L
s
% Start of user PostScript
10. 25. 10.0094 25.0478 MAarrowhead1
% End of user PostScript
.33094 .76662 m
.33099 .76789 L
s
% Start of user PostScript
11. 25. 11.0017 25.0414 MAarrowhead1
% End of user PostScript
.36165 .76662 m
.36152 .76873 L
s
% Start of user PostScript
12. 25. 11.9959 25.0685 MAarrowhead1
% End of user PostScript
.39236 .76662 m
.39369 .76795 L
s
% Start of user PostScript
13. 25. 13.0432 25.0432 MAarrowhead1
% End of user PostScript
.42308 .76662 m
.42368 .76723 L
s
% Start of user PostScript
14. 25. 14.0198 25.0198 MAarrowhead1
% End of user PostScript
.45379 .76662 m
.4536 .76777 L
s
% Start of user PostScript
15. 25. 14.9939 25.0375 MAarrowhead1
% End of user PostScript
.4845 .76662 m
.48528 .76573 L
s
% Start of user PostScript
16. 25. 16.0253 24.9708 MAarrowhead1
% End of user PostScript
.51521 .76662 m
.51588 .7684 L
s
% Start of user PostScript
17. 25. 17.0215 25.058 MAarrowhead1
% End of user PostScript
.54593 .76662 m
.54825 .76769 L
s
% Start of user PostScript
18. 25. 18.0757 25.0349 MAarrowhead1
% End of user PostScript
.57664 .76662 m
.57721 .77088 L
s
% Start of user PostScript
19. 25. 19.0187 25.1387 MAarrowhead1
% End of user PostScript
.60735 .76662 m
.60669 .76883 L
s
% Start of user PostScript
20. 25. 19.9784 25.0718 MAarrowhead1
% End of user PostScript
.63807 .76662 m
.63555 .76331 L
s
% Start of user PostScript
21. 25. 20.918 24.8921 MAarrowhead1
% End of user PostScript
.66878 .76662 m
.66812 .76789 L
s
% Start of user PostScript
22. 25. 21.9785 25.0413 MAarrowhead1
% End of user PostScript
.69949 .76662 m
.69949 .76662 L
s
% Start of user PostScript
23. 25. MAarrowzero1
% End of user PostScript
.7302 .76662 m
.73069 .7671 L
s
% Start of user PostScript
24. 25. 24.0157 25.0157 MAarrowhead1
% End of user PostScript
.76092 .76662 m
.76092 .76662 L
s
% Start of user PostScript
25. 25. MAarrowzero1
% End of user PostScript
.79163 .76662 m
.79163 .76662 L
s
% Start of user PostScript
26. 25. MAarrowzero1
% End of user PostScript
.82234 .76662 m
.82234 .76662 L
s
% Start of user PostScript
27. 25. MAarrowzero1
% End of user PostScript
.85306 .76662 m
.85306 .76662 L
s
% Start of user PostScript
28. 25. MAarrowzero1
% End of user PostScript
.88377 .76662 m
.88377 .76662 L
s
% Start of user PostScript
29. 25. MAarrowzero1
% End of user PostScript
.91448 .76662 m
.91448 .76662 L
s
% Start of user PostScript
30. 25. MAarrowzero1
% End of user PostScript
.94519 .76662 m
.94519 .76662 L
s
% Start of user PostScript
31. 25. MAarrowzero1
% End of user PostScript
.97591 .76662 m
.97591 .76662 L
s
% Start of user PostScript
32. 25. MAarrowzero1
% End of user PostScript
.02381 .79733 m
.02381 .79733 L
s
% Start of user PostScript
1. 26. MAarrowzero1
% End of user PostScript
.05452 .79733 m
.05452 .79733 L
s
% Start of user PostScript
2. 26. MAarrowzero1
% End of user PostScript
.08524 .79733 m
.08524 .79733 L
s
% Start of user PostScript
3. 26. MAarrowzero1
% End of user PostScript
.11595 .79733 m
.11595 .79733 L
s
% Start of user PostScript
4. 26. MAarrowzero1
% End of user PostScript
.14666 .79733 m
.14666 .79733 L
s
% Start of user PostScript
5. 26. MAarrowzero1
% End of user PostScript
.17737 .79733 m
.17737 .79733 L
s
% Start of user PostScript
6. 26. MAarrowzero1
% End of user PostScript
.20809 .79733 m
.20809 .79733 L
s
% Start of user PostScript
7. 26. MAarrowzero1
% End of user PostScript
.2388 .79733 m
.24364 .78823 L
s
% Start of user PostScript
8. 26. 8.15776 25.7034 MAarrowhead1
% End of user PostScript
.26951 .79733 m
.2684 .79543 L
s
% Start of user PostScript
9. 26. 8.96392 25.9381 MAarrowhead1
% End of user PostScript
.30022 .79733 m
.30109 .79626 L
s
% Start of user PostScript
10. 26. 10.0283 25.9651 MAarrowhead1
% End of user PostScript
.33094 .79733 m
.32983 .79919 L
s
% Start of user PostScript
11. 26. 10.9639 26.0604 MAarrowhead1
% End of user PostScript
.36165 .79733 m
.35952 .79783 L
s
% Start of user PostScript
12. 26. 11.9306 26.0161 MAarrowhead1
% End of user PostScript
.39236 .79733 m
.39401 .79898 L
s
% Start of user PostScript
13. 26. 13.0537 26.0537 MAarrowhead1
% End of user PostScript
.42308 .79733 m
.424 .79708 L
s
% Start of user PostScript
14. 26. 14.0302 25.9917 MAarrowhead1
% End of user PostScript
.45379 .79733 m
.45036 .79691 L
s
% Start of user PostScript
15. 26. 14.8882 25.9863 MAarrowhead1
% End of user PostScript
.4845 .79733 m
.48504 .79787 L
s
% Start of user PostScript
16. 26. 16.0174 26.0174 MAarrowhead1
% End of user PostScript
.51521 .79733 m
.51607 .79948 L
s
% Start of user PostScript
17. 26. 17.0278 26.0698 MAarrowhead1
% End of user PostScript
.54593 .79733 m
.54575 .79948 L
s
% Start of user PostScript
18. 26. 17.9941 26.0698 MAarrowhead1
% End of user PostScript
.57664 .79733 m
.57521 .79694 L
s
% Start of user PostScript
19. 26. 18.9534 25.9871 MAarrowhead1
% End of user PostScript
.60735 .79733 m
.60486 .79176 L
s
% Start of user PostScript
20. 26. 19.9188 25.8185 MAarrowhead1
% End of user PostScript
.63807 .79733 m
.63976 .79729 L
s
% Start of user PostScript
21. 26. 21.0553 25.9985 MAarrowhead1
% End of user PostScript
.66878 .79733 m
.66291 .79147 L
s
% Start of user PostScript
22. 26. 21.8089 25.8089 MAarrowhead1
% End of user PostScript
.69949 .79733 m
.69949 .79733 L
s
% Start of user PostScript
23. 26. MAarrowzero1
% End of user PostScript
.7302 .79733 m
.73049 .79705 L
s
% Start of user PostScript
24. 26. 24.0093 25.9907 MAarrowhead1
% End of user PostScript
.76092 .79733 m
.7614 .79782 L
s
% Start of user PostScript
25. 26. 25.0157 26.0157 MAarrowhead1
% End of user PostScript
.79163 .79733 m
.79115 .79782 L
s
% Start of user PostScript
26. 26. 25.9843 26.0157 MAarrowhead1
% End of user PostScript
.82234 .79733 m
.82234 .79733 L
s
% Start of user PostScript
27. 26. MAarrowzero1
% End of user PostScript
.85306 .79733 m
.85306 .79733 L
s
% Start of user PostScript
28. 26. MAarrowzero1
% End of user PostScript
.88377 .79733 m
.88377 .79733 L
s
% Start of user PostScript
29. 26. MAarrowzero1
% End of user PostScript
.91448 .79733 m
.91448 .79733 L
s
% Start of user PostScript
30. 26. MAarrowzero1
% End of user PostScript
.94519 .79733 m
.94519 .79733 L
s
% Start of user PostScript
31. 26. MAarrowzero1
% End of user PostScript
.97591 .79733 m
.97591 .79733 L
s
% Start of user PostScript
32. 26. MAarrowzero1
% End of user PostScript
.02381 .82805 m
.02381 .82805 L
s
% Start of user PostScript
1. 27. MAarrowzero1
% End of user PostScript
.05452 .82805 m
.05452 .82805 L
s
% Start of user PostScript
2. 27. MAarrowzero1
% End of user PostScript
.08524 .82805 m
.08524 .82805 L
s
% Start of user PostScript
3. 27. MAarrowzero1
% End of user PostScript
.11595 .82805 m
.11595 .82805 L
s
% Start of user PostScript
4. 27. MAarrowzero1
% End of user PostScript
.14666 .82805 m
.14666 .82805 L
s
% Start of user PostScript
5. 27. MAarrowzero1
% End of user PostScript
.17737 .82805 m
.17737 .82805 L
s
% Start of user PostScript
6. 27. MAarrowzero1
% End of user PostScript
.20809 .82805 m
.20809 .82805 L
s
% Start of user PostScript
7. 27. MAarrowzero1
% End of user PostScript
.2388 .82805 m
.2388 .82805 L
s
% Start of user PostScript
8. 27. MAarrowzero1
% End of user PostScript
.26951 .82805 m
.2734 .82495 L
s
% Start of user PostScript
9. 27. 9.12675 26.8991 MAarrowhead1
% End of user PostScript
.30022 .82805 m
.29944 .82816 L
s
% Start of user PostScript
10. 27. 9.97437 27.0037 MAarrowhead1
% End of user PostScript
.33094 .82805 m
.32997 .82902 L
s
% Start of user PostScript
11. 27. 10.9684 27.0316 MAarrowhead1
% End of user PostScript
.36165 .82805 m
.36129 .82569 L
s
% Start of user PostScript
12. 27. 11.9882 26.9232 MAarrowhead1
% End of user PostScript
.39236 .82805 m
.39127 .82799 L
s
% Start of user PostScript
13. 27. 12.9645 26.9982 MAarrowhead1
% End of user PostScript
.42308 .82805 m
.42069 .82739 L
s
% Start of user PostScript
14. 27. 13.9224 26.9785 MAarrowhead1
% End of user PostScript
.45379 .82805 m
.45322 .82618 L
s
% Start of user PostScript
15. 27. 14.9814 26.939 MAarrowhead1
% End of user PostScript
.4845 .82805 m
.48455 .82702 L
s
% Start of user PostScript
16. 27. 16.0017 26.9665 MAarrowhead1
% End of user PostScript
.51521 .82805 m
.51512 .82398 L
s
% Start of user PostScript
17. 27. 16.997 26.8676 MAarrowhead1
% End of user PostScript
.54593 .82805 m
.54455 .82545 L
s
% Start of user PostScript
18. 27. 17.9551 26.9155 MAarrowhead1
% End of user PostScript
.57664 .82805 m
.57815 .83353 L
s
% Start of user PostScript
19. 27. 19.049 27.1784 MAarrowhead1
% End of user PostScript
.60735 .82805 m
.60788 .82894 L
s
% Start of user PostScript
20. 27. 20.0172 27.029 MAarrowhead1
% End of user PostScript
.63807 .82805 m
.63252 .81964 L
s
% Start of user PostScript
21. 27. 20.8193 26.7264 MAarrowhead1
% End of user PostScript
.66878 .82805 m
.6683 .82853 L
s
% Start of user PostScript
22. 27. 21.9843 27.0157 MAarrowhead1
% End of user PostScript
.69949 .82805 m
.69978 .82776 L
s
% Start of user PostScript
23. 27. 23.0093 26.9907 MAarrowhead1
% End of user PostScript
.7302 .82805 m
.72992 .82776 L
s
% Start of user PostScript
24. 27. 23.9907 26.9907 MAarrowhead1
% End of user PostScript
.76092 .82805 m
.76092 .82805 L
s
% Start of user PostScript
25. 27. MAarrowzero1
% End of user PostScript
.79163 .82805 m
.79163 .82805 L
s
% Start of user PostScript
26. 27. MAarrowzero1
% End of user PostScript
.82234 .82805 m
.82234 .82805 L
s
% Start of user PostScript
27. 27. MAarrowzero1
% End of user PostScript
.85306 .82805 m
.85306 .82805 L
s
% Start of user PostScript
28. 27. MAarrowzero1
% End of user PostScript
.88377 .82805 m
.88377 .82805 L
s
% Start of user PostScript
29. 27. MAarrowzero1
% End of user PostScript
.91448 .82805 m
.91448 .82805 L
s
% Start of user PostScript
30. 27. MAarrowzero1
% End of user PostScript
.94519 .82805 m
.94519 .82805 L
s
% Start of user PostScript
31. 27. MAarrowzero1
% End of user PostScript
.97591 .82805 m
.97591 .82805 L
s
% Start of user PostScript
32. 27. MAarrowzero1
% End of user PostScript
.02381 .85876 m
.02381 .85876 L
s
% Start of user PostScript
1. 28. MAarrowzero1
% End of user PostScript
.05452 .85876 m
.05452 .85876 L
s
% Start of user PostScript
2. 28. MAarrowzero1
% End of user PostScript
.08524 .85876 m
.08524 .85876 L
s
% Start of user PostScript
3. 28. MAarrowzero1
% End of user PostScript
.11595 .85876 m
.11595 .85876 L
s
% Start of user PostScript
4. 28. MAarrowzero1
% End of user PostScript
.14666 .85876 m
.14666 .85876 L
s
% Start of user PostScript
5. 28. MAarrowzero1
% End of user PostScript
.17737 .85876 m
.17689 .85828 L
s
% Start of user PostScript
6. 28. 5.98431 27.9843 MAarrowhead1
% End of user PostScript
.20809 .85876 m
.20809 .85876 L
s
% Start of user PostScript
7. 28. MAarrowzero1
% End of user PostScript
.2388 .85876 m
.2388 .85876 L
s
% Start of user PostScript
8. 28. MAarrowzero1
% End of user PostScript
.26951 .85876 m
.26951 .85876 L
s
% Start of user PostScript
9. 28. MAarrowzero1
% End of user PostScript
.30022 .85876 m
.30302 .8447 L
s
% Start of user PostScript
10. 28. 10.091 27.5421 MAarrowhead1
% End of user PostScript
.33094 .85876 m
.32837 .86222 L
s
% Start of user PostScript
11. 28. 10.9164 28.1127 MAarrowhead1
% End of user PostScript
.36165 .85876 m
.36322 .85547 L
s
% Start of user PostScript
12. 28. 12.0512 27.8927 MAarrowhead1
% End of user PostScript
.39236 .85876 m
.38947 .85631 L
s
% Start of user PostScript
13. 28. 12.9059 27.9204 MAarrowhead1
% End of user PostScript
.42308 .85876 m
.42418 .86084 L
s
% Start of user PostScript
14. 28. 14.0358 28.0676 MAarrowhead1
% End of user PostScript
.45379 .85876 m
.45349 .85735 L
s
% Start of user PostScript
15. 28. 14.9904 27.954 MAarrowhead1
% End of user PostScript
.4845 .85876 m
.48221 .86208 L
s
% Start of user PostScript
16. 28. 15.9255 28.1082 MAarrowhead1
% End of user PostScript
.51521 .85876 m
.51964 .86075 L
s
% Start of user PostScript
17. 28. 17.1442 28.0647 MAarrowhead1
% End of user PostScript
.54593 .85876 m
.54626 .85842 L
s
% Start of user PostScript
18. 28. 18.011 27.989 MAarrowhead1
% End of user PostScript
.57664 .85876 m
.57692 .85648 L
s
% Start of user PostScript
19. 28. 19.0091 27.9259 MAarrowhead1
% End of user PostScript
.60735 .85876 m
.6 .85237 L
s
% Start of user PostScript
20. 28. 19.7607 27.7921 MAarrowhead1
% End of user PostScript
.63807 .85876 m
.63855 .85924 L
s
% Start of user PostScript
21. 28. 21.0157 28.0157 MAarrowhead1
% End of user PostScript
.66878 .85876 m
.66878 .85876 L
s
% Start of user PostScript
22. 28. MAarrowzero1
% End of user PostScript
.69949 .85876 m
.69921 .85904 L
s
% Start of user PostScript
23. 28. 22.9907 28.0093 MAarrowhead1
% End of user PostScript
.7302 .85876 m
.7302 .85876 L
s
% Start of user PostScript
24. 28. MAarrowzero1
% End of user PostScript
.76092 .85876 m
.7612 .85848 L
s
% Start of user PostScript
25. 28. 25.0093 27.9907 MAarrowhead1
% End of user PostScript
.79163 .85876 m
.79135 .85848 L
s
% Start of user PostScript
26. 28. 25.9907 27.9907 MAarrowhead1
% End of user PostScript
.82234 .85876 m
.82234 .85876 L
s
% Start of user PostScript
27. 28. MAarrowzero1
% End of user PostScript
.85306 .85876 m
.85306 .85876 L
s
% Start of user PostScript
28. 28. MAarrowzero1
% End of user PostScript
.88377 .85876 m
.88377 .85876 L
s
% Start of user PostScript
29. 28. MAarrowzero1
% End of user PostScript
.91448 .85876 m
.9142 .85904 L
s
% Start of user PostScript
30. 28. 29.9907 28.0093 MAarrowhead1
% End of user PostScript
.94519 .85876 m
.94519 .85876 L
s
% Start of user PostScript
31. 28. MAarrowzero1
% End of user PostScript
.97591 .85876 m
.97591 .85876 L
s
% Start of user PostScript
32. 28. MAarrowzero1
% End of user PostScript
.02381 .88947 m
.02381 .88947 L
s
% Start of user PostScript
1. 29. MAarrowzero1
% End of user PostScript
.05452 .88947 m
.05452 .88947 L
s
% Start of user PostScript
2. 29. MAarrowzero1
% End of user PostScript
.08524 .88947 m
.08524 .88947 L
s
% Start of user PostScript
3. 29. MAarrowzero1
% End of user PostScript
.11595 .88947 m
.11595 .88947 L
s
% Start of user PostScript
4. 29. MAarrowzero1
% End of user PostScript
.14666 .88947 m
.14666 .88947 L
s
% Start of user PostScript
5. 29. MAarrowzero1
% End of user PostScript
.17737 .88947 m
.17786 .88996 L
s
% Start of user PostScript
6. 29. 6.01569 29.0157 MAarrowhead1
% End of user PostScript
.20809 .88947 m
.20809 .88947 L
s
% Start of user PostScript
7. 29. MAarrowzero1
% End of user PostScript
.2388 .88947 m
.2388 .88947 L
s
% Start of user PostScript
8. 29. MAarrowzero1
% End of user PostScript
.26951 .88947 m
.26951 .88947 L
s
% Start of user PostScript
9. 29. MAarrowzero1
% End of user PostScript
.30022 .88947 m
.30022 .88947 L
s
% Start of user PostScript
10. 29. MAarrowzero1
% End of user PostScript
.33094 .88947 m
.33046 .88899 L
s
% Start of user PostScript
11. 29. 10.9843 28.9843 MAarrowhead1
% End of user PostScript
.36165 .88947 m
.36213 .87912 L
s
% Start of user PostScript
12. 29. 12.0157 28.6628 MAarrowhead1
% End of user PostScript
.39236 .88947 m
.39226 .89219 L
s
% Start of user PostScript
13. 29. 12.9965 29.0886 MAarrowhead1
% End of user PostScript
.42308 .88947 m
.42224 .88974 L
s
% Start of user PostScript
14. 29. 13.9727 29.0087 MAarrowhead1
% End of user PostScript
.45379 .88947 m
.45558 .88325 L
s
% Start of user PostScript
15. 29. 15.0585 28.7973 MAarrowhead1
% End of user PostScript
.4845 .88947 m
.48367 .88752 L
s
% Start of user PostScript
16. 29. 15.9728 28.9363 MAarrowhead1
% End of user PostScript
.51521 .88947 m
.51443 .89248 L
s
% Start of user PostScript
17. 29. 16.9745 29.0979 MAarrowhead1
% End of user PostScript
.54593 .88947 m
.5436 .88551 L
s
% Start of user PostScript
18. 29. 17.9242 28.8709 MAarrowhead1
% End of user PostScript
.57664 .88947 m
.57684 .89024 L
s
% Start of user PostScript
19. 29. 19.0064 29.0249 MAarrowhead1
% End of user PostScript
.60735 .88947 m
.60783 .88996 L
s
% Start of user PostScript
20. 29. 20.0157 29.0157 MAarrowhead1
% End of user PostScript
.63807 .88947 m
.63778 .88976 L
s
% Start of user PostScript
21. 29. 20.9907 29.0093 MAarrowhead1
% End of user PostScript
.66878 .88947 m
.66878 .88947 L
s
% Start of user PostScript
22. 29. MAarrowzero1
% End of user PostScript
.69949 .88947 m
.69978 .88919 L
s
% Start of user PostScript
23. 29. 23.0093 28.9907 MAarrowhead1
% End of user PostScript
.7302 .88947 m
.7302 .88947 L
s
% Start of user PostScript
24. 29. MAarrowzero1
% End of user PostScript
.76092 .88947 m
.76043 .88996 L
s
% Start of user PostScript
25. 29. 24.9843 29.0157 MAarrowhead1
% End of user PostScript
.79163 .88947 m
.79163 .89044 L
s
% Start of user PostScript
26. 29. 26. 29.0314 MAarrowhead1
% End of user PostScript
.82234 .88947 m
.82186 .88899 L
s
% Start of user PostScript
27. 29. 26.9843 28.9843 MAarrowhead1
% End of user PostScript
.85306 .88947 m
.85257 .88996 L
s
% Start of user PostScript
28. 29. 27.9843 29.0157 MAarrowhead1
% End of user PostScript
.88377 .88947 m
.883 .89024 L
s
% Start of user PostScript
29. 29. 28.9751 29.0249 MAarrowhead1
% End of user PostScript
.91448 .88947 m
.91525 .89024 L
s
% Start of user PostScript
30. 29. 30.0249 29.0249 MAarrowhead1
% End of user PostScript
.94519 .88947 m
.94519 .88947 L
s
% Start of user PostScript
31. 29. MAarrowzero1
% End of user PostScript
.97591 .88947 m
.97591 .88947 L
s
% Start of user PostScript
32. 29. MAarrowzero1
% End of user PostScript
.02381 .92019 m
.02381 .92019 L
s
% Start of user PostScript
1. 30. MAarrowzero1
% End of user PostScript
.05452 .92019 m
.05452 .92019 L
s
% Start of user PostScript
2. 30. MAarrowzero1
% End of user PostScript
.08524 .92019 m
.08524 .92019 L
s
% Start of user PostScript
3. 30. MAarrowzero1
% End of user PostScript
.11595 .92019 m
.11595 .92019 L
s
% Start of user PostScript
4. 30. MAarrowzero1
% End of user PostScript
.14666 .92019 m
.14666 .92019 L
s
% Start of user PostScript
5. 30. MAarrowzero1
% End of user PostScript
.17737 .92019 m
.17737 .92019 L
s
% Start of user PostScript
6. 30. MAarrowzero1
% End of user PostScript
.20809 .92019 m
.20809 .92019 L
s
% Start of user PostScript
7. 30. MAarrowzero1
% End of user PostScript
.2388 .92019 m
.2388 .92019 L
s
% Start of user PostScript
8. 30. MAarrowzero1
% End of user PostScript
.26951 .92019 m
.26951 .92019 L
s
% Start of user PostScript
9. 30. MAarrowzero1
% End of user PostScript
.30022 .92019 m
.30022 .92019 L
s
% Start of user PostScript
10. 30. MAarrowzero1
% End of user PostScript
.33094 .92019 m
.33122 .91894 L
s
% Start of user PostScript
11. 30. 11.0093 29.9594 MAarrowhead1
% End of user PostScript
.36165 .92019 m
.36193 .92047 L
s
% Start of user PostScript
12. 30. 12.0093 30.0093 MAarrowhead1
% End of user PostScript
.39236 .92019 m
.39256 .91942 L
s
% Start of user PostScript
13. 30. 13.0064 29.9751 MAarrowhead1
% End of user PostScript
.42308 .92019 m
.42327 .91942 L
s
% Start of user PostScript
14. 30. 14.0064 29.9751 MAarrowhead1
% End of user PostScript
.45379 .92019 m
.45379 .92019 L
s
% Start of user PostScript
15. 30. MAarrowzero1
% End of user PostScript
.4845 .92019 m
.4845 .92019 L
s
% Start of user PostScript
16. 30. MAarrowzero1
% End of user PostScript
.51521 .92019 m
.51521 .92019 L
s
% Start of user PostScript
17. 30. MAarrowzero1
% End of user PostScript
.54593 .92019 m
.54593 .92019 L
s
% Start of user PostScript
18. 30. MAarrowzero1
% End of user PostScript
.57664 .92019 m
.57712 .9197 L
s
% Start of user PostScript
19. 30. 19.0157 29.9843 MAarrowhead1
% End of user PostScript
.60735 .92019 m
.60755 .92095 L
s
% Start of user PostScript
20. 30. 20.0064 30.0249 MAarrowhead1
% End of user PostScript
.63807 .92019 m
.63758 .9197 L
s
% Start of user PostScript
21. 30. 20.9843 29.9843 MAarrowhead1
% End of user PostScript
.66878 .92019 m
.66878 .92019 L
s
% Start of user PostScript
22. 30. MAarrowzero1
% End of user PostScript
.69949 .92019 m
.69901 .92067 L
s
% Start of user PostScript
23. 30. 22.9843 30.0157 MAarrowhead1
% End of user PostScript
.7302 .92019 m
.73049 .9199 L
s
% Start of user PostScript
24. 30. 24.0093 29.9907 MAarrowhead1
% End of user PostScript
.76092 .92019 m
.76168 .91999 L
s
% Start of user PostScript
25. 30. 25.0249 29.9936 MAarrowhead1
% End of user PostScript
.79163 .92019 m
.79163 .92019 L
s
% Start of user PostScript
26. 30. MAarrowzero1
% End of user PostScript
.82234 .92019 m
.82186 .9197 L
s
% Start of user PostScript
27. 30. 26.9843 29.9843 MAarrowhead1
% End of user PostScript
.85306 .92019 m
.85229 .92095 L
s
% Start of user PostScript
28. 30. 27.9751 30.0249 MAarrowhead1
% End of user PostScript
.88377 .92019 m
.88405 .9199 L
s
% Start of user PostScript
29. 30. 29.0093 29.9907 MAarrowhead1
% End of user PostScript
.91448 .92019 m
.91544 .92019 L
s
% Start of user PostScript
30. 30. 30.0314 30. MAarrowhead1
% End of user PostScript
.94519 .92019 m
.94519 .92019 L
s
% Start of user PostScript
31. 30. MAarrowzero1
% End of user PostScript
.97591 .92019 m
.97542 .92067 L
s
% Start of user PostScript
32. 30. 31.9843 30.0157 MAarrowhead1
% End of user PostScript
.02381 .9509 m
.02381 .9509 L
s
% Start of user PostScript
1. 31. MAarrowzero1
% End of user PostScript
.05452 .9509 m
.05452 .9509 L
s
% Start of user PostScript
2. 31. MAarrowzero1
% End of user PostScript
.08524 .9509 m
.08524 .9509 L
s
% Start of user PostScript
3. 31. MAarrowzero1
% End of user PostScript
.11595 .9509 m
.11595 .9509 L
s
% Start of user PostScript
4. 31. MAarrowzero1
% End of user PostScript
.14666 .9509 m
.14666 .9509 L
s
% Start of user PostScript
5. 31. MAarrowzero1
% End of user PostScript
.17737 .9509 m
.17689 .95138 L
s
% Start of user PostScript
6. 31. 5.98431 31.0157 MAarrowhead1
% End of user PostScript
.20809 .9509 m
.20809 .9509 L
s
% Start of user PostScript
7. 31. MAarrowzero1
% End of user PostScript
.2388 .9509 m
.2388 .9509 L
s
% Start of user PostScript
8. 31. MAarrowzero1
% End of user PostScript
.26951 .9509 m
.26951 .9509 L
s
% Start of user PostScript
9. 31. MAarrowzero1
% End of user PostScript
.30022 .9509 m
.30071 .95042 L
s
% Start of user PostScript
10. 31. 10.0157 30.9843 MAarrowhead1
% End of user PostScript
.33094 .9509 m
.33122 .95118 L
s
% Start of user PostScript
11. 31. 11.0093 31.0093 MAarrowhead1
% End of user PostScript
.36165 .9509 m
.36165 .9509 L
s
% Start of user PostScript
12. 31. MAarrowzero1
% End of user PostScript
.39236 .9509 m
.39284 .95042 L
s
% Start of user PostScript
13. 31. 13.0157 30.9843 MAarrowhead1
% End of user PostScript
.42308 .9509 m
.42231 .9511 L
s
% Start of user PostScript
14. 31. 13.9751 31.0064 MAarrowhead1
% End of user PostScript
.45379 .9509 m
.45254 .95118 L
s
% Start of user PostScript
15. 31. 14.9594 31.0093 MAarrowhead1
% End of user PostScript
.4845 .9509 m
.4845 .9509 L
s
% Start of user PostScript
16. 31. MAarrowzero1
% End of user PostScript
.51521 .9509 m
.5157 .95138 L
s
% Start of user PostScript
17. 31. 17.0157 31.0157 MAarrowhead1
% End of user PostScript
.54593 .9509 m
.54621 .95118 L
s
% Start of user PostScript
18. 31. 18.0093 31.0093 MAarrowhead1
% End of user PostScript
.57664 .9509 m
.57568 .9509 L
s
% Start of user PostScript
19. 31. 18.9686 31. MAarrowhead1
% End of user PostScript
.60735 .9509 m
.60764 .95118 L
s
% Start of user PostScript
20. 31. 20.0093 31.0093 MAarrowhead1
% End of user PostScript
.63807 .9509 m
.63903 .9509 L
s
% Start of user PostScript
21. 31. 21.0314 31. MAarrowhead1
% End of user PostScript
.66878 .9509 m
.66849 .95118 L
s
% Start of user PostScript
22. 31. 21.9907 31.0093 MAarrowhead1
% End of user PostScript
.69949 .9509 m
.69949 .9509 L
s
% Start of user PostScript
23. 31. MAarrowzero1
% End of user PostScript
.7302 .9509 m
.72944 .95013 L
s
% Start of user PostScript
24. 31. 23.9751 30.9751 MAarrowhead1
% End of user PostScript
.76092 .9509 m
.76092 .9509 L
s
% Start of user PostScript
25. 31. MAarrowzero1
% End of user PostScript
.79163 .9509 m
.79163 .9509 L
s
% Start of user PostScript
26. 31. MAarrowzero1
% End of user PostScript
.82234 .9509 m
.82331 .9509 L
s
% Start of user PostScript
27. 31. 27.0314 31. MAarrowhead1
% End of user PostScript
.85306 .9509 m
.85277 .95061 L
s
% Start of user PostScript
28. 31. 27.9907 30.9907 MAarrowhead1
% End of user PostScript
.88377 .9509 m
.88425 .95042 L
s
% Start of user PostScript
29. 31. 29.0157 30.9843 MAarrowhead1
% End of user PostScript
.91448 .9509 m
.914 .95138 L
s
% Start of user PostScript
30. 31. 29.9843 31.0157 MAarrowhead1
% End of user PostScript
.94519 .9509 m
.94519 .9509 L
s
% Start of user PostScript
31. 31. MAarrowzero1
% End of user PostScript
.97591 .9509 m
.97619 .95118 L
s
% Start of user PostScript
32. 31. 32.0093 31.0093 MAarrowhead1
% End of user PostScript
.02381 .98161 m
.02381 .98161 L
s
% Start of user PostScript
1. 32. MAarrowzero1
% End of user PostScript
.05452 .98161 m
.05452 .98161 L
s
% Start of user PostScript
2. 32. MAarrowzero1
% End of user PostScript
.08524 .98161 m
.08524 .98161 L
s
% Start of user PostScript
3. 32. MAarrowzero1
% End of user PostScript
.11595 .98161 m
.11595 .98161 L
s
% Start of user PostScript
4. 32. MAarrowzero1
% End of user PostScript
.14666 .98161 m
.14666 .98161 L
s
% Start of user PostScript
5. 32. MAarrowzero1
% End of user PostScript
.17737 .98161 m
.17689 .98209 L
s
% Start of user PostScript
6. 32. 5.98431 32.0157 MAarrowhead1
% End of user PostScript
.20809 .98161 m
.2078 .98133 L
s
% Start of user PostScript
7. 32. 6.99075 31.9907 MAarrowhead1
% End of user PostScript
.2388 .98161 m
.2388 .98161 L
s
% Start of user PostScript
8. 32. MAarrowzero1
% End of user PostScript
.26951 .98161 m
.26999 .98209 L
s
% Start of user PostScript
9. 32. 9.01569 32.0157 MAarrowhead1
% End of user PostScript
.30022 .98161 m
.30051 .9819 L
s
% Start of user PostScript
10. 32. 10.0093 32.0093 MAarrowhead1
% End of user PostScript
.33094 .98161 m
.33122 .98133 L
s
% Start of user PostScript
11. 32. 11.0093 31.9907 MAarrowhead1
% End of user PostScript
.36165 .98161 m
.36213 .98113 L
s
% Start of user PostScript
12. 32. 12.0157 31.9843 MAarrowhead1
% End of user PostScript
.39236 .98161 m
.39236 .98161 L
s
% Start of user PostScript
13. 32. MAarrowzero1
% End of user PostScript
.42308 .98161 m
.42308 .98161 L
s
% Start of user PostScript
14. 32. MAarrowzero1
% End of user PostScript
.45379 .98161 m
.45331 .98113 L
s
% Start of user PostScript
15. 32. 14.9843 31.9843 MAarrowhead1
% End of user PostScript
.4845 .98161 m
.4845 .98161 L
s
% Start of user PostScript
16. 32. MAarrowzero1
% End of user PostScript
.51521 .98161 m
.51445 .98085 L
s
% Start of user PostScript
17. 32. 16.9751 31.9751 MAarrowhead1
% End of user PostScript
.54593 .98161 m
.54593 .98161 L
s
% Start of user PostScript
18. 32. MAarrowzero1
% End of user PostScript
.57664 .98161 m
.57664 .98161 L
s
% Start of user PostScript
19. 32. MAarrowzero1
% End of user PostScript
.60735 .98161 m
.60735 .98161 L
s
% Start of user PostScript
20. 32. MAarrowzero1
% End of user PostScript
.63807 .98161 m
.63855 .98113 L
s
% Start of user PostScript
21. 32. 21.0157 31.9843 MAarrowhead1
% End of user PostScript
.66878 .98161 m
.66906 .98133 L
s
% Start of user PostScript
22. 32. 22.0093 31.9907 MAarrowhead1
% End of user PostScript
.69949 .98161 m
.69949 .98161 L
s
% Start of user PostScript
23. 32. MAarrowzero1
% End of user PostScript
.7302 .98161 m
.73069 .98113 L
s
% Start of user PostScript
24. 32. 24.0157 31.9843 MAarrowhead1
% End of user PostScript
.76092 .98161 m
.7612 .98133 L
s
% Start of user PostScript
25. 32. 25.0093 31.9907 MAarrowhead1
% End of user PostScript
.79163 .98161 m
.79163 .98161 L
s
% Start of user PostScript
26. 32. MAarrowzero1
% End of user PostScript
.82234 .98161 m
.82234 .98161 L
s
% Start of user PostScript
27. 32. MAarrowzero1
% End of user PostScript
.85306 .98161 m
.85306 .98161 L
s
% Start of user PostScript
28. 32. MAarrowzero1
% End of user PostScript
.88377 .98161 m
.8832 .98161 L
s
% Start of user PostScript
29. 32. 28.9815 32. MAarrowhead1
% End of user PostScript
.91448 .98161 m
.914 .98113 L
s
% Start of user PostScript
30. 32. 29.9843 31.9843 MAarrowhead1
% End of user PostScript
.94519 .98161 m
.94596 .98141 L
s
% Start of user PostScript
31. 32. 31.0249 31.9936 MAarrowhead1
% End of user PostScript
.97591 .98161 m
.97591 .98161 L
s
% Start of user PostScript
32. 32. MAarrowzero1
% End of user PostScript
0 0 m
1 0 L
1 1.00605 L
0 1.00605 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0114064 0.97619 0.467664 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.00630325 0.0306807 -0.00316641 0.0306807 [
[.5 1.01577 -38 0 ]
[.5 1.01577 38 12.5625 ]
[ 0 0 0 0 ]
[ 1 1.00327 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.01577 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Rot) show
81.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(.) show
93.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(vectors) show
135.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.0001 w
.02438 .02751 m
.02467 .02751 L
s
% Start of user PostScript
1. 1. 1.00941 1. MAarrowhead1
% End of user PostScript
.05506 .02751 m
.05545 .02798 L
s
% Start of user PostScript
2. 1. 2.01271 1.01522 MAarrowhead1
% End of user PostScript
.08574 .02751 m
.08602 .02702 L
s
% Start of user PostScript
3. 1. 3.00925 0.983843 MAarrowhead1
% End of user PostScript
.11642 .02751 m
.11589 .02776 L
s
% Start of user PostScript
4. 1. 3.98259 1.008 MAarrowhead1
% End of user PostScript
.1471 .02751 m
.1473 .02828 L
s
% Start of user PostScript
5. 1. 5.00643 1.02494 MAarrowhead1
% End of user PostScript
.17778 .02751 m
.17739 .0278 L
s
% Start of user PostScript
6. 1. 5.98729 1.00925 MAarrowhead1
% End of user PostScript
.20846 .02751 m
.21325 .03412 L
s
% Start of user PostScript
7. 1. 7.15614 1.21524 MAarrowhead1
% End of user PostScript
.23914 .02751 m
.23957 .02794 L
s
% Start of user PostScript
8. 1. 8.01386 1.01386 MAarrowhead1
% End of user PostScript
.26982 .02751 m
.2689 .02751 L
s
% Start of user PostScript
9. 1. 8.96976 1. MAarrowhead1
% End of user PostScript
.3005 .02751 m
.30056 .02746 L
s
% Start of user PostScript
10. 1. 10.0017 0.998275 MAarrowhead1
% End of user PostScript
.33118 .02751 m
.33105 .02605 L
s
% Start of user PostScript
11. 1. 10.9955 0.952294 MAarrowhead1
% End of user PostScript
.36186 .02751 m
.36192 .02833 L
s
% Start of user PostScript
12. 1. 12.0017 1.02643 MAarrowhead1
% End of user PostScript
.39255 .02751 m
.39255 .02751 L
s
% Start of user PostScript
13. 1. MAarrowzero1
% End of user PostScript
.42323 .02751 m
.42228 .02674 L
s
% Start of user PostScript
14. 1. 13.9692 0.974725 MAarrowhead1
% End of user PostScript
.45391 .02751 m
.45362 .0278 L
s
% Start of user PostScript
15. 1. 14.9907 1.00925 MAarrowhead1
% End of user PostScript
.48459 .02751 m
.48453 .02757 L
s
% Start of user PostScript
16. 1. 15.9983 1.00173 MAarrowhead1
% End of user PostScript
.51527 .02751 m
.51575 .02771 L
s
% Start of user PostScript
17. 1. 17.0157 1.00627 MAarrowhead1
% End of user PostScript
.54595 .02751 m
.54657 .02757 L
s
% Start of user PostScript
18. 1. 18.0202 1.00173 MAarrowhead1
% End of user PostScript
.57663 .02751 m
.57759 .02751 L
s
% Start of user PostScript
19. 1. 19.0314 1. MAarrowhead1
% End of user PostScript
.60731 .02751 m
.60742 .02751 L
s
% Start of user PostScript
20. 1. 20.0035 1. MAarrowhead1
% End of user PostScript
.63799 .02751 m
.6381 .02751 L
s
% Start of user PostScript
21. 1. 21.0035 1. MAarrowhead1
% End of user PostScript
.66867 .02751 m
.66872 .02757 L
s
% Start of user PostScript
22. 1. 22.0017 1.00173 MAarrowhead1
% End of user PostScript
.69935 .02751 m
.70491 .03307 L
s
% Start of user PostScript
23. 1. 23.1811 1.18108 MAarrowhead1
% End of user PostScript
.73003 .02751 m
.7306 .02705 L
s
% Start of user PostScript
24. 1. 24.0186 0.984882 MAarrowhead1
% End of user PostScript
.76071 .02751 m
.76157 .02733 L
s
% Start of user PostScript
25. 1. 25.0278 0.994137 MAarrowhead1
% End of user PostScript
.79139 .02751 m
.79134 .02689 L
s
% Start of user PostScript
26. 1. 25.9983 0.979765 MAarrowhead1
% End of user PostScript
.82207 .02751 m
.82184 .02718 L
s
% Start of user PostScript
27. 1. 26.9925 0.98902 MAarrowhead1
% End of user PostScript
.85276 .02751 m
.85267 .02743 L
s
% Start of user PostScript
28. 1. 27.9972 0.997235 MAarrowhead1
% End of user PostScript
.88344 .02751 m
.88324 .02771 L
s
% Start of user PostScript
29. 1. 28.9937 1.00627 MAarrowhead1
% End of user PostScript
.91412 .02751 m
.91587 .02587 L
s
% Start of user PostScript
30. 1. 30.0571 0.946333 MAarrowhead1
% End of user PostScript
.9448 .02751 m
.94363 .02868 L
s
% Start of user PostScript
31. 1. 30.962 1.03798 MAarrowhead1
% End of user PostScript
.97548 .02751 m
.97599 .02389 L
s
% Start of user PostScript
32. 1. 32.0168 0.881784 MAarrowhead1
% End of user PostScript
.02438 .05819 m
.02438 .05819 L
s
% Start of user PostScript
1. 2. MAarrowzero1
% End of user PostScript
.05506 .05819 m
.05502 .05873 L
s
% Start of user PostScript
2. 2. 1.9989 2.01741 MAarrowhead1
% End of user PostScript
.08574 .05819 m
.08588 .05862 L
s
% Start of user PostScript
3. 2. 3.00455 2.01396 MAarrowhead1
% End of user PostScript
.11642 .05819 m
.11556 .05819 L
s
% Start of user PostScript
4. 2. 3.97208 2. MAarrowhead1
% End of user PostScript
.1471 .05819 m
.1471 .05819 L
s
% Start of user PostScript
5. 2. MAarrowzero1
% End of user PostScript
.17778 .05819 m
.17953 .05887 L
s
% Start of user PostScript
6. 2. 6.0569 2.02208 MAarrowhead1
% End of user PostScript
.20846 .05819 m
.20911 .05834 L
s
% Start of user PostScript
7. 2. 7.02114 2.00471 MAarrowhead1
% End of user PostScript
.23914 .05819 m
.23642 .0616 L
s
% Start of user PostScript
8. 2. 7.91143 2.11096 MAarrowhead1
% End of user PostScript
.26982 .05819 m
.26954 .05876 L
s
% Start of user PostScript
9. 2. 8.99084 2.01857 MAarrowhead1
% End of user PostScript
.3005 .05819 m
.30056 .05825 L
s
% Start of user PostScript
10. 2. 10.0019 2.00194 MAarrowhead1
% End of user PostScript
.33118 .05819 m
.33163 .05775 L
s
% Start of user PostScript
11. 2. 11.0145 1.98545 MAarrowhead1
% End of user PostScript
.36186 .05819 m
.36153 .05853 L
s
% Start of user PostScript
12. 2. 11.989 2.01098 MAarrowhead1
% End of user PostScript
.39255 .05819 m
.39226 .05791 L
s
% Start of user PostScript
13. 2. 12.9907 1.99075 MAarrowhead1
% End of user PostScript
.42323 .05819 m
.42328 .05921 L
s
% Start of user PostScript
14. 2. 14.0017 2.0331 MAarrowhead1
% End of user PostScript
.45391 .05819 m
.45314 .05839 L
s
% Start of user PostScript
15. 2. 14.9751 2.00643 MAarrowhead1
% End of user PostScript
.48459 .05819 m
.4843 .05848 L
s
% Start of user PostScript
16. 2. 15.9907 2.00925 MAarrowhead1
% End of user PostScript
.51527 .05819 m
.51394 .0578 L
s
% Start of user PostScript
17. 2. 16.9568 1.98708 MAarrowhead1
% End of user PostScript
.54595 .05819 m
.54538 .05866 L
s
% Start of user PostScript
18. 2. 17.9814 2.01512 MAarrowhead1
% End of user PostScript
.57663 .05819 m
.57601 .05768 L
s
% Start of user PostScript
19. 2. 18.9797 1.98316 MAarrowhead1
% End of user PostScript
.60731 .05819 m
.60598 .05857 L
s
% Start of user PostScript
20. 2. 19.9565 2.01214 MAarrowhead1
% End of user PostScript
.63799 .05819 m
.63737 .05871 L
s
% Start of user PostScript
21. 2. 20.9797 2.01684 MAarrowhead1
% End of user PostScript
.66867 .05819 m
.66764 .05819 L
s
% Start of user PostScript
22. 2. 21.9663 2. MAarrowhead1
% End of user PostScript
.69935 .05819 m
.69893 .0588 L
s
% Start of user PostScript
23. 2. 22.9861 2.01982 MAarrowhead1
% End of user PostScript
.73003 .05819 m
.73051 .06129 L
s
% Start of user PostScript
24. 2. 24.0156 2.10073 MAarrowhead1
% End of user PostScript
.76071 .05819 m
.76077 .05825 L
s
% Start of user PostScript
25. 2. 25.0017 2.00173 MAarrowhead1
% End of user PostScript
.79139 .05819 m
.79125 .05805 L
s
% Start of user PostScript
26. 2. 25.9953 1.99529 MAarrowhead1
% End of user PostScript
.82207 .05819 m
.82256 .05771 L
s
% Start of user PostScript
27. 2. 27.0157 1.98431 MAarrowhead1
% End of user PostScript
.85276 .05819 m
.85153 .05873 L
s
% Start of user PostScript
28. 2. 27.9602 2.01741 MAarrowhead1
% End of user PostScript
.88344 .05819 m
.88313 .05858 L
s
% Start of user PostScript
29. 2. 28.9901 2.01239 MAarrowhead1
% End of user PostScript
.91412 .05819 m
.90974 .0586 L
s
% Start of user PostScript
30. 2. 29.8574 2.01329 MAarrowhead1
% End of user PostScript
.9448 .05819 m
.94423 .05702 L
s
% Start of user PostScript
31. 2. 30.9814 1.96155 MAarrowhead1
% End of user PostScript
.97548 .05819 m
.97542 .05707 L
s
% Start of user PostScript
32. 2. 31.9981 1.96324 MAarrowhead1
% End of user PostScript
.02438 .08888 m
.02545 .08888 L
s
% Start of user PostScript
1. 3. 1.03482 3. MAarrowhead1
% End of user PostScript
.05506 .08888 m
.05534 .08916 L
s
% Start of user PostScript
2. 3. 2.00925 3.00925 MAarrowhead1
% End of user PostScript
.08574 .08888 m
.08538 .08873 L
s
% Start of user PostScript
3. 3. 2.98839 2.99529 MAarrowhead1
% End of user PostScript
.11642 .08888 m
.11642 .08831 L
s
% Start of user PostScript
4. 3. 4. 2.98149 MAarrowhead1
% End of user PostScript
.1471 .08888 m
.14696 .08873 L
s
% Start of user PostScript
5. 3. 4.99529 2.99529 MAarrowhead1
% End of user PostScript
.17778 .08888 m
.17764 .08873 L
s
% Start of user PostScript
6. 3. 5.99529 2.99529 MAarrowhead1
% End of user PostScript
.20846 .08888 m
.2086 .0893 L
s
% Start of user PostScript
7. 3. 7.00455 3.01396 MAarrowhead1
% End of user PostScript
.23914 .08888 m
.23904 .08848 L
s
% Start of user PostScript
8. 3. 7.99655 2.98714 MAarrowhead1
% End of user PostScript
.26982 .08888 m
.2705 .09063 L
s
% Start of user PostScript
9. 3. 9.0222 3.05702 MAarrowhead1
% End of user PostScript
.3005 .08888 m
.29827 .08664 L
s
% Start of user PostScript
10. 3. 9.92729 2.92729 MAarrowhead1
% End of user PostScript
.33118 .08888 m
.33093 .0902 L
s
% Start of user PostScript
11. 3. 10.9916 3.04306 MAarrowhead1
% End of user PostScript
.36186 .08888 m
.36138 .08839 L
s
% Start of user PostScript
12. 3. 11.9843 2.98431 MAarrowhead1
% End of user PostScript
.39255 .08888 m
.39249 .08882 L
s
% Start of user PostScript
13. 3. 12.9983 2.99827 MAarrowhead1
% End of user PostScript
.42323 .08888 m
.42294 .08859 L
s
% Start of user PostScript
14. 3. 13.9907 2.99075 MAarrowhead1
% End of user PostScript
.45391 .08888 m
.45429 .08925 L
s
% Start of user PostScript
15. 3. 15.0124 3.01235 MAarrowhead1
% End of user PostScript
.48459 .08888 m
.48459 .08888 L
s
% Start of user PostScript
16. 3. MAarrowzero1
% End of user PostScript
.51527 .08888 m
.51527 .08888 L
s
% Start of user PostScript
17. 3. MAarrowzero1
% End of user PostScript
.54595 .08888 m
.54491 .08859 L
s
% Start of user PostScript
18. 3. 17.966 2.99075 MAarrowhead1
% End of user PostScript
.57663 .08888 m
.57762 .08894 L
s
% Start of user PostScript
19. 3. 19.0322 3.00194 MAarrowhead1
% End of user PostScript
.60731 .08888 m
.60618 .08907 L
s
% Start of user PostScript
20. 3. 19.9633 3.00649 MAarrowhead1
% End of user PostScript
.63799 .08888 m
.63817 .08962 L
s
% Start of user PostScript
21. 3. 21.0059 3.02437 MAarrowhead1
% End of user PostScript
.66867 .08888 m
.66867 .08888 L
s
% Start of user PostScript
22. 3. MAarrowzero1
% End of user PostScript
.69935 .08888 m
.69927 .08972 L
s
% Start of user PostScript
23. 3. 22.9972 3.02747 MAarrowhead1
% End of user PostScript
.73003 .08888 m
.72998 .08893 L
s
% Start of user PostScript
24. 3. 23.9983 3.00173 MAarrowhead1
% End of user PostScript
.76071 .08888 m
.75949 .08858 L
s
% Start of user PostScript
25. 3. 24.96 2.99027 MAarrowhead1
% End of user PostScript
.79139 .08888 m
.79657 .09033 L
s
% Start of user PostScript
26. 3. 26.1687 3.04729 MAarrowhead1
% End of user PostScript
.82207 .08888 m
.82076 .08793 L
s
% Start of user PostScript
27. 3. 26.9572 2.96902 MAarrowhead1
% End of user PostScript
.85276 .08888 m
.85299 .08757 L
s
% Start of user PostScript
28. 3. 28.0077 2.95743 MAarrowhead1
% End of user PostScript
.88344 .08888 m
.88365 .08859 L
s
% Start of user PostScript
29. 3. 29.007 2.99053 MAarrowhead1
% End of user PostScript
.91412 .08888 m
.91339 .08718 L
s
% Start of user PostScript
30. 3. 29.9763 2.94471 MAarrowhead1
% End of user PostScript
.9448 .08888 m
.94426 .09174 L
s
% Start of user PostScript
31. 3. 30.9826 3.09337 MAarrowhead1
% End of user PostScript
.97548 .08888 m
.97576 .08916 L
s
% Start of user PostScript
32. 3. 32.0093 3.00925 MAarrowhead1
% End of user PostScript
.02438 .11956 m
.02445 .11956 L
s
% Start of user PostScript
1. 4. 1.00251 4. MAarrowhead1
% End of user PostScript
.05506 .11956 m
.05506 .11985 L
s
% Start of user PostScript
2. 4. 2. 4.00941 MAarrowhead1
% End of user PostScript
.08574 .11956 m
.0852 .12009 L
s
% Start of user PostScript
3. 4. 2.98259 4.01741 MAarrowhead1
% End of user PostScript
.11642 .11956 m
.11646 .11952 L
s
% Start of user PostScript
4. 4. 4.00125 3.99875 MAarrowhead1
% End of user PostScript
.1471 .11956 m
.1471 .11956 L
s
% Start of user PostScript
5. 4. MAarrowzero1
% End of user PostScript
.17778 .11956 m
.1775 .11927 L
s
% Start of user PostScript
6. 4. 5.99075 3.99075 MAarrowhead1
% End of user PostScript
.20846 .11956 m
.20875 .11927 L
s
% Start of user PostScript
7. 4. 7.00925 3.99075 MAarrowhead1
% End of user PostScript
.23914 .11956 m
.23929 .11991 L
s
% Start of user PostScript
8. 4. 8.00471 4.01161 MAarrowhead1
% End of user PostScript
.26982 .11956 m
.26939 .12327 L
s
% Start of user PostScript
9. 4. 8.98582 4.12108 MAarrowhead1
% End of user PostScript
.3005 .11956 m
.30132 .12224 L
s
% Start of user PostScript
10. 4. 10.0266 4.08747 MAarrowhead1
% End of user PostScript
.33118 .11956 m
.3249 .11249 L
s
% Start of user PostScript
11. 4. 10.7953 3.76984 MAarrowhead1
% End of user PostScript
.36186 .11956 m
.36137 .11849 L
s
% Start of user PostScript
12. 4. 11.9837 3.96522 MAarrowhead1
% End of user PostScript
.39255 .11956 m
.39301 .11909 L
s
% Start of user PostScript
13. 4. 13.0151 3.98488 MAarrowhead1
% End of user PostScript
.42323 .11956 m
.42361 .11994 L
s
% Start of user PostScript
14. 4. 14.0124 4.01235 MAarrowhead1
% End of user PostScript
.45391 .11956 m
.45391 .11956 L
s
% Start of user PostScript
15. 4. MAarrowzero1
% End of user PostScript
.48459 .11956 m
.48421 .11994 L
s
% Start of user PostScript
16. 4. 15.9876 4.01235 MAarrowhead1
% End of user PostScript
.51527 .11956 m
.51565 .11918 L
s
% Start of user PostScript
17. 4. 17.0124 3.98765 MAarrowhead1
% End of user PostScript
.54595 .11956 m
.54519 .11956 L
s
% Start of user PostScript
18. 4. 17.9753 4. MAarrowhead1
% End of user PostScript
.57663 .11956 m
.5761 .11942 L
s
% Start of user PostScript
19. 4. 18.9826 3.99545 MAarrowhead1
% End of user PostScript
.60731 .11956 m
.60759 .11927 L
s
% Start of user PostScript
20. 4. 20.0093 3.99075 MAarrowhead1
% End of user PostScript
.63799 .11956 m
.63737 .11883 L
s
% Start of user PostScript
21. 4. 20.9798 3.97631 MAarrowhead1
% End of user PostScript
.66867 .11956 m
.66829 .11918 L
s
% Start of user PostScript
22. 4. 21.9876 3.98765 MAarrowhead1
% End of user PostScript
.69935 .11956 m
.6984 .11975 L
s
% Start of user PostScript
23. 4. 22.9689 4.00643 MAarrowhead1
% End of user PostScript
.73003 .11956 m
.72739 .12041 L
s
% Start of user PostScript
24. 4. 23.9138 4.02782 MAarrowhead1
% End of user PostScript
.76071 .11956 m
.75855 .12172 L
s
% Start of user PostScript
25. 4. 24.9294 4.07061 MAarrowhead1
% End of user PostScript
.79139 .11956 m
.79383 .11627 L
s
% Start of user PostScript
26. 4. 26.0795 3.89282 MAarrowhead1
% End of user PostScript
.82207 .11956 m
.82154 .11823 L
s
% Start of user PostScript
27. 4. 26.9826 3.95675 MAarrowhead1
% End of user PostScript
.85276 .11956 m
.85276 .11956 L
s
% Start of user PostScript
28. 4. MAarrowzero1
% End of user PostScript
.88344 .11956 m
.88367 .11797 L
s
% Start of user PostScript
29. 4. 29.0077 3.94816 MAarrowhead1
% End of user PostScript
.91412 .11956 m
.91624 .11743 L
s
% Start of user PostScript
30. 4. 30.0693 3.93075 MAarrowhead1
% End of user PostScript
.9448 .11956 m
.94534 .1168 L
s
% Start of user PostScript
31. 4. 31.0176 3.91029 MAarrowhead1
% End of user PostScript
.97548 .11956 m
.97586 .11925 L
s
% Start of user PostScript
32. 4. 32.0125 3.99006 MAarrowhead1
% End of user PostScript
.02438 .15024 m
.02545 .15024 L
s
% Start of user PostScript
1. 5. 1.03482 5. MAarrowhead1
% End of user PostScript
.05506 .15024 m
.05477 .15052 L
s
% Start of user PostScript
2. 5. 1.99075 5.00925 MAarrowhead1
% End of user PostScript
.08574 .15024 m
.08574 .15024 L
s
% Start of user PostScript
3. 5. MAarrowzero1
% End of user PostScript
.11642 .15024 m
.1171 .15006 L
s
% Start of user PostScript
4. 5. 4.02212 4.9942 MAarrowhead1
% End of user PostScript
.1471 .15024 m
.14653 .15024 L
s
% Start of user PostScript
5. 5. 4.98149 5. MAarrowhead1
% End of user PostScript
.17778 .15024 m
.17782 .14999 L
s
% Start of user PostScript
6. 5. 6.00125 4.99184 MAarrowhead1
% End of user PostScript
.20846 .15024 m
.20803 .15038 L
s
% Start of user PostScript
7. 5. 6.98604 5.00455 MAarrowhead1
% End of user PostScript
.23914 .15024 m
.23914 .15016 L
s
% Start of user PostScript
8. 5. 8. 4.99749 MAarrowhead1
% End of user PostScript
.26982 .15024 m
.26954 .15052 L
s
% Start of user PostScript
9. 5. 8.99075 5.00925 MAarrowhead1
% End of user PostScript
.3005 .15024 m
.29958 .15225 L
s
% Start of user PostScript
10. 5. 9.96976 5.06549 MAarrowhead1
% End of user PostScript
.33118 .15024 m
.3305 .15303 L
s
% Start of user PostScript
11. 5. 10.9776 5.09106 MAarrowhead1
% End of user PostScript
.36186 .15024 m
.36186 .15024 L
s
% Start of user PostScript
12. 5. MAarrowzero1
% End of user PostScript
.39255 .15024 m
.39261 .15018 L
s
% Start of user PostScript
13. 5. 13.0019 4.99806 MAarrowhead1
% End of user PostScript
.42323 .15024 m
.42361 .14986 L
s
% Start of user PostScript
14. 5. 14.0124 4.98765 MAarrowhead1
% End of user PostScript
.45391 .15024 m
.45353 .15062 L
s
% Start of user PostScript
15. 5. 14.9876 5.01235 MAarrowhead1
% End of user PostScript
.48459 .15024 m
.48459 .15024 L
s
% Start of user PostScript
16. 5. MAarrowzero1
% End of user PostScript
.51527 .15024 m
.51518 .15004 L
s
% Start of user PostScript
17. 5. 16.9972 4.99373 MAarrowhead1
% End of user PostScript
.54595 .15024 m
.54513 .15077 L
s
% Start of user PostScript
18. 5. 17.9733 5.01725 MAarrowhead1
% End of user PostScript
.57663 .15024 m
.57663 .15024 L
s
% Start of user PostScript
19. 5. MAarrowzero1
% End of user PostScript
.60731 .15024 m
.6066 .15052 L
s
% Start of user PostScript
20. 5. 19.9767 5.00925 MAarrowhead1
% End of user PostScript
.63799 .15024 m
.63799 .14955 L
s
% Start of user PostScript
21. 5. 21. 4.97761 MAarrowhead1
% End of user PostScript
.66867 .15024 m
.66646 .15152 L
s
% Start of user PostScript
22. 5. 21.9279 5.0419 MAarrowhead1
% End of user PostScript
.69935 .15024 m
.69777 .15201 L
s
% Start of user PostScript
23. 5. 22.9483 5.05769 MAarrowhead1
% End of user PostScript
.73003 .15024 m
.72887 .15498 L
s
% Start of user PostScript
24. 5. 23.9621 5.15447 MAarrowhead1
% End of user PostScript
.76071 .15024 m
.75952 .15035 L
s
% Start of user PostScript
25. 5. 24.9612 5.00357 MAarrowhead1
% End of user PostScript
.79139 .15024 m
.79062 .15032 L
s
% Start of user PostScript
26. 5. 25.9748 5.00276 MAarrowhead1
% End of user PostScript
.82207 .15024 m
.82233 .14998 L
s
% Start of user PostScript
27. 5. 27.0082 4.99178 MAarrowhead1
% End of user PostScript
.85276 .15024 m
.85399 .149 L
s
% Start of user PostScript
28. 5. 28.0402 4.95982 MAarrowhead1
% End of user PostScript
.88344 .15024 m
.88442 .14926 L
s
% Start of user PostScript
29. 5. 29.032 4.96804 MAarrowhead1
% End of user PostScript
.91412 .15024 m
.91537 .14899 L
s
% Start of user PostScript
30. 5. 30.0407 4.95925 MAarrowhead1
% End of user PostScript
.9448 .15024 m
.94582 .1495 L
s
% Start of user PostScript
31. 5. 31.0333 4.9761 MAarrowhead1
% End of user PostScript
.97548 .15024 m
.97548 .14967 L
s
% Start of user PostScript
32. 5. 32. 4.98149 MAarrowhead1
% End of user PostScript
.02438 .18092 m
.02438 .18092 L
s
% Start of user PostScript
1. 6. MAarrowzero1
% End of user PostScript
.05506 .18092 m
.05502 .1801 L
s
% Start of user PostScript
2. 6. 1.99875 5.97333 MAarrowhead1
% End of user PostScript
.08574 .18092 m
.08545 .1812 L
s
% Start of user PostScript
3. 6. 2.99075 6.00925 MAarrowhead1
% End of user PostScript
.11642 .18092 m
.11642 .18092 L
s
% Start of user PostScript
4. 6. MAarrowzero1
% End of user PostScript
.1471 .18092 m
.14692 .18053 L
s
% Start of user PostScript
5. 6. 4.9942 5.98729 MAarrowhead1
% End of user PostScript
.17778 .18092 m
.17831 .18088 L
s
% Start of user PostScript
6. 6. 6.01741 5.9989 MAarrowhead1
% End of user PostScript
.20846 .18092 m
.20846 .18177 L
s
% Start of user PostScript
7. 6. 7. 6.02792 MAarrowhead1
% End of user PostScript
.23914 .18092 m
.2391 .18174 L
s
% Start of user PostScript
8. 6. 7.99875 6.02667 MAarrowhead1
% End of user PostScript
.26982 .18092 m
.26886 .18188 L
s
% Start of user PostScript
9. 6. 8.96851 6.03149 MAarrowhead1
% End of user PostScript
.3005 .18092 m
.3013 .18171 L
s
% Start of user PostScript
10. 6. 10.0259 6.0259 MAarrowhead1
% End of user PostScript
.33118 .18092 m
.33195 .18015 L
s
% Start of user PostScript
11. 6. 11.0249 5.97506 MAarrowhead1
% End of user PostScript
.36186 .18092 m
.36351 .16311 L
s
% Start of user PostScript
12. 6. 12.0537 5.41953 MAarrowhead1
% End of user PostScript
.39255 .18092 m
.39212 .18117 L
s
% Start of user PostScript
13. 6. 12.9863 6.00822 MAarrowhead1
% End of user PostScript
.42323 .18092 m
.42376 .18077 L
s
% Start of user PostScript
14. 6. 14.0173 5.99529 MAarrowhead1
% End of user PostScript
.45391 .18092 m
.45405 .18106 L
s
% Start of user PostScript
15. 6. 15.0045 6.00455 MAarrowhead1
% End of user PostScript
.48459 .18092 m
.48397 .18126 L
s
% Start of user PostScript
16. 6. 15.9798 6.01114 MAarrowhead1
% End of user PostScript
.51527 .18092 m
.51479 .18015 L
s
% Start of user PostScript
17. 6. 16.9845 5.97506 MAarrowhead1
% End of user PostScript
.54595 .18092 m
.546 .18097 L
s
% Start of user PostScript
18. 6. 18.0017 6.00173 MAarrowhead1
% End of user PostScript
.57663 .18092 m
.57595 .18092 L
s
% Start of user PostScript
19. 6. 18.9778 6.00022 MAarrowhead1
% End of user PostScript
.60731 .18092 m
.60612 .18136 L
s
% Start of user PostScript
20. 6. 19.9611 6.01443 MAarrowhead1
% End of user PostScript
.63799 .18092 m
.63606 .18353 L
s
% Start of user PostScript
21. 6. 20.9369 6.08504 MAarrowhead1
% End of user PostScript
.66867 .18092 m
.66764 .18183 L
s
% Start of user PostScript
22. 6. 21.9665 6.02967 MAarrowhead1
% End of user PostScript
.69935 .18092 m
.70024 .17952 L
s
% Start of user PostScript
23. 6. 23.0289 5.95459 MAarrowhead1
% End of user PostScript
.73003 .18092 m
.73097 .18185 L
s
% Start of user PostScript
24. 6. 24.0305 6.03045 MAarrowhead1
% End of user PostScript
.76071 .18092 m
.76164 .17914 L
s
% Start of user PostScript
25. 6. 25.0302 5.94204 MAarrowhead1
% End of user PostScript
.79139 .18092 m
.79373 .17958 L
s
% Start of user PostScript
26. 6. 26.0763 5.95627 MAarrowhead1
% End of user PostScript
.82207 .18092 m
.82145 .18029 L
s
% Start of user PostScript
27. 6. 26.9796 5.97961 MAarrowhead1
% End of user PostScript
.85276 .18092 m
.85352 .17922 L
s
% Start of user PostScript
28. 6. 28.0251 5.94471 MAarrowhead1
% End of user PostScript
.88344 .18092 m
.88475 .17961 L
s
% Start of user PostScript
29. 6. 29.0427 5.95731 MAarrowhead1
% End of user PostScript
.91412 .18092 m
.9144 .1812 L
s
% Start of user PostScript
30. 6. 30.0093 6.00925 MAarrowhead1
% End of user PostScript
.9448 .18092 m
.94455 .18067 L
s
% Start of user PostScript
31. 6. 30.9918 5.99184 MAarrowhead1
% End of user PostScript
.97548 .18092 m
.97619 .18077 L
s
% Start of user PostScript
32. 6. 32.0232 5.99529 MAarrowhead1
% End of user PostScript
.02438 .2116 m
.02438 .2116 L
s
% Start of user PostScript
1. 7. MAarrowzero1
% End of user PostScript
.05506 .2116 m
.05506 .21217 L
s
% Start of user PostScript
2. 7. 2. 7.01851 MAarrowhead1
% End of user PostScript
.08574 .2116 m
.08645 .21174 L
s
% Start of user PostScript
3. 7. 3.02322 7.00471 MAarrowhead1
% End of user PostScript
.11642 .2116 m
.11642 .2116 L
s
% Start of user PostScript
4. 7. MAarrowzero1
% End of user PostScript
.1471 .2116 m
.14682 .21188 L
s
% Start of user PostScript
5. 7. 4.99075 7.00925 MAarrowhead1
% End of user PostScript
.17778 .2116 m
.17764 .21089 L
s
% Start of user PostScript
6. 7. 5.99529 6.97678 MAarrowhead1
% End of user PostScript
.20846 .2116 m
.20928 .21135 L
s
% Start of user PostScript
7. 7. 7.02667 6.99184 MAarrowhead1
% End of user PostScript
.23914 .2116 m
.23889 .21156 L
s
% Start of user PostScript
8. 7. 7.99184 6.99875 MAarrowhead1
% End of user PostScript
.26982 .2116 m
.26948 .21387 L
s
% Start of user PostScript
9. 7. 8.9888 7.07394 MAarrowhead1
% End of user PostScript
.3005 .2116 m
.3009 .2145 L
s
% Start of user PostScript
10. 7. 10.013 7.09447 MAarrowhead1
% End of user PostScript
.33118 .2116 m
.33041 .21519 L
s
% Start of user PostScript
11. 7. 10.9747 7.11712 MAarrowhead1
% End of user PostScript
.36186 .2116 m
.36215 .19572 L
s
% Start of user PostScript
12. 7. 12.0093 6.48251 MAarrowhead1
% End of user PostScript
.39255 .2116 m
.39176 .21082 L
s
% Start of user PostScript
13. 7. 12.9745 6.97447 MAarrowhead1
% End of user PostScript
.42323 .2116 m
.42261 .21222 L
s
% Start of user PostScript
14. 7. 13.9798 7.02024 MAarrowhead1
% End of user PostScript
.45391 .2116 m
.45318 .2122 L
s
% Start of user PostScript
15. 7. 14.9765 7.01967 MAarrowhead1
% End of user PostScript
.48459 .2116 m
.48459 .2116 L
s
% Start of user PostScript
16. 7. MAarrowzero1
% End of user PostScript
.51527 .2116 m
.51401 .21074 L
s
% Start of user PostScript
17. 7. 16.9591 6.97196 MAarrowhead1
% End of user PostScript
.54595 .2116 m
.5458 .21145 L
s
% Start of user PostScript
18. 7. 17.9953 6.99529 MAarrowhead1
% End of user PostScript
.57663 .2116 m
.57533 .21194 L
s
% Start of user PostScript
19. 7. 18.9576 7.01098 MAarrowhead1
% End of user PostScript
.60731 .2116 m
.60565 .21197 L
s
% Start of user PostScript
20. 7. 19.9459 7.01214 MAarrowhead1
% End of user PostScript
.63799 .2116 m
.63734 .21152 L
s
% Start of user PostScript
21. 7. 20.9788 6.99731 MAarrowhead1
% End of user PostScript
.66867 .2116 m
.66762 .21185 L
s
% Start of user PostScript
22. 7. 21.9659 7.00827 MAarrowhead1
% End of user PostScript
.69935 .2116 m
.70015 .2108 L
s
% Start of user PostScript
23. 7. 23.0259 6.9741 MAarrowhead1
% End of user PostScript
.73003 .2116 m
.73268 .21163 L
s
% Start of user PostScript
24. 7. 24.0863 7.00116 MAarrowhead1
% End of user PostScript
.76071 .2116 m
.75963 .2116 L
s
% Start of user PostScript
25. 7. 24.9647 7. MAarrowhead1
% End of user PostScript
.79139 .2116 m
.79004 .21024 L
s
% Start of user PostScript
26. 7. 25.9557 6.95571 MAarrowhead1
% End of user PostScript
.82207 .2116 m
.82077 .2129 L
s
% Start of user PostScript
27. 7. 26.9575 7.04247 MAarrowhead1
% End of user PostScript
.85276 .2116 m
.85402 .21022 L
s
% Start of user PostScript
28. 7. 28.0413 6.95522 MAarrowhead1
% End of user PostScript
.88344 .2116 m
.88353 .21151 L
s
% Start of user PostScript
29. 7. 29.003 6.99702 MAarrowhead1
% End of user PostScript
.91412 .2116 m
.91499 .21129 L
s
% Start of user PostScript
30. 7. 30.0286 6.9899 MAarrowhead1
% End of user PostScript
.9448 .2116 m
.9448 .2116 L
s
% Start of user PostScript
31. 7. MAarrowzero1
% End of user PostScript
.97548 .2116 m
.97576 .21188 L
s
% Start of user PostScript
32. 7. 32.0093 7.00925 MAarrowhead1
% End of user PostScript
.02438 .24228 m
.02381 .24228 L
s
% Start of user PostScript
1. 8. 0.98149 8. MAarrowhead1
% End of user PostScript
.05506 .24228 m
.05427 .24256 L
s
% Start of user PostScript
2. 8. 1.97443 8.00925 MAarrowhead1
% End of user PostScript
.08574 .24228 m
.08631 .24228 L
s
% Start of user PostScript
3. 8. 3.01851 8. MAarrowhead1
% End of user PostScript
.11642 .24228 m
.11642 .24228 L
s
% Start of user PostScript
4. 8. MAarrowzero1
% End of user PostScript
.1471 .24228 m
.14724 .24242 L
s
% Start of user PostScript
5. 8. 5.00471 8.00471 MAarrowhead1
% End of user PostScript
.17778 .24228 m
.17782 .24146 L
s
% Start of user PostScript
6. 8. 6.00125 7.97333 MAarrowhead1
% End of user PostScript
.20846 .24228 m
.20775 .24242 L
s
% Start of user PostScript
7. 8. 6.97678 8.00471 MAarrowhead1
% End of user PostScript
.23914 .24228 m
.23864 .24596 L
s
% Start of user PostScript
8. 8. 7.98351 8.11994 MAarrowhead1
% End of user PostScript
.26982 .24228 m
.26943 .24267 L
s
% Start of user PostScript
9. 8. 8.98729 8.01271 MAarrowhead1
% End of user PostScript
.3005 .24228 m
.30121 .24487 L
s
% Start of user PostScript
10. 8. 10.0231 8.08437 MAarrowhead1
% End of user PostScript
.33118 .24228 m
.33204 .24314 L
s
% Start of user PostScript
11. 8. 11.028 8.02804 MAarrowhead1
% End of user PostScript
.36186 .24228 m
.36331 .22982 L
s
% Start of user PostScript
12. 8. 12.0471 7.59378 MAarrowhead1
% End of user PostScript
.39255 .24228 m
.39426 .24296 L
s
% Start of user PostScript
13. 8. 13.0559 8.02218 MAarrowhead1
% End of user PostScript
.42323 .24228 m
.42447 .24256 L
s
% Start of user PostScript
14. 8. 14.0406 8.00925 MAarrowhead1
% End of user PostScript
.45391 .24228 m
.45501 .24228 L
s
% Start of user PostScript
15. 8. 15.036 8. MAarrowhead1
% End of user PostScript
.48459 .24228 m
.48514 .24347 L
s
% Start of user PostScript
16. 8. 16.018 8.0388 MAarrowhead1
% End of user PostScript
.51527 .24228 m
.51463 .24228 L
s
% Start of user PostScript
17. 8. 16.9792 8. MAarrowhead1
% End of user PostScript
.54595 .24228 m
.54483 .24214 L
s
% Start of user PostScript
18. 8. 17.9637 7.99549 MAarrowhead1
% End of user PostScript
.57663 .24228 m
.57644 .24287 L
s
% Start of user PostScript
19. 8. 18.9938 8.01925 MAarrowhead1
% End of user PostScript
.60731 .24228 m
.6056 .24743 L
s
% Start of user PostScript
20. 8. 19.9444 8.16792 MAarrowhead1
% End of user PostScript
.63799 .24228 m
.63631 .24543 L
s
% Start of user PostScript
21. 8. 20.9452 8.10257 MAarrowhead1
% End of user PostScript
.66867 .24228 m
.6696 .24356 L
s
% Start of user PostScript
22. 8. 22.0304 8.04178 MAarrowhead1
% End of user PostScript
.69935 .24228 m
.69935 .24335 L
s
% Start of user PostScript
23. 8. 23. 8.03506 MAarrowhead1
% End of user PostScript
.73003 .24228 m
.72974 .24081 L
s
% Start of user PostScript
24. 8. 23.9905 7.95225 MAarrowhead1
% End of user PostScript
.76071 .24228 m
.76274 .2443 L
s
% Start of user PostScript
25. 8. 25.0659 8.0659 MAarrowhead1
% End of user PostScript
.79139 .24228 m
.78986 .23706 L
s
% Start of user PostScript
26. 8. 25.95 7.83 MAarrowhead1
% End of user PostScript
.82207 .24228 m
.82284 .24162 L
s
% Start of user PostScript
27. 8. 27.0251 7.97839 MAarrowhead1
% End of user PostScript
.85276 .24228 m
.85436 .24039 L
s
% Start of user PostScript
28. 8. 28.0523 7.93827 MAarrowhead1
% End of user PostScript
.88344 .24228 m
.88386 .24242 L
s
% Start of user PostScript
29. 8. 29.014 8.00455 MAarrowhead1
% End of user PostScript
.91412 .24228 m
.91383 .242 L
s
% Start of user PostScript
30. 8. 29.9907 7.99075 MAarrowhead1
% End of user PostScript
.9448 .24228 m
.94451 .24256 L
s
% Start of user PostScript
31. 8. 30.9907 8.00925 MAarrowhead1
% End of user PostScript
.97548 .24228 m
.97548 .24228 L
s
% Start of user PostScript
32. 8. MAarrowzero1
% End of user PostScript
.02438 .27296 m
.02438 .27296 L
s
% Start of user PostScript
1. 9. MAarrowzero1
% End of user PostScript
.05506 .27296 m
.05463 .27339 L
s
% Start of user PostScript
2. 9. 1.98604 9.01396 MAarrowhead1
% End of user PostScript
.08574 .27296 m
.08645 .27282 L
s
% Start of user PostScript
3. 9. 3.02322 8.99529 MAarrowhead1
% End of user PostScript
.11642 .27296 m
.11599 .27339 L
s
% Start of user PostScript
4. 9. 3.98604 9.01396 MAarrowhead1
% End of user PostScript
.1471 .27296 m
.14738 .27324 L
s
% Start of user PostScript
5. 9. 5.00925 9.00925 MAarrowhead1
% End of user PostScript
.17778 .27296 m
.17806 .27268 L
s
% Start of user PostScript
6. 9. 6.00925 8.99075 MAarrowhead1
% End of user PostScript
.20846 .27296 m
.20807 .27364 L
s
% Start of user PostScript
7. 9. 6.98729 9.02212 MAarrowhead1
% End of user PostScript
.23914 .27296 m
.23801 .27755 L
s
% Start of user PostScript
8. 9. 7.9631 9.14976 MAarrowhead1
% End of user PostScript
.26982 .27296 m
.27051 .27461 L
s
% Start of user PostScript
9. 9. 9.02235 9.05373 MAarrowhead1
% End of user PostScript
.3005 .27296 m
.2994 .27589 L
s
% Start of user PostScript
10. 9. 9.9639 9.09539 MAarrowhead1
% End of user PostScript
.33118 .27296 m
.33444 .26971 L
s
% Start of user PostScript
11. 9. 11.106 8.89396 MAarrowhead1
% End of user PostScript
.36186 .27296 m
.36158 .27228 L
s
% Start of user PostScript
12. 9. 11.9907 8.97788 MAarrowhead1
% End of user PostScript
.39255 .27296 m
.39263 .27287 L
s
% Start of user PostScript
13. 9. 13.0028 8.99724 MAarrowhead1
% End of user PostScript
.42323 .27296 m
.42385 .27358 L
s
% Start of user PostScript
14. 9. 14.0202 9.02024 MAarrowhead1
% End of user PostScript
.45391 .27296 m
.45401 .27296 L
s
% Start of user PostScript
15. 9. 15.0035 9. MAarrowhead1
% End of user PostScript
.48459 .27296 m
.48587 .27335 L
s
% Start of user PostScript
16. 9. 16.0418 9.01271 MAarrowhead1
% End of user PostScript
.51527 .27296 m
.51633 .27402 L
s
% Start of user PostScript
17. 9. 17.0345 9.03447 MAarrowhead1
% End of user PostScript
.54595 .27296 m
.5449 .27248 L
s
% Start of user PostScript
18. 9. 17.9658 8.98431 MAarrowhead1
% End of user PostScript
.57663 .27296 m
.57589 .27369 L
s
% Start of user PostScript
19. 9. 18.976 9.02396 MAarrowhead1
% End of user PostScript
.60731 .27296 m
.60679 .26515 L
s
% Start of user PostScript
20. 9. 19.9832 8.74535 MAarrowhead1
% End of user PostScript
.63799 .27296 m
.63878 .2795 L
s
% Start of user PostScript
21. 9. 21.0257 9.21325 MAarrowhead1
% End of user PostScript
.66867 .27296 m
.67043 .26775 L
s
% Start of user PostScript
22. 9. 22.0575 8.83025 MAarrowhead1
% End of user PostScript
.69935 .27296 m
.70076 .27352 L
s
% Start of user PostScript
23. 9. 23.046 9.01831 MAarrowhead1
% End of user PostScript
.73003 .27296 m
.73012 .27169 L
s
% Start of user PostScript
24. 9. 24.0029 8.95857 MAarrowhead1
% End of user PostScript
.76071 .27296 m
.76163 .27411 L
s
% Start of user PostScript
25. 9. 25.03 9.03735 MAarrowhead1
% End of user PostScript
.79139 .27296 m
.79029 .27307 L
s
% Start of user PostScript
26. 9. 25.964 9.00349 MAarrowhead1
% End of user PostScript
.82207 .27296 m
.82336 .27364 L
s
% Start of user PostScript
27. 9. 27.0419 9.02202 MAarrowhead1
% End of user PostScript
.85276 .27296 m
.85461 .27213 L
s
% Start of user PostScript
28. 9. 28.0606 8.97312 MAarrowhead1
% End of user PostScript
.88344 .27296 m
.88354 .27363 L
s
% Start of user PostScript
29. 9. 29.0035 9.02196 MAarrowhead1
% End of user PostScript
.91412 .27296 m
.91383 .27324 L
s
% Start of user PostScript
30. 9. 29.9907 9.00925 MAarrowhead1
% End of user PostScript
.9448 .27296 m
.94508 .27324 L
s
% Start of user PostScript
31. 9. 31.0093 9.00925 MAarrowhead1
% End of user PostScript
.97548 .27296 m
.97548 .27296 L
s
% Start of user PostScript
32. 9. MAarrowzero1
% End of user PostScript
.02438 .30364 m
.02438 .30364 L
s
% Start of user PostScript
1. 10. MAarrowzero1
% End of user PostScript
.05506 .30364 m
.05506 .30364 L
s
% Start of user PostScript
2. 10. MAarrowzero1
% End of user PostScript
.08574 .30364 m
.08602 .30392 L
s
% Start of user PostScript
3. 10. 3.00925 10.0093 MAarrowhead1
% End of user PostScript
.11642 .30364 m
.1167 .30336 L
s
% Start of user PostScript
4. 10. 4.00925 9.99075 MAarrowhead1
% End of user PostScript
.1471 .30364 m
.1471 .30421 L
s
% Start of user PostScript
5. 10. 5. 10.0185 MAarrowhead1
% End of user PostScript
.17778 .30364 m
.17835 .30364 L
s
% Start of user PostScript
6. 10. 6.01851 10. MAarrowhead1
% End of user PostScript
.20846 .30364 m
.20841 .30552 L
s
% Start of user PostScript
7. 10. 6.99827 10.0613 MAarrowhead1
% End of user PostScript
.23914 .30364 m
.23881 .30659 L
s
% Start of user PostScript
8. 10. 7.98914 10.096 MAarrowhead1
% End of user PostScript
.26982 .30364 m
.26911 .30293 L
s
% Start of user PostScript
9. 10. 8.97678 9.97678 MAarrowhead1
% End of user PostScript
.3005 .30364 m
.30195 .30288 L
s
% Start of user PostScript
10. 10. 10.0473 9.9751 MAarrowhead1
% End of user PostScript
.33118 .30364 m
.33147 .30307 L
s
% Start of user PostScript
11. 10. 11.0093 9.98133 MAarrowhead1
% End of user PostScript
.36186 .30364 m
.36161 .3035 L
s
% Start of user PostScript
12. 10. 11.9918 9.99529 MAarrowhead1
% End of user PostScript
.39255 .30364 m
.3916 .30448 L
s
% Start of user PostScript
13. 10. 12.9693 10.0273 MAarrowhead1
% End of user PostScript
.42323 .30364 m
.42098 .30364 L
s
% Start of user PostScript
14. 10. 13.9269 10. MAarrowhead1
% End of user PostScript
.45391 .30364 m
.45285 .30402 L
s
% Start of user PostScript
15. 10. 14.9657 10.0124 MAarrowhead1
% End of user PostScript
.48459 .30364 m
.48375 .3028 L
s
% Start of user PostScript
16. 10. 15.9727 9.97275 MAarrowhead1
% End of user PostScript
.51527 .30364 m
.51532 .30369 L
s
% Start of user PostScript
17. 10. 17.0017 10.0017 MAarrowhead1
% End of user PostScript
.54595 .30364 m
.54547 .30423 L
s
% Start of user PostScript
18. 10. 17.9843 10.0191 MAarrowhead1
% End of user PostScript
.57663 .30364 m
.57598 .30537 L
s
% Start of user PostScript
19. 10. 18.9787 10.0565 MAarrowhead1
% End of user PostScript
.60731 .30364 m
.60538 .30171 L
s
% Start of user PostScript
20. 10. 19.937 9.93702 MAarrowhead1
% End of user PostScript
.63799 .30364 m
.63495 .30629 L
s
% Start of user PostScript
21. 10. 20.901 10.0865 MAarrowhead1
% End of user PostScript
.66867 .30364 m
.67335 .30832 L
s
% Start of user PostScript
22. 10. 22.1526 10.1526 MAarrowhead1
% End of user PostScript
.69935 .30364 m
.70026 .30444 L
s
% Start of user PostScript
23. 10. 23.0295 10.0261 MAarrowhead1
% End of user PostScript
.73003 .30364 m
.72998 .29972 L
s
% Start of user PostScript
24. 10. 23.9983 9.87231 MAarrowhead1
% End of user PostScript
.76071 .30364 m
.7589 .30183 L
s
% Start of user PostScript
25. 10. 24.941 9.94104 MAarrowhead1
% End of user PostScript
.79139 .30364 m
.79179 .30314 L
s
% Start of user PostScript
26. 10. 26.0129 9.98363 MAarrowhead1
% End of user PostScript
.82207 .30364 m
.82223 .30153 L
s
% Start of user PostScript
27. 10. 27.0049 9.93116 MAarrowhead1
% End of user PostScript
.85276 .30364 m
.85265 .30403 L
s
% Start of user PostScript
28. 10. 27.9965 10.0129 MAarrowhead1
% End of user PostScript
.88344 .30364 m
.88315 .30336 L
s
% Start of user PostScript
29. 10. 28.9907 9.99075 MAarrowhead1
% End of user PostScript
.91412 .30364 m
.91483 .3035 L
s
% Start of user PostScript
30. 10. 30.0232 9.99529 MAarrowhead1
% End of user PostScript
.9448 .30364 m
.94508 .30336 L
s
% Start of user PostScript
31. 10. 31.0093 9.99075 MAarrowhead1
% End of user PostScript
.97548 .30364 m
.97548 .30364 L
s
% Start of user PostScript
32. 10. MAarrowzero1
% End of user PostScript
.02438 .33432 m
.02495 .33432 L
s
% Start of user PostScript
1. 11. 1.01851 11. MAarrowhead1
% End of user PostScript
.05506 .33432 m
.05506 .33489 L
s
% Start of user PostScript
2. 11. 2. 11.0185 MAarrowhead1
% End of user PostScript
.08574 .33432 m
.08545 .3346 L
s
% Start of user PostScript
3. 11. 2.99075 11.0093 MAarrowhead1
% End of user PostScript
.11642 .33432 m
.11642 .33432 L
s
% Start of user PostScript
4. 11. MAarrowzero1
% End of user PostScript
.1471 .33432 m
.14738 .3346 L
s
% Start of user PostScript
5. 11. 5.00925 11.0093 MAarrowhead1
% End of user PostScript
.17778 .33432 m
.17764 .33475 L
s
% Start of user PostScript
6. 11. 5.99545 11.014 MAarrowhead1
% End of user PostScript
.20846 .33432 m
.2073 .33798 L
s
% Start of user PostScript
7. 11. 6.96224 11.1193 MAarrowhead1
% End of user PostScript
.23914 .33432 m
.23763 .33773 L
s
% Start of user PostScript
8. 11. 7.95078 11.1113 MAarrowhead1
% End of user PostScript
.26982 .33432 m
.2689 .33621 L
s
% Start of user PostScript
9. 11. 8.96976 11.0616 MAarrowhead1
% End of user PostScript
.3005 .33432 m
.30506 .32987 L
s
% Start of user PostScript
10. 11. 10.1485 10.8549 MAarrowhead1
% End of user PostScript
.33118 .33432 m
.33118 .33443 L
s
% Start of user PostScript
11. 11. 11. 11.0035 MAarrowhead1
% End of user PostScript
.36186 .33432 m
.35684 .33593 L
s
% Start of user PostScript
12. 11. 11.8364 11.0524 MAarrowhead1
% End of user PostScript
.39255 .33432 m
.38956 .33531 L
s
% Start of user PostScript
13. 11. 12.9028 11.0322 MAarrowhead1
% End of user PostScript
.42323 .33432 m
.41932 .33511 L
s
% Start of user PostScript
14. 11. 13.8728 11.0257 MAarrowhead1
% End of user PostScript
.45391 .33432 m
.44694 .33353 L
s
% Start of user PostScript
15. 11. 14.7728 10.9744 MAarrowhead1
% End of user PostScript
.48459 .33432 m
.47798 .32963 L
s
% Start of user PostScript
16. 11. 15.7847 10.847 MAarrowhead1
% End of user PostScript
.51527 .33432 m
.51527 .33432 L
s
% Start of user PostScript
17. 11. MAarrowzero1
% End of user PostScript
.54595 .33432 m
.54643 .33556 L
s
% Start of user PostScript
18. 11. 18.0157 11.0404 MAarrowhead1
% End of user PostScript
.57663 .33432 m
.57722 .33645 L
s
% Start of user PostScript
19. 11. 19.0194 11.0692 MAarrowhead1
% End of user PostScript
.60731 .33432 m
.60538 .33676 L
s
% Start of user PostScript
20. 11. 19.937 11.0795 MAarrowhead1
% End of user PostScript
.63799 .33432 m
.6349 .33037 L
s
% Start of user PostScript
21. 11. 20.8992 10.8713 MAarrowhead1
% End of user PostScript
.66867 .33432 m
.66776 .33871 L
s
% Start of user PostScript
22. 11. 21.9703 11.143 MAarrowhead1
% End of user PostScript
.69935 .33432 m
.70493 .33861 L
s
% Start of user PostScript
23. 11. 23.1817 11.1398 MAarrowhead1
% End of user PostScript
.73003 .33432 m
.73153 .33408 L
s
% Start of user PostScript
24. 11. 24.0488 10.992 MAarrowhead1
% End of user PostScript
.76071 .33432 m
.7595 .33167 L
s
% Start of user PostScript
25. 11. 24.9604 10.9137 MAarrowhead1
% End of user PostScript
.79139 .33432 m
.79375 .33633 L
s
% Start of user PostScript
26. 11. 26.0768 11.0653 MAarrowhead1
% End of user PostScript
.82207 .33432 m
.8221 .32909 L
s
% Start of user PostScript
27. 11. 27.0008 10.8295 MAarrowhead1
% End of user PostScript
.85276 .33432 m
.85357 .33407 L
s
% Start of user PostScript
28. 11. 28.0267 10.9918 MAarrowhead1
% End of user PostScript
.88344 .33432 m
.88315 .3346 L
s
% Start of user PostScript
29. 11. 28.9907 11.0093 MAarrowhead1
% End of user PostScript
.91412 .33432 m
.9144 .3346 L
s
% Start of user PostScript
30. 11. 30.0093 11.0093 MAarrowhead1
% End of user PostScript
.9448 .33432 m
.9448 .33432 L
s
% Start of user PostScript
31. 11. MAarrowzero1
% End of user PostScript
.97548 .33432 m
.97519 .33404 L
s
% Start of user PostScript
32. 11. 31.9907 10.9907 MAarrowhead1
% End of user PostScript
.02438 .365 m
.02438 .365 L
s
% Start of user PostScript
1. 12. MAarrowzero1
% End of user PostScript
.05506 .365 m
.05449 .365 L
s
% Start of user PostScript
2. 12. 1.98149 12. MAarrowhead1
% End of user PostScript
.08574 .365 m
.08535 .36461 L
s
% Start of user PostScript
3. 12. 2.98729 11.9873 MAarrowhead1
% End of user PostScript
.11642 .365 m
.11642 .36557 L
s
% Start of user PostScript
4. 12. 4. 12.0185 MAarrowhead1
% End of user PostScript
.1471 .365 m
.1471 .36557 L
s
% Start of user PostScript
5. 12. 5. 12.0185 MAarrowhead1
% End of user PostScript
.17778 .365 m
.17831 .36554 L
s
% Start of user PostScript
6. 12. 6.01741 12.0174 MAarrowhead1
% End of user PostScript
.20846 .365 m
.20567 .36876 L
s
% Start of user PostScript
7. 12. 6.90886 12.1225 MAarrowhead1
% End of user PostScript
.23914 .365 m
.2377 .36645 L
s
% Start of user PostScript
8. 12. 7.95292 12.0471 MAarrowhead1
% End of user PostScript
.26982 .365 m
.27016 .36534 L
s
% Start of user PostScript
9. 12. 9.01098 12.011 MAarrowhead1
% End of user PostScript
.3005 .365 m
.30022 .36472 L
s
% Start of user PostScript
10. 12. 9.99075 11.9907 MAarrowhead1
% End of user PostScript
.33118 .365 m
.33138 .36424 L
s
% Start of user PostScript
11. 12. 11.0064 11.9751 MAarrowhead1
% End of user PostScript
.36186 .365 m
.36153 .36466 L
s
% Start of user PostScript
12. 12. 11.989 11.989 MAarrowhead1
% End of user PostScript
.39255 .365 m
.39206 .36481 L
s
% Start of user PostScript
13. 12. 12.9843 11.9937 MAarrowhead1
% End of user PostScript
.42323 .365 m
.42312 .365 L
s
% Start of user PostScript
14. 12. 13.9965 12. MAarrowhead1
% End of user PostScript
.45391 .365 m
.45434 .36543 L
s
% Start of user PostScript
15. 12. 15.014 12.014 MAarrowhead1
% End of user PostScript
.48459 .365 m
.4843 .36529 L
s
% Start of user PostScript
16. 12. 15.9907 12.0093 MAarrowhead1
% End of user PostScript
.51527 .365 m
.51465 .36562 L
s
% Start of user PostScript
17. 12. 16.9798 12.0202 MAarrowhead1
% End of user PostScript
.54595 .365 m
.54595 .36568 L
s
% Start of user PostScript
18. 12. 18. 12.022 MAarrowhead1
% End of user PostScript
.57663 .365 m
.57734 .36526 L
s
% Start of user PostScript
19. 12. 19.0231 12.0083 MAarrowhead1
% End of user PostScript
.60731 .365 m
.61004 .37096 L
s
% Start of user PostScript
20. 12. 20.0891 12.1942 MAarrowhead1
% End of user PostScript
.63799 .365 m
.6351 .362 L
s
% Start of user PostScript
21. 12. 20.9056 11.9022 MAarrowhead1
% End of user PostScript
.66867 .365 m
.67023 .36656 L
s
% Start of user PostScript
22. 12. 22.0507 12.0507 MAarrowhead1
% End of user PostScript
.69935 .365 m
.69785 .36204 L
s
% Start of user PostScript
23. 12. 22.9511 11.9035 MAarrowhead1
% End of user PostScript
.73003 .365 m
.73134 .36631 L
s
% Start of user PostScript
24. 12. 24.0426 12.0426 MAarrowhead1
% End of user PostScript
.76071 .365 m
.76113 .3662 L
s
% Start of user PostScript
25. 12. 25.0136 12.039 MAarrowhead1
% End of user PostScript
.79139 .365 m
.7917 .36831 L
s
% Start of user PostScript
26. 12. 26.0099 12.108 MAarrowhead1
% End of user PostScript
.82207 .365 m
.82116 .36409 L
s
% Start of user PostScript
27. 12. 26.9702 11.9702 MAarrowhead1
% End of user PostScript
.85276 .365 m
.85286 .3649 L
s
% Start of user PostScript
28. 12. 28.0035 11.9965 MAarrowhead1
% End of user PostScript
.88344 .365 m
.88344 .36443 L
s
% Start of user PostScript
29. 12. 29. 11.9815 MAarrowhead1
% End of user PostScript
.91412 .365 m
.91468 .365 L
s
% Start of user PostScript
30. 12. 30.0185 12. MAarrowhead1
% End of user PostScript
.9448 .365 m
.9448 .365 L
s
% Start of user PostScript
31. 12. MAarrowzero1
% End of user PostScript
.97548 .365 m
.97519 .36472 L
s
% Start of user PostScript
32. 12. 31.9907 11.9907 MAarrowhead1
% End of user PostScript
.02438 .39568 m
.02495 .39568 L
s
% Start of user PostScript
1. 13. 1.01851 13. MAarrowhead1
% End of user PostScript
.05506 .39568 m
.05506 .39568 L
s
% Start of user PostScript
2. 13. MAarrowzero1
% End of user PostScript
.08574 .39568 m
.08574 .39568 L
s
% Start of user PostScript
3. 13. MAarrowzero1
% End of user PostScript
.11642 .39568 m
.11642 .39568 L
s
% Start of user PostScript
4. 13. MAarrowzero1
% End of user PostScript
.1471 .39568 m
.14749 .39607 L
s
% Start of user PostScript
5. 13. 5.01271 13.0127 MAarrowhead1
% End of user PostScript
.17778 .39568 m
.17627 .40146 L
s
% Start of user PostScript
6. 13. 5.95063 13.1883 MAarrowhead1
% End of user PostScript
.20846 .39568 m
.20746 .39697 L
s
% Start of user PostScript
7. 13. 6.96725 13.0418 MAarrowhead1
% End of user PostScript
.23914 .39568 m
.2406 .39525 L
s
% Start of user PostScript
8. 13. 8.04765 12.986 MAarrowhead1
% End of user PostScript
.26982 .39568 m
.26972 .37816 L
s
% Start of user PostScript
9. 13. 8.99665 12.4289 MAarrowhead1
% End of user PostScript
.3005 .39568 m
.30031 .39492 L
s
% Start of user PostScript
10. 13. 9.99357 12.9751 MAarrowhead1
% End of user PostScript
.33118 .39568 m
.33152 .39602 L
s
% Start of user PostScript
11. 13. 11.011 13.011 MAarrowhead1
% End of user PostScript
.36186 .39568 m
.36183 .39515 L
s
% Start of user PostScript
12. 13. 11.999 12.9825 MAarrowhead1
% End of user PostScript
.39255 .39568 m
.39441 .39611 L
s
% Start of user PostScript
13. 13. 13.0606 13.014 MAarrowhead1
% End of user PostScript
.42323 .39568 m
.41619 .39568 L
s
% Start of user PostScript
14. 13. 13.7706 13. MAarrowhead1
% End of user PostScript
.45391 .39568 m
.45015 .39375 L
s
% Start of user PostScript
15. 13. 14.8775 12.937 MAarrowhead1
% End of user PostScript
.48459 .39568 m
.48563 .39597 L
s
% Start of user PostScript
16. 13. 16.034 13.0093 MAarrowhead1
% End of user PostScript
.51527 .39568 m
.51598 .3964 L
s
% Start of user PostScript
17. 13. 17.0233 13.0233 MAarrowhead1
% End of user PostScript
.54595 .39568 m
.54611 .39595 L
s
% Start of user PostScript
18. 13. 18.0053 13.0087 MAarrowhead1
% End of user PostScript
.57663 .39568 m
.57663 .39579 L
s
% Start of user PostScript
19. 13. 19. 13.0035 MAarrowhead1
% End of user PostScript
.60731 .39568 m
.60746 .39814 L
s
% Start of user PostScript
20. 13. 20.0049 13.0802 MAarrowhead1
% End of user PostScript
.63799 .39568 m
.63655 .3928 L
s
% Start of user PostScript
21. 13. 20.9529 12.9062 MAarrowhead1
% End of user PostScript
.66867 .39568 m
.66828 .39242 L
s
% Start of user PostScript
22. 13. 21.9872 12.8938 MAarrowhead1
% End of user PostScript
.69935 .39568 m
.6969 .39115 L
s
% Start of user PostScript
23. 13. 22.9202 12.8524 MAarrowhead1
% End of user PostScript
.73003 .39568 m
.72891 .39806 L
s
% Start of user PostScript
24. 13. 23.9634 13.0774 MAarrowhead1
% End of user PostScript
.76071 .39568 m
.75842 .39339 L
s
% Start of user PostScript
25. 13. 24.9254 12.9254 MAarrowhead1
% End of user PostScript
.79139 .39568 m
.79134 .39602 L
s
% Start of user PostScript
26. 13. 25.9983 13.0109 MAarrowhead1
% End of user PostScript
.82207 .39568 m
.82124 .39834 L
s
% Start of user PostScript
27. 13. 26.9727 13.0868 MAarrowhead1
% End of user PostScript
.85276 .39568 m
.85276 .39568 L
s
% Start of user PostScript
28. 13. MAarrowzero1
% End of user PostScript
.88344 .39568 m
.88372 .39597 L
s
% Start of user PostScript
29. 13. 29.0093 13.0093 MAarrowhead1
% End of user PostScript
.91412 .39568 m
.91412 .39568 L
s
% Start of user PostScript
30. 13. MAarrowzero1
% End of user PostScript
.9448 .39568 m
.9448 .39568 L
s
% Start of user PostScript
31. 13. MAarrowzero1
% End of user PostScript
.97548 .39568 m
.97576 .3954 L
s
% Start of user PostScript
32. 13. 32.0093 12.9907 MAarrowhead1
% End of user PostScript
.02438 .42636 m
.02438 .42636 L
s
% Start of user PostScript
1. 14. MAarrowzero1
% End of user PostScript
.05506 .42636 m
.05534 .42608 L
s
% Start of user PostScript
2. 14. 2.00925 13.9907 MAarrowhead1
% End of user PostScript
.08574 .42636 m
.08545 .42665 L
s
% Start of user PostScript
3. 14. 2.99075 14.0093 MAarrowhead1
% End of user PostScript
.11642 .42636 m
.11614 .42608 L
s
% Start of user PostScript
4. 14. 3.99075 13.9907 MAarrowhead1
% End of user PostScript
.1471 .42636 m
.14767 .42636 L
s
% Start of user PostScript
5. 14. 5.01851 14. MAarrowhead1
% End of user PostScript
.17778 .42636 m
.1734 .43432 L
s
% Start of user PostScript
6. 14. 5.8572 14.2594 MAarrowhead1
% End of user PostScript
.20846 .42636 m
.20711 .42686 L
s
% Start of user PostScript
7. 14. 6.9558 14.0163 MAarrowhead1
% End of user PostScript
.23914 .42636 m
.23652 .42966 L
s
% Start of user PostScript
8. 14. 7.91463 14.1073 MAarrowhead1
% End of user PostScript
.26982 .42636 m
.27006 .42602 L
s
% Start of user PostScript
9. 14. 9.00769 13.9889 MAarrowhead1
% End of user PostScript
.3005 .42636 m
.3005 .42636 L
s
% Start of user PostScript
10. 14. MAarrowzero1
% End of user PostScript
.33118 .42636 m
.33127 .42645 L
s
% Start of user PostScript
11. 14. 11.0028 14.0028 MAarrowhead1
% End of user PostScript
.36186 .42636 m
.36201 .42554 L
s
% Start of user PostScript
12. 14. 12.0047 13.9733 MAarrowhead1
% End of user PostScript
.39255 .42636 m
.39201 .4269 L
s
% Start of user PostScript
13. 14. 12.9826 14.0174 MAarrowhead1
% End of user PostScript
.42323 .42636 m
.4219 .42769 L
s
% Start of user PostScript
14. 14. 13.9568 14.0432 MAarrowhead1
% End of user PostScript
.45391 .42636 m
.45387 .42622 L
s
% Start of user PostScript
15. 14. 14.9987 13.9953 MAarrowhead1
% End of user PostScript
.48459 .42636 m
.48469 .42636 L
s
% Start of user PostScript
16. 14. 16.0035 14. MAarrowhead1
% End of user PostScript
.51527 .42636 m
.51507 .42656 L
s
% Start of user PostScript
17. 14. 16.9936 14.0064 MAarrowhead1
% End of user PostScript
.54595 .42636 m
.54661 .42703 L
s
% Start of user PostScript
18. 14. 18.0216 14.0216 MAarrowhead1
% End of user PostScript
.57663 .42636 m
.57735 .42708 L
s
% Start of user PostScript
19. 14. 19.0233 14.0233 MAarrowhead1
% End of user PostScript
.60731 .42636 m
.6077 .42772 L
s
% Start of user PostScript
20. 14. 20.0127 14.0441 MAarrowhead1
% End of user PostScript
.63799 .42636 m
.6379 .42384 L
s
% Start of user PostScript
21. 14. 20.9971 13.9178 MAarrowhead1
% End of user PostScript
.66867 .42636 m
.66818 .42696 L
s
% Start of user PostScript
22. 14. 21.9838 14.0196 MAarrowhead1
% End of user PostScript
.69935 .42636 m
.69822 .42641 L
s
% Start of user PostScript
23. 14. 22.9631 14.0016 MAarrowhead1
% End of user PostScript
.73003 .42636 m
.72943 .42497 L
s
% Start of user PostScript
24. 14. 23.9804 13.9545 MAarrowhead1
% End of user PostScript
.76071 .42636 m
.7596 .42844 L
s
% Start of user PostScript
25. 14. 24.9637 14.0677 MAarrowhead1
% End of user PostScript
.79139 .42636 m
.79247 .42443 L
s
% Start of user PostScript
26. 14. 26.0349 13.9369 MAarrowhead1
% End of user PostScript
.82207 .42636 m
.82207 .42636 L
s
% Start of user PostScript
27. 14. MAarrowzero1
% End of user PostScript
.85276 .42636 m
.85219 .42636 L
s
% Start of user PostScript
28. 14. 27.9815 14. MAarrowhead1
% End of user PostScript
.88344 .42636 m
.88372 .42665 L
s
% Start of user PostScript
29. 14. 29.0093 14.0093 MAarrowhead1
% End of user PostScript
.91412 .42636 m
.91412 .42636 L
s
% Start of user PostScript
30. 14. MAarrowzero1
% End of user PostScript
.9448 .42636 m
.9448 .42636 L
s
% Start of user PostScript
31. 14. MAarrowzero1
% End of user PostScript
.97548 .42636 m
.97548 .42636 L
s
% Start of user PostScript
32. 14. MAarrowzero1
% End of user PostScript
.02438 .45704 m
.02438 .45704 L
s
% Start of user PostScript
1. 15. MAarrowzero1
% End of user PostScript
.05506 .45704 m
.05506 .45704 L
s
% Start of user PostScript
2. 15. MAarrowzero1
% End of user PostScript
.08574 .45704 m
.08574 .45704 L
s
% Start of user PostScript
3. 15. MAarrowzero1
% End of user PostScript
.11642 .45704 m
.1167 .45733 L
s
% Start of user PostScript
4. 15. 4.00925 15.0093 MAarrowhead1
% End of user PostScript
.1471 .45704 m
.14767 .45704 L
s
% Start of user PostScript
5. 15. 5.01851 15. MAarrowhead1
% End of user PostScript
.17778 .45704 m
.17599 .4589 L
s
% Start of user PostScript
6. 15. 5.94163 15.0605 MAarrowhead1
% End of user PostScript
.20846 .45704 m
.20756 .45733 L
s
% Start of user PostScript
7. 15. 6.97075 15.0093 MAarrowhead1
% End of user PostScript
.23914 .45704 m
.24273 .45783 L
s
% Start of user PostScript
8. 15. 8.1168 15.0257 MAarrowhead1
% End of user PostScript
.26982 .45704 m
.27036 .45634 L
s
% Start of user PostScript
9. 15. 9.01747 14.977 MAarrowhead1
% End of user PostScript
.3005 .45704 m
.30098 .45656 L
s
% Start of user PostScript
10. 15. 10.0157 14.9843 MAarrowhead1
% End of user PostScript
.33118 .45704 m
.33175 .45665 L
s
% Start of user PostScript
11. 15. 11.0185 14.9871 MAarrowhead1
% End of user PostScript
.36186 .45704 m
.36186 .45704 L
s
% Start of user PostScript
12. 15. MAarrowzero1
% End of user PostScript
.39255 .45704 m
.39255 .45704 L
s
% Start of user PostScript
13. 15. MAarrowzero1
% End of user PostScript
.42323 .45704 m
.42323 .45804 L
s
% Start of user PostScript
14. 15. 14. 15.0325 MAarrowhead1
% End of user PostScript
.45391 .45704 m
.45425 .4567 L
s
% Start of user PostScript
15. 15. 15.0112 14.9888 MAarrowhead1
% End of user PostScript
.48459 .45704 m
.48424 .45739 L
s
% Start of user PostScript
16. 15. 15.9888 15.0112 MAarrowhead1
% End of user PostScript
.51527 .45704 m
.51527 .45704 L
s
% Start of user PostScript
17. 15. MAarrowzero1
% End of user PostScript
.54595 .45704 m
.54634 .45743 L
s
% Start of user PostScript
18. 15. 18.0127 15.0127 MAarrowhead1
% End of user PostScript
.57663 .45704 m
.57674 .45804 L
s
% Start of user PostScript
19. 15. 19.0035 15.0325 MAarrowhead1
% End of user PostScript
.60731 .45704 m
.60762 .4606 L
s
% Start of user PostScript
20. 15. 20.01 15.116 MAarrowhead1
% End of user PostScript
.63799 .45704 m
.63915 .45924 L
s
% Start of user PostScript
21. 15. 21.0379 15.0715 MAarrowhead1
% End of user PostScript
.66867 .45704 m
.66831 .4555 L
s
% Start of user PostScript
22. 15. 21.9882 14.9497 MAarrowhead1
% End of user PostScript
.69935 .45704 m
.70122 .45653 L
s
% Start of user PostScript
23. 15. 23.061 14.9834 MAarrowhead1
% End of user PostScript
.73003 .45704 m
.72932 .45633 L
s
% Start of user PostScript
24. 15. 23.9767 14.9767 MAarrowhead1
% End of user PostScript
.76071 .45704 m
.75984 .46128 L
s
% Start of user PostScript
25. 15. 24.9714 15.1381 MAarrowhead1
% End of user PostScript
.79139 .45704 m
.79164 .45251 L
s
% Start of user PostScript
26. 15. 26.008 14.8521 MAarrowhead1
% End of user PostScript
.82207 .45704 m
.82207 .45704 L
s
% Start of user PostScript
27. 15. MAarrowzero1
% End of user PostScript
.85276 .45704 m
.85276 .45704 L
s
% Start of user PostScript
28. 15. MAarrowzero1
% End of user PostScript
.88344 .45704 m
.88372 .45676 L
s
% Start of user PostScript
29. 15. 29.0093 14.9907 MAarrowhead1
% End of user PostScript
.91412 .45704 m
.9144 .45676 L
s
% Start of user PostScript
30. 15. 30.0093 14.9907 MAarrowhead1
% End of user PostScript
.9448 .45704 m
.9448 .45704 L
s
% Start of user PostScript
31. 15. MAarrowzero1
% End of user PostScript
.97548 .45704 m
.97519 .45676 L
s
% Start of user PostScript
32. 15. 31.9907 14.9907 MAarrowhead1
% End of user PostScript
.02438 .48772 m
.02495 .48772 L
s
% Start of user PostScript
1. 16. 1.01851 16. MAarrowhead1
% End of user PostScript
.05506 .48772 m
.05506 .48772 L
s
% Start of user PostScript
2. 16. MAarrowzero1
% End of user PostScript
.08574 .48772 m
.08602 .48801 L
s
% Start of user PostScript
3. 16. 3.00925 16.0093 MAarrowhead1
% End of user PostScript
.11642 .48772 m
.11642 .48772 L
s
% Start of user PostScript
4. 16. MAarrowzero1
% End of user PostScript
.1471 .48772 m
.1471 .48716 L
s
% Start of user PostScript
5. 16. 5. 15.9815 MAarrowhead1
% End of user PostScript
.17778 .48772 m
.17776 .49071 L
s
% Start of user PostScript
6. 16. 5.99941 16.0975 MAarrowhead1
% End of user PostScript
.20846 .48772 m
.20787 .49092 L
s
% Start of user PostScript
7. 16. 6.98075 16.1043 MAarrowhead1
% End of user PostScript
.23914 .48772 m
.23852 .48642 L
s
% Start of user PostScript
8. 16. 7.97976 15.9575 MAarrowhead1
% End of user PostScript
.26982 .48772 m
.2703 .48724 L
s
% Start of user PostScript
9. 16. 9.01569 15.9843 MAarrowhead1
% End of user PostScript
.3005 .48772 m
.30011 .48829 L
s
% Start of user PostScript
10. 16. 9.98708 16.0185 MAarrowhead1
% End of user PostScript
.33118 .48772 m
.32988 .48749 L
s
% Start of user PostScript
11. 16. 10.9575 15.9924 MAarrowhead1
% End of user PostScript
.36186 .48772 m
.3611 .48696 L
s
% Start of user PostScript
12. 16. 11.9751 15.9751 MAarrowhead1
% End of user PostScript
.39255 .48772 m
.39263 .48714 L
s
% Start of user PostScript
13. 16. 13.0028 15.9808 MAarrowhead1
% End of user PostScript
.42323 .48772 m
.42294 .4904 L
s
% Start of user PostScript
14. 16. 13.9907 16.0873 MAarrowhead1
% End of user PostScript
.45391 .48772 m
.45307 .48699 L
s
% Start of user PostScript
15. 16. 14.9727 15.9762 MAarrowhead1
% End of user PostScript
.48459 .48772 m
.48473 .48758 L
s
% Start of user PostScript
16. 16. 16.0047 15.9953 MAarrowhead1
% End of user PostScript
.51527 .48772 m
.51383 .48735 L
s
% Start of user PostScript
17. 16. 16.953 15.9879 MAarrowhead1
% End of user PostScript
.54595 .48772 m
.54575 .48763 L
s
% Start of user PostScript
18. 16. 17.9936 15.997 MAarrowhead1
% End of user PostScript
.57663 .48772 m
.57641 .48869 L
s
% Start of user PostScript
19. 16. 18.9929 16.0314 MAarrowhead1
% End of user PostScript
.60731 .48772 m
.60802 .4893 L
s
% Start of user PostScript
20. 16. 20.0231 16.0512 MAarrowhead1
% End of user PostScript
.63799 .48772 m
.6383 .48974 L
s
% Start of user PostScript
21. 16. 21.01 16.0658 MAarrowhead1
% End of user PostScript
.66867 .48772 m
.66867 .48602 L
s
% Start of user PostScript
22. 16. 22. 15.9444 MAarrowhead1
% End of user PostScript
.69935 .48772 m
.69935 .48772 L
s
% Start of user PostScript
23. 16. MAarrowzero1
% End of user PostScript
.73003 .48772 m
.72955 .48724 L
s
% Start of user PostScript
24. 16. 23.9843 15.9843 MAarrowhead1
% End of user PostScript
.76071 .48772 m
.76113 .48571 L
s
% Start of user PostScript
25. 16. 25.0135 15.9343 MAarrowhead1
% End of user PostScript
.79139 .48772 m
.7929 .48119 L
s
% Start of user PostScript
26. 16. 26.049 15.7869 MAarrowhead1
% End of user PostScript
.82207 .48772 m
.82179 .48744 L
s
% Start of user PostScript
27. 16. 26.9907 15.9907 MAarrowhead1
% End of user PostScript
.85276 .48772 m
.85276 .48772 L
s
% Start of user PostScript
28. 16. MAarrowzero1
% End of user PostScript
.88344 .48772 m
.88344 .48772 L
s
% Start of user PostScript
29. 16. MAarrowzero1
% End of user PostScript
.91412 .48772 m
.91412 .48829 L
s
% Start of user PostScript
30. 16. 30. 16.0185 MAarrowhead1
% End of user PostScript
.9448 .48772 m
.9448 .48772 L
s
% Start of user PostScript
31. 16. MAarrowzero1
% End of user PostScript
.97548 .48772 m
.97548 .48772 L
s
% Start of user PostScript
32. 16. MAarrowzero1
% End of user PostScript
.02438 .5184 m
.02495 .5184 L
s
% Start of user PostScript
1. 17. 1.01851 17. MAarrowhead1
% End of user PostScript
.05506 .5184 m
.05506 .5184 L
s
% Start of user PostScript
2. 17. MAarrowzero1
% End of user PostScript
.08574 .5184 m
.08602 .51812 L
s
% Start of user PostScript
3. 17. 3.00925 16.9907 MAarrowhead1
% End of user PostScript
.11642 .5184 m
.11614 .51812 L
s
% Start of user PostScript
4. 17. 3.99075 16.9907 MAarrowhead1
% End of user PostScript
.1471 .5184 m
.14583 .52954 L
s
% Start of user PostScript
5. 17. 4.95869 17.3628 MAarrowhead1
% End of user PostScript
.17778 .5184 m
.1772 .52071 L
s
% Start of user PostScript
6. 17. 5.98096 17.0751 MAarrowhead1
% End of user PostScript
.20846 .5184 m
.20561 .51653 L
s
% Start of user PostScript
7. 17. 6.90716 16.939 MAarrowhead1
% End of user PostScript
.23914 .5184 m
.24068 .51759 L
s
% Start of user PostScript
8. 17. 8.05 16.9735 MAarrowhead1
% End of user PostScript
.26982 .5184 m
.2686 .51894 L
s
% Start of user PostScript
9. 17. 8.9602 17.0174 MAarrowhead1
% End of user PostScript
.3005 .5184 m
.3036 .51518 L
s
% Start of user PostScript
10. 17. 10.1008 16.8947 MAarrowhead1
% End of user PostScript
.33118 .5184 m
.32984 .51907 L
s
% Start of user PostScript
11. 17. 10.9563 17.0218 MAarrowhead1
% End of user PostScript
.36186 .5184 m
.36242 .51891 L
s
% Start of user PostScript
12. 17. 12.0181 17.0165 MAarrowhead1
% End of user PostScript
.39255 .5184 m
.39264 .51657 L
s
% Start of user PostScript
13. 17. 13.003 16.9402 MAarrowhead1
% End of user PostScript
.42323 .5184 m
.42328 .52007 L
s
% Start of user PostScript
14. 17. 14.0017 17.0544 MAarrowhead1
% End of user PostScript
.45391 .5184 m
.45146 .51698 L
s
% Start of user PostScript
15. 17. 14.9204 16.9537 MAarrowhead1
% End of user PostScript
.48459 .5184 m
.49136 .51503 L
s
% Start of user PostScript
16. 17. 16.2208 16.89 MAarrowhead1
% End of user PostScript
.51527 .5184 m
.51658 .51421 L
s
% Start of user PostScript
17. 17. 17.0429 16.8634 MAarrowhead1
% End of user PostScript
.54595 .5184 m
.5436 .51832 L
s
% Start of user PostScript
18. 17. 17.9234 16.9971 MAarrowhead1
% End of user PostScript
.57663 .5184 m
.57604 .51782 L
s
% Start of user PostScript
19. 17. 18.9809 16.9809 MAarrowhead1
% End of user PostScript
.60731 .5184 m
.60736 .51942 L
s
% Start of user PostScript
20. 17. 20.0016 17.0332 MAarrowhead1
% End of user PostScript
.63799 .5184 m
.63745 .52084 L
s
% Start of user PostScript
21. 17. 20.9824 17.0792 MAarrowhead1
% End of user PostScript
.66867 .5184 m
.66637 .51724 L
s
% Start of user PostScript
22. 17. 21.9248 16.9622 MAarrowhead1
% End of user PostScript
.69935 .5184 m
.69788 .51505 L
s
% Start of user PostScript
23. 17. 22.9521 16.8905 MAarrowhead1
% End of user PostScript
.73003 .5184 m
.72901 .51718 L
s
% Start of user PostScript
24. 17. 23.9666 16.96 MAarrowhead1
% End of user PostScript
.76071 .5184 m
.76133 .51347 L
s
% Start of user PostScript
25. 17. 25.0199 16.8393 MAarrowhead1
% End of user PostScript
.79139 .5184 m
.79221 .51759 L
s
% Start of user PostScript
26. 17. 26.0267 16.9733 MAarrowhead1
% End of user PostScript
.82207 .5184 m
.82207 .5184 L
s
% Start of user PostScript
27. 17. MAarrowzero1
% End of user PostScript
.85276 .5184 m
.85276 .5184 L
s
% Start of user PostScript
28. 17. MAarrowzero1
% End of user PostScript
.88344 .5184 m
.88315 .51869 L
s
% Start of user PostScript
29. 17. 28.9907 17.0093 MAarrowhead1
% End of user PostScript
.91412 .5184 m
.91412 .5184 L
s
% Start of user PostScript
30. 17. MAarrowzero1
% End of user PostScript
.9448 .5184 m
.9448 .5184 L
s
% Start of user PostScript
31. 17. MAarrowzero1
% End of user PostScript
.97548 .5184 m
.97548 .5184 L
s
% Start of user PostScript
32. 17. MAarrowzero1
% End of user PostScript
.02438 .54909 m
.02438 .54909 L
s
% Start of user PostScript
1. 18. MAarrowzero1
% End of user PostScript
.05506 .54909 m
.05534 .54937 L
s
% Start of user PostScript
2. 18. 2.00925 18.0093 MAarrowhead1
% End of user PostScript
.08574 .54909 m
.08602 .54937 L
s
% Start of user PostScript
3. 18. 3.00925 18.0093 MAarrowhead1
% End of user PostScript
.11642 .54909 m
.11614 .54937 L
s
% Start of user PostScript
4. 18. 3.99075 18.0093 MAarrowhead1
% End of user PostScript
.1471 .54909 m
.15217 .55213 L
s
% Start of user PostScript
5. 18. 5.1652 18.0991 MAarrowhead1
% End of user PostScript
.17778 .54909 m
.17594 .54724 L
s
% Start of user PostScript
6. 18. 5.94 17.94 MAarrowhead1
% End of user PostScript
.20846 .54909 m
.21009 .54384 L
s
% Start of user PostScript
7. 18. 7.05298 17.829 MAarrowhead1
% End of user PostScript
.23914 .54909 m
.23798 .54706 L
s
% Start of user PostScript
8. 18. 7.96208 17.9339 MAarrowhead1
% End of user PostScript
.26982 .54909 m
.27164 .54898 L
s
% Start of user PostScript
9. 18. 9.0592 17.9965 MAarrowhead1
% End of user PostScript
.3005 .54909 m
.31087 .55073 L
s
% Start of user PostScript
10. 18. 10.338 18.0537 MAarrowhead1
% End of user PostScript
.33118 .54909 m
.34354 .54864 L
s
% Start of user PostScript
11. 18. 11.4028 17.9855 MAarrowhead1
% End of user PostScript
.36186 .54909 m
.36167 .5475 L
s
% Start of user PostScript
12. 18. 11.9937 17.9483 MAarrowhead1
% End of user PostScript
.39255 .54909 m
.39246 .5485 L
s
% Start of user PostScript
13. 18. 12.9972 17.9808 MAarrowhead1
% End of user PostScript
.42323 .54909 m
.42399 .54928 L
s
% Start of user PostScript
14. 18. 14.0249 18.0064 MAarrowhead1
% End of user PostScript
.45391 .54909 m
.45347 .54941 L
s
% Start of user PostScript
15. 18. 14.9859 18.0106 MAarrowhead1
% End of user PostScript
.48459 .54909 m
.49144 .54753 L
s
% Start of user PostScript
16. 18. 16.2234 17.9492 MAarrowhead1
% End of user PostScript
.51527 .54909 m
.52314 .55047 L
s
% Start of user PostScript
17. 18. 17.2565 18.0452 MAarrowhead1
% End of user PostScript
.54595 .54909 m
.55114 .54701 L
s
% Start of user PostScript
18. 18. 18.1692 17.9323 MAarrowhead1
% End of user PostScript
.57663 .54909 m
.57797 .5486 L
s
% Start of user PostScript
19. 18. 19.0438 17.9843 MAarrowhead1
% End of user PostScript
.60731 .54909 m
.6066 .54966 L
s
% Start of user PostScript
20. 18. 19.9768 18.0187 MAarrowhead1
% End of user PostScript
.63799 .54909 m
.63836 .55043 L
s
% Start of user PostScript
21. 18. 21.0121 18.0439 MAarrowhead1
% End of user PostScript
.66867 .54909 m
.66867 .54744 L
s
% Start of user PostScript
22. 18. 22. 17.9462 MAarrowhead1
% End of user PostScript
.69935 .54909 m
.6985 .5434 L
s
% Start of user PostScript
23. 18. 22.9722 17.8148 MAarrowhead1
% End of user PostScript
.73003 .54909 m
.73066 .54542 L
s
% Start of user PostScript
24. 18. 24.0204 17.8804 MAarrowhead1
% End of user PostScript
.76071 .54909 m
.76149 .54512 L
s
% Start of user PostScript
25. 18. 25.0254 17.8706 MAarrowhead1
% End of user PostScript
.79139 .54909 m
.79139 .54909 L
s
% Start of user PostScript
26. 18. MAarrowzero1
% End of user PostScript
.82207 .54909 m
.82207 .54909 L
s
% Start of user PostScript
27. 18. MAarrowzero1
% End of user PostScript
.85276 .54909 m
.85276 .54909 L
s
% Start of user PostScript
28. 18. MAarrowzero1
% End of user PostScript
.88344 .54909 m
.88344 .54909 L
s
% Start of user PostScript
29. 18. MAarrowzero1
% End of user PostScript
.91412 .54909 m
.91412 .54909 L
s
% Start of user PostScript
30. 18. MAarrowzero1
% End of user PostScript
.9448 .54909 m
.9448 .54909 L
s
% Start of user PostScript
31. 18. MAarrowzero1
% End of user PostScript
.97548 .54909 m
.97548 .54909 L
s
% Start of user PostScript
32. 18. MAarrowzero1
% End of user PostScript
.02438 .57977 m
.02438 .57977 L
s
% Start of user PostScript
1. 19. MAarrowzero1
% End of user PostScript
.05506 .57977 m
.05506 .57977 L
s
% Start of user PostScript
2. 19. MAarrowzero1
% End of user PostScript
.08574 .57977 m
.08574 .57977 L
s
% Start of user PostScript
3. 19. MAarrowzero1
% End of user PostScript
.11642 .57977 m
.11642 .5792 L
s
% Start of user PostScript
4. 19. 4. 18.9815 MAarrowhead1
% End of user PostScript
.1471 .57977 m
.13861 .5919 L
s
% Start of user PostScript
5. 19. 4.72324 19.3956 MAarrowhead1
% End of user PostScript
.17778 .57977 m
.17987 .58185 L
s
% Start of user PostScript
6. 19. 6.06806 19.0681 MAarrowhead1
% End of user PostScript
.20846 .57977 m
.20783 .57913 L
s
% Start of user PostScript
7. 19. 6.97939 18.9794 MAarrowhead1
% End of user PostScript
.23914 .57977 m
.23903 .57579 L
s
% Start of user PostScript
8. 19. 7.99633 18.8704 MAarrowhead1
% End of user PostScript
.26982 .57977 m
.27567 .5796 L
s
% Start of user PostScript
9. 19. 9.19057 18.9945 MAarrowhead1
% End of user PostScript
.3005 .57977 m
.30408 .57989 L
s
% Start of user PostScript
10. 19. 10.1164 19.0039 MAarrowhead1
% End of user PostScript
.33118 .57977 m
.33231 .57943 L
s
% Start of user PostScript
11. 19. 11.0368 18.989 MAarrowhead1
% End of user PostScript
.36186 .57977 m
.36186 .57977 L
s
% Start of user PostScript
12. 19. MAarrowzero1
% End of user PostScript
.39255 .57977 m
.3926 .58078 L
s
% Start of user PostScript
13. 19. 13.0017 19.0331 MAarrowhead1
% End of user PostScript
.42323 .57977 m
.4241 .57968 L
s
% Start of user PostScript
14. 19. 14.0286 18.9972 MAarrowhead1
% End of user PostScript
.45391 .57977 m
.4545 .57968 L
s
% Start of user PostScript
15. 19. 15.0192 18.9972 MAarrowhead1
% End of user PostScript
.48459 .57977 m
.48997 .58136 L
s
% Start of user PostScript
16. 19. 16.1755 19.052 MAarrowhead1
% End of user PostScript
.51527 .57977 m
.52308 .58249 L
s
% Start of user PostScript
17. 19. 17.2546 19.0888 MAarrowhead1
% End of user PostScript
.54595 .57977 m
.54437 .58013 L
s
% Start of user PostScript
18. 19. 17.9486 19.0117 MAarrowhead1
% End of user PostScript
.57663 .57977 m
.57765 .57875 L
s
% Start of user PostScript
19. 19. 19.0332 18.9668 MAarrowhead1
% End of user PostScript
.60731 .57977 m
.60731 .58234 L
s
% Start of user PostScript
20. 19. 20. 19.084 MAarrowhead1
% End of user PostScript
.63799 .57977 m
.63506 .57983 L
s
% Start of user PostScript
21. 19. 20.9045 19.0021 MAarrowhead1
% End of user PostScript
.66867 .57977 m
.66538 .58188 L
s
% Start of user PostScript
22. 19. 21.8926 19.0688 MAarrowhead1
% End of user PostScript
.69935 .57977 m
.69974 .57823 L
s
% Start of user PostScript
23. 19. 23.0127 18.95 MAarrowhead1
% End of user PostScript
.73003 .57977 m
.73098 .57489 L
s
% Start of user PostScript
24. 19. 24.031 18.8411 MAarrowhead1
% End of user PostScript
.76071 .57977 m
.76386 .56955 L
s
% Start of user PostScript
25. 19. 25.1027 18.667 MAarrowhead1
% End of user PostScript
.79139 .57977 m
.79139 .57977 L
s
% Start of user PostScript
26. 19. MAarrowzero1
% End of user PostScript
.82207 .57977 m
.82207 .57977 L
s
% Start of user PostScript
27. 19. MAarrowzero1
% End of user PostScript
.85276 .57977 m
.85276 .57977 L
s
% Start of user PostScript
28. 19. MAarrowzero1
% End of user PostScript
.88344 .57977 m
.88344 .57977 L
s
% Start of user PostScript
29. 19. MAarrowzero1
% End of user PostScript
.91412 .57977 m
.91383 .58005 L
s
% Start of user PostScript
30. 19. 29.9907 19.0093 MAarrowhead1
% End of user PostScript
.9448 .57977 m
.9448 .57977 L
s
% Start of user PostScript
31. 19. MAarrowzero1
% End of user PostScript
.97548 .57977 m
.97548 .57977 L
s
% Start of user PostScript
32. 19. MAarrowzero1
% End of user PostScript
.02438 .61045 m
.02438 .61045 L
s
% Start of user PostScript
1. 20. MAarrowzero1
% End of user PostScript
.05506 .61045 m
.05506 .61045 L
s
% Start of user PostScript
2. 20. MAarrowzero1
% End of user PostScript
.08574 .61045 m
.08574 .61045 L
s
% Start of user PostScript
3. 20. MAarrowzero1
% End of user PostScript
.11642 .61045 m
.11642 .61045 L
s
% Start of user PostScript
4. 20. MAarrowzero1
% End of user PostScript
.1471 .61045 m
.14676 .61011 L
s
% Start of user PostScript
5. 20. 4.98902 19.989 MAarrowhead1
% End of user PostScript
.17778 .61045 m
.1773 .60997 L
s
% Start of user PostScript
6. 20. 5.98431 19.9843 MAarrowhead1
% End of user PostScript
.20846 .61045 m
.20886 .61016 L
s
% Start of user PostScript
7. 20. 7.01292 19.9905 MAarrowhead1
% End of user PostScript
.23914 .61045 m
.2405 .60761 L
s
% Start of user PostScript
8. 20. 8.0442 19.9076 MAarrowhead1
% End of user PostScript
.26982 .61045 m
.26982 .61034 L
s
% Start of user PostScript
9. 20. 9. 19.9965 MAarrowhead1
% End of user PostScript
.3005 .61045 m
.3005 .61062 L
s
% Start of user PostScript
10. 20. 10. 20.0055 MAarrowhead1
% End of user PostScript
.33118 .61045 m
.33158 .61005 L
s
% Start of user PostScript
11. 20. 11.0129 19.9871 MAarrowhead1
% End of user PostScript
.36186 .61045 m
.36107 .61045 L
s
% Start of user PostScript
12. 20. 11.9742 20. MAarrowhead1
% End of user PostScript
.39255 .61045 m
.39255 .61045 L
s
% Start of user PostScript
13. 20. MAarrowzero1
% End of user PostScript
.42323 .61045 m
.42226 .61045 L
s
% Start of user PostScript
14. 20. 13.9686 20. MAarrowhead1
% End of user PostScript
.45391 .61045 m
.45337 .61042 L
s
% Start of user PostScript
15. 20. 14.9825 19.999 MAarrowhead1
% End of user PostScript
.48459 .61045 m
.48391 .61073 L
s
% Start of user PostScript
16. 20. 15.9779 20.0093 MAarrowhead1
% End of user PostScript
.51527 .61045 m
.51418 .6101 L
s
% Start of user PostScript
17. 20. 16.9645 19.9888 MAarrowhead1
% End of user PostScript
.54595 .61045 m
.54595 .61145 L
s
% Start of user PostScript
18. 20. 18. 20.0325 MAarrowhead1
% End of user PostScript
.57663 .61045 m
.57589 .61194 L
s
% Start of user PostScript
19. 20. 18.976 20.0487 MAarrowhead1
% End of user PostScript
.60731 .61045 m
.6086 .61174 L
s
% Start of user PostScript
20. 20. 20.042 20.042 MAarrowhead1
% End of user PostScript
.63799 .61045 m
.63656 .61317 L
s
% Start of user PostScript
21. 20. 20.9533 20.0887 MAarrowhead1
% End of user PostScript
.66867 .61045 m
.66761 .61258 L
s
% Start of user PostScript
22. 20. 21.9654 20.0694 MAarrowhead1
% End of user PostScript
.69935 .61045 m
.69942 .60926 L
s
% Start of user PostScript
23. 20. 23.0022 19.9614 MAarrowhead1
% End of user PostScript
.73003 .61045 m
.73133 .61254 L
s
% Start of user PostScript
24. 20. 24.0424 20.0683 MAarrowhead1
% End of user PostScript
.76071 .61045 m
.761 .61016 L
s
% Start of user PostScript
25. 20. 25.0093 19.9907 MAarrowhead1
% End of user PostScript
.79139 .61045 m
.79139 .61045 L
s
% Start of user PostScript
26. 20. MAarrowzero1
% End of user PostScript
.82207 .61045 m
.82207 .61045 L
s
% Start of user PostScript
27. 20. MAarrowzero1
% End of user PostScript
.85276 .61045 m
.85276 .61045 L
s
% Start of user PostScript
28. 20. MAarrowzero1
% End of user PostScript
.88344 .61045 m
.88344 .61045 L
s
% Start of user PostScript
29. 20. MAarrowzero1
% End of user PostScript
.91412 .61045 m
.91383 .61016 L
s
% Start of user PostScript
30. 20. 29.9907 19.9907 MAarrowhead1
% End of user PostScript
.9448 .61045 m
.9448 .61045 L
s
% Start of user PostScript
31. 20. MAarrowzero1
% End of user PostScript
.97548 .61045 m
.97548 .61045 L
s
% Start of user PostScript
32. 20. MAarrowzero1
% End of user PostScript
.02438 .64113 m
.02438 .64113 L
s
% Start of user PostScript
1. 21. MAarrowzero1
% End of user PostScript
.05506 .64113 m
.05477 .64141 L
s
% Start of user PostScript
2. 21. 1.99075 21.0093 MAarrowhead1
% End of user PostScript
.08574 .64113 m
.08574 .64113 L
s
% Start of user PostScript
3. 21. MAarrowzero1
% End of user PostScript
.11642 .64113 m
.11642 .64113 L
s
% Start of user PostScript
4. 21. MAarrowzero1
% End of user PostScript
.1471 .64113 m
.15495 .64432 L
s
% Start of user PostScript
5. 21. 5.25578 21.104 MAarrowhead1
% End of user PostScript
.17778 .64113 m
.1762 .64127 L
s
% Start of user PostScript
6. 21. 5.94863 21.0047 MAarrowhead1
% End of user PostScript
.20846 .64113 m
.20927 .64228 L
s
% Start of user PostScript
7. 21. 7.02622 21.0377 MAarrowhead1
% End of user PostScript
.23914 .64113 m
.24009 .64018 L
s
% Start of user PostScript
8. 21. 8.03092 20.9691 MAarrowhead1
% End of user PostScript
.26982 .64113 m
.26982 .64045 L
s
% Start of user PostScript
9. 21. 9. 20.978 MAarrowhead1
% End of user PostScript
.3005 .64113 m
.30042 .64104 L
s
% Start of user PostScript
10. 21. 9.99724 20.9972 MAarrowhead1
% End of user PostScript
.33118 .64113 m
.33127 .64025 L
s
% Start of user PostScript
11. 21. 11.0028 20.9714 MAarrowhead1
% End of user PostScript
.36186 .64113 m
.36138 .64082 L
s
% Start of user PostScript
12. 21. 11.9843 20.9898 MAarrowhead1
% End of user PostScript
.39255 .64113 m
.39206 .64161 L
s
% Start of user PostScript
13. 21. 12.9843 21.0157 MAarrowhead1
% End of user PostScript
.42323 .64113 m
.42331 .64121 L
s
% Start of user PostScript
14. 21. 14.0028 21.0028 MAarrowhead1
% End of user PostScript
.45391 .64113 m
.45391 .64113 L
s
% Start of user PostScript
15. 21. MAarrowzero1
% End of user PostScript
.48459 .64113 m
.48459 .64152 L
s
% Start of user PostScript
16. 21. 16. 21.0129 MAarrowhead1
% End of user PostScript
.51527 .64113 m
.51527 .6398 L
s
% Start of user PostScript
17. 21. 17. 20.9568 MAarrowhead1
% End of user PostScript
.54595 .64113 m
.5459 .64118 L
s
% Start of user PostScript
18. 21. 17.9983 21.0017 MAarrowhead1
% End of user PostScript
.57663 .64113 m
.57714 .64285 L
s
% Start of user PostScript
19. 21. 19.0165 21.0561 MAarrowhead1
% End of user PostScript
.60731 .64113 m
.60665 .64291 L
s
% Start of user PostScript
20. 21. 19.9785 21.058 MAarrowhead1
% End of user PostScript
.63799 .64113 m
.63732 .64216 L
s
% Start of user PostScript
21. 21. 20.9781 21.0337 MAarrowhead1
% End of user PostScript
.66867 .64113 m
.6693 .63875 L
s
% Start of user PostScript
22. 21. 22.0204 20.9224 MAarrowhead1
% End of user PostScript
.69935 .64113 m
.69969 .64061 L
s
% Start of user PostScript
23. 21. 23.011 20.9831 MAarrowhead1
% End of user PostScript
.73003 .64113 m
.73114 .64002 L
s
% Start of user PostScript
24. 21. 24.0362 20.9638 MAarrowhead1
% End of user PostScript
.76071 .64113 m
.76071 .64113 L
s
% Start of user PostScript
25. 21. MAarrowzero1
% End of user PostScript
.79139 .64113 m
.79139 .64113 L
s
% Start of user PostScript
26. 21. MAarrowzero1
% End of user PostScript
.82207 .64113 m
.82207 .64113 L
s
% Start of user PostScript
27. 21. MAarrowzero1
% End of user PostScript
.85276 .64113 m
.85276 .64113 L
s
% Start of user PostScript
28. 21. MAarrowzero1
% End of user PostScript
.88344 .64113 m
.88344 .64113 L
s
% Start of user PostScript
29. 21. MAarrowzero1
% End of user PostScript
.91412 .64113 m
.91412 .64113 L
s
% Start of user PostScript
30. 21. MAarrowzero1
% End of user PostScript
.9448 .64113 m
.9448 .64113 L
s
% Start of user PostScript
31. 21. MAarrowzero1
% End of user PostScript
.97548 .64113 m
.97548 .64113 L
s
% Start of user PostScript
32. 21. MAarrowzero1
% End of user PostScript
.02438 .67181 m
.02438 .67181 L
s
% Start of user PostScript
1. 22. MAarrowzero1
% End of user PostScript
.05506 .67181 m
.05506 .67181 L
s
% Start of user PostScript
2. 22. MAarrowzero1
% End of user PostScript
.08574 .67181 m
.08574 .67181 L
s
% Start of user PostScript
3. 22. MAarrowzero1
% End of user PostScript
.11642 .67181 m
.11642 .67181 L
s
% Start of user PostScript
4. 22. MAarrowzero1
% End of user PostScript
.1471 .67181 m
.14738 .67209 L
s
% Start of user PostScript
5. 22. 5.00925 22.0093 MAarrowhead1
% End of user PostScript
.17778 .67181 m
.17877 .67082 L
s
% Start of user PostScript
6. 22. 6.03218 21.9678 MAarrowhead1
% End of user PostScript
.20846 .67181 m
.20905 .67207 L
s
% Start of user PostScript
7. 22. 7.01925 22.0087 MAarrowhead1
% End of user PostScript
.23914 .67181 m
.23954 .6693 L
s
% Start of user PostScript
8. 22. 8.01282 21.9182 MAarrowhead1
% End of user PostScript
.26982 .67181 m
.27025 .67127 L
s
% Start of user PostScript
9. 22. 9.01396 21.9826 MAarrowhead1
% End of user PostScript
.3005 .67181 m
.3005 .67181 L
s
% Start of user PostScript
10. 22. MAarrowzero1
% End of user PostScript
.33118 .67181 m
.33158 .67141 L
s
% Start of user PostScript
11. 22. 11.0129 21.9871 MAarrowhead1
% End of user PostScript
.36186 .67181 m
.36186 .67181 L
s
% Start of user PostScript
12. 22. MAarrowzero1
% End of user PostScript
.39255 .67181 m
.39255 .67181 L
s
% Start of user PostScript
13. 22. MAarrowzero1
% End of user PostScript
.42323 .67181 m
.42323 .67181 L
s
% Start of user PostScript
14. 22. MAarrowzero1
% End of user PostScript
.45391 .67181 m
.45357 .67215 L
s
% Start of user PostScript
15. 22. 14.989 22.011 MAarrowhead1
% End of user PostScript
.48459 .67181 m
.48419 .67238 L
s
% Start of user PostScript
16. 22. 15.9871 22.0185 MAarrowhead1
% End of user PostScript
.51527 .67181 m
.51527 .67284 L
s
% Start of user PostScript
17. 22. 17. 22.0337 MAarrowhead1
% End of user PostScript
.54595 .67181 m
.54566 .67252 L
s
% Start of user PostScript
18. 22. 17.9907 22.0233 MAarrowhead1
% End of user PostScript
.57663 .67181 m
.57662 .67287 L
s
% Start of user PostScript
19. 22. 18.9996 22.0345 MAarrowhead1
% End of user PostScript
.60731 .67181 m
.60672 .67301 L
s
% Start of user PostScript
20. 22. 19.9808 22.0392 MAarrowhead1
% End of user PostScript
.63799 .67181 m
.63833 .67215 L
s
% Start of user PostScript
21. 22. 21.011 22.011 MAarrowhead1
% End of user PostScript
.66867 .67181 m
.66756 .67292 L
s
% Start of user PostScript
22. 22. 21.9639 22.0361 MAarrowhead1
% End of user PostScript
.69935 .67181 m
.69819 .67365 L
s
% Start of user PostScript
23. 22. 22.962 22.06 MAarrowhead1
% End of user PostScript
.73003 .67181 m
.73168 .6691 L
s
% Start of user PostScript
24. 22. 24.0536 21.9116 MAarrowhead1
% End of user PostScript
.76071 .67181 m
.76071 .67181 L
s
% Start of user PostScript
25. 22. MAarrowzero1
% End of user PostScript
.79139 .67181 m
.79139 .67181 L
s
% Start of user PostScript
26. 22. MAarrowzero1
% End of user PostScript
.82207 .67181 m
.82207 .67181 L
s
% Start of user PostScript
27. 22. MAarrowzero1
% End of user PostScript
.85276 .67181 m
.85276 .67181 L
s
% Start of user PostScript
28. 22. MAarrowzero1
% End of user PostScript
.88344 .67181 m
.88344 .67181 L
s
% Start of user PostScript
29. 22. MAarrowzero1
% End of user PostScript
.91412 .67181 m
.91412 .67181 L
s
% Start of user PostScript
30. 22. MAarrowzero1
% End of user PostScript
.9448 .67181 m
.9448 .67181 L
s
% Start of user PostScript
31. 22. MAarrowzero1
% End of user PostScript
.97548 .67181 m
.97548 .67181 L
s
% Start of user PostScript
32. 22. MAarrowzero1
% End of user PostScript
.02438 .70249 m
.02438 .70249 L
s
% Start of user PostScript
1. 23. MAarrowzero1
% End of user PostScript
.05506 .70249 m
.05506 .70249 L
s
% Start of user PostScript
2. 23. MAarrowzero1
% End of user PostScript
.08574 .70249 m
.08574 .70249 L
s
% Start of user PostScript
3. 23. MAarrowzero1
% End of user PostScript
.11642 .70249 m
.11642 .70249 L
s
% Start of user PostScript
4. 23. MAarrowzero1
% End of user PostScript
.1471 .70249 m
.1471 .70249 L
s
% Start of user PostScript
5. 23. MAarrowzero1
% End of user PostScript
.17778 .70249 m
.18042 .71067 L
s
% Start of user PostScript
6. 23. 6.0861 23.2668 MAarrowhead1
% End of user PostScript
.20846 .70249 m
.2103 .70347 L
s
% Start of user PostScript
7. 23. 7.05988 23.032 MAarrowhead1
% End of user PostScript
.23914 .70249 m
.23891 .70036 L
s
% Start of user PostScript
8. 23. 7.99253 22.9307 MAarrowhead1
% End of user PostScript
.26982 .70249 m
.27039 .70163 L
s
% Start of user PostScript
9. 23. 9.01863 22.972 MAarrowhead1
% End of user PostScript
.3005 .70249 m
.3009 .70249 L
s
% Start of user PostScript
10. 23. 10.0129 23. MAarrowhead1
% End of user PostScript
.33118 .70249 m
.33076 .70206 L
s
% Start of user PostScript
11. 23. 10.986 22.986 MAarrowhead1
% End of user PostScript
.36186 .70249 m
.36186 .70249 L
s
% Start of user PostScript
12. 23. MAarrowzero1
% End of user PostScript
.39255 .70249 m
.39235 .70297 L
s
% Start of user PostScript
13. 23. 12.9937 23.0157 MAarrowhead1
% End of user PostScript
.42323 .70249 m
.42274 .70201 L
s
% Start of user PostScript
14. 23. 13.9843 22.9843 MAarrowhead1
% End of user PostScript
.45391 .70249 m
.45391 .70249 L
s
% Start of user PostScript
15. 23. MAarrowzero1
% End of user PostScript
.48459 .70249 m
.48459 .70249 L
s
% Start of user PostScript
16. 23. MAarrowzero1
% End of user PostScript
.51527 .70249 m
.5155 .70311 L
s
% Start of user PostScript
17. 23. 17.0075 23.0204 MAarrowhead1
% End of user PostScript
.54595 .70249 m
.54561 .70272 L
s
% Start of user PostScript
18. 23. 17.9889 23.0077 MAarrowhead1
% End of user PostScript
.57663 .70249 m
.57538 .7051 L
s
% Start of user PostScript
19. 23. 18.9593 23.0852 MAarrowhead1
% End of user PostScript
.60731 .70249 m
.60765 .70404 L
s
% Start of user PostScript
20. 23. 20.011 23.0506 MAarrowhead1
% End of user PostScript
.63799 .70249 m
.64036 .70698 L
s
% Start of user PostScript
21. 23. 21.0772 23.1464 MAarrowhead1
% End of user PostScript
.66867 .70249 m
.67017 .69537 L
s
% Start of user PostScript
22. 23. 22.0489 22.768 MAarrowhead1
% End of user PostScript
.69935 .70249 m
.70098 .69829 L
s
% Start of user PostScript
23. 23. 23.0529 22.8631 MAarrowhead1
% End of user PostScript
.73003 .70249 m
.73003 .70306 L
s
% Start of user PostScript
24. 23. 24. 23.0185 MAarrowhead1
% End of user PostScript
.76071 .70249 m
.76071 .70249 L
s
% Start of user PostScript
25. 23. MAarrowzero1
% End of user PostScript
.79139 .70249 m
.79139 .70249 L
s
% Start of user PostScript
26. 23. MAarrowzero1
% End of user PostScript
.82207 .70249 m
.82207 .70249 L
s
% Start of user PostScript
27. 23. MAarrowzero1
% End of user PostScript
.85276 .70249 m
.85276 .70249 L
s
% Start of user PostScript
28. 23. MAarrowzero1
% End of user PostScript
.88344 .70249 m
.88344 .70249 L
s
% Start of user PostScript
29. 23. MAarrowzero1
% End of user PostScript
.91412 .70249 m
.91412 .70249 L
s
% Start of user PostScript
30. 23. MAarrowzero1
% End of user PostScript
.9448 .70249 m
.9448 .70249 L
s
% Start of user PostScript
31. 23. MAarrowzero1
% End of user PostScript
.97548 .70249 m
.97548 .70249 L
s
% Start of user PostScript
32. 23. MAarrowzero1
% End of user PostScript
.02438 .73317 m
.02438 .73317 L
s
% Start of user PostScript
1. 24. MAarrowzero1
% End of user PostScript
.05506 .73317 m
.05506 .73317 L
s
% Start of user PostScript
2. 24. MAarrowzero1
% End of user PostScript
.08574 .73317 m
.08574 .73317 L
s
% Start of user PostScript
3. 24. MAarrowzero1
% End of user PostScript
.11642 .73317 m
.11642 .73317 L
s
% Start of user PostScript
4. 24. MAarrowzero1
% End of user PostScript
.1471 .73317 m
.1471 .73317 L
s
% Start of user PostScript
5. 24. MAarrowzero1
% End of user PostScript
.17778 .73317 m
.17912 .73451 L
s
% Start of user PostScript
6. 24. 6.04373 24.0437 MAarrowhead1
% End of user PostScript
.20846 .73317 m
.20853 .73059 L
s
% Start of user PostScript
7. 24. 7.00235 23.916 MAarrowhead1
% End of user PostScript
.23914 .73317 m
.23721 .73199 L
s
% Start of user PostScript
8. 24. 7.93712 23.9614 MAarrowhead1
% End of user PostScript
.26982 .73317 m
.27011 .73345 L
s
% Start of user PostScript
9. 24. 9.00925 24.0093 MAarrowhead1
% End of user PostScript
.3005 .73317 m
.2997 .73226 L
s
% Start of user PostScript
10. 24. 9.97369 23.9702 MAarrowhead1
% End of user PostScript
.33118 .73317 m
.3307 .73365 L
s
% Start of user PostScript
11. 24. 10.9843 24.0157 MAarrowhead1
% End of user PostScript
.36186 .73317 m
.36078 .73322 L
s
% Start of user PostScript
12. 24. 11.9646 24.0017 MAarrowhead1
% End of user PostScript
.39255 .73317 m
.39021 .73355 L
s
% Start of user PostScript
13. 24. 12.9237 24.0124 MAarrowhead1
% End of user PostScript
.42323 .73317 m
.42145 .73355 L
s
% Start of user PostScript
14. 24. 13.9422 24.0124 MAarrowhead1
% End of user PostScript
.45391 .73317 m
.45195 .73297 L
s
% Start of user PostScript
15. 24. 14.9363 23.9936 MAarrowhead1
% End of user PostScript
.48459 .73317 m
.48242 .73351 L
s
% Start of user PostScript
16. 24. 15.9292 24.0113 MAarrowhead1
% End of user PostScript
.51527 .73317 m
.51296 .73365 L
s
% Start of user PostScript
17. 24. 16.9248 24.0157 MAarrowhead1
% End of user PostScript
.54595 .73317 m
.54479 .73433 L
s
% Start of user PostScript
18. 24. 17.9621 24.0379 MAarrowhead1
% End of user PostScript
.57663 .73317 m
.57372 .73441 L
s
% Start of user PostScript
19. 24. 18.9051 24.0404 MAarrowhead1
% End of user PostScript
.60731 .73317 m
.60822 .73208 L
s
% Start of user PostScript
20. 24. 20.0295 23.9645 MAarrowhead1
% End of user PostScript
.63799 .73317 m
.64075 .73342 L
s
% Start of user PostScript
21. 24. 21.0898 24.0082 MAarrowhead1
% End of user PostScript
.66867 .73317 m
.66946 .73059 L
s
% Start of user PostScript
22. 24. 22.0258 23.9158 MAarrowhead1
% End of user PostScript
.69935 .73317 m
.70211 .7308 L
s
% Start of user PostScript
23. 24. 23.0898 23.9229 MAarrowhead1
% End of user PostScript
.73003 .73317 m
.73003 .73317 L
s
% Start of user PostScript
24. 24. MAarrowzero1
% End of user PostScript
.76071 .73317 m
.76071 .73317 L
s
% Start of user PostScript
25. 24. MAarrowzero1
% End of user PostScript
.79139 .73317 m
.79139 .73317 L
s
% Start of user PostScript
26. 24. MAarrowzero1
% End of user PostScript
.82207 .73317 m
.82207 .73317 L
s
% Start of user PostScript
27. 24. MAarrowzero1
% End of user PostScript
.85276 .73317 m
.85304 .73289 L
s
% Start of user PostScript
28. 24. 28.0093 23.9907 MAarrowhead1
% End of user PostScript
.88344 .73317 m
.88344 .73317 L
s
% Start of user PostScript
29. 24. MAarrowzero1
% End of user PostScript
.91412 .73317 m
.91412 .73317 L
s
% Start of user PostScript
30. 24. MAarrowzero1
% End of user PostScript
.9448 .73317 m
.9448 .73317 L
s
% Start of user PostScript
31. 24. MAarrowzero1
% End of user PostScript
.97548 .73317 m
.97548 .73317 L
s
% Start of user PostScript
32. 24. MAarrowzero1
% End of user PostScript
.02438 .76385 m
.02438 .76385 L
s
% Start of user PostScript
1. 25. MAarrowzero1
% End of user PostScript
.05506 .76385 m
.05506 .76385 L
s
% Start of user PostScript
2. 25. MAarrowzero1
% End of user PostScript
.08574 .76385 m
.08602 .76357 L
s
% Start of user PostScript
3. 25. 3.00925 24.9907 MAarrowhead1
% End of user PostScript
.11642 .76385 m
.11642 .76385 L
s
% Start of user PostScript
4. 25. MAarrowzero1
% End of user PostScript
.1471 .76385 m
.1471 .76385 L
s
% Start of user PostScript
5. 25. MAarrowzero1
% End of user PostScript
.17778 .76385 m
.17778 .76385 L
s
% Start of user PostScript
6. 25. MAarrowzero1
% End of user PostScript
.20846 .76385 m
.21504 .76947 L
s
% Start of user PostScript
7. 25. 7.21445 25.1831 MAarrowhead1
% End of user PostScript
.23914 .76385 m
.23745 .76324 L
s
% Start of user PostScript
8. 25. 7.94471 24.98 MAarrowhead1
% End of user PostScript
.26982 .76385 m
.26764 .76167 L
s
% Start of user PostScript
9. 25. 8.92886 24.9289 MAarrowhead1
% End of user PostScript
.3005 .76385 m
.29904 .76414 L
s
% Start of user PostScript
10. 25. 9.9522 25.0094 MAarrowhead1
% End of user PostScript
.33118 .76385 m
.32991 .7639 L
s
% Start of user PostScript
11. 25. 10.9586 25.0017 MAarrowhead1
% End of user PostScript
.36186 .76385 m
.35976 .76372 L
s
% Start of user PostScript
12. 25. 11.9315 24.9959 MAarrowhead1
% End of user PostScript
.39255 .76385 m
.39122 .76517 L
s
% Start of user PostScript
13. 25. 12.9568 25.0432 MAarrowhead1
% End of user PostScript
.42323 .76385 m
.42262 .76446 L
s
% Start of user PostScript
14. 25. 13.9802 25.0198 MAarrowhead1
% End of user PostScript
.45391 .76385 m
.45276 .76366 L
s
% Start of user PostScript
15. 25. 14.9625 24.9939 MAarrowhead1
% End of user PostScript
.48459 .76385 m
.48548 .76463 L
s
% Start of user PostScript
16. 25. 16.0292 25.0253 MAarrowhead1
% End of user PostScript
.51527 .76385 m
.51349 .76451 L
s
% Start of user PostScript
17. 25. 16.942 25.0215 MAarrowhead1
% End of user PostScript
.54595 .76385 m
.54488 .76617 L
s
% Start of user PostScript
18. 25. 17.9651 25.0757 MAarrowhead1
% End of user PostScript
.57663 .76385 m
.57238 .76442 L
s
% Start of user PostScript
19. 25. 18.8613 25.0187 MAarrowhead1
% End of user PostScript
.60731 .76385 m
.60511 .76319 L
s
% Start of user PostScript
20. 25. 19.9282 24.9784 MAarrowhead1
% End of user PostScript
.63799 .76385 m
.6413 .76134 L
s
% Start of user PostScript
21. 25. 21.1079 24.918 MAarrowhead1
% End of user PostScript
.66867 .76385 m
.6674 .76319 L
s
% Start of user PostScript
22. 25. 21.9587 24.9785 MAarrowhead1
% End of user PostScript
.69935 .76385 m
.69935 .76385 L
s
% Start of user PostScript
23. 25. MAarrowzero1
% End of user PostScript
.73003 .76385 m
.72955 .76433 L
s
% Start of user PostScript
24. 25. 23.9843 25.0157 MAarrowhead1
% End of user PostScript
.76071 .76385 m
.76071 .76385 L
s
% Start of user PostScript
25. 25. MAarrowzero1
% End of user PostScript
.79139 .76385 m
.79139 .76385 L
s
% Start of user PostScript
26. 25. MAarrowzero1
% End of user PostScript
.82207 .76385 m
.82207 .76385 L
s
% Start of user PostScript
27. 25. MAarrowzero1
% End of user PostScript
.85276 .76385 m
.85276 .76385 L
s
% Start of user PostScript
28. 25. MAarrowzero1
% End of user PostScript
.88344 .76385 m
.88344 .76385 L
s
% Start of user PostScript
29. 25. MAarrowzero1
% End of user PostScript
.91412 .76385 m
.91412 .76385 L
s
% Start of user PostScript
30. 25. MAarrowzero1
% End of user PostScript
.9448 .76385 m
.9448 .76385 L
s
% Start of user PostScript
31. 25. MAarrowzero1
% End of user PostScript
.97548 .76385 m
.97548 .76385 L
s
% Start of user PostScript
32. 25. MAarrowzero1
% End of user PostScript
.02438 .79453 m
.02438 .79453 L
s
% Start of user PostScript
1. 26. MAarrowzero1
% End of user PostScript
.05506 .79453 m
.05506 .79453 L
s
% Start of user PostScript
2. 26. MAarrowzero1
% End of user PostScript
.08574 .79453 m
.08574 .79453 L
s
% Start of user PostScript
3. 26. MAarrowzero1
% End of user PostScript
.11642 .79453 m
.11642 .79453 L
s
% Start of user PostScript
4. 26. MAarrowzero1
% End of user PostScript
.1471 .79453 m
.1471 .79453 L
s
% Start of user PostScript
5. 26. MAarrowzero1
% End of user PostScript
.17778 .79453 m
.17778 .79453 L
s
% Start of user PostScript
6. 26. MAarrowzero1
% End of user PostScript
.20846 .79453 m
.20846 .79453 L
s
% Start of user PostScript
7. 26. MAarrowzero1
% End of user PostScript
.23914 .79453 m
.24824 .79937 L
s
% Start of user PostScript
8. 26. 8.29659 26.1578 MAarrowhead1
% End of user PostScript
.26982 .79453 m
.27172 .79342 L
s
% Start of user PostScript
9. 26. 9.06192 25.9639 MAarrowhead1
% End of user PostScript
.3005 .79453 m
.30157 .7954 L
s
% Start of user PostScript
10. 26. 10.0349 26.0283 MAarrowhead1
% End of user PostScript
.33118 .79453 m
.32933 .79342 L
s
% Start of user PostScript
11. 26. 10.9396 25.9639 MAarrowhead1
% End of user PostScript
.36186 .79453 m
.36137 .7924 L
s
% Start of user PostScript
12. 26. 11.9839 25.9306 MAarrowhead1
% End of user PostScript
.39255 .79453 m
.3909 .79618 L
s
% Start of user PostScript
13. 26. 12.9463 26.0537 MAarrowhead1
% End of user PostScript
.42323 .79453 m
.42348 .79546 L
s
% Start of user PostScript
14. 26. 14.0083 26.0302 MAarrowhead1
% End of user PostScript
.45391 .79453 m
.45433 .7911 L
s
% Start of user PostScript
15. 26. 15.0137 25.8882 MAarrowhead1
% End of user PostScript
.48459 .79453 m
.48405 .79507 L
s
% Start of user PostScript
16. 26. 15.9826 26.0174 MAarrowhead1
% End of user PostScript
.51527 .79453 m
.51313 .79538 L
s
% Start of user PostScript
17. 26. 16.9302 26.0278 MAarrowhead1
% End of user PostScript
.54595 .79453 m
.54381 .79435 L
s
% Start of user PostScript
18. 26. 17.9302 25.9941 MAarrowhead1
% End of user PostScript
.57663 .79453 m
.57703 .7931 L
s
% Start of user PostScript
19. 26. 19.0129 25.9534 MAarrowhead1
% End of user PostScript
.60731 .79453 m
.61288 .79204 L
s
% Start of user PostScript
20. 26. 20.1815 25.9188 MAarrowhead1
% End of user PostScript
.63799 .79453 m
.63804 .79623 L
s
% Start of user PostScript
21. 26. 21.0015 26.0553 MAarrowhead1
% End of user PostScript
.66867 .79453 m
.67453 .78867 L
s
% Start of user PostScript
22. 26. 22.1911 25.8089 MAarrowhead1
% End of user PostScript
.69935 .79453 m
.69935 .79453 L
s
% Start of user PostScript
23. 26. MAarrowzero1
% End of user PostScript
.73003 .79453 m
.73032 .79481 L
s
% Start of user PostScript
24. 26. 24.0093 26.0093 MAarrowhead1
% End of user PostScript
.76071 .79453 m
.76023 .79501 L
s
% Start of user PostScript
25. 26. 24.9843 26.0157 MAarrowhead1
% End of user PostScript
.79139 .79453 m
.79091 .79405 L
s
% Start of user PostScript
26. 26. 25.9843 25.9843 MAarrowhead1
% End of user PostScript
.82207 .79453 m
.82207 .79453 L
s
% Start of user PostScript
27. 26. MAarrowzero1
% End of user PostScript
.85276 .79453 m
.85276 .79453 L
s
% Start of user PostScript
28. 26. MAarrowzero1
% End of user PostScript
.88344 .79453 m
.88344 .79453 L
s
% Start of user PostScript
29. 26. MAarrowzero1
% End of user PostScript
.91412 .79453 m
.91412 .79453 L
s
% Start of user PostScript
30. 26. MAarrowzero1
% End of user PostScript
.9448 .79453 m
.9448 .79453 L
s
% Start of user PostScript
31. 26. MAarrowzero1
% End of user PostScript
.97548 .79453 m
.97548 .79453 L
s
% Start of user PostScript
32. 26. MAarrowzero1
% End of user PostScript
.02438 .82521 m
.02438 .82521 L
s
% Start of user PostScript
1. 27. MAarrowzero1
% End of user PostScript
.05506 .82521 m
.05506 .82521 L
s
% Start of user PostScript
2. 27. MAarrowzero1
% End of user PostScript
.08574 .82521 m
.08574 .82521 L
s
% Start of user PostScript
3. 27. MAarrowzero1
% End of user PostScript
.11642 .82521 m
.11642 .82521 L
s
% Start of user PostScript
4. 27. MAarrowzero1
% End of user PostScript
.1471 .82521 m
.1471 .82521 L
s
% Start of user PostScript
5. 27. MAarrowzero1
% End of user PostScript
.17778 .82521 m
.17778 .82521 L
s
% Start of user PostScript
6. 27. MAarrowzero1
% End of user PostScript
.20846 .82521 m
.20846 .82521 L
s
% Start of user PostScript
7. 27. MAarrowzero1
% End of user PostScript
.23914 .82521 m
.23914 .82521 L
s
% Start of user PostScript
8. 27. MAarrowzero1
% End of user PostScript
.26982 .82521 m
.27292 .8291 L
s
% Start of user PostScript
9. 27. 9.1009 27.1267 MAarrowhead1
% End of user PostScript
.3005 .82521 m
.30039 .82443 L
s
% Start of user PostScript
10. 27. 9.99633 26.9744 MAarrowhead1
% End of user PostScript
.33118 .82521 m
.33021 .82424 L
s
% Start of user PostScript
11. 27. 10.9684 26.9684 MAarrowhead1
% End of user PostScript
.36186 .82521 m
.36422 .82485 L
s
% Start of user PostScript
12. 27. 12.0768 26.9882 MAarrowhead1
% End of user PostScript
.39255 .82521 m
.3926 .82412 L
s
% Start of user PostScript
13. 27. 13.0018 26.9645 MAarrowhead1
% End of user PostScript
.42323 .82521 m
.42389 .82283 L
s
% Start of user PostScript
14. 27. 14.0215 26.9224 MAarrowhead1
% End of user PostScript
.45391 .82521 m
.45578 .82464 L
s
% Start of user PostScript
15. 27. 15.061 26.9814 MAarrowhead1
% End of user PostScript
.48459 .82521 m
.48562 .82526 L
s
% Start of user PostScript
16. 27. 16.0335 27.0017 MAarrowhead1
% End of user PostScript
.51527 .82521 m
.51933 .82512 L
s
% Start of user PostScript
17. 27. 17.1324 26.997 MAarrowhead1
% End of user PostScript
.54595 .82521 m
.54854 .82383 L
s
% Start of user PostScript
18. 27. 18.0845 26.9551 MAarrowhead1
% End of user PostScript
.57663 .82521 m
.57116 .82672 L
s
% Start of user PostScript
19. 27. 18.8216 27.049 MAarrowhead1
% End of user PostScript
.60731 .82521 m
.60642 .82574 L
s
% Start of user PostScript
20. 27. 19.971 27.0172 MAarrowhead1
% End of user PostScript
.63799 .82521 m
.64639 .81967 L
s
% Start of user PostScript
21. 27. 21.2736 26.8193 MAarrowhead1
% End of user PostScript
.66867 .82521 m
.66819 .82473 L
s
% Start of user PostScript
22. 27. 21.9843 26.9843 MAarrowhead1
% End of user PostScript
.69935 .82521 m
.69964 .8255 L
s
% Start of user PostScript
23. 27. 23.0093 27.0093 MAarrowhead1
% End of user PostScript
.73003 .82521 m
.73032 .82493 L
s
% Start of user PostScript
24. 27. 24.0093 26.9907 MAarrowhead1
% End of user PostScript
.76071 .82521 m
.76071 .82521 L
s
% Start of user PostScript
25. 27. MAarrowzero1
% End of user PostScript
.79139 .82521 m
.79139 .82521 L
s
% Start of user PostScript
26. 27. MAarrowzero1
% End of user PostScript
.82207 .82521 m
.82207 .82521 L
s
% Start of user PostScript
27. 27. MAarrowzero1
% End of user PostScript
.85276 .82521 m
.85276 .82521 L
s
% Start of user PostScript
28. 27. MAarrowzero1
% End of user PostScript
.88344 .82521 m
.88344 .82521 L
s
% Start of user PostScript
29. 27. MAarrowzero1
% End of user PostScript
.91412 .82521 m
.91412 .82521 L
s
% Start of user PostScript
30. 27. MAarrowzero1
% End of user PostScript
.9448 .82521 m
.9448 .82521 L
s
% Start of user PostScript
31. 27. MAarrowzero1
% End of user PostScript
.97548 .82521 m
.97548 .82521 L
s
% Start of user PostScript
32. 27. MAarrowzero1
% End of user PostScript
.02438 .85589 m
.02438 .85589 L
s
% Start of user PostScript
1. 28. MAarrowzero1
% End of user PostScript
.05506 .85589 m
.05506 .85589 L
s
% Start of user PostScript
2. 28. MAarrowzero1
% End of user PostScript
.08574 .85589 m
.08574 .85589 L
s
% Start of user PostScript
3. 28. MAarrowzero1
% End of user PostScript
.11642 .85589 m
.11642 .85589 L
s
% Start of user PostScript
4. 28. MAarrowzero1
% End of user PostScript
.1471 .85589 m
.1471 .85589 L
s
% Start of user PostScript
5. 28. MAarrowzero1
% End of user PostScript
.17778 .85589 m
.17826 .85541 L
s
% Start of user PostScript
6. 28. 6.01569 27.9843 MAarrowhead1
% End of user PostScript
.20846 .85589 m
.20846 .85589 L
s
% Start of user PostScript
7. 28. MAarrowzero1
% End of user PostScript
.23914 .85589 m
.23914 .85589 L
s
% Start of user PostScript
8. 28. MAarrowzero1
% End of user PostScript
.26982 .85589 m
.26982 .85589 L
s
% Start of user PostScript
9. 28. MAarrowzero1
% End of user PostScript
.3005 .85589 m
.31455 .85868 L
s
% Start of user PostScript
10. 28. 10.4579 28.091 MAarrowhead1
% End of user PostScript
.33118 .85589 m
.32773 .85333 L
s
% Start of user PostScript
11. 28. 10.8873 27.9164 MAarrowhead1
% End of user PostScript
.36186 .85589 m
.36516 .85746 L
s
% Start of user PostScript
12. 28. 12.1073 28.0512 MAarrowhead1
% End of user PostScript
.39255 .85589 m
.39499 .853 L
s
% Start of user PostScript
13. 28. 13.0796 27.9059 MAarrowhead1
% End of user PostScript
.42323 .85589 m
.42115 .85699 L
s
% Start of user PostScript
14. 28. 13.9324 28.0358 MAarrowhead1
% End of user PostScript
.45391 .85589 m
.45532 .8556 L
s
% Start of user PostScript
15. 28. 15.046 27.9904 MAarrowhead1
% End of user PostScript
.48459 .85589 m
.48127 .85361 L
s
% Start of user PostScript
16. 28. 15.8918 27.9255 MAarrowhead1
% End of user PostScript
.51527 .85589 m
.51328 .86032 L
s
% Start of user PostScript
17. 28. 16.9353 28.1442 MAarrowhead1
% End of user PostScript
.54595 .85589 m
.54629 .85623 L
s
% Start of user PostScript
18. 28. 18.011 28.011 MAarrowhead1
% End of user PostScript
.57663 .85589 m
.5789 .85617 L
s
% Start of user PostScript
19. 28. 19.0741 28.0091 MAarrowhead1
% End of user PostScript
.60731 .85589 m
.61369 .84855 L
s
% Start of user PostScript
20. 28. 20.2079 27.7607 MAarrowhead1
% End of user PostScript
.63799 .85589 m
.63751 .85637 L
s
% Start of user PostScript
21. 28. 20.9843 28.0157 MAarrowhead1
% End of user PostScript
.66867 .85589 m
.66867 .85589 L
s
% Start of user PostScript
22. 28. MAarrowzero1
% End of user PostScript
.69935 .85589 m
.69907 .85561 L
s
% Start of user PostScript
23. 28. 22.9907 27.9907 MAarrowhead1
% End of user PostScript
.73003 .85589 m
.73003 .85589 L
s
% Start of user PostScript
24. 28. MAarrowzero1
% End of user PostScript
.76071 .85589 m
.761 .85618 L
s
% Start of user PostScript
25. 28. 25.0093 28.0093 MAarrowhead1
% End of user PostScript
.79139 .85589 m
.79168 .85561 L
s
% Start of user PostScript
26. 28. 26.0093 27.9907 MAarrowhead1
% End of user PostScript
.82207 .85589 m
.82207 .85589 L
s
% Start of user PostScript
27. 28. MAarrowzero1
% End of user PostScript
.85276 .85589 m
.85276 .85589 L
s
% Start of user PostScript
28. 28. MAarrowzero1
% End of user PostScript
.88344 .85589 m
.88344 .85589 L
s
% Start of user PostScript
29. 28. MAarrowzero1
% End of user PostScript
.91412 .85589 m
.91383 .85561 L
s
% Start of user PostScript
30. 28. 29.9907 27.9907 MAarrowhead1
% End of user PostScript
.9448 .85589 m
.9448 .85589 L
s
% Start of user PostScript
31. 28. MAarrowzero1
% End of user PostScript
.97548 .85589 m
.97548 .85589 L
s
% Start of user PostScript
32. 28. MAarrowzero1
% End of user PostScript
.02438 .88657 m
.02438 .88657 L
s
% Start of user PostScript
1. 29. MAarrowzero1
% End of user PostScript
.05506 .88657 m
.05506 .88657 L
s
% Start of user PostScript
2. 29. MAarrowzero1
% End of user PostScript
.08574 .88657 m
.08574 .88657 L
s
% Start of user PostScript
3. 29. MAarrowzero1
% End of user PostScript
.11642 .88657 m
.11642 .88657 L
s
% Start of user PostScript
4. 29. MAarrowzero1
% End of user PostScript
.1471 .88657 m
.1471 .88657 L
s
% Start of user PostScript
5. 29. MAarrowzero1
% End of user PostScript
.17778 .88657 m
.1773 .88705 L
s
% Start of user PostScript
6. 29. 5.98431 29.0157 MAarrowhead1
% End of user PostScript
.20846 .88657 m
.20846 .88657 L
s
% Start of user PostScript
7. 29. MAarrowzero1
% End of user PostScript
.23914 .88657 m
.23914 .88657 L
s
% Start of user PostScript
8. 29. MAarrowzero1
% End of user PostScript
.26982 .88657 m
.26982 .88657 L
s
% Start of user PostScript
9. 29. MAarrowzero1
% End of user PostScript
.3005 .88657 m
.3005 .88657 L
s
% Start of user PostScript
10. 29. MAarrowzero1
% End of user PostScript
.33118 .88657 m
.33167 .88609 L
s
% Start of user PostScript
11. 29. 11.0157 28.9843 MAarrowhead1
% End of user PostScript
.36186 .88657 m
.37221 .88705 L
s
% Start of user PostScript
12. 29. 12.3372 29.0157 MAarrowhead1
% End of user PostScript
.39255 .88657 m
.38983 .88647 L
s
% Start of user PostScript
13. 29. 12.9114 28.9965 MAarrowhead1
% End of user PostScript
.42323 .88657 m
.42296 .88574 L
s
% Start of user PostScript
14. 29. 13.9913 28.9727 MAarrowhead1
% End of user PostScript
.45391 .88657 m
.46013 .88837 L
s
% Start of user PostScript
15. 29. 15.2027 29.0585 MAarrowhead1
% End of user PostScript
.48459 .88657 m
.48654 .88574 L
s
% Start of user PostScript
16. 29. 16.0637 28.9728 MAarrowhead1
% End of user PostScript
.51527 .88657 m
.51226 .88579 L
s
% Start of user PostScript
17. 29. 16.9021 28.9745 MAarrowhead1
% End of user PostScript
.54595 .88657 m
.54991 .88425 L
s
% Start of user PostScript
18. 29. 18.1291 28.9242 MAarrowhead1
% End of user PostScript
.57663 .88657 m
.57586 .88677 L
s
% Start of user PostScript
19. 29. 18.9751 29.0064 MAarrowhead1
% End of user PostScript
.60731 .88657 m
.60683 .88705 L
s
% Start of user PostScript
20. 29. 19.9843 29.0157 MAarrowhead1
% End of user PostScript
.63799 .88657 m
.63771 .88629 L
s
% Start of user PostScript
21. 29. 20.9907 28.9907 MAarrowhead1
% End of user PostScript
.66867 .88657 m
.66867 .88657 L
s
% Start of user PostScript
22. 29. MAarrowzero1
% End of user PostScript
.69935 .88657 m
.69964 .88686 L
s
% Start of user PostScript
23. 29. 23.0093 29.0093 MAarrowhead1
% End of user PostScript
.73003 .88657 m
.73003 .88657 L
s
% Start of user PostScript
24. 29. MAarrowzero1
% End of user PostScript
.76071 .88657 m
.76023 .88609 L
s
% Start of user PostScript
25. 29. 24.9843 28.9843 MAarrowhead1
% End of user PostScript
.79139 .88657 m
.79043 .88657 L
s
% Start of user PostScript
26. 29. 25.9686 29. MAarrowhead1
% End of user PostScript
.82207 .88657 m
.82256 .88609 L
s
% Start of user PostScript
27. 29. 27.0157 28.9843 MAarrowhead1
% End of user PostScript
.85276 .88657 m
.85227 .88609 L
s
% Start of user PostScript
28. 29. 27.9843 28.9843 MAarrowhead1
% End of user PostScript
.88344 .88657 m
.88267 .88581 L
s
% Start of user PostScript
29. 29. 28.9751 28.9751 MAarrowhead1
% End of user PostScript
.91412 .88657 m
.91335 .88734 L
s
% Start of user PostScript
30. 29. 29.9751 29.0249 MAarrowhead1
% End of user PostScript
.9448 .88657 m
.9448 .88657 L
s
% Start of user PostScript
31. 29. MAarrowzero1
% End of user PostScript
.97548 .88657 m
.97548 .88657 L
s
% Start of user PostScript
32. 29. MAarrowzero1
% End of user PostScript
.02438 .91725 m
.02438 .91725 L
s
% Start of user PostScript
1. 30. MAarrowzero1
% End of user PostScript
.05506 .91725 m
.05506 .91725 L
s
% Start of user PostScript
2. 30. MAarrowzero1
% End of user PostScript
.08574 .91725 m
.08574 .91725 L
s
% Start of user PostScript
3. 30. MAarrowzero1
% End of user PostScript
.11642 .91725 m
.11642 .91725 L
s
% Start of user PostScript
4. 30. MAarrowzero1
% End of user PostScript
.1471 .91725 m
.1471 .91725 L
s
% Start of user PostScript
5. 30. MAarrowzero1
% End of user PostScript
.17778 .91725 m
.17778 .91725 L
s
% Start of user PostScript
6. 30. MAarrowzero1
% End of user PostScript
.20846 .91725 m
.20846 .91725 L
s
% Start of user PostScript
7. 30. MAarrowzero1
% End of user PostScript
.23914 .91725 m
.23914 .91725 L
s
% Start of user PostScript
8. 30. MAarrowzero1
% End of user PostScript
.26982 .91725 m
.26982 .91725 L
s
% Start of user PostScript
9. 30. MAarrowzero1
% End of user PostScript
.3005 .91725 m
.3005 .91725 L
s
% Start of user PostScript
10. 30. MAarrowzero1
% End of user PostScript
.33118 .91725 m
.33243 .91754 L
s
% Start of user PostScript
11. 30. 11.0406 30.0093 MAarrowhead1
% End of user PostScript
.36186 .91725 m
.36158 .91754 L
s
% Start of user PostScript
12. 30. 11.9907 30.0093 MAarrowhead1
% End of user PostScript
.39255 .91725 m
.39331 .91745 L
s
% Start of user PostScript
13. 30. 13.0249 30.0064 MAarrowhead1
% End of user PostScript
.42323 .91725 m
.42399 .91745 L
s
% Start of user PostScript
14. 30. 14.0249 30.0064 MAarrowhead1
% End of user PostScript
.45391 .91725 m
.45391 .91725 L
s
% Start of user PostScript
15. 30. MAarrowzero1
% End of user PostScript
.48459 .91725 m
.48459 .91725 L
s
% Start of user PostScript
16. 30. MAarrowzero1
% End of user PostScript
.51527 .91725 m
.51527 .91725 L
s
% Start of user PostScript
17. 30. MAarrowzero1
% End of user PostScript
.54595 .91725 m
.54595 .91725 L
s
% Start of user PostScript
18. 30. MAarrowzero1
% End of user PostScript
.57663 .91725 m
.57711 .91773 L
s
% Start of user PostScript
19. 30. 19.0157 30.0157 MAarrowhead1
% End of user PostScript
.60731 .91725 m
.60654 .91745 L
s
% Start of user PostScript
20. 30. 19.9751 30.0064 MAarrowhead1
% End of user PostScript
.63799 .91725 m
.63847 .91677 L
s
% Start of user PostScript
21. 30. 21.0157 29.9843 MAarrowhead1
% End of user PostScript
.66867 .91725 m
.66867 .91725 L
s
% Start of user PostScript
22. 30. MAarrowzero1
% End of user PostScript
.69935 .91725 m
.69887 .91677 L
s
% Start of user PostScript
23. 30. 22.9843 29.9843 MAarrowhead1
% End of user PostScript
.73003 .91725 m
.73032 .91754 L
s
% Start of user PostScript
24. 30. 24.0093 30.0093 MAarrowhead1
% End of user PostScript
.76071 .91725 m
.76091 .91802 L
s
% Start of user PostScript
25. 30. 25.0064 30.0249 MAarrowhead1
% End of user PostScript
.79139 .91725 m
.79139 .91725 L
s
% Start of user PostScript
26. 30. MAarrowzero1
% End of user PostScript
.82207 .91725 m
.82256 .91677 L
s
% Start of user PostScript
27. 30. 27.0157 29.9843 MAarrowhead1
% End of user PostScript
.85276 .91725 m
.85199 .91649 L
s
% Start of user PostScript
28. 30. 27.9751 29.9751 MAarrowhead1
% End of user PostScript
.88344 .91725 m
.88372 .91754 L
s
% Start of user PostScript
29. 30. 29.0093 30.0093 MAarrowhead1
% End of user PostScript
.91412 .91725 m
.91412 .91822 L
s
% Start of user PostScript
30. 30. 30. 30.0314 MAarrowhead1
% End of user PostScript
.9448 .91725 m
.9448 .91725 L
s
% Start of user PostScript
31. 30. MAarrowzero1
% End of user PostScript
.97548 .91725 m
.975 .91677 L
s
% Start of user PostScript
32. 30. 31.9843 29.9843 MAarrowhead1
% End of user PostScript
.02438 .94793 m
.02438 .94793 L
s
% Start of user PostScript
1. 31. MAarrowzero1
% End of user PostScript
.05506 .94793 m
.05506 .94793 L
s
% Start of user PostScript
2. 31. MAarrowzero1
% End of user PostScript
.08574 .94793 m
.08574 .94793 L
s
% Start of user PostScript
3. 31. MAarrowzero1
% End of user PostScript
.11642 .94793 m
.11642 .94793 L
s
% Start of user PostScript
4. 31. MAarrowzero1
% End of user PostScript
.1471 .94793 m
.1471 .94793 L
s
% Start of user PostScript
5. 31. MAarrowzero1
% End of user PostScript
.17778 .94793 m
.1773 .94745 L
s
% Start of user PostScript
6. 31. 5.98431 30.9843 MAarrowhead1
% End of user PostScript
.20846 .94793 m
.20846 .94793 L
s
% Start of user PostScript
7. 31. MAarrowzero1
% End of user PostScript
.23914 .94793 m
.23914 .94793 L
s
% Start of user PostScript
8. 31. MAarrowzero1
% End of user PostScript
.26982 .94793 m
.26982 .94793 L
s
% Start of user PostScript
9. 31. MAarrowzero1
% End of user PostScript
.3005 .94793 m
.30098 .94842 L
s
% Start of user PostScript
10. 31. 10.0157 31.0157 MAarrowhead1
% End of user PostScript
.33118 .94793 m
.3309 .94822 L
s
% Start of user PostScript
11. 31. 10.9907 31.0093 MAarrowhead1
% End of user PostScript
.36186 .94793 m
.36186 .94793 L
s
% Start of user PostScript
12. 31. MAarrowzero1
% End of user PostScript
.39255 .94793 m
.39303 .94842 L
s
% Start of user PostScript
13. 31. 13.0157 31.0157 MAarrowhead1
% End of user PostScript
.42323 .94793 m
.42303 .94717 L
s
% Start of user PostScript
14. 31. 13.9936 30.9751 MAarrowhead1
% End of user PostScript
.45391 .94793 m
.45362 .94669 L
s
% Start of user PostScript
15. 31. 14.9907 30.9594 MAarrowhead1
% End of user PostScript
.48459 .94793 m
.48459 .94793 L
s
% Start of user PostScript
16. 31. MAarrowzero1
% End of user PostScript
.51527 .94793 m
.51479 .94842 L
s
% Start of user PostScript
17. 31. 16.9843 31.0157 MAarrowhead1
% End of user PostScript
.54595 .94793 m
.54566 .94822 L
s
% Start of user PostScript
18. 31. 17.9907 31.0093 MAarrowhead1
% End of user PostScript
.57663 .94793 m
.57663 .94697 L
s
% Start of user PostScript
19. 31. 19. 30.9686 MAarrowhead1
% End of user PostScript
.60731 .94793 m
.60703 .94822 L
s
% Start of user PostScript
20. 31. 19.9907 31.0093 MAarrowhead1
% End of user PostScript
.63799 .94793 m
.63799 .9489 L
s
% Start of user PostScript
21. 31. 21. 31.0314 MAarrowhead1
% End of user PostScript
.66867 .94793 m
.66839 .94765 L
s
% Start of user PostScript
22. 31. 21.9907 30.9907 MAarrowhead1
% End of user PostScript
.69935 .94793 m
.69935 .94793 L
s
% Start of user PostScript
23. 31. MAarrowzero1
% End of user PostScript
.73003 .94793 m
.7308 .94717 L
s
% Start of user PostScript
24. 31. 24.0249 30.9751 MAarrowhead1
% End of user PostScript
.76071 .94793 m
.76071 .94793 L
s
% Start of user PostScript
25. 31. MAarrowzero1
% End of user PostScript
.79139 .94793 m
.79139 .94793 L
s
% Start of user PostScript
26. 31. MAarrowzero1
% End of user PostScript
.82207 .94793 m
.82207 .9489 L
s
% Start of user PostScript
27. 31. 27. 31.0314 MAarrowhead1
% End of user PostScript
.85276 .94793 m
.85304 .94765 L
s
% Start of user PostScript
28. 31. 28.0093 30.9907 MAarrowhead1
% End of user PostScript
.88344 .94793 m
.88392 .94842 L
s
% Start of user PostScript
29. 31. 29.0157 31.0157 MAarrowhead1
% End of user PostScript
.91412 .94793 m
.91364 .94745 L
s
% Start of user PostScript
30. 31. 29.9843 30.9843 MAarrowhead1
% End of user PostScript
.9448 .94793 m
.9448 .94793 L
s
% Start of user PostScript
31. 31. MAarrowzero1
% End of user PostScript
.97548 .94793 m
.97519 .94822 L
s
% Start of user PostScript
32. 31. 31.9907 31.0093 MAarrowhead1
% End of user PostScript
.02438 .97862 m
.02438 .97862 L
s
% Start of user PostScript
1. 32. MAarrowzero1
% End of user PostScript
.05506 .97862 m
.05506 .97862 L
s
% Start of user PostScript
2. 32. MAarrowzero1
% End of user PostScript
.08574 .97862 m
.08574 .97862 L
s
% Start of user PostScript
3. 32. MAarrowzero1
% End of user PostScript
.11642 .97862 m
.11642 .97862 L
s
% Start of user PostScript
4. 32. MAarrowzero1
% End of user PostScript
.1471 .97862 m
.1471 .97862 L
s
% Start of user PostScript
5. 32. MAarrowzero1
% End of user PostScript
.17778 .97862 m
.1773 .97813 L
s
% Start of user PostScript
6. 32. 5.98431 31.9843 MAarrowhead1
% End of user PostScript
.20846 .97862 m
.20875 .97833 L
s
% Start of user PostScript
7. 32. 7.00925 31.9907 MAarrowhead1
% End of user PostScript
.23914 .97862 m
.23914 .97862 L
s
% Start of user PostScript
8. 32. MAarrowzero1
% End of user PostScript
.26982 .97862 m
.26934 .9791 L
s
% Start of user PostScript
9. 32. 8.98431 32.0157 MAarrowhead1
% End of user PostScript
.3005 .97862 m
.30022 .9789 L
s
% Start of user PostScript
10. 32. 9.99075 32.0093 MAarrowhead1
% End of user PostScript
.33118 .97862 m
.33147 .9789 L
s
% Start of user PostScript
11. 32. 11.0093 32.0093 MAarrowhead1
% End of user PostScript
.36186 .97862 m
.36235 .9791 L
s
% Start of user PostScript
12. 32. 12.0157 32.0157 MAarrowhead1
% End of user PostScript
.39255 .97862 m
.39255 .97862 L
s
% Start of user PostScript
13. 32. MAarrowzero1
% End of user PostScript
.42323 .97862 m
.42323 .97862 L
s
% Start of user PostScript
14. 32. MAarrowzero1
% End of user PostScript
.45391 .97862 m
.45439 .97813 L
s
% Start of user PostScript
15. 32. 15.0157 31.9843 MAarrowhead1
% End of user PostScript
.48459 .97862 m
.48459 .97862 L
s
% Start of user PostScript
16. 32. MAarrowzero1
% End of user PostScript
.51527 .97862 m
.51603 .97785 L
s
% Start of user PostScript
17. 32. 17.0249 31.9751 MAarrowhead1
% End of user PostScript
.54595 .97862 m
.54595 .97862 L
s
% Start of user PostScript
18. 32. MAarrowzero1
% End of user PostScript
.57663 .97862 m
.57663 .97862 L
s
% Start of user PostScript
19. 32. MAarrowzero1
% End of user PostScript
.60731 .97862 m
.60731 .97862 L
s
% Start of user PostScript
20. 32. MAarrowzero1
% End of user PostScript
.63799 .97862 m
.63847 .9791 L
s
% Start of user PostScript
21. 32. 21.0157 32.0157 MAarrowhead1
% End of user PostScript
.66867 .97862 m
.66896 .9789 L
s
% Start of user PostScript
22. 32. 22.0093 32.0093 MAarrowhead1
% End of user PostScript
.69935 .97862 m
.69935 .97862 L
s
% Start of user PostScript
23. 32. MAarrowzero1
% End of user PostScript
.73003 .97862 m
.73051 .9791 L
s
% Start of user PostScript
24. 32. 24.0157 32.0157 MAarrowhead1
% End of user PostScript
.76071 .97862 m
.761 .9789 L
s
% Start of user PostScript
25. 32. 25.0093 32.0093 MAarrowhead1
% End of user PostScript
.79139 .97862 m
.79139 .97862 L
s
% Start of user PostScript
26. 32. MAarrowzero1
% End of user PostScript
.82207 .97862 m
.82207 .97862 L
s
% Start of user PostScript
27. 32. MAarrowzero1
% End of user PostScript
.85276 .97862 m
.85276 .97862 L
s
% Start of user PostScript
28. 32. MAarrowzero1
% End of user PostScript
.88344 .97862 m
.88344 .97805 L
s
% Start of user PostScript
29. 32. 29. 31.9815 MAarrowhead1
% End of user PostScript
.91412 .97862 m
.9146 .97813 L
s
% Start of user PostScript
30. 32. 30.0157 31.9843 MAarrowhead1
% End of user PostScript
.9448 .97862 m
.94499 .97938 L
s
% Start of user PostScript
31. 32. 31.0064 32.0249 MAarrowhead1
% End of user PostScript
.97548 .97862 m
.97548 .97862 L
s
% Start of user PostScript
32. 32. MAarrowzero1
% End of user PostScript
0 0 m
1 0 L
1 1.00327 L
0 1.00327 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[15]:=",
  ImageSize->{400, 191.625},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0000_b000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00k03oool0
0d00000000000?ooo`0M0?ooo`03@00000000000oooo0840oooo000a0?ooo`03@00000000000oooo
00P0oooo00=000000000003oool02P3oool00d00000000000000000F0?ooo`05@000003oool0oooo
@00000000000=`3oool00d00000000000?ooo`040?ooo`03@00000000000000000H0oooo00<00000
0?ooo`3oool0;03oool00`000000oooo0?ooo`0<0?ooo`8000001`3oool01@000000oooo0?ooo`3o
ool000000180oooo0P00000`0?ooo`030000003oool0oooo02D0oooo00=000000?ooo`3oool09`3o
ool00380oooo00<000000?ooo`3oool01`3oool2000000/0oooo0`00000:0?ooo`03@000003oool0
oooo00T0oooo0P0000000`3oool000000000000g0?ooo`<00000103oool3000000D0oooo00=00000
000000000000;03oool00d00000000000?ooo`0;0?ooo`03000004000000000000H0oooo00D00000
@00000000000oooo@0000002000000L0oooo00<00000@000003oool02@3oool00`000000oooo0?oo
o`0<0?ooo`03000004000000oooo0080oooo0P0000020?ooo`8000000`3oool2000000L0oooo0P00
00080?ooo`03@00000000000000001d0oooo00<00000@000003oool01@3oool3000002P0oooo000U
0?ooo`03@000003oool0oooo0080oooo00@000000?ooo`3oool0oooo0`0000001400000000000000
003oool4000000<0oooo00<000000?ooo`3oool00P3oool200000080oooo0P0000030?ooo`030000
003oool0oooo0080oooo00A000000?ooo`3oool0oooo1P0000030?ooo`03@000003oool0oooo0080
oooo0P0000030?ooo`050000003oool0oooo0?oood000000103oool00`000000oooo0?ooo`020?oo
o`050000003oool0oooo0?ooo`000000103oool01D000000oooo0?ooo`3ooom0000000@0oooo00=0
00000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo00@000000?ooo`3oool0
oooo0`0000000d000000oooo0000000200000080oooo00E000000?ooo`3oool0oooo000000040?oo
o`030000003oool0oooo008000000`3oool300000003@000003oool0oooo0240oooo00=000000?oo
o`3oool00P0000040?ooo`030000003oool0oooo0080oooo1@0000040?ooo`H000000P3oool20000
00@0oooo100000000d000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00D000000?oo
o`3oool0oooo@00000040?ooo`040000003oool0oooo0?ooo`@0000000<0oooo@000003oool02000
00000`3oool0000000000002000000<0oooo00=000000?ooo`0000000`0000040?ooo`03@000003o
ool0oooo00800000103oool010000000oooo0?ooo`3oool2000000<0oooo00<000000?ooo`3oool0
0P3oool01@000000oooo0?ooo`3oool0000000@0oooo100000000`3oool000000?ooo`020?ooo`80
00000`3oool00`000000oooo0?ooo`0T0?ooo`00:03oool2000000H0oooo0P0000001@3oool00000
0?oood000000000000D0oooo00<000000?ooo`3oool00`0000020?ooo`800000103oool00`000000
oooo0?ooo`060?ooo`80000000=000000000003oool02@3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool00000
0100oooo0`0000040?ooo`8000000P3oool00`000000oooo0?ooo`030?ooo`80000000<0oooo0000
003oool01`3oool00`000000oooo0?ooo`020?ooo`8000000`3oool010000000oooo0?ooo`3oool3
000002/0oooo0P0000060?ooo`8000001`3oool2000000030?ooo`000000oooo00T0oooo0P000005
0?ooo`030000003oool0oooo00/0oooo0P0000040?ooo`8000000`3oool01T00000000000?ooo`3o
oom00000000000<0oooo00=000000000003oool01P3oool00d00000000000?ooo`0:0?ooo`040000
003oool0000000000080oooo0`0000040?ooo`030000003oool0oooo0080oooo00D000000?ooo`3o
ool0oooo000000060?ooo`<000002@3oool00`000000oooo0?ooo`0T0?ooo`009`3oool3000000P0
oooo00=000000000000000002`3oool00d000000oooo0?ooo`03000001H0oooo00=000000000003o
ool01P3oool00d00000000000?ooo`060?ooo`0300000400000000000080oooo0P0000020?ooo`<0
00000`3oool00`000000oooo0?ooo`050?ooo`03@0000000000000000080oooo00=000000?ooo`3o
ool00`3oool200000003@00000000000000000`0oooo00<000000?ooo`3oool0203oool00`000010
00000?ooo`070?ooo`030000003oool0oooo02D0oooo00=000000000003oool00P00000H0?ooo`06
@000003oool0oooo0?oood00000000000P3oool00d00000000000?ooo`020?ooo`800000103oool0
0d000000oooo0?ooo`040?ooo`04@000000000000000@00000D0oooo00=00000000000000000203o
ool00d000000oooo0?ooo`0;0?ooo`03@000003oool0oooo00H0oooo00Y000000000000000100000
0000003ooom000000?oood00000000000P3oool300000080oooo0P0000030?ooo`800000103oool0
1400000000000000000000080?ooo`8000009P3oool002P0oooo00=000000?ooo`3oool01`3oool3
000000l0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo00<0oooo0P0000070?ooo`8000000P3oool00`000000oooo0?ooo`020?ooo`<0000000@0oooo
00000000001000000P3oool2000000=000000P0000020?ooo`030000003oool0oooo0080oooo0`00
00000`3oool000000?ooo`060?ooo`040000003oool00000@00000X0oooo00=00000000000000000
0`3oool00`000000oooo0?ooo`020?ooo`03@0000000000000000340oooo0P0000000d0000000000
0000000<0?ooo`050000003oool0oooo0?ooo`0000001`3oool200000080oooo0`0000000`3oool0
0000000000030?ooo`03000004000000oooo0080oooo0`0000050?ooo`<000001@3oool014000000
00000000000000080?ooo`8000002@3oool00d000000oooo0?ooo`02000000L0oooo0P0000000d00
00000000000000030?ooo`8000000P3oool200000005@000003oool0oooo0000040000000`3oool0
0`0000100000@00000030?ooo`<000002@3oool00`00001000000?ooo`0U0?ooo`009`3oool20000
00<0oooo0P0000050?ooo`030000003oool0oooo00d0oooo00E00000000000000000oooo@0000002
00000080oooo0P0000070?ooo`03@00000000000000000@0oooo00@000000?ooo`00000000001P3o
ool010000000oooo@000000000050?ooo`80000000=000000000000000001@3oool5000000030?oo
od000000000000D0oooo00<000000?oood0000000P00000E0?ooo`<0000000<0oooo@00000000000
103oool2000000D0oooo00<00000@000003oool00P3oool00`00001000000?ooo`0U0?ooo`030000
003oool0oooo008000001`3oool01@00001000000?ooo`3ooom00000008000000P3oool00d000000
0000000000040?ooo`8000000`3oool200000080oooo00<000000?ooo`3oool01`3oool2000000@0
oooo00@00000@000003oool00000103oool3000000030?ooo`000000oooo00L0oooo0P0000080?oo
o`<0000000<0oooo0000000000001@3oool01000001000000000000000030?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool02`3oool3000000040?ooo`0000000000000000<0oooo00<0
0000@000003oool0;03oool002D0oooo00=000000?ooo`0000000`0000000`3oool0000000000002
000000<0oooo00<000000?ooo`3oool00P3oool01D000000oooo0?ooo`3oool0000000@0oooo00@0
00000?ooo`3oool0oooo0P0000020?ooo`80000000<0oooo0000000000000P0000030?ooo`040000
003oool0oooo0?ooo`8000000`3oool00`000000oooo00000003000000@0oooo00<000000?ooo`3o
ool00P0000040?ooo`040000003oool0oooo0?ooo`8000000`3oool2000000<0oooo00<000000?oo
o`3oool00P0000040?ooo`040000003oool0oooo0?ooo`L000000`3oool01D000000oooo0?ooo`3o
oom0000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`02000000@0oooo00@0
00000?ooo`3oool0oooo100000000`3oool000000000000200000280oooo00E000000?ooo`3oool0
oooo000000040?ooo`030000003oool0oooo0080oooo1000000014000000oooo0?ooo`3oool20000
00<0oooo0P0000030?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo00000003
0?ooo`8000000`3oool00`00001000000?ooo`020?ooo`@0000000<0oooo0000003oool00P3oool2
000000<0oooo00@000000?ooo`3oool0oooo0`0000000d000000oooo000000040?ooo`<0000000=0
00000000000000000P0000000`3oool000000?ooo`030?ooo`D00000103oool00`000000oooo0?oo
o`020?ooo`050000003oool0oooo0?oood0000000`3oool2000000<0oooo0P0000030?ooo`040000
003oool0oooo0?ooo`@0000000<0oooo0000003oool00`3oool00`000000oooo0?ooo`0T0?ooo`00
9`3oool00d00000000000?ooo`020?ooo`03@00000000000oooo00d0oooo00@000000?ooo`3oool0
oooo0P00000:0?ooo`03@00000000000oooo00D0oooo0P0000080?ooo`03@00000000000oooo02`0
oooo00=000000000003oool03@3oool3000000/0oooo00<000000?ooo`3oool0203oool200000380
oooo0P00000I0?ooo`<000002`3oool200000100oooo0P0000070?ooo`<00000303oool200000100
oooo0`00000B0?ooo`8000000`3oool00`000000oooo0?ooo`0T0?ooo`00>`3oool200000080oooo
0P00000?0?ooo`04@000003oool0oooo0?ooo`80000000A000000?ooo`3ooom000006P3oool00d00
0000oooo0?ooo`050?ooo`03@00000000000oooo01@0oooo00=000000000003oool0203oool00d00
00000000@000000l0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool01P3oool00d00
000000000?ooo`060?ooo`03@000003ooom00000008000003P3oool00`000000oooo0?ooo`0C0?oo
o`030000003oool0oooo0080oooo00=000000000003oool0203oool00d00000000000?ooo`0>0?oo
o`03@000003oool0oooo0140oooo00=000000000040000001000000U0?ooo`00>`3oool00`000010
00000?ooo`020?ooo`03@000003oool0oooo00`0oooo0`0000030?ooo`040000003oool0oooo0?oo
o`8000006@3oool2000000H0oooo0P00000E0?ooo`8000002@3oool2000000d0oooo00=000000?oo
o`3oool0;03oool00d00000000000?ooo`0D0?ooo`03@00000000000000000P0oooo00<000000?oo
o`3oool01`3oool2000000h0oooo00=000000000003oool0603oool00`0000100000000000090?oo
o`8000002P3oool00`000000oooo0?ooo`0F0?ooo`80000000E000000000000000000000@000000U
0?ooo`00<03oool00`00001000000?ooo`020?ooo`03000004000000oooo00H0oooo00<00000@000
003oool01P3oool00`00001000000?ooo`050?ooo`<000001P3oool2000000T0oooo00<00000@000
003oool03@3oool2000000P0oooo00<000000?ooo`3oool0203oool2000000X0oooo00<000000?oo
o`3oool00P3oool010000000oooo0?ooo`3oool2000000d0oooo0`00000X0?ooo`@000000P3oool2
000000@0oooo0`0000000d000000oooo000000030?ooo`<0000000=000000?ooo`0000000P000000
0d0000000000000000030?ooo`040000003oool0oooo0?ooo`8000000`3oool2000000<0oooo0P00
00020?ooo`8000000`3oool00d000000oooo0?ooo`020?ooo`D00000103oool00d000000oooo0?oo
o`020?ooo`04@000003oool0oooo0?ooo`H000000`3oool6000000@0oooo00E000000?ooo`3oool0
oooo000000040?ooo`04@000003oool0oooo0?ooo`H00000103oool200000080oooo00<000000?oo
o`3oool00P3oool014000000oooo0?ooo`3oool2000000<0oooo00@000000?ooo`3oool0oooo0P00
000V0?ooo`009@3oool010000000oooo0?ooo`3oool2000000<0oooo100000000`3oool000000000
0002000000030?oood000000oooo0080oooo1P0000030?ooo`H000000`3oool200000004@0000000
00000000000000@0oooo00D000000?ooo`3oool0oooo@00000040?ooo`H000000`3oool00d000000
oooo0?ooo`020?ooo`04@000003oool0oooo0?ooo`8000000`3oool00`000000oooo0?ooo`020?oo
o`050000003oool0oooo0?ooo`000000103oool00d000000oooo@0000003000000<0oooo00=00000
0?ooo`3oool00P3oool010000000oooo0?ooo`3oool2000000<0oooo00@000000?ooo`3oool0oooo
0`00000014000000oooo0000000000030?ooo`80000000A0000000000000000000000P3oool20000
0280oooo00=000000000003oool02`3oool2000000030?ooo`000000oooo00@0oooo0P0000030?oo
o`8000001@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo0P0000000d00
0000oooo000000040?ooo`8000002@3oool200000100oooo00=000000000003oool02@3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo00P0oooo00<00000@000000000000P0000040?oo
o`04000004000000oooo000000P0oooo0P0000030?ooo`030000003oool0oooo02T0oooo000U0?oo
o`030000003oool0000000800000103oool00`000000oooo0?ooo`0=0?ooo`<000001`3oool20000
01T0oooo0`00000=0?ooo`05@00000000000oooo0?oood0000000P0000050?ooo`<00000203oool0
0d00000000000?ooo`0;0?ooo`8000002@3oool200000080oooo0P0000000d000000oooo0?ooo`05
0?ooo`<00000:P3oool00d00000000000?ooo`040?ooo`04@000003oool0000000000100oooo0`00
00070?ooo`@000001P3oool200000003@000003oool0oooo0080oooo00<000000?ooo`3oool01`3o
ool00d00000000000000000b0?ooo`80000000<0oooo000000000000203oool00`000000oooo0?oo
o`0]0?ooo`00903oool3000000030?oood000000oooo0080oooo00=000000000000000003`3oool2
@00000P0oooo00=000000?ooo`3oool06@3oool00d000000oooo0?ooo`020?ooo`030000003oool0
oooo00L0oooo0P0000020?ooo`<000001P3oool014000000oooo0?oood0000030?ooo`03@000003o
ool0oooo008000000P3oool01D00000000000?ooo`3oool0000000@0oooo0P0000000d000000oooo
0?ooo`030?ooo`03@000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00d000000oooo
0?ooo`0Y0?ooo`800000103oool2000000030?ooo`000010000000l0oooo0`00000014000000oooo
0?oood000002000000050?oood00000000000?ooo`000000203oool00`000000oooo0?ooo`020?oo
o`<00000203oool3000002T0oooo00=000000?ooo`3oool01`3oool010000000oooo000004000008
0?ooo`03000004000000oooo02d0oooo000T0?ooo`80000000=000000?ooo`3oool0103oool30000
00d0oooo0`0000080?ooo`8000002P3oool00d000000oooo0?ooo`030?ooo`03@000003oool0oooo
00/0oooo00=000000000003oool02@3oool00`000000oooo0?ooo`0200000003@000003oool0oooo
00H0oooo0`000000103oool000000000000000020?ooo`030000003oool0oooo0080000000@0oooo
@0000000000000002P3oool2000003h0oooo00<000000?ooo`3oool00`3oool300000100oooo00A0
000000000000000000000`3oool300000080oooo00D000000?ooo`3oool0oooo0000000;0?ooo`03
@00000000000000000T0oooo00<000000?ooo`3oool0203oool00`00001000000?ooo`020?ooo`03
000004000000oooo00l0oooo00H00000@000003oool0oooo0000040000020?ooo`<00000A03oool0
02D0oooo00=000000?ooo`0000000`0000030?ooo`8000000`3oool00d000000oooo0?ooo`020?oo
o`04@000003oool0oooo0?ooo`8000000`3oool00d000000oooo00000003000000030?ooo`000000
000000H000000`3oool300000080oooo1@0000040?ooo`030000003oool0oooo0080oooo00=00000
0?ooo`3oool00P0000040?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo0000
00040?ooo`<0000000=000000000000000000`3oool00`000000oooo0?ooo`020?ooo`050000003o
ool0oooo0?ooo`0000000P3oool3000000<0oooo0P0000030?ooo`@0000000<0oooo@000003oool0
0P3oool300000003@00000000000000000<0oooo0`0000000d000000oooo0000000U0?ooo`05@000
003oool0oooo0?ooo`000000103oool2000000<0oooo00E000000?ooo`3oool0oooo@00000040?oo
o`040000003oool0oooo0?ooo`8000000P3oool2000000@0oooo00D000000?ooo`3oool0oooo0000
00030?ooo`<000000P3oool2000000<0oooo00@000000?ooo`3oool0oooo0P0000030?ooo`03@000
003oool0oooo0080oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`3oool400000003
0?ooo`000000000000<00000103oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo0?oo
o`/000000`3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?oood000000103oool0
10000000oooo0?ooo`3oool2000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`0T0?ooo`009`3oool00d00000000000?ooo`0I0?ooo`03@00000000000oooo0080oooo00A00000
0000003oool0oooo0`0000030?ooo`8000002@3oool5000000d0oooo0P00000>0?ooo`8000003P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo0P0000000d000000oooo0?oo
o`0:0?ooo`80000000<0oooo000000000000103oool2000000040?ooo`0000000000000003X0oooo
0P0000000`3oool00000000000090?ooo`030000003oool0oooo00H0oooo0P00000014000000oooo
0000000000020?ooo`800000403oool2000000H0oooo0P0000030?ooo`<00000103oool2000000<0
oooo0P0000040?ooo`8000002@3oool2000000@0oooo00<000000?ooo`3oool01P3oool00`000000
oooo00000002000000<0oooo0P0000020?ooo`8000009`3oool002P0oooo00<000000?ooo`3oool0
303oool00d00000000000?ooo`050?ooo`030000003oool0oooo00L0oooo00A00000000000000010
0000403oool4000000<0oooo00<000000?ooo`3oool02@3oool01000001000000?ooo`0000080?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool0303oool01@000000oooo0?ooo`3ooom0
000000800000403oool200000003@000003oool0oooo00D0oooo0P0000000d000000oooo0?ooo`0h
0?ooo`@000003P3oool01T00000000000?ooo`3ooom00000000000<0oooo00@00000@00000000000
00002`3oool00d000000oooo0?ooo`020?ooo`<000003@3oool2000000@0oooo00<00000@000003o
ool00P3oool00`00001000000?ooo`020?ooo`04@000003oool0oooo@00000H0oooo00<00000@000
003oool0103oool00`00001000000?ooo`050?ooo`<0000000<0oooo@000003oool00`3oool20000
00040?ooo`0000000000000002L0oooo000W0?ooo`03@00000000000000000d0oooo0P0000050?oo
o`03@00000000000000000P0oooo1000000A0?ooo`80000000A000000?ooo`3ooom000000P00000:
0?ooo`040000003ooom00000000000L0oooo00=000000000003oool01P3oool00d00000000000?oo
o`020?ooo`030000003oool0oooo00H0oooo00=000000000000000000`3oool200000180oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`0j0?ooo`030000003ooom0000000l0oooo00@0
00000?ooo`3oool0oooo0P0000030?ooo`040000003oool0oooo@00000X0oooo0`0000040?ooo`03
@000003oool0oooo00D0oooo00=000000?ooo`3oool0103oool00`00001000000?ooo`030?ooo`03
0000003oool0oooo0080oooo00@00000@000003oool0oooo0`0000000`3oool000000000000<0?oo
o`030000003oool0oooo00D0oooo0P0000000d000000oooo0?ooo`050?ooo`04@000003oool0oooo
@00002P0oooo000X0?ooo`8000003P3oool00`000000oooo0?ooo`030?ooo`<000002@3oool00`00
0000oooo0000000200000080oooo0P00000A0?ooo`8000003@3oool2000000L0oooo0P0000050?oo
o`0600000400000000000000003ooom000000P0000020?ooo`800000103oool2000000<0oooo00<0
00000?ooo`3oool06`3oool00`00001000000?ooo`0N0?ooo`8000005@3oool00`00001000000?oo
o`060?ooo`03000004000000oooo00L0oooo00@00000@0000000000000000`3oool00`000000oooo
0?ooo`0@0?ooo`800000303oool3000000L0oooo00<00000@000003oool01@3oool300000080oooo
0P0000020?ooo`800000103oool00`00001000000?ooo`020?ooo`03000004000000oooo00D0oooo
00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo02d0oooo000U0?ooo`030000
003oool0oooo0080oooo00D000000?ooo`3oool0oooo@00000040?ooo`030000003oool0oooo0080
oooo00@000000?ooo`3oool0oooo100000000`3oool000000?ooo`020?ooo`03@000003oool0oooo
0080oooo00<000000?oood0000000`0000000`3ooom0000000000002000000<0oooo00E000000?oo
o`3oool0oooo@00000040?ooo`8000000`3oool01@000000oooo0?ooo`3ooom0000000@0oooo00=0
00000?ooo`3oool00P3oool01@000000oooo0?ooo`3ooom0000000@0oooo00@000000?ooo`3oool0
oooo100000000`3oool000000?ooo`020?ooo`80000000<0oooo@000000000000P0000030?ooo`05
0000003oool0oooo0?ooo`000000103oool200000080oooo0P0000030?ooo`8000000`3oool20000
0080oooo00<000000?ooo`3oool00P3oool4000001l0oooo00A0000000000000000000000`3oool0
0d000000oooo0?ooo`020?ooo`03@000003oool0000000<000000`3oool4000000030?ooo`000000
oooo0080oooo100000000`3ooom000000?ooo`030?ooo`D00000103oool00`000000oooo0?ooo`02
0?ooo`05@000003oool0oooo0?oood0000000`3oool2000000<0oooo00<000000?ooo`3oool00P3o
ool00d000000oooo0?ooo`020?ooo`040000003oool0oooo0?ooo`8000000`3oool014000000oooo
0?ooo`3oool4000000030?ooo`000000oooo0080oooo0P0000030?ooo`030000003oool0oooo0080
oooo00@000000?ooo`3oool0oooo100000000`3oool000000000000400000080oooo0P0000030?oo
o`8000000P3oool300000080oooo0P0000040?ooo`030000003oool0oooo02@0oooo000U0?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool0203oool200000280oooo0P0000000d000000
oooo0?ooo`0L0?ooo`800000603oool300000005@000003oool000000000040000000P3oool20000
0006@000003oool0oooo000004000000oooo0P0000050?ooo`800000;@3oool3000000T0oooo00H0
00000?ooo`3oool0oooo@000000000020?ooo`03@00000000000000001L0oooo0`00000>0?ooo`03
0000003oool0oooo00l0oooo00<000000?ooo`3oool05P3oool300000080oooo0`0000030?ooo`03
0000003oool0oooo00<0000000@0oooo00000000000000001@3oool00`000000oooo0?ooo`0T0?oo
o`00903oool3000000/0oooo0`00000D0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3o
ool0103oool3000000@0oooo00<000000?ooo`3oool02`3oool01T00000000000000003ooom00000
000000L0oooo00<000000?ooo`3oool05`3oool2000000<0oooo00<000000?ooo`3oool00P3oool0
1@000000oooo0?ooo`3oool000000080oooo0P0000000d000000oooo0?ooo`0a0?ooo`03@000003o
ool0oooo00P0oooo0`0000020?ooo`8000000P3oool3000000@0oooo00=000000?ooo`0000002P3o
ool00`000000oooo0?ooo`040?ooo`03@000003oool0oooo00`0oooo0P00000@0?ooo`80000000=0
00000?ooo`3oool00P3oool00d000000oooo0?ooo`030?ooo`030000003oool0oooo00/0oooo00=0
00000?ooo`3oool00P3oool01T000000oooo0?ooo`3oool00000@00000<0oooo00E000000?ooo`3o
ool0oooo@00000050?ooo`<000009@3oool002@0oooo0P0000000d000000oooo0?ooo`090?ooo`80
000000=000000?ooo`3oool04@3oool00d00000000000?ooo`0?0?ooo`03@00000000000000000H0
oooo00<000000?ooo`3oool00P3oool00d00000000000?ooo`060?ooo`03@000003oool0oooo00<0
oooo0`0000020?ooo`050000003oool0oooo0?ooo`0000000P3oool3000001P0oooo00<00000@000
003oool03P3oool00`000000oooo0?ooo`0n0?ooo`80000000A000000?ooo`3oool00000103oool0
0`000000oooo0?ooo`020?ooo`80000000=000000000003oool02@3oool00`000000oooo0?ooo`0C
0?ooo`03000004000000oooo00d0oooo00<00000@000000000000`0000020?ooo`<000000`3oool0
0d00000000000000000T0?ooo`80000000=000000?ooo`3oool08`3oool002`0oooo00<00000@000
003oool02`3oool01000001000000000003oool2000000<0oooo0P0000040?ooo`800000103oool0
1P000000oooo0?ooo`3oool000000?ooo`<0000000=000000?ooo`3oool00P0000040?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool00P0000050?ooo`<0000000<0oooo0000003oool0
0P3oool010000000oooo0?ooo`3oool2000000060?oood00000000000000003ooom000000P000004
0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003o
ool0oooo00<0oooo1@0000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`0S0?ooo`05@000003oool0oooo0?ooo`000000103oool00d000000oooo
0?ooo`020?ooo`06@000003oool0oooo0?ooo`000000oooo100000030?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`02000000@0oooo00@000000?oo
o`3oool0oooo0P0000030?ooo`<0000000=000000?ooo`0000000`3oool00d000000oooo0?ooo`02
0?ooo`<0000000=000000?ooo`0000000`3oool00d000000oooo0?ooo`020?ooo`<0000000=00000
0000000000000P0000000`3oool00000000000030?ooo`050000003oool0oooo0?ooo`0000000`3o
ool2000000@0oooo00D000000?ooo`3oool0oooo000000040?ooo`050000003oool0oooo0?ooo`00
0000103oool00`000000oooo0?ooo`020?ooo`05@000003oool0oooo0?ooo`0000000`3oool20000
02H0oooo000U0?ooo`03@000003oool0oooo0080oooo100000000d000000oooo0?ooo`020?ooo`03
@000003oool0oooo0080oooo1@0000000`3ooom0000000000002000000030?oood00000000000080
00000`3oool00`000000oooo0?ooo`03000000<0oooo0`0000000`3oool00000000000030?ooo`80
00000`3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000103oool20000
00<0oooo00D000000?ooo`3oool0oooo000000040?ooo`040000003oool0oooo0?ooo`8000000P3o
ool2000000@0oooo0P0000000`3oool00000000000040?ooo`8000000P3oool2000000<0oooo0P00
00030?ooo`80000000A000000?ooo`00000000000`3oool01@000000oooo0?ooo`3ooom0000000@0
oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0<0?ooo`03000004000000000001L0
oooo0P0000030?ooo`03000004000000oooo00@0oooo0`00000;0?ooo`80000000<0oooo00000000
00002@3oool2000000D0oooo00<000000?ooo`3oool01@3oool2000000P0oooo0P0000000`3oool0
0000000000050?ooo`80000000<0oooo0000000000000`3oool2000000P0oooo00<000000?ooo`00
00000P00000W0?ooo`00?03oool2000000L0oooo00=000000000003oool0103oool3000000D0oooo
0P0000000d000000oooo0?ooo`070?ooo`<000000P3oool2000000T0oooo00=000000?ooo`3oool0
0P0000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool01D000000oooo
0?ooo`3oool0000000@0oooo100000040?ooo`04@000000000000000@0000080oooo00<000000?oo
o`3oool0203oool01P000000oooo0?ooo`00001000000?ooo`<000001P3oool3000002P0oooo00=0
00000000003oool0303oool00`0000100000@000000>0?ooo`05@0000000000000000?oood000000
0P0000020?ooo`03000004000000oooo00<0oooo00<000000?ooo`3oool00`3oool3000000030?oo
od000000oooo00<0oooo00=000000?ooo`3oool01@3oool2000001L0oooo0`0000080?ooo`040000
003oool0oooo@00000H0oooo00<00000@000000000000P0000020?ooo`800000203oool300000003
0?ooo`000000oooo02L0oooo000f0?ooo`030000003oool0oooo00<0oooo00<00000@00004000000
1P3oool2000000H0oooo00=000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`09@000
003oool00000000004000000oooo@00000000010000000T0oooo0P0000000`3oool00000@0000002
@000008000000P3oool00d0000000000000000040?ooo`80000000=000000000000000001@3oool0
0`000000oooo@00000040?ooo`<000000`3oool014000000000000000000000:0?ooo`030000003o
ool0oooo0080000000=000000?ooo`3oool0103oool200000003@000003oool0oooo02H0oooo0P00
00000`3oool000000?ooo`0:0?ooo`<000003P3oool3000000070?ooo`00000000000000003oool0
0000@0000002000000<0oooo00<000000?ooo`3oool0103oool00d000000oooo0?ooo`0200000080
oooo0`0000060?ooo`80000000=000000?ooo`3oool01P3oool00d000000oooo0?ooo`020?ooo`03
@000003oool0oooo00H0oooo00=000000000040000001`3oool00`00001000000?ooo`080?ooo`@0
000000E000000?ooo`3oool0oooo@00000080?ooo`8000000T000002000002L0oooo000W0?ooo`80
0000303oool00d0000000000000000050?ooo`8000001P3oool00`000000oooo0?ooo`02000000L0
oooo0P0000050?ooo`03000004000000oooo0080oooo0P0000000d00000000000?ooo`030?ooo`80
0000203oool2000000<0oooo1@0000030?ooo`8000000`3oool200000080oooo0P00000=0?ooo`04
0000003oool0oooo0?ooo`80000000=00000000000000000503oool2000002/0oooo00<000000?oo
od0000000P00000:0?ooo`800000103oool2000000X0oooo00D000000?ooo`3oool0oooo00000004
0?ooo`8000000P3oool2000000P0oooo0P0000030?ooo`8000004@3oool200000080oooo0`000003
0?ooo`04000004000000oooo0?ooo`<000000P3oool2000000L0oooo00<00000@000003oool01@3o
ool2000000T0oooo0P0000080?ooo`8000009`3oool002D0oooo00=000000?ooo`0000000`000003
0?ooo`030000003oool0oooo0080oooo00A000000?ooo`3oool0oooo0P0000030?ooo`@0000000<0
oooo0000003oool00P3oool00`000000oooo@0000003000000030?ooo`00000000000080000000<0
oooo@000000000000P0000000`3oool000000000000200000080oooo0P0000020?ooo`800000103o
ool01@000000oooo0?ooo`3ooom0000000@0oooo00@000000?ooo`3oool0oooo0P0000030?ooo`03
0000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000040?ooo`040000003oool0oooo
0?ooo`8000000`3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000000`3o
ool2000000<0oooo0P0000030?ooo`03@000003oool0oooo0080oooo00H000000?ooo`3oool0oooo
@000003oool4000002D0oooo00E000000?ooo`3oool0oooo000000030?ooo`800000103oool01D00
0000oooo0?ooo`3oool0000000@0oooo1P0000030?ooo`03@000003oool0oooo0080oooo00D00000
0?ooo`3oool0oooo000000040?ooo`040000003oool0oooo0?ooo`8000000`3oool300000003@000
003oool0000000<0oooo00<000000?ooo`3oool00P3oool014000000oooo0?ooo`3oool2000000<0
oooo00=000000?ooo`3oool00P3oool8000000030?ooo`00000000000080000000<0oooo00000000
00000P3oool00`000000oooo00000003000000<0oooo100000000`3oool00000000000030?ooo`04
0000003oool0oooo0?ooo`8000000`3oool00d000000oooo00000003000000<0oooo00=000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0T0?ooo`009`3oool00d00000000000?ooo`040?ooo`03
0000003oool0oooo0100oooo00<000000?ooo`3oool0203oool00d00000000000?ooo`090?ooo`80
0000<@3oool200000080oooo00<000000?ooo`3oool0403oool2000000L0oooo0P0000040?ooo`03
@00000000000oooo03h0oooo00<00000@00000000000603oool00d000000oooo0?ooo`020?ooo`<0
00003`3oool200000003@000003oool0oooo00l0oooo0P0000030?ooo`<0000000<0oooo@0000000
00001`3oool200000080oooo0P00000014000000oooo0?ooo`3oool3000000H0oooo00=000000000
003oool0<03oool002@0oooo00=000000000000000000P3oool00`000000oooo0?ooo`020?ooo`80
0000403oool3000000H0oooo00<000000?ooo`3oool08P3oool00d0000000000000000030?ooo`03
@00000000000oooo01@0oooo0P00000014000000000000000000000A0?ooo`80000000=000000?oo
o`3oool0103oool0100000100000@0000000000a0?ooo`03@000003oool0oooo00T0oooo00=00000
0000003oool00`3oool00`000000oooo0?ooo`020?ooo`05@000003oool0oooo@00000000000103o
ool00d000000oooo@0000002000000030?ooo`000000oooo00/0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00I00000000000000000oooo
@000000000030?ooo`05@00000000000oooo0?ooo`0000000`3oool2@00000030000003oool0oooo
00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`05@000003oool0oooo
0?ooo`0000002@3oool00d00000000000000000Z0?ooo`00903oool3000000030?oood0000000000
00@0oooo00<00000@000003oool03P3oool01400000000000000040000040?ooo`03@00000000000
000002@0oooo0`0000030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`090?ooo`070000003oool00000000004000000oooo@00000070?ooo`03@000
003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool200000003@00000000000oooo02l0oooo
0`00000:0?ooo`800000203oool3000000030?ooo`000000000000@0oooo1@0000000d0000000000
000000050?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool01`3oool00d0000000000
0?ooo`0=0?ooo`8000000P3oool300000080oooo0P0000000d0000000000000000040?ooo`800000
1@3oool00d00000000000000000?0?ooo`03@00000000000000000P0oooo0`00000Z0?ooo`009@3o
ool010000000oooo0?ooo`3oool2000001<0oooo00D00000@0000000000000000?ooo`02000000<0
oooo0`00000;0?ooo`<0000000E000000?ooo`3oool0oooo0000000A0?ooo`040000003oool0oooo
0?ooo`@000000`3oool300000080oooo00=000000000000000001P3oool2000000H0oooo0`000000
0`3oool000000?ooo`030?ooo`8000001P3oool00`000000oooo0?ooo`070?ooo`80000000<0oooo
000000000000:P3oool300000003@00000000000000000@00000103oool01D000000oooo0?ooo`3o
ool0000000@0oooo00@000000?ooo`3oool0oooo0`0000020?ooo`030000003oool0oooo0080oooo
0P0000020?ooo`030000003oool0oooo00<00000103oool00`000010000000000002000000030?oo
od000000000000L000000P3oool2000000@0oooo0`0000001T000000000000000000001000000?oo
o`8000000P3oool2000000<0oooo0P000000103oool000000000000000030?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool00`0000030?ooo`040000003oool0oooo0?ooo`8000000`3o
ool2000000040?ooo`0000000000000000@0oooo00D000000?ooo`3oool0oooo000000040?ooo`03
@000003oool0oooo02@0oooo000U0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0
oooo000000040?ooo`03@000003oool0oooo0080oooo00A000000?ooo`3oool0oooo10000000103o
ool000000?oood000003000000<0oooo00<000000?ooo`0000000`0000030?ooo`040000003oool0
oooo0?ooo`<000000P3oool2000000<0oooo00<000000?ooo`3oool00P3oool5000000@0oooo00@0
00000?ooo`3oool0oooo0P0000001T0000000000000000000000oooo@00000<000000`3oool20000
0080oooo0P0000000`3ooom0000000000002000000<0oooo1P0000030?ooo`@0000000<0oooo0000
000000000`3oool200000080oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0
000000@0oooo00=000000?ooo`3oool09@3oool3000000030?oood000000000000X0oooo00<00000
0?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool00P3o
ool01@000000oooo0?ooo`3oool0000000@0oooo00@000000?ooo`3oool0oooo0P0000020?ooo`80
00000`3oool200000003@00000000000oooo00D0oooo00<000000?ooo`3oool0103oool200000080
oooo0P0000000`3oool000000?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool00P3oool01P00
0000oooo0?ooo`3oool000000?ooo`<000000`3oool2000000@0oooo00<000000?ooo`3oool00P3o
ool200000080oooo00<000000?ooo`3oool0:@3oool002h0oooo00<000000?ooo`3oool06`3oool0
0d00000000000?ooo`020?ooo`<000001@3oool00`000000oooo0?ooo`0200000080oooo0P000004
0?ooo`030000003ooom0000000/0oooo00=000000?ooo`3oool0303oool3000000/0oooo0`000004
0?ooo`03@00000000000oooo00<0oooo00@00000@000003oool0oooo0P0000000d000000oooo0000
00150?ooo`04@00000000000oooo0?ooo`<000000`3oool00d000000oooo0?ooo`050?ooo`030000
003oool0oooo00/0oooo00<00000@000003oool0=@3oool200000080oooo00<000000?ooo`3oool0
0P3oool00`0000100000@00000040?ooo`<000000`3oool00d0000000000000000040?ooo`030000
04000000oooo02`0oooo000X0?ooo`030000003oool0oooo00<0oooo0P0000000`3oool000000?oo
o`0<0?ooo`030000003oool0oooo0100oooo00=000000?ooo`3oool01P3oool200000080oooo0`00
00030?ooo`8000003@3oool3000000d0oooo00=000000?ooo`3oool02`3oool00d000000oooo0?oo
o`030?ooo`800000103oool00`000000oooo0?ooo`020?ooo`030000003oool0000000800000>03o
ool00d000000oooo0?ooo`060?ooo`03@000003oool0oooo008000000P3oool200000004@000003o
ool0oooo0?ooo`8000000P3oool01D00000000000?oood000000000000D0oooo00=000000000003o
ool03@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00T0oooo00=000000?ooo`3o
ool0103oool00d00000000000?ooo`0<0?ooo`03000004000010000000800000103oool010000000
oooo0?ooo`0000040?ooo`03@000003oool0oooo0080oooo0`0000040?ooo`03@000003oool00000
02`0oooo000W0?ooo`03@00000000000000000@0oooo00<00000@000040000000P00000;0?ooo`<0
00000P3oool2000000L0oooo0P00000>0?ooo`06@000003oool0oooo0?ooo`00001000000`3oool0
0`00001000000?ooo`0;0?ooo`D00000803oool00`000000oooo0?ooo`0:0?ooo`80000000=00000
0?ooo`3oool0=@3oool3000000H0oooo0`0000000`3oool000000?ooo`070?ooo`8000000`3oool2
00000080oooo0P0000040?ooo`030000003oool0oooo00`0oooo00=000000000000000001P3oool2
000000<0oooo00=000000000000000002@3oool3000000030?ooo`000000oooo0080oooo0P000004
0?ooo`040000003oool00000000000P0oooo0`0000050?ooo`03@00000000000000000T0oooo00<0
00000?ooo`3oool00P3oool200000003@00000000000oooo02/0oooo000U0?ooo`04@000003oool0
oooo0?ooo`8000000`3oool010000000oooo0?ooo`3oool2000000@0oooo00L000000?ooo`3oool0
oooo0000003ooom0000000<0000000<0oooo0000000000000P0000020?ooo`80000000<0oooo@000
000000000P0000030?ooo`8000000`3oool300000003@00000000000oooo00<0oooo00<000000?oo
o`3oool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo00@000000?ooo`3oool0oooo0P00
00001400000000000000000000030?ooo`80000000=000000000000000000P0000020?ooo`800000
103oool010000000oooo0?ooo`3oool2000000<0oooo00D000000?ooo`3oool0oooo000000040?oo
o`040000003oool0oooo0?ooo`8000000P3oool2000000@0oooo00E000000?ooo`3oool0oooo0000
00040?ooo`03@000003oool0oooo02<0oooo00A000000?ooo`3oool0oooo1P0000040?ooo`050000
003oool0oooo0?ooo`000000103oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?oo
o`3oool00P3oool010000000oooo0?ooo`3oool2000000<0oooo00<000000?ooo`3oool00P3oool0
1@000000oooo0?ooo`3ooom0000000<0oooo0P0000030?ooo`03@000003ooom0000000<000000`3o
ool2000000<0oooo0P0000030?ooo`050000003oool0oooo0?ooo`000000103oool010000000oooo
0?ooo`3oool200000004@000000000000000000000@0oooo00<000000?ooo`3oool00P3oool01000
0000oooo0?ooo`3oool6000000<0oooo0P0000030?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00P0000040?ooo`03@000003oool0oooo02@0oooo000^0?ooo`8000001P3oool20000
00D0oooo0P0000040?ooo`04@00000000000oooo0?ooo`<000002@3oool200000003@000003oool0
oooo0080oooo0`0000030?ooo`800000103oool01@000000oooo0?ooo`3oool000000080oooo0P00
000?0?ooo`03000004000000000000D0oooo0P00000014000000oooo0000000000040?ooo`@00000
2@3oool010000000oooo0?ooo`3oool5000000P0oooo0P00000`0?ooo`03@00000000000oooo00h0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00<0
0000103oool00`000000oooo0?ooo`0I0?ooo`80000000=000000?ooo`3oool00`3oool2000000<0
oooo00@000000?ooo`3oool0oooo0P0000080?ooo`030000003oool0oooo00P0oooo0P0000030?oo
o`<00000>@3oool002l0oooo00<000000?ooo`3oool00`3oool3000000D0oooo0P0000000d000000
oooo0?ooo`060?ooo`05@000003oool0oooo0?oood0000001`3oool2000000<0oooo00=000000?oo
o`3oool00P0000000`3oool00000@000000200000080oooo0P0000020?ooo`80000000@0oooo@000
0000000000000`3oool00`000000oooo0?ooo`0C0?ooo`040000003oool00000000000D0oooo0`00
00000`3ooom000000?ooo`050?ooo`8000000P3oool01@000000oooo0000003ooom0000000<0oooo
00=000000?ooo`3oool00P3oool2000003d0oooo00A000000000003oool0oooo0`0000020?ooo`03
@00000000000oooo0080oooo00=000000000003oool02P3oool00d000000oooo0?ooo`020?ooo`80
00001@3oool00d000000oooo0?ooo`0D0?ooo`05@000003oool0oooo@000000000000P3oool00`00
001000000?ooo`050?ooo`80000000A000000?ooo`3oool00000103oool3000000h0oooo00A00000
0?oood0000000000>03oool002l0oooo00<00000@000003oool0103oool00d000000oooo0?ooo`05
0?ooo`030000003oool0oooo00X0oooo0`0000060?ooo`030000003oool0oooo0080oooo00D00000
@000000000000000@00000020?ooo`<0000000@0oooo@0000000000000000P3oool00`0000100000
00000002000000<0oooo00=000000000000000000P3oool00`000000oooo0?ooo`050?ooo`900000
00<000000?ooo`3oool01P3oool200000003@000003oool0oooo00@0oooo00=000000?ooo`000000
0P0000050?ooo`04000004000000oooo@00000<0000000A000000?ooo`3oool0oooo0`0000040?oo
o`03@000003oool0oooo03/0oooo0P0000020?ooo`80000000=000000?ooo`3oool00P0000030?oo
o`800000403oool00`00001000000?ooo`030?ooo`<00000203oool00d000000oooo0?ooo`090?oo
o`<0000000@0oooo00000000000000001`3oool014000000oooo0?ooo`0000020?ooo`03@0000000
0000oooo00<0oooo0P0000000d000000oooo0?ooo`0>0?ooo`800000>03oool003D0oooo0P000007
0?ooo`8000000`3oool2000000H0oooo0P0000080?ooo`03000004000000oooo0080000000@0oooo
00000000000000000`3oool010000000oooo0?ooo`3oool2000000@0oooo0P0000050?ooo`800000
00@0oooo00000000000000001@3oool5000000D0oooo00<000000?ooo`3oool01`3oool00`000010
00000?ooo`02000000T0oooo0`0000050?ooo`800000=`3oool2000000X0oooo00@000000?ooo`00
000000001@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01D0oooo0P0000030?oo
o`04000004000000oooo0?ooo`<000002`3oool200000080oooo0P0000020?ooo`030000003oool0
oooo0080oooo0`0000000d00000000000?ooo`020?ooo`800000103oool01@000000oooo0?ooo`3o
ool0000000T0oooo00D000000?ooo`3oool0oooo0000000i0?ooo`009@3oool00d000000oooo0?oo
o`020?ooo`05@000003oool0oooo0?oood000000103oool00d000000oooo00000003000000<0oooo
00<000000?ooo`0000000`0000000`3ooom0000000000002000000<0oooo00<000000?ooo`3oool0
0P3oool010000000oooo0?ooo`3oool4000000030?ooo`000000oooo0080oooo0P0000030?ooo`03
0000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000040?ooo`03@000003oool0oooo
0080oooo00<00000@000000000000P0000030?ooo`8000000`3oool200000080oooo0P0000030?oo
o`8000000`3oool6000000<0oooo0P0000030?ooo`@0000000<0oooo0000003oool00P3oool00`00
0000oooo0?ooo`020?ooo`8000000P3oool00d000000oooo0?ooo`020?ooo`03@000003oool0oooo
02<0oooo00M000000?ooo`3oool0oooo@000003ooom0000000<000000`3oool2000000<0oooo00<0
00000?oood0000000`0000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3o
ool200000080oooo0P0000030?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo
000000030?ooo`@0000000<0oooo0000000000000P0000000`3oool00000000000030?ooo`05@000
003oool0oooo0?ooo`000000103oool010000000oooo0?ooo`3oool300000080oooo00@000000?oo
o`3oool0oooo0P0000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool2
000000030?ooo`000000000000<0oooo0P0000030?ooo`030000003oool0oooo0080oooo0P000002
0?ooo`8000000`3oool00`000000oooo0?ooo`020?ooo`03@000003oool0oooo02@0oooo000e0?oo
o`03@00000000000oooo00@0oooo00@000000?oood00000000003`3oool00`000000oooo0?ooo`03
0?ooo`800000;@3oool3000000040?ooo`0000000000000000H0oooo0P0000060?ooo`80000000A0
00000?ooo`3oool0oooo0P00000:0?ooo`80000000=000000?ooo`3oool0;P3oool00d0000000000
0?ooo`040?ooo`<00000603oool4000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0@0?ooo`03000004000000oooo00D0oooo00<000000?ooo`3oool01`3oool200000003@000
003oool0oooo00`0oooo0`0000030?ooo`D000000`3oool2000000T0oooo100000020?ooo`<00000
:`3oool002h0oooo00=000000000003oool02`3oool200000140oooo00<00000@000003oool01P3o
ool01@000000oooo0?ooo`3oool0000000<0oooo00=000000000003oool0603oool00`000000oooo
0?ooo`070?ooo`05@000003oool0oooo0?oood0000003`3oool3000000T0oooo00<000000?ooo`3o
ool0103oool2000000L0oooo00=000000000003oool09P3oool2000000H0oooo00=000000?ooo`3o
ool02@3oool014000000oooo0?oood00000200000080oooo00=000000000000000000P3oool00d00
00000000000000050?ooo`<000000P3oool200000180oooo00<000000?ooo`3oool0103oool00d00
000000000?ooo`020?ooo`03@00000000000oooo00@0oooo00=000000?ooo`3oool0103oool00d00
00000000000000060?ooo`80000000=000000?ooo`3oool00P3oool200000004@000003oool0oooo
0?ooo`<000002@3oool00`000000oooo@00000040?ooo`03@000003oool0oooo02X0oooo000^0?oo
o`800000303oool01000001000000?ooo`0000040?ooo`050000003oool0oooo0?ooo`0000001P3o
ool00`000000oooo0?ooo`040?ooo`03@0000000000000000080oooo00=000000000003oool00P3o
ool2000000<0oooo00=000000000000000000`3oool00d000000oooo0?ooo`0<0?ooo`<000001P3o
ool00d00000000000?ooo`0@0?ooo`05@000003oool0oooo0?ooo`0000002@3oool00d0000000000
0?ooo`050?ooo`030000003oool0oooo00H0oooo0`00000V0?ooo`030000003oool0oooo0100oooo
0`0000000`3oool00000000000030?ooo`8000000`3oool2000000H0oooo0P00000014000000oooo
0?ooo`000002@00000@0oooo00I000000?ooo`3oool0oooo00000400000>0?ooo`8000000`3oool2
000000@0oooo0`0000050?ooo`<0000000<0oooo0000003oool02`3oool2000000@0oooo00<00000
@000003oool0?03oool002D0oooo00@000000?ooo`00000000001@3oool00`000000oooo0?ooo`07
0?ooo`<000000`3oool300000080oooo00E00000000000000000oooo@0000002000000@0oooo00<0
00000?ooo`3oool01P3oool2000000<0oooo0P0000030?ooo`040000003oool0oooo0?ooo`<00000
0`3oool2000000H0oooo0P0000020?ooo`80000000@0oooo@0000000000000001@3oool5000000@0
oooo00D000000?ooo`3oool0oooo000000040?ooo`<000000P3oool00`000000oooo0?ooo`020?oo
o`05000004000000oooo0?ooo`0000000P3oool2000000@0oooo00<000000?ooo`3oool01P3oool3
00000200oooo100000030?ooo`030000003oool0oooo0080oooo00=000000?ooo`3oool00P3oool0
1D000000oooo0?ooo`3ooom0000000@0oooo00@000000?ooo`3oool0oooo0P0000030?ooo`800000
0`3oool200000080oooo0P0000030?ooo`03@000003oool0oooo0080oooo0P0000020?ooo`/00000
00A000000?ooo`0000000000103oool01D000000oooo0?ooo`3oool0000000@0oooo00@000000?oo
o`3oool0oooo0`0000020?ooo`030000003oool0oooo0080oooo00<000000?oood0000000P000003
0?ooo`8000000`3oool2000000040?oood0000000000000000@0oooo00<000000?ooo`3oool00P00
00040?ooo`<0000000=000000?oood0000000`3oool00d000000oooo0?ooo`020?ooo`030000003o
ool0oooo02@0oooo000U0?ooo`030000003ooom0000000<000000`3oool00`000000oooo0?ooo`02
0?ooo`03@000003oool0oooo00<0000000I0000000000000000000000?oood000003000000<0oooo
0P0000020?ooo`8000000`3oool300000080oooo00=000000?ooo`3oool00P3oool010000000oooo
0?ooo`3oool2000000<0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`3oool20000
00<0oooo00=000000?ooo`0000001`0000030?ooo`8000000`3oool200000003@000000000000000
008000000P3oool2000000<0oooo0P0000020?ooo`8000000P3oool2000000<0oooo100000020?oo
o`050000003oool0oooo0?ooo`000000103oool01@000000oooo0?ooo`3ooom0000000@0oooo00<0
00000?ooo`3oool0803oool00d00000000000?ooo`0K0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool00P3oool00`000000oooo00000002000000P0oooo100000070?ooo`8000000P3o
ool200000080oooo0P0000000d000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00D0
00000?ooo`3oool0oooo000000040?ooo`8000000`3oool010000000oooo0?ooo`3oool5000000@0
oooo0P0000020?ooo`800000103oool4000000L0oooo0P00000:0?ooo`8000009@3oool002@0oooo
0`0000020?ooo`03@00000000000000000T0oooo0`00000G0?ooo`80000000=000000?ooo`3oool0
203oool00d00000000000?ooo`070?ooo`050000003oool0oooo0?ooo`0000001P3oool00d000000
oooo0?ooo`020?ooo`03@000003oool0oooo0100oooo0P0000040?ooo`8000001@3oool3000000P0
oooo0P0000070?ooo`<00000>P3oool00d00000000000?ooo`020?ooo`05@00000000000oooo0?oo
o`0000002P3oool00d000000oooo000000040?ooo`03@000003oool0oooo01@0oooo00<000000?oo
o`3oool00P3oool00d0000000000000000030?ooo`04@00000000000oooo@000008000003@3oool0
0`00001000000?ooo`070?ooo`03@00000000000oooo00@0oooo0P00000014000000oooo0?ooo`00
00030?ooo`80000000<0oooo@000003oool0503oool00`00001000000?ooo`0S0?ooo`00903oool2
00000003@000003oool0oooo00<00000103oool00d000000oooo0?ooo`030?ooo`03@000003oool0
oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo00X0oooo0P00000?0?ooo`030000003oool0oooo01<0oooo00=000000?ooo`3oool0103oool0
0d000000oooo0?ooo`020?ooo`80000000=000000?ooo`3oool00`3oool00d000000oooo0?ooo`05
0?ooo`04@000003oool00000@00000L0oooo0P0000000d000000oooo0?ooo`0h0?ooo`8000000`3o
ool2000000030?oood000000000000D0oooo00=000000000003oool00P3oool01000001000000000
0000000I0?ooo`03@00000000000oooo00<0oooo0`0000030?ooo`H0000000<0oooo0000003oool0
0`3oool00d00000000000?ooo`040?ooo`030000003oool0000000L0oooo0`0000030?ooo`03@000
0000000000000080oooo00=000000000003oool00P3oool00`00001000000?ooo`0F0?ooo`030000
003oool0oooo02<0oooo000Z0?ooo`030000003oool0oooo0080oooo0`0000030?ooo`8000001`3o
ool300000080oooo00=00000000000000000503oool00`00001000000000000:0?ooo`8000000`3o
ool300000080oooo0P00000?0?ooo`<000001`3oool00`00001000000?ooo`0?0?ooo`<000001`3o
ool00`00001000000?ooo`0;0?ooo`03000004000000oooo02L0oooo00<00000@000003oool01@3o
ool01@000000oooo0?ooo`3oool0000000<0oooo0P0000030?ooo`8000000`3oool2000000030?oo
o`000000000000H0oooo00<00000@000003oool01P3oool00`00001000000?ooo`020?ooo`030000
04000000oooo00<0oooo0P0000040?ooo`030000003oool0oooo0080oooo0P0000020?ooo`030000
003ooom0000000800000103oool00`000000oooo0?ooo`020?ooo`030000003ooom0000000800000
103oool00`000000oooo@0000002000000@0oooo0P0000030?ooo`030000003oool0oooo00d0oooo
0P00000<0?ooo`03000004000000oooo0280oooo000U0?ooo`03@000003oool0oooo0080oooo00@0
00000?ooo`3oool0oooo1P0000000`3oool0000000000002000000<0oooo00<000000?oood000000
0`0000030?ooo`8000000`3oool00`000000oooo0?ooo`020?ooo`04@000003oool0oooo0?ooo`80
00000`3oool5000000@0oooo00=000000?ooo`3oool00P3oool5000000030?oood00000000000080
000000<0oooo0000000000000P0000030?ooo`030000003oool0oooo00@000000P3oool300000080
oooo00@000000?ooo`3oool0oooo100000000`3oool000000?ooo`04000000030?ooo`0000000000
008000000`3oool2000000<0oooo00@000000?ooo`3oool0oooo100000000`3oool000000?ooo`02
0?ooo`03@000003oool0oooo0080oooo1000000R0?ooo`04@000003oool0oooo0?ooo`@0000000<0
oooo0000000000000`3oool01@000000oooo0?ooo`3oool0000000@0oooo00D000000?ooo`3oool0
oooo000000040?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool0oooo100000000`3o
ool000000?ooo`020?ooo`@0000000<0oooo0000000000000P0000000`3ooom000000?ooo`020?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0
000000<0oooo0P0000030?ooo`8000000`3oool200000080oooo0P0000030?ooo`8000000P3oool2
000000@0oooo00D000000?ooo`3oool0oooo000000040?ooo`8000000P3oool00d000000oooo0?oo
o`020?ooo`030000003oool0000000<000000`3oool00d000000oooo0?ooo`020?ooo`@000008`3o
ool00300oooo00=000000000003oool00P3oool00d00000000000?ooo`030?ooo`8000000`3oool2
000000H0oooo0`0000090?ooo`80000000A000000?ooo`3oool0oooo0P0000080?ooo`80000000<0
oooo@00000000000203oool00d00000000000?ooo`030?ooo`8000000P3oool3000000<0oooo00<0
00000?ooo`3oool00`0000070?ooo`80000000@0oooo00000000000000000P3oool00d0000000000
0?ooo`090?ooo`030000003oool0oooo00<0oooo0P0000000`3oool000000?ooo`090?ooo`800000
:03oool200000080oooo0P0000000d000000oooo0?ooo`0L0?ooo`80000000<0oooo0000003oool0
103oool2000000<0oooo0P00000M0?ooo`030000003oool0oooo0080oooo00<00000@000003oool0
1P3oool00`000000oooo0?ooo`0@0?ooo`03000004000000oooo00D0oooo00@000000?oood000000
0000303oool2000002<0oooo000j0?ooo`<000000P3oool00`000000oooo0?ooo`050?ooo`<00000
1P3oool00d000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo0`0000000d000000oooo
0?ooo`0=0?ooo`8000000`3oool00d000000oooo0?ooo`050?ooo`<000001`3oool200000080oooo
00E000000?ooo`3oool0oooo@000000;0?ooo`8000001`3oool3000003L0oooo0`0000040?ooo`03
0000003oool0oooo00<0oooo00=000000?ooo`3oool00P3oool00d00000000000?ooo`060?ooo`03
0000003oool0oooo00D0oooo00=00000000000000000603oool00`000000oooo0?ooo`020?ooo`03
@00000000000000000L0oooo00=000000000003oool00`3oool00`000000oooo0?ooo`060?ooo`06
000004000000oooo0?oood00000000001P3oool00d0000000000000000030?ooo`03@00000000000
oooo00D0oooo00=00000000000000000<`3oool003X0oooo0P0000000d000000oooo@00000020000
00L0oooo00<00000@000003oool01@3oool2000000h0oooo00I00000000000000000oooo@000003o
ool2000000l0oooo00=000000?ooo`3oool02@3oool00d0000000000@00000060?ooo`03@0000000
0010000000D0oooo0`0000040?ooo`030000003oool0oooo00<0oooo00<00000@000003oool01P3o
ool200000003@000003oool0oooo03H0oooo00<000000?ooo`3oool00P3oool00d00000000000?oo
o`040?ooo`8000000`3oool3000000H0oooo00<000000?ooo`3oool01@3oool3000000D0oooo00<0
00000?ooo`3oool02`3oool01@000000oooo0?ooo`3ooom00000008000000`3oool3000000L0oooo
0P00000A0?ooo`<000001@3oool3000000<0oooo0P0000060?ooo`<00000<`3oool003X0oooo0`00
00020?ooo`800000203oool00`00001000000?ooo`030?ooo`8000002@3oool01000001000000?oo
o`0000020?ooo`<000000P3oool2000000h0oooo0P0000030?ooo`8000001P3oool300000080oooo
00H00000@000003oool0oooo000004000002000000D0oooo0`0000030?ooo`<000001P3oool20000
0140oooo00<00000@000003oool07P3oool200000180oooo0P0000040?ooo`8000000P3oool60000
00<0oooo0P0000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool40000
00H0oooo00<00000@000003oool00P0000000d0000000000000000030?ooo`800000103oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool01@00
0000oooo0?ooo`3oool0000000@0oooo0P0000020?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00/0oooo00<00000
0?ooo`3oool0903oool002D0oooo00<000000?ooo`3oool00P3oool01D000000oooo0?ooo`3ooom0
000000@0oooo00A000000?ooo`3oool0oooo0P0000000`3ooom0000000000002000000<0oooo00H0
00000?ooo`3oool0oooo0000003oool4000000@0oooo00D000000?ooo`3oool0oooo000000040?oo
o`H000000`3oool010000000oooo0?ooo`3oool2000000<0oooo00<000000?ooo`0000000`000004
0?ooo`9000000`0000000`3ooom0000000000002000000<0oooo0P0000020?ooo`L000000P3oool2
000000<0oooo0P0000001T0000000000000000000000oooo@00000<00000103oool2@00000<00000
103oool01D000000oooo0?ooo`3ooom0000000@0oooo1000000O0?ooo`04@0000000000000000000
00<0oooo00=000000?ooo`3oool00P3oool00d000000oooo0?ooo`020?ooo`05@000003oool0oooo
0?ooo`000000103oool01@000000oooo0?ooo`3oool000000080oooo0`0000030?ooo`0300000400
0000oooo0080oooo0P0000030?ooo`030000003oool0oooo0080oooo00<00000@000000000000P00
00030?ooo`@0000000D0oooo0000000000000000@0000002000000@0oooo00D000000?ooo`3oool0
oooo000000040?ooo`05@000003oool0oooo0?ooo`000000103oool2000000<0oooo00@000000?oo
o`3oool0oooo0P0000030?ooo`030000003oool0oooo0080oooo0P0000020?ooo`030000003oool0
oooo0080oooo00D000000?ooo`3oool0oooo@00000040?ooo`030000003oool0oooo0080oooo00E0
00000?ooo`3oool0oooo@00000020?ooo`<000009P3oool002D0oooo00<000000?ooo`3oool01P3o
ool01D00000000000?ooo`3ooom0000000D000003@3oool2000000X0oooo0`0000080?ooo`800000
0`3oool00`000000oooo0?ooo`050?ooo`8000000P3oool200000380oooo00=000000000003oool0
?P3oool00d00000000000000000C0?ooo`03@000003oool0oooo00T0oooo00<000000?ooo`3oool0
1@3oool2000000h0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`020?ooo`800000
0P3oool3000000<0oooo00<00000@000003oool01P3oool200000003@000003oool0oooo00`0oooo
00=000000000000000002@3oool3000002L0oooo000T0?ooo`<000001`3oool200000080oooo0`00
00000`3ooom000000?ooo`070?ooo`03@00000000000oooo0080oooo00@000000?ooo`0000100000
2P3oool00d000000oooo0?ooo`050?ooo`@000000P3oool00`000000oooo0?ooo`050?ooo`<00000
0P3oool00d000000oooo0?ooo`0D0?ooo`030000003oool0oooo00<0oooo00=000000000003oool0
1@3oool00`000000oooo0?ooo`0<0?ooo`800000?`3oool3000000`0oooo00=000000?ooo`3oool0
1`3oool00d000000oooo0?ooo`060?ooo`03000004000000oooo00D0oooo0P0000050?ooo`05@000
003oool0oooo0?oood0000003P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080
oooo00=000000000003oool00`3oool200000005@000003oool000000000040000000`3oool00`00
0000oooo0?ooo`060?ooo`03@00000000000000000h0oooo0`00000:0?ooo`03@000003oool0oooo
02H0oooo000T0?ooo`80000000=000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`04000001<0
oooo0`00000014000000oooo@000000000080?ooo`03000004000000oooo01L0oooo0`0000040?oo
o`8000001@3oool3000000h0oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`030?oo
o`8000001P3oool2000000@0oooo00@00000@000003oool0oooo0P00000?0?ooo`03000004000000
oooo00<0oooo0`000000103oool000000000000000030?ooo`8000001`3oool300000080oooo00=0
0000000000000000103oool2000000P0oooo0`0000030?ooo`03000004000000oooo00@0oooo0`00
000=0?ooo`04000004000000oooo000003@0oooo000U0?ooo`03@000003oool0oooo0080oooo00D0
00000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo0080oooo00<000000?oood000000
0P0000030?ooo`80000000@0oooo@000000000000000103oool00`000000oooo0?ooo`020?ooo`05
@000003oool0oooo0?oood000000103oool200000004@00000000000000000000080oooo0P000004
0?ooo`<000000T0000040?ooo`03@000003oool0oooo0080oooo00D000000?ooo`3oool0oooo0000
00030?ooo`8000000`3oool200000004@000000000000000000000@0oooo00@000000?ooo`3oool0
oooo0P0000001400000000000000000000030?ooo`8000000`3oool00d000000oooo0?ooo`020?oo
o`050000003oool0oooo0?ooo`000000103oool01D000000oooo0?ooo`3ooom0000000@0oooo00=0
00000?ooo`3oool08`3oool01D000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0
0P3oool5000000<0oooo0P0000030?ooo`@0000000<0oooo0000000000000`3oool01@000000oooo
0?ooo`3ooom0000000@0oooo00=000000?ooo`3oool00P3oool010000000oooo0?ooo`3oool20000
00<0oooo00H000000?ooo`3oool0oooo@000003oool4000000@0oooo0T000003000000<0oooo0P00
00030?ooo`8000000`3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo0?ooo`@00000
00<0oooo0000003oool00P3oool2000000<0oooo00<000000?ooo`3oool00P3oool014000000oooo
0?ooo`3oool4000000030?ooo`000000oooo00<0oooo00E000000?ooo`3oool0oooo@00000040?oo
o`03@000003oool0oooo02@0oooo000Z0?ooo`800000303oool010000000oooo0?ooo`3oool20000
00<0oooo00@000000?ooo`3oool0oooo0P0000040?ooo`8000003@3oool2000000D0oooo00<00000
0?ooo`3oool0103oool2000000T0oooo0P0000020?ooo`80000000@0oooo00000000000000001P3o
ool2000000H0oooo00<000000?ooo`3oool01@3oool2000000@0oooo0P0000000d000000oooo0?oo
o`070?ooo`800000=P3oool2000000T0oooo00<00000@000000000001@3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo008000003@3oool2000000h0oooo00=000000000003oool05`3o
ool00`000000oooo0?ooo`080?ooo`80000000<0oooo0000000000001P3oool2000000X0oooo0P00
000f0?ooo`00:`3oool00`00001000000?ooo`090?ooo`8000001`3oool00`000000oooo0?ooo`08
0?ooo`80000000=000000?ooo`3oool08`3oool00`000000oooo0?ooo`0200000080oooo00=00000
0?ooo`3oool07@3oool00`000000oooo0?ooo`070?ooo`800000=P3oool2000000/0oooo00<00000
@000003oool0403oool3000000`0oooo0P0000080?ooo`03@00000000000000000H0oooo00=00000
0000000000001P3oool00`000000oooo0?ooo`020?ooo`03@0000000000000000080oooo00A00000
0000003oool0oooo0`00000=0?ooo`06000004000000oooo@00000000000oooo0P0000130?ooo`00
:`3oool00`000000oooo0?ooo`090?ooo`05000004000000oooo0?ooo`0000000`3oool00d000000
00000?ooo`0:0?ooo`030000003oool0oooo02<0oooo00<00000@000003oool00P3oool00d000000
oooo0?ooo`0G0?ooo`03@000003oool0oooo0140oooo00=000000?ooo`3oool0=@3oool00d000000
oooo0?ooo`090?ooo`030000003oool0oooo00H0oooo00=000000?ooo`3oool0203oool00d000000
oooo0?ooo`0<0?ooo`03@000003oool0oooo00H0oooo0`0000060?ooo`<000001@3oool00d000000
00000?ooo`030?ooo`<000000P3oool2000000050?oood00000000000000040000003@3oool00`00
0000oooo0?ooo`03000000030?oood000000oooo0480oooo000j0?ooo`03@00000000000000000<0
oooo0P0000040?ooo`030000003oool0oooo01D0oooo0P0000070?ooo`8000007`3oool00`000010
00000?ooo`050?ooo`@000001P3oool00`00001000000?ooo`0I0?ooo`03000004000000oooo02`0
oooo0P0000020?ooo`8000001P3oool3000000<0oooo0`00000L0?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool01@3oool2000000@0oooo00D000000?ooo`3oool0oooo000000030?oo
o`8000004@3oool2000000<0oooo00<000000?ooo`3oool0@03oool002D0oooo00=000000?ooo`3o
ool00P3oool01D000000oooo0?ooo`3ooom0000000@0oooo00<000000?ooo`3oool00P3oool01000
0000oooo0?ooo`3oool2000000<0oooo00@000000?ooo`3oool0oooo0P0000030?ooo`8000000`3o
ool01@000000oooo0?ooo`3oool0000000@0oooo00I000000?ooo`3oool0oooo@000003oool40000
00@0oooo1@0000040?ooo`03@000003oool0oooo0080oooo1@0000000`3oool00000000000020000
00<0oooo0P0000030?ooo`H000000`3oool200000004@000000000000000000000<0oooo10000000
0`3ooom000000?ooo`030?ooo`05@000003oool0oooo0?ooo`000000103oool01@000000oooo0?oo
o`3ooom0000000@0oooo1000000R0?ooo`05@000003oool0oooo0?oood000000103oool00d000000
oooo00000007000000@0oooo00@000000?ooo`3oool0oooo0`000000140000000000000000000003
0?ooo`050000003oool0oooo0?ooo`0000000`3oool2000000@0oooo00E000000?ooo`3oool0oooo
@00000040?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`020?ooo`05
@000003oool0oooo0?ooo`000000103oool01@000000oooo0?ooo`3oool0000000@0oooo00<00000
0?ooo`3oool00P3oool6000000<0oooo0P0000020?ooo`8000000`3oool00`000000oooo0?ooo`02
0?ooo`05@000003oool0oooo0?oood000000103oool00`000000oooo0?ooo`020?ooo`050000003o
ool0oooo0?oood000000103oool2000002D0oooo000a0?ooo`8000001@3oool00`000000oooo0?oo
o`0:0?ooo`800000103oool200000004@000003oool0000000000080oooo0P0000090?ooo`03@000
00000000oooo00D0oooo00<00000@000000000002@3oool200000080oooo0P0000020?ooo`03@000
00000000oooo0080oooo0`0000060?ooo`@000003P3oool2000000/0oooo0P0000020?ooo`800000
2@3oool2000002d0oooo00I000000000003oool0oooo@0000000000<0?ooo`8000001@3oool20000
00050?ooo`00000000000000040000000`00000@0?ooo`<000004P3oool00d000000oooo0?ooo`0;
0?ooo`030000003oool00000008000001@3oool00`00001000000?ooo`040?ooo`<00000303oool0
1P000000oooo0?ooo`3ooom00000000000T0oooo00<00000@000003oool08`3oool00300oooo0`00
00040?ooo`8000002`3oool300000004@000003oool0oooo0?ooo`<0000000H0oooo000000000010
00000?oood000002000000<0oooo00=000000?ooo`3oool02`3oool2@00000H0oooo00=000000000
000000000P0000000`3ooom00000@00000080?ooo`03@000003oool0oooo00P0oooo0P0000000d00
0000oooo0?ooo`020?ooo`03@000003oool0oooo00X0oooo00=000000000003oool01P3oool20000
0005@000003oool0oooo000004000000<`3oool00`000000oooo0?ooo`0<0?ooo`03@00000000000
00000080oooo00=000000000003oool01@3oool2000000<0oooo00E000000?ooo`0000000000@000
000>0?ooo`05@0000000000000000?oood0000004`3oool2000000040?oood000000000000000080
oooo00=000000000003oool00`3oool00`0000100000@00000070?ooo`030000003oool0oooo00@0
oooo0P0000000d000000oooo0?ooo`090?ooo`<000000P3oool2000000T0oooo00<000000?ooo`3o
ool08`3oool00340oooo00=000000?ooo`3oool00`3oool00`00001000000?ooo`050?ooo`030000
003oool0oooo00<0oooo0`0000040?ooo`040000003oool0oooo000000<0oooo0P0000040?ooo`80
0000103oool00`000000oooo0?ooo`050?ooo`8000001P3oool2000000030?oood000000oooo00<0
00004`3oool00`000000oooo0?ooo`030?ooo`<000002`3oool3000000L0oooo00D000000?ooo`3o
ool0oooo0000000c0?ooo`03@00000000000000000d0oooo0`0000020?ooo`8000001`3oool00d00
0000oooo0?ooo`020?ooo`800000403oool3000001D0oooo0P0000020?ooo`8000000P3oool20000
00@0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0:0?ooo`80000000=000000?oo
o`3oool00P00000_0?ooo`009@3oool00`000000oooo0?ooo`0B0?ooo`8000000P3oool3000000D0
oooo0`000000103oool000000?oood000002000000@0oooo0P0000030?ooo`800000103oool30000
00D0oooo0P0000070?ooo`030000003oool0oooo0080oooo00@00000@0000000000000000P3oool4
000000030?ooo`0000000000008000001@3oool00`00001000000?ooo`050?ooo`80000000D0oooo
0000000000000000@000000300000003@000003oool0oooo00<00000203oool2000002d0oooo1000
00030?ooo`04@000003oool0oooo0?ooo`800000103oool01D000000oooo0?ooo`3oool0000000@0
oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo0080oooo00D000000?oo
o`3oool0oooo000000040?ooo`<0000000=000000000000000000`3oool00`000000oooo0?ooo`02
0?ooo`040000003oool0oooo0?ooo`H000000`3oool300000003@000003ooom0000000@0oooo00@0
00000?ooo`3oool0oooo0P0000030?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0
oooo@00000040?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000040?oo
o`<000000T0000040?ooo`03@000003oool0oooo0080oooo00D000000?ooo`3oool0oooo@0000004
0?ooo`03@000003oool0oooo02@0oooo000U0?ooo`030000003oool0oooo0080oooo00E000000?oo
o`3oool0oooo@00000040?ooo`03@000003oool0oooo0080oooo0P0000001D000000000000000000
0010000000<000000`3oool2000000<0oooo0`0000000`3oool00000000000030?ooo`030000003o
ool0oooo0080oooo00@000000?ooo`3oool0oooo0P0000001400000000000000000000040?ooo`05
0000003oool0oooo0?oood000000103oool010000000oooo0?ooo`3oool200000080oooo0P000000
0`3oool0000000000002000000040?ooo`0000000000000000@0oooo100000000`3ooom000000?oo
o`020?ooo`030000003oool0oooo0080oooo0`000000103oool000000000000000020?ooo`030000
003oool0oooo0080oooo00M000000?ooo`3oool0oooo@000003ooom0000000<000000`3oool00d00
0000oooo0?ooo`020?ooo`03@000003oool0oooo0200oooo00=000000000003oool04P3oool00`00
0000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000103oool2000000030?ooo`000000
000000/0oooo0P0000001P3oool00000000004000000oooo000000@0oooo00<000000?ooo`3oool0
0P3oool00`0000100000000000070?ooo`8000001P3oool00`000000oooo0?ooo`020?ooo`050000
003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`060?ooo`8000000P3oool200000080
oooo0P0000060?ooo`800000>P3oool002@0oooo0`00000;0?ooo`03@00000000000000001D0oooo
0`0000000d000000oooo0?ooo`020?ooo`030000003oool0oooo01h0oooo00=000000000003oool0
103oool00d000000oooo0?ooo`020?ooo`03@000003oool0oooo00@0oooo00=000000000003oool0
3@3oool01@000000oooo0?ooo`3oool000000540oooo0P0000030?ooo`03@000003oool0oooo00H0
oooo1@00000@0?ooo`@000000P3oool00d0000000000000000050?ooo`030000003oool0oooo0140
oooo00=000000000003oool00P3oool014000000oooo0?ooo`3oool2000000T0oooo00<00000@000
003oool00P0000020?ooo`8000003P3oool00d00000000000?ooo`0a0?ooo`00903oool200000003
@000003oool0oooo00T0oooo0`00000<0?ooo`03@00000000000000000@0oooo00E0000000000000
0000oooo000000040?ooo`03@00000000000oooo0180oooo00=000000000000000002P3oool30000
00@0oooo00=000000?ooo`3oool02@3oool3000000P0oooo00=000000?ooo`3oool04@3oool00`00
0000oooo0?ooo`140?ooo`03000004000000oooo0080oooo0P0000070?ooo`8000000T0000030?oo
o`03@000003oool0oooo00H0oooo00<000000?ooo`3oool00`3oool200000003@000003oool0oooo
00<000006@3oool2000000<0oooo0P0000020?ooo`03000004000000oooo00P0oooo00D000000?oo
o`0000000000@00000030?ooo`03@000003oool0oooo00`0oooo0`00000a0?ooo`00<`3oool00`00
0000oooo0?ooo`0200000080oooo0P0000050?ooo`8000001P3oool2000000L0oooo0P00000:0?oo
o`8000001P3oool200000080oooo00<000000?ooo`3oool01P3oool2000000@0oooo0`0000030?oo
o`8000001@3oool2000000@0oooo00@00000@000003oool0oooo0`00000A0?ooo`03@00000000000
oooo0300oooo0P0000070?ooo`800000203oool0100000100000@000000000030?ooo`8000003@3o
ool2000000L0oooo00@00000@0000000000000002@3oool00`000000oooo0?ooo`060?ooo`800000
0`3oool00`000000oooo0?ooo`030?ooo`03000004000000oooo00@0oooo00<000000?ooo`3oool0
0P3oool2000000L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0?0?ooo`<00000
<P3oool002D0oooo00<000000?ooo`3oool00P3oool01D000000oooo0?ooo`3oool0000000@0oooo
00<000000?ooo`3oool00`0000000d000000000000000002000000<0oooo0P0000020?ooo`030000
003oool0oooo0080oooo00@000000?ooo`3oool0oooo0P0000030?ooo`030000003oool0oooo0080
oooo00@000000?ooo`3oool0oooo1P0000030?ooo`8000000`3oool200000080oooo0`0000001400
0000oooo0000000000030?ooo`H0000000<0oooo@000000000000P0000030?ooo`040000003oool0
oooo0?ooo`@0000000<0oooo0000000000000P3oool300000003@000003oool0000000@0oooo00=0
00000?ooo`3oool00P3oool00d000000oooo0?ooo`02000000@0oooo00E000000?ooo`3oool0oooo
@00000040?ooo`03@000003oool0oooo0200oooo100000030?ooo`03@000003oool0000000<00000
103oool6000000<0oooo00@000000?ooo`3oool0oooo0P0000020?ooo`800000103oool010000000
oooo0?ooo`3oool2000000<0oooo0P0000020?ooo`8000000`3oool00`000000oooo0?ooo`020?oo
o`040000003oool0oooo0?ooo`H000000`3oool2000000<0oooo100000000`3oool0000000000002
0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool0oooo0P0000030?ooo`8000000`3o
ool2000000<0oooo00D000000?ooo`3oool0oooo000000040?ooo`05@000003oool0oooo0?oood00
0000103oool00`000000oooo0?ooo`020?ooo`05@000003oool0oooo0?oood000000103oool00d00
0000oooo0?ooo`0T0?ooo`009@3oool00`000000oooo0?ooo`070?ooo`8000001@3oool00d000000
00000?ooo`080?ooo`040000003oool0oooo0?ooo`800000203oool200000003@000003oool0oooo
0080oooo0P0000060?ooo`03@00000000000oooo00@0oooo00<000000?ooo`3oool00P3oool20000
00<0oooo0`0000000`3oool000000?ooo`050?ooo`03@00000000000oooo01P0oooo0P0000020?oo
o`800000?03oool00d00000000000?ooo`060?ooo`03@00000000000oooo00L0oooo0`0000090?oo
o`@000001`3oool3000000d0oooo00<000000?ooo`3oool01`3oool300000003@000003oool0oooo
0080oooo0P0000050?ooo`8000000P3oool200000003@000003oool0oooo00P0oooo0P0000001400
0000oooo0?ooo`0000040?ooo`03000004000000oooo0080000000@0oooo0000000000000000@P3o
ool002@0oooo0`0000080?ooo`80000000=000000?ooo`3oool04P3oool00`00001000000?ooo`07
0?ooo`030000003oool0oooo0080oooo0`00000=0?ooo`03@00000000000oooo0080oooo0P000000
0d000000oooo0?ooo`020?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool06`3oool2
00000003@000003oool0oooo03l0oooo00D000000?ooo`3oool0oooo000000070?ooo`04@000003o
ool0oooo000000X0oooo00<00000@000003oool0203oool00d000000oooo0?ooo`0;0?ooo`<00000
2@3oool00d000000oooo0?ooo`030?ooo`80000000=000000?ooo`3oool0203oool00`000000oooo
0?ooo`020?ooo`03@00000000000000000H0oooo00D000000?ooo`3oool00000@00000030?ooo`05
0000003oool0oooo0000040000000P3oool00`000000oooo0?ooo`110?ooo`00903oool200000003
@000003oool0oooo00L0oooo00<000000?ooo`3oool02`3oool00d000000oooo0?ooo`050?ooo`03
0000003ooom0000000H0oooo00D000000?ooo`3oool0oooo000000020?ooo`03@000003oool0oooo
00`0oooo0P00000C0?ooo`03@00000000000000001d0oooo00<000000?ooo`3oool0?`3oool01D00
000000000?ooo`3ooom00000008000001P3oool3000002@0oooo0P0000000d000000oooo00000006
0?ooo`<000005P3oool00d0000000000000000090?ooo`030000003oool0oooo00T0oooo00=00000
0?ooo`3oool0@@3oool00300oooo0P0000060?ooo`030000003oool0oooo0080oooo0`0000060?oo
o`<0000000<0oooo0000003oool00`3oool01@000000oooo0?ooo`3oool0000000H0oooo00H00000
@000003oool0oooo0000040000060?ooo`050000003oool0oooo0?ooo`000000103oool01@000000
oooo0?ooo`3oool0000000L0oooo0P00000;0?ooo`05000004000000oooo0?oood000000D03oool2
00000080oooo0P0000050?ooo`80000000=00000000000000000103oool00`000000oooo0?ooo`02
0?ooo`060000003oool0oooo0?ooo`000000oooo0P0000040?ooo`8000000`3oool2000000@0oooo
00<000000?ooo`3oool00`3oool00d0000000000000000050?ooo`H0000000<0oooo000000000000
103oool2000000P0oooo1@0000040?ooo`050000003oool0oooo0?ooo`000000103oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo04@0oooo000U0?ooo`04@000003oool0oooo0?ooo`80
00000`3oool00`000000oooo00000003000000<0oooo0P0000030?ooo`8000000P3oool300000003
@000003oool0000000<0000000<0oooo0000003oool00P3oool2000000<0oooo0P0000030?ooo`P0
000000<0oooo0000003oool00`3oool01@000000oooo0?ooo`3oool0000000<0oooo0P0000030?oo
o`8000000`3oool00`000000oooo0?ooo`020?ooo`H000000`3oool8000000050?ooo`0000000000
0000040000000`0000000d000000oooo@00000040?ooo`03@000003oool0oooo0080oooo00E00000
0?ooo`3oool0oooo@00000040?ooo`05@000003oool0oooo0?oood000000103oool00d000000oooo
0?ooo`0S0?ooo`05@000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`020?ooo`04
0000003oool0oooo0?ooo`8000000`3oool200000080oooo0P0000030?ooo`80000000A000000000
0000000000000P3oool01T0000000000000000000000oooo@00000<000000P3oool01@000000oooo
0?ooo`3oool0000000<0oooo0P0000030?ooo`030000003oool0oooo00<000000P3oool00d000000
000000000004000000030?ooo`0000000000008000000`3oool2000000<0oooo00<000000?ooo`3o
ool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo00@000000?ooo`3oool0oooo0P000003
0?ooo`03@000003oool0oooo0080oooo00E000000?ooo`3oool0oooo@00000040?ooo`03@000003o
ool0oooo0080oooo00E000000?ooo`3oool0oooo@00000040?ooo`03@000003oool0oooo02@0oooo
000W0?ooo`<00000103oool010000000oooo@000000000040?ooo`8000002@3oool00d0000000000
000000060?ooo`8000000P3oool00`00001000000?ooo`020?ooo`03000004000000oooo00@0oooo
0P0000020?ooo`@00000203oool200000080oooo0P0000040?ooo`050000003oool0oooo0?ooo`00
00001P3oool00d00000000000?ooo`060?ooo`8000001P3oool2000000<0oooo0P00000C0?ooo`03
@00000000000000004D0oooo00<00000@000000000000P0000040?ooo`030000003oool0oooo00h0
oooo0P0000020?ooo`03@00000000000000000X0oooo00=000000?ooo`3oool01P3oool01T000000
oooo0?ooo`3ooom00000000000h0oooo0P0000030?ooo`8000000P3oool2000000<0oooo0P000016
0?ooo`00:03oool00d000000oooo0?ooo`030?ooo`8000001`3oool00d000000oooo0?ooo`070?oo
o`<000001P3oool00`00001000000?ooo`0B0?ooo`8000002@3oool00`00001000000?ooo`020?oo
o`04@000003oool0oooo@0000080000000E000000?ooo`3oool00000@00000070?ooo`05@0000000
0000oooo0?ooo`000000903oool3000004<0oooo00<000000?ooo`0000000P3oool00`0000100000
0?ooo`030?ooo`03000004000000oooo00h0oooo00@00000@000003oool0oooo0`00000N0?ooo`03
@00000000000oooo00H0oooo00<00000@000040000000P3oool01P00001000000?ooo`3oool00000
@0000080oooo0P0000000d000000oooo0?ooo`0E0?ooo`03@000003oool0oooo02`0oooo000^0?oo
o`03000004000000oooo00H0oooo00<000000?ooo`3oool01`3oool2000000L0oooo00<000000?oo
o`3oool04`3oool00d000000oooo0?ooo`0<0?ooo`040000003oool0oooo0?ooo`8000000`3oool0
0`000000oooo0?ooo`060?ooo`80000000<0oooo@000000000009@3oool00`000000oooo0?ooo`0n
0?ooo`05@000003oool0oooo@00000000000403oool2000000d0oooo0P0000000d00000000000000
00020?ooo`800000103oool2000000<0oooo00<000000?ooo`3oool01@3oool00`00001000000?oo
o`040?ooo`8000001@3oool00`00001000000?ooo`02000000L0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0D0?ooo`<00000;@3oool002D0oooo00=000000?ooo`3oool00P3oool0
1D000000oooo0?ooo`3ooom0000000@0oooo0`0000000d0000000000000000030?ooo`8000000`3o
ool010000000oooo0?ooo`3oool300000003@000003oool0000000@0oooo00D000000?ooo`3oool0
oooo000000040?ooo`03@000003oool0000000<000000`3oool00`000000oooo0?ooo`020?ooo`04
0000003oool0oooo0?ooo`8000000`3oool010000000oooo0?ooo`3oool2000000<0oooo00<00000
0?ooo`0000000`0000030?ooo`040000003oool0oooo0?ooo`8000000`3oool300000005@0000000
000000000000040000000`00000014000000oooo0?oood0000040?ooo`03@000003oool0oooo0080
oooo00E000000?ooo`3oool0oooo@00000040?ooo`050000003oool0oooo0?oood000000103oool0
0d000000oooo0?ooo`0S0?ooo`05@000003oool0oooo0?oood000000103oool00d000000oooo0?oo
o`020?ooo`040000003oool0oooo0?ooo`8000000P3oool2000000<0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0800000080oooo0P0000040?ooo`06@000003oool0oooo0?ooo`00
0000oooo200000020?ooo`06@0000000000000000000003ooom000000P0000030?ooo`@0000000<0
oooo0000003oool00P3oool00`000000oooo0?ooo`020?ooo`@0000000H0oooo0000000000000000
0?ooo`0000040?ooo`040000003oool0oooo0?ooo`8000000`3oool00d000000oooo0?ooo`020?oo
o`05@000003oool0oooo0?oood000000103oool00d000000oooo0?ooo`020?ooo`050000003oool0
oooo0?oood000000103oool00d000000oooo0?ooo`0T0?ooo`00=@3oool200000004@00000000000
00000?ooo`8000002P3oool5000000<0oooo00@000000?ooo`3oool0oooo0P0000050?ooo`03@000
00000000oooo00@0oooo00<000000?ooo`3oool00P3oool200000080oooo0P0000020?ooo`800000
103oool00`000000oooo0?ooo`020?ooo`03000004000000000000D0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`020?ooo`<000000P3oool200000080oooo0P00001B0?ooo`030000
003oool0oooo00800000103oool010000000oooo0?ooo`3oool2000000<0oooo00D000000?ooo`3o
oom00000000000020?ooo`04@00000000000oooo0?ooo`<000002`3oool01T00000000000?ooo`3o
oom00000000000/0oooo0P0000060?ooo`8000000`3oool00`000000oooo0?ooo`040?ooo`@00000
0`3oool010000000oooo0?ooo`3oool200000080oooo0`0000160?ooo`00>03oool00`0000100000
00000002000000030?oood000000oooo00T0oooo0P0000000d000000oooo0?ooo`02000000@0oooo
00@000000?ooo`3ooom000000P0000060?ooo`03@0000000000000000080oooo00A0000000000000
001000000P0000030?ooo`03000004000000oooo00P0oooo0P0000000d000000oooo0?ooo`0?0?oo
o`030000003oool0oooo01`0oooo00=000000?ooo`3oool0>03oool200000080oooo00<000000?oo
o`3oool0203oool00`00001000000?ooo`03000000X0oooo00=000000?ooo`3oool07P3oool01400
000000000000003oool2000000040?oood000000oooo000000D0oooo00=000000000003oool00P3o
ool00d000000oooo0?ooo`02000000<0oooo0P0000030?ooo`03000004000000oooo04D0oooo000i
0?ooo`80000000=000000?ooo`0000000P0000090?ooo`030000003oool0oooo0080oooo00<00000
@000003oool00`3oool00`00001000000?ooo`03000000H0oooo0`0000020?ooo`<0000000=00000
000000000000103oool2000000D0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool09@3oool2000003T0oooo00<00000@000003oool0303o
ool00`000000oooo0?ooo`0200000003@000003oool0oooo02T0oooo0`0000020?ooo`04@000003o
ool00000@00000800000103oool300000080oooo0P0000000`3oool00000@00000020?ooo`03@000
00000010000004/0oooo000h0?ooo`8000000`3oool2000000d0oooo0P00000:0?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`02000000@0oooo1000
00020?ooo`03@00000000000000000L0oooo0`000000103oool000000000000000060?ooo`030000
04000000oooo01`0oooo0P00001=0?ooo`030000003oool0oooo0140oooo00<00000@000003oool0
1`3oool01P00001000000?ooo`3oool00000@00000<0oooo00<00000@000003oool0103oool00`00
0000oooo0?ooo`020?ooo`80000000<0oooo000000000000103oool2000000<0oooo0P0000060?oo
o`800000B`3oool002D0oooo00=000000?ooo`3oool00P3oool01D000000oooo0?ooo`3ooom00000
00@0oooo00=000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo00@00000
0?ooo`3oool0oooo0`0000000d000000oooo00000005000000<0oooo00<000000?ooo`3oool00P3o
ool01@000000oooo0?ooo`3ooom0000000@0oooo00<000000?ooo`3oool00P3oool01@000000oooo
0?ooo`3oool0000000@0oooo00<000000?ooo`0000000`0000020?ooo`8000000`3oool200000003
0?oood00000000000080000000A0000000000000000000000`3oool6000000@0oooo00D000000?oo
o`3oool0oooo@00000040?ooo`03@000003oool0oooo0080oooo00E000000?ooo`3oool0oooo@000
00040?ooo`050000003oool0oooo0?oood000000103oool00d000000oooo0?ooo`0S0?ooo`05@000
003oool0oooo0?oood000000103oool00d000000oooo0?ooo`020?ooo`04@000003oool0oooo0?oo
o`8000000`3oool200000080oooo0P0000020?ooo`800000103oool01@000000oooo0?ooo`3ooom0
000000@0oooo00@000000?ooo`3oool0oooo100000000`3ooom000000?ooo`030?ooo`P0000000<0
oooo0000000000001@0000000d000000oooo000000040?ooo`040000003oool0oooo0?ooo`800000
0`3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000103oool00`000000
oooo0?ooo`020?ooo`050000003oool0oooo0?oood000000103oool01D000000oooo0?ooo`3ooom0
000000@0oooo00=000000?ooo`3oool00P3oool200000080oooo00=000000?ooo`3oool00P3oool0
0d000000oooo0?ooo`0T0?ooo`00@@3oool00`000000oooo0?ooo`020?ooo`<000000`3oool00d00
000000000?ooo`050?ooo`8000006`3oool00d00000000000?ooo`060?ooo`<000003`3oool30000
00D0oooo00<000000?ooo`3oool0A`3oool00d00000000000?ooo`0<0?ooo`80000000=000000?oo
o`3oool0100000030?ooo`800000103oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
00<0oooo0P0000050?ooo`03@000000000000000008000000P3oool200000003@000000000000000
0080000000D0oooo0000000000000000@0000002000001D0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`0E0?ooo`03000004000000oooo02`0oooo000l0?ooo`04@00000000000oooo
0?ooo`<00000103oool00`000000oooo0?ooo`0:0?ooo`80000000A000000?ooo`3ooom000008@3o
ool00d000000oooo0?ooo`0?0?ooo`03@000003oool0oooo00<0oooo0P0000190?ooo`8000003P3o
ool020000000oooo0?ooo`3oool000000?oood00000000000P3oool200000004@000003oool0oooo
0?ooo`8000001`3oool3000000P0oooo00=000000000003oool00`0000060?ooo`<000001@3oool4
00000080oooo00=000000000003oool00`3oool01D00000000000?ooo`3ooom00000008000001P3o
ool2000000L0oooo0P00000G0?ooo`030000003oool0oooo02`0oooo000h0?ooo`040000003oool0
oooo0?ooo`8000000P3oool200000003@000003oool0oooo0100oooo00@000000?ooo`3oool0oooo
0P00000O0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool04@3oool00`0000100000
0?ooo`180?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool01@3oool00d0000000000
000000080?ooo`03000004000000oooo00H0oooo0P0000000d000000oooo0?ooo`060?ooo`050000
003oool0oooo0?ooo`000000203oool00`000000oooo0?ooo`060?ooo`040000003oool0oooo0?oo
o`800000103oool010000000oooo0?ooo`3oool2000000L0oooo00<00000@000003oool01P3oool0
0`00001000000?ooo`150?ooo`009`3oool2000000h0oooo0P0000030?ooo`030000003oool0oooo
0080oooo00D000000?ooo`3oool0oooo000000060?ooo`03000004000000oooo00T0oooo0P000000
0d00000000000000000:0?ooo`800000203oool00`00001000000?ooo`030?ooo`80000000H0oooo
00000000000000000?oood000002000000D0oooo0P0000070?ooo`030000003oool0oooo04P0oooo
00E000000?ooo`3oool0oooo000000040?ooo`03@000003oool0oooo0080oooo00=000000?oood00
00000P0000040?ooo`H000000`3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?oo
od000000103oool010000000oooo0?ooo`3oool300000004@000003oool00000000000<0oooo00D0
00000?ooo`3oool0oooo@00000040?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0
oooo000000040?ooo`040000003oool0oooo0?ooo`8000000`3oool2000000<0oooo00D000000?oo
o`3oool0oooo000000040?ooo`030000003oool0oooo0080oooo00E000000?ooo`3oool0oooo@000
00040?ooo`05@000003oool0oooo0?oood000000103oool00d000000oooo0?ooo`020?ooo`05@000
003oool0oooo0?oood000000103oool00d000000oooo0?ooo`0T0?ooo`009@3oool00d000000oooo
@0000003000000<0oooo00=000000?ooo`3oool00P3oool014000000oooo0?ooo`3oool2000000<0
oooo00<000000?ooo`3oool00`0000030?ooo`8000000`3oool4000000030?oood000000oooo0080
oooo0`0000000d000000oooo000000030?ooo`8000000`3oool00`000000oooo0?ooo`020?ooo`90
00000`0000040?ooo`@0000000<0oooo@000000000000`0000000`3ooom000000000000200000080
oooo0P0000040?ooo`<0000000=000000000000000000`3oool300000080oooo00E000000?ooo`3o
ool0oooo@00000040?ooo`03@000003oool0oooo0080oooo00E000000?ooo`3oool0oooo@0000004
0?ooo`05@000003oool0oooo0?oood000000103oool00d000000oooo0?ooo`0e0?ooo`800000203o
ool00`000000oooo0?ooo`02000000@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`030?ooo`80000000<0oooo0000003oool04@3oool00`000000oooo0?ooo`060?ooo`050000003o
ool0oooo0?ooo`000000103oool010000000oooo0?ooo`3oool200000080oooo0P0000020?ooo`80
0000C03oool003H0oooo0P0000000d000000oooo0?ooo`030?ooo`<000001@3oool2000000`0oooo
0`00000:0?ooo`030000003oool0oooo0180oooo0P00000@0?ooo`030000003oool0oooo00800000
00=000000?ooo`3oool00P0000000d000000oooo0?ooo`1G0?ooo`03@00000000000oooo00T0oooo
0P0000040?ooo`8000001`3oool300000180oooo00=000000?oood0000000P0000020?ooo`03@000
00000000oooo00<0oooo00A000000?ooo`3ooom000000P0000030?ooo`03@00000000000000000D0
oooo00<000000?oood0000000P0000000`3ooom0000000000002000004`0oooo000o0?ooo`03@000
003oool0oooo00@0oooo0P0000000d000000oooo0?ooo`0:0?ooo`030000003oool0oooo00P0oooo
0`0000000`3oool000000?ooo`020?ooo`030000003oool0oooo00L0oooo00D000000?ooo`3oool0
oooo@00000040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool010000000
oooo0?ooo`0000040?ooo`030000003oool0oooo05P0oooo0P0000050?ooo`030000003oool0oooo
00<0oooo00=000000?ooo`3oool00P3oool00`00001000000?ooo`060?ooo`80000000=000000?oo
o`3oool03`3oool2000000040?ooo`000000000000000080oooo0P0000040?ooo`80000000@0oooo
00000000000000000`3oool4000000<0oooo00<00000@000003oool00P0000001D000000oooo0000
00000010000004d0oooo000e0?ooo`800000:@3oool20000009000000P000000103oool000000000
000000020?ooo`8000000`3oool01400000000000000003oool2000000<0oooo00=0000000000000
00001P3oool00d0000000000000000020?ooo`03@0000000000000000640oooo00<000000?ooo`3o
ool0103oool00d00000000000000000U0?ooo`<0000000<0oooo0000003oool00`3oool010000000
oooo0?ooo`3oool2000000<0oooo00@000000?ooo`3oool0oooo0P0000000d000000000000000005
0?ooo`8000000P3oool2000004l0oooo000U0?ooo`03@000003oool0oooo0080oooo00E000000?oo
o`3oool0oooo@00000040?ooo`03@000003oool0000000<000000`3oool2000000<0oooo00@00000
0?ooo`3oool0oooo0`00000014000000oooo0000000000030?ooo`05@000003oool0oooo0?ooo`00
0000103oool01D000000oooo0?ooo`3ooom0000000@0oooo00A000000?ooo`3oool0oooo0P000000
1D0000000000000000000000oooo00@000000`3oool6000000<0oooo0P0000030?ooo`040000003o
ool0oooo0?ooo`8000000`3oool2000000<0oooo0P0000030?ooo`05@000003oool0oooo0?oood00
0000103oool00d000000oooo0?ooo`020?ooo`05@000003oool0oooo0?oood000000103oool01D00
0000oooo0?ooo`3ooom0000000@0oooo00=000000?ooo`3oool08`3oool01D000000oooo0?ooo`3o
oom0000000@0oooo00=000000?ooo`3oool00P3oool01D000000oooo0?ooo`3oool0000000@0oooo
00@000000?ooo`3oool0oooo0P0000030?ooo`030000003oool0oooo0080oooo00D000000?ooo`3o
ool0oooo@00000040?ooo`030000003oool0oooo0080oooo00E000000?ooo`3oool0oooo@0000004
0?ooo`04@000003oool0oooo0?ooo`8000000`3oool00`000000oooo0?ooo`020?ooo`050000003o
ool0oooo0?ooo`000000103oool01@000000oooo0?ooo`3oool0000000<0oooo0P0000040?ooo`05
0000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`020?ooo`05@000003oool0oooo
0?oood000000103oool01D000000oooo0?ooo`3ooom0000000@0oooo00=000000?ooo`3oool00P3o
ool01D000000oooo0?ooo`3ooom0000000@0oooo00=000000?ooo`3oool0903oool003D0oooo00=0
00000000003oool01@3oool4000000H0oooo0P0000020?ooo`80000000=000000?ooo`3oool0103o
ool2000001H0oooo00=000000000003oool01P3oool00d00000000000?ooo`090?ooo`030000003o
ool0oooo00`0oooo0P0000000d000000oooo0?ooo`1J0?ooo`8000002@3oool00`000000oooo0?oo
o`02000000T0oooo00<000000?ooo`3oool0>03oool2000004/0oooo000n0?ooo`<000002`3oool0
0`000000oooo0?ooo`050?ooo`03000004000010000000`0oooo00=000000?ooo`3oool03@3oool0
0d00000000000?ooo`0;0?ooo`8000003P3oool00`000000oooo0?ooo`1J0?ooo`<00000203oool2
000000040?ooo`0000000000000000P0oooo0`0000060?ooo`03@00000000000000000l0oooo00=0
00000000003oool01@3oool01D000000oooo0?oood00000000000080oooo00=000000000003oool0
0P3oool00`000000oooo0?ooo`090?ooo`040000040000000000000004X0oooo000o0?ooo`03@000
003oool0oooo0180oooo0`00000;0?ooo`<000003P3oool2000000030?ooo`000000oooo00T0oooo
00<00000@000003oool0J`3oool2@00000030000003oool0000000D0oooo00D00000@000003oool0
oooo@00000090?ooo`80000000=000000?ooo`3oool0103oool300000100oooo00<000000?ooo`3o
ool00`3oool3000000050?ooo`00000000000000003oool00P000000103ooom0000000000000000<
0?ooo`<00000BP3oool003`0oooo0P0000030?ooo`030000003oool0oooo00<0oooo00<00000@000
003oool02P3oool2000000@0oooo0P0000060?ooo`800000403oool5000000P0oooo0P0000090?oo
o`800000HP3oool2000000040?oood0000000000000000@0oooo00<000000?ooo`3oool00`3oool2
000000l0oooo00<000000?ooo`3oool03`3oool2000000@0oooo0P0000020?ooo`8000000P3oool0
10000000oooo0?ooo`3oool2000000@0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?oo
o`3oool0000004/0oooo000U0?ooo`03@000003oool0oooo0080oooo00E000000?ooo`3oool0oooo
@00000040?ooo`03@000003oool0oooo0080oooo00=000000?ooo`0000000P0000030?ooo`800000
0`3oool4000000070?ooo`0000000000000004000000oooo000000030?ooo`030000003oool0oooo
0080oooo00=000000?ooo`0000000`0000030?ooo`030000003oool0oooo0080oooo00I000000?oo
o`3oool0oooo@000003oool4000000@0oooo00<00000@000000000001`000000103oool000000000
000000030?ooo`<0000000=000000?ooo`0000001@0000040?ooo`05@000003oool0oooo0?oood00
0000103oool00d000000oooo0?ooo`020?ooo`05@000003oool0oooo0?oood000000103oool01D00
0000oooo0?ooo`3ooom0000000@0oooo00=000000?ooo`3oool08`3oool01D000000oooo0?ooo`3o
oom0000000@0oooo00=000000?ooo`3oool00P3oool01D000000oooo0?ooo`3ooom0000000@0oooo
00@000000?ooo`3oool0oooo0P0000030?ooo`030000003oool0oooo0080oooo00<00000@0000000
00000P0000040?ooo`<0000000=000000?oood0000000`3oool00`000000oooo0?ooo`020?ooo`80
00000P3oool00d000000oooo0?ooo`020?ooo`03@000003oool0oooo0080oooo00D000000?ooo`3o
ool0oooo000000040?ooo`050000003oool0oooo0?ooo`000000103oool010000000oooo0?ooo`3o
ool2000000<0oooo0P0000030?ooo`030000003oool0oooo0080oooo00E000000?ooo`3oool0oooo
@00000040?ooo`05@000003oool0oooo0?oood000000103oool00d000000oooo0?ooo`020?ooo`05
@000003oool0oooo0?oood000000103oool00d000000oooo0?ooo`0T0?ooo`00>`3oool00d000000
oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo0P0000020?ooo`<0000000<0oooo0000003o
ool02@3oool00d00000000000?ooo`0@0?ooo`8000002`3oool00d00000000000?ooo`030?ooo`80
00001@3oool200000080oooo00<00000@00000000000H`3oool00`000000oooo0?ooo`050?ooo`<0
00000P3oool2000000T0oooo0`00000;0?ooo`03000004000000oooo01l0oooo0`0000030?ooo`03
0000003oool0oooo04h0oooo000o0?ooo`03000004000000oooo00@0oooo00=000000000003oool0
0`3oool01`000000oooo000000000000oooo@00000000000103oool01D00000000000000003ooom0
0000008000000P3oool00d00000000000?ooo`030?ooo`05@00000000000oooo@000000000000P3o
ool2@00000040000003oool0oooo000000<0oooo00=000000000000000001`3oool00d000000oooo
0?ooo`1/0?ooo`030000003oool0oooo00L0oooo0P00000014000000oooo00000000000;0?ooo`03
@000003oool0oooo00X0oooo00<000000?ooo`3oool0403oool00d000000oooo0?ooo`0=0?ooo`06
000004000000oooo0?ooo`0000100000D03oool004H0oooo0`0000050?ooo`050000040000000000
@00000000000103oool300000080oooo0P0000020?ooo`800000103oool2000000030?ooo`000000
000000<0oooo0P000000103ooom000000000000000030?ooo`800000M@3oool00d00000000000000
000=0?ooo`03@000003oool0oooo00P0oooo0P0000080?ooo`03000004000000oooo0080oooo00=0
00000?ooo`3oool01P3oool01T000000oooo0?ooo`3oool00000@0000080oooo0`0000020?ooo`03
000004000000oooo05l0oooo000U0?ooo`03@000003oool0oooo0080oooo00E000000?ooo`3oool0
oooo@00000040?ooo`03@000003oool0oooo0080oooo00E000000?ooo`3oool0oooo000000030?oo
o`@0000000A0000000000000000000000P3oool00`000000oooo0?ooo`020?ooo`D00000103oool0
10000000oooo0?ooo`3oool2000000<0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?oo
o`3oool0000000@0oooo00<000000?ooo`3oool00`0000020?ooo`800000103oool01@000000oooo
0?ooo`3oool0000000@0oooo0P0000020?ooo`8000000`3oool00d000000oooo0?ooo`020?ooo`05
@000003oool0oooo0?oood000000103oool00d000000oooo0?ooo`020?ooo`050000003oool0oooo
0?oood000000103oool01D000000oooo0?ooo`3ooom0000000@0oooo00=000000?ooo`3oool08`3o
ool01D000000oooo0?ooo`3ooom0000000@0oooo00=000000?ooo`3oool00P3oool01D000000oooo
0?ooo`3ooom0000000<0oooo0P0000030?ooo`8000000`3oool6000000<0oooo00<000000?ooo`3o
ool00P3oool700000003@000003oool0000000<0000000<0oooo0000000000001@0000000d000000
oooo00000002000000030?ooo`00000000000080000000<0oooo0000000000000P3oool400000003
0?ooo`000000000000@00000103oool010000000oooo0?ooo`3oool2000000<0oooo00=000000?oo
o`3oool00P3oool01D000000oooo0?ooo`3ooom0000000@0oooo00E000000?ooo`3oool0oooo0000
00040?ooo`03@000003oool0oooo0080oooo00E000000?ooo`3oool0oooo@00000040?ooo`03@000
003oool0oooo02@0oooo000k0?ooo`800000103oool5000000@0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000103oool01@000000oooo
0?ooo`3oool0000000@0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool00000
00@0oooo0P0000020?ooo`030000003oool0oooo00<0oooo0P00000014000000oooo00000000000E
0?ooo`030000003oool0oooo0500oooo0P0000040?ooo`03000004000000000000H0oooo0P000008
0?ooo`8000000`3oool2000000H0oooo0`0000030?ooo`8000000P3oool2000000T0oooo0`000000
0d00000000000?ooo`040?ooo`80000000@0oooo00000000000000005@3oool2000003T0oooo000j
0?ooo`8000001`3oool010000000oooo@000000000020?ooo`<000000`3oool01P000000oooo0?oo
o`3ooom00000000000<0oooo00=000000?ooo`3oool01@3oool00`000000oooo0?ooo`030?ooo`03
@000003oool0oooo00D0oooo00<000000?ooo`3oool0303oool0140000000000@000003oool20000
00<0oooo00=000000?ooo`0000000P3oool200000003@00000000000oooo0140oooo0P00001B0?oo
o`800000103oool3000000H0oooo0P0000000d000000oooo0?ooo`0:0?ooo`03@000003oool0oooo
00L0oooo00<000000?ooo`3oool02@3oool00d000000oooo0?ooo`030?ooo`<00000203oool20000
0080oooo00=000000?ooo`3oool0103oool00d000000oooo0?ooo`0<0?ooo`800000>P3oool003/0
oooo00=000000?ooo`3oool01`3oool3000000030?ooo`000000000000=000000P0000030?ooo`80
00000`3oool2000000030?ooo`000000oooo0080oooo00=000000000003oool0103oool2000000D0
oooo00=000000000003oool00P3oool00`000000oooo0?ooo`020?ooo`03@00000000000oooo00<0
oooo0P0000020?ooo`03000004000000oooo0080oooo0P0000040?ooo`0300000400000000000180
oooo00<00000@000003oool0D03oool200000003@000003oool0oooo00<0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`0:0?ooo`800000103oool00d000000oooo0?ooo`020?ooo`03
0000003oool0oooo00T0oooo0P0000050?ooo`03000004000000oooo00H0oooo0P0000000d000000
oooo0?ooo`070?ooo`8000003P3oool00d000000oooo0?ooo`0h0?ooo`00<03oool00`0000100000
0?ooo`0?0?ooo`030000003oool0oooo00800000103oool2000000030?ooo`000000000000<0oooo
00<000000?ooo`3oool00P3oool200000003@00000000000000000<0oooo0P0000040?ooo`800000
1P3oool2000000040?oood0000000000000000<0oooo0P0000040?ooo`8000000P3oool00`000000
oooo0?ooo`020?ooo`8000001P3oool2000006@0oooo00=000000000003oool03P3oool00`000010
00000?ooo`020?ooo`03000004000000oooo00D0oooo0`0000020?ooo`<000000P3oool3000000H0
oooo00<00000@000003oool00P0000040?ooo`03000004000000oooo01<0oooo0P00001:0?ooo`00
9@3oool00d000000oooo0?ooo`020?ooo`04@000003oool0oooo0?ooo`@0000000<0oooo@000003o
ool00`3oool01D000000oooo0?ooo`3ooom0000000<0oooo0P0000030?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo00@00000
0?ooo`3oool0oooo0P0000030?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo
000000040?ooo`040000003oool0oooo0?ooo`8000000`3oool00`000000oooo0?ooo`020?ooo`04
0000003oool0oooo0?ooo`8000000`3oool00`000000oooo0?ooo`020?ooo`05@000003oool0oooo
0?ooo`000000103oool01D000000oooo0?ooo`3ooom0000000@0oooo00=000000?ooo`3oool00P3o
ool01D000000oooo0?ooo`3ooom0000000@0oooo00E000000?ooo`3oool0oooo@00000040?ooo`03
@000003oool0oooo02<0oooo00E000000?ooo`3oool0oooo@00000030?ooo`800000103oool01D00
0000oooo0?ooo`3ooom0000000@0oooo00A000000?ooo`3oool0oooo0P0000030?ooo`<0000000=0
00000000000000000`3oool4000000030?ooo`000000000000D0000000A000000?ooo`0000000000
0`3oool200000080oooo0P0000001400000000000000000000030?ooo`@0000000<0oooo0000003o
ool00P3oool4000000060?ooo`0000000000000004000000oooo0P0000020?ooo`8000000`3oool0
0d000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00E000000?ooo`3oool0oooo@000
00040?ooo`05@000003oool0oooo0?oood000000103oool00d000000oooo0?ooo`020?ooo`05@000
003oool0oooo0?oood000000103oool00d000000oooo0?ooo`0T0?ooo`00<03oool2000000d0oooo
0`00000V0?ooo`<000003@3oool00`000000oooo0?ooo`070?ooo`03000004000000oooo05/0oooo
0`00000C0?ooo`030000003oool0oooo0080oooo0`000000103oool000000000040000030?ooo`80
00000`3oool200000080oooo0P00000;0?ooo`<000005@3oool4000000@0oooo0P0000000d000000
oooo0?ooo`1@0?ooo`00@03oool00d000000oooo0?ooo`0A0?ooo`03@000003oool0oooo00@0oooo
00<000000?ooo`3oool02`3oool01@000000oooo0?ooo`3ooom00000008000000`3oool00d000000
00000000000<0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool01@3oool00d000000
oooo0?ooo`140?ooo`8000006@3oool01`000000oooo0?ooo`3oool000000?ooo`0000003`3oool0
1400000000000?oood000002000000D0oooo00D000000?ooo`3ooom000000000000C0?ooo`03@000
00000000oooo00D0oooo00<000000?ooo`3oool00`3oool00d0000000000000000040?ooo`03@000
003oool0oooo04<0oooo00160?ooo`030000003oool0oooo00/0oooo0P0000040?ooo`03@0000000
0000000000/0oooo00<00000@000003oool00`3oool2000000<0oooo0P00000L0?ooo`03@0000000
0000000000D0oooo0`0000150?ooo`03@000003oool0oooo01D0oooo00<000000?ooo`3oool01@3o
ool00d00000000000?ooo`0>0?ooo`H00000203oool00`000000oooo0?ooo`030?ooo`03@000003o
ool0oooo00`0oooo0P00000<0?ooo`<000000`3oool3000004@0oooo00150?ooo`8000000`3oool0
0`000000oooo0?ooo`020?ooo`040000003oool0oooo0?ooo`800000103oool4000000X0oooo00=0
0000000000000000103oool2000000<0oooo0P0000070?ooo`030000003oool0oooo00800000103o
ool2000000/0oooo0P0000050?ooo`800000?`3oool01D000000oooo0?ooo`3ooom0000000@0oooo
00=000000?ooo`3oool00P3oool01D000000oooo0?ooo`3ooom0000000@0oooo00E000000?ooo`3o
ool0oooo@00000020?ooo`03@00000000000000000<0oooo0P0000020?ooo`800000103oool20000
0080oooo0P0000030?ooo`<000000P3oool01@000000oooo0?ooo`3oool0000000@0oooo0P000003
0?ooo`<0000000L0oooo0000000000000000@000003oool0000000<0oooo0P0000030?ooo`030000
003oool0oooo0080oooo0P0000020?ooo`03@000003oool0oooo0080oooo00<000000?ooo`3oool0
0P3oool200000080oooo00<000000?ooo`3oool00P3oool01D000000oooo0?ooo`3ooom0000000@0
oooo00=000000?ooo`3oool00P3oool01D000000oooo0?ooo`3ooom0000000@0oooo00=000000?oo
o`3oool0903oool002D0oooo00=000000?ooo`3oool00P3oool01D000000oooo0?ooo`3ooom00000
00@0oooo00=000000?ooo`3oool00P3oool01D000000oooo0?ooo`3ooom0000000@0oooo00E00000
0?ooo`3oool0oooo000000040?ooo`8000000P3oool2000000<0oooo00<000000?ooo`3oool00P3o
ool:000000<0oooo1P0000040?ooo`040000003oool0oooo0?ooo`8000000`3oool300000005@000
0000000000000?oood0000000`0000030?ooo`80000000A000000?ooo`3ooom000000`3oool00`00
0000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000103oool00d000000oooo0?ooo`02
0?ooo`05@000003oool0oooo0?oood000000103oool01D000000oooo0?ooo`3ooom0000000@0oooo
00=000000?ooo`3oool0@`3oool5000000@0oooo00<000000?ooo`3oool00`3oool200000003@000
00000000000000<0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000@0
oooo00@000000?ooo`3oool0oooo0P0000050?ooo`@0000000@0oooo0000000000000000103oool0
0`000000oooo0?ooo`03000000P0oooo00D000000?ooo`3oool0oooo000000050?ooo`800000@03o
ool004@0oooo00<00000@000003oool0103oool010000010000000000000000@0?ooo`8000001P3o
ool200000100oooo0P000000103oool000000000040000080?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool0JP3oool00d000000oooo0?ooo`0;0?ooo`040000003oool00000000000/0
oooo0`00000@0?ooo`8000000P3oool00d000000oooo0?ooo`070?ooo`03@000003oool0oooo0140
oooo0P0000000d000000oooo0?ooo`0m0?ooo`00B`3oool300000003@000003oool0oooo00@0oooo
00=000000?ooo`3oool01`3oool00d000000oooo0?ooo`0E0?ooo`05@00000000000oooo0?oood00
00000P0000090?ooo`03@000003oool0oooo00@0oooo0`00001]0?ooo`030000003oool0oooo00/0
oooo0P0000000d000000oooo0?ooo`080?ooo`80000000=000000?ooo`3oool03@3oool200000003
@000003oool0oooo00h0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0n0?ooo`00
D@3oool00`00001000000?ooo`0300000200oooo0P0000030?ooo`8000000P3oool00`000000oooo
0?ooo`030?ooo`<000001@3oool200000003@000003oool0oooo06X0oooo00=000000000003oool0
703oool2000000<0oooo0P00000;0?ooo`03000004000000oooo0080oooo00<00000@000003oool0
0P0000050?ooo`03@00000000000oooo0500oooo000U0?ooo`03@000003oool0oooo0080oooo00E0
00000?ooo`3oool0oooo@00000040?ooo`03@000003oool0oooo0080oooo00E000000?ooo`3oool0
oooo@00000040?ooo`05@000003oool0oooo0?oood000000103oool2000000<0oooo1P0000030?oo
o`040000003oool0oooo0?ooo`8000000`3oool300000003@000003oool0000000<0oooo00<00000
0?ooo`3oool00P3oool010000000oooo0?ooo`3oool2000000<0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`03000000<0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?oo
o`3oool0000000@0oooo00E000000?ooo`3oool0oooo@00000040?ooo`03@000003oool0oooo0080
oooo00E000000?ooo`3oool0oooo@00000040?ooo`05@000003oool0oooo0?oood000000103oool0
0d000000oooo0?ooo`0S0?ooo`05@000003oool0oooo0?oood000000103oool00d000000oooo0?oo
o`020?ooo`05@000003oool0oooo0?oood000000103oool01D000000oooo0?ooo`3ooom0000000@0
oooo00A000000?ooo`3oool0oooo0P0000030?ooo`030000003oool0oooo0080oooo1P0000030?oo
o`030000003oool0oooo0080oooo00<000000?ooo`0000001`0000000`3oool00000000000020000
00<0oooo0P0000020?ooo`@0000000<0oooo000000000000100000040?ooo`030000003oool0oooo
00800000103oool00`000000oooo0?ooo`020?ooo`05@000003oool0oooo0?oood000000103oool0
1D000000oooo0?ooo`3ooom0000000@0oooo00=000000?ooo`3oool00P3oool01D000000oooo0?oo
o`3ooom0000000@0oooo00=000000?ooo`3oool0903oool004P0oooo0`0000060?ooo`8000001@3o
ool00`000000oooo0?ooo`020?ooo`80000000=000000?ooo`3oool00`0000000`3oool000000?oo
o`020?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool0oooo0P0000030?ooo`030000
003oool0oooo00H0oooo0P0000000d000000oooo0?ooo`030?ooo`8000001@3oool2000006d0oooo
00@000000?ooo`3oool0oooo0P0000040?ooo`03000004000000000000D0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo00000002000000030?oood000000000000<0oooo00=000000000003o
ool00P3oool3000000`0oooo0P0000040?ooo`8000001`3oool00`000000oooo0?ooo`190?ooo`00
B@3oool00d000000oooo0?ooo`080?ooo`04@000003oool0oooo0?ooo`8000001@3oool200000080
oooo00D000000?ooo`3oool00000@00000020?ooo`04000004000000oooo0?ooo`<000000`3oool0
0`00001000000?ooo`090?ooo`8000001P3oool3000000030?oood000000oooo0080oooo0P000000
0d000000oooo0?ooo`0G0?ooo`03@000003oool0oooo05D0oooo00<00000@000003oool00`3oool0
0`000000oooo0?ooo`030?ooo`<000000P3oool2000000030?oood000000oooo00X0oooo00A00000
0?oood00000000003@3oool014000000oooo0?oood0000030?ooo`03000004000000oooo00@0oooo
0`0000020?ooo`03@00000000000oooo04D0oooo001?0?ooo`030000003oool0oooo0080oooo0P00
00020?ooo`03000004000000oooo00@0oooo00=000000000003oool0103oool010000000oooo0?oo
o`3oool600000005@000003oool0oooo0?ooo`0000002P3oool00d00000000000?ooo`070?ooo`03
@000003oool00000008000000`3oool00`000000oooo0?ooo`0H0?ooo`800000EP3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo0080oooo0P0000001d000000oooo0?ooo`0000100000
0?oood0000002`3oool200000005@00000000000oooo0?ooo`000000303oool300000080oooo00<0
00000?ooo`3oool0103oool200000003@000003oool0oooo00800000AP3oool004h0oooo0P000003
0?ooo`8000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo0P0000080?ooo`80000000@0
oooo0000000000000000203oool010000000oooo0?ooo`3oool200000080oooo0P0000090?ooo`80
0000103oool2000000L0oooo00<00000@000003oool03P3oool2000005H0oooo0P0000020?ooo`80
000000@0oooo@0000000000000001@3oool010000000oooo0?ooo`3oool3000000D0oooo00<00000
0?ooo`3oool00P3oool200000080oooo0P000000103oool000000000000000050?ooo`030000003o
ool0oooo0080oooo0P00000@0?ooo`030000003oool0oooo04@0oooo000U0?ooo`03@000003oool0
oooo0080oooo00E000000?ooo`3oool0oooo@00000040?ooo`03@000003oool0oooo0080oooo00A0
00000?ooo`3oool0oooo0P0000030?ooo`05@000003oool0oooo0?oood000000103oool014000000
oooo0?ooo`3oool2000000<0oooo00@000000?ooo`3oool0oooo0P0000030?ooo`<000000P3oool0
0`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000000P3oool01400000000000000
000000030?ooo`050000003oool0oooo0?ooo`000000103oool01@00001000000?ooo`3oool00000
00@0oooo00A000000?ooo`3oool0oooo0P0000030?ooo`03@000003oool0000000<000000`3oool4
000000030?oood000000oooo00<0oooo00E000000?ooo`3oool0oooo@00000040?ooo`050000003o
ool0oooo0?oood000000103oool00d000000oooo0?ooo`0S0?ooo`05@000003oool0oooo0?oood00
0000103oool00d000000oooo0?ooo`020?ooo`05@000003oool0oooo0?oood0000000`3oool20000
00<0oooo00=000000?ooo`3oool00P3oool00d000000oooo0?ooo`020?ooo`04@000003oool0oooo
@00000<000000P3oool200000004@000003oool0000000000080oooo0P0000030?ooo`L000000`3o
ool200000080oooo0P0000030?ooo`030000003ooom0000000<000000P3oool3000000<0oooo00<0
00000?ooo`3oool00P3oool014000000oooo0?ooo`3oool2000000<0oooo00=000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`02000000@0oooo00E000000?ooo`3oool0oooo@00000040?ooo`03
@000003oool0oooo0080oooo0P0000020?ooo`03@000003oool0oooo0080oooo00=000000?ooo`3o
ool0903oool003d0oooo0P0000000d000000oooo0?ooo`0=0?ooo`03@000003oool0oooo00D0oooo
0P0000040?ooo`80000000=000000?ooo`3oool0103oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0oooo00800000103oool00`000000oooo0?ooo`0A0?ooo`03@00000000000oooo00H0oooo
0P00001B0?ooo`<000005`3oool3000000@0oooo0`0000060?ooo`03@00000000000oooo00@0oooo
0P0000000d000000oooo0?ooo`0=0?ooo`03@000003oool0oooo00`0oooo0P0000000d000000oooo
0?ooo`050?ooo`@000004`3oool00`00001000000?ooo`0/0?ooo`00>`3oool010000000oooo0?oo
o`00000G0?ooo`80000000E000000?ooo`3oool0oooo@0000002000000@0oooo00E000000?ooo`3o
ool00000@00000070?ooo`04@00000000000oooo0?ooo`80000000@0oooo@0000000000000000P3o
ool00`000000oooo0?ooo`050?ooo`03@000003oool0oooo00l0oooo00E000000?ooo`3ooom00000
000000090?ooo`03@000003oool0oooo0080oooo0T0000000`000000oooo0?ooo`120?ooo`05@000
003oool0oooo0?oood0000005@3oool00`000000oooo0?ooo`040?ooo`03@000003oool0oooo00d0
oooo00<000000?ooo`3oool04@3oool00d000000oooo0?ooo`0:0?ooo`030000003oool0oooo00L0
oooo00<00000@000003oool04`3oool00d000000oooo0?ooo`0/0?ooo`00>P3oool00d0000000000
0?ooo`0K0?ooo`040000003oool0oooo0?ooo`800000103oool200000080oooo00<000000?ooo`3o
ool01P3oool200000080oooo00P00000@000003oool0oooo000004000000oooo@000008000001@3o
ool3000000l0oooo0`0000000`3oool00000000000080?ooo`<000000P3oool4000004L0oooo0P00
000U0?ooo`030000003oool0oooo01H0oooo0`00000[0?ooo`<00000;@3oool002D0oooo00=00000
0?ooo`3oool00P3oool01D000000oooo0?ooo`3ooom0000000@0oooo00=000000?ooo`3oool00P3o
ool00d000000oooo0?ooo`02000000@0oooo00E000000?ooo`3oool0oooo@00000040?ooo`03@000
003oool0oooo0080oooo00E000000?ooo`3oool0oooo000000040?ooo`050000003oool0oooo0?oo
o`000000103oool6000000<0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`3oool2
00000080oooo0P0000030?ooo`8000000`3oool2000000<0oooo00=000000?ooo`3oool00P3oool0
1@000000oooo0?ooo`3ooom0000000@0oooo00D000000?ooo`3oool0oooo000000040?ooo`040000
003oool0oooo0?ooo`8000000`3oool3000000030?ooo`000000000000<0oooo00=000000?ooo`3o
ool00P3oool00d000000oooo0?ooo`0S0?ooo`05@000003oool0oooo0?oood000000103oool00d00
0000oooo0?ooo`020?ooo`05@000003oool0oooo0?oood000000103oool400000003@000003oool0
oooo0080oooo00=000000?ooo`3oool00P3oool01D000000oooo0?ooo`3ooom0000000@0oooo00<0
00000?ooo`3oool0100000020?ooo`<0000000A000000?ooo`000000oooo0`0000030?ooo`800000
0`3oool300000004@000003oool00000000000<0oooo0`0000000d00000000000000000200000003
0?ooo`000000oooo00<0oooo00=000000000000000000P0000040?ooo`04@000003oool0oooo0?oo
o`8000000`3oool300000003@000003oool0000000<0oooo00<000000?ooo`3oool00P3oool01000
0000oooo0?ooo`3oool2000000<0oooo00=000000?ooo`3oool00P3oool00d000000oooo0?ooo`0T
0?ooo`00E03oool2000000040?ooo`000000000000000080oooo00<000000?ooo`3oool01P3oool2
000000<0oooo0P0000030?ooo`040000003oool0oooo0?ooo`8000000`3oool00`000000oooo0?oo
o`0>0?ooo`8000003@3oool00`000000oooo0?ooo`020?ooo`<000001P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo05P0oooo0P0000030?ooo`03@00000000000oooo00@0oooo0`00
0000103oool00000000004000006000000D0oooo1@0000060?ooo`8000001@3oool00`000000oooo
0?ooo`030?ooo`03@00000000000oooo00X0oooo0P00000014000000oooo0?ooo`3oool3000000D0
oooo0P0000020?ooo`800000<`3oool005@0oooo0P00000014000000000000000400000:0?ooo`<0
0000103oool00`000000oooo0?ooo`060?ooo`03000004000000oooo00D0oooo00=000000000003o
ool02@3oool3000000030?oood000000oooo0100oooo0P0000000d000000oooo0?ooo`0B0?ooo`03
@000003oool0oooo04d0oooo0`00000<0?ooo`040000003oool00000000000D0oooo00=000000?oo
o`3oool01P3oool00`00001000000?ooo`020?ooo`030000003oool0oooo00L0oooo0`00000@0?oo
o`04@00000000000oooo000000<0oooo0`0000050?ooo`80000000Q000000?ooo`3oool00000@000
003ooom00000000002l0oooo001E0?ooo`030000003oool0oooo00d0oooo00<00000@000003oool0
0`3oool00`00001000000?ooo`060?ooo`030000003oool0oooo00D0oooo0P00000;0?ooo`04@000
003oool0000000000140oooo00<000000?ooo`3oool00`3oool00d000000oooo0?ooo`0>0?ooo`80
0000C`3oool00d000000oooo0?ooo`0=0?ooo`80000000=000000?ooo`3oool03`3oool00d000000
0000000000080?ooo`80000000=000000?ooo`3oool03P3oool2000000H0oooo00=000000?ooo`3o
ool01@3oool01@000000oooo0?ooo`3oool000000080oooo0P00000_0?ooo`00O@3oool00`000000
oooo0?ooo`0;0?ooo`<00000503oool3000000<0oooo0P00000:0?ooo`@00000C@3oool2000000L0
oooo0P0000030?ooo`8000005P3oool2000000H0oooo00<00000@000003oool04`3oool00`000000
oooo0?ooo`0D0?ooo`030000003oool0oooo02d0oooo000U0?ooo`03@000003oool0oooo0080oooo
00E000000?ooo`3oool0oooo@00000040?ooo`03@000003oool0oooo0080oooo00E000000?ooo`3o
ool0oooo@00000040?ooo`05@000003oool0oooo0?oood000000103oool00d000000oooo0?ooo`02
0?ooo`05@000003oool0oooo0?ooo`000000103oool014000000oooo0?ooo`3oool2000000<0oooo
00<000000?ooo`3oool00P3oool01D000000oooo0?ooo`3ooom0000000@0oooo00=000000?ooo`3o
ool00P3oool01D000000oooo0?ooo`3oool0000000@0oooo00D000000?ooo`3oool0oooo00000004
0?ooo`04@000003oool0oooo0?ooo`8000000`3oool010000000oooo0?ooo`3oool2000000<0oooo
00=000000?ooo`3oool00P3oool010000000oooo0?ooo`3oool2000000<0oooo00<000000?ooo`00
00000`0000030?ooo`03@000003oool0oooo0080oooo0P00000T0?ooo`05@000003oool0oooo0?oo
od000000103oool00d000000oooo0?ooo`020?ooo`05@000003oool0oooo0?oood000000103oool0
1D000000oooo0?ooo`3ooom0000000@0oooo00=000000?ooo`3oool00P3oool01T000000oooo0?oo
o`3ooom000000?ooo`@00000103oool00d000000000000000002000000030?ooo`00000000000080
00000`3oool00d000000oooo0?ooo`020?ooo`03@000003oool0oooo0080oooo00E000000?ooo`3o
ool0oooo@00000040?ooo`040000003oool0oooo0?ooo`H00000103oool01D000000oooo0?ooo`3o
ool0000000@0oooo00=000000?ooo`3oool00P3oool01@000000oooo0?ooo`3ooom0000000@0oooo
00@000000?ooo`3oool0oooo0P0000030?ooo`03@000003oool0oooo0080oooo00D000000?ooo`3o
ool0oooo@00000040?ooo`030000003oool0oooo02@0oooo001B0?ooo`8000001`3oool300000080
oooo0P00000E0?ooo`800000203oool2000000`0oooo00<000000?ooo`0000000P0000090?ooo`80
00001P3oool2000000030?oood000000000005/0oooo00=000000000003oool01P3oool00d000000
00000?ooo`020?ooo`03@00000000000oooo01d0oooo100000080?ooo`800000403oool2000000@0
oooo0P0000000d000000oooo0?ooo`0=0?ooo`8000009@3oool003h0oooo00=000000?ooo`3oool0
4@3oool2000000H0oooo0`0000020?ooo`800000303oool00`000000oooo0?ooo`030?ooo`03@000
00000000oooo008000000`3oool00`000000oooo0?ooo`040?ooo`04000004000000oooo@0000080
00001P3oool300000003@000003oool0oooo00X0oooo00<00000@000003oool00`3oool2000000H0
oooo00=000000?ooo`3oool00`3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo00@0
oooo00=000000000003oool0103oool00`000000oooo0?ooo`0B0?ooo`03@000003oool0oooo0080
oooo00=000000?ooo`3oool01P3oool00d0000000000@0000002000000P0oooo00<00000@000003o
ool03@3oool00`0000100000000000040?ooo`<000003`3oool00`0000100000@000000T0?ooo`00
?@3oool300000140oooo00=000000000040000001`3oool00`00001000000?ooo`020?ooo`04@000
003oool0oooo@00000@0oooo00E000000?ooo`3oool0oooo@0000002000000@0oooo0P0000020?oo
o`04@000003oool0oooo@000008000001@3oool00`000000oooo0?ooo`03000000H0oooo0P000000
0d000000oooo0?ooo`0;0?ooo`030000003oool0oooo00@0oooo00=000000?ooo`3oool0103oool2
000000<0oooo00=00000000000000000C@3oool00d00000000000?ooo`050?ooo`<000000`3oool0
0d00000000000?ooo`0C0?ooo`8000000P3oool3000000H0oooo1P0000080?ooo`030000003oool0
oooo00h0oooo0P0000050?ooo`03@00000000000000000h0oooo0`00000T0?ooo`00?@3oool20000
01<0oooo0P00000>0?ooo`<000000P3oool3000000<0oooo0P0000050?ooo`030000003oool0oooo
00<0oooo0`0000000`3oool00000000000060?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool0203oool2000000l0oooo0P0000050?ooo`800000?@3oool2000000l0oooo0P0000040?oo
o`<000001@3oool2000000@0oooo00D000000?ooo`3oool0oooo000000090?ooo`8000000`3oool2
00000080oooo00<000000?ooo`3oool00P3oool200000080oooo00<000000?ooo`3oool02`3oool0
0`000000oooo0?ooo`0;0?ooo`<00000103oool2000000@0oooo0P0000080?ooo`8000009@3oool0
02D0oooo00=000000?ooo`3oool00P3oool01D000000oooo0?ooo`3ooom0000000@0oooo00=00000
0?ooo`3oool00P3oool01D000000oooo0?ooo`3oool0000000@0oooo00E000000?ooo`3oool0oooo
@00000040?ooo`03@000003oool0000000<000000`3oool00`000000oooo0?ooo`020?ooo`03@000
003oool0000000<000000`3oool2000000<0oooo0P0000020?ooo`03@000003oool0oooo0080oooo
00<000000?ooo`3oool00P3oool010000000oooo0?ooo`3oool4000000030?ooo`000010000000<0
0000103oool00`000000oooo0?ooo`020?ooo`04@000003oool0oooo0?ooo`<000000P3oool01d00
0000oooo0?ooo`3ooom000000?oood0000000`0000040?ooo`05@000003oool0oooo0?ooo`000000
103oool01@000000oooo0?ooo`3ooom0000000@0oooo00<000000?ooo`3oool08`3oool01D000000
oooo0?ooo`3ooom0000000@0oooo00=000000?ooo`3oool00P3oool01D000000oooo0?ooo`3ooom0
000000@0oooo0`000002@00000@0oooo00=000000?ooo`3oool00P3oool01D000000oooo0?ooo`3o
ool0000000@0oooo00<000000?ooo`3oool00P3oool01D000000oooo0?ooo`3oool0000000@0oooo
0P0000020?ooo`8000000`3oool00d000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`00
0000103oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool00P3oool01D00
0000oooo0?ooo`3ooom000000080oooo0`0000040?ooo`05@000003oool0oooo0?oood000000103o
ool00`000010000000000002000000@0oooo00<000000?ooo`3oool00P3oool200000003@000003o
oom0000000@0oooo00<000000?ooo`3oool0903oool004`0oooo0`00000;0?ooo`<00000<`3oool2
00000003@000003oool0oooo00l0oooo0`00001;0?ooo`<000004P3oool00d00000000000000000<
0?ooo`8000000`3oool00`000000oooo0?ooo`0>0?ooo`<000004P3oool3000000@0oooo00=00000
0000003oool05P3oool2000000030?ooo`000000oooo02X0oooo000n0?ooo`03@000003oool0oooo
00P0oooo00D000000?ooo`3ooom000000000000<0?ooo`03@000003oool0oooo03@0oooo00<00000
0?ooo`3oool04@3oool00d000000oooo0?ooo`1;0?ooo`030000003oool0oooo00X0oooo00=00000
0?ooo`3oool00P3oool00d000000oooo00000002000000030?ooo`000000oooo00T0oooo0P000000
1D000000oooo0?ooo`000010000000l0oooo0P0000000d000000oooo0?ooo`030?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`030?ooo`800000603o
ool00d00000000000000000[0?ooo`00?@3oool3000000L0oooo00=000000000000000000P3oool0
0d00000000000000001I0?ooo`03000004000000oooo05@0oooo0`0000020?ooo`<0000000@0oooo
0000003ooom000000P00000V0?ooo`<000000P3oool00d0000000000000000060?ooo`03@0000000
0000000000D0oooo00<000000?ooo`3oool05`3oool2000002/0oooo000U0?ooo`03@000003oool0
oooo0080oooo00E000000?ooo`3oool0oooo@00000040?ooo`03@000003oool0oooo0080oooo00A0
00000?ooo`3oool0oooo0P0000030?ooo`050000003oool0oooo0?oood0000000`3oool2000000<0
oooo0P0000030?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo@00000040?oo
o`03@000003oool0oooo0080oooo00D000000?ooo`3oool0oooo@00000040?ooo`030000003oool0
oooo0080oooo00E000000?ooo`3oool0oooo@00000040?ooo`05@000003oool0oooo0?ooo`000000
103oool00`000000oooo0?ooo`020?ooo`05@000003oool0oooo0?ooo`000000103oool01@000000
oooo0?ooo`3ooom0000000@0oooo00=000000?ooo`3oool00P3oool014000000oooo0?ooo`3oool4
000000040?ooo`000000oooo0?ooo`800000103oool00d000000oooo0?ooo`0S0?ooo`05@000003o
ool0oooo0?oood000000103oool00d000000oooo0?ooo`020?ooo`05@000003oool0oooo0?oood00
0000103oool200000080oooo0P0000030?ooo`03@000003oool0oooo0080oooo00@000000?ooo`3o
ool0oooo0P0000030?ooo`040000003oool0oooo0?ooo`8000000`3oool00d000000oooo0?ooo`02
0?ooo`05@000003oool0oooo0?ooo`000000103oool00d000000oooo0?ooo`020?ooo`050000003o
ool0oooo0?oood000000103oool01d000000oooo0?ooo`3ooom000000?oood0000000`0000030?oo
o`8000000`3oool014000000oooo0?ooo`3oool2000000@0oooo00D000000?ooo`3oool0oooo@000
00040?ooo`05@000003oool0oooo0?oood000000103oool00`000000oooo0?ooo`020?ooo`050000
003oool0oooo0?ooo`000000103oool00d000000oooo0?ooo`0T0?ooo`00@@3oool00`000000oooo
0?ooo`0>0?ooo`8000000P3oool2000000h0oooo0P0000070?ooo`8000003`3oool200000080oooo
0P0000080?ooo`8000000P3oool2000001@0oooo0P0000000`3oool0000000000002000004<0oooo
1000000S0?ooo`8000001`3oool2000003L0oooo00<000000?ooo`3oool00P00000`0?ooo`00@03o
ool3000000h0oooo0P0000020?ooo`<000003`3oool00`00001000000?ooo`060?ooo`0300000400
0000oooo00`0oooo0P0000020?ooo`<000001`3oool200000080oooo0`00000H0?ooo`0300000400
0000oooo04@0oooo0`00000R0?ooo`8000001`3oool3000003H0oooo1P00000`0?ooo`00@03oool2
00000003@000003oool0oooo00d0oooo00E000000?ooo`3oool0oooo@000000@0?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool03@3oool01D000000oooo0?ooo`3ooom0000000T0oooo
00E000000?ooo`3oool0oooo@000000I0?ooo`030000003oool0oooo04D0oooo00=000000?ooo`3o
ool08P3oool00d000000oooo0?ooo`060?ooo`03@000003oool0oooo03D0oooo0P0000000d000000
oooo@000000a0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?oo
o`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00B@3oool4@0000080oooo0d0000030?ooo`9000001P3o
ool00d000000oooo0?ooo`090?ooo`9000000`3oool2@0000080oooo0d0000030?ooo`9000000`3o
ool2@0000080oooo0d0000020?ooo`900000M@3oool3@00000040?oood000000oooo0?ooo`900000
0`3oool2@00000H0oooo00=000000?ooo`3oool02@3oool2@00000<0oooo0T0000020?ooo`=00000
0`3oool2@00000<0oooo0T0000020?ooo`=000000P3oool2@00005@0oooo001:0?ooo`04@000003o
ool0oooo@0000080oooo00=000000?ooo`3oool00P3oool2@0000180oooo0T0000020?ooo`03@000
003oool0oooo0080oooo00=000000?ooo`3oool00P3oool01T000000oooo0?oood000000oooo@000
0080oooo00A000000?ooo`3ooom000001@3oool00d000000oooo0?ooo`1c0?ooo`06@000003oool0
oooo@000003ooom000000P3oool00d000000oooo@00000020?ooo`03@000003oool0oooo00l0oooo
0T0000020?ooo`03@000003oool0oooo0080oooo00=000000?ooo`3oool00P3oool01T000000oooo
0?oood000000oooo@0000080oooo00A000000?ooo`3ooom000001@3oool00d000000oooo0?ooo`1A
0?ooo`00BP3oool014000000oooo0?oood0000020?ooo`05@000003oool0oooo0?oood0000000P3o
ool00d000000oooo0?ooo`0>0?ooo`05@000003oool0oooo@000003oool00d0000020?ooo`03@000
003oool0oooo0080oooo00=000000?ooo`3oool00P3oool014000000oooo0?oood0000020?ooo`03
@000003oool0oooo0080oooo00=000000?ooo`3oool0M03oool3@0000080oooo00I000000?ooo`3o
oom000000?oood00000C0?ooo`05@000003oool0oooo@000003oool00d0000020?ooo`03@000003o
ool0oooo0080oooo00=000000?ooo`3oool00P3oool014000000oooo0?oood0000020?ooo`03@000
003oool0oooo0080oooo00=000000?ooo`3oool0DP3oool004X0oooo00E000000?ooo`3ooom00000
0?ooo`02@0000080oooo0T0000020?ooo`03@000003oool0oooo00d0oooo0T0000020?ooo`03@000
003ooom00000009000000P3oool3@00000030?oood0000100000009000000`3oool2@0000080oooo
140000020?ooo`900000M@3oool014000000oooo0?oood0000020?ooo`90000000<0oooo@0000400
00000T00000@0?ooo`9000000P3oool00d000000oooo@0000002@0000080oooo0d0000000`3ooom0
0000@0000002@00000<0oooo0T0000020?ooo`A000000P3oool2@00005<0oooo001:0?ooo`04@000
003oool0oooo@00002T0oooo00=000000?ooo`3oool0Q03oool014000000oooo0?oood0000060?oo
o`03@000003oool0oooo0200oooo00=000000?ooo`3oool0HP3oool004T0oooo140000030?ooo`03
@000003oool0oooo0:X0oooo1400002?0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA
0?ooo`00o`3ooonA0?ooo`00PP3oool2@0000?l0oooo3@3oool008@0oooo00=000000?ooo`3oool0
o`3oool:0?ooo`00MP3oool3@00000<0oooo0d0000030?ooo`=000001@3oool014000000oooo0?oo
o`3oool3@00000D0oooo00=000000?ooo`3oool02@3oool2@00000<0oooo0T0000020?ooo`=00000
0`3oool2@00000<0oooo0T0000020?ooo`=000003`3oool3@00000040?oood0000100000@0000080
oooo0T0000040?ooo`9000000P3oool3@0000080oooo0d0000000`3ooom00000@0000002@00000<0
oooo0d0000020?ooo`9000000P3oool3@00000<0oooo0T0000000`3ooom00000@00000020?ooo`04
@000003ooom00000@00008L0oooo001g0?ooo`03@000003oool0oooo00<0oooo00E000000?ooo`3o
ool0oooo@00000020?ooo`03@000003oool0oooo00L0oooo00=000000?ooo`3oool0403oool00d00
0000oooo@00000020?ooo`03@000003oool0oooo0080oooo00=000000?ooo`3oool00P3oool01T00
0000oooo0?oood000000oooo@0000080oooo00A000000?ooo`3ooom000003`3oool014000000oooo
0?oood0000020?ooo`03@000003oool0oooo00<0oooo00A000000?ooo`3ooom000000P3oool01400
0000oooo0?oood0000040?ooo`05@000003oool0oooo0?oood0000000P3oool00d000000oooo@000
00020?ooo`03@000003ooom000000080oooo00A000000?ooo`3ooom000000`3oool01T000000oooo
0?oood000000oooo@0000080oooo00E000000?ooo`3oool0oooo@00000260?ooo`00M`3oool00d00
0000oooo0?ooo`030?ooo`05@000003oool0oooo0?oood0000000P3oool00d000000oooo0?ooo`08
0?ooo`03@000003oool0oooo00l0oooo00=000000?oood0000000P3oool3@0000080oooo00=00000
0?ooo`3oool00P3oool00d000000oooo0?ooo`020?ooo`04@000003oool0oooo@0000080oooo00=0
00000?ooo`3oool03@3oool014000000oooo0?oood0000020?ooo`03@000003oool0oooo0080oooo
00E000000?ooo`3oool0oooo@00000050?ooo`03@000003oool0oooo0080oooo00E000000?ooo`3o
ool0oooo@00000020?ooo`03@000003ooom000000080oooo00=000000?oood0000001@3oool01D00
0000oooo0?ooo`3ooom000000080oooo00=000000?oood0000000P3oool014000000oooo0?oood00
00270?ooo`00M`3oool2@00000<0oooo0T0000040?ooo`=000002P3oool00d000000oooo0?ooo`0?
0?ooo`05@000003oool0oooo@000003oool00d0000020?ooo`=0000000<0oooo@000040000000T00
00030?ooo`9000000P3oool4@00000h0oooo0d0000000`3ooom00000@00000040?ooo`90000000<0
oooo@000040000000T0000020?ooo`A0000000<0oooo@000040000000`3oool3@00000040?oood00
001000000?ooo`I000000P3oool2@00000@0oooo0T0000000`3ooom00000@0000002@00000<0oooo
0T0000260?ooo`00M`3oool014000000oooo0?oood00000C0?ooo`03@000003ooom0000000l0oooo
00E000000?ooo`3oool0oooo@000000;0?ooo`03@000003oool0oooo01/0oooo00=000000?ooo`3o
ool02@3oool00d000000oooo0?ooo`0<0?ooo`03@000003oool0oooo00L0oooo00=000000?ooo`3o
ool0VP3oool007H0oooo1D0000020?ooo`03@000003oool0oooo00l0oooo00=000000?ooo`3oool0
3P3oool2@00000030?oood000010000002P0oooo0T0000020?ooo`03@000003oool0oooo0140oooo
00=000000?ooo`3oool00T00000?0?ooo`03@000003oool0oooo09@0oooo003o0?oooi40oooo003o
0?oooi40oooo0000\
\>"],
  ImageRangeCache->{{{0, 399}, {190.625, 0}} -> {-0.15659, -0.0239586, 
  0.00579745, 0.00579745}, {{27, 191.25}, {186.438, 
  21.1875}} -> {-7.19754, -0.870697, 0.217202, 0.217202}, {{207.688, 
  371.938}, {186.438, 21.1875}} -> {-46.3394, -0.80496, 0.216836, 0.216836}}]
}, Open  ]],

Cell[TextData[{
  StyleBox["\t",
    FontFamily->"Times New Roman",
    FontSize->10.5],
  StyleBox[
  "The divergent and rotational vectors are the orthogonal each other. To \
check up this, we compute the inner products between them located at the same \
position, and then we print out the maximum as well as minimum values of the \
inner products. ",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell[CellGroupData[{

Cell["\<\
innerPro=Table[divV[[i,j]].rotV[[i,j]],
\t{i,dim[[1]]},{j,dim[[2]]}];
Print[\"Max=\",Max[innerPro],\" Min=\",Min[innerPro]];\
\>", "Input",
  CellLabel->"In[21]:="],

Cell[BoxData[
    InterpretationBox[
      \("Max="\[InvisibleSpace]0.`\[InvisibleSpace]" Min="\[InvisibleSpace]0.`
        \),
      SequenceForm[ "Max=", 0.0, " Min=", 0.0],
      Editable->False]], "Print"]
}, Open  ]],

Cell[TextData[{
  StyleBox["\t",
    FontFamily->"Times New Roman",
    FontSize->10.5],
  StyleBox[
  "Thus, we have confirmed that the divergent and rotational vectors are \
orthogonal. This means that both of the divergent and rotational vectors of a \
monochrome image independently exist each other. In the other words, \
according to the Helmholtz's theorem, taking a sum of the divergence and \
rotational field vectors can represent any vector fields, so that taking a \
sum of the divergent and rotational vectors represents the characteristic \
vector distribution of a monochrome image [2]. Figure 3 shows a \
characteristic vector distribution of the monochrome image in Fig.1, where \
the vectors are periodically sampled with 2 pixels.",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell[TextData[{
  StyleBox["Helmholtz's theorem",
    FontWeight->"Bold"],
  ":\n\n",
  StyleBox["V",
    FontWeight->"Bold"],
  " = ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox["V",
            FontWeight->"Bold",
            FontSlant->"Plain"], "rot"], TraditionalForm]]],
  "+ ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox["V",
            FontWeight->"Bold",
            FontSlant->"Plain"], "div"], TraditionalForm]]],
  " ",
  StyleBox[",\t\t\t\t\t\t\t\t\t\t",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  "(3)",
  StyleBox["\n\n",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  "W",
  StyleBox["here ",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"],
  StyleBox["V",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman",
    FontWeight->"Bold"],
  StyleBox[", ",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"],
  StyleBox["V",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman",
    FontWeight->"Bold"],
  StyleBox["div",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman",
    FontVariations->{"CompatibilityType"->"Subscript"}],
  StyleBox[" and ",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"],
  StyleBox["V",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman",
    FontWeight->"Bold"],
  StyleBox["rot",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman",
    FontVariations->{"CompatibilityType"->"Subscript"}],
  StyleBox[
  " are the arbitrary, divergent and rotational vectors, respectively.",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"]
}], "NumberedEquation",
  TextAlignment->Left,
  TextJustification->1],

Cell[CellGroupData[{

Cell["\<\
chractV=divV+rotV;
ListPlotVectorField[
\tTable[chractV[[i,j,k]],{i,1,dim[[1]],2},
\t\t{j,1,dim[[1]],2},{k,dim[[3]]}],
\tFrame->False,
\tPlotLabel->\"Fig.3.Characteristic vector distribution\"];\
\>", "Input",
  CellLabel->"In[23]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00335 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00898392 0.0151052 0.0122493 0.0151052 [
[.5 1.01585 -122 0 ]
[.5 1.01585 122 12.5625 ]
[ 0 0 0 0 ]
[ 1 1.00335 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.01585 -183 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Fig) show
81.000000 12.812500 moveto
(.3) show
93.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(.) show
99.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Characteristic) show
189.000000 12.812500 moveto
(vector) show
231.000000 12.812500 moveto
(distribution) show
303.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-0.02 0.005 moveto 0 0 lineto
-0.02 -0.005 lineto fill
-0.02 0.005 moveto 0 0 lineto
-0.02 -0.005 lineto
-0.02 0.005 lineto stroke
} ifelse
grestore
} def
/MAarrowzero1 {
gsave
mathtops translate
0 0 Mdot
grestore
} def
% End of user PostScript
.0001 w
.02409 .02735 m
.02409 .02735 L
s
% Start of user PostScript
1. 1. MAarrowzero1
% End of user PostScript
.03919 .02735 m
.03891 .02725 L
s
% Start of user PostScript
2. 1. 1.98149 0.993098 MAarrowhead1
% End of user PostScript
.0543 .02735 m
.0542 .02774 L
s
% Start of user PostScript
3. 1. 2.9931 1.02541 MAarrowhead1
% End of user PostScript
.0694 .02735 m
.06993 .02697 L
s
% Start of user PostScript
4. 1. 4.03482 0.974588 MAarrowhead1
% End of user PostScript
.08451 .02735 m
.08409 .02725 L
s
% Start of user PostScript
5. 1. 4.97208 0.993098 MAarrowhead1
% End of user PostScript
.09962 .02735 m
.1 .02721 L
s
% Start of user PostScript
6. 1. 6.02541 0.990588 MAarrowhead1
% End of user PostScript
.11472 .02735 m
.1162 .0273 L
s
% Start of user PostScript
7. 1. 7.09792 0.996549 MAarrowhead1
% End of user PostScript
.12983 .02735 m
.12983 .0273 L
s
% Start of user PostScript
8. 1. 8. 0.996549 MAarrowhead1
% End of user PostScript
.14493 .02735 m
.14493 .02769 L
s
% Start of user PostScript
9. 1. 9. 1.02239 MAarrowhead1
% End of user PostScript
.16004 .02735 m
.16004 .02735 L
s
% Start of user PostScript
10. 1. MAarrowzero1
% End of user PostScript
.17514 .02735 m
.17509 .02741 L
s
% Start of user PostScript
11. 1. 10.9965 1.00345 MAarrowhead1
% End of user PostScript
.19025 .02735 m
.18896 .02769 L
s
% Start of user PostScript
12. 1. 11.9151 1.02239 MAarrowhead1
% End of user PostScript
.20535 .02735 m
.20368 .02389 L
s
% Start of user PostScript
13. 1. 12.8894 0.770588 MAarrowhead1
% End of user PostScript
.22046 .02735 m
.22093 .02783 L
s
% Start of user PostScript
14. 1. 14.0314 1.03137 MAarrowhead1
% End of user PostScript
.23556 .02735 m
.23593 .02735 L
s
% Start of user PostScript
15. 1. 15.0243 1. MAarrowhead1
% End of user PostScript
.25067 .02735 m
.25021 .02781 L
s
% Start of user PostScript
16. 1. 15.9698 1.03024 MAarrowhead1
% End of user PostScript
.26577 .02735 m
.26532 .02721 L
s
% Start of user PostScript
17. 1. 16.9698 0.990588 MAarrowhead1
% End of user PostScript
.28088 .02735 m
.28088 .02735 L
s
% Start of user PostScript
18. 1. MAarrowzero1
% End of user PostScript
.29598 .02735 m
.29644 .02735 L
s
% Start of user PostScript
19. 1. 19.0302 1. MAarrowhead1
% End of user PostScript
.31109 .02735 m
.31109 .02727 L
s
% Start of user PostScript
20. 1. 20. 0.994471 MAarrowhead1
% End of user PostScript
.32619 .02735 m
.32591 .02697 L
s
% Start of user PostScript
21. 1. 20.9815 0.974588 MAarrowhead1
% End of user PostScript
.3413 .02735 m
.3413 .02763 L
s
% Start of user PostScript
22. 1. 22. 1.01851 MAarrowhead1
% End of user PostScript
.3564 .02735 m
.3564 .02741 L
s
% Start of user PostScript
23. 1. 23. 1.00345 MAarrowhead1
% End of user PostScript
.37151 .02735 m
.37086 .02773 L
s
% Start of user PostScript
24. 1. 23.9568 1.02471 MAarrowhead1
% End of user PostScript
.38661 .02735 m
.38727 .02741 L
s
% Start of user PostScript
25. 1. 25.0432 1.00345 MAarrowhead1
% End of user PostScript
.40172 .02735 m
.40121 .02741 L
s
% Start of user PostScript
26. 1. 25.9663 1.00345 MAarrowhead1
% End of user PostScript
.41682 .02735 m
.41635 .02741 L
s
% Start of user PostScript
27. 1. 26.9686 1.00345 MAarrowhead1
% End of user PostScript
.43193 .02735 m
.43146 .02755 L
s
% Start of user PostScript
28. 1. 27.9686 1.01286 MAarrowhead1
% End of user PostScript
.44703 .02735 m
.44676 .02783 L
s
% Start of user PostScript
29. 1. 28.9815 1.03137 MAarrowhead1
% End of user PostScript
.46214 .02735 m
.46167 .02735 L
s
% Start of user PostScript
30. 1. 29.9686 1. MAarrowhead1
% End of user PostScript
.47725 .02735 m
.47677 .02763 L
s
% Start of user PostScript
31. 1. 30.9686 1.01851 MAarrowhead1
% End of user PostScript
.49235 .02735 m
.49282 .02735 L
s
% Start of user PostScript
32. 1. 32.0314 1. MAarrowhead1
% End of user PostScript
.50746 .02735 m
.50698 .02755 L
s
% Start of user PostScript
33. 1. 32.9686 1.01286 MAarrowhead1
% End of user PostScript
.52256 .02735 m
.52256 .02735 L
s
% Start of user PostScript
34. 1. MAarrowzero1
% End of user PostScript
.53767 .02735 m
.53786 .02735 L
s
% Start of user PostScript
35. 1. 35.0129 1. MAarrowhead1
% End of user PostScript
.55277 .02735 m
.55282 .02741 L
s
% Start of user PostScript
36. 1. 36.0035 1.00345 MAarrowhead1
% End of user PostScript
.56788 .02735 m
.56788 .0273 L
s
% Start of user PostScript
37. 1. 37. 0.996549 MAarrowhead1
% End of user PostScript
.58298 .02735 m
.58298 .0273 L
s
% Start of user PostScript
38. 1. 38. 0.996549 MAarrowhead1
% End of user PostScript
.59809 .02735 m
.59823 .02735 L
s
% Start of user PostScript
39. 1. 39.0094 1. MAarrowhead1
% End of user PostScript
.61319 .02735 m
.61305 .02786 L
s
% Start of user PostScript
40. 1. 39.9906 1.03369 MAarrowhead1
% End of user PostScript
.6283 .02735 m
.6283 .0273 L
s
% Start of user PostScript
41. 1. 41. 0.996549 MAarrowhead1
% End of user PostScript
.6434 .02735 m
.6434 .02735 L
s
% Start of user PostScript
42. 1. MAarrowzero1
% End of user PostScript
.65851 .02735 m
.6565 .02735 L
s
% Start of user PostScript
43. 1. 42.8673 1. MAarrowhead1
% End of user PostScript
.67361 .02735 m
.67833 .03014 L
s
% Start of user PostScript
44. 1. 44.3123 1.18412 MAarrowhead1
% End of user PostScript
.68872 .02735 m
.68624 .0269 L
s
% Start of user PostScript
45. 1. 44.836 0.969765 MAarrowhead1
% End of user PostScript
.70382 .02735 m
.70382 .02735 L
s
% Start of user PostScript
46. 1. MAarrowzero1
% End of user PostScript
.71893 .02735 m
.71893 .02735 L
s
% Start of user PostScript
47. 1. MAarrowzero1
% End of user PostScript
.73403 .02735 m
.73367 .02735 L
s
% Start of user PostScript
48. 1. 47.9757 1. MAarrowhead1
% End of user PostScript
.74914 .02735 m
.74877 .02726 L
s
% Start of user PostScript
49. 1. 48.9757 0.994039 MAarrowhead1
% End of user PostScript
.76424 .02735 m
.76439 .02721 L
s
% Start of user PostScript
50. 1. 50.0094 0.990588 MAarrowhead1
% End of user PostScript
.77935 .02735 m
.77902 .02693 L
s
% Start of user PostScript
51. 1. 50.978 0.972078 MAarrowhead1
% End of user PostScript
.79445 .02735 m
.7944 .0273 L
s
% Start of user PostScript
52. 1. 51.9965 0.996549 MAarrowhead1
% End of user PostScript
.80956 .02735 m
.80875 .0273 L
s
% Start of user PostScript
53. 1. 52.9467 0.996549 MAarrowhead1
% End of user PostScript
.82466 .02735 m
.82419 .02744 L
s
% Start of user PostScript
54. 1. 53.9686 1.00596 MAarrowhead1
% End of user PostScript
.83977 .02735 m
.83935 .02778 L
s
% Start of user PostScript
55. 1. 54.9721 1.02792 MAarrowhead1
% End of user PostScript
.85488 .02735 m
.85488 .02735 L
s
% Start of user PostScript
56. 1. MAarrowzero1
% End of user PostScript
.86998 .02735 m
.87045 .02783 L
s
% Start of user PostScript
57. 1. 57.0314 1.03137 MAarrowhead1
% End of user PostScript
.88509 .02735 m
.88575 .02735 L
s
% Start of user PostScript
58. 1. 58.0443 1. MAarrowhead1
% End of user PostScript
.90019 .02735 m
.90056 .0271 L
s
% Start of user PostScript
59. 1. 59.0243 0.983451 MAarrowhead1
% End of user PostScript
.9153 .02735 m
.91535 .02699 L
s
% Start of user PostScript
60. 1. 60.0039 0.975725 MAarrowhead1
% End of user PostScript
.9304 .02735 m
.93082 .02506 L
s
% Start of user PostScript
61. 1. 61.0277 0.848392 MAarrowhead1
% End of user PostScript
.94551 .02735 m
.94633 .02899 L
s
% Start of user PostScript
62. 1. 62.0545 1.10827 MAarrowhead1
% End of user PostScript
.96061 .02735 m
.95857 .02606 L
s
% Start of user PostScript
63. 1. 62.8649 0.914627 MAarrowhead1
% End of user PostScript
.97572 .02735 m
.97544 .0275 L
s
% Start of user PostScript
64. 1. 63.9815 1.00941 MAarrowhead1
% End of user PostScript
.02409 .04246 m
.02423 .04232 L
s
% Start of user PostScript
1. 2. 1.00941 1.99059 MAarrowhead1
% End of user PostScript
.03919 .04246 m
.0393 .04221 L
s
% Start of user PostScript
2. 2. 2.0069 1.98369 MAarrowhead1
% End of user PostScript
.0543 .04246 m
.05472 .0425 L
s
% Start of user PostScript
3. 2. 3.02792 2.00251 MAarrowhead1
% End of user PostScript
.0694 .04246 m
.06983 .04204 L
s
% Start of user PostScript
4. 2. 4.02792 1.97208 MAarrowhead1
% End of user PostScript
.08451 .04246 m
.08441 .04208 L
s
% Start of user PostScript
5. 2. 4.9931 1.97459 MAarrowhead1
% End of user PostScript
.09962 .04246 m
.09962 .04242 L
s
% Start of user PostScript
6. 2. 6. 1.99749 MAarrowhead1
% End of user PostScript
.11472 .04246 m
.11458 .04284 L
s
% Start of user PostScript
7. 2. 6.99059 2.02541 MAarrowhead1
% End of user PostScript
.12983 .04246 m
.1313 .04103 L
s
% Start of user PostScript
8. 2. 8.09792 1.90553 MAarrowhead1
% End of user PostScript
.14493 .04246 m
.1454 .04274 L
s
% Start of user PostScript
9. 2. 9.03137 2.01851 MAarrowhead1
% End of user PostScript
.16004 .04246 m
.16004 .04265 L
s
% Start of user PostScript
10. 2. 10. 2.01286 MAarrowhead1
% End of user PostScript
.17514 .04246 m
.17509 .04279 L
s
% Start of user PostScript
11. 2. 10.9965 2.02196 MAarrowhead1
% End of user PostScript
.19025 .04246 m
.189 .04279 L
s
% Start of user PostScript
12. 2. 11.9174 2.02196 MAarrowhead1
% End of user PostScript
.20535 .04246 m
.21096 .04335 L
s
% Start of user PostScript
13. 2. 13.3714 2.0591 MAarrowhead1
% End of user PostScript
.22046 .04246 m
.21912 .04246 L
s
% Start of user PostScript
14. 2. 13.9114 2. MAarrowhead1
% End of user PostScript
.23556 .04246 m
.23598 .04246 L
s
% Start of user PostScript
15. 2. 15.0277 2. MAarrowhead1
% End of user PostScript
.25067 .04246 m
.25067 .04212 L
s
% Start of user PostScript
16. 2. 16. 1.97761 MAarrowhead1
% End of user PostScript
.26577 .04246 m
.26532 .04292 L
s
% Start of user PostScript
17. 2. 16.9698 2.03024 MAarrowhead1
% End of user PostScript
.28088 .04246 m
.28037 .04246 L
s
% Start of user PostScript
18. 2. 17.9663 2. MAarrowhead1
% End of user PostScript
.29598 .04246 m
.29598 .04241 L
s
% Start of user PostScript
19. 2. 19. 1.99655 MAarrowhead1
% End of user PostScript
.31109 .04246 m
.31154 .04292 L
s
% Start of user PostScript
20. 2. 20.0302 2.03024 MAarrowhead1
% End of user PostScript
.32619 .04246 m
.3254 .04181 L
s
% Start of user PostScript
21. 2. 20.9478 1.95678 MAarrowhead1
% End of user PostScript
.3413 .04246 m
.3413 .04274 L
s
% Start of user PostScript
22. 2. 22. 2.01851 MAarrowhead1
% End of user PostScript
.3564 .04246 m
.35683 .04283 L
s
% Start of user PostScript
23. 2. 23.0282 2.02471 MAarrowhead1
% End of user PostScript
.37151 .04246 m
.37202 .0426 L
s
% Start of user PostScript
24. 2. 24.0341 2.00941 MAarrowhead1
% End of user PostScript
.38661 .04246 m
.38661 .04246 L
s
% Start of user PostScript
25. 2. MAarrowzero1
% End of user PostScript
.40172 .04246 m
.402 .04246 L
s
% Start of user PostScript
26. 2. 26.0185 2. MAarrowhead1
% End of user PostScript
.41682 .04246 m
.41598 .04254 L
s
% Start of user PostScript
27. 2. 26.9439 2.00553 MAarrowhead1
% End of user PostScript
.43193 .04246 m
.43188 .04251 L
s
% Start of user PostScript
28. 2. 27.9965 2.00345 MAarrowhead1
% End of user PostScript
.44703 .04246 m
.44703 .04274 L
s
% Start of user PostScript
29. 2. 29. 2.01851 MAarrowhead1
% End of user PostScript
.46214 .04246 m
.46209 .04246 L
s
% Start of user PostScript
30. 2. 29.9965 2. MAarrowhead1
% End of user PostScript
.47725 .04246 m
.47725 .04251 L
s
% Start of user PostScript
31. 2. 31. 2.00345 MAarrowhead1
% End of user PostScript
.49235 .04246 m
.4923 .04218 L
s
% Start of user PostScript
32. 2. 31.9965 1.98149 MAarrowhead1
% End of user PostScript
.50746 .04246 m
.50779 .04232 L
s
% Start of user PostScript
33. 2. 33.022 1.99059 MAarrowhead1
% End of user PostScript
.52256 .04246 m
.52275 .04246 L
s
% Start of user PostScript
34. 2. 34.0129 2. MAarrowhead1
% End of user PostScript
.53767 .04246 m
.538 .04218 L
s
% Start of user PostScript
35. 2. 35.022 1.98149 MAarrowhead1
% End of user PostScript
.55277 .04246 m
.55324 .04218 L
s
% Start of user PostScript
36. 2. 36.0314 1.98149 MAarrowhead1
% End of user PostScript
.56788 .04246 m
.56835 .04199 L
s
% Start of user PostScript
37. 2. 37.0314 1.96863 MAarrowhead1
% End of user PostScript
.58298 .04246 m
.58298 .04246 L
s
% Start of user PostScript
38. 2. MAarrowzero1
% End of user PostScript
.59809 .04246 m
.59814 .04241 L
s
% Start of user PostScript
39. 2. 39.0035 1.99655 MAarrowhead1
% End of user PostScript
.61319 .04246 m
.61324 .04241 L
s
% Start of user PostScript
40. 2. 40.0035 1.99655 MAarrowhead1
% End of user PostScript
.6283 .04246 m
.62835 .04241 L
s
% Start of user PostScript
41. 2. 41.0035 1.99655 MAarrowhead1
% End of user PostScript
.6434 .04246 m
.6434 .04246 L
s
% Start of user PostScript
42. 2. MAarrowzero1
% End of user PostScript
.65851 .04246 m
.65856 .04246 L
s
% Start of user PostScript
43. 2. 43.0035 2. MAarrowhead1
% End of user PostScript
.67361 .04246 m
.67166 .04246 L
s
% Start of user PostScript
44. 2. 43.8707 2. MAarrowhead1
% End of user PostScript
.68872 .04246 m
.69419 .04246 L
s
% Start of user PostScript
45. 2. 45.3622 2. MAarrowhead1
% End of user PostScript
.70382 .04246 m
.70135 .04195 L
s
% Start of user PostScript
46. 2. 45.836 1.96631 MAarrowhead1
% End of user PostScript
.71893 .04246 m
.71898 .04195 L
s
% Start of user PostScript
47. 2. 47.0035 1.96631 MAarrowhead1
% End of user PostScript
.73403 .04246 m
.73454 .04232 L
s
% Start of user PostScript
48. 2. 48.0337 1.99059 MAarrowhead1
% End of user PostScript
.74914 .04246 m
.74947 .04195 L
s
% Start of user PostScript
49. 2. 49.022 1.96631 MAarrowhead1
% End of user PostScript
.76424 .04246 m
.76475 .0419 L
s
% Start of user PostScript
50. 2. 50.0337 1.96286 MAarrowhead1
% End of user PostScript
.77935 .04246 m
.77902 .04218 L
s
% Start of user PostScript
51. 2. 50.978 1.98149 MAarrowhead1
% End of user PostScript
.79445 .04246 m
.79412 .04241 L
s
% Start of user PostScript
52. 2. 51.978 1.99655 MAarrowhead1
% End of user PostScript
.80956 .04246 m
.80928 .04241 L
s
% Start of user PostScript
53. 2. 52.9815 1.99655 MAarrowhead1
% End of user PostScript
.82466 .04246 m
.82466 .04199 L
s
% Start of user PostScript
54. 2. 54. 1.96863 MAarrowhead1
% End of user PostScript
.83977 .04246 m
.83969 .04246 L
s
% Start of user PostScript
55. 2. 54.9945 2. MAarrowhead1
% End of user PostScript
.85488 .04246 m
.85488 .04246 L
s
% Start of user PostScript
56. 2. MAarrowzero1
% End of user PostScript
.86998 .04246 m
.86998 .04265 L
s
% Start of user PostScript
57. 2. 57. 2.01255 MAarrowhead1
% End of user PostScript
.88509 .04246 m
.885 .04199 L
s
% Start of user PostScript
58. 2. 57.994 1.96863 MAarrowhead1
% End of user PostScript
.90019 .04246 m
.90024 .04079 L
s
% Start of user PostScript
59. 2. 59.0035 1.88922 MAarrowhead1
% End of user PostScript
.9153 .04246 m
.9153 .04212 L
s
% Start of user PostScript
60. 2. 60. 1.97761 MAarrowhead1
% End of user PostScript
.9304 .04246 m
.9304 .04361 L
s
% Start of user PostScript
61. 2. 61. 2.07596 MAarrowhead1
% End of user PostScript
.94551 .04246 m
.94704 .04318 L
s
% Start of user PostScript
62. 2. 62.1014 2.0478 MAarrowhead1
% End of user PostScript
.96061 .04246 m
.95908 .04042 L
s
% Start of user PostScript
63. 2. 62.8986 1.86494 MAarrowhead1
% End of user PostScript
.97572 .04246 m
.97491 .04274 L
s
% Start of user PostScript
64. 2. 63.9467 2.01851 MAarrowhead1
% End of user PostScript
.02409 .05756 m
.02409 .05756 L
s
% Start of user PostScript
1. 3. MAarrowzero1
% End of user PostScript
.03919 .05756 m
.03934 .05781 L
s
% Start of user PostScript
2. 3. 2.00941 3.01631 MAarrowhead1
% End of user PostScript
.0543 .05756 m
.05402 .05771 L
s
% Start of user PostScript
3. 3. 2.98149 3.00941 MAarrowhead1
% End of user PostScript
.0694 .05756 m
.0693 .05756 L
s
% Start of user PostScript
4. 3. 3.9931 3. MAarrowhead1
% End of user PostScript
.08451 .05756 m
.08451 .05767 L
s
% Start of user PostScript
5. 3. 5. 3.0069 MAarrowhead1
% End of user PostScript
.09962 .05756 m
.09934 .05784 L
s
% Start of user PostScript
6. 3. 5.98149 3.01851 MAarrowhead1
% End of user PostScript
.11472 .05756 m
.11458 .05756 L
s
% Start of user PostScript
7. 3. 6.99059 3. MAarrowhead1
% End of user PostScript
.12983 .05756 m
.13025 .05784 L
s
% Start of user PostScript
8. 3. 8.02792 3.01851 MAarrowhead1
% End of user PostScript
.14493 .05756 m
.14646 .05746 L
s
% Start of user PostScript
9. 3. 9.10137 2.9931 MAarrowhead1
% End of user PostScript
.16004 .05756 m
.16062 .05756 L
s
% Start of user PostScript
10. 3. 10.0384 3. MAarrowhead1
% End of user PostScript
.17514 .05756 m
.17534 .05723 L
s
% Start of user PostScript
11. 3. 11.0129 2.97804 MAarrowhead1
% End of user PostScript
.19025 .05756 m
.1901 .05723 L
s
% Start of user PostScript
12. 3. 11.9906 2.97804 MAarrowhead1
% End of user PostScript
.20535 .05756 m
.20412 .05756 L
s
% Start of user PostScript
13. 3. 12.9185 3. MAarrowhead1
% End of user PostScript
.22046 .05756 m
.22193 .05628 L
s
% Start of user PostScript
14. 3. 14.0975 2.91482 MAarrowhead1
% End of user PostScript
.23556 .05756 m
.23565 .05729 L
s
% Start of user PostScript
15. 3. 15.006 2.98149 MAarrowhead1
% End of user PostScript
.25067 .05756 m
.25109 .0572 L
s
% Start of user PostScript
16. 3. 16.0277 2.97573 MAarrowhead1
% End of user PostScript
.26577 .05756 m
.26532 .05756 L
s
% Start of user PostScript
17. 3. 16.9698 3. MAarrowhead1
% End of user PostScript
.28088 .05756 m
.28133 .0572 L
s
% Start of user PostScript
18. 3. 18.0302 2.97573 MAarrowhead1
% End of user PostScript
.29598 .05756 m
.29603 .05751 L
s
% Start of user PostScript
19. 3. 19.0035 2.99655 MAarrowhead1
% End of user PostScript
.31109 .05756 m
.31063 .05807 L
s
% Start of user PostScript
20. 3. 19.9698 3.03369 MAarrowhead1
% End of user PostScript
.32619 .05756 m
.32614 .05802 L
s
% Start of user PostScript
21. 3. 20.9965 3.03024 MAarrowhead1
% End of user PostScript
.3413 .05756 m
.34088 .05794 L
s
% Start of user PostScript
22. 3. 21.9721 3.02471 MAarrowhead1
% End of user PostScript
.3564 .05756 m
.3564 .05771 L
s
% Start of user PostScript
23. 3. 23. 3.00941 MAarrowhead1
% End of user PostScript
.37151 .05756 m
.37151 .05756 L
s
% Start of user PostScript
24. 3. MAarrowzero1
% End of user PostScript
.38661 .05756 m
.38661 .05751 L
s
% Start of user PostScript
25. 3. 25. 2.99655 MAarrowhead1
% End of user PostScript
.40172 .05756 m
.40209 .05751 L
s
% Start of user PostScript
26. 3. 26.0247 2.99655 MAarrowhead1
% End of user PostScript
.41682 .05756 m
.41739 .05742 L
s
% Start of user PostScript
27. 3. 27.0376 2.99059 MAarrowhead1
% End of user PostScript
.43193 .05756 m
.43113 .0579 L
s
% Start of user PostScript
28. 3. 27.9474 3.02239 MAarrowhead1
% End of user PostScript
.44703 .05756 m
.44731 .05771 L
s
% Start of user PostScript
29. 3. 29.0185 3.00941 MAarrowhead1
% End of user PostScript
.46214 .05756 m
.46214 .05737 L
s
% Start of user PostScript
30. 3. 30. 2.98702 MAarrowhead1
% End of user PostScript
.47725 .05756 m
.47719 .05756 L
s
% Start of user PostScript
31. 3. 30.9965 3. MAarrowhead1
% End of user PostScript
.49235 .05756 m
.49235 .05756 L
s
% Start of user PostScript
32. 3. MAarrowzero1
% End of user PostScript
.50746 .05756 m
.50698 .05756 L
s
% Start of user PostScript
33. 3. 32.9686 3. MAarrowhead1
% End of user PostScript
.52256 .05756 m
.52275 .05709 L
s
% Start of user PostScript
34. 3. 34.0129 2.96863 MAarrowhead1
% End of user PostScript
.53767 .05756 m
.53733 .05837 L
s
% Start of user PostScript
35. 3. 34.978 3.05333 MAarrowhead1
% End of user PostScript
.55277 .05756 m
.55268 .05729 L
s
% Start of user PostScript
36. 3. 35.994 2.98149 MAarrowhead1
% End of user PostScript
.56788 .05756 m
.56773 .05743 L
s
% Start of user PostScript
37. 3. 36.9906 2.9909 MAarrowhead1
% End of user PostScript
.58298 .05756 m
.58346 .05743 L
s
% Start of user PostScript
38. 3. 38.0314 2.9909 MAarrowhead1
% End of user PostScript
.59809 .05756 m
.59823 .05756 L
s
% Start of user PostScript
39. 3. 39.0094 3. MAarrowhead1
% End of user PostScript
.61319 .05756 m
.61352 .05729 L
s
% Start of user PostScript
40. 3. 40.022 2.98149 MAarrowhead1
% End of user PostScript
.6283 .05756 m
.62802 .05756 L
s
% Start of user PostScript
41. 3. 40.9815 3. MAarrowhead1
% End of user PostScript
.6434 .05756 m
.64345 .05784 L
s
% Start of user PostScript
42. 3. 42.0035 3.01851 MAarrowhead1
% End of user PostScript
.65851 .05756 m
.65856 .0579 L
s
% Start of user PostScript
43. 3. 43.0035 3.02196 MAarrowhead1
% End of user PostScript
.67361 .05756 m
.67389 .05756 L
s
% Start of user PostScript
44. 3. 44.0185 3. MAarrowhead1
% End of user PostScript
.68872 .05756 m
.68676 .05756 L
s
% Start of user PostScript
45. 3. 44.8707 3. MAarrowhead1
% End of user PostScript
.70382 .05756 m
.7069 .05668 L
s
% Start of user PostScript
46. 3. 46.2039 2.94161 MAarrowhead1
% End of user PostScript
.71893 .05756 m
.71752 .05756 L
s
% Start of user PostScript
47. 3. 46.9069 3. MAarrowhead1
% End of user PostScript
.73403 .05756 m
.73409 .05751 L
s
% Start of user PostScript
48. 3. 48.0035 2.99655 MAarrowhead1
% End of user PostScript
.74914 .05756 m
.74942 .05751 L
s
% Start of user PostScript
49. 3. 49.0185 2.99655 MAarrowhead1
% End of user PostScript
.76424 .05756 m
.76424 .05729 L
s
% Start of user PostScript
50. 3. 50. 2.98149 MAarrowhead1
% End of user PostScript
.77935 .05756 m
.77954 .05742 L
s
% Start of user PostScript
51. 3. 51.0129 2.99059 MAarrowhead1
% End of user PostScript
.79445 .05756 m
.79445 .05742 L
s
% Start of user PostScript
52. 3. 52. 2.99059 MAarrowhead1
% End of user PostScript
.80956 .05756 m
.80956 .05742 L
s
% Start of user PostScript
53. 3. 53. 2.99059 MAarrowhead1
% End of user PostScript
.82466 .05756 m
.82424 .05765 L
s
% Start of user PostScript
54. 3. 53.9721 3.00596 MAarrowhead1
% End of user PostScript
.83977 .05756 m
.83977 .05756 L
s
% Start of user PostScript
55. 3. MAarrowzero1
% End of user PostScript
.85488 .05756 m
.85521 .0579 L
s
% Start of user PostScript
56. 3. 56.0224 3.02239 MAarrowhead1
% End of user PostScript
.86998 .05756 m
.86951 .0582 L
s
% Start of user PostScript
57. 3. 56.9686 3.04196 MAarrowhead1
% End of user PostScript
.88509 .05756 m
.8838 .05684 L
s
% Start of user PostScript
58. 3. 57.9146 2.9522 MAarrowhead1
% End of user PostScript
.90019 .05756 m
.90013 .05742 L
s
% Start of user PostScript
59. 3. 58.9961 2.99059 MAarrowhead1
% End of user PostScript
.9153 .05756 m
.91368 .05841 L
s
% Start of user PostScript
60. 3. 59.8931 3.05565 MAarrowhead1
% End of user PostScript
.9304 .05756 m
.93002 .05899 L
s
% Start of user PostScript
61. 3. 60.9746 3.09447 MAarrowhead1
% End of user PostScript
.94551 .05756 m
.9476 .05932 L
s
% Start of user PostScript
62. 3. 62.1389 3.11631 MAarrowhead1
% End of user PostScript
.96061 .05756 m
.95971 .05494 L
s
% Start of user PostScript
63. 3. 62.9405 2.82624 MAarrowhead1
% End of user PostScript
.97572 .05756 m
.97582 .05784 L
s
% Start of user PostScript
64. 3. 64.0069 3.01851 MAarrowhead1
% End of user PostScript
.02409 .07267 m
.02409 .07267 L
s
% Start of user PostScript
1. 4. MAarrowzero1
% End of user PostScript
.03919 .07267 m
.03881 .07295 L
s
% Start of user PostScript
2. 4. 1.97459 4.01851 MAarrowhead1
% End of user PostScript
.0543 .07267 m
.05455 .07295 L
s
% Start of user PostScript
3. 4. 3.01631 4.01851 MAarrowhead1
% End of user PostScript
.0694 .07267 m
.06993 .07295 L
s
% Start of user PostScript
4. 4. 4.03482 4.01851 MAarrowhead1
% End of user PostScript
.08451 .07267 m
.08479 .07281 L
s
% Start of user PostScript
5. 4. 5.01851 4.00941 MAarrowhead1
% End of user PostScript
.09962 .07267 m
.09972 .0732 L
s
% Start of user PostScript
6. 4. 6.0069 4.03482 MAarrowhead1
% End of user PostScript
.11472 .07267 m
.1143 .07309 L
s
% Start of user PostScript
7. 4. 6.97208 4.02792 MAarrowhead1
% End of user PostScript
.12983 .07267 m
.12983 .07253 L
s
% Start of user PostScript
8. 4. 8. 3.99059 MAarrowhead1
% End of user PostScript
.14493 .07267 m
.14493 .07267 L
s
% Start of user PostScript
9. 4. MAarrowzero1
% End of user PostScript
.16004 .07267 m
.16042 .07295 L
s
% Start of user PostScript
10. 4. 10.0254 4.01851 MAarrowhead1
% End of user PostScript
.17514 .07267 m
.17633 .07214 L
s
% Start of user PostScript
11. 4. 11.079 3.96518 MAarrowhead1
% End of user PostScript
.19025 .07267 m
.19072 .07228 L
s
% Start of user PostScript
12. 4. 12.0314 3.97416 MAarrowhead1
% End of user PostScript
.20535 .07267 m
.20574 .07242 L
s
% Start of user PostScript
13. 4. 13.0258 3.98357 MAarrowhead1
% End of user PostScript
.22046 .07267 m
.22083 .07267 L
s
% Start of user PostScript
14. 4. 14.0245 4. MAarrowhead1
% End of user PostScript
.23556 .07267 m
.2359 .07568 L
s
% Start of user PostScript
15. 4. 15.0224 4.19953 MAarrowhead1
% End of user PostScript
.25067 .07267 m
.25081 .073 L
s
% Start of user PostScript
16. 4. 16.0094 4.02196 MAarrowhead1
% End of user PostScript
.26577 .07267 m
.26591 .07309 L
s
% Start of user PostScript
17. 4. 17.0094 4.02773 MAarrowhead1
% End of user PostScript
.28088 .07267 m
.28088 .07267 L
s
% Start of user PostScript
18. 4. MAarrowzero1
% End of user PostScript
.29598 .07267 m
.29604 .07267 L
s
% Start of user PostScript
19. 4. 19.0039 4. MAarrowhead1
% End of user PostScript
.31109 .07267 m
.31065 .0735 L
s
% Start of user PostScript
20. 4. 19.9709 4.05494 MAarrowhead1
% End of user PostScript
.32619 .07267 m
.32619 .07223 L
s
% Start of user PostScript
21. 4. 21. 3.9709 MAarrowhead1
% End of user PostScript
.3413 .07267 m
.3413 .07267 L
s
% Start of user PostScript
22. 4. MAarrowzero1
% End of user PostScript
.3564 .07267 m
.3564 .073 L
s
% Start of user PostScript
23. 4. 23. 4.02196 MAarrowhead1
% End of user PostScript
.37151 .07267 m
.371 .07267 L
s
% Start of user PostScript
24. 4. 23.9663 4. MAarrowhead1
% End of user PostScript
.38661 .07267 m
.38633 .07267 L
s
% Start of user PostScript
25. 4. 24.9815 4. MAarrowhead1
% End of user PostScript
.40172 .07267 m
.40172 .07267 L
s
% Start of user PostScript
26. 4. MAarrowzero1
% End of user PostScript
.41682 .07267 m
.41735 .07314 L
s
% Start of user PostScript
27. 4. 27.0348 4.03137 MAarrowhead1
% End of user PostScript
.43193 .07267 m
.43278 .07332 L
s
% Start of user PostScript
28. 4. 28.0561 4.04322 MAarrowhead1
% End of user PostScript
.44703 .07267 m
.44676 .07314 L
s
% Start of user PostScript
29. 4. 28.9815 4.03137 MAarrowhead1
% End of user PostScript
.46214 .07267 m
.46209 .07309 L
s
% Start of user PostScript
30. 4. 29.9965 4.02792 MAarrowhead1
% End of user PostScript
.47725 .07267 m
.47725 .07295 L
s
% Start of user PostScript
31. 4. 31. 4.01851 MAarrowhead1
% End of user PostScript
.49235 .07267 m
.4915 .07286 L
s
% Start of user PostScript
32. 4. 31.9439 4.01286 MAarrowhead1
% End of user PostScript
.50746 .07267 m
.50661 .07313 L
s
% Start of user PostScript
33. 4. 32.9439 4.03024 MAarrowhead1
% End of user PostScript
.52256 .07267 m
.52177 .07318 L
s
% Start of user PostScript
34. 4. 33.9478 4.03369 MAarrowhead1
% End of user PostScript
.53767 .07267 m
.53761 .07318 L
s
% Start of user PostScript
35. 4. 34.9965 4.03369 MAarrowhead1
% End of user PostScript
.55277 .07267 m
.55226 .0731 L
s
% Start of user PostScript
36. 4. 35.9663 4.02816 MAarrowhead1
% End of user PostScript
.56788 .07267 m
.56732 .07272 L
s
% Start of user PostScript
37. 4. 36.9629 4.00345 MAarrowhead1
% End of user PostScript
.58298 .07267 m
.58247 .07272 L
s
% Start of user PostScript
38. 4. 37.9663 4.00345 MAarrowhead1
% End of user PostScript
.59809 .07267 m
.59761 .07351 L
s
% Start of user PostScript
39. 4. 38.9686 4.05565 MAarrowhead1
% End of user PostScript
.61319 .07267 m
.613 .07277 L
s
% Start of user PostScript
40. 4. 39.9871 4.0069 MAarrowhead1
% End of user PostScript
.6283 .07267 m
.62824 .07323 L
s
% Start of user PostScript
41. 4. 40.9965 4.03714 MAarrowhead1
% End of user PostScript
.6434 .07267 m
.64289 .07318 L
s
% Start of user PostScript
42. 4. 41.9663 4.03369 MAarrowhead1
% End of user PostScript
.65851 .07267 m
.658 .07318 L
s
% Start of user PostScript
43. 4. 42.9663 4.03369 MAarrowhead1
% End of user PostScript
.67361 .07267 m
.6731 .07304 L
s
% Start of user PostScript
44. 4. 43.9663 4.02427 MAarrowhead1
% End of user PostScript
.68872 .07267 m
.68881 .07318 L
s
% Start of user PostScript
45. 4. 45.006 4.03369 MAarrowhead1
% End of user PostScript
.70382 .07267 m
.70136 .07271 L
s
% Start of user PostScript
46. 4. 45.837 4.00251 MAarrowhead1
% End of user PostScript
.71893 .07267 m
.72069 .07396 L
s
% Start of user PostScript
47. 4. 47.1163 4.08514 MAarrowhead1
% End of user PostScript
.73403 .07267 m
.73389 .07272 L
s
% Start of user PostScript
48. 4. 47.9906 4.00345 MAarrowhead1
% End of user PostScript
.74914 .07267 m
.74919 .07267 L
s
% Start of user PostScript
49. 4. 49.0035 4. MAarrowhead1
% End of user PostScript
.76424 .07267 m
.76405 .07295 L
s
% Start of user PostScript
50. 4. 49.9871 4.01851 MAarrowhead1
% End of user PostScript
.77935 .07267 m
.77921 .07267 L
s
% Start of user PostScript
51. 4. 50.9906 4. MAarrowhead1
% End of user PostScript
.79445 .07267 m
.79431 .07267 L
s
% Start of user PostScript
52. 4. 51.9906 4. MAarrowhead1
% End of user PostScript
.80956 .07267 m
.80956 .0722 L
s
% Start of user PostScript
53. 4. 53. 3.96863 MAarrowhead1
% End of user PostScript
.82466 .07267 m
.82433 .07267 L
s
% Start of user PostScript
54. 4. 53.9776 4. MAarrowhead1
% End of user PostScript
.83977 .07267 m
.83943 .07353 L
s
% Start of user PostScript
55. 4. 54.9776 4.05722 MAarrowhead1
% End of user PostScript
.85488 .07267 m
.85451 .07482 L
s
% Start of user PostScript
56. 4. 55.9757 4.1422 MAarrowhead1
% End of user PostScript
.86998 .07267 m
.87002 .07301 L
s
% Start of user PostScript
57. 4. 57.0025 4.02227 MAarrowhead1
% End of user PostScript
.88509 .07267 m
.88341 .07153 L
s
% Start of user PostScript
58. 4. 57.8892 3.92447 MAarrowhead1
% End of user PostScript
.90019 .07267 m
.89824 .07502 L
s
% Start of user PostScript
59. 4. 58.8707 4.15588 MAarrowhead1
% End of user PostScript
.9153 .07267 m
.91455 .07263 L
s
% Start of user PostScript
60. 4. 59.9503 3.99749 MAarrowhead1
% End of user PostScript
.9304 .07267 m
.92954 .07237 L
s
% Start of user PostScript
61. 4. 60.943 3.98012 MAarrowhead1
% End of user PostScript
.94551 .07267 m
.94604 .07348 L
s
% Start of user PostScript
62. 4. 62.0351 4.05357 MAarrowhead1
% End of user PostScript
.96061 .07267 m
.96003 .07214 L
s
% Start of user PostScript
63. 4. 62.9613 3.96518 MAarrowhead1
% End of user PostScript
.97572 .07267 m
.97519 .07267 L
s
% Start of user PostScript
64. 4. 63.9652 4. MAarrowhead1
% End of user PostScript
.02409 .08778 m
.02451 .08735 L
s
% Start of user PostScript
1. 5. 1.02792 4.97208 MAarrowhead1
% End of user PostScript
.03919 .08778 m
.03934 .08778 L
s
% Start of user PostScript
2. 5. 2.00941 5. MAarrowhead1
% End of user PostScript
.0543 .08778 m
.05392 .08778 L
s
% Start of user PostScript
3. 5. 2.97459 5. MAarrowhead1
% End of user PostScript
.0694 .08778 m
.06983 .08778 L
s
% Start of user PostScript
4. 5. 4.02792 5. MAarrowhead1
% End of user PostScript
.08451 .08778 m
.08451 .08767 L
s
% Start of user PostScript
5. 5. 5. 4.9931 MAarrowhead1
% End of user PostScript
.09962 .08778 m
.09909 .08788 L
s
% Start of user PostScript
6. 5. 5.96518 5.0069 MAarrowhead1
% End of user PostScript
.11472 .08778 m
.11472 .08792 L
s
% Start of user PostScript
7. 5. 7. 5.00941 MAarrowhead1
% End of user PostScript
.12983 .08778 m
.12944 .08725 L
s
% Start of user PostScript
8. 5. 7.97459 4.96518 MAarrowhead1
% End of user PostScript
.14493 .08778 m
.14451 .08802 L
s
% Start of user PostScript
9. 5. 8.97208 5.01631 MAarrowhead1
% End of user PostScript
.16004 .08778 m
.16046 .0882 L
s
% Start of user PostScript
10. 5. 10.0279 5.02792 MAarrowhead1
% End of user PostScript
.17514 .08778 m
.17556 .08805 L
s
% Start of user PostScript
11. 5. 11.0279 5.01851 MAarrowhead1
% End of user PostScript
.19025 .08778 m
.19053 .08805 L
s
% Start of user PostScript
12. 5. 12.0185 5.01851 MAarrowhead1
% End of user PostScript
.20535 .08778 m
.20493 .0875 L
s
% Start of user PostScript
13. 5. 12.9721 4.98149 MAarrowhead1
% End of user PostScript
.22046 .08778 m
.22046 .08805 L
s
% Start of user PostScript
14. 5. 14. 5.01851 MAarrowhead1
% End of user PostScript
.23556 .08778 m
.23556 .0875 L
s
% Start of user PostScript
15. 5. 15. 4.98149 MAarrowhead1
% End of user PostScript
.25067 .08778 m
.25272 .08758 L
s
% Start of user PostScript
16. 5. 16.1362 4.98733 MAarrowhead1
% End of user PostScript
.26577 .08778 m
.26368 .0872 L
s
% Start of user PostScript
17. 5. 16.8613 4.96161 MAarrowhead1
% End of user PostScript
.28088 .08778 m
.28088 .08855 L
s
% Start of user PostScript
18. 5. 18. 5.05149 MAarrowhead1
% End of user PostScript
.29598 .08778 m
.29632 .08778 L
s
% Start of user PostScript
19. 5. 19.0224 5. MAarrowhead1
% End of user PostScript
.31109 .08778 m
.31161 .0883 L
s
% Start of user PostScript
20. 5. 20.0346 5.03463 MAarrowhead1
% End of user PostScript
.32619 .08778 m
.32567 .08855 L
s
% Start of user PostScript
21. 5. 20.9654 5.05106 MAarrowhead1
% End of user PostScript
.3413 .08778 m
.34045 .08792 L
s
% Start of user PostScript
22. 5. 21.9439 5.00941 MAarrowhead1
% End of user PostScript
.3564 .08778 m
.3564 .08815 L
s
% Start of user PostScript
23. 5. 23. 5.02471 MAarrowhead1
% End of user PostScript
.37151 .08778 m
.37103 .08744 L
s
% Start of user PostScript
24. 5. 23.9686 4.97804 MAarrowhead1
% End of user PostScript
.38661 .08778 m
.38628 .08778 L
s
% Start of user PostScript
25. 5. 24.978 5. MAarrowhead1
% End of user PostScript
.40172 .08778 m
.40191 .08778 L
s
% Start of user PostScript
26. 5. 26.0129 5. MAarrowhead1
% End of user PostScript
.41682 .08778 m
.41682 .08778 L
s
% Start of user PostScript
27. 5. MAarrowzero1
% End of user PostScript
.43193 .08778 m
.43198 .08805 L
s
% Start of user PostScript
28. 5. 28.0035 5.01851 MAarrowhead1
% End of user PostScript
.44703 .08778 m
.44703 .08744 L
s
% Start of user PostScript
29. 5. 29. 4.97804 MAarrowhead1
% End of user PostScript
.46214 .08778 m
.46242 .08815 L
s
% Start of user PostScript
30. 5. 30.0185 5.02471 MAarrowhead1
% End of user PostScript
.47725 .08778 m
.47762 .08778 L
s
% Start of user PostScript
31. 5. 31.0247 5. MAarrowhead1
% End of user PostScript
.49235 .08778 m
.49281 .08732 L
s
% Start of user PostScript
32. 5. 32.0302 4.96976 MAarrowhead1
% End of user PostScript
.50746 .08778 m
.5083 .0873 L
s
% Start of user PostScript
33. 5. 33.0561 4.96863 MAarrowhead1
% End of user PostScript
.52256 .08778 m
.52385 .08681 L
s
% Start of user PostScript
34. 5. 34.0852 4.93608 MAarrowhead1
% End of user PostScript
.53767 .08778 m
.53896 .08695 L
s
% Start of user PostScript
35. 5. 35.0859 4.94549 MAarrowhead1
% End of user PostScript
.55277 .08778 m
.55331 .087 L
s
% Start of user PostScript
36. 5. 36.036 4.94894 MAarrowhead1
% End of user PostScript
.56788 .08778 m
.56842 .08723 L
s
% Start of user PostScript
37. 5. 37.036 4.964 MAarrowhead1
% End of user PostScript
.58298 .08778 m
.58353 .08662 L
s
% Start of user PostScript
38. 5. 38.036 4.92353 MAarrowhead1
% End of user PostScript
.59809 .08778 m
.59858 .08723 L
s
% Start of user PostScript
39. 5. 39.0325 4.964 MAarrowhead1
% End of user PostScript
.61319 .08778 m
.61411 .087 L
s
% Start of user PostScript
40. 5. 40.0605 4.94894 MAarrowhead1
% End of user PostScript
.6283 .08778 m
.62921 .08695 L
s
% Start of user PostScript
41. 5. 41.0605 4.94506 MAarrowhead1
% End of user PostScript
.6434 .08778 m
.64423 .08649 L
s
% Start of user PostScript
42. 5. 42.0549 4.91482 MAarrowhead1
% End of user PostScript
.65851 .08778 m
.6593 .08805 L
s
% Start of user PostScript
43. 5. 43.0526 5.01851 MAarrowhead1
% End of user PostScript
.67361 .08778 m
.67413 .08726 L
s
% Start of user PostScript
44. 5. 44.0341 4.96588 MAarrowhead1
% End of user PostScript
.68872 .08778 m
.68951 .08772 L
s
% Start of user PostScript
45. 5. 45.0526 4.99612 MAarrowhead1
% End of user PostScript
.70382 .08778 m
.70434 .08738 L
s
% Start of user PostScript
46. 5. 46.0341 4.97416 MAarrowhead1
% End of user PostScript
.71893 .08778 m
.71812 .08686 L
s
% Start of user PostScript
47. 5. 46.9464 4.93953 MAarrowhead1
% End of user PostScript
.73403 .08778 m
.73562 .08783 L
s
% Start of user PostScript
48. 5. 48.1049 5.00388 MAarrowhead1
% End of user PostScript
.74914 .08778 m
.75078 .0853 L
s
% Start of user PostScript
49. 5. 49.1085 4.83596 MAarrowhead1
% End of user PostScript
.76424 .08778 m
.75855 .08811 L
s
% Start of user PostScript
50. 5. 49.6233 5.02239 MAarrowhead1
% End of user PostScript
.77935 .08778 m
.77806 .08828 L
s
% Start of user PostScript
51. 5. 50.9148 5.03369 MAarrowhead1
% End of user PostScript
.79445 .08778 m
.79398 .08792 L
s
% Start of user PostScript
52. 5. 51.9686 5.00941 MAarrowhead1
% End of user PostScript
.80956 .08778 m
.80909 .08969 L
s
% Start of user PostScript
53. 5. 52.9686 5.1269 MAarrowhead1
% End of user PostScript
.82466 .08778 m
.8207 .09249 L
s
% Start of user PostScript
54. 5. 53.7378 5.31227 MAarrowhead1
% End of user PostScript
.83977 .08778 m
.83859 .09084 L
s
% Start of user PostScript
55. 5. 54.922 5.20286 MAarrowhead1
% End of user PostScript
.85488 .08778 m
.85488 .0861 L
s
% Start of user PostScript
56. 5. 56. 4.88941 MAarrowhead1
% End of user PostScript
.86998 .08778 m
.87086 .08793 L
s
% Start of user PostScript
57. 5. 57.0584 5.01047 MAarrowhead1
% End of user PostScript
.88509 .08778 m
.88456 .08695 L
s
% Start of user PostScript
58. 5. 57.9649 4.94549 MAarrowhead1
% End of user PostScript
.90019 .08778 m
.90019 .08739 L
s
% Start of user PostScript
59. 5. 59. 4.97459 MAarrowhead1
% End of user PostScript
.9153 .08778 m
.91572 .08855 L
s
% Start of user PostScript
60. 5. 60.0282 5.05106 MAarrowhead1
% End of user PostScript
.9304 .08778 m
.93088 .08816 L
s
% Start of user PostScript
61. 5. 61.0318 5.02541 MAarrowhead1
% End of user PostScript
.94551 .08778 m
.94343 .08615 L
s
% Start of user PostScript
62. 5. 61.8626 4.89267 MAarrowhead1
% End of user PostScript
.96061 .08778 m
.95966 .08729 L
s
% Start of user PostScript
63. 5. 62.937 4.9682 MAarrowhead1
% End of user PostScript
.97572 .08778 m
.97596 .0875 L
s
% Start of user PostScript
64. 5. 64.0163 4.98149 MAarrowhead1
% End of user PostScript
.02409 .10288 m
.02462 .10235 L
s
% Start of user PostScript
1. 6. 1.03482 5.96518 MAarrowhead1
% End of user PostScript
.03919 .10288 m
.03877 .10284 L
s
% Start of user PostScript
2. 6. 1.97208 5.99749 MAarrowhead1
% End of user PostScript
.0543 .10288 m
.05458 .10288 L
s
% Start of user PostScript
3. 6. 3.01851 6. MAarrowhead1
% End of user PostScript
.0694 .10288 m
.06983 .10235 L
s
% Start of user PostScript
4. 6. 4.02792 5.96518 MAarrowhead1
% End of user PostScript
.08451 .10288 m
.08426 .10298 L
s
% Start of user PostScript
5. 6. 4.98369 6.0069 MAarrowhead1
% End of user PostScript
.09962 .10288 m
.09976 .10288 L
s
% Start of user PostScript
6. 6. 6.00941 6. MAarrowhead1
% End of user PostScript
.11472 .10288 m
.11444 .1026 L
s
% Start of user PostScript
7. 6. 6.98149 5.98149 MAarrowhead1
% End of user PostScript
.12983 .10288 m
.12968 .10288 L
s
% Start of user PostScript
8. 6. 7.99059 6. MAarrowhead1
% End of user PostScript
.14493 .10288 m
.14479 .10288 L
s
% Start of user PostScript
9. 6. 8.99059 6. MAarrowhead1
% End of user PostScript
.16004 .10288 m
.16004 .10288 L
s
% Start of user PostScript
10. 6. MAarrowzero1
% End of user PostScript
.17514 .10288 m
.175 .10288 L
s
% Start of user PostScript
11. 6. 10.9906 6. MAarrowhead1
% End of user PostScript
.19025 .10288 m
.19067 .10288 L
s
% Start of user PostScript
12. 6. 12.0279 6. MAarrowhead1
% End of user PostScript
.20535 .10288 m
.20563 .10302 L
s
% Start of user PostScript
13. 6. 13.0185 6.00941 MAarrowhead1
% End of user PostScript
.22046 .10288 m
.22003 .10298 L
s
% Start of user PostScript
14. 6. 13.9721 6.0069 MAarrowhead1
% End of user PostScript
.23556 .10288 m
.23532 .10274 L
s
% Start of user PostScript
15. 6. 14.9837 5.99059 MAarrowhead1
% End of user PostScript
.25067 .10288 m
.25305 .10503 L
s
% Start of user PostScript
16. 6. 16.1575 6.14216 MAarrowhead1
% End of user PostScript
.26577 .10288 m
.26697 .10341 L
s
% Start of user PostScript
17. 6. 17.0792 6.03482 MAarrowhead1
% End of user PostScript
.28088 .10288 m
.28058 .10284 L
s
% Start of user PostScript
18. 6. 17.9802 5.99749 MAarrowhead1
% End of user PostScript
.29598 .10288 m
.29379 .10288 L
s
% Start of user PostScript
19. 6. 18.8546 6. MAarrowhead1
% End of user PostScript
.31109 .10288 m
.31115 .10316 L
s
% Start of user PostScript
20. 6. 20.0039 6.01851 MAarrowhead1
% End of user PostScript
.32619 .10288 m
.32672 .10366 L
s
% Start of user PostScript
21. 6. 21.0346 6.05149 MAarrowhead1
% End of user PostScript
.3413 .10288 m
.34125 .10255 L
s
% Start of user PostScript
22. 6. 21.9965 5.97804 MAarrowhead1
% End of user PostScript
.3564 .10288 m
.35593 .10288 L
s
% Start of user PostScript
23. 6. 22.9686 6. MAarrowhead1
% End of user PostScript
.37151 .10288 m
.37151 .1026 L
s
% Start of user PostScript
24. 6. 24. 5.98149 MAarrowhead1
% End of user PostScript
.38661 .10288 m
.38656 .10288 L
s
% Start of user PostScript
25. 6. 24.9965 6. MAarrowhead1
% End of user PostScript
.40172 .10288 m
.40167 .10283 L
s
% Start of user PostScript
26. 6. 25.9965 5.99655 MAarrowhead1
% End of user PostScript
.41682 .10288 m
.41654 .10288 L
s
% Start of user PostScript
27. 6. 26.9815 6. MAarrowhead1
% End of user PostScript
.43193 .10288 m
.4316 .10288 L
s
% Start of user PostScript
28. 6. 27.978 6. MAarrowhead1
% End of user PostScript
.44703 .10288 m
.44741 .10288 L
s
% Start of user PostScript
29. 6. 29.0247 6. MAarrowhead1
% End of user PostScript
.46214 .10288 m
.46177 .10288 L
s
% Start of user PostScript
30. 6. 29.9753 6. MAarrowhead1
% End of user PostScript
.47725 .10288 m
.47725 .10288 L
s
% Start of user PostScript
31. 6. MAarrowzero1
% End of user PostScript
.49235 .10288 m
.49235 .10288 L
s
% Start of user PostScript
32. 6. MAarrowzero1
% End of user PostScript
.50746 .10288 m
.50746 .10288 L
s
% Start of user PostScript
33. 6. MAarrowzero1
% End of user PostScript
.52256 .10288 m
.52321 .10251 L
s
% Start of user PostScript
34. 6. 34.0432 5.97529 MAarrowhead1
% End of user PostScript
.53767 .10288 m
.53701 .10325 L
s
% Start of user PostScript
35. 6. 34.9568 6.02471 MAarrowhead1
% End of user PostScript
.55277 .10288 m
.5524 .10288 L
s
% Start of user PostScript
36. 6. 35.9753 6. MAarrowhead1
% End of user PostScript
.56788 .10288 m
.56839 .10242 L
s
% Start of user PostScript
37. 6. 37.0341 5.96976 MAarrowhead1
% End of user PostScript
.58298 .10288 m
.58284 .10288 L
s
% Start of user PostScript
38. 6. 37.9906 6. MAarrowhead1
% End of user PostScript
.59809 .10288 m
.59763 .10353 L
s
% Start of user PostScript
39. 6. 38.9698 6.04322 MAarrowhead1
% End of user PostScript
.61319 .10288 m
.61319 .10251 L
s
% Start of user PostScript
40. 6. 40. 5.97529 MAarrowhead1
% End of user PostScript
.6283 .10288 m
.62875 .10316 L
s
% Start of user PostScript
41. 6. 41.0302 6.01851 MAarrowhead1
% End of user PostScript
.6434 .10288 m
.6434 .10288 L
s
% Start of user PostScript
42. 6. MAarrowzero1
% End of user PostScript
.65851 .10288 m
.65851 .10288 L
s
% Start of user PostScript
43. 6. MAarrowzero1
% End of user PostScript
.67361 .10288 m
.67361 .10325 L
s
% Start of user PostScript
44. 6. 44. 6.02471 MAarrowhead1
% End of user PostScript
.68872 .10288 m
.68909 .10334 L
s
% Start of user PostScript
45. 6. 45.0247 6.03024 MAarrowhead1
% End of user PostScript
.70382 .10288 m
.70382 .1034 L
s
% Start of user PostScript
46. 6. 46. 6.03412 MAarrowhead1
% End of user PostScript
.71893 .10288 m
.71893 .10293 L
s
% Start of user PostScript
47. 6. 47. 6.00345 MAarrowhead1
% End of user PostScript
.73403 .10288 m
.73398 .10242 L
s
% Start of user PostScript
48. 6. 47.9965 5.96976 MAarrowhead1
% End of user PostScript
.74914 .10288 m
.74839 .10334 L
s
% Start of user PostScript
49. 6. 48.9503 6.03024 MAarrowhead1
% End of user PostScript
.76424 .10288 m
.76305 .10272 L
s
% Start of user PostScript
50. 6. 49.921 5.98941 MAarrowhead1
% End of user PostScript
.77935 .10288 m
.78261 .10105 L
s
% Start of user PostScript
51. 6. 51.216 5.87863 MAarrowhead1
% End of user PostScript
.79445 .10288 m
.79556 .10536 L
s
% Start of user PostScript
52. 6. 52.0732 6.16412 MAarrowhead1
% End of user PostScript
.80956 .10288 m
.80845 .10306 L
s
% Start of user PostScript
53. 6. 52.9262 6.0118 MAarrowhead1
% End of user PostScript
.82466 .10288 m
.82466 .1033 L
s
% Start of user PostScript
54. 6. 54. 6.02792 MAarrowhead1
% End of user PostScript
.83977 .10288 m
.83924 .10212 L
s
% Start of user PostScript
55. 6. 54.9652 5.94969 MAarrowhead1
% End of user PostScript
.85488 .10288 m
.85273 .10341 L
s
% Start of user PostScript
56. 6. 55.858 6.03482 MAarrowhead1
% End of user PostScript
.86998 .10288 m
.86994 .10263 L
s
% Start of user PostScript
57. 6. 56.9975 5.98357 MAarrowhead1
% End of user PostScript
.88509 .10288 m
.88667 .10664 L
s
% Start of user PostScript
58. 6. 58.1048 6.2491 MAarrowhead1
% End of user PostScript
.90019 .10288 m
.899 .1024 L
s
% Start of user PostScript
59. 6. 58.921 5.96839 MAarrowhead1
% End of user PostScript
.9153 .10288 m
.91313 .10119 L
s
% Start of user PostScript
60. 6. 59.8567 5.88804 MAarrowhead1
% End of user PostScript
.9304 .10288 m
.93155 .10455 L
s
% Start of user PostScript
61. 6. 61.076 6.11078 MAarrowhead1
% End of user PostScript
.94551 .10288 m
.94741 .10237 L
s
% Start of user PostScript
62. 6. 62.1258 5.96631 MAarrowhead1
% End of user PostScript
.96061 .10288 m
.96089 .10288 L
s
% Start of user PostScript
63. 6. 63.0185 6. MAarrowhead1
% End of user PostScript
.97572 .10288 m
.97582 .10278 L
s
% Start of user PostScript
64. 6. 64.0069 5.9931 MAarrowhead1
% End of user PostScript
.02409 .11799 m
.02451 .11756 L
s
% Start of user PostScript
1. 7. 1.02792 6.97208 MAarrowhead1
% End of user PostScript
.03919 .11799 m
.03891 .11841 L
s
% Start of user PostScript
2. 7. 1.98149 7.02792 MAarrowhead1
% End of user PostScript
.0543 .11799 m
.05444 .11795 L
s
% Start of user PostScript
3. 7. 3.00941 6.99749 MAarrowhead1
% End of user PostScript
.0694 .11799 m
.06979 .11841 L
s
% Start of user PostScript
4. 7. 4.02541 7.02792 MAarrowhead1
% End of user PostScript
.08451 .11799 m
.08451 .11851 L
s
% Start of user PostScript
5. 7. 5. 7.03482 MAarrowhead1
% End of user PostScript
.09962 .11799 m
.10004 .11841 L
s
% Start of user PostScript
6. 7. 6.02792 7.02792 MAarrowhead1
% End of user PostScript
.11472 .11799 m
.11472 .11837 L
s
% Start of user PostScript
7. 7. 7. 7.02541 MAarrowhead1
% End of user PostScript
.12983 .11799 m
.13021 .11813 L
s
% Start of user PostScript
8. 7. 8.02541 7.00941 MAarrowhead1
% End of user PostScript
.14493 .11799 m
.14493 .11799 L
s
% Start of user PostScript
9. 7. MAarrowzero1
% End of user PostScript
.16004 .11799 m
.16004 .11841 L
s
% Start of user PostScript
10. 7. 10. 7.02792 MAarrowhead1
% End of user PostScript
.17514 .11799 m
.17514 .1176 L
s
% Start of user PostScript
11. 7. 11. 6.97459 MAarrowhead1
% End of user PostScript
.19025 .11799 m
.19025 .11841 L
s
% Start of user PostScript
12. 7. 12. 7.02792 MAarrowhead1
% End of user PostScript
.20535 .11799 m
.20577 .11809 L
s
% Start of user PostScript
13. 7. 13.0279 7.0069 MAarrowhead1
% End of user PostScript
.22046 .11799 m
.22021 .11799 L
s
% Start of user PostScript
14. 7. 13.9837 7. MAarrowhead1
% End of user PostScript
.23556 .11799 m
.23598 .11795 L
s
% Start of user PostScript
15. 7. 15.0279 6.99749 MAarrowhead1
% End of user PostScript
.25067 .11799 m
.25228 .11885 L
s
% Start of user PostScript
16. 7. 16.1069 7.05702 MAarrowhead1
% End of user PostScript
.26577 .11799 m
.26878 .11732 L
s
% Start of user PostScript
17. 7. 17.199 6.95565 MAarrowhead1
% End of user PostScript
.28088 .11799 m
.27931 .11799 L
s
% Start of user PostScript
18. 7. 17.8961 7. MAarrowhead1
% End of user PostScript
.29598 .11799 m
.29704 .11891 L
s
% Start of user PostScript
19. 7. 19.0703 7.0609 MAarrowhead1
% End of user PostScript
.31109 .11799 m
.30512 .11755 L
s
% Start of user PostScript
20. 7. 19.6052 6.9709 MAarrowhead1
% End of user PostScript
.32619 .11799 m
.32575 .11771 L
s
% Start of user PostScript
21. 7. 20.9709 6.98149 MAarrowhead1
% End of user PostScript
.3413 .11799 m
.34081 .1187 L
s
% Start of user PostScript
22. 7. 21.9675 7.04761 MAarrowhead1
% End of user PostScript
.3564 .11799 m
.35631 .11799 L
s
% Start of user PostScript
23. 7. 22.994 7. MAarrowhead1
% End of user PostScript
.37151 .11799 m
.37146 .11765 L
s
% Start of user PostScript
24. 7. 23.9965 6.97804 MAarrowhead1
% End of user PostScript
.38661 .11799 m
.38661 .11799 L
s
% Start of user PostScript
25. 7. MAarrowzero1
% End of user PostScript
.40172 .11799 m
.40172 .11799 L
s
% Start of user PostScript
26. 7. MAarrowzero1
% End of user PostScript
.41682 .11799 m
.41649 .11793 L
s
% Start of user PostScript
27. 7. 26.978 6.99655 MAarrowhead1
% End of user PostScript
.43193 .11799 m
.43193 .11799 L
s
% Start of user PostScript
28. 7. MAarrowzero1
% End of user PostScript
.44703 .11799 m
.44703 .11799 L
s
% Start of user PostScript
29. 7. MAarrowzero1
% End of user PostScript
.46214 .11799 m
.46214 .11836 L
s
% Start of user PostScript
30. 7. 30. 7.02471 MAarrowhead1
% End of user PostScript
.47725 .11799 m
.47687 .11836 L
s
% Start of user PostScript
31. 7. 30.9753 7.02471 MAarrowhead1
% End of user PostScript
.49235 .11799 m
.49192 .11799 L
s
% Start of user PostScript
32. 7. 31.9718 7. MAarrowhead1
% End of user PostScript
.50746 .11799 m
.50708 .11799 L
s
% Start of user PostScript
33. 7. 32.9753 7. MAarrowhead1
% End of user PostScript
.52256 .11799 m
.52256 .11799 L
s
% Start of user PostScript
34. 7. MAarrowzero1
% End of user PostScript
.53767 .11799 m
.53767 .11799 L
s
% Start of user PostScript
35. 7. MAarrowzero1
% End of user PostScript
.55277 .11799 m
.5524 .11799 L
s
% Start of user PostScript
36. 7. 35.9753 7. MAarrowhead1
% End of user PostScript
.56788 .11799 m
.56788 .11813 L
s
% Start of user PostScript
37. 7. 37. 7.00941 MAarrowhead1
% End of user PostScript
.58298 .11799 m
.58298 .1185 L
s
% Start of user PostScript
38. 7. 38. 7.03412 MAarrowhead1
% End of user PostScript
.59809 .11799 m
.59809 .11771 L
s
% Start of user PostScript
39. 7. 39. 6.98149 MAarrowhead1
% End of user PostScript
.61319 .11799 m
.61319 .11799 L
s
% Start of user PostScript
40. 7. MAarrowzero1
% End of user PostScript
.6283 .11799 m
.62824 .11784 L
s
% Start of user PostScript
41. 7. 40.9961 6.99059 MAarrowhead1
% End of user PostScript
.6434 .11799 m
.64298 .11799 L
s
% Start of user PostScript
42. 7. 41.9718 7. MAarrowhead1
% End of user PostScript
.65851 .11799 m
.65799 .11836 L
s
% Start of user PostScript
43. 7. 42.9659 7.02471 MAarrowhead1
% End of user PostScript
.67361 .11799 m
.67324 .11733 L
s
% Start of user PostScript
44. 7. 43.9753 6.95678 MAarrowhead1
% End of user PostScript
.68872 .11799 m
.68909 .11836 L
s
% Start of user PostScript
45. 7. 45.0247 7.02471 MAarrowhead1
% End of user PostScript
.70382 .11799 m
.70368 .11799 L
s
% Start of user PostScript
46. 7. 45.9906 7. MAarrowhead1
% End of user PostScript
.71893 .11799 m
.71856 .11836 L
s
% Start of user PostScript
47. 7. 46.9753 7.02471 MAarrowhead1
% End of user PostScript
.73403 .11799 m
.73364 .11804 L
s
% Start of user PostScript
48. 7. 47.9742 7.00388 MAarrowhead1
% End of user PostScript
.74914 .11799 m
.74837 .11887 L
s
% Start of user PostScript
49. 7. 48.9489 7.05839 MAarrowhead1
% End of user PostScript
.76424 .11799 m
.76387 .11946 L
s
% Start of user PostScript
50. 7. 49.9753 7.0978 MAarrowhead1
% End of user PostScript
.77935 .11799 m
.77877 .12066 L
s
% Start of user PostScript
51. 7. 50.9615 7.17678 MAarrowhead1
% End of user PostScript
.79445 .11799 m
.79445 .11623 L
s
% Start of user PostScript
52. 7. 52. 6.88388 MAarrowhead1
% End of user PostScript
.80956 .11799 m
.8106 .11684 L
s
% Start of user PostScript
53. 7. 53.0687 6.92447 MAarrowhead1
% End of user PostScript
.82466 .11799 m
.8239 .11799 L
s
% Start of user PostScript
54. 7. 53.9497 7. MAarrowhead1
% End of user PostScript
.83977 .11799 m
.83977 .11765 L
s
% Start of user PostScript
55. 7. 55. 6.97761 MAarrowhead1
% End of user PostScript
.85488 .11799 m
.85448 .11661 L
s
% Start of user PostScript
56. 7. 55.9742 6.9091 MAarrowhead1
% End of user PostScript
.86998 .11799 m
.86993 .11711 L
s
% Start of user PostScript
57. 7. 56.9965 6.94204 MAarrowhead1
% End of user PostScript
.88509 .11799 m
.88548 .12013 L
s
% Start of user PostScript
58. 7. 58.0258 7.1422 MAarrowhead1
% End of user PostScript
.90019 .11799 m
.89937 .11799 L
s
% Start of user PostScript
59. 7. 58.9455 7. MAarrowhead1
% End of user PostScript
.9153 .11799 m
.91457 .11668 L
s
% Start of user PostScript
60. 7. 59.9522 6.91388 MAarrowhead1
% End of user PostScript
.9304 .11799 m
.93002 .11726 L
s
% Start of user PostScript
61. 7. 60.9746 6.9522 MAarrowhead1
% End of user PostScript
.94551 .11799 m
.94575 .11765 L
s
% Start of user PostScript
62. 7. 62.0163 6.97761 MAarrowhead1
% End of user PostScript
.96061 .11799 m
.96109 .11809 L
s
% Start of user PostScript
63. 7. 63.0318 7.0069 MAarrowhead1
% End of user PostScript
.97572 .11799 m
.97544 .11827 L
s
% Start of user PostScript
64. 7. 63.9815 7.01851 MAarrowhead1
% End of user PostScript
.02409 .13309 m
.02413 .13305 L
s
% Start of user PostScript
1. 8. 1.00251 7.99749 MAarrowhead1
% End of user PostScript
.03919 .13309 m
.03877 .13323 L
s
% Start of user PostScript
2. 8. 1.97208 8.00941 MAarrowhead1
% End of user PostScript
.0543 .13309 m
.05444 .13323 L
s
% Start of user PostScript
3. 8. 3.00941 8.00941 MAarrowhead1
% End of user PostScript
.0694 .13309 m
.0694 .13362 L
s
% Start of user PostScript
4. 8. 4. 8.03482 MAarrowhead1
% End of user PostScript
.08451 .13309 m
.08451 .13362 L
s
% Start of user PostScript
5. 8. 5. 8.03482 MAarrowhead1
% End of user PostScript
.09962 .13309 m
.09989 .13309 L
s
% Start of user PostScript
6. 8. 6.01851 8. MAarrowhead1
% End of user PostScript
.11472 .13309 m
.11472 .13305 L
s
% Start of user PostScript
7. 8. 7. 7.99749 MAarrowhead1
% End of user PostScript
.12983 .13309 m
.12983 .13305 L
s
% Start of user PostScript
8. 8. 8. 7.99749 MAarrowhead1
% End of user PostScript
.14493 .13309 m
.14493 .13309 L
s
% Start of user PostScript
9. 8. MAarrowzero1
% End of user PostScript
.16004 .13309 m
.15989 .13267 L
s
% Start of user PostScript
10. 8. 9.99059 7.97208 MAarrowhead1
% End of user PostScript
.17514 .13309 m
.17486 .13309 L
s
% Start of user PostScript
11. 8. 10.9815 8. MAarrowhead1
% End of user PostScript
.19025 .13309 m
.19025 .13299 L
s
% Start of user PostScript
12. 8. 12. 7.9931 MAarrowhead1
% End of user PostScript
.20535 .13309 m
.20535 .13281 L
s
% Start of user PostScript
13. 8. 13. 7.98149 MAarrowhead1
% End of user PostScript
.22046 .13309 m
.22035 .13309 L
s
% Start of user PostScript
14. 8. 13.9931 8. MAarrowhead1
% End of user PostScript
.23556 .13309 m
.23581 .1332 L
s
% Start of user PostScript
15. 8. 15.0163 8.0069 MAarrowhead1
% End of user PostScript
.25067 .13309 m
.25185 .13399 L
s
% Start of user PostScript
16. 8. 16.078 8.05953 MAarrowhead1
% End of user PostScript
.26577 .13309 m
.26739 .13513 L
s
% Start of user PostScript
17. 8. 17.1069 8.13525 MAarrowhead1
% End of user PostScript
.28088 .13309 m
.28411 .13398 L
s
% Start of user PostScript
18. 8. 18.2142 8.0591 MAarrowhead1
% End of user PostScript
.29598 .13309 m
.29771 .13401 L
s
% Start of user PostScript
19. 8. 19.114 8.0609 MAarrowhead1
% End of user PostScript
.31109 .13309 m
.31252 .13452 L
s
% Start of user PostScript
20. 8. 20.0946 8.09459 MAarrowhead1
% End of user PostScript
.32619 .13309 m
.31962 .13271 L
s
% Start of user PostScript
21. 8. 20.5651 7.97459 MAarrowhead1
% End of user PostScript
.3413 .13309 m
.34053 .13265 L
s
% Start of user PostScript
22. 8. 21.9489 7.9709 MAarrowhead1
% End of user PostScript
.3564 .13309 m
.35563 .13281 L
s
% Start of user PostScript
23. 8. 22.9489 7.98149 MAarrowhead1
% End of user PostScript
.37151 .13309 m
.37151 .13309 L
s
% Start of user PostScript
24. 8. MAarrowzero1
% End of user PostScript
.38661 .13309 m
.38661 .13263 L
s
% Start of user PostScript
25. 8. 25. 7.96976 MAarrowhead1
% End of user PostScript
.40172 .13309 m
.40172 .13309 L
s
% Start of user PostScript
26. 8. MAarrowzero1
% End of user PostScript
.41682 .13309 m
.4172 .13309 L
s
% Start of user PostScript
27. 8. 27.0247 8. MAarrowhead1
% End of user PostScript
.43193 .13309 m
.43156 .13346 L
s
% Start of user PostScript
28. 8. 27.9753 8.02471 MAarrowhead1
% End of user PostScript
.44703 .13309 m
.44703 .13309 L
s
% Start of user PostScript
29. 8. MAarrowzero1
% End of user PostScript
.46214 .13309 m
.46177 .13346 L
s
% Start of user PostScript
30. 8. 29.9753 8.02471 MAarrowhead1
% End of user PostScript
.47725 .13309 m
.47725 .13346 L
s
% Start of user PostScript
31. 8. 31. 8.02471 MAarrowhead1
% End of user PostScript
.49235 .13309 m
.49202 .13361 L
s
% Start of user PostScript
32. 8. 31.978 8.03412 MAarrowhead1
% End of user PostScript
.50746 .13309 m
.50746 .13272 L
s
% Start of user PostScript
33. 8. 33. 7.97529 MAarrowhead1
% End of user PostScript
.52256 .13309 m
.52256 .13309 L
s
% Start of user PostScript
34. 8. MAarrowzero1
% End of user PostScript
.53767 .13309 m
.53729 .13346 L
s
% Start of user PostScript
35. 8. 34.9753 8.02471 MAarrowhead1
% End of user PostScript
.55277 .13309 m
.5531 .1329 L
s
% Start of user PostScript
36. 8. 36.022 7.98745 MAarrowhead1
% End of user PostScript
.56788 .13309 m
.56754 .13329 L
s
% Start of user PostScript
37. 8. 36.978 8.01286 MAarrowhead1
% End of user PostScript
.58298 .13309 m
.58251 .13309 L
s
% Start of user PostScript
38. 8. 37.9686 8. MAarrowhead1
% End of user PostScript
.59809 .13309 m
.59809 .13281 L
s
% Start of user PostScript
39. 8. 39. 7.98149 MAarrowhead1
% End of user PostScript
.61319 .13309 m
.61319 .13309 L
s
% Start of user PostScript
40. 8. MAarrowzero1
% End of user PostScript
.6283 .13309 m
.62763 .13304 L
s
% Start of user PostScript
41. 8. 40.9561 7.99655 MAarrowhead1
% End of user PostScript
.6434 .13309 m
.64283 .13281 L
s
% Start of user PostScript
42. 8. 41.9624 7.98149 MAarrowhead1
% End of user PostScript
.65851 .13309 m
.65813 .13309 L
s
% Start of user PostScript
43. 8. 42.9753 8. MAarrowhead1
% End of user PostScript
.67361 .13309 m
.67375 .13309 L
s
% Start of user PostScript
44. 8. 44.0094 8. MAarrowhead1
% End of user PostScript
.68872 .13309 m
.68834 .13366 L
s
% Start of user PostScript
45. 8. 44.9753 8.03757 MAarrowhead1
% End of user PostScript
.70382 .13309 m
.70281 .13411 L
s
% Start of user PostScript
46. 8. 45.9326 8.06737 MAarrowhead1
% End of user PostScript
.71893 .13309 m
.71805 .13481 L
s
% Start of user PostScript
47. 8. 46.9416 8.11404 MAarrowhead1
% End of user PostScript
.73403 .13309 m
.73313 .13448 L
s
% Start of user PostScript
48. 8. 47.9405 8.09208 MAarrowhead1
% End of user PostScript
.74914 .13309 m
.74914 .13522 L
s
% Start of user PostScript
49. 8. 49. 8.14122 MAarrowhead1
% End of user PostScript
.76424 .13309 m
.76255 .13733 L
s
% Start of user PostScript
50. 8. 49.8877 8.28078 MAarrowhead1
% End of user PostScript
.77935 .13309 m
.77893 .13027 L
s
% Start of user PostScript
51. 8. 50.9723 7.81337 MAarrowhead1
% End of user PostScript
.79445 .13309 m
.79563 .13499 L
s
% Start of user PostScript
52. 8. 52.078 8.12553 MAarrowhead1
% End of user PostScript
.80956 .13309 m
.80864 .1327 L
s
% Start of user PostScript
53. 8. 52.9393 7.97416 MAarrowhead1
% End of user PostScript
.82466 .13309 m
.82666 .13177 L
s
% Start of user PostScript
54. 8. 54.1318 7.91255 MAarrowhead1
% End of user PostScript
.83977 .13309 m
.83977 .13309 L
s
% Start of user PostScript
55. 8. MAarrowzero1
% End of user PostScript
.85488 .13309 m
.85331 .13309 L
s
% Start of user PostScript
56. 8. 55.8961 8. MAarrowhead1
% End of user PostScript
.86998 .13309 m
.86931 .13219 L
s
% Start of user PostScript
57. 8. 56.9558 7.94047 MAarrowhead1
% End of user PostScript
.88509 .13309 m
.88392 .13193 L
s
% Start of user PostScript
58. 8. 57.9231 7.9231 MAarrowhead1
% End of user PostScript
.90019 .13309 m
.90019 .131 L
s
% Start of user PostScript
59. 8. 59. 7.86149 MAarrowhead1
% End of user PostScript
.9153 .13309 m
.91612 .13429 L
s
% Start of user PostScript
60. 8. 60.0545 8.07918 MAarrowhead1
% End of user PostScript
.9304 .13309 m
.92931 .13147 L
s
% Start of user PostScript
61. 8. 60.9279 7.89267 MAarrowhead1
% End of user PostScript
.94551 .13309 m
.94492 .13337 L
s
% Start of user PostScript
62. 8. 61.9613 8.01851 MAarrowhead1
% End of user PostScript
.96061 .13309 m
.96065 .13275 L
s
% Start of user PostScript
63. 8. 63.0025 7.97761 MAarrowhead1
% End of user PostScript
.97572 .13309 m
.97529 .13256 L
s
% Start of user PostScript
64. 8. 63.9721 7.96518 MAarrowhead1
% End of user PostScript
.02409 .1482 m
.02423 .14805 L
s
% Start of user PostScript
1. 9. 1.00941 8.99059 MAarrowhead1
% End of user PostScript
.03919 .1482 m
.03895 .1482 L
s
% Start of user PostScript
2. 9. 1.98369 9. MAarrowhead1
% End of user PostScript
.0543 .1482 m
.0543 .14777 L
s
% Start of user PostScript
3. 9. 3. 8.97208 MAarrowhead1
% End of user PostScript
.0694 .1482 m
.0693 .14777 L
s
% Start of user PostScript
4. 9. 3.9931 8.97208 MAarrowhead1
% End of user PostScript
.08451 .1482 m
.08451 .14792 L
s
% Start of user PostScript
5. 9. 5. 8.98149 MAarrowhead1
% End of user PostScript
.09962 .1482 m
.09951 .14834 L
s
% Start of user PostScript
6. 9. 5.9931 9.00941 MAarrowhead1
% End of user PostScript
.11472 .1482 m
.115 .14858 L
s
% Start of user PostScript
7. 9. 7.01851 9.02541 MAarrowhead1
% End of user PostScript
.12983 .1482 m
.12983 .14872 L
s
% Start of user PostScript
8. 9. 8. 9.03482 MAarrowhead1
% End of user PostScript
.14493 .1482 m
.14465 .14862 L
s
% Start of user PostScript
9. 9. 8.98149 9.02792 MAarrowhead1
% End of user PostScript
.16004 .1482 m
.15961 .14792 L
s
% Start of user PostScript
10. 9. 9.97208 8.98149 MAarrowhead1
% End of user PostScript
.17514 .1482 m
.17552 .14792 L
s
% Start of user PostScript
11. 9. 11.0254 8.98149 MAarrowhead1
% End of user PostScript
.19025 .1482 m
.18997 .14809 L
s
% Start of user PostScript
12. 9. 11.9815 8.9931 MAarrowhead1
% End of user PostScript
.20535 .1482 m
.20577 .14834 L
s
% Start of user PostScript
13. 9. 13.0279 9.00941 MAarrowhead1
% End of user PostScript
.22046 .1482 m
.22031 .14805 L
s
% Start of user PostScript
14. 9. 13.9906 8.99059 MAarrowhead1
% End of user PostScript
.23556 .1482 m
.23556 .1482 L
s
% Start of user PostScript
15. 9. MAarrowzero1
% End of user PostScript
.25067 .1482 m
.25025 .14853 L
s
% Start of user PostScript
16. 9. 15.9721 9.02239 MAarrowhead1
% End of user PostScript
.26577 .1482 m
.26505 .14811 L
s
% Start of user PostScript
17. 9. 16.9522 8.99404 MAarrowhead1
% End of user PostScript
.28088 .1482 m
.2813 .15019 L
s
% Start of user PostScript
18. 9. 18.0279 9.1318 MAarrowhead1
% End of user PostScript
.29598 .1482 m
.29738 .14996 L
s
% Start of user PostScript
19. 9. 19.0923 9.11655 MAarrowhead1
% End of user PostScript
.31109 .1482 m
.31184 .1482 L
s
% Start of user PostScript
20. 9. 20.0499 9. MAarrowhead1
% End of user PostScript
.32619 .1482 m
.32743 .14876 L
s
% Start of user PostScript
21. 9. 21.082 9.03733 MAarrowhead1
% End of user PostScript
.3413 .1482 m
.33206 .14867 L
s
% Start of user PostScript
22. 9. 21.3882 9.03137 MAarrowhead1
% End of user PostScript
.3564 .1482 m
.35574 .14791 L
s
% Start of user PostScript
23. 9. 22.9558 8.98118 MAarrowhead1
% End of user PostScript
.37151 .1482 m
.37123 .1482 L
s
% Start of user PostScript
24. 9. 23.9815 9. MAarrowhead1
% End of user PostScript
.38661 .1482 m
.38616 .14834 L
s
% Start of user PostScript
25. 9. 24.9698 9.00941 MAarrowhead1
% End of user PostScript
.40172 .1482 m
.40172 .1482 L
s
% Start of user PostScript
26. 9. MAarrowzero1
% End of user PostScript
.41682 .1482 m
.41682 .1482 L
s
% Start of user PostScript
27. 9. MAarrowzero1
% End of user PostScript
.43193 .1482 m
.4323 .14857 L
s
% Start of user PostScript
28. 9. 28.0247 9.02471 MAarrowhead1
% End of user PostScript
.44703 .1482 m
.44703 .1482 L
s
% Start of user PostScript
29. 9. MAarrowzero1
% End of user PostScript
.46214 .1482 m
.46214 .1482 L
s
% Start of user PostScript
30. 9. MAarrowzero1
% End of user PostScript
.47725 .1482 m
.47725 .14871 L
s
% Start of user PostScript
31. 9. 31. 9.03412 MAarrowhead1
% End of user PostScript
.49235 .1482 m
.49268 .1482 L
s
% Start of user PostScript
32. 9. 32.022 9. MAarrowhead1
% End of user PostScript
.50746 .1482 m
.50712 .14833 L
s
% Start of user PostScript
33. 9. 32.978 9.0091 MAarrowhead1
% End of user PostScript
.52256 .1482 m
.52251 .14853 L
s
% Start of user PostScript
34. 9. 33.9965 9.02196 MAarrowhead1
% End of user PostScript
.53767 .1482 m
.53767 .14857 L
s
% Start of user PostScript
35. 9. 35. 9.02471 MAarrowhead1
% End of user PostScript
.55277 .1482 m
.5531 .14806 L
s
% Start of user PostScript
36. 9. 36.022 8.9909 MAarrowhead1
% End of user PostScript
.56788 .1482 m
.56802 .14834 L
s
% Start of user PostScript
37. 9. 37.0094 9.00941 MAarrowhead1
% End of user PostScript
.58298 .1482 m
.58312 .14853 L
s
% Start of user PostScript
38. 9. 38.0094 9.02196 MAarrowhead1
% End of user PostScript
.59809 .1482 m
.59726 .14853 L
s
% Start of user PostScript
39. 9. 38.9455 9.02196 MAarrowhead1
% End of user PostScript
.61319 .1482 m
.61333 .14853 L
s
% Start of user PostScript
40. 9. 40.0094 9.02196 MAarrowhead1
% End of user PostScript
.6283 .1482 m
.6283 .14772 L
s
% Start of user PostScript
41. 9. 41. 8.96863 MAarrowhead1
% End of user PostScript
.6434 .1482 m
.64293 .14758 L
s
% Start of user PostScript
42. 9. 41.9686 8.95953 MAarrowhead1
% End of user PostScript
.65851 .1482 m
.65884 .149 L
s
% Start of user PostScript
43. 9. 43.022 9.05333 MAarrowhead1
% End of user PostScript
.67361 .1482 m
.67361 .14867 L
s
% Start of user PostScript
44. 9. 44. 9.03137 MAarrowhead1
% End of user PostScript
.68872 .1482 m
.68823 .14897 L
s
% Start of user PostScript
45. 9. 44.9675 9.05106 MAarrowhead1
% End of user PostScript
.70382 .1482 m
.70416 .14875 L
s
% Start of user PostScript
46. 9. 46.0224 9.03643 MAarrowhead1
% End of user PostScript
.71893 .1482 m
.71898 .14951 L
s
% Start of user PostScript
47. 9. 47.0035 9.08702 MAarrowhead1
% End of user PostScript
.73403 .1482 m
.73303 .15054 L
s
% Start of user PostScript
48. 9. 47.9338 9.15525 MAarrowhead1
% End of user PostScript
.74914 .1482 m
.75023 .14931 L
s
% Start of user PostScript
49. 9. 49.0722 9.07376 MAarrowhead1
% End of user PostScript
.76424 .1482 m
.76463 .14584 L
s
% Start of user PostScript
50. 9. 50.0258 8.84392 MAarrowhead1
% End of user PostScript
.77935 .1482 m
.7794 .14777 L
s
% Start of user PostScript
51. 9. 51.0035 8.97208 MAarrowhead1
% End of user PostScript
.79445 .1482 m
.79445 .1482 L
s
% Start of user PostScript
52. 9. MAarrowzero1
% End of user PostScript
.80956 .1482 m
.80956 .14872 L
s
% Start of user PostScript
53. 9. 53. 9.03482 MAarrowhead1
% End of user PostScript
.82466 .1482 m
.82338 .14994 L
s
% Start of user PostScript
54. 9. 53.9149 9.11537 MAarrowhead1
% End of user PostScript
.83977 .1482 m
.83879 .14906 L
s
% Start of user PostScript
55. 9. 54.9349 9.05722 MAarrowhead1
% End of user PostScript
.85488 .1482 m
.85586 .14682 L
s
% Start of user PostScript
56. 9. 56.0651 8.9091 MAarrowhead1
% End of user PostScript
.86998 .1482 m
.86998 .14825 L
s
% Start of user PostScript
57. 9. 57. 9.00345 MAarrowhead1
% End of user PostScript
.88509 .1482 m
.88509 .14726 L
s
% Start of user PostScript
58. 9. 58. 8.93816 MAarrowhead1
% End of user PostScript
.90019 .1482 m
.90025 .14783 L
s
% Start of user PostScript
59. 9. 59.0039 8.97573 MAarrowhead1
% End of user PostScript
.9153 .1482 m
.91619 .14658 L
s
% Start of user PostScript
60. 9. 60.0591 8.8931 MAarrowhead1
% End of user PostScript
.9304 .1482 m
.92992 .14814 L
s
% Start of user PostScript
61. 9. 60.9684 8.99612 MAarrowhead1
% End of user PostScript
.94551 .1482 m
.94603 .14721 L
s
% Start of user PostScript
62. 9. 62.0348 8.93451 MAarrowhead1
% End of user PostScript
.96061 .1482 m
.96089 .14792 L
s
% Start of user PostScript
63. 9. 63.0185 8.98149 MAarrowhead1
% End of user PostScript
.97572 .1482 m
.97572 .14777 L
s
% Start of user PostScript
64. 9. 64. 8.97208 MAarrowhead1
% End of user PostScript
.02409 .1633 m
.02462 .16278 L
s
% Start of user PostScript
1. 10. 1.03482 9.96518 MAarrowhead1
% End of user PostScript
.03919 .1633 m
.03947 .16383 L
s
% Start of user PostScript
2. 10. 2.01851 10.0348 MAarrowhead1
% End of user PostScript
.0543 .1633 m
.0543 .16358 L
s
% Start of user PostScript
3. 10. 3. 10.0185 MAarrowhead1
% End of user PostScript
.0694 .1633 m
.06979 .1633 L
s
% Start of user PostScript
4. 10. 4.02541 10. MAarrowhead1
% End of user PostScript
.08451 .1633 m
.08451 .1633 L
s
% Start of user PostScript
5. 10. MAarrowzero1
% End of user PostScript
.09962 .1633 m
.09962 .16383 L
s
% Start of user PostScript
6. 10. 6. 10.0348 MAarrowhead1
% End of user PostScript
.11472 .1633 m
.11497 .16288 L
s
% Start of user PostScript
7. 10. 7.01631 9.97208 MAarrowhead1
% End of user PostScript
.12983 .1633 m
.1294 .16355 L
s
% Start of user PostScript
8. 10. 7.97208 10.0163 MAarrowhead1
% End of user PostScript
.14493 .1633 m
.14465 .16358 L
s
% Start of user PostScript
9. 10. 8.98149 10.0185 MAarrowhead1
% End of user PostScript
.16004 .1633 m
.16032 .1633 L
s
% Start of user PostScript
10. 10. 10.0185 10. MAarrowhead1
% End of user PostScript
.17514 .1633 m
.17504 .16316 L
s
% Start of user PostScript
11. 10. 10.9931 9.99059 MAarrowhead1
% End of user PostScript
.19025 .1633 m
.19053 .16344 L
s
% Start of user PostScript
12. 10. 12.0185 10.0094 MAarrowhead1
% End of user PostScript
.20535 .1633 m
.20521 .16358 L
s
% Start of user PostScript
13. 10. 12.9906 10.0185 MAarrowhead1
% End of user PostScript
.22046 .1633 m
.22074 .1633 L
s
% Start of user PostScript
14. 10. 14.0185 10. MAarrowhead1
% End of user PostScript
.23556 .1633 m
.23552 .16326 L
s
% Start of user PostScript
15. 10. 14.9975 9.99749 MAarrowhead1
% End of user PostScript
.25067 .1633 m
.25095 .16389 L
s
% Start of user PostScript
16. 10. 16.0185 10.0387 MAarrowhead1
% End of user PostScript
.26577 .1633 m
.26577 .16358 L
s
% Start of user PostScript
17. 10. 17. 10.0185 MAarrowhead1
% End of user PostScript
.28088 .1633 m
.28164 .16406 L
s
% Start of user PostScript
18. 10. 18.0503 10.0503 MAarrowhead1
% End of user PostScript
.29598 .1633 m
.29652 .16475 L
s
% Start of user PostScript
19. 10. 19.0353 10.0957 MAarrowhead1
% End of user PostScript
.31109 .1633 m
.31193 .1633 L
s
% Start of user PostScript
20. 10. 20.0556 10. MAarrowhead1
% End of user PostScript
.32619 .1633 m
.32723 .16501 L
s
% Start of user PostScript
21. 10. 21.0687 10.1134 MAarrowhead1
% End of user PostScript
.3413 .1633 m
.34181 .16283 L
s
% Start of user PostScript
22. 10. 22.0337 9.96863 MAarrowhead1
% End of user PostScript
.3564 .1633 m
.3564 .1633 L
s
% Start of user PostScript
23. 10. MAarrowzero1
% End of user PostScript
.37151 .1633 m
.37146 .1633 L
s
% Start of user PostScript
24. 10. 23.9965 10. MAarrowhead1
% End of user PostScript
.38661 .1633 m
.38661 .16324 L
s
% Start of user PostScript
25. 10. 25. 9.99612 MAarrowhead1
% End of user PostScript
.40172 .1633 m
.40158 .16293 L
s
% Start of user PostScript
26. 10. 25.9906 9.97529 MAarrowhead1
% End of user PostScript
.41682 .1633 m
.41682 .16293 L
s
% Start of user PostScript
27. 10. 27. 9.97529 MAarrowhead1
% End of user PostScript
.43193 .1633 m
.43156 .1633 L
s
% Start of user PostScript
28. 10. 27.9753 10. MAarrowhead1
% End of user PostScript
.44703 .1633 m
.44703 .16367 L
s
% Start of user PostScript
29. 10. 29. 10.0247 MAarrowhead1
% End of user PostScript
.46214 .1633 m
.46214 .16363 L
s
% Start of user PostScript
30. 10. 30. 10.022 MAarrowhead1
% End of user PostScript
.47725 .1633 m
.47725 .1633 L
s
% Start of user PostScript
31. 10. MAarrowzero1
% End of user PostScript
.49235 .1633 m
.49216 .1633 L
s
% Start of user PostScript
32. 10. 31.9871 10. MAarrowhead1
% End of user PostScript
.50746 .1633 m
.50732 .16325 L
s
% Start of user PostScript
33. 10. 32.9909 9.99655 MAarrowhead1
% End of user PostScript
.52256 .1633 m
.52256 .16378 L
s
% Start of user PostScript
34. 10. 34. 10.0314 MAarrowhead1
% End of user PostScript
.53767 .1633 m
.53752 .16396 L
s
% Start of user PostScript
35. 10. 34.9906 10.0439 MAarrowhead1
% End of user PostScript
.55277 .1633 m
.55277 .1635 L
s
% Start of user PostScript
36. 10. 36. 10.0129 MAarrowhead1
% End of user PostScript
.56788 .1633 m
.56788 .1633 L
s
% Start of user PostScript
37. 10. MAarrowzero1
% End of user PostScript
.58298 .1633 m
.58298 .16363 L
s
% Start of user PostScript
38. 10. 38. 10.022 MAarrowhead1
% End of user PostScript
.59809 .1633 m
.59787 .16379 L
s
% Start of user PostScript
39. 10. 38.986 10.0325 MAarrowhead1
% End of user PostScript
.61319 .1633 m
.61285 .16385 L
s
% Start of user PostScript
40. 10. 39.9776 10.0364 MAarrowhead1
% End of user PostScript
.6283 .1633 m
.62796 .16296 L
s
% Start of user PostScript
41. 10. 40.9776 9.97761 MAarrowhead1
% End of user PostScript
.6434 .1633 m
.64428 .16351 L
s
% Start of user PostScript
42. 10. 42.058 10.014 MAarrowhead1
% End of user PostScript
.65851 .1633 m
.65805 .16502 L
s
% Start of user PostScript
43. 10. 42.9698 10.114 MAarrowhead1
% End of user PostScript
.67361 .1633 m
.67282 .16406 L
s
% Start of user PostScript
44. 10. 43.9474 10.0501 MAarrowhead1
% End of user PostScript
.68872 .1633 m
.68881 .16495 L
s
% Start of user PostScript
45. 10. 45.006 10.1094 MAarrowhead1
% End of user PostScript
.70382 .1633 m
.70302 .16563 L
s
% Start of user PostScript
46. 10. 45.9467 10.1539 MAarrowhead1
% End of user PostScript
.71893 .1633 m
.72069 .16621 L
s
% Start of user PostScript
47. 10. 47.1165 10.1924 MAarrowhead1
% End of user PostScript
.73403 .1633 m
.73571 .16388 L
s
% Start of user PostScript
48. 10. 48.1107 10.0385 MAarrowhead1
% End of user PostScript
.74914 .1633 m
.74861 .16394 L
s
% Start of user PostScript
49. 10. 48.9647 10.0424 MAarrowhead1
% End of user PostScript
.76424 .1633 m
.76307 .16246 L
s
% Start of user PostScript
50. 10. 49.922 9.94435 MAarrowhead1
% End of user PostScript
.77935 .1633 m
.77901 .16372 L
s
% Start of user PostScript
51. 10. 50.9776 10.0279 MAarrowhead1
% End of user PostScript
.79445 .1633 m
.79445 .16269 L
s
% Start of user PostScript
52. 10. 52. 9.95922 MAarrowhead1
% End of user PostScript
.80956 .1633 m
.80956 .16305 L
s
% Start of user PostScript
53. 10. 53. 9.98357 MAarrowhead1
% End of user PostScript
.82466 .1633 m
.82556 .1633 L
s
% Start of user PostScript
54. 10. 54.0595 10. MAarrowhead1
% End of user PostScript
.83977 .1633 m
.83977 .16209 L
s
% Start of user PostScript
55. 10. 55. 9.91965 MAarrowhead1
% End of user PostScript
.85488 .1633 m
.85473 .16296 L
s
% Start of user PostScript
56. 10. 55.9906 9.97761 MAarrowhead1
% End of user PostScript
.86998 .1633 m
.86998 .16234 L
s
% Start of user PostScript
57. 10. 57. 9.93608 MAarrowhead1
% End of user PostScript
.88509 .1633 m
.88509 .1633 L
s
% Start of user PostScript
58. 10. MAarrowzero1
% End of user PostScript
.90019 .1633 m
.90019 .16207 L
s
% Start of user PostScript
59. 10. 59. 9.91851 MAarrowhead1
% End of user PostScript
.9153 .1633 m
.91496 .16207 L
s
% Start of user PostScript
60. 10. 59.978 9.91851 MAarrowhead1
% End of user PostScript
.9304 .1633 m
.93054 .16244 L
s
% Start of user PostScript
61. 10. 61.0094 9.94278 MAarrowhead1
% End of user PostScript
.94551 .1633 m
.94551 .1632 L
s
% Start of user PostScript
62. 10. 62. 9.9931 MAarrowhead1
% End of user PostScript
.96061 .1633 m
.96033 .16302 L
s
% Start of user PostScript
63. 10. 62.9815 9.98149 MAarrowhead1
% End of user PostScript
.97572 .1633 m
.97572 .16302 L
s
% Start of user PostScript
64. 10. 64. 9.98149 MAarrowhead1
% End of user PostScript
.02409 .17841 m
.02409 .17841 L
s
% Start of user PostScript
1. 11. MAarrowzero1
% End of user PostScript
.03919 .17841 m
.03958 .17855 L
s
% Start of user PostScript
2. 11. 2.02541 11.0094 MAarrowhead1
% End of user PostScript
.0543 .17841 m
.05458 .17844 L
s
% Start of user PostScript
3. 11. 3.01851 11.0025 MAarrowhead1
% End of user PostScript
.0694 .17841 m
.06913 .17826 L
s
% Start of user PostScript
4. 11. 3.98149 10.9906 MAarrowhead1
% End of user PostScript
.08451 .17841 m
.08451 .17802 L
s
% Start of user PostScript
5. 11. 5. 10.9746 MAarrowhead1
% End of user PostScript
.09962 .17841 m
.09965 .17802 L
s
% Start of user PostScript
6. 11. 6.00251 10.9746 MAarrowhead1
% End of user PostScript
.11472 .17841 m
.11472 .17841 L
s
% Start of user PostScript
7. 11. MAarrowzero1
% End of user PostScript
.12983 .17841 m
.12983 .17855 L
s
% Start of user PostScript
8. 11. 8. 11.0094 MAarrowhead1
% End of user PostScript
.14493 .17841 m
.14465 .17802 L
s
% Start of user PostScript
9. 11. 8.98149 10.9746 MAarrowhead1
% End of user PostScript
.16004 .17841 m
.15989 .17841 L
s
% Start of user PostScript
10. 11. 9.99059 11. MAarrowhead1
% End of user PostScript
.17514 .17841 m
.17462 .17855 L
s
% Start of user PostScript
11. 11. 10.9652 11.0094 MAarrowhead1
% End of user PostScript
.19025 .17841 m
.19067 .17841 L
s
% Start of user PostScript
12. 11. 12.0279 11. MAarrowhead1
% End of user PostScript
.20535 .17841 m
.20507 .17841 L
s
% Start of user PostScript
13. 11. 12.9815 11. MAarrowhead1
% End of user PostScript
.22046 .17841 m
.22007 .17841 L
s
% Start of user PostScript
14. 11. 13.9746 11. MAarrowhead1
% End of user PostScript
.23556 .17841 m
.23546 .17855 L
s
% Start of user PostScript
15. 11. 14.9931 11.0094 MAarrowhead1
% End of user PostScript
.25067 .17841 m
.25052 .17869 L
s
% Start of user PostScript
16. 11. 15.9906 11.0185 MAarrowhead1
% End of user PostScript
.26577 .17841 m
.26744 .18057 L
s
% Start of user PostScript
17. 11. 17.1104 11.1433 MAarrowhead1
% End of user PostScript
.28088 .17841 m
.28088 .17917 L
s
% Start of user PostScript
18. 11. 18. 11.0503 MAarrowhead1
% End of user PostScript
.29598 .17841 m
.29683 .17841 L
s
% Start of user PostScript
19. 11. 19.0561 11. MAarrowhead1
% End of user PostScript
.31109 .17841 m
.31251 .18039 L
s
% Start of user PostScript
20. 11. 20.0942 11.1315 MAarrowhead1
% End of user PostScript
.32619 .17841 m
.32776 .17941 L
s
% Start of user PostScript
21. 11. 21.104 11.0667 MAarrowhead1
% End of user PostScript
.3413 .17841 m
.34146 .17717 L
s
% Start of user PostScript
22. 11. 22.0106 10.918 MAarrowhead1
% End of user PostScript
.3564 .17841 m
.34869 .17249 L
s
% Start of user PostScript
23. 11. 22.4895 10.6083 MAarrowhead1
% End of user PostScript
.37151 .17841 m
.37151 .1783 L
s
% Start of user PostScript
24. 11. 24. 10.9927 MAarrowhead1
% End of user PostScript
.38661 .17841 m
.38713 .17892 L
s
% Start of user PostScript
25. 11. 25.0341 11.0341 MAarrowhead1
% End of user PostScript
.40172 .17841 m
.4012 .17826 L
s
% Start of user PostScript
26. 11. 25.9659 10.9906 MAarrowhead1
% End of user PostScript
.41682 .17841 m
.41649 .1786 L
s
% Start of user PostScript
27. 11. 26.978 11.0129 MAarrowhead1
% End of user PostScript
.43193 .17841 m
.43193 .17874 L
s
% Start of user PostScript
28. 11. 28. 11.022 MAarrowhead1
% End of user PostScript
.44703 .17841 m
.44684 .17841 L
s
% Start of user PostScript
29. 11. 28.9871 11. MAarrowhead1
% End of user PostScript
.46214 .17841 m
.46214 .17846 L
s
% Start of user PostScript
30. 11. 30. 11.0035 MAarrowhead1
% End of user PostScript
.47725 .17841 m
.47739 .17846 L
s
% Start of user PostScript
31. 11. 31.0094 11.0035 MAarrowhead1
% End of user PostScript
.49235 .17841 m
.49202 .17846 L
s
% Start of user PostScript
32. 11. 31.978 11.0035 MAarrowhead1
% End of user PostScript
.50746 .17841 m
.50779 .17869 L
s
% Start of user PostScript
33. 11. 33.022 11.0185 MAarrowhead1
% End of user PostScript
.52256 .17841 m
.52228 .17855 L
s
% Start of user PostScript
34. 11. 33.9815 11.0094 MAarrowhead1
% End of user PostScript
.53767 .17841 m
.53767 .17862 L
s
% Start of user PostScript
35. 11. 35. 11.014 MAarrowhead1
% End of user PostScript
.55277 .17841 m
.55291 .17841 L
s
% Start of user PostScript
36. 11. 36.0094 11. MAarrowhead1
% End of user PostScript
.56788 .17841 m
.56754 .17918 L
s
% Start of user PostScript
37. 11. 36.978 11.0511 MAarrowhead1
% End of user PostScript
.58298 .17841 m
.58277 .1789 L
s
% Start of user PostScript
38. 11. 37.986 11.0325 MAarrowhead1
% End of user PostScript
.59809 .17841 m
.59771 .17945 L
s
% Start of user PostScript
39. 11. 38.9753 11.0689 MAarrowhead1
% End of user PostScript
.61319 .17841 m
.61319 .17793 L
s
% Start of user PostScript
40. 11. 40. 10.9686 MAarrowhead1
% End of user PostScript
.6283 .17841 m
.62824 .17758 L
s
% Start of user PostScript
41. 11. 40.9965 10.9455 MAarrowhead1
% End of user PostScript
.6434 .17841 m
.6434 .17978 L
s
% Start of user PostScript
42. 11. 42. 11.0909 MAarrowhead1
% End of user PostScript
.65851 .17841 m
.65851 .17793 L
s
% Start of user PostScript
43. 11. 43. 10.9686 MAarrowhead1
% End of user PostScript
.67361 .17841 m
.67281 .17984 L
s
% Start of user PostScript
44. 11. 43.9467 11.0946 MAarrowhead1
% End of user PostScript
.68872 .17841 m
.68791 .18133 L
s
% Start of user PostScript
45. 11. 44.9464 11.1938 MAarrowhead1
% End of user PostScript
.70382 .17841 m
.70507 .17933 L
s
% Start of user PostScript
46. 11. 46.0829 11.0609 MAarrowhead1
% End of user PostScript
.71893 .17841 m
.71748 .17807 L
s
% Start of user PostScript
47. 11. 46.9043 10.978 MAarrowhead1
% End of user PostScript
.73403 .17841 m
.73398 .17735 L
s
% Start of user PostScript
48. 11. 47.9965 10.9301 MAarrowhead1
% End of user PostScript
.74914 .17841 m
.74763 .17799 L
s
% Start of user PostScript
49. 11. 48.9 10.9723 MAarrowhead1
% End of user PostScript
.76424 .17841 m
.76419 .17841 L
s
% Start of user PostScript
50. 11. 49.9965 11. MAarrowhead1
% End of user PostScript
.77935 .17841 m
.77935 .17874 L
s
% Start of user PostScript
51. 11. 51. 11.0224 MAarrowhead1
% End of user PostScript
.79445 .17841 m
.79217 .17675 L
s
% Start of user PostScript
52. 11. 51.8486 10.8906 MAarrowhead1
% End of user PostScript
.80956 .17841 m
.80951 .17684 L
s
% Start of user PostScript
53. 11. 52.9965 10.8961 MAarrowhead1
% End of user PostScript
.82466 .17841 m
.82419 .17674 L
s
% Start of user PostScript
54. 11. 53.9686 10.8894 MAarrowhead1
% End of user PostScript
.83977 .17841 m
.83977 .17841 L
s
% Start of user PostScript
55. 11. MAarrowzero1
% End of user PostScript
.85488 .17841 m
.85488 .17674 L
s
% Start of user PostScript
56. 11. 56. 10.8894 MAarrowhead1
% End of user PostScript
.86998 .17841 m
.86998 .17841 L
s
% Start of user PostScript
57. 11. MAarrowzero1
% End of user PostScript
.88509 .17841 m
.8847 .17793 L
s
% Start of user PostScript
58. 11. 57.9746 10.9684 MAarrowhead1
% End of user PostScript
.90019 .17841 m
.90019 .1776 L
s
% Start of user PostScript
59. 11. 59. 10.9464 MAarrowhead1
% End of user PostScript
.9153 .17841 m
.91477 .17782 L
s
% Start of user PostScript
60. 11. 59.9652 10.9613 MAarrowhead1
% End of user PostScript
.9304 .17841 m
.93082 .17893 L
s
% Start of user PostScript
61. 11. 61.0279 11.0348 MAarrowhead1
% End of user PostScript
.94551 .17841 m
.94551 .17788 L
s
% Start of user PostScript
62. 11. 62. 10.9652 MAarrowhead1
% End of user PostScript
.96061 .17841 m
.96089 .17883 L
s
% Start of user PostScript
63. 11. 63.0185 11.0279 MAarrowhead1
% End of user PostScript
.97572 .17841 m
.97572 .17813 L
s
% Start of user PostScript
64. 11. 64. 10.9815 MAarrowhead1
% End of user PostScript
.02409 .19351 m
.02409 .19351 L
s
% Start of user PostScript
1. 12. MAarrowzero1
% End of user PostScript
.03919 .19351 m
.03919 .19309 L
s
% Start of user PostScript
2. 12. 2. 11.9721 MAarrowhead1
% End of user PostScript
.0543 .19351 m
.05388 .19313 L
s
% Start of user PostScript
3. 12. 2.97208 11.9746 MAarrowhead1
% End of user PostScript
.0694 .19351 m
.0694 .19379 L
s
% Start of user PostScript
4. 12. 4. 12.0185 MAarrowhead1
% End of user PostScript
.08451 .19351 m
.08451 .19379 L
s
% Start of user PostScript
5. 12. 5. 12.0185 MAarrowhead1
% End of user PostScript
.09962 .19351 m
.09962 .19351 L
s
% Start of user PostScript
6. 12. MAarrowzero1
% End of user PostScript
.11472 .19351 m
.11472 .19351 L
s
% Start of user PostScript
7. 12. MAarrowzero1
% End of user PostScript
.12983 .19351 m
.13011 .19351 L
s
% Start of user PostScript
8. 12. 8.01851 12. MAarrowhead1
% End of user PostScript
.14493 .19351 m
.14465 .19341 L
s
% Start of user PostScript
9. 12. 8.98149 11.9931 MAarrowhead1
% End of user PostScript
.16004 .19351 m
.16004 .19379 L
s
% Start of user PostScript
10. 12. 10. 12.0185 MAarrowhead1
% End of user PostScript
.17514 .19351 m
.17539 .19323 L
s
% Start of user PostScript
11. 12. 11.0163 11.9815 MAarrowhead1
% End of user PostScript
.19025 .19351 m
.19053 .19379 L
s
% Start of user PostScript
12. 12. 12.0185 12.0185 MAarrowhead1
% End of user PostScript
.20535 .19351 m
.20577 .19393 L
s
% Start of user PostScript
13. 12. 13.0279 12.0279 MAarrowhead1
% End of user PostScript
.22046 .19351 m
.22046 .19309 L
s
% Start of user PostScript
14. 12. 14. 11.9721 MAarrowhead1
% End of user PostScript
.23556 .19351 m
.23595 .19393 L
s
% Start of user PostScript
15. 12. 15.0254 12.0279 MAarrowhead1
% End of user PostScript
.25067 .19351 m
.25067 .19435 L
s
% Start of user PostScript
16. 12. 16. 12.0556 MAarrowhead1
% End of user PostScript
.26577 .19351 m
.26577 .19446 L
s
% Start of user PostScript
17. 12. 17. 12.063 MAarrowhead1
% End of user PostScript
.28088 .19351 m
.28206 .19413 L
s
% Start of user PostScript
18. 12. 18.078 12.0408 MAarrowhead1
% End of user PostScript
.29598 .19351 m
.29677 .19351 L
s
% Start of user PostScript
19. 12. 19.0518 12. MAarrowhead1
% End of user PostScript
.31109 .19351 m
.31142 .19525 L
s
% Start of user PostScript
20. 12. 20.022 12.1149 MAarrowhead1
% End of user PostScript
.32619 .19351 m
.32619 .19276 L
s
% Start of user PostScript
21. 12. 21. 11.9501 MAarrowhead1
% End of user PostScript
.3413 .19351 m
.34231 .19517 L
s
% Start of user PostScript
22. 12. 22.0667 12.1095 MAarrowhead1
% End of user PostScript
.3564 .19351 m
.34845 .18393 L
s
% Start of user PostScript
23. 12. 22.4733 11.3658 MAarrowhead1
% End of user PostScript
.37151 .19351 m
.37117 .19266 L
s
% Start of user PostScript
24. 12. 23.9776 11.9439 MAarrowhead1
% End of user PostScript
.38661 .19351 m
.38653 .19384 L
s
% Start of user PostScript
25. 12. 24.9945 12.022 MAarrowhead1
% End of user PostScript
.40172 .19351 m
.40172 .19351 L
s
% Start of user PostScript
26. 12. MAarrowzero1
% End of user PostScript
.41682 .19351 m
.41701 .19318 L
s
% Start of user PostScript
27. 12. 27.0125 11.978 MAarrowhead1
% End of user PostScript
.43193 .19351 m
.43193 .19379 L
s
% Start of user PostScript
28. 12. 28. 12.0185 MAarrowhead1
% End of user PostScript
.44703 .19351 m
.44717 .19351 L
s
% Start of user PostScript
29. 12. 29.0091 12. MAarrowhead1
% End of user PostScript
.46214 .19351 m
.46167 .19351 L
s
% Start of user PostScript
30. 12. 29.9686 12. MAarrowhead1
% End of user PostScript
.47725 .19351 m
.47711 .19399 L
s
% Start of user PostScript
31. 12. 30.9909 12.0314 MAarrowhead1
% End of user PostScript
.49235 .19351 m
.49188 .19412 L
s
% Start of user PostScript
32. 12. 31.9686 12.0405 MAarrowhead1
% End of user PostScript
.50746 .19351 m
.50684 .19337 L
s
% Start of user PostScript
33. 12. 32.9595 11.9906 MAarrowhead1
% End of user PostScript
.52256 .19351 m
.52202 .19384 L
s
% Start of user PostScript
34. 12. 33.964 12.022 MAarrowhead1
% End of user PostScript
.53767 .19351 m
.53772 .19351 L
s
% Start of user PostScript
35. 12. 35.0035 12. MAarrowhead1
% End of user PostScript
.55277 .19351 m
.55277 .19385 L
s
% Start of user PostScript
36. 12. 36. 12.0224 MAarrowhead1
% End of user PostScript
.56788 .19351 m
.56754 .19385 L
s
% Start of user PostScript
37. 12. 36.978 12.0224 MAarrowhead1
% End of user PostScript
.58298 .19351 m
.58284 .19441 L
s
% Start of user PostScript
38. 12. 37.9906 12.0595 MAarrowhead1
% End of user PostScript
.59809 .19351 m
.59772 .19432 L
s
% Start of user PostScript
39. 12. 38.9755 12.0533 MAarrowhead1
% End of user PostScript
.61319 .19351 m
.61182 .19271 L
s
% Start of user PostScript
40. 12. 39.9091 11.9467 MAarrowhead1
% End of user PostScript
.6283 .19351 m
.62863 .19575 L
s
% Start of user PostScript
41. 12. 41.022 12.1481 MAarrowhead1
% End of user PostScript
.6434 .19351 m
.6434 .19357 L
s
% Start of user PostScript
42. 12. 42. 12.0039 MAarrowhead1
% End of user PostScript
.65851 .19351 m
.65845 .19447 L
s
% Start of user PostScript
43. 12. 42.9961 12.0632 MAarrowhead1
% End of user PostScript
.67361 .19351 m
.67259 .19462 L
s
% Start of user PostScript
44. 12. 43.9322 12.0733 MAarrowhead1
% End of user PostScript
.68872 .19351 m
.68847 .19239 L
s
% Start of user PostScript
45. 12. 44.9835 11.9257 MAarrowhead1
% End of user PostScript
.70382 .19351 m
.70564 .19346 L
s
% Start of user PostScript
46. 12. 46.12 11.9965 MAarrowhead1
% End of user PostScript
.71893 .19351 m
.71985 .19351 L
s
% Start of user PostScript
47. 12. 47.0609 12. MAarrowhead1
% End of user PostScript
.73403 .19351 m
.73397 .192 L
s
% Start of user PostScript
48. 12. 47.9961 11.9 MAarrowhead1
% End of user PostScript
.74914 .19351 m
.74872 .19218 L
s
% Start of user PostScript
49. 12. 48.9723 11.9118 MAarrowhead1
% End of user PostScript
.76424 .19351 m
.76361 .19385 L
s
% Start of user PostScript
50. 12. 49.958 12.0224 MAarrowhead1
% End of user PostScript
.77935 .19351 m
.77984 .1917 L
s
% Start of user PostScript
51. 12. 51.0325 11.88 MAarrowhead1
% End of user PostScript
.79445 .19351 m
.7944 .19299 L
s
% Start of user PostScript
52. 12. 51.9965 11.9652 MAarrowhead1
% End of user PostScript
.80956 .19351 m
.80894 .19351 L
s
% Start of user PostScript
53. 12. 52.9592 12. MAarrowhead1
% End of user PostScript
.82466 .19351 m
.82466 .19351 L
s
% Start of user PostScript
54. 12. MAarrowzero1
% End of user PostScript
.83977 .19351 m
.83931 .1923 L
s
% Start of user PostScript
55. 12. 54.9698 11.9196 MAarrowhead1
% End of user PostScript
.85488 .19351 m
.85493 .19178 L
s
% Start of user PostScript
56. 12. 56.0039 11.8855 MAarrowhead1
% End of user PostScript
.86998 .19351 m
.86998 .19222 L
s
% Start of user PostScript
57. 12. 57. 11.9146 MAarrowhead1
% End of user PostScript
.88509 .19351 m
.88419 .19276 L
s
% Start of user PostScript
58. 12. 57.9405 11.9503 MAarrowhead1
% End of user PostScript
.90019 .19351 m
.90047 .19351 L
s
% Start of user PostScript
59. 12. 59.0185 12. MAarrowhead1
% End of user PostScript
.9153 .19351 m
.91477 .19337 L
s
% Start of user PostScript
60. 12. 59.9652 11.9906 MAarrowhead1
% End of user PostScript
.9304 .19351 m
.93015 .19351 L
s
% Start of user PostScript
61. 12. 60.9837 12. MAarrowhead1
% End of user PostScript
.94551 .19351 m
.94551 .19379 L
s
% Start of user PostScript
62. 12. 62. 12.0185 MAarrowhead1
% End of user PostScript
.96061 .19351 m
.96089 .19309 L
s
% Start of user PostScript
63. 12. 63.0185 11.9721 MAarrowhead1
% End of user PostScript
.97572 .19351 m
.97572 .19309 L
s
% Start of user PostScript
64. 12. 64. 11.9721 MAarrowhead1
% End of user PostScript
.02409 .20862 m
.02409 .20862 L
s
% Start of user PostScript
1. 13. MAarrowzero1
% End of user PostScript
.03919 .20862 m
.03919 .20834 L
s
% Start of user PostScript
2. 13. 2. 12.9815 MAarrowhead1
% End of user PostScript
.0543 .20862 m
.05402 .20862 L
s
% Start of user PostScript
3. 13. 2.98149 13. MAarrowhead1
% End of user PostScript
.0694 .20862 m
.06968 .20862 L
s
% Start of user PostScript
4. 13. 4.01851 13. MAarrowhead1
% End of user PostScript
.08451 .20862 m
.08451 .20862 L
s
% Start of user PostScript
5. 13. MAarrowzero1
% End of user PostScript
.09962 .20862 m
.09962 .20862 L
s
% Start of user PostScript
6. 13. MAarrowzero1
% End of user PostScript
.11472 .20862 m
.11472 .20862 L
s
% Start of user PostScript
7. 13. MAarrowzero1
% End of user PostScript
.12983 .20862 m
.13011 .20862 L
s
% Start of user PostScript
8. 13. 8.01851 13. MAarrowhead1
% End of user PostScript
.14493 .20862 m
.14521 .20862 L
s
% Start of user PostScript
9. 13. 9.01851 13. MAarrowhead1
% End of user PostScript
.16004 .20862 m
.16004 .20834 L
s
% Start of user PostScript
10. 13. 10. 12.9815 MAarrowhead1
% End of user PostScript
.17514 .20862 m
.17542 .2089 L
s
% Start of user PostScript
11. 13. 11.0185 13.0185 MAarrowhead1
% End of user PostScript
.19025 .20862 m
.19053 .2089 L
s
% Start of user PostScript
12. 13. 12.0185 13.0185 MAarrowhead1
% End of user PostScript
.20535 .20862 m
.20535 .20834 L
s
% Start of user PostScript
13. 13. 13. 12.9815 MAarrowhead1
% End of user PostScript
.22046 .20862 m
.22035 .20876 L
s
% Start of user PostScript
14. 13. 13.9931 13.0094 MAarrowhead1
% End of user PostScript
.23556 .20862 m
.23598 .20823 L
s
% Start of user PostScript
15. 13. 15.0279 12.9746 MAarrowhead1
% End of user PostScript
.25067 .20862 m
.25156 .2106 L
s
% Start of user PostScript
16. 13. 16.0591 13.1312 MAarrowhead1
% End of user PostScript
.26577 .20862 m
.26625 .20937 L
s
% Start of user PostScript
17. 13. 17.0314 13.0501 MAarrowhead1
% End of user PostScript
.28088 .20862 m
.28206 .20962 L
s
% Start of user PostScript
18. 13. 18.078 13.0662 MAarrowhead1
% End of user PostScript
.29598 .20862 m
.29604 .20862 L
s
% Start of user PostScript
19. 13. 19.0039 13. MAarrowhead1
% End of user PostScript
.31109 .20862 m
.31067 .20811 L
s
% Start of user PostScript
20. 13. 19.9721 12.9663 MAarrowhead1
% End of user PostScript
.32619 .20862 m
.32619 .21093 L
s
% Start of user PostScript
21. 13. 21. 13.1535 MAarrowhead1
% End of user PostScript
.3413 .20862 m
.34082 .20828 L
s
% Start of user PostScript
22. 13. 21.9686 12.9776 MAarrowhead1
% End of user PostScript
.3564 .20862 m
.34791 .20019 L
s
% Start of user PostScript
23. 13. 22.438 12.4419 MAarrowhead1
% End of user PostScript
.37151 .20862 m
.37151 .20834 L
s
% Start of user PostScript
24. 13. 24. 12.9815 MAarrowhead1
% End of user PostScript
.38661 .20862 m
.38661 .20785 L
s
% Start of user PostScript
25. 13. 25. 12.9489 MAarrowhead1
% End of user PostScript
.40172 .20862 m
.40125 .20862 L
s
% Start of user PostScript
26. 13. 25.9686 13. MAarrowhead1
% End of user PostScript
.41682 .20862 m
.41744 .20862 L
s
% Start of user PostScript
27. 13. 27.0405 13. MAarrowhead1
% End of user PostScript
.43193 .20862 m
.43207 .20909 L
s
% Start of user PostScript
28. 13. 28.0094 13.0314 MAarrowhead1
% End of user PostScript
.44703 .20862 m
.44682 .20862 L
s
% Start of user PostScript
29. 13. 28.986 13. MAarrowhead1
% End of user PostScript
.46214 .20862 m
.46214 .20911 L
s
% Start of user PostScript
30. 13. 30. 13.0325 MAarrowhead1
% End of user PostScript
.47725 .20862 m
.47703 .20911 L
s
% Start of user PostScript
31. 13. 30.986 13.0325 MAarrowhead1
% End of user PostScript
.49235 .20862 m
.49235 .2089 L
s
% Start of user PostScript
32. 13. 32. 13.0185 MAarrowhead1
% End of user PostScript
.50746 .20862 m
.50746 .20911 L
s
% Start of user PostScript
33. 13. 33. 13.0325 MAarrowhead1
% End of user PostScript
.52256 .20862 m
.52289 .20883 L
s
% Start of user PostScript
34. 13. 34.022 13.014 MAarrowhead1
% End of user PostScript
.53767 .20862 m
.53761 .20899 L
s
% Start of user PostScript
35. 13. 34.9961 13.0247 MAarrowhead1
% End of user PostScript
.55277 .20862 m
.55231 .20868 L
s
% Start of user PostScript
36. 13. 35.9698 13.0039 MAarrowhead1
% End of user PostScript
.56788 .20862 m
.56793 .20907 L
s
% Start of user PostScript
37. 13. 37.0035 13.0302 MAarrowhead1
% End of user PostScript
.58298 .20862 m
.58346 .20909 L
s
% Start of user PostScript
38. 13. 38.0314 13.0314 MAarrowhead1
% End of user PostScript
.59809 .20862 m
.59803 .20823 L
s
% Start of user PostScript
39. 13. 38.9961 12.9742 MAarrowhead1
% End of user PostScript
.61319 .20862 m
.61333 .21057 L
s
% Start of user PostScript
40. 13. 40.0094 13.1294 MAarrowhead1
% End of user PostScript
.6283 .20862 m
.6283 .209 L
s
% Start of user PostScript
41. 13. 41. 13.0254 MAarrowhead1
% End of user PostScript
.6434 .20862 m
.64293 .20967 L
s
% Start of user PostScript
42. 13. 41.9686 13.0699 MAarrowhead1
% End of user PostScript
.65851 .20862 m
.65808 .20972 L
s
% Start of user PostScript
43. 13. 42.9718 13.0733 MAarrowhead1
% End of user PostScript
.67361 .20862 m
.67328 .21057 L
s
% Start of user PostScript
44. 13. 43.978 13.1294 MAarrowhead1
% End of user PostScript
.68872 .20862 m
.68808 .20842 L
s
% Start of user PostScript
45. 13. 44.9576 12.9867 MAarrowhead1
% End of user PostScript
.70382 .20862 m
.70382 .20778 L
s
% Start of user PostScript
46. 13. 46. 12.9444 MAarrowhead1
% End of user PostScript
.71893 .20862 m
.72035 .2078 L
s
% Start of user PostScript
47. 13. 47.0942 12.9462 MAarrowhead1
% End of user PostScript
.73403 .20862 m
.73423 .20862 L
s
% Start of user PostScript
48. 13. 48.0131 13. MAarrowhead1
% End of user PostScript
.74914 .20862 m
.74796 .2092 L
s
% Start of user PostScript
49. 13. 48.922 13.0385 MAarrowhead1
% End of user PostScript
.76424 .20862 m
.76408 .20695 L
s
% Start of user PostScript
50. 13. 49.9894 12.8894 MAarrowhead1
% End of user PostScript
.77935 .20862 m
.77736 .20758 L
s
% Start of user PostScript
51. 13. 50.8682 12.9311 MAarrowhead1
% End of user PostScript
.79445 .20862 m
.79445 .20927 L
s
% Start of user PostScript
52. 13. 52. 13.0432 MAarrowhead1
% End of user PostScript
.80956 .20862 m
.80942 .20739 L
s
% Start of user PostScript
53. 13. 52.9906 12.9185 MAarrowhead1
% End of user PostScript
.82466 .20862 m
.82609 .20932 L
s
% Start of user PostScript
54. 13. 54.0944 13.0467 MAarrowhead1
% End of user PostScript
.83977 .20862 m
.83895 .20695 L
s
% Start of user PostScript
55. 13. 54.9455 12.8894 MAarrowhead1
% End of user PostScript
.85488 .20862 m
.8544 .20733 L
s
% Start of user PostScript
56. 13. 55.9684 12.9146 MAarrowhead1
% End of user PostScript
.86998 .20862 m
.8697 .20787 L
s
% Start of user PostScript
57. 13. 56.9817 12.9503 MAarrowhead1
% End of user PostScript
.88509 .20862 m
.88458 .2091 L
s
% Start of user PostScript
58. 13. 57.9663 13.0318 MAarrowhead1
% End of user PostScript
.90019 .20862 m
.90053 .20837 L
s
% Start of user PostScript
59. 13. 59.0224 12.9837 MAarrowhead1
% End of user PostScript
.9153 .20862 m
.9154 .20851 L
s
% Start of user PostScript
60. 13. 60.0069 12.9931 MAarrowhead1
% End of user PostScript
.9304 .20862 m
.9304 .2089 L
s
% Start of user PostScript
61. 13. 61. 13.0185 MAarrowhead1
% End of user PostScript
.94551 .20862 m
.94579 .20862 L
s
% Start of user PostScript
62. 13. 62.0185 13. MAarrowhead1
% End of user PostScript
.96061 .20862 m
.96089 .20847 L
s
% Start of user PostScript
63. 13. 63.0185 12.9906 MAarrowhead1
% End of user PostScript
.97572 .20862 m
.97572 .2082 L
s
% Start of user PostScript
64. 13. 64. 12.9721 MAarrowhead1
% End of user PostScript
.02409 .22372 m
.02409 .22372 L
s
% Start of user PostScript
1. 14. MAarrowzero1
% End of user PostScript
.03919 .22372 m
.03891 .224 L
s
% Start of user PostScript
2. 14. 1.98149 14.0185 MAarrowhead1
% End of user PostScript
.0543 .22372 m
.05458 .224 L
s
% Start of user PostScript
3. 14. 3.01851 14.0185 MAarrowhead1
% End of user PostScript
.0694 .22372 m
.06913 .22344 L
s
% Start of user PostScript
4. 14. 3.98149 13.9815 MAarrowhead1
% End of user PostScript
.08451 .22372 m
.08493 .22344 L
s
% Start of user PostScript
5. 14. 5.02792 13.9815 MAarrowhead1
% End of user PostScript
.09962 .22372 m
.09934 .22414 L
s
% Start of user PostScript
6. 14. 5.98149 14.0279 MAarrowhead1
% End of user PostScript
.11472 .22372 m
.11472 .22372 L
s
% Start of user PostScript
7. 14. MAarrowzero1
% End of user PostScript
.12983 .22372 m
.12955 .22344 L
s
% Start of user PostScript
8. 14. 7.98149 13.9815 MAarrowhead1
% End of user PostScript
.14493 .22372 m
.14493 .224 L
s
% Start of user PostScript
9. 14. 9. 14.0185 MAarrowhead1
% End of user PostScript
.16004 .22372 m
.15976 .22411 L
s
% Start of user PostScript
10. 14. 9.98149 14.0254 MAarrowhead1
% End of user PostScript
.17514 .22372 m
.17472 .22344 L
s
% Start of user PostScript
11. 14. 10.9721 13.9815 MAarrowhead1
% End of user PostScript
.19025 .22372 m
.19025 .224 L
s
% Start of user PostScript
12. 14. 12. 14.0185 MAarrowhead1
% End of user PostScript
.20535 .22372 m
.20563 .2232 L
s
% Start of user PostScript
13. 14. 13.0185 13.9652 MAarrowhead1
% End of user PostScript
.22046 .22372 m
.22018 .2232 L
s
% Start of user PostScript
14. 14. 13.9815 13.9652 MAarrowhead1
% End of user PostScript
.23556 .22372 m
.23542 .22383 L
s
% Start of user PostScript
15. 14. 14.9906 14.0069 MAarrowhead1
% End of user PostScript
.25067 .22372 m
.25287 .22721 L
s
% Start of user PostScript
16. 14. 16.1458 14.2308 MAarrowhead1
% End of user PostScript
.26577 .22372 m
.26672 .22501 L
s
% Start of user PostScript
17. 14. 17.0627 14.0851 MAarrowhead1
% End of user PostScript
.28088 .22372 m
.28238 .2252 L
s
% Start of user PostScript
18. 14. 18.0992 14.0976 MAarrowhead1
% End of user PostScript
.29598 .22372 m
.29761 .22495 L
s
% Start of user PostScript
19. 14. 19.1075 14.0815 MAarrowhead1
% End of user PostScript
.31109 .22372 m
.31109 .2228 L
s
% Start of user PostScript
20. 14. 20. 13.9387 MAarrowhead1
% End of user PostScript
.32619 .22372 m
.32758 .22587 L
s
% Start of user PostScript
21. 14. 21.0918 14.1424 MAarrowhead1
% End of user PostScript
.3413 .22372 m
.33989 .22406 L
s
% Start of user PostScript
22. 14. 21.9066 14.0224 MAarrowhead1
% End of user PostScript
.3564 .22372 m
.34873 .21577 L
s
% Start of user PostScript
23. 14. 22.4918 13.4733 MAarrowhead1
% End of user PostScript
.37151 .22372 m
.37074 .22328 L
s
% Start of user PostScript
24. 14. 23.9489 13.9709 MAarrowhead1
% End of user PostScript
.38661 .22372 m
.38584 .22372 L
s
% Start of user PostScript
25. 14. 24.9489 14. MAarrowhead1
% End of user PostScript
.40172 .22372 m
.40205 .22405 L
s
% Start of user PostScript
26. 14. 26.022 14.022 MAarrowhead1
% End of user PostScript
.41682 .22372 m
.41682 .22433 L
s
% Start of user PostScript
27. 14. 27. 14.0405 MAarrowhead1
% End of user PostScript
.43193 .22372 m
.43144 .22393 L
s
% Start of user PostScript
28. 14. 27.9675 14.014 MAarrowhead1
% End of user PostScript
.44703 .22372 m
.44698 .22437 L
s
% Start of user PostScript
29. 14. 28.9961 14.0432 MAarrowhead1
% End of user PostScript
.46214 .22372 m
.46208 .2241 L
s
% Start of user PostScript
30. 14. 29.9961 14.0247 MAarrowhead1
% End of user PostScript
.47725 .22372 m
.47725 .22372 L
s
% Start of user PostScript
31. 14. MAarrowzero1
% End of user PostScript
.49235 .22372 m
.49168 .2247 L
s
% Start of user PostScript
32. 14. 31.9558 14.0651 MAarrowhead1
% End of user PostScript
.50746 .22372 m
.50641 .22392 L
s
% Start of user PostScript
33. 14. 32.9311 14.0129 MAarrowhead1
% End of user PostScript
.52256 .22372 m
.52205 .22404 L
s
% Start of user PostScript
34. 14. 33.9663 14.0208 MAarrowhead1
% End of user PostScript
.53767 .22372 m
.53752 .22372 L
s
% Start of user PostScript
35. 14. 34.9906 14. MAarrowhead1
% End of user PostScript
.55277 .22372 m
.5523 .2242 L
s
% Start of user PostScript
36. 14. 35.9686 14.0314 MAarrowhead1
% End of user PostScript
.56788 .22372 m
.5674 .22453 L
s
% Start of user PostScript
37. 14. 36.9686 14.0533 MAarrowhead1
% End of user PostScript
.58298 .22372 m
.58298 .22414 L
s
% Start of user PostScript
38. 14. 38. 14.0279 MAarrowhead1
% End of user PostScript
.59809 .22372 m
.59745 .22472 L
s
% Start of user PostScript
39. 14. 38.958 14.0662 MAarrowhead1
% End of user PostScript
.61319 .22372 m
.61272 .22526 L
s
% Start of user PostScript
40. 14. 39.9686 14.1015 MAarrowhead1
% End of user PostScript
.6283 .22372 m
.62794 .224 L
s
% Start of user PostScript
41. 14. 40.9761 14.0185 MAarrowhead1
% End of user PostScript
.6434 .22372 m
.64413 .22344 L
s
% Start of user PostScript
42. 14. 42.0479 13.9815 MAarrowhead1
% End of user PostScript
.65851 .22372 m
.65812 .22436 L
s
% Start of user PostScript
43. 14. 42.9742 14.0424 MAarrowhead1
% End of user PostScript
.67361 .22372 m
.67412 .22296 L
s
% Start of user PostScript
44. 14. 44.0337 13.9498 MAarrowhead1
% End of user PostScript
.68872 .22372 m
.68872 .22294 L
s
% Start of user PostScript
45. 14. 45. 13.9482 MAarrowhead1
% End of user PostScript
.70382 .22372 m
.70293 .22283 L
s
% Start of user PostScript
46. 14. 45.9409 13.9409 MAarrowhead1
% End of user PostScript
.71893 .22372 m
.72025 .22244 L
s
% Start of user PostScript
47. 14. 47.0875 13.9149 MAarrowhead1
% End of user PostScript
.73403 .22372 m
.73599 .22338 L
s
% Start of user PostScript
48. 14. 48.1294 13.9776 MAarrowhead1
% End of user PostScript
.74914 .22372 m
.74861 .22425 L
s
% Start of user PostScript
49. 14. 48.9647 14.0353 MAarrowhead1
% End of user PostScript
.76424 .22372 m
.76324 .22205 L
s
% Start of user PostScript
50. 14. 49.9338 13.8894 MAarrowhead1
% End of user PostScript
.77935 .22372 m
.77801 .22372 L
s
% Start of user PostScript
51. 14. 50.9114 14. MAarrowhead1
% End of user PostScript
.79445 .22372 m
.7944 .22302 L
s
% Start of user PostScript
52. 14. 51.9965 13.9533 MAarrowhead1
% End of user PostScript
.80956 .22372 m
.80956 .22501 L
s
% Start of user PostScript
53. 14. 53. 14.0849 MAarrowhead1
% End of user PostScript
.82466 .22372 m
.82414 .22377 L
s
% Start of user PostScript
54. 14. 53.9652 14.0035 MAarrowhead1
% End of user PostScript
.83977 .22372 m
.83972 .22242 L
s
% Start of user PostScript
55. 14. 54.9965 13.9139 MAarrowhead1
% End of user PostScript
.85488 .22372 m
.85373 .22267 L
s
% Start of user PostScript
56. 14. 55.9243 13.9302 MAarrowhead1
% End of user PostScript
.86998 .22372 m
.86998 .22363 L
s
% Start of user PostScript
57. 14. 57. 13.994 MAarrowhead1
% End of user PostScript
.88509 .22372 m
.88509 .2242 L
s
% Start of user PostScript
58. 14. 58. 14.0318 MAarrowhead1
% End of user PostScript
.90019 .22372 m
.90047 .22314 L
s
% Start of user PostScript
59. 14. 59.0185 13.9613 MAarrowhead1
% End of user PostScript
.9153 .22372 m
.91558 .22372 L
s
% Start of user PostScript
60. 14. 60.0185 14. MAarrowhead1
% End of user PostScript
.9304 .22372 m
.9304 .22372 L
s
% Start of user PostScript
61. 14. MAarrowzero1
% End of user PostScript
.94551 .22372 m
.94523 .22372 L
s
% Start of user PostScript
62. 14. 61.9815 14. MAarrowhead1
% End of user PostScript
.96061 .22372 m
.96089 .22372 L
s
% Start of user PostScript
63. 14. 63.0185 14. MAarrowhead1
% End of user PostScript
.97572 .22372 m
.97529 .22372 L
s
% Start of user PostScript
64. 14. 63.9721 14. MAarrowhead1
% End of user PostScript
.02409 .23883 m
.02437 .23855 L
s
% Start of user PostScript
1. 15. 1.01851 14.9815 MAarrowhead1
% End of user PostScript
.03919 .23883 m
.03919 .23883 L
s
% Start of user PostScript
2. 15. MAarrowzero1
% End of user PostScript
.0543 .23883 m
.05458 .23883 L
s
% Start of user PostScript
3. 15. 3.01851 15. MAarrowhead1
% End of user PostScript
.0694 .23883 m
.06983 .23844 L
s
% Start of user PostScript
4. 15. 4.02792 14.9746 MAarrowhead1
% End of user PostScript
.08451 .23883 m
.08479 .23841 L
s
% Start of user PostScript
5. 15. 5.01851 14.9721 MAarrowhead1
% End of user PostScript
.09962 .23883 m
.09962 .23883 L
s
% Start of user PostScript
6. 15. MAarrowzero1
% End of user PostScript
.11472 .23883 m
.11514 .23883 L
s
% Start of user PostScript
7. 15. 7.02792 15. MAarrowhead1
% End of user PostScript
.12983 .23883 m
.12972 .23911 L
s
% Start of user PostScript
8. 15. 7.9931 15.0185 MAarrowhead1
% End of user PostScript
.14493 .23883 m
.14521 .23921 L
s
% Start of user PostScript
9. 15. 9.01851 15.0254 MAarrowhead1
% End of user PostScript
.16004 .23883 m
.16042 .23911 L
s
% Start of user PostScript
10. 15. 10.0254 15.0185 MAarrowhead1
% End of user PostScript
.17514 .23883 m
.17514 .23911 L
s
% Start of user PostScript
11. 15. 11. 15.0185 MAarrowhead1
% End of user PostScript
.19025 .23883 m
.19025 .23911 L
s
% Start of user PostScript
12. 15. 12. 15.0185 MAarrowhead1
% End of user PostScript
.20535 .23883 m
.20525 .23911 L
s
% Start of user PostScript
13. 15. 12.9931 15.0185 MAarrowhead1
% End of user PostScript
.22046 .23883 m
.22074 .23893 L
s
% Start of user PostScript
14. 15. 14.0185 15.0069 MAarrowhead1
% End of user PostScript
.23556 .23883 m
.23567 .23982 L
s
% Start of user PostScript
15. 15. 15.0069 15.0655 MAarrowhead1
% End of user PostScript
.25067 .23883 m
.25116 .2399 L
s
% Start of user PostScript
16. 15. 16.0327 15.0713 MAarrowhead1
% End of user PostScript
.26577 .23883 m
.26577 .24011 L
s
% Start of user PostScript
17. 15. 17. 15.0852 MAarrowhead1
% End of user PostScript
.28088 .23883 m
.28152 .23955 L
s
% Start of user PostScript
18. 15. 18.0424 15.0479 MAarrowhead1
% End of user PostScript
.29598 .23883 m
.29598 .23973 L
s
% Start of user PostScript
19. 15. 19. 15.0595 MAarrowhead1
% End of user PostScript
.31109 .23883 m
.31235 .24067 L
s
% Start of user PostScript
20. 15. 20.0836 15.1221 MAarrowhead1
% End of user PostScript
.32619 .23883 m
.32748 .23992 L
s
% Start of user PostScript
21. 15. 21.0853 15.0726 MAarrowhead1
% End of user PostScript
.3413 .23883 m
.34164 .23777 L
s
% Start of user PostScript
22. 15. 22.0224 14.9297 MAarrowhead1
% End of user PostScript
.3564 .23883 m
.34901 .23164 L
s
% Start of user PostScript
23. 15. 22.5106 14.5243 MAarrowhead1
% End of user PostScript
.37151 .23883 m
.37107 .23888 L
s
% Start of user PostScript
24. 15. 23.9709 15.0035 MAarrowhead1
% End of user PostScript
.38661 .23883 m
.38612 .23921 L
s
% Start of user PostScript
25. 15. 24.9675 15.0254 MAarrowhead1
% End of user PostScript
.40172 .23883 m
.40156 .23932 L
s
% Start of user PostScript
26. 15. 25.9894 15.0325 MAarrowhead1
% End of user PostScript
.41682 .23883 m
.41721 .23883 L
s
% Start of user PostScript
27. 15. 27.0258 15. MAarrowhead1
% End of user PostScript
.43193 .23883 m
.43199 .23928 L
s
% Start of user PostScript
28. 15. 28.0039 15.0302 MAarrowhead1
% End of user PostScript
.44703 .23883 m
.44703 .23919 L
s
% Start of user PostScript
29. 15. 29. 15.0243 MAarrowhead1
% End of user PostScript
.46214 .23883 m
.46167 .23935 L
s
% Start of user PostScript
30. 15. 29.9686 15.0348 MAarrowhead1
% End of user PostScript
.47725 .23883 m
.47677 .24014 L
s
% Start of user PostScript
31. 15. 30.9686 15.0872 MAarrowhead1
% End of user PostScript
.49235 .23883 m
.49202 .23963 L
s
% Start of user PostScript
32. 15. 31.978 15.0533 MAarrowhead1
% End of user PostScript
.50746 .23883 m
.50675 .23883 L
s
% Start of user PostScript
33. 15. 32.9536 15. MAarrowhead1
% End of user PostScript
.52256 .23883 m
.52209 .23953 L
s
% Start of user PostScript
34. 15. 33.9686 15.0464 MAarrowhead1
% End of user PostScript
.53767 .23883 m
.53767 .2393 L
s
% Start of user PostScript
35. 15. 35. 15.0314 MAarrowhead1
% End of user PostScript
.55277 .23883 m
.55277 .23958 L
s
% Start of user PostScript
36. 15. 36. 15.0499 MAarrowhead1
% End of user PostScript
.56788 .23883 m
.56782 .23883 L
s
% Start of user PostScript
37. 15. 36.9961 15. MAarrowhead1
% End of user PostScript
.58298 .23883 m
.5836 .23983 L
s
% Start of user PostScript
38. 15. 38.0408 15.0662 MAarrowhead1
% End of user PostScript
.59809 .23883 m
.59984 .2403 L
s
% Start of user PostScript
39. 15. 39.1161 15.0976 MAarrowhead1
% End of user PostScript
.61319 .23883 m
.61244 .23844 L
s
% Start of user PostScript
40. 15. 39.9501 14.9742 MAarrowhead1
% End of user PostScript
.6283 .23883 m
.62869 .23947 L
s
% Start of user PostScript
41. 15. 41.0258 15.0424 MAarrowhead1
% End of user PostScript
.6434 .23883 m
.64225 .2412 L
s
% Start of user PostScript
42. 15. 41.9239 15.1573 MAarrowhead1
% End of user PostScript
.65851 .23883 m
.65851 .24024 L
s
% Start of user PostScript
43. 15. 43. 15.0934 MAarrowhead1
% End of user PostScript
.67361 .23883 m
.67347 .23592 L
s
% Start of user PostScript
44. 15. 43.9906 14.8076 MAarrowhead1
% End of user PostScript
.68872 .23883 m
.68747 .23883 L
s
% Start of user PostScript
45. 15. 44.9171 15. MAarrowhead1
% End of user PostScript
.70382 .23883 m
.70249 .23878 L
s
% Start of user PostScript
46. 15. 45.9118 14.9965 MAarrowhead1
% End of user PostScript
.71893 .23883 m
.7184 .23784 L
s
% Start of user PostScript
47. 15. 46.9652 14.9349 MAarrowhead1
% End of user PostScript
.73403 .23883 m
.73338 .23751 L
s
% Start of user PostScript
48. 15. 47.9568 14.9125 MAarrowhead1
% End of user PostScript
.74914 .23883 m
.75032 .23883 L
s
% Start of user PostScript
49. 15. 49.078 15. MAarrowhead1
% End of user PostScript
.76424 .23883 m
.765 .23865 L
s
% Start of user PostScript
50. 15. 50.0503 14.9882 MAarrowhead1
% End of user PostScript
.77935 .23883 m
.78016 .23897 L
s
% Start of user PostScript
51. 15. 51.0538 15.0094 MAarrowhead1
% End of user PostScript
.79445 .23883 m
.7944 .24006 L
s
% Start of user PostScript
52. 15. 51.9965 15.0815 MAarrowhead1
% End of user PostScript
.80956 .23883 m
.80961 .23964 L
s
% Start of user PostScript
53. 15. 53.0035 15.0538 MAarrowhead1
% End of user PostScript
.82466 .23883 m
.82433 .23751 L
s
% Start of user PostScript
54. 15. 53.9776 14.9125 MAarrowhead1
% End of user PostScript
.83977 .23883 m
.83977 .23749 L
s
% Start of user PostScript
55. 15. 55. 14.9112 MAarrowhead1
% End of user PostScript
.85488 .23883 m
.85497 .23925 L
s
% Start of user PostScript
56. 15. 56.006 15.0277 MAarrowhead1
% End of user PostScript
.86998 .23883 m
.86947 .23849 L
s
% Start of user PostScript
57. 15. 56.9663 14.9776 MAarrowhead1
% End of user PostScript
.88509 .23883 m
.88512 .23841 L
s
% Start of user PostScript
58. 15. 58.0025 14.9721 MAarrowhead1
% End of user PostScript
.90019 .23883 m
.90072 .23911 L
s
% Start of user PostScript
59. 15. 59.0348 15.0185 MAarrowhead1
% End of user PostScript
.9153 .23883 m
.91502 .23844 L
s
% Start of user PostScript
60. 15. 59.9815 14.9746 MAarrowhead1
% End of user PostScript
.9304 .23883 m
.93068 .23883 L
s
% Start of user PostScript
61. 15. 61.0185 15. MAarrowhead1
% End of user PostScript
.94551 .23883 m
.94508 .23883 L
s
% Start of user PostScript
62. 15. 61.9721 15. MAarrowhead1
% End of user PostScript
.96061 .23883 m
.96061 .23883 L
s
% Start of user PostScript
63. 15. MAarrowzero1
% End of user PostScript
.97572 .23883 m
.97544 .23883 L
s
% Start of user PostScript
64. 15. 63.9815 15. MAarrowhead1
% End of user PostScript
.02409 .25393 m
.02381 .25421 L
s
% Start of user PostScript
1. 16. 0.98149 16.0185 MAarrowhead1
% End of user PostScript
.03919 .25393 m
.03947 .25393 L
s
% Start of user PostScript
2. 16. 2.01851 16. MAarrowhead1
% End of user PostScript
.0543 .25393 m
.05405 .25446 L
s
% Start of user PostScript
3. 16. 2.98369 16.0348 MAarrowhead1
% End of user PostScript
.0694 .25393 m
.06983 .25393 L
s
% Start of user PostScript
4. 16. 4.02792 16. MAarrowhead1
% End of user PostScript
.08451 .25393 m
.08479 .25365 L
s
% Start of user PostScript
5. 16. 5.01851 15.9815 MAarrowhead1
% End of user PostScript
.09962 .25393 m
.09962 .25421 L
s
% Start of user PostScript
6. 16. 6. 16.0185 MAarrowhead1
% End of user PostScript
.11472 .25393 m
.11472 .25393 L
s
% Start of user PostScript
7. 16. MAarrowzero1
% End of user PostScript
.12983 .25393 m
.1294 .25393 L
s
% Start of user PostScript
8. 16. 7.97208 16. MAarrowhead1
% End of user PostScript
.14493 .25393 m
.14507 .25393 L
s
% Start of user PostScript
9. 16. 9.00941 16. MAarrowhead1
% End of user PostScript
.16004 .25393 m
.15993 .25383 L
s
% Start of user PostScript
10. 16. 9.9931 15.9931 MAarrowhead1
% End of user PostScript
.17514 .25393 m
.17476 .25351 L
s
% Start of user PostScript
11. 16. 10.9746 15.9721 MAarrowhead1
% End of user PostScript
.19025 .25393 m
.19053 .25421 L
s
% Start of user PostScript
12. 16. 12.0185 16.0185 MAarrowhead1
% End of user PostScript
.20535 .25393 m
.20507 .25435 L
s
% Start of user PostScript
13. 16. 12.9815 16.0279 MAarrowhead1
% End of user PostScript
.22046 .25393 m
.22031 .25393 L
s
% Start of user PostScript
14. 16. 13.9906 16. MAarrowhead1
% End of user PostScript
.23556 .25393 m
.23712 .25599 L
s
% Start of user PostScript
15. 16. 15.1035 16.1364 MAarrowhead1
% End of user PostScript
.25067 .25393 m
.25155 .25531 L
s
% Start of user PostScript
16. 16. 16.0582 16.0909 MAarrowhead1
% End of user PostScript
.26577 .25393 m
.26577 .25432 L
s
% Start of user PostScript
17. 16. 17. 16.0254 MAarrowhead1
% End of user PostScript
.28088 .25393 m
.28116 .25432 L
s
% Start of user PostScript
18. 16. 18.0185 16.0258 MAarrowhead1
% End of user PostScript
.29598 .25393 m
.29761 .25486 L
s
% Start of user PostScript
19. 16. 19.1075 16.0613 MAarrowhead1
% End of user PostScript
.31109 .25393 m
.31307 .25731 L
s
% Start of user PostScript
20. 16. 20.1315 16.2238 MAarrowhead1
% End of user PostScript
.32619 .25393 m
.32704 .25393 L
s
% Start of user PostScript
21. 16. 21.0561 16. MAarrowhead1
% End of user PostScript
.3413 .25393 m
.3413 .25427 L
s
% Start of user PostScript
22. 16. 22. 16.0224 MAarrowhead1
% End of user PostScript
.3564 .25393 m
.35098 .24709 L
s
% Start of user PostScript
23. 16. 22.6409 15.5467 MAarrowhead1
% End of user PostScript
.37151 .25393 m
.37271 .25254 L
s
% Start of user PostScript
24. 16. 24.0792 15.9079 MAarrowhead1
% End of user PostScript
.38661 .25393 m
.38779 .25342 L
s
% Start of user PostScript
25. 16. 25.078 15.9663 MAarrowhead1
% End of user PostScript
.40172 .25393 m
.40313 .25281 L
s
% Start of user PostScript
26. 16. 26.0931 15.9254 MAarrowhead1
% End of user PostScript
.41682 .25393 m
.41758 .25346 L
s
% Start of user PostScript
27. 16. 27.0499 15.9686 MAarrowhead1
% End of user PostScript
.43193 .25393 m
.43262 .2536 L
s
% Start of user PostScript
28. 16. 28.0454 15.978 MAarrowhead1
% End of user PostScript
.44703 .25393 m
.44758 .25339 L
s
% Start of user PostScript
29. 16. 29.036 15.964 MAarrowhead1
% End of user PostScript
.46214 .25393 m
.46384 .25342 L
s
% Start of user PostScript
30. 16. 30.1129 15.9659 MAarrowhead1
% End of user PostScript
.47725 .25393 m
.4781 .25425 L
s
% Start of user PostScript
31. 16. 31.0568 16.0208 MAarrowhead1
% End of user PostScript
.49235 .25393 m
.49204 .25404 L
s
% Start of user PostScript
32. 16. 31.9792 16.0069 MAarrowhead1
% End of user PostScript
.50746 .25393 m
.50714 .25425 L
s
% Start of user PostScript
33. 16. 32.9792 16.0208 MAarrowhead1
% End of user PostScript
.52256 .25393 m
.52146 .25455 L
s
% Start of user PostScript
34. 16. 33.9274 16.0408 MAarrowhead1
% End of user PostScript
.53767 .25393 m
.53705 .25441 L
s
% Start of user PostScript
35. 16. 34.9592 16.0318 MAarrowhead1
% End of user PostScript
.55277 .25393 m
.55246 .25455 L
s
% Start of user PostScript
36. 16. 35.9792 16.0408 MAarrowhead1
% End of user PostScript
.56788 .25393 m
.56807 .25432 L
s
% Start of user PostScript
37. 16. 37.0131 16.0254 MAarrowhead1
% End of user PostScript
.58298 .25393 m
.58251 .25418 L
s
% Start of user PostScript
38. 16. 37.9686 16.0163 MAarrowhead1
% End of user PostScript
.59809 .25393 m
.59978 .25731 L
s
% Start of user PostScript
39. 16. 39.1123 16.2236 MAarrowhead1
% End of user PostScript
.61319 .25393 m
.61198 .25237 L
s
% Start of user PostScript
40. 16. 39.9199 15.8964 MAarrowhead1
% End of user PostScript
.6283 .25393 m
.62902 .25631 L
s
% Start of user PostScript
41. 16. 41.0478 16.1573 MAarrowhead1
% End of user PostScript
.6434 .25393 m
.64284 .25453 L
s
% Start of user PostScript
42. 16. 41.9627 16.0396 MAarrowhead1
% End of user PostScript
.65851 .25393 m
.6596 .2541 L
s
% Start of user PostScript
43. 16. 43.0722 16.0114 MAarrowhead1
% End of user PostScript
.67361 .25393 m
.67197 .25217 L
s
% Start of user PostScript
44. 16. 43.8912 15.8835 MAarrowhead1
% End of user PostScript
.68872 .25393 m
.68925 .25446 L
s
% Start of user PostScript
45. 16. 45.0351 16.0351 MAarrowhead1
% End of user PostScript
.70382 .25393 m
.70382 .25446 L
s
% Start of user PostScript
46. 16. 46. 16.0351 MAarrowhead1
% End of user PostScript
.71893 .25393 m
.71806 .25335 L
s
% Start of user PostScript
47. 16. 46.9428 15.9617 MAarrowhead1
% End of user PostScript
.73403 .25393 m
.73535 .25374 L
s
% Start of user PostScript
48. 16. 48.0875 15.9871 MAarrowhead1
% End of user PostScript
.74914 .25393 m
.75113 .25393 L
s
% Start of user PostScript
49. 16. 49.1318 16. MAarrowhead1
% End of user PostScript
.76424 .25393 m
.76458 .25489 L
s
% Start of user PostScript
50. 16. 50.022 16.0632 MAarrowhead1
% End of user PostScript
.77935 .25393 m
.77603 .25212 L
s
% Start of user PostScript
51. 16. 50.78 15.88 MAarrowhead1
% End of user PostScript
.79445 .25393 m
.79569 .25525 L
s
% Start of user PostScript
52. 16. 52.0815 16.0875 MAarrowhead1
% End of user PostScript
.80956 .25393 m
.80961 .25323 L
s
% Start of user PostScript
53. 16. 53.0035 15.9533 MAarrowhead1
% End of user PostScript
.82466 .25393 m
.82466 .25291 L
s
% Start of user PostScript
54. 16. 54. 15.9326 MAarrowhead1
% End of user PostScript
.83977 .25393 m
.83963 .25221 L
s
% Start of user PostScript
55. 16. 54.9906 15.886 MAarrowhead1
% End of user PostScript
.85488 .25393 m
.85538 .25318 L
s
% Start of user PostScript
56. 16. 56.0337 15.9503 MAarrowhead1
% End of user PostScript
.86998 .25393 m
.87026 .25379 L
s
% Start of user PostScript
57. 16. 57.0185 15.9906 MAarrowhead1
% End of user PostScript
.88509 .25393 m
.88481 .25393 L
s
% Start of user PostScript
58. 16. 57.9815 16. MAarrowhead1
% End of user PostScript
.90019 .25393 m
.89991 .25393 L
s
% Start of user PostScript
59. 16. 58.9815 16. MAarrowhead1
% End of user PostScript
.9153 .25393 m
.9153 .25365 L
s
% Start of user PostScript
60. 16. 60. 15.9815 MAarrowhead1
% End of user PostScript
.9304 .25393 m
.9304 .25421 L
s
% Start of user PostScript
61. 16. 61. 16.0185 MAarrowhead1
% End of user PostScript
.94551 .25393 m
.94551 .25393 L
s
% Start of user PostScript
62. 16. MAarrowzero1
% End of user PostScript
.96061 .25393 m
.96061 .25393 L
s
% Start of user PostScript
63. 16. MAarrowzero1
% End of user PostScript
.97572 .25393 m
.97572 .25393 L
s
% Start of user PostScript
64. 16. MAarrowzero1
% End of user PostScript
.02409 .26904 m
.02381 .26932 L
s
% Start of user PostScript
1. 17. 0.98149 17.0185 MAarrowhead1
% End of user PostScript
.03919 .26904 m
.03947 .26914 L
s
% Start of user PostScript
2. 17. 2.01851 17.0069 MAarrowhead1
% End of user PostScript
.0543 .26904 m
.0543 .26932 L
s
% Start of user PostScript
3. 17. 3. 17.0185 MAarrowhead1
% End of user PostScript
.0694 .26904 m
.0693 .26904 L
s
% Start of user PostScript
4. 17. 3.9931 17. MAarrowhead1
% End of user PostScript
.08451 .26904 m
.08409 .26904 L
s
% Start of user PostScript
5. 17. 4.97208 17. MAarrowhead1
% End of user PostScript
.09962 .26904 m
.09962 .26904 L
s
% Start of user PostScript
6. 17. MAarrowzero1
% End of user PostScript
.11472 .26904 m
.11472 .26932 L
s
% Start of user PostScript
7. 17. 7. 17.0185 MAarrowhead1
% End of user PostScript
.12983 .26904 m
.12944 .26876 L
s
% Start of user PostScript
8. 17. 7.97459 16.9815 MAarrowhead1
% End of user PostScript
.14493 .26904 m
.14493 .26932 L
s
% Start of user PostScript
9. 17. 9. 17.0185 MAarrowhead1
% End of user PostScript
.16004 .26904 m
.16004 .26932 L
s
% Start of user PostScript
10. 17. 10. 17.0185 MAarrowhead1
% End of user PostScript
.17514 .26904 m
.17486 .26851 L
s
% Start of user PostScript
11. 17. 10.9815 16.9652 MAarrowhead1
% End of user PostScript
.19025 .26904 m
.18997 .26918 L
s
% Start of user PostScript
12. 17. 11.9815 17.0094 MAarrowhead1
% End of user PostScript
.20535 .26904 m
.20535 .26904 L
s
% Start of user PostScript
13. 17. MAarrowzero1
% End of user PostScript
.22046 .26904 m
.22046 .26904 L
s
% Start of user PostScript
14. 17. MAarrowzero1
% End of user PostScript
.23556 .26904 m
.23689 .2709 L
s
% Start of user PostScript
15. 17. 15.0882 17.1235 MAarrowhead1
% End of user PostScript
.25067 .26904 m
.251 .27015 L
s
% Start of user PostScript
16. 17. 16.022 17.0733 MAarrowhead1
% End of user PostScript
.26577 .26904 m
.26577 .2699 L
s
% Start of user PostScript
17. 17. 17. 17.0568 MAarrowhead1
% End of user PostScript
.28088 .26904 m
.28152 .26853 L
s
% Start of user PostScript
18. 17. 18.0424 16.9663 MAarrowhead1
% End of user PostScript
.29598 .26904 m
.29547 .26853 L
s
% Start of user PostScript
19. 17. 18.9663 16.9663 MAarrowhead1
% End of user PostScript
.31109 .26904 m
.31109 .2698 L
s
% Start of user PostScript
20. 17. 20. 17.0502 MAarrowhead1
% End of user PostScript
.32619 .26904 m
.32661 .26964 L
s
% Start of user PostScript
21. 17. 21.0279 17.0396 MAarrowhead1
% End of user PostScript
.3413 .26904 m
.34164 .26429 L
s
% Start of user PostScript
22. 17. 22.0224 16.6855 MAarrowhead1
% End of user PostScript
.3564 .26904 m
.35646 .26474 L
s
% Start of user PostScript
23. 17. 23.0035 16.7158 MAarrowhead1
% End of user PostScript
.37151 .26904 m
.37151 .26862 L
s
% Start of user PostScript
24. 17. 24. 16.9721 MAarrowhead1
% End of user PostScript
.38661 .26904 m
.38723 .26904 L
s
% Start of user PostScript
25. 17. 25.0405 17. MAarrowhead1
% End of user PostScript
.40172 .26904 m
.40252 .26884 L
s
% Start of user PostScript
26. 17. 26.0533 16.9871 MAarrowhead1
% End of user PostScript
.41682 .26904 m
.4173 .26904 L
s
% Start of user PostScript
27. 17. 27.0314 17. MAarrowhead1
% End of user PostScript
.43193 .26904 m
.43263 .26909 L
s
% Start of user PostScript
28. 17. 28.0467 17.0035 MAarrowhead1
% End of user PostScript
.44703 .26904 m
.44788 .26904 L
s
% Start of user PostScript
29. 17. 29.0561 17. MAarrowhead1
% End of user PostScript
.46214 .26904 m
.46283 .26904 L
s
% Start of user PostScript
30. 17. 30.0454 17. MAarrowhead1
% End of user PostScript
.47725 .26904 m
.47811 .26904 L
s
% Start of user PostScript
31. 17. 31.0573 17. MAarrowhead1
% End of user PostScript
.49235 .26904 m
.49456 .26856 L
s
% Start of user PostScript
32. 17. 32.1465 16.9686 MAarrowhead1
% End of user PostScript
.50746 .26904 m
.50888 .26904 L
s
% Start of user PostScript
33. 17. 33.0946 17. MAarrowhead1
% End of user PostScript
.52256 .26904 m
.52198 .26962 L
s
% Start of user PostScript
34. 17. 33.9615 17.0385 MAarrowhead1
% End of user PostScript
.53767 .26904 m
.53789 .26914 L
s
% Start of user PostScript
35. 17. 35.0151 17.0069 MAarrowhead1
% End of user PostScript
.55277 .26904 m
.55219 .26904 L
s
% Start of user PostScript
36. 17. 35.9615 17. MAarrowhead1
% End of user PostScript
.56788 .26904 m
.56788 .27017 L
s
% Start of user PostScript
37. 17. 37. 17.0753 MAarrowhead1
% End of user PostScript
.58298 .26904 m
.58346 .2707 L
s
% Start of user PostScript
38. 17. 38.0314 17.11 MAarrowhead1
% End of user PostScript
.59809 .26904 m
.59686 .26904 L
s
% Start of user PostScript
39. 17. 38.9187 17. MAarrowhead1
% End of user PostScript
.61319 .26904 m
.61157 .26692 L
s
% Start of user PostScript
40. 17. 39.8925 16.86 MAarrowhead1
% End of user PostScript
.6283 .26904 m
.6283 .27013 L
s
% Start of user PostScript
41. 17. 41. 17.0726 MAarrowhead1
% End of user PostScript
.6434 .26904 m
.64117 .26951 L
s
% Start of user PostScript
42. 17. 41.8521 17.0314 MAarrowhead1
% End of user PostScript
.65851 .26904 m
.66068 .26898 L
s
% Start of user PostScript
43. 17. 43.144 16.9961 MAarrowhead1
% End of user PostScript
.67361 .26904 m
.67199 .26826 L
s
% Start of user PostScript
44. 17. 43.8925 16.9482 MAarrowhead1
% End of user PostScript
.68872 .26904 m
.69053 .27015 L
s
% Start of user PostScript
45. 17. 45.12 17.0738 MAarrowhead1
% End of user PostScript
.70382 .26904 m
.705 .26851 L
s
% Start of user PostScript
46. 17. 46.078 16.9647 MAarrowhead1
% End of user PostScript
.71893 .26904 m
.71851 .26775 L
s
% Start of user PostScript
47. 17. 46.9721 16.9149 MAarrowhead1
% End of user PostScript
.73403 .26904 m
.73398 .26821 L
s
% Start of user PostScript
48. 17. 47.9965 16.9455 MAarrowhead1
% End of user PostScript
.74914 .26904 m
.75092 .26899 L
s
% Start of user PostScript
49. 17. 49.1179 16.9965 MAarrowhead1
% End of user PostScript
.76424 .26904 m
.76391 .26953 L
s
% Start of user PostScript
50. 17. 49.978 17.0325 MAarrowhead1
% End of user PostScript
.77935 .26904 m
.77824 .2684 L
s
% Start of user PostScript
51. 17. 50.9267 16.958 MAarrowhead1
% End of user PostScript
.79445 .26904 m
.79351 .26904 L
s
% Start of user PostScript
52. 17. 51.9373 17. MAarrowhead1
% End of user PostScript
.80956 .26904 m
.80865 .26833 L
s
% Start of user PostScript
53. 17. 52.9395 16.9533 MAarrowhead1
% End of user PostScript
.82466 .26904 m
.82345 .26522 L
s
% Start of user PostScript
54. 17. 53.9196 16.747 MAarrowhead1
% End of user PostScript
.83977 .26904 m
.83977 .27046 L
s
% Start of user PostScript
55. 17. 55. 17.0945 MAarrowhead1
% End of user PostScript
.85488 .26904 m
.85473 .26766 L
s
% Start of user PostScript
56. 17. 55.9906 16.9091 MAarrowhead1
% End of user PostScript
.86998 .26904 m
.8697 .26823 L
s
% Start of user PostScript
57. 17. 56.9815 16.9467 MAarrowhead1
% End of user PostScript
.88509 .26904 m
.88509 .26914 L
s
% Start of user PostScript
58. 17. 58. 17.0069 MAarrowhead1
% End of user PostScript
.90019 .26904 m
.90047 .26862 L
s
% Start of user PostScript
59. 17. 59.0185 16.9721 MAarrowhead1
% End of user PostScript
.9153 .26904 m
.91558 .26862 L
s
% Start of user PostScript
60. 17. 60.0185 16.9721 MAarrowhead1
% End of user PostScript
.9304 .26904 m
.93012 .26904 L
s
% Start of user PostScript
61. 17. 60.9815 17. MAarrowhead1
% End of user PostScript
.94551 .26904 m
.94579 .26904 L
s
% Start of user PostScript
62. 17. 62.0185 17. MAarrowhead1
% End of user PostScript
.96061 .26904 m
.96061 .26904 L
s
% Start of user PostScript
63. 17. MAarrowzero1
% End of user PostScript
.97572 .26904 m
.97544 .26904 L
s
% Start of user PostScript
64. 17. 63.9815 17. MAarrowhead1
% End of user PostScript
.02409 .28414 m
.02409 .28414 L
s
% Start of user PostScript
1. 18. MAarrowzero1
% End of user PostScript
.03919 .28414 m
.03919 .28386 L
s
% Start of user PostScript
2. 18. 2. 17.9815 MAarrowhead1
% End of user PostScript
.0543 .28414 m
.0543 .28456 L
s
% Start of user PostScript
3. 18. 3. 18.0279 MAarrowhead1
% End of user PostScript
.0694 .28414 m
.0694 .28414 L
s
% Start of user PostScript
4. 18. MAarrowzero1
% End of user PostScript
.08451 .28414 m
.08479 .28372 L
s
% Start of user PostScript
5. 18. 5.01851 17.9721 MAarrowhead1
% End of user PostScript
.09962 .28414 m
.09962 .28376 L
s
% Start of user PostScript
6. 18. 6. 17.9746 MAarrowhead1
% End of user PostScript
.11472 .28414 m
.11472 .28456 L
s
% Start of user PostScript
7. 18. 7. 18.0279 MAarrowhead1
% End of user PostScript
.12983 .28414 m
.12983 .28414 L
s
% Start of user PostScript
8. 18. MAarrowzero1
% End of user PostScript
.14493 .28414 m
.14521 .28414 L
s
% Start of user PostScript
9. 18. 9.01851 18. MAarrowhead1
% End of user PostScript
.16004 .28414 m
.16004 .28386 L
s
% Start of user PostScript
10. 18. 10. 17.9815 MAarrowhead1
% End of user PostScript
.17514 .28414 m
.17514 .28386 L
s
% Start of user PostScript
11. 18. 11. 17.9815 MAarrowhead1
% End of user PostScript
.19025 .28414 m
.19025 .28414 L
s
% Start of user PostScript
12. 18. MAarrowzero1
% End of user PostScript
.20535 .28414 m
.20549 .28467 L
s
% Start of user PostScript
13. 18. 13.0094 18.0348 MAarrowhead1
% End of user PostScript
.22046 .28414 m
.22141 .28559 L
s
% Start of user PostScript
14. 18. 14.063 18.096 MAarrowhead1
% End of user PostScript
.23556 .28414 m
.23727 .28696 L
s
% Start of user PostScript
15. 18. 15.1129 18.1867 MAarrowhead1
% End of user PostScript
.25067 .28414 m
.25146 .28543 L
s
% Start of user PostScript
16. 18. 16.0526 18.0852 MAarrowhead1
% End of user PostScript
.26577 .28414 m
.26692 .28462 L
s
% Start of user PostScript
17. 18. 17.0761 18.0314 MAarrowhead1
% End of user PostScript
.28088 .28414 m
.28088 .28465 L
s
% Start of user PostScript
18. 18. 18. 18.0337 MAarrowhead1
% End of user PostScript
.29598 .28414 m
.29688 .28613 L
s
% Start of user PostScript
19. 18. 19.0593 18.1315 MAarrowhead1
% End of user PostScript
.31109 .28414 m
.30982 .28273 L
s
% Start of user PostScript
20. 18. 19.916 17.9066 MAarrowhead1
% End of user PostScript
.32619 .28414 m
.32619 .28094 L
s
% Start of user PostScript
21. 18. 21. 17.7879 MAarrowhead1
% End of user PostScript
.3413 .28414 m
.34116 .28358 L
s
% Start of user PostScript
22. 18. 21.9906 17.9627 MAarrowhead1
% End of user PostScript
.3564 .28414 m
.35593 .28395 L
s
% Start of user PostScript
23. 18. 22.9686 17.9871 MAarrowhead1
% End of user PostScript
.37151 .28414 m
.37118 .28414 L
s
% Start of user PostScript
24. 18. 23.978 18. MAarrowhead1
% End of user PostScript
.38661 .28414 m
.38661 .28406 L
s
% Start of user PostScript
25. 18. 25. 17.9945 MAarrowhead1
% End of user PostScript
.40172 .28414 m
.40233 .28414 L
s
% Start of user PostScript
26. 18. 26.0405 18. MAarrowhead1
% End of user PostScript
.41682 .28414 m
.41744 .28414 L
s
% Start of user PostScript
27. 18. 27.0405 18. MAarrowhead1
% End of user PostScript
.43193 .28414 m
.43212 .28462 L
s
% Start of user PostScript
28. 18. 28.0129 18.0314 MAarrowhead1
% End of user PostScript
.44703 .28414 m
.44709 .28409 L
s
% Start of user PostScript
29. 18. 29.0035 17.9965 MAarrowhead1
% End of user PostScript
.46214 .28414 m
.4622 .28494 L
s
% Start of user PostScript
30. 18. 30.0039 18.0526 MAarrowhead1
% End of user PostScript
.47725 .28414 m
.47807 .2837 L
s
% Start of user PostScript
31. 18. 31.0545 17.9709 MAarrowhead1
% End of user PostScript
.49235 .28414 m
.49284 .28425 L
s
% Start of user PostScript
32. 18. 32.0325 18.0071 MAarrowhead1
% End of user PostScript
.50746 .28414 m
.5085 .28414 L
s
% Start of user PostScript
33. 18. 33.0689 18. MAarrowhead1
% End of user PostScript
.52256 .28414 m
.52415 .2821 L
s
% Start of user PostScript
34. 18. 34.1049 17.8649 MAarrowhead1
% End of user PostScript
.53767 .28414 m
.53691 .28442 L
s
% Start of user PostScript
35. 18. 34.9501 18.0185 MAarrowhead1
% End of user PostScript
.55277 .28414 m
.55252 .28439 L
s
% Start of user PostScript
36. 18. 35.9837 18.0165 MAarrowhead1
% End of user PostScript
.56788 .28414 m
.56788 .28487 L
s
% Start of user PostScript
37. 18. 37. 18.0479 MAarrowhead1
% End of user PostScript
.58298 .28414 m
.58379 .2855 L
s
% Start of user PostScript
38. 18. 38.0536 18.0895 MAarrowhead1
% End of user PostScript
.59809 .28414 m
.59399 .28055 L
s
% Start of user PostScript
39. 18. 38.7285 17.7622 MAarrowhead1
% End of user PostScript
.61319 .28414 m
.61162 .28091 L
s
% Start of user PostScript
40. 18. 39.896 17.7859 MAarrowhead1
% End of user PostScript
.6283 .28414 m
.63191 .28698 L
s
% Start of user PostScript
41. 18. 41.2389 18.1876 MAarrowhead1
% End of user PostScript
.6434 .28414 m
.6434 .28438 L
s
% Start of user PostScript
42. 18. 42. 18.016 MAarrowhead1
% End of user PostScript
.65851 .28414 m
.65681 .28071 L
s
% Start of user PostScript
43. 18. 42.8877 17.7728 MAarrowhead1
% End of user PostScript
.67361 .28414 m
.67494 .28085 L
s
% Start of user PostScript
44. 18. 44.0882 17.7822 MAarrowhead1
% End of user PostScript
.68872 .28414 m
.68969 .28372 L
s
% Start of user PostScript
45. 18. 45.0644 17.9723 MAarrowhead1
% End of user PostScript
.70382 .28414 m
.70235 .2838 L
s
% Start of user PostScript
46. 18. 45.9024 17.9776 MAarrowhead1
% End of user PostScript
.71893 .28414 m
.71835 .28347 L
s
% Start of user PostScript
47. 18. 46.9615 17.9556 MAarrowhead1
% End of user PostScript
.73403 .28414 m
.73231 .28344 L
s
% Start of user PostScript
48. 18. 47.886 17.9533 MAarrowhead1
% End of user PostScript
.74914 .28414 m
.75016 .28425 L
s
% Start of user PostScript
49. 18. 49.0674 18.0073 MAarrowhead1
% End of user PostScript
.76424 .28414 m
.76504 .28548 L
s
% Start of user PostScript
50. 18. 50.0526 18.0886 MAarrowhead1
% End of user PostScript
.77935 .28414 m
.77886 .28474 L
s
% Start of user PostScript
51. 18. 50.9675 18.0395 MAarrowhead1
% End of user PostScript
.79445 .28414 m
.79313 .28233 L
s
% Start of user PostScript
52. 18. 51.9125 17.8798 MAarrowhead1
% End of user PostScript
.80956 .28414 m
.81052 .28384 L
s
% Start of user PostScript
53. 18. 53.0639 17.9801 MAarrowhead1
% End of user PostScript
.82466 .28414 m
.82217 .28367 L
s
% Start of user PostScript
54. 18. 53.8347 17.9684 MAarrowhead1
% End of user PostScript
.83977 .28414 m
.84028 .28282 L
s
% Start of user PostScript
55. 18. 55.0337 17.9125 MAarrowhead1
% End of user PostScript
.85488 .28414 m
.85502 .2839 L
s
% Start of user PostScript
56. 18. 56.0094 17.9837 MAarrowhead1
% End of user PostScript
.86998 .28414 m
.87036 .28442 L
s
% Start of user PostScript
57. 18. 57.0254 18.0185 MAarrowhead1
% End of user PostScript
.88509 .28414 m
.88536 .28442 L
s
% Start of user PostScript
58. 18. 58.0185 18.0185 MAarrowhead1
% End of user PostScript
.90019 .28414 m
.90019 .28442 L
s
% Start of user PostScript
59. 18. 59. 18.0185 MAarrowhead1
% End of user PostScript
.9153 .28414 m
.9153 .28386 L
s
% Start of user PostScript
60. 18. 60. 17.9815 MAarrowhead1
% End of user PostScript
.9304 .28414 m
.93068 .28414 L
s
% Start of user PostScript
61. 18. 61.0185 18. MAarrowhead1
% End of user PostScript
.94551 .28414 m
.94551 .28414 L
s
% Start of user PostScript
62. 18. MAarrowzero1
% End of user PostScript
.96061 .28414 m
.96061 .28414 L
s
% Start of user PostScript
63. 18. MAarrowzero1
% End of user PostScript
.97572 .28414 m
.97572 .28442 L
s
% Start of user PostScript
64. 18. 64. 18.0185 MAarrowhead1
% End of user PostScript
.02409 .29925 m
.02423 .29911 L
s
% Start of user PostScript
1. 19. 1.00941 18.9906 MAarrowhead1
% End of user PostScript
.03919 .29925 m
.03947 .29953 L
s
% Start of user PostScript
2. 19. 2.01851 19.0185 MAarrowhead1
% End of user PostScript
.0543 .29925 m
.0543 .29925 L
s
% Start of user PostScript
3. 19. MAarrowzero1
% End of user PostScript
.0694 .29925 m
.06979 .29953 L
s
% Start of user PostScript
4. 19. 4.02541 19.0185 MAarrowhead1
% End of user PostScript
.08451 .29925 m
.08451 .29925 L
s
% Start of user PostScript
5. 19. MAarrowzero1
% End of user PostScript
.09962 .29925 m
.09962 .29897 L
s
% Start of user PostScript
6. 19. 6. 18.9815 MAarrowhead1
% End of user PostScript
.11472 .29925 m
.115 .29925 L
s
% Start of user PostScript
7. 19. 7.01851 19. MAarrowhead1
% End of user PostScript
.12983 .29925 m
.12993 .29897 L
s
% Start of user PostScript
8. 19. 8.0069 18.9815 MAarrowhead1
% End of user PostScript
.14493 .29925 m
.14493 .29925 L
s
% Start of user PostScript
9. 19. MAarrowzero1
% End of user PostScript
.16004 .29925 m
.16042 .29897 L
s
% Start of user PostScript
10. 19. 10.0254 18.9815 MAarrowhead1
% End of user PostScript
.17514 .29925 m
.17514 .29925 L
s
% Start of user PostScript
11. 19. MAarrowzero1
% End of user PostScript
.19025 .29925 m
.19025 .299 L
s
% Start of user PostScript
12. 19. 12. 18.9837 MAarrowhead1
% End of user PostScript
.20535 .29925 m
.20507 .29963 L
s
% Start of user PostScript
13. 19. 12.9815 19.0254 MAarrowhead1
% End of user PostScript
.22046 .29925 m
.22062 .30013 L
s
% Start of user PostScript
14. 19. 14.0106 19.0584 MAarrowhead1
% End of user PostScript
.23556 .29925 m
.23606 .30086 L
s
% Start of user PostScript
15. 19. 15.033 19.1069 MAarrowhead1
% End of user PostScript
.25067 .29925 m
.25058 .30043 L
s
% Start of user PostScript
16. 19. 15.994 19.078 MAarrowhead1
% End of user PostScript
.26577 .29925 m
.26671 .30015 L
s
% Start of user PostScript
17. 19. 17.062 19.0595 MAarrowhead1
% End of user PostScript
.28088 .29925 m
.28163 .29981 L
s
% Start of user PostScript
18. 19. 18.0499 19.0373 MAarrowhead1
% End of user PostScript
.29598 .29925 m
.29704 .30157 L
s
% Start of user PostScript
19. 19. 19.0703 19.1539 MAarrowhead1
% End of user PostScript
.31109 .29925 m
.31167 .29744 L
s
% Start of user PostScript
20. 19. 20.0385 18.88 MAarrowhead1
% End of user PostScript
.32619 .29925 m
.32625 .29302 L
s
% Start of user PostScript
21. 19. 21.0035 18.5875 MAarrowhead1
% End of user PostScript
.3413 .29925 m
.3411 .29883 L
s
% Start of user PostScript
22. 19. 21.9871 18.9721 MAarrowhead1
% End of user PostScript
.3564 .29925 m
.3564 .29925 L
s
% Start of user PostScript
23. 19. MAarrowzero1
% End of user PostScript
.37151 .29925 m
.3709 .29944 L
s
% Start of user PostScript
24. 19. 23.9595 19.0129 MAarrowhead1
% End of user PostScript
.38661 .29925 m
.38581 .29944 L
s
% Start of user PostScript
25. 19. 24.9467 19.0129 MAarrowhead1
% End of user PostScript
.40172 .29925 m
.40152 .29944 L
s
% Start of user PostScript
26. 19. 25.9871 19.0129 MAarrowhead1
% End of user PostScript
.41682 .29925 m
.41663 .30011 L
s
% Start of user PostScript
27. 19. 26.9871 19.0568 MAarrowhead1
% End of user PostScript
.43193 .29925 m
.43122 .30015 L
s
% Start of user PostScript
28. 19. 27.9533 19.0595 MAarrowhead1
% End of user PostScript
.44703 .29925 m
.44653 .29925 L
s
% Start of user PostScript
29. 19. 28.9663 19. MAarrowhead1
% End of user PostScript
.46214 .29925 m
.46162 .29967 L
s
% Start of user PostScript
30. 19. 29.9659 19.0282 MAarrowhead1
% End of user PostScript
.47725 .29925 m
.47725 .29925 L
s
% Start of user PostScript
31. 19. MAarrowzero1
% End of user PostScript
.49235 .29925 m
.4923 .29958 L
s
% Start of user PostScript
32. 19. 31.9965 19.022 MAarrowhead1
% End of user PostScript
.50746 .29925 m
.50784 .29925 L
s
% Start of user PostScript
33. 19. 33.0254 19. MAarrowhead1
% End of user PostScript
.52256 .29925 m
.5236 .2993 L
s
% Start of user PostScript
34. 19. 34.0689 19.0035 MAarrowhead1
% End of user PostScript
.53767 .29925 m
.54059 .29888 L
s
% Start of user PostScript
35. 19. 35.1938 18.9755 MAarrowhead1
% End of user PostScript
.55277 .29925 m
.55241 .30053 L
s
% Start of user PostScript
36. 19. 35.9761 19.0852 MAarrowhead1
% End of user PostScript
.56788 .29925 m
.56788 .30006 L
s
% Start of user PostScript
37. 19. 37. 19.0538 MAarrowhead1
% End of user PostScript
.58298 .29925 m
.58328 .30034 L
s
% Start of user PostScript
38. 19. 38.02 19.0722 MAarrowhead1
% End of user PostScript
.59809 .29925 m
.5952 .29696 L
s
% Start of user PostScript
39. 19. 38.809 18.8486 MAarrowhead1
% End of user PostScript
.61319 .29925 m
.61675 .3012 L
s
% Start of user PostScript
40. 19. 40.2354 19.1294 MAarrowhead1
% End of user PostScript
.6283 .29925 m
.62877 .29895 L
s
% Start of user PostScript
41. 19. 41.0314 18.9801 MAarrowhead1
% End of user PostScript
.6434 .29925 m
.64464 .29839 L
s
% Start of user PostScript
42. 19. 42.082 18.9432 MAarrowhead1
% End of user PostScript
.65851 .29925 m
.65921 .29914 L
s
% Start of user PostScript
43. 19. 43.0464 18.9927 MAarrowhead1
% End of user PostScript
.67361 .29925 m
.67415 .29985 L
s
% Start of user PostScript
44. 19. 44.0353 19.0395 MAarrowhead1
% End of user PostScript
.68872 .29925 m
.6876 .2992 L
s
% Start of user PostScript
45. 19. 44.9262 18.9965 MAarrowhead1
% End of user PostScript
.70382 .29925 m
.70424 .30154 L
s
% Start of user PostScript
46. 19. 46.0279 19.1518 MAarrowhead1
% End of user PostScript
.71893 .29925 m
.71972 .29974 L
s
% Start of user PostScript
47. 19. 47.0526 19.0325 MAarrowhead1
% End of user PostScript
.73403 .29925 m
.73456 .29995 L
s
% Start of user PostScript
48. 19. 48.0348 19.0467 MAarrowhead1
% End of user PostScript
.74914 .29925 m
.74718 .30013 L
s
% Start of user PostScript
49. 19. 48.8706 19.0584 MAarrowhead1
% End of user PostScript
.76424 .29925 m
.7682 .29925 L
s
% Start of user PostScript
50. 19. 50.262 19. MAarrowhead1
% End of user PostScript
.77935 .29925 m
.77768 .29925 L
s
% Start of user PostScript
51. 19. 50.8894 19. MAarrowhead1
% End of user PostScript
.79445 .29925 m
.79428 .29969 L
s
% Start of user PostScript
52. 19. 51.9885 19.0293 MAarrowhead1
% End of user PostScript
.80956 .29925 m
.80951 .29828 L
s
% Start of user PostScript
53. 19. 52.9965 18.9361 MAarrowhead1
% End of user PostScript
.82466 .29925 m
.82433 .29682 L
s
% Start of user PostScript
54. 19. 53.978 18.8391 MAarrowhead1
% End of user PostScript
.83977 .29925 m
.8392 .29891 L
s
% Start of user PostScript
55. 19. 54.9624 18.9776 MAarrowhead1
% End of user PostScript
.85488 .29925 m
.85502 .29939 L
s
% Start of user PostScript
56. 19. 56.0094 19.0094 MAarrowhead1
% End of user PostScript
.86998 .29925 m
.86998 .29925 L
s
% Start of user PostScript
57. 19. MAarrowzero1
% End of user PostScript
.88509 .29925 m
.88481 .29897 L
s
% Start of user PostScript
58. 19. 57.9815 18.9815 MAarrowhead1
% End of user PostScript
.90019 .29925 m
.90019 .29925 L
s
% Start of user PostScript
59. 19. MAarrowzero1
% End of user PostScript
.9153 .29925 m
.9153 .29925 L
s
% Start of user PostScript
60. 19. MAarrowzero1
% End of user PostScript
.9304 .29925 m
.93068 .29925 L
s
% Start of user PostScript
61. 19. 61.0185 19. MAarrowhead1
% End of user PostScript
.94551 .29925 m
.94579 .29925 L
s
% Start of user PostScript
62. 19. 62.0185 19. MAarrowhead1
% End of user PostScript
.96061 .29925 m
.96061 .29925 L
s
% Start of user PostScript
63. 19. MAarrowzero1
% End of user PostScript
.97572 .29925 m
.97572 .29897 L
s
% Start of user PostScript
64. 19. 64. 18.9815 MAarrowhead1
% End of user PostScript
.02409 .31435 m
.02409 .31435 L
s
% Start of user PostScript
1. 20. MAarrowzero1
% End of user PostScript
.03919 .31435 m
.03919 .31435 L
s
% Start of user PostScript
2. 20. MAarrowzero1
% End of user PostScript
.0543 .31435 m
.0543 .31435 L
s
% Start of user PostScript
3. 20. MAarrowzero1
% End of user PostScript
.0694 .31435 m
.0694 .31435 L
s
% Start of user PostScript
4. 20. MAarrowzero1
% End of user PostScript
.08451 .31435 m
.08479 .31435 L
s
% Start of user PostScript
5. 20. 5.01851 20. MAarrowhead1
% End of user PostScript
.09962 .31435 m
.09989 .31435 L
s
% Start of user PostScript
6. 20. 6.01851 20. MAarrowhead1
% End of user PostScript
.11472 .31435 m
.11472 .31407 L
s
% Start of user PostScript
7. 20. 7. 19.9815 MAarrowhead1
% End of user PostScript
.12983 .31435 m
.13011 .31435 L
s
% Start of user PostScript
8. 20. 8.01851 20. MAarrowhead1
% End of user PostScript
.14493 .31435 m
.14521 .31463 L
s
% Start of user PostScript
9. 20. 9.01851 20.0185 MAarrowhead1
% End of user PostScript
.16004 .31435 m
.16018 .31425 L
s
% Start of user PostScript
10. 20. 10.0094 19.9931 MAarrowhead1
% End of user PostScript
.17514 .31435 m
.17542 .31407 L
s
% Start of user PostScript
11. 20. 11.0185 19.9815 MAarrowhead1
% End of user PostScript
.19025 .31435 m
.18997 .31463 L
s
% Start of user PostScript
12. 20. 11.9815 20.0185 MAarrowhead1
% End of user PostScript
.20535 .31435 m
.20625 .3153 L
s
% Start of user PostScript
13. 20. 13.0595 20.063 MAarrowhead1
% End of user PostScript
.22046 .31435 m
.22177 .31613 L
s
% Start of user PostScript
14. 20. 14.087 20.1175 MAarrowhead1
% End of user PostScript
.23556 .31435 m
.23685 .31597 L
s
% Start of user PostScript
15. 20. 15.0852 20.1069 MAarrowhead1
% End of user PostScript
.25067 .31435 m
.25186 .31502 L
s
% Start of user PostScript
16. 20. 16.0793 20.0439 MAarrowhead1
% End of user PostScript
.26577 .31435 m
.26507 .31435 L
s
% Start of user PostScript
17. 20. 16.9536 20. MAarrowhead1
% End of user PostScript
.28088 .31435 m
.28288 .31668 L
s
% Start of user PostScript
18. 20. 18.1327 20.1539 MAarrowhead1
% End of user PostScript
.29598 .31435 m
.29632 .31326 L
s
% Start of user PostScript
19. 20. 19.0224 19.9278 MAarrowhead1
% End of user PostScript
.31109 .31435 m
.31095 .3055 L
s
% Start of user PostScript
20. 20. 19.9906 19.4137 MAarrowhead1
% End of user PostScript
.32619 .31435 m
.32605 .31393 L
s
% Start of user PostScript
21. 20. 20.9906 19.9721 MAarrowhead1
% End of user PostScript
.3413 .31435 m
.34158 .31463 L
s
% Start of user PostScript
22. 20. 22.0185 20.0185 MAarrowhead1
% End of user PostScript
.3564 .31435 m
.35621 .31441 L
s
% Start of user PostScript
23. 20. 22.9871 20.0035 MAarrowhead1
% End of user PostScript
.37151 .31435 m
.37143 .31553 L
s
% Start of user PostScript
24. 20. 23.9945 20.078 MAarrowhead1
% End of user PostScript
.38661 .31435 m
.38656 .31523 L
s
% Start of user PostScript
25. 20. 24.9965 20.058 MAarrowhead1
% End of user PostScript
.40172 .31435 m
.40101 .31567 L
s
% Start of user PostScript
26. 20. 25.9533 20.0871 MAarrowhead1
% End of user PostScript
.41682 .31435 m
.41572 .31546 L
s
% Start of user PostScript
27. 20. 26.9269 20.0731 MAarrowhead1
% End of user PostScript
.43193 .31435 m
.43083 .31513 L
s
% Start of user PostScript
28. 20. 27.9269 20.0511 MAarrowhead1
% End of user PostScript
.44703 .31435 m
.4467 .31506 L
s
% Start of user PostScript
29. 20. 28.978 20.0467 MAarrowhead1
% End of user PostScript
.46214 .31435 m
.46132 .31435 L
s
% Start of user PostScript
30. 20. 29.9455 20. MAarrowhead1
% End of user PostScript
.47725 .31435 m
.47642 .31435 L
s
% Start of user PostScript
31. 20. 30.9455 20. MAarrowhead1
% End of user PostScript
.49235 .31435 m
.49235 .31435 L
s
% Start of user PostScript
32. 20. MAarrowzero1
% End of user PostScript
.50746 .31435 m
.50751 .31435 L
s
% Start of user PostScript
33. 20. 33.0035 20. MAarrowhead1
% End of user PostScript
.52256 .31435 m
.52293 .3145 L
s
% Start of user PostScript
34. 20. 34.0247 20.0094 MAarrowhead1
% End of user PostScript
.53767 .31435 m
.53772 .31488 L
s
% Start of user PostScript
35. 20. 35.0035 20.0348 MAarrowhead1
% End of user PostScript
.55277 .31435 m
.55481 .31477 L
s
% Start of user PostScript
36. 20. 36.1351 20.0279 MAarrowhead1
% End of user PostScript
.56788 .31435 m
.56841 .31553 L
s
% Start of user PostScript
37. 20. 37.0353 20.0778 MAarrowhead1
% End of user PostScript
.58298 .31435 m
.5834 .3155 L
s
% Start of user PostScript
38. 20. 38.0279 20.0756 MAarrowhead1
% End of user PostScript
.59809 .31435 m
.59618 .31435 L
s
% Start of user PostScript
39. 20. 38.874 20. MAarrowhead1
% End of user PostScript
.61319 .31435 m
.61009 .31134 L
s
% Start of user PostScript
40. 20. 39.7947 19.8007 MAarrowhead1
% End of user PostScript
.6283 .31435 m
.62811 .31716 L
s
% Start of user PostScript
41. 20. 40.9875 20.1855 MAarrowhead1
% End of user PostScript
.6434 .31435 m
.64553 .31606 L
s
% Start of user PostScript
42. 20. 42.141 20.1129 MAarrowhead1
% End of user PostScript
.65851 .31435 m
.66312 .31435 L
s
% Start of user PostScript
43. 20. 43.3053 20. MAarrowhead1
% End of user PostScript
.67361 .31435 m
.6715 .31429 L
s
% Start of user PostScript
44. 20. 43.86 19.9961 MAarrowhead1
% End of user PostScript
.68872 .31435 m
.68956 .3143 L
s
% Start of user PostScript
45. 20. 45.0556 19.9965 MAarrowhead1
% End of user PostScript
.70382 .31435 m
.70344 .31264 L
s
% Start of user PostScript
46. 20. 45.9746 19.8867 MAarrowhead1
% End of user PostScript
.71893 .31435 m
.71697 .31245 L
s
% Start of user PostScript
47. 20. 46.8706 19.874 MAarrowhead1
% End of user PostScript
.73403 .31435 m
.73342 .31303 L
s
% Start of user PostScript
48. 20. 47.9592 19.9125 MAarrowhead1
% End of user PostScript
.74914 .31435 m
.74736 .31435 L
s
% Start of user PostScript
49. 20. 48.8821 20. MAarrowhead1
% End of user PostScript
.76424 .31435 m
.7675 .31585 L
s
% Start of user PostScript
50. 20. 50.2155 20.099 MAarrowhead1
% End of user PostScript
.77935 .31435 m
.7793 .31391 L
s
% Start of user PostScript
51. 20. 50.9965 19.9707 MAarrowhead1
% End of user PostScript
.79445 .31435 m
.79523 .31374 L
s
% Start of user PostScript
52. 20. 52.0513 19.9592 MAarrowhead1
% End of user PostScript
.80956 .31435 m
.80859 .31324 L
s
% Start of user PostScript
53. 20. 52.9361 19.9262 MAarrowhead1
% End of user PostScript
.82466 .31435 m
.82517 .31483 L
s
% Start of user PostScript
54. 20. 54.0337 20.0318 MAarrowhead1
% End of user PostScript
.83977 .31435 m
.83991 .3146 L
s
% Start of user PostScript
55. 20. 55.0094 20.0163 MAarrowhead1
% End of user PostScript
.85488 .31435 m
.85512 .31397 L
s
% Start of user PostScript
56. 20. 56.0163 19.9746 MAarrowhead1
% End of user PostScript
.86998 .31435 m
.8697 .31435 L
s
% Start of user PostScript
57. 20. 56.9815 20. MAarrowhead1
% End of user PostScript
.88509 .31435 m
.88509 .3145 L
s
% Start of user PostScript
58. 20. 58. 20.0094 MAarrowhead1
% End of user PostScript
.90019 .31435 m
.90047 .31393 L
s
% Start of user PostScript
59. 20. 59.0185 19.9721 MAarrowhead1
% End of user PostScript
.9153 .31435 m
.91558 .31463 L
s
% Start of user PostScript
60. 20. 60.0185 20.0185 MAarrowhead1
% End of user PostScript
.9304 .31435 m
.9304 .31407 L
s
% Start of user PostScript
61. 20. 61. 19.9815 MAarrowhead1
% End of user PostScript
.94551 .31435 m
.94523 .31435 L
s
% Start of user PostScript
62. 20. 61.9815 20. MAarrowhead1
% End of user PostScript
.96061 .31435 m
.96061 .31435 L
s
% Start of user PostScript
63. 20. MAarrowzero1
% End of user PostScript
.97572 .31435 m
.97572 .31435 L
s
% Start of user PostScript
64. 20. MAarrowzero1
% End of user PostScript
.02409 .32946 m
.02409 .32946 L
s
% Start of user PostScript
1. 21. MAarrowzero1
% End of user PostScript
.03919 .32946 m
.03891 .32918 L
s
% Start of user PostScript
2. 21. 1.98149 20.9815 MAarrowhead1
% End of user PostScript
.0543 .32946 m
.0543 .32946 L
s
% Start of user PostScript
3. 21. MAarrowzero1
% End of user PostScript
.0694 .32946 m
.06913 .32946 L
s
% Start of user PostScript
4. 21. 3.98149 21. MAarrowhead1
% End of user PostScript
.08451 .32946 m
.08451 .32946 L
s
% Start of user PostScript
5. 21. MAarrowzero1
% End of user PostScript
.09962 .32946 m
.09989 .32974 L
s
% Start of user PostScript
6. 21. 6.01851 21.0185 MAarrowhead1
% End of user PostScript
.11472 .32946 m
.11472 .32946 L
s
% Start of user PostScript
7. 21. MAarrowzero1
% End of user PostScript
.12983 .32946 m
.12955 .32984 L
s
% Start of user PostScript
8. 21. 7.98149 21.0254 MAarrowhead1
% End of user PostScript
.14493 .32946 m
.14493 .32946 L
s
% Start of user PostScript
9. 21. MAarrowzero1
% End of user PostScript
.16004 .32946 m
.16014 .32918 L
s
% Start of user PostScript
10. 21. 10.0069 20.9815 MAarrowhead1
% End of user PostScript
.17514 .32946 m
.17514 .32946 L
s
% Start of user PostScript
11. 21. MAarrowzero1
% End of user PostScript
.19025 .32946 m
.19077 .32998 L
s
% Start of user PostScript
12. 21. 12.0348 21.0348 MAarrowhead1
% End of user PostScript
.20535 .32946 m
.20607 .32951 L
s
% Start of user PostScript
13. 21. 13.0478 21.0035 MAarrowhead1
% End of user PostScript
.22046 .32946 m
.22139 .3325 L
s
% Start of user PostScript
14. 21. 14.0616 21.2017 MAarrowhead1
% End of user PostScript
.23556 .32946 m
.23575 .33057 L
s
% Start of user PostScript
15. 21. 15.0125 21.0733 MAarrowhead1
% End of user PostScript
.25067 .32946 m
.25031 .32997 L
s
% Start of user PostScript
16. 21. 15.9761 21.0337 MAarrowhead1
% End of user PostScript
.26577 .32946 m
.26561 .32946 L
s
% Start of user PostScript
17. 21. 16.9894 21. MAarrowhead1
% End of user PostScript
.28088 .32946 m
.28139 .32946 L
s
% Start of user PostScript
18. 21. 18.0337 21. MAarrowhead1
% End of user PostScript
.29598 .32946 m
.29598 .32111 L
s
% Start of user PostScript
19. 21. 19. 20.4476 MAarrowhead1
% End of user PostScript
.31109 .32946 m
.31109 .32951 L
s
% Start of user PostScript
20. 21. 20. 21.0035 MAarrowhead1
% End of user PostScript
.32619 .32946 m
.32619 .32951 L
s
% Start of user PostScript
21. 21. 21. 21.0035 MAarrowhead1
% End of user PostScript
.3413 .32946 m
.34158 .32946 L
s
% Start of user PostScript
22. 21. 22.0185 21. MAarrowhead1
% End of user PostScript
.3564 .32946 m
.35461 .33239 L
s
% Start of user PostScript
23. 21. 22.8815 21.1943 MAarrowhead1
% End of user PostScript
.37151 .32946 m
.37283 .32876 L
s
% Start of user PostScript
24. 21. 24.0875 20.9538 MAarrowhead1
% End of user PostScript
.38661 .32946 m
.39002 .32681 L
s
% Start of user PostScript
25. 21. 25.2255 20.8247 MAarrowhead1
% End of user PostScript
.40172 .32946 m
.40221 .32897 L
s
% Start of user PostScript
26. 21. 26.0325 20.9675 MAarrowhead1
% End of user PostScript
.41682 .32946 m
.41835 .32718 L
s
% Start of user PostScript
27. 21. 27.1012 20.8489 MAarrowhead1
% End of user PostScript
.43193 .32946 m
.43325 .32946 L
s
% Start of user PostScript
28. 21. 28.0875 21. MAarrowhead1
% End of user PostScript
.44703 .32946 m
.44799 .32862 L
s
% Start of user PostScript
29. 21. 29.0632 20.9442 MAarrowhead1
% End of user PostScript
.46214 .32946 m
.46041 .32946 L
s
% Start of user PostScript
30. 21. 29.8854 21. MAarrowhead1
% End of user PostScript
.47725 .32946 m
.4764 .32946 L
s
% Start of user PostScript
31. 21. 30.9439 21. MAarrowhead1
% End of user PostScript
.49235 .32946 m
.49191 .32946 L
s
% Start of user PostScript
32. 21. 31.9709 21. MAarrowhead1
% End of user PostScript
.50746 .32946 m
.50795 .3299 L
s
% Start of user PostScript
33. 21. 33.0325 21.0291 MAarrowhead1
% End of user PostScript
.52256 .32946 m
.52289 .32946 L
s
% Start of user PostScript
34. 21. 34.022 21. MAarrowhead1
% End of user PostScript
.53767 .32946 m
.53804 .32946 L
s
% Start of user PostScript
35. 21. 35.0247 21. MAarrowhead1
% End of user PostScript
.55277 .32946 m
.55347 .32968 L
s
% Start of user PostScript
36. 21. 36.0464 21.0147 MAarrowhead1
% End of user PostScript
.56788 .32946 m
.57161 .33008 L
s
% Start of user PostScript
37. 21. 37.2475 21.0408 MAarrowhead1
% End of user PostScript
.58298 .32946 m
.58416 .33052 L
s
% Start of user PostScript
38. 21. 38.078 21.0703 MAarrowhead1
% End of user PostScript
.59809 .32946 m
.59736 .32946 L
s
% Start of user PostScript
39. 21. 38.9521 21. MAarrowhead1
% End of user PostScript
.61319 .32946 m
.61115 .33199 L
s
% Start of user PostScript
40. 21. 39.8646 21.1679 MAarrowhead1
% End of user PostScript
.6283 .32946 m
.63025 .32861 L
s
% Start of user PostScript
41. 21. 41.1294 20.9439 MAarrowhead1
% End of user PostScript
.6434 .32946 m
.6393 .32753 L
s
% Start of user PostScript
42. 21. 41.7282 20.8721 MAarrowhead1
% End of user PostScript
.65851 .32946 m
.6566 .32842 L
s
% Start of user PostScript
43. 21. 42.874 20.9315 MAarrowhead1
% End of user PostScript
.67361 .32946 m
.67602 .32995 L
s
% Start of user PostScript
44. 21. 44.1595 21.0325 MAarrowhead1
% End of user PostScript
.68872 .32946 m
.68872 .3277 L
s
% Start of user PostScript
45. 21. 45. 20.8835 MAarrowhead1
% End of user PostScript
.70382 .32946 m
.70349 .32964 L
s
% Start of user PostScript
46. 21. 45.978 21.0118 MAarrowhead1
% End of user PostScript
.71893 .32946 m
.71813 .32828 L
s
% Start of user PostScript
47. 21. 46.9474 20.922 MAarrowhead1
% End of user PostScript
.73403 .32946 m
.73453 .32993 L
s
% Start of user PostScript
48. 21. 48.0325 21.0314 MAarrowhead1
% End of user PostScript
.74914 .32946 m
.74843 .32955 L
s
% Start of user PostScript
49. 21. 48.9533 21.006 MAarrowhead1
% End of user PostScript
.76424 .32946 m
.76424 .32893 L
s
% Start of user PostScript
50. 21. 50. 20.9649 MAarrowhead1
% End of user PostScript
.77935 .32946 m
.77797 .33081 L
s
% Start of user PostScript
51. 21. 50.9089 21.0898 MAarrowhead1
% End of user PostScript
.79445 .32946 m
.79384 .32884 L
s
% Start of user PostScript
52. 21. 51.9592 20.9592 MAarrowhead1
% End of user PostScript
.80956 .32946 m
.80785 .32737 L
s
% Start of user PostScript
53. 21. 52.8871 20.8615 MAarrowhead1
% End of user PostScript
.82466 .32946 m
.82461 .32828 L
s
% Start of user PostScript
54. 21. 53.9961 20.922 MAarrowhead1
% End of user PostScript
.83977 .32946 m
.84005 .3298 L
s
% Start of user PostScript
55. 21. 55.0185 21.0224 MAarrowhead1
% End of user PostScript
.85488 .32946 m
.85526 .32893 L
s
% Start of user PostScript
56. 21. 56.0254 20.9652 MAarrowhead1
% End of user PostScript
.86998 .32946 m
.86998 .32974 L
s
% Start of user PostScript
57. 21. 57. 21.0185 MAarrowhead1
% End of user PostScript
.88509 .32946 m
.88481 .32918 L
s
% Start of user PostScript
58. 21. 57.9815 20.9815 MAarrowhead1
% End of user PostScript
.90019 .32946 m
.89991 .32918 L
s
% Start of user PostScript
59. 21. 58.9815 20.9815 MAarrowhead1
% End of user PostScript
.9153 .32946 m
.91502 .32974 L
s
% Start of user PostScript
60. 21. 59.9815 21.0185 MAarrowhead1
% End of user PostScript
.9304 .32946 m
.9304 .32918 L
s
% Start of user PostScript
61. 21. 61. 20.9815 MAarrowhead1
% End of user PostScript
.94551 .32946 m
.94551 .32946 L
s
% Start of user PostScript
62. 21. MAarrowzero1
% End of user PostScript
.96061 .32946 m
.96061 .32974 L
s
% Start of user PostScript
63. 21. 63. 21.0185 MAarrowhead1
% End of user PostScript
.97572 .32946 m
.97544 .32918 L
s
% Start of user PostScript
64. 21. 63.9815 20.9815 MAarrowhead1
% End of user PostScript
.02409 .34456 m
.02437 .34428 L
s
% Start of user PostScript
1. 22. 1.01851 21.9815 MAarrowhead1
% End of user PostScript
.03919 .34456 m
.03947 .34456 L
s
% Start of user PostScript
2. 22. 2.01851 22. MAarrowhead1
% End of user PostScript
.0543 .34456 m
.05458 .34484 L
s
% Start of user PostScript
3. 22. 3.01851 22.0185 MAarrowhead1
% End of user PostScript
.0694 .34456 m
.0694 .34456 L
s
% Start of user PostScript
4. 22. MAarrowzero1
% End of user PostScript
.08451 .34456 m
.08451 .34484 L
s
% Start of user PostScript
5. 22. 5. 22.0185 MAarrowhead1
% End of user PostScript
.09962 .34456 m
.09934 .34428 L
s
% Start of user PostScript
6. 22. 5.98149 21.9815 MAarrowhead1
% End of user PostScript
.11472 .34456 m
.11472 .34456 L
s
% Start of user PostScript
7. 22. MAarrowzero1
% End of user PostScript
.12983 .34456 m
.12983 .34428 L
s
% Start of user PostScript
8. 22. 8. 21.9815 MAarrowhead1
% End of user PostScript
.14493 .34456 m
.14521 .34456 L
s
% Start of user PostScript
9. 22. 9.01851 22. MAarrowhead1
% End of user PostScript
.16004 .34456 m
.15976 .34418 L
s
% Start of user PostScript
10. 22. 9.98149 21.9746 MAarrowhead1
% End of user PostScript
.17514 .34456 m
.17528 .34484 L
s
% Start of user PostScript
11. 22. 11.0094 22.0185 MAarrowhead1
% End of user PostScript
.19025 .34456 m
.19162 .34627 L
s
% Start of user PostScript
12. 22. 12.0909 22.1129 MAarrowhead1
% End of user PostScript
.20535 .34456 m
.20658 .34694 L
s
% Start of user PostScript
13. 22. 13.0815 22.157 MAarrowhead1
% End of user PostScript
.22046 .34456 m
.22137 .34632 L
s
% Start of user PostScript
14. 22. 14.0605 22.1165 MAarrowhead1
% End of user PostScript
.23556 .34456 m
.2365 .34699 L
s
% Start of user PostScript
15. 22. 15.062 22.1605 MAarrowhead1
% End of user PostScript
.25067 .34456 m
.25137 .34546 L
s
% Start of user PostScript
16. 22. 16.0464 22.0593 MAarrowhead1
% End of user PostScript
.26577 .34456 m
.26625 .34595 L
s
% Start of user PostScript
17. 22. 17.0314 22.0918 MAarrowhead1
% End of user PostScript
.28088 .34456 m
.28054 .34258 L
s
% Start of user PostScript
18. 22. 17.9776 21.8685 MAarrowhead1
% End of user PostScript
.29598 .34456 m
.29603 .34013 L
s
% Start of user PostScript
19. 22. 19.0035 21.7064 MAarrowhead1
% End of user PostScript
.31109 .34456 m
.31109 .3449 L
s
% Start of user PostScript
20. 22. 20. 22.022 MAarrowhead1
% End of user PostScript
.32619 .34456 m
.32625 .34462 L
s
% Start of user PostScript
21. 22. 21.0035 22.0035 MAarrowhead1
% End of user PostScript
.3413 .34456 m
.33886 .3475 L
s
% Start of user PostScript
22. 22. 21.8383 22.1943 MAarrowhead1
% End of user PostScript
.3564 .34456 m
.35472 .34783 L
s
% Start of user PostScript
23. 22. 22.8888 22.216 MAarrowhead1
% End of user PostScript
.37151 .34456 m
.36855 .34722 L
s
% Start of user PostScript
24. 22. 23.804 22.1756 MAarrowhead1
% End of user PostScript
.38661 .34456 m
.38563 .34652 L
s
% Start of user PostScript
25. 22. 24.935 22.1294 MAarrowhead1
% End of user PostScript
.40172 .34456 m
.39907 .34603 L
s
% Start of user PostScript
26. 22. 25.8244 22.0969 MAarrowhead1
% End of user PostScript
.41682 .34456 m
.41529 .34687 L
s
% Start of user PostScript
27. 22. 26.8985 22.1529 MAarrowhead1
% End of user PostScript
.43193 .34456 m
.42917 .34636 L
s
% Start of user PostScript
28. 22. 27.8172 22.1192 MAarrowhead1
% End of user PostScript
.44703 .34456 m
.44322 .34761 L
s
% Start of user PostScript
29. 22. 28.7471 22.2016 MAarrowhead1
% End of user PostScript
.46214 .34456 m
.45952 .34754 L
s
% Start of user PostScript
30. 22. 29.8262 22.1972 MAarrowhead1
% End of user PostScript
.47725 .34456 m
.47168 .3455 L
s
% Start of user PostScript
31. 22. 30.6318 22.0623 MAarrowhead1
% End of user PostScript
.49235 .34456 m
.49026 .34428 L
s
% Start of user PostScript
32. 22. 31.8618 21.9815 MAarrowhead1
% End of user PostScript
.50746 .34456 m
.50746 .34456 L
s
% Start of user PostScript
33. 22. MAarrowzero1
% End of user PostScript
.52256 .34456 m
.52256 .34506 L
s
% Start of user PostScript
34. 22. 34. 22.0325 MAarrowhead1
% End of user PostScript
.53767 .34456 m
.53851 .34494 L
s
% Start of user PostScript
35. 22. 35.0561 22.0247 MAarrowhead1
% End of user PostScript
.55277 .34456 m
.5533 .34462 L
s
% Start of user PostScript
36. 22. 36.0348 22.0035 MAarrowhead1
% End of user PostScript
.56788 .34456 m
.56921 .34532 L
s
% Start of user PostScript
37. 22. 37.0886 22.0499 MAarrowhead1
% End of user PostScript
.58298 .34456 m
.58697 .34613 L
s
% Start of user PostScript
38. 22. 38.2644 22.1036 MAarrowhead1
% End of user PostScript
.59809 .34456 m
.59834 .34672 L
s
% Start of user PostScript
39. 22. 39.0165 22.1425 MAarrowhead1
% End of user PostScript
.61319 .34456 m
.61124 .34338 L
s
% Start of user PostScript
40. 22. 39.8706 21.922 MAarrowhead1
% End of user PostScript
.6283 .34456 m
.62483 .34414 L
s
% Start of user PostScript
41. 22. 40.7705 21.9721 MAarrowhead1
% End of user PostScript
.6434 .34456 m
.64494 .34657 L
s
% Start of user PostScript
42. 22. 42.1015 22.1329 MAarrowhead1
% End of user PostScript
.65851 .34456 m
.66022 .34717 L
s
% Start of user PostScript
43. 22. 43.1133 22.1726 MAarrowhead1
% End of user PostScript
.67361 .34456 m
.6711 .34369 L
s
% Start of user PostScript
44. 22. 43.8333 21.942 MAarrowhead1
% End of user PostScript
.68872 .34456 m
.69357 .34393 L
s
% Start of user PostScript
45. 22. 45.3215 21.958 MAarrowhead1
% End of user PostScript
.70382 .34456 m
.70464 .34595 L
s
% Start of user PostScript
46. 22. 46.0538 22.0921 MAarrowhead1
% End of user PostScript
.71893 .34456 m
.71954 .34371 L
s
% Start of user PostScript
47. 22. 47.0408 21.9432 MAarrowhead1
% End of user PostScript
.73403 .34456 m
.73354 .34499 L
s
% Start of user PostScript
48. 22. 47.9675 22.0279 MAarrowhead1
% End of user PostScript
.74914 .34456 m
.74724 .34386 L
s
% Start of user PostScript
49. 22. 48.874 21.9533 MAarrowhead1
% End of user PostScript
.76424 .34456 m
.76413 .34456 L
s
% Start of user PostScript
50. 22. 49.9927 22. MAarrowhead1
% End of user PostScript
.77935 .34456 m
.7815 .34439 L
s
% Start of user PostScript
51. 22. 51.1422 21.9885 MAarrowhead1
% End of user PostScript
.79445 .34456 m
.79583 .34456 L
s
% Start of user PostScript
52. 22. 52.0911 22. MAarrowhead1
% End of user PostScript
.80956 .34456 m
.807 .34198 L
s
% Start of user PostScript
53. 22. 52.8303 21.8287 MAarrowhead1
% End of user PostScript
.82466 .34456 m
.82452 .34462 L
s
% Start of user PostScript
54. 22. 53.9906 22.0039 MAarrowhead1
% End of user PostScript
.83977 .34456 m
.84005 .34404 L
s
% Start of user PostScript
55. 22. 55.0185 21.9652 MAarrowhead1
% End of user PostScript
.85488 .34456 m
.85435 .34456 L
s
% Start of user PostScript
56. 22. 55.9652 22. MAarrowhead1
% End of user PostScript
.86998 .34456 m
.86998 .34484 L
s
% Start of user PostScript
57. 22. 57. 22.0185 MAarrowhead1
% End of user PostScript
.88509 .34456 m
.88509 .34484 L
s
% Start of user PostScript
58. 22. 58. 22.0185 MAarrowhead1
% End of user PostScript
.90019 .34456 m
.90047 .34456 L
s
% Start of user PostScript
59. 22. 59.0185 22. MAarrowhead1
% End of user PostScript
.9153 .34456 m
.9153 .34456 L
s
% Start of user PostScript
60. 22. MAarrowzero1
% End of user PostScript
.9304 .34456 m
.9304 .34456 L
s
% Start of user PostScript
61. 22. MAarrowzero1
% End of user PostScript
.94551 .34456 m
.94551 .34456 L
s
% Start of user PostScript
62. 22. MAarrowzero1
% End of user PostScript
.96061 .34456 m
.96033 .34456 L
s
% Start of user PostScript
63. 22. 62.9815 22. MAarrowhead1
% End of user PostScript
.97572 .34456 m
.97544 .34456 L
s
% Start of user PostScript
64. 22. 63.9815 22. MAarrowhead1
% End of user PostScript
.02409 .35967 m
.02437 .35939 L
s
% Start of user PostScript
1. 23. 1.01851 22.9815 MAarrowhead1
% End of user PostScript
.03919 .35967 m
.03919 .35967 L
s
% Start of user PostScript
2. 23. MAarrowzero1
% End of user PostScript
.0543 .35967 m
.0543 .35995 L
s
% Start of user PostScript
3. 23. 3. 23.0185 MAarrowhead1
% End of user PostScript
.0694 .35967 m
.06968 .35939 L
s
% Start of user PostScript
4. 23. 4.01851 22.9815 MAarrowhead1
% End of user PostScript
.08451 .35967 m
.08479 .35995 L
s
% Start of user PostScript
5. 23. 5.01851 23.0185 MAarrowhead1
% End of user PostScript
.09962 .35967 m
.09989 .35995 L
s
% Start of user PostScript
6. 23. 6.01851 23.0185 MAarrowhead1
% End of user PostScript
.11472 .35967 m
.115 .35967 L
s
% Start of user PostScript
7. 23. 7.01851 23. MAarrowhead1
% End of user PostScript
.12983 .35967 m
.13011 .35967 L
s
% Start of user PostScript
8. 23. 8.01851 23. MAarrowhead1
% End of user PostScript
.14493 .35967 m
.14521 .35977 L
s
% Start of user PostScript
9. 23. 9.01851 23.0069 MAarrowhead1
% End of user PostScript
.16004 .35967 m
.16032 .35967 L
s
% Start of user PostScript
10. 23. 10.0185 23. MAarrowhead1
% End of user PostScript
.17514 .35967 m
.17489 .35967 L
s
% Start of user PostScript
11. 23. 10.9837 23. MAarrowhead1
% End of user PostScript
.19025 .35967 m
.19109 .36106 L
s
% Start of user PostScript
12. 23. 12.0556 23.0921 MAarrowhead1
% End of user PostScript
.20535 .35967 m
.20678 .36273 L
s
% Start of user PostScript
13. 23. 13.0946 23.2026 MAarrowhead1
% End of user PostScript
.22046 .35967 m
.22093 .36078 L
s
% Start of user PostScript
14. 23. 14.0314 23.0733 MAarrowhead1
% End of user PostScript
.23556 .35967 m
.23556 .35972 L
s
% Start of user PostScript
15. 23. 15. 23.0035 MAarrowhead1
% End of user PostScript
.25067 .35967 m
.25083 .36039 L
s
% Start of user PostScript
16. 23. 16.0106 23.0479 MAarrowhead1
% End of user PostScript
.26577 .35967 m
.26577 .35984 L
s
% Start of user PostScript
17. 23. 17. 23.0114 MAarrowhead1
% End of user PostScript
.28088 .35967 m
.27373 .35196 L
s
% Start of user PostScript
18. 23. 17.5268 22.4898 MAarrowhead1
% End of user PostScript
.29598 .35967 m
.29593 .35972 L
s
% Start of user PostScript
19. 23. 18.9965 23.0035 MAarrowhead1
% End of user PostScript
.31109 .35967 m
.31089 .36 L
s
% Start of user PostScript
20. 23. 19.9871 23.022 MAarrowhead1
% End of user PostScript
.32619 .35967 m
.32652 .35972 L
s
% Start of user PostScript
21. 23. 21.022 23.0035 MAarrowhead1
% End of user PostScript
.3413 .35967 m
.34163 .35849 L
s
% Start of user PostScript
22. 23. 22.022 22.922 MAarrowhead1
% End of user PostScript
.3564 .35967 m
.36085 .35637 L
s
% Start of user PostScript
23. 23. 23.2942 22.7815 MAarrowhead1
% End of user PostScript
.37151 .35967 m
.37706 .35531 L
s
% Start of user PostScript
24. 23. 24.3678 22.7114 MAarrowhead1
% End of user PostScript
.38661 .35967 m
.39145 .35456 L
s
% Start of user PostScript
25. 23. 25.32 22.6615 MAarrowhead1
% End of user PostScript
.40172 .35967 m
.40507 .35541 L
s
% Start of user PostScript
26. 23. 26.222 22.7183 MAarrowhead1
% End of user PostScript
.41682 .35967 m
.42213 .35403 L
s
% Start of user PostScript
27. 23. 27.3514 22.6267 MAarrowhead1
% End of user PostScript
.43193 .35967 m
.43682 .35484 L
s
% Start of user PostScript
28. 23. 28.3235 22.68 MAarrowhead1
% End of user PostScript
.44703 .35967 m
.45136 .35568 L
s
% Start of user PostScript
29. 23. 29.2863 22.7361 MAarrowhead1
% End of user PostScript
.46214 .35967 m
.4635 .35823 L
s
% Start of user PostScript
30. 23. 30.0898 22.9045 MAarrowhead1
% End of user PostScript
.47725 .35967 m
.47774 .35876 L
s
% Start of user PostScript
31. 23. 31.0325 22.9395 MAarrowhead1
% End of user PostScript
.49235 .35967 m
.4924 .35918 L
s
% Start of user PostScript
32. 23. 32.0035 22.9675 MAarrowhead1
% End of user PostScript
.50746 .35967 m
.50784 .35967 L
s
% Start of user PostScript
33. 23. 33.0254 23. MAarrowhead1
% End of user PostScript
.52256 .35967 m
.52277 .35983 L
s
% Start of user PostScript
34. 23. 34.014 23.0106 MAarrowhead1
% End of user PostScript
.53767 .35967 m
.538 .36016 L
s
% Start of user PostScript
35. 23. 35.022 23.0325 MAarrowhead1
% End of user PostScript
.55277 .35967 m
.55329 .35967 L
s
% Start of user PostScript
36. 23. 36.0341 23. MAarrowhead1
% End of user PostScript
.56788 .35967 m
.56835 .36014 L
s
% Start of user PostScript
37. 23. 37.0314 23.0314 MAarrowhead1
% End of user PostScript
.58298 .35967 m
.58519 .36034 L
s
% Start of user PostScript
38. 23. 38.146 23.0447 MAarrowhead1
% End of user PostScript
.59809 .35967 m
.60166 .36037 L
s
% Start of user PostScript
39. 23. 39.2367 23.0467 MAarrowhead1
% End of user PostScript
.61319 .35967 m
.61067 .3557 L
s
% Start of user PostScript
40. 23. 39.8333 22.7375 MAarrowhead1
% End of user PostScript
.6283 .35967 m
.62592 .35967 L
s
% Start of user PostScript
41. 23. 40.8427 23. MAarrowhead1
% End of user PostScript
.6434 .35967 m
.64134 .36083 L
s
% Start of user PostScript
42. 23. 41.8635 23.0768 MAarrowhead1
% End of user PostScript
.65851 .35967 m
.65511 .35794 L
s
% Start of user PostScript
43. 23. 42.7749 22.8858 MAarrowhead1
% End of user PostScript
.67361 .35967 m
.66913 .35905 L
s
% Start of user PostScript
44. 23. 43.7032 22.9592 MAarrowhead1
% End of user PostScript
.68872 .35967 m
.68782 .35967 L
s
% Start of user PostScript
45. 23. 44.9405 23. MAarrowhead1
% End of user PostScript
.70382 .35967 m
.70511 .35777 L
s
% Start of user PostScript
46. 23. 46.0851 22.874 MAarrowhead1
% End of user PostScript
.71893 .35967 m
.71972 .36067 L
s
% Start of user PostScript
47. 23. 47.0526 23.0662 MAarrowhead1
% End of user PostScript
.73403 .35967 m
.73285 .35967 L
s
% Start of user PostScript
48. 23. 47.922 23. MAarrowhead1
% End of user PostScript
.74914 .35967 m
.74796 .35777 L
s
% Start of user PostScript
49. 23. 48.922 22.874 MAarrowhead1
% End of user PostScript
.76424 .35967 m
.76199 .35859 L
s
% Start of user PostScript
50. 23. 49.8507 22.9287 MAarrowhead1
% End of user PostScript
.77935 .35967 m
.78211 .36199 L
s
% Start of user PostScript
51. 23. 51.183 23.1537 MAarrowhead1
% End of user PostScript
.79445 .35967 m
.79428 .36132 L
s
% Start of user PostScript
52. 23. 51.9885 23.1094 MAarrowhead1
% End of user PostScript
.80956 .35967 m
.80899 .35878 L
s
% Start of user PostScript
53. 23. 52.9624 22.9409 MAarrowhead1
% End of user PostScript
.82466 .35967 m
.82466 .35967 L
s
% Start of user PostScript
54. 23. MAarrowzero1
% End of user PostScript
.83977 .35967 m
.83919 .3588 L
s
% Start of user PostScript
55. 23. 54.9613 22.9428 MAarrowhead1
% End of user PostScript
.85488 .35967 m
.85515 .35939 L
s
% Start of user PostScript
56. 23. 56.0185 22.9815 MAarrowhead1
% End of user PostScript
.86998 .35967 m
.8697 .35939 L
s
% Start of user PostScript
57. 23. 56.9815 22.9815 MAarrowhead1
% End of user PostScript
.88509 .35967 m
.88509 .35967 L
s
% Start of user PostScript
58. 23. MAarrowzero1
% End of user PostScript
.90019 .35967 m
.90047 .35967 L
s
% Start of user PostScript
59. 23. 59.0185 23. MAarrowhead1
% End of user PostScript
.9153 .35967 m
.9153 .35995 L
s
% Start of user PostScript
60. 23. 60. 23.0185 MAarrowhead1
% End of user PostScript
.9304 .35967 m
.9304 .35967 L
s
% Start of user PostScript
61. 23. MAarrowzero1
% End of user PostScript
.94551 .35967 m
.94579 .35967 L
s
% Start of user PostScript
62. 23. 62.0185 23. MAarrowhead1
% End of user PostScript
.96061 .35967 m
.96061 .35995 L
s
% Start of user PostScript
63. 23. 63. 23.0185 MAarrowhead1
% End of user PostScript
.97572 .35967 m
.97572 .35939 L
s
% Start of user PostScript
64. 23. 64. 22.9815 MAarrowhead1
% End of user PostScript
.02409 .37477 m
.02409 .37477 L
s
% Start of user PostScript
1. 24. MAarrowzero1
% End of user PostScript
.03919 .37477 m
.03919 .37505 L
s
% Start of user PostScript
2. 24. 2. 24.0185 MAarrowhead1
% End of user PostScript
.0543 .37477 m
.05402 .37505 L
s
% Start of user PostScript
3. 24. 2.98149 24.0185 MAarrowhead1
% End of user PostScript
.0694 .37477 m
.0694 .37477 L
s
% Start of user PostScript
4. 24. MAarrowzero1
% End of user PostScript
.08451 .37477 m
.08413 .37477 L
s
% Start of user PostScript
5. 24. 4.97459 24. MAarrowhead1
% End of user PostScript
.09962 .37477 m
.09989 .37477 L
s
% Start of user PostScript
6. 24. 6.01851 24. MAarrowhead1
% End of user PostScript
.11472 .37477 m
.115 .37505 L
s
% Start of user PostScript
7. 24. 7.01851 24.0185 MAarrowhead1
% End of user PostScript
.12983 .37477 m
.12983 .37477 L
s
% Start of user PostScript
8. 24. MAarrowzero1
% End of user PostScript
.14493 .37477 m
.14521 .37505 L
s
% Start of user PostScript
9. 24. 9.01851 24.0185 MAarrowhead1
% End of user PostScript
.16004 .37477 m
.16004 .37477 L
s
% Start of user PostScript
10. 24. MAarrowzero1
% End of user PostScript
.17514 .37477 m
.17567 .37477 L
s
% Start of user PostScript
11. 24. 11.0348 24. MAarrowhead1
% End of user PostScript
.19025 .37477 m
.19095 .37699 L
s
% Start of user PostScript
12. 24. 12.0469 24.1465 MAarrowhead1
% End of user PostScript
.20535 .37477 m
.20583 .378 L
s
% Start of user PostScript
13. 24. 13.0314 24.2136 MAarrowhead1
% End of user PostScript
.22046 .37477 m
.22192 .37609 L
s
% Start of user PostScript
14. 24. 14.0969 24.0875 MAarrowhead1
% End of user PostScript
.23556 .37477 m
.23556 .3762 L
s
% Start of user PostScript
15. 24. 15. 24.0942 MAarrowhead1
% End of user PostScript
.25067 .37477 m
.25067 .37351 L
s
% Start of user PostScript
16. 24. 16. 23.916 MAarrowhead1
% End of user PostScript
.26577 .37477 m
.2661 .37477 L
s
% Start of user PostScript
17. 24. 17.022 24. MAarrowhead1
% End of user PostScript
.28088 .37477 m
.28088 .37335 L
s
% Start of user PostScript
18. 24. 18. 23.9058 MAarrowhead1
% End of user PostScript
.29598 .37477 m
.2957 .37477 L
s
% Start of user PostScript
19. 24. 18.9815 24. MAarrowhead1
% End of user PostScript
.31109 .37477 m
.31109 .37477 L
s
% Start of user PostScript
20. 24. MAarrowzero1
% End of user PostScript
.32619 .37477 m
.32591 .3743 L
s
% Start of user PostScript
21. 24. 20.9815 23.9686 MAarrowhead1
% End of user PostScript
.3413 .37477 m
.34116 .3743 L
s
% Start of user PostScript
22. 24. 21.9906 23.9686 MAarrowhead1
% End of user PostScript
.3564 .37477 m
.35607 .37477 L
s
% Start of user PostScript
23. 24. 22.978 24. MAarrowhead1
% End of user PostScript
.37151 .37477 m
.37118 .37477 L
s
% Start of user PostScript
24. 24. 23.978 24. MAarrowhead1
% End of user PostScript
.38661 .37477 m
.38628 .37492 L
s
% Start of user PostScript
25. 24. 24.978 24.0094 MAarrowhead1
% End of user PostScript
.40172 .37477 m
.40172 .37477 L
s
% Start of user PostScript
26. 24. MAarrowzero1
% End of user PostScript
.41682 .37477 m
.41677 .37483 L
s
% Start of user PostScript
27. 24. 26.9965 24.0035 MAarrowhead1
% End of user PostScript
.43193 .37477 m
.43193 .37449 L
s
% Start of user PostScript
28. 24. 28. 23.9815 MAarrowhead1
% End of user PostScript
.44703 .37477 m
.44746 .37477 L
s
% Start of user PostScript
29. 24. 29.0279 24. MAarrowhead1
% End of user PostScript
.46214 .37477 m
.46248 .37505 L
s
% Start of user PostScript
30. 24. 30.0224 24.0185 MAarrowhead1
% End of user PostScript
.47725 .37477 m
.47725 .37505 L
s
% Start of user PostScript
31. 24. 31. 24.0185 MAarrowhead1
% End of user PostScript
.49235 .37477 m
.4932 .37477 L
s
% Start of user PostScript
32. 24. 32.0561 24. MAarrowhead1
% End of user PostScript
.50746 .37477 m
.50746 .37539 L
s
% Start of user PostScript
33. 24. 33. 24.0405 MAarrowhead1
% End of user PostScript
.52256 .37477 m
.52256 .37449 L
s
% Start of user PostScript
34. 24. 34. 23.9815 MAarrowhead1
% End of user PostScript
.53767 .37477 m
.538 .37511 L
s
% Start of user PostScript
35. 24. 35.022 24.022 MAarrowhead1
% End of user PostScript
.55277 .37477 m
.55291 .37477 L
s
% Start of user PostScript
36. 24. 36.0094 24. MAarrowhead1
% End of user PostScript
.56788 .37477 m
.56835 .37455 L
s
% Start of user PostScript
37. 24. 37.0314 23.9853 MAarrowhead1
% End of user PostScript
.58298 .37477 m
.58441 .37553 L
s
% Start of user PostScript
38. 24. 38.0946 24.0499 MAarrowhead1
% End of user PostScript
.59809 .37477 m
.60237 .37636 L
s
% Start of user PostScript
39. 24. 39.2833 24.1051 MAarrowhead1
% End of user PostScript
.61319 .37477 m
.6121 .3753 L
s
% Start of user PostScript
40. 24. 39.9278 24.0349 MAarrowhead1
% End of user PostScript
.6283 .37477 m
.62539 .37472 L
s
% Start of user PostScript
41. 24. 40.8078 23.9965 MAarrowhead1
% End of user PostScript
.6434 .37477 m
.64009 .3755 L
s
% Start of user PostScript
42. 24. 41.7808 24.0478 MAarrowhead1
% End of user PostScript
.65851 .37477 m
.66004 .37477 L
s
% Start of user PostScript
43. 24. 43.1015 24. MAarrowhead1
% End of user PostScript
.67361 .37477 m
.67282 .37601 L
s
% Start of user PostScript
44. 24. 43.9474 24.082 MAarrowhead1
% End of user PostScript
.68872 .37477 m
.68652 .37405 L
s
% Start of user PostScript
45. 24. 44.8546 23.9524 MAarrowhead1
% End of user PostScript
.70382 .37477 m
.70479 .37749 L
s
% Start of user PostScript
46. 24. 46.0639 24.1795 MAarrowhead1
% End of user PostScript
.71893 .37477 m
.72021 .37477 L
s
% Start of user PostScript
47. 24. 47.0851 24. MAarrowhead1
% End of user PostScript
.73403 .37477 m
.73521 .37611 L
s
% Start of user PostScript
48. 24. 48.078 24.0886 MAarrowhead1
% End of user PostScript
.74914 .37477 m
.74993 .37516 L
s
% Start of user PostScript
49. 24. 49.0526 24.0254 MAarrowhead1
% End of user PostScript
.76424 .37477 m
.76246 .3736 L
s
% Start of user PostScript
50. 24. 49.8821 23.922 MAarrowhead1
% End of user PostScript
.77935 .37477 m
.78113 .37625 L
s
% Start of user PostScript
51. 24. 51.1179 24.098 MAarrowhead1
% End of user PostScript
.79445 .37477 m
.79445 .37548 L
s
% Start of user PostScript
52. 24. 52. 24.0467 MAarrowhead1
% End of user PostScript
.80956 .37477 m
.80866 .37477 L
s
% Start of user PostScript
53. 24. 52.9405 24. MAarrowhead1
% End of user PostScript
.82466 .37477 m
.82466 .37516 L
s
% Start of user PostScript
54. 24. 54. 24.0254 MAarrowhead1
% End of user PostScript
.83977 .37477 m
.83977 .37467 L
s
% Start of user PostScript
55. 24. 55. 23.9931 MAarrowhead1
% End of user PostScript
.85488 .37477 m
.85488 .37477 L
s
% Start of user PostScript
56. 24. MAarrowzero1
% End of user PostScript
.86998 .37477 m
.8697 .37449 L
s
% Start of user PostScript
57. 24. 56.9815 23.9815 MAarrowhead1
% End of user PostScript
.88509 .37477 m
.88509 .37477 L
s
% Start of user PostScript
58. 24. MAarrowzero1
% End of user PostScript
.90019 .37477 m
.90047 .37449 L
s
% Start of user PostScript
59. 24. 59.0185 23.9815 MAarrowhead1
% End of user PostScript
.9153 .37477 m
.9153 .37505 L
s
% Start of user PostScript
60. 24. 60. 24.0185 MAarrowhead1
% End of user PostScript
.9304 .37477 m
.9304 .37477 L
s
% Start of user PostScript
61. 24. MAarrowzero1
% End of user PostScript
.94551 .37477 m
.94551 .37505 L
s
% Start of user PostScript
62. 24. 62. 24.0185 MAarrowhead1
% End of user PostScript
.96061 .37477 m
.96033 .37477 L
s
% Start of user PostScript
63. 24. 62.9815 24. MAarrowhead1
% End of user PostScript
.97572 .37477 m
.97572 .37477 L
s
% Start of user PostScript
64. 24. MAarrowzero1
% End of user PostScript
.02409 .38988 m
.02409 .38988 L
s
% Start of user PostScript
1. 25. MAarrowzero1
% End of user PostScript
.03919 .38988 m
.03919 .3896 L
s
% Start of user PostScript
2. 25. 2. 24.9815 MAarrowhead1
% End of user PostScript
.0543 .38988 m
.05458 .3896 L
s
% Start of user PostScript
3. 25. 3.01851 24.9815 MAarrowhead1
% End of user PostScript
.0694 .38988 m
.0694 .38988 L
s
% Start of user PostScript
4. 25. MAarrowzero1
% End of user PostScript
.08451 .38988 m
.08479 .38988 L
s
% Start of user PostScript
5. 25. 5.01851 25. MAarrowhead1
% End of user PostScript
.09962 .38988 m
.09934 .38988 L
s
% Start of user PostScript
6. 25. 5.98149 25. MAarrowhead1
% End of user PostScript
.11472 .38988 m
.11472 .38988 L
s
% Start of user PostScript
7. 25. MAarrowzero1
% End of user PostScript
.12983 .38988 m
.12983 .39016 L
s
% Start of user PostScript
8. 25. 8. 25.0185 MAarrowhead1
% End of user PostScript
.14493 .38988 m
.14465 .39016 L
s
% Start of user PostScript
9. 25. 8.98149 25.0185 MAarrowhead1
% End of user PostScript
.16004 .38988 m
.16032 .3896 L
s
% Start of user PostScript
10. 25. 10.0185 24.9815 MAarrowhead1
% End of user PostScript
.17514 .38988 m
.17653 .39208 L
s
% Start of user PostScript
11. 25. 11.0921 25.1458 MAarrowhead1
% End of user PostScript
.19025 .38988 m
.19116 .39245 L
s
% Start of user PostScript
12. 25. 12.0607 25.1701 MAarrowhead1
% End of user PostScript
.20535 .38988 m
.20535 .39099 L
s
% Start of user PostScript
13. 25. 13. 25.0738 MAarrowhead1
% End of user PostScript
.22046 .38988 m
.22091 .39016 L
s
% Start of user PostScript
14. 25. 14.0302 25.0185 MAarrowhead1
% End of user PostScript
.23556 .38988 m
.23556 .38895 L
s
% Start of user PostScript
15. 25. 15. 24.9384 MAarrowhead1
% End of user PostScript
.25067 .38988 m
.25058 .38861 L
s
% Start of user PostScript
16. 25. 15.994 24.916 MAarrowhead1
% End of user PostScript
.26577 .38988 m
.26577 .3866 L
s
% Start of user PostScript
17. 25. 17. 24.7831 MAarrowhead1
% End of user PostScript
.28088 .38988 m
.28074 .39016 L
s
% Start of user PostScript
18. 25. 17.9906 25.0185 MAarrowhead1
% End of user PostScript
.29598 .38988 m
.2957 .38946 L
s
% Start of user PostScript
19. 25. 18.9815 24.9721 MAarrowhead1
% End of user PostScript
.31109 .38988 m
.31109 .38988 L
s
% Start of user PostScript
20. 25. MAarrowzero1
% End of user PostScript
.32619 .38988 m
.32647 .38955 L
s
% Start of user PostScript
21. 25. 21.0185 24.978 MAarrowhead1
% End of user PostScript
.3413 .38988 m
.3413 .39002 L
s
% Start of user PostScript
22. 25. 22. 25.0094 MAarrowhead1
% End of user PostScript
.3564 .38988 m
.3564 .38988 L
s
% Start of user PostScript
23. 25. MAarrowzero1
% End of user PostScript
.37151 .38988 m
.37151 .39021 L
s
% Start of user PostScript
24. 25. 24. 25.022 MAarrowhead1
% End of user PostScript
.38661 .38988 m
.38667 .3912 L
s
% Start of user PostScript
25. 25. 25.0035 25.0875 MAarrowhead1
% End of user PostScript
.40172 .38988 m
.40118 .39155 L
s
% Start of user PostScript
26. 25. 25.964 25.1106 MAarrowhead1
% End of user PostScript
.41682 .38988 m
.41649 .39117 L
s
% Start of user PostScript
27. 25. 26.978 25.0852 MAarrowhead1
% End of user PostScript
.43193 .38988 m
.43111 .39004 L
s
% Start of user PostScript
28. 25. 27.9455 25.0106 MAarrowhead1
% End of user PostScript
.44703 .38988 m
.4467 .39021 L
s
% Start of user PostScript
29. 25. 28.978 25.022 MAarrowhead1
% End of user PostScript
.46214 .38988 m
.46172 .3896 L
s
% Start of user PostScript
30. 25. 29.9721 24.9815 MAarrowhead1
% End of user PostScript
.47725 .38988 m
.47744 .38988 L
s
% Start of user PostScript
31. 25. 31.013 25. MAarrowhead1
% End of user PostScript
.49235 .38988 m
.49235 .38917 L
s
% Start of user PostScript
32. 25. 32. 24.9533 MAarrowhead1
% End of user PostScript
.50746 .38988 m
.5076 .39053 L
s
% Start of user PostScript
33. 25. 33.0094 25.0432 MAarrowhead1
% End of user PostScript
.52256 .38988 m
.52289 .39021 L
s
% Start of user PostScript
34. 25. 34.022 25.022 MAarrowhead1
% End of user PostScript
.53767 .38988 m
.538 .39037 L
s
% Start of user PostScript
35. 25. 35.022 25.0325 MAarrowhead1
% End of user PostScript
.55277 .38988 m
.55329 .39039 L
s
% Start of user PostScript
36. 25. 36.0341 25.0341 MAarrowhead1
% End of user PostScript
.56788 .38988 m
.56862 .38988 L
s
% Start of user PostScript
37. 25. 37.0496 25. MAarrowhead1
% End of user PostScript
.58298 .38988 m
.58373 .3903 L
s
% Start of user PostScript
38. 25. 38.0499 25.0282 MAarrowhead1
% End of user PostScript
.59809 .38988 m
.60063 .39153 L
s
% Start of user PostScript
39. 25. 39.1682 25.1095 MAarrowhead1
% End of user PostScript
.61319 .38988 m
.614 .38849 L
s
% Start of user PostScript
40. 25. 40.0538 24.9077 MAarrowhead1
% End of user PostScript
.6283 .38988 m
.62614 .38891 L
s
% Start of user PostScript
41. 25. 40.8575 24.9356 MAarrowhead1
% End of user PostScript
.6434 .38988 m
.64166 .38946 L
s
% Start of user PostScript
42. 25. 41.8846 24.9721 MAarrowhead1
% End of user PostScript
.65851 .38988 m
.65803 .39064 L
s
% Start of user PostScript
43. 25. 42.9686 25.0501 MAarrowhead1
% End of user PostScript
.67361 .38988 m
.67262 .38934 L
s
% Start of user PostScript
44. 25. 43.9345 24.9642 MAarrowhead1
% End of user PostScript
.68872 .38988 m
.68524 .38845 L
s
% Start of user PostScript
45. 25. 44.77 24.9054 MAarrowhead1
% End of user PostScript
.70382 .38988 m
.70326 .39034 L
s
% Start of user PostScript
46. 25. 45.9624 25.0302 MAarrowhead1
% End of user PostScript
.71893 .38988 m
.72114 .39153 L
s
% Start of user PostScript
47. 25. 47.1465 25.1094 MAarrowhead1
% End of user PostScript
.73403 .38988 m
.73643 .39112 L
s
% Start of user PostScript
48. 25. 48.1585 25.082 MAarrowhead1
% End of user PostScript
.74914 .38988 m
.74834 .39037 L
s
% Start of user PostScript
49. 25. 48.9474 25.0325 MAarrowhead1
% End of user PostScript
.76424 .38988 m
.76407 .38993 L
s
% Start of user PostScript
50. 25. 49.9885 25.0035 MAarrowhead1
% End of user PostScript
.77935 .38988 m
.7804 .39046 L
s
% Start of user PostScript
51. 25. 51.0699 25.0385 MAarrowhead1
% End of user PostScript
.79445 .38988 m
.79164 .38552 L
s
% Start of user PostScript
52. 25. 51.8136 24.7113 MAarrowhead1
% End of user PostScript
.80956 .38988 m
.80752 .3884 L
s
% Start of user PostScript
53. 25. 52.8649 24.9022 MAarrowhead1
% End of user PostScript
.82466 .38988 m
.82466 .38907 L
s
% Start of user PostScript
54. 25. 54. 24.9467 MAarrowhead1
% End of user PostScript
.83977 .38988 m
.83977 .3896 L
s
% Start of user PostScript
55. 25. 55. 24.9815 MAarrowhead1
% End of user PostScript
.85488 .38988 m
.85488 .38988 L
s
% Start of user PostScript
56. 25. MAarrowzero1
% End of user PostScript
.86998 .38988 m
.86998 .39016 L
s
% Start of user PostScript
57. 25. 57. 25.0185 MAarrowhead1
% End of user PostScript
.88509 .38988 m
.88536 .38988 L
s
% Start of user PostScript
58. 25. 58.0185 25. MAarrowhead1
% End of user PostScript
.90019 .38988 m
.90019 .38988 L
s
% Start of user PostScript
59. 25. MAarrowzero1
% End of user PostScript
.9153 .38988 m
.91558 .38988 L
s
% Start of user PostScript
60. 25. 60.0185 25. MAarrowhead1
% End of user PostScript
.9304 .38988 m
.9304 .39016 L
s
% Start of user PostScript
61. 25. 61. 25.0185 MAarrowhead1
% End of user PostScript
.94551 .38988 m
.94551 .38988 L
s
% Start of user PostScript
62. 25. MAarrowzero1
% End of user PostScript
.96061 .38988 m
.96033 .38988 L
s
% Start of user PostScript
63. 25. 62.9815 25. MAarrowhead1
% End of user PostScript
.97572 .38988 m
.97572 .38988 L
s
% Start of user PostScript
64. 25. MAarrowzero1
% End of user PostScript
.02409 .40498 m
.02437 .4047 L
s
% Start of user PostScript
1. 26. 1.01851 25.9815 MAarrowhead1
% End of user PostScript
.03919 .40498 m
.03919 .40498 L
s
% Start of user PostScript
2. 26. MAarrowzero1
% End of user PostScript
.0543 .40498 m
.0543 .40498 L
s
% Start of user PostScript
3. 26. MAarrowzero1
% End of user PostScript
.0694 .40498 m
.06968 .40498 L
s
% Start of user PostScript
4. 26. 4.01851 26. MAarrowhead1
% End of user PostScript
.08451 .40498 m
.08451 .40498 L
s
% Start of user PostScript
5. 26. MAarrowzero1
% End of user PostScript
.09962 .40498 m
.09962 .4047 L
s
% Start of user PostScript
6. 26. 6. 25.9815 MAarrowhead1
% End of user PostScript
.11472 .40498 m
.11472 .40498 L
s
% Start of user PostScript
7. 26. MAarrowzero1
% End of user PostScript
.12983 .40498 m
.12983 .40498 L
s
% Start of user PostScript
8. 26. MAarrowzero1
% End of user PostScript
.14493 .40498 m
.14531 .40498 L
s
% Start of user PostScript
9. 26. 9.02541 26. MAarrowhead1
% End of user PostScript
.16004 .40498 m
.16032 .40498 L
s
% Start of user PostScript
10. 26. 10.0185 26. MAarrowhead1
% End of user PostScript
.17514 .40498 m
.17724 .40857 L
s
% Start of user PostScript
11. 26. 11.1389 26.2377 MAarrowhead1
% End of user PostScript
.19025 .40498 m
.19109 .4078 L
s
% Start of user PostScript
12. 26. 12.0561 26.1862 MAarrowhead1
% End of user PostScript
.20535 .40498 m
.20549 .40611 L
s
% Start of user PostScript
13. 26. 13.0091 26.0746 MAarrowhead1
% End of user PostScript
.22046 .40498 m
.21953 .40534 L
s
% Start of user PostScript
14. 26. 13.9384 26.0235 MAarrowhead1
% End of user PostScript
.23556 .40498 m
.23607 .40405 L
s
% Start of user PostScript
15. 26. 15.0337 25.9384 MAarrowhead1
% End of user PostScript
.25067 .40498 m
.25055 .40625 L
s
% Start of user PostScript
16. 26. 15.9921 26.084 MAarrowhead1
% End of user PostScript
.26577 .40498 m
.25709 .39641 L
s
% Start of user PostScript
17. 26. 16.4255 25.4322 MAarrowhead1
% End of user PostScript
.28088 .40498 m
.28068 .40504 L
s
% Start of user PostScript
18. 26. 17.9871 26.0035 MAarrowhead1
% End of user PostScript
.29598 .40498 m
.29551 .4047 L
s
% Start of user PostScript
19. 26. 18.9686 25.9815 MAarrowhead1
% End of user PostScript
.31109 .40498 m
.31081 .40465 L
s
% Start of user PostScript
20. 26. 19.9815 25.978 MAarrowhead1
% End of user PostScript
.32619 .40498 m
.32652 .40498 L
s
% Start of user PostScript
21. 26. 21.022 26. MAarrowhead1
% End of user PostScript
.3413 .40498 m
.34149 .40498 L
s
% Start of user PostScript
22. 26. 22.0129 26. MAarrowhead1
% End of user PostScript
.3564 .40498 m
.35612 .40474 L
s
% Start of user PostScript
23. 26. 22.9815 25.9836 MAarrowhead1
% End of user PostScript
.37151 .40498 m
.36941 .40881 L
s
% Start of user PostScript
24. 26. 23.8613 26.2534 MAarrowhead1
% End of user PostScript
.38661 .40498 m
.38774 .40428 L
s
% Start of user PostScript
25. 26. 25.0746 25.9533 MAarrowhead1
% End of user PostScript
.40172 .40498 m
.40311 .40554 L
s
% Start of user PostScript
26. 26. 26.0921 26.037 MAarrowhead1
% End of user PostScript
.41682 .40498 m
.41336 .40845 L
s
% Start of user PostScript
27. 26. 26.7706 26.2294 MAarrowhead1
% End of user PostScript
.43193 .40498 m
.43033 .40484 L
s
% Start of user PostScript
28. 26. 27.894 25.9906 MAarrowhead1
% End of user PostScript
.44703 .40498 m
.44423 .40588 L
s
% Start of user PostScript
29. 26. 28.8145 26.0595 MAarrowhead1
% End of user PostScript
.46214 .40498 m
.4616 .40493 L
s
% Start of user PostScript
30. 26. 29.964 25.9965 MAarrowhead1
% End of user PostScript
.47725 .40498 m
.4779 .40461 L
s
% Start of user PostScript
31. 26. 31.0432 25.9753 MAarrowhead1
% End of user PostScript
.49235 .40498 m
.4924 .40493 L
s
% Start of user PostScript
32. 26. 32.0035 25.9965 MAarrowhead1
% End of user PostScript
.50746 .40498 m
.50816 .40498 L
s
% Start of user PostScript
33. 26. 33.0467 26. MAarrowhead1
% End of user PostScript
.52256 .40498 m
.52261 .40578 L
s
% Start of user PostScript
34. 26. 34.0035 26.0526 MAarrowhead1
% End of user PostScript
.53767 .40498 m
.53788 .40504 L
s
% Start of user PostScript
35. 26. 35.014 26.0035 MAarrowhead1
% End of user PostScript
.55277 .40498 m
.55329 .40498 L
s
% Start of user PostScript
36. 26. 36.0341 26. MAarrowhead1
% End of user PostScript
.56788 .40498 m
.56793 .40504 L
s
% Start of user PostScript
37. 26. 37.0035 26.0035 MAarrowhead1
% End of user PostScript
.58298 .40498 m
.58373 .40504 L
s
% Start of user PostScript
38. 26. 38.0499 26.0035 MAarrowhead1
% End of user PostScript
.59809 .40498 m
.59937 .40612 L
s
% Start of user PostScript
39. 26. 39.0851 26.0753 MAarrowhead1
% End of user PostScript
.61319 .40498 m
.61647 .40689 L
s
% Start of user PostScript
40. 26. 40.217 26.126 MAarrowhead1
% End of user PostScript
.6283 .40498 m
.62617 .40428 L
s
% Start of user PostScript
41. 26. 40.8591 25.9533 MAarrowhead1
% End of user PostScript
.6434 .40498 m
.64136 .40493 L
s
% Start of user PostScript
42. 26. 41.8646 25.9965 MAarrowhead1
% End of user PostScript
.65851 .40498 m
.65671 .40357 L
s
% Start of user PostScript
43. 26. 42.8811 25.9066 MAarrowhead1
% End of user PostScript
.67361 .40498 m
.674 .40606 L
s
% Start of user PostScript
44. 26. 44.0258 26.071 MAarrowhead1
% End of user PostScript
.68872 .40498 m
.68528 .40396 L
s
% Start of user PostScript
45. 26. 44.7725 25.9322 MAarrowhead1
% End of user PostScript
.70382 .40498 m
.70272 .40285 L
s
% Start of user PostScript
46. 26. 45.9267 25.8588 MAarrowhead1
% End of user PostScript
.71893 .40498 m
.71954 .40671 L
s
% Start of user PostScript
47. 26. 47.0408 26.114 MAarrowhead1
% End of user PostScript
.73403 .40498 m
.7337 .40514 L
s
% Start of user PostScript
48. 26. 47.9776 26.0106 MAarrowhead1
% End of user PostScript
.74914 .40498 m
.74688 .40498 L
s
% Start of user PostScript
49. 26. 48.8507 26. MAarrowhead1
% End of user PostScript
.76424 .40498 m
.76296 .4037 L
s
% Start of user PostScript
50. 26. 49.9148 25.9149 MAarrowhead1
% End of user PostScript
.77935 .40498 m
.77949 .40518 L
s
% Start of user PostScript
51. 26. 51.0092 26.0127 MAarrowhead1
% End of user PostScript
.79445 .40498 m
.7959 .40585 L
s
% Start of user PostScript
52. 26. 52.096 26.0572 MAarrowhead1
% End of user PostScript
.80956 .40498 m
.81046 .40671 L
s
% Start of user PostScript
53. 26. 53.0595 26.114 MAarrowhead1
% End of user PostScript
.82466 .40498 m
.82466 .40295 L
s
% Start of user PostScript
54. 26. 54. 25.8652 MAarrowhead1
% End of user PostScript
.83977 .40498 m
.83977 .40498 L
s
% Start of user PostScript
55. 26. MAarrowzero1
% End of user PostScript
.85488 .40498 m
.85488 .40498 L
s
% Start of user PostScript
56. 26. MAarrowzero1
% End of user PostScript
.86998 .40498 m
.87026 .40498 L
s
% Start of user PostScript
57. 26. 57.0185 26. MAarrowhead1
% End of user PostScript
.88509 .40498 m
.88509 .40498 L
s
% Start of user PostScript
58. 26. MAarrowzero1
% End of user PostScript
.90019 .40498 m
.90019 .40498 L
s
% Start of user PostScript
59. 26. MAarrowzero1
% End of user PostScript
.9153 .40498 m
.9153 .40498 L
s
% Start of user PostScript
60. 26. MAarrowzero1
% End of user PostScript
.9304 .40498 m
.9304 .40498 L
s
% Start of user PostScript
61. 26. MAarrowzero1
% End of user PostScript
.94551 .40498 m
.94551 .40498 L
s
% Start of user PostScript
62. 26. MAarrowzero1
% End of user PostScript
.96061 .40498 m
.96061 .4047 L
s
% Start of user PostScript
63. 26. 63. 25.9815 MAarrowhead1
% End of user PostScript
.97572 .40498 m
.97572 .40526 L
s
% Start of user PostScript
64. 26. 64. 26.0185 MAarrowhead1
% End of user PostScript
.02409 .42009 m
.02437 .41981 L
s
% Start of user PostScript
1. 27. 1.01851 26.9815 MAarrowhead1
% End of user PostScript
.03919 .42009 m
.03919 .41981 L
s
% Start of user PostScript
2. 27. 2. 26.9815 MAarrowhead1
% End of user PostScript
.0543 .42009 m
.05458 .41981 L
s
% Start of user PostScript
3. 27. 3.01851 26.9815 MAarrowhead1
% End of user PostScript
.0694 .42009 m
.0694 .42037 L
s
% Start of user PostScript
4. 27. 4. 27.0185 MAarrowhead1
% End of user PostScript
.08451 .42009 m
.08451 .42009 L
s
% Start of user PostScript
5. 27. MAarrowzero1
% End of user PostScript
.09962 .42009 m
.09962 .42009 L
s
% Start of user PostScript
6. 27. MAarrowzero1
% End of user PostScript
.11472 .42009 m
.115 .42009 L
s
% Start of user PostScript
7. 27. 7.01851 27. MAarrowhead1
% End of user PostScript
.12983 .42009 m
.12983 .42009 L
s
% Start of user PostScript
8. 27. MAarrowzero1
% End of user PostScript
.14493 .42009 m
.14455 .42009 L
s
% Start of user PostScript
9. 27. 8.97459 27. MAarrowhead1
% End of user PostScript
.16004 .42009 m
.16032 .42009 L
s
% Start of user PostScript
10. 27. 10.0185 27. MAarrowhead1
% End of user PostScript
.17514 .42009 m
.17868 .4245 L
s
% Start of user PostScript
11. 27. 11.2342 27.2922 MAarrowhead1
% End of user PostScript
.19025 .42009 m
.19025 .42151 L
s
% Start of user PostScript
12. 27. 12. 27.0942 MAarrowhead1
% End of user PostScript
.20535 .42009 m
.20442 .42174 L
s
% Start of user PostScript
13. 27. 12.9384 27.1095 MAarrowhead1
% End of user PostScript
.22046 .42009 m
.2216 .42051 L
s
% Start of user PostScript
14. 27. 14.0756 27.0279 MAarrowhead1
% End of user PostScript
.23556 .42009 m
.23556 .41955 L
s
% Start of user PostScript
15. 27. 15. 26.964 MAarrowhead1
% End of user PostScript
.25067 .42009 m
.25044 .4209 L
s
% Start of user PostScript
16. 27. 15.9847 27.0538 MAarrowhead1
% End of user PostScript
.26577 .42009 m
.2613 .41352 L
s
% Start of user PostScript
17. 27. 16.704 26.5651 MAarrowhead1
% End of user PostScript
.28088 .42009 m
.28074 .4199 L
s
% Start of user PostScript
18. 27. 17.9909 26.9871 MAarrowhead1
% End of user PostScript
.29598 .42009 m
.29537 .41984 L
s
% Start of user PostScript
19. 27. 18.9595 26.9836 MAarrowhead1
% End of user PostScript
.31109 .42009 m
.3117 .41976 L
s
% Start of user PostScript
20. 27. 20.0405 26.978 MAarrowhead1
% End of user PostScript
.32619 .42009 m
.3268 .42017 L
s
% Start of user PostScript
21. 27. 21.0405 27.0055 MAarrowhead1
% End of user PostScript
.3413 .42009 m
.34149 .42009 L
s
% Start of user PostScript
22. 27. 22.0129 27. MAarrowhead1
% End of user PostScript
.3564 .42009 m
.35579 .41976 L
s
% Start of user PostScript
23. 27. 22.9595 26.978 MAarrowhead1
% End of user PostScript
.37151 .42009 m
.37151 .4197 L
s
% Start of user PostScript
24. 27. 24. 26.9742 MAarrowhead1
% End of user PostScript
.38661 .42009 m
.38714 .41956 L
s
% Start of user PostScript
25. 27. 25.0349 26.9651 MAarrowhead1
% End of user PostScript
.40172 .42009 m
.40281 .42014 L
s
% Start of user PostScript
26. 27. 26.0724 27.0035 MAarrowhead1
% End of user PostScript
.41682 .42009 m
.41726 .41983 L
s
% Start of user PostScript
27. 27. 27.0291 26.9825 MAarrowhead1
% End of user PostScript
.43193 .42009 m
.4317 .4202 L
s
% Start of user PostScript
28. 27. 27.9849 27.0071 MAarrowhead1
% End of user PostScript
.44703 .42009 m
.44874 .42009 L
s
% Start of user PostScript
29. 27. 29.1129 27. MAarrowhead1
% End of user PostScript
.46214 .42009 m
.46126 .41856 L
s
% Start of user PostScript
30. 27. 29.942 26.8985 MAarrowhead1
% End of user PostScript
.47725 .42009 m
.47725 .42009 L
s
% Start of user PostScript
31. 27. MAarrowzero1
% End of user PostScript
.49235 .42009 m
.49254 .42009 L
s
% Start of user PostScript
32. 27. 32.0129 27. MAarrowhead1
% End of user PostScript
.50746 .42009 m
.50816 .42009 L
s
% Start of user PostScript
33. 27. 33.0467 27. MAarrowhead1
% End of user PostScript
.52256 .42009 m
.52191 .42074 L
s
% Start of user PostScript
34. 27. 33.9568 27.0432 MAarrowhead1
% End of user PostScript
.53767 .42009 m
.53819 .42023 L
s
% Start of user PostScript
35. 27. 35.0348 27.0094 MAarrowhead1
% End of user PostScript
.55277 .42009 m
.55326 .42009 L
s
% Start of user PostScript
36. 27. 36.0325 27. MAarrowhead1
% End of user PostScript
.56788 .42009 m
.56854 .42084 L
s
% Start of user PostScript
37. 27. 37.0442 27.0496 MAarrowhead1
% End of user PostScript
.58298 .42009 m
.58351 .42084 L
s
% Start of user PostScript
38. 27. 38.0351 27.0499 MAarrowhead1
% End of user PostScript
.59809 .42009 m
.59886 .42125 L
s
% Start of user PostScript
39. 27. 39.0514 27.0768 MAarrowhead1
% End of user PostScript
.61319 .42009 m
.61837 .42481 L
s
% Start of user PostScript
40. 27. 40.3429 27.3127 MAarrowhead1
% End of user PostScript
.6283 .42009 m
.62796 .42009 L
s
% Start of user PostScript
41. 27. 40.9776 27. MAarrowhead1
% End of user PostScript
.6434 .42009 m
.64301 .41878 L
s
% Start of user PostScript
42. 27. 41.9742 26.9136 MAarrowhead1
% End of user PostScript
.65851 .42009 m
.65944 .42154 L
s
% Start of user PostScript
43. 27. 43.062 27.0957 MAarrowhead1
% End of user PostScript
.67361 .42009 m
.67508 .42188 L
s
% Start of user PostScript
44. 27. 44.0969 27.1188 MAarrowhead1
% End of user PostScript
.68872 .42009 m
.69177 .42266 L
s
% Start of user PostScript
45. 27. 45.2018 27.17 MAarrowhead1
% End of user PostScript
.70382 .42009 m
.70401 .4219 L
s
% Start of user PostScript
46. 27. 46.0125 27.12 MAarrowhead1
% End of user PostScript
.71893 .42009 m
.71791 .41784 L
s
% Start of user PostScript
47. 27. 46.9326 26.8511 MAarrowhead1
% End of user PostScript
.73403 .42009 m
.73324 .41929 L
s
% Start of user PostScript
48. 27. 47.9474 26.9474 MAarrowhead1
% End of user PostScript
.74914 .42009 m
.74914 .41898 L
s
% Start of user PostScript
49. 27. 49. 26.9267 MAarrowhead1
% End of user PostScript
.76424 .42009 m
.76333 .41965 L
s
% Start of user PostScript
50. 27. 49.9395 26.9711 MAarrowhead1
% End of user PostScript
.77935 .42009 m
.77807 .41872 L
s
% Start of user PostScript
51. 27. 50.9151 26.9091 MAarrowhead1
% End of user PostScript
.79445 .42009 m
.79592 .4206 L
s
% Start of user PostScript
52. 27. 52.0969 27.0337 MAarrowhead1
% End of user PostScript
.80956 .42009 m
.8073 .41666 L
s
% Start of user PostScript
53. 27. 52.8507 26.7731 MAarrowhead1
% End of user PostScript
.82466 .42009 m
.82494 .42037 L
s
% Start of user PostScript
54. 27. 54.0185 27.0185 MAarrowhead1
% End of user PostScript
.83977 .42009 m
.83977 .42009 L
s
% Start of user PostScript
55. 27. MAarrowzero1
% End of user PostScript
.85488 .42009 m
.85488 .42009 L
s
% Start of user PostScript
56. 27. MAarrowzero1
% End of user PostScript
.86998 .42009 m
.87026 .42009 L
s
% Start of user PostScript
57. 27. 57.0185 27. MAarrowhead1
% End of user PostScript
.88509 .42009 m
.88509 .42037 L
s
% Start of user PostScript
58. 27. 58. 27.0185 MAarrowhead1
% End of user PostScript
.90019 .42009 m
.90019 .42009 L
s
% Start of user PostScript
59. 27. MAarrowzero1
% End of user PostScript
.9153 .42009 m
.9153 .41981 L
s
% Start of user PostScript
60. 27. 60. 26.9815 MAarrowhead1
% End of user PostScript
.9304 .42009 m
.9304 .42009 L
s
% Start of user PostScript
61. 27. MAarrowzero1
% End of user PostScript
.94551 .42009 m
.94551 .42009 L
s
% Start of user PostScript
62. 27. MAarrowzero1
% End of user PostScript
.96061 .42009 m
.96089 .42009 L
s
% Start of user PostScript
63. 27. 63.0185 27. MAarrowhead1
% End of user PostScript
.97572 .42009 m
.97572 .42009 L
s
% Start of user PostScript
64. 27. MAarrowzero1
% End of user PostScript
.02409 .43519 m
.02409 .43519 L
s
% Start of user PostScript
1. 28. MAarrowzero1
% End of user PostScript
.03919 .43519 m
.03919 .43519 L
s
% Start of user PostScript
2. 28. MAarrowzero1
% End of user PostScript
.0543 .43519 m
.0543 .43492 L
s
% Start of user PostScript
3. 28. 3. 27.9815 MAarrowhead1
% End of user PostScript
.0694 .43519 m
.0694 .43492 L
s
% Start of user PostScript
4. 28. 4. 27.9815 MAarrowhead1
% End of user PostScript
.08451 .43519 m
.08451 .43547 L
s
% Start of user PostScript
5. 28. 5. 28.0185 MAarrowhead1
% End of user PostScript
.09962 .43519 m
.09989 .43547 L
s
% Start of user PostScript
6. 28. 6.01851 28.0185 MAarrowhead1
% End of user PostScript
.11472 .43519 m
.11444 .43519 L
s
% Start of user PostScript
7. 28. 6.98149 28. MAarrowhead1
% End of user PostScript
.12983 .43519 m
.12983 .43509 L
s
% Start of user PostScript
8. 28. 8. 27.9931 MAarrowhead1
% End of user PostScript
.14493 .43519 m
.14521 .43492 L
s
% Start of user PostScript
9. 28. 9.01851 27.9815 MAarrowhead1
% End of user PostScript
.16004 .43519 m
.16032 .43558 L
s
% Start of user PostScript
10. 28. 10.0185 28.0254 MAarrowhead1
% End of user PostScript
.17514 .43519 m
.1769 .44127 L
s
% Start of user PostScript
11. 28. 11.1165 28.4022 MAarrowhead1
% End of user PostScript
.19025 .43519 m
.19067 .43715 L
s
% Start of user PostScript
12. 28. 12.0282 28.1294 MAarrowhead1
% End of user PostScript
.20535 .43519 m
.20493 .43611 L
s
% Start of user PostScript
13. 28. 12.9721 28.0605 MAarrowhead1
% End of user PostScript
.22046 .43519 m
.2203 .43498 L
s
% Start of user PostScript
14. 28. 13.9894 27.986 MAarrowhead1
% End of user PostScript
.23556 .43519 m
.23589 .43811 L
s
% Start of user PostScript
15. 28. 15.022 28.1927 MAarrowhead1
% End of user PostScript
.25067 .43519 m
.2501 .43576 L
s
% Start of user PostScript
16. 28. 15.9628 28.0373 MAarrowhead1
% End of user PostScript
.26577 .43519 m
.26572 .43491 L
s
% Start of user PostScript
17. 28. 16.9965 27.9812 MAarrowhead1
% End of user PostScript
.28088 .43519 m
.28079 .43547 L
s
% Start of user PostScript
18. 28. 17.994 28.0185 MAarrowhead1
% End of user PostScript
.29598 .43519 m
.29598 .43519 L
s
% Start of user PostScript
19. 28. MAarrowzero1
% End of user PostScript
.31109 .43519 m
.31109 .43519 L
s
% Start of user PostScript
20. 28. MAarrowzero1
% End of user PostScript
.32619 .43519 m
.32628 .43519 L
s
% Start of user PostScript
21. 28. 21.0055 28. MAarrowhead1
% End of user PostScript
.3413 .43519 m
.34191 .43519 L
s
% Start of user PostScript
22. 28. 22.0405 28. MAarrowhead1
% End of user PostScript
.3564 .43519 m
.35607 .43472 L
s
% Start of user PostScript
23. 28. 22.978 27.9686 MAarrowhead1
% End of user PostScript
.37151 .43519 m
.37098 .43528 L
s
% Start of user PostScript
24. 28. 23.9651 28.0055 MAarrowhead1
% End of user PostScript
.38661 .43519 m
.38661 .43572 L
s
% Start of user PostScript
25. 28. 25. 28.0348 MAarrowhead1
% End of user PostScript
.40172 .43519 m
.40219 .43539 L
s
% Start of user PostScript
26. 28. 26.0314 28.0129 MAarrowhead1
% End of user PostScript
.41682 .43519 m
.41682 .4365 L
s
% Start of user PostScript
27. 28. 27. 28.0863 MAarrowhead1
% End of user PostScript
.43193 .43519 m
.43155 .43513 L
s
% Start of user PostScript
28. 28. 27.9746 27.9955 MAarrowhead1
% End of user PostScript
.44703 .43519 m
.44694 .43514 L
s
% Start of user PostScript
29. 28. 28.994 27.9965 MAarrowhead1
% End of user PostScript
.46214 .43519 m
.462 .43402 L
s
% Start of user PostScript
30. 28. 29.9906 27.922 MAarrowhead1
% End of user PostScript
.47725 .43519 m
.4773 .43514 L
s
% Start of user PostScript
31. 28. 31.0035 27.9965 MAarrowhead1
% End of user PostScript
.49235 .43519 m
.49268 .435 L
s
% Start of user PostScript
32. 28. 32.022 27.9871 MAarrowhead1
% End of user PostScript
.50746 .43519 m
.50746 .43539 L
s
% Start of user PostScript
33. 28. 33. 28.0129 MAarrowhead1
% End of user PostScript
.52256 .43519 m
.52256 .43514 L
s
% Start of user PostScript
34. 28. 34. 27.9965 MAarrowhead1
% End of user PostScript
.53767 .43519 m
.53832 .43519 L
s
% Start of user PostScript
35. 28. 35.0432 28. MAarrowhead1
% End of user PostScript
.55277 .43519 m
.55282 .43525 L
s
% Start of user PostScript
36. 28. 36.0035 28.0035 MAarrowhead1
% End of user PostScript
.56788 .43519 m
.56858 .43519 L
s
% Start of user PostScript
37. 28. 37.0467 28. MAarrowhead1
% End of user PostScript
.58298 .43519 m
.58416 .4359 L
s
% Start of user PostScript
38. 28. 38.0778 28.0464 MAarrowhead1
% End of user PostScript
.59809 .43519 m
.59894 .43567 L
s
% Start of user PostScript
39. 28. 39.0568 28.0314 MAarrowhead1
% End of user PostScript
.61319 .43519 m
.61711 .43634 L
s
% Start of user PostScript
40. 28. 40.2594 28.0758 MAarrowhead1
% End of user PostScript
.6283 .43519 m
.62701 .434 L
s
% Start of user PostScript
41. 28. 40.9149 27.9207 MAarrowhead1
% End of user PostScript
.6434 .43519 m
.64421 .43405 L
s
% Start of user PostScript
42. 28. 42.0538 27.9243 MAarrowhead1
% End of user PostScript
.65851 .43519 m
.65856 .43574 L
s
% Start of user PostScript
43. 28. 43.0035 28.0358 MAarrowhead1
% End of user PostScript
.67361 .43519 m
.67543 .43715 L
s
% Start of user PostScript
44. 28. 44.12 28.1294 MAarrowhead1
% End of user PostScript
.68872 .43519 m
.68819 .43578 L
s
% Start of user PostScript
45. 28. 44.9647 28.0385 MAarrowhead1
% End of user PostScript
.70382 .43519 m
.70209 .4341 L
s
% Start of user PostScript
46. 28. 45.8854 27.9278 MAarrowhead1
% End of user PostScript
.71893 .43519 m
.71795 .4348 L
s
% Start of user PostScript
47. 28. 46.9349 27.9742 MAarrowhead1
% End of user PostScript
.73403 .43519 m
.73772 .43748 L
s
% Start of user PostScript
48. 28. 48.2439 28.1514 MAarrowhead1
% End of user PostScript
.74914 .43519 m
.74961 .43677 L
s
% Start of user PostScript
49. 28. 49.0314 28.104 MAarrowhead1
% End of user PostScript
.76424 .43519 m
.76424 .43391 L
s
% Start of user PostScript
50. 28. 50. 27.9148 MAarrowhead1
% End of user PostScript
.77935 .43519 m
.77892 .43371 L
s
% Start of user PostScript
51. 28. 50.9718 27.902 MAarrowhead1
% End of user PostScript
.79445 .43519 m
.79169 .43402 L
s
% Start of user PostScript
52. 28. 51.817 27.9224 MAarrowhead1
% End of user PostScript
.80956 .43519 m
.80956 .43519 L
s
% Start of user PostScript
53. 28. MAarrowzero1
% End of user PostScript
.82466 .43519 m
.82466 .43547 L
s
% Start of user PostScript
54. 28. 54. 28.0185 MAarrowhead1
% End of user PostScript
.83977 .43519 m
.83949 .43547 L
s
% Start of user PostScript
55. 28. 54.9815 28.0185 MAarrowhead1
% End of user PostScript
.85488 .43519 m
.85488 .43519 L
s
% Start of user PostScript
56. 28. MAarrowzero1
% End of user PostScript
.86998 .43519 m
.87026 .43519 L
s
% Start of user PostScript
57. 28. 57.0185 28. MAarrowhead1
% End of user PostScript
.88509 .43519 m
.88509 .43519 L
s
% Start of user PostScript
58. 28. MAarrowzero1
% End of user PostScript
.90019 .43519 m
.90019 .43519 L
s
% Start of user PostScript
59. 28. MAarrowzero1
% End of user PostScript
.9153 .43519 m
.9153 .43519 L
s
% Start of user PostScript
60. 28. MAarrowzero1
% End of user PostScript
.9304 .43519 m
.9304 .43519 L
s
% Start of user PostScript
61. 28. MAarrowzero1
% End of user PostScript
.94551 .43519 m
.94551 .43547 L
s
% Start of user PostScript
62. 28. 62. 28.0185 MAarrowhead1
% End of user PostScript
.96061 .43519 m
.96061 .43519 L
s
% Start of user PostScript
63. 28. MAarrowzero1
% End of user PostScript
.97572 .43519 m
.97572 .43519 L
s
% Start of user PostScript
64. 28. MAarrowzero1
% End of user PostScript
.02409 .4503 m
.02437 .45002 L
s
% Start of user PostScript
1. 29. 1.01851 28.9815 MAarrowhead1
% End of user PostScript
.03919 .4503 m
.03919 .45002 L
s
% Start of user PostScript
2. 29. 2. 28.9815 MAarrowhead1
% End of user PostScript
.0543 .4503 m
.0543 .45058 L
s
% Start of user PostScript
3. 29. 3. 29.0185 MAarrowhead1
% End of user PostScript
.0694 .4503 m
.0694 .45002 L
s
% Start of user PostScript
4. 29. 4. 28.9815 MAarrowhead1
% End of user PostScript
.08451 .4503 m
.08451 .4503 L
s
% Start of user PostScript
5. 29. MAarrowzero1
% End of user PostScript
.09962 .4503 m
.09962 .4503 L
s
% Start of user PostScript
6. 29. MAarrowzero1
% End of user PostScript
.11472 .4503 m
.11472 .4503 L
s
% Start of user PostScript
7. 29. MAarrowzero1
% End of user PostScript
.12983 .4503 m
.12983 .4503 L
s
% Start of user PostScript
8. 29. MAarrowzero1
% End of user PostScript
.14493 .4503 m
.14465 .45058 L
s
% Start of user PostScript
9. 29. 8.98149 29.0185 MAarrowhead1
% End of user PostScript
.16004 .4503 m
.16018 .45058 L
s
% Start of user PostScript
10. 29. 10.0094 29.0185 MAarrowhead1
% End of user PostScript
.17514 .4503 m
.17715 .45273 L
s
% Start of user PostScript
11. 29. 11.1329 29.161 MAarrowhead1
% End of user PostScript
.19025 .4503 m
.19118 .45046 L
s
% Start of user PostScript
12. 29. 12.0616 29.0106 MAarrowhead1
% End of user PostScript
.20535 .4503 m
.20568 .45093 L
s
% Start of user PostScript
13. 29. 13.022 29.042 MAarrowhead1
% End of user PostScript
.22046 .4503 m
.22046 .4503 L
s
% Start of user PostScript
14. 29. MAarrowzero1
% End of user PostScript
.23556 .4503 m
.23556 .44977 L
s
% Start of user PostScript
15. 29. 15. 28.9651 MAarrowhead1
% End of user PostScript
.25067 .4503 m
.24985 .44234 L
s
% Start of user PostScript
16. 29. 15.9462 28.4733 MAarrowhead1
% End of user PostScript
.26577 .4503 m
.26563 .44997 L
s
% Start of user PostScript
17. 29. 16.9906 28.978 MAarrowhead1
% End of user PostScript
.28088 .4503 m
.28096 .45038 L
s
% Start of user PostScript
18. 29. 18.0055 29.0055 MAarrowhead1
% End of user PostScript
.29598 .4503 m
.29598 .4503 L
s
% Start of user PostScript
19. 29. MAarrowzero1
% End of user PostScript
.31109 .4503 m
.31109 .44983 L
s
% Start of user PostScript
20. 29. 20. 28.9686 MAarrowhead1
% End of user PostScript
.32619 .4503 m
.32667 .44983 L
s
% Start of user PostScript
21. 29. 21.0314 28.9686 MAarrowhead1
% End of user PostScript
.3413 .4503 m
.34121 .45022 L
s
% Start of user PostScript
22. 29. 21.9945 28.9945 MAarrowhead1
% End of user PostScript
.3564 .4503 m
.35701 .4503 L
s
% Start of user PostScript
23. 29. 23.0405 29. MAarrowhead1
% End of user PostScript
.37151 .4503 m
.37179 .45063 L
s
% Start of user PostScript
24. 29. 24.0185 29.022 MAarrowhead1
% End of user PostScript
.38661 .4503 m
.38723 .4503 L
s
% Start of user PostScript
25. 29. 25.0405 29. MAarrowhead1
% End of user PostScript
.40172 .4503 m
.40242 .45106 L
s
% Start of user PostScript
26. 29. 26.0467 29.0501 MAarrowhead1
% End of user PostScript
.41682 .4503 m
.4173 .45079 L
s
% Start of user PostScript
27. 29. 27.0314 29.0325 MAarrowhead1
% End of user PostScript
.43193 .4503 m
.43188 .44981 L
s
% Start of user PostScript
28. 29. 27.9965 28.9675 MAarrowhead1
% End of user PostScript
.44703 .4503 m
.44703 .44947 L
s
% Start of user PostScript
29. 29. 29. 28.9451 MAarrowhead1
% End of user PostScript
.46214 .4503 m
.46214 .44997 L
s
% Start of user PostScript
30. 29. 30. 28.978 MAarrowhead1
% End of user PostScript
.47725 .4503 m
.47725 .45011 L
s
% Start of user PostScript
31. 29. 31. 28.9871 MAarrowhead1
% End of user PostScript
.49235 .4503 m
.49207 .44969 L
s
% Start of user PostScript
32. 29. 31.9815 28.9595 MAarrowhead1
% End of user PostScript
.50746 .4503 m
.50765 .45016 L
s
% Start of user PostScript
33. 29. 33.0125 28.9906 MAarrowhead1
% End of user PostScript
.52256 .4503 m
.52266 .4503 L
s
% Start of user PostScript
34. 29. 34.0069 29. MAarrowhead1
% End of user PostScript
.53767 .4503 m
.53837 .451 L
s
% Start of user PostScript
35. 29. 35.0467 29.0467 MAarrowhead1
% End of user PostScript
.55277 .4503 m
.5531 .45044 L
s
% Start of user PostScript
36. 29. 36.022 29.0094 MAarrowhead1
% End of user PostScript
.56788 .4503 m
.5684 .45079 L
s
% Start of user PostScript
37. 29. 37.0348 29.0325 MAarrowhead1
% End of user PostScript
.58298 .4503 m
.58351 .45087 L
s
% Start of user PostScript
38. 29. 38.0348 29.0376 MAarrowhead1
% End of user PostScript
.59809 .4503 m
.59924 .45159 L
s
% Start of user PostScript
39. 29. 39.0761 29.0852 MAarrowhead1
% End of user PostScript
.61319 .4503 m
.61479 .45077 L
s
% Start of user PostScript
40. 29. 40.106 29.0314 MAarrowhead1
% End of user PostScript
.6283 .4503 m
.62763 .45044 L
s
% Start of user PostScript
41. 29. 40.9556 29.0094 MAarrowhead1
% End of user PostScript
.6434 .4503 m
.64231 .4503 L
s
% Start of user PostScript
42. 29. 41.9278 29. MAarrowhead1
% End of user PostScript
.65851 .4503 m
.65856 .44919 L
s
% Start of user PostScript
43. 29. 43.0035 28.9262 MAarrowhead1
% End of user PostScript
.67361 .4503 m
.67205 .44974 L
s
% Start of user PostScript
44. 29. 43.8964 28.9627 MAarrowhead1
% End of user PostScript
.68872 .4503 m
.68979 .4503 L
s
% Start of user PostScript
45. 29. 45.071 29. MAarrowhead1
% End of user PostScript
.70382 .4503 m
.70225 .44829 L
s
% Start of user PostScript
46. 29. 45.896 28.8667 MAarrowhead1
% End of user PostScript
.71893 .4503 m
.71803 .44893 L
s
% Start of user PostScript
47. 29. 46.9405 28.9091 MAarrowhead1
% End of user PostScript
.73403 .4503 m
.73851 .45525 L
s
% Start of user PostScript
48. 29. 48.2961 29.3275 MAarrowhead1
% End of user PostScript
.74914 .4503 m
.7512 .45195 L
s
% Start of user PostScript
49. 29. 49.1365 29.1095 MAarrowhead1
% End of user PostScript
.76424 .4503 m
.76424 .45049 L
s
% Start of user PostScript
50. 29. 50. 29.0125 MAarrowhead1
% End of user PostScript
.77935 .4503 m
.77898 .44844 L
s
% Start of user PostScript
51. 29. 50.9755 28.8765 MAarrowhead1
% End of user PostScript
.79445 .4503 m
.79248 .44804 L
s
% Start of user PostScript
52. 29. 51.8692 28.8507 MAarrowhead1
% End of user PostScript
.80956 .4503 m
.80956 .4503 L
s
% Start of user PostScript
53. 29. MAarrowzero1
% End of user PostScript
.82466 .4503 m
.82466 .4503 L
s
% Start of user PostScript
54. 29. MAarrowzero1
% End of user PostScript
.83977 .4503 m
.83977 .4503 L
s
% Start of user PostScript
55. 29. MAarrowzero1
% End of user PostScript
.85488 .4503 m
.85488 .4503 L
s
% Start of user PostScript
56. 29. MAarrowzero1
% End of user PostScript
.86998 .4503 m
.86998 .4503 L
s
% Start of user PostScript
57. 29. MAarrowzero1
% End of user PostScript
.88509 .4503 m
.88509 .4503 L
s
% Start of user PostScript
58. 29. MAarrowzero1
% End of user PostScript
.90019 .4503 m
.90019 .4503 L
s
% Start of user PostScript
59. 29. MAarrowzero1
% End of user PostScript
.9153 .4503 m
.9153 .45002 L
s
% Start of user PostScript
60. 29. 60. 28.9815 MAarrowhead1
% End of user PostScript
.9304 .4503 m
.9304 .4503 L
s
% Start of user PostScript
61. 29. MAarrowzero1
% End of user PostScript
.94551 .4503 m
.94579 .4503 L
s
% Start of user PostScript
62. 29. 62.0185 29. MAarrowhead1
% End of user PostScript
.96061 .4503 m
.96061 .45002 L
s
% Start of user PostScript
63. 29. 63. 28.9815 MAarrowhead1
% End of user PostScript
.97572 .4503 m
.97572 .45058 L
s
% Start of user PostScript
64. 29. 64. 29.0185 MAarrowhead1
% End of user PostScript
.02409 .46541 m
.02409 .46541 L
s
% Start of user PostScript
1. 30. MAarrowzero1
% End of user PostScript
.03919 .46541 m
.03947 .46541 L
s
% Start of user PostScript
2. 30. 2.01851 30. MAarrowhead1
% End of user PostScript
.0543 .46541 m
.0543 .46541 L
s
% Start of user PostScript
3. 30. MAarrowzero1
% End of user PostScript
.0694 .46541 m
.0694 .46541 L
s
% Start of user PostScript
4. 30. MAarrowzero1
% End of user PostScript
.08451 .46541 m
.08451 .46541 L
s
% Start of user PostScript
5. 30. MAarrowzero1
% End of user PostScript
.09962 .46541 m
.09962 .46541 L
s
% Start of user PostScript
6. 30. MAarrowzero1
% End of user PostScript
.11472 .46541 m
.115 .46541 L
s
% Start of user PostScript
7. 30. 7.01851 30. MAarrowhead1
% End of user PostScript
.12983 .46541 m
.12983 .46541 L
s
% Start of user PostScript
8. 30. MAarrowzero1
% End of user PostScript
.14493 .46541 m
.14521 .46513 L
s
% Start of user PostScript
9. 30. 9.01851 29.9815 MAarrowhead1
% End of user PostScript
.16004 .46541 m
.16251 .47271 L
s
% Start of user PostScript
10. 30. 10.1639 30.4836 MAarrowhead1
% End of user PostScript
.17514 .46541 m
.17517 .4672 L
s
% Start of user PostScript
11. 30. 11.0021 30.1188 MAarrowhead1
% End of user PostScript
.19025 .46541 m
.18824 .46426 L
s
% Start of user PostScript
12. 30. 11.8673 29.9243 MAarrowhead1
% End of user PostScript
.20535 .46541 m
.20505 .46599 L
s
% Start of user PostScript
13. 30. 12.98 30.0385 MAarrowhead1
% End of user PostScript
.22046 .46541 m
.22266 .4674 L
s
% Start of user PostScript
14. 30. 14.146 30.1319 MAarrowhead1
% End of user PostScript
.23556 .46541 m
.23771 .46403 L
s
% Start of user PostScript
15. 30. 15.1425 29.9089 MAarrowhead1
% End of user PostScript
.25067 .46541 m
.25028 .46465 L
s
% Start of user PostScript
16. 30. 15.9746 29.9499 MAarrowhead1
% End of user PostScript
.26577 .46541 m
.26569 .46479 L
s
% Start of user PostScript
17. 30. 16.9945 29.9595 MAarrowhead1
% End of user PostScript
.28088 .46541 m
.28088 .46588 L
s
% Start of user PostScript
18. 30. 18. 30.0314 MAarrowhead1
% End of user PostScript
.29598 .46541 m
.29598 .46493 L
s
% Start of user PostScript
19. 30. 19. 29.9686 MAarrowhead1
% End of user PostScript
.31109 .46541 m
.31109 .46541 L
s
% Start of user PostScript
20. 30. MAarrowzero1
% End of user PostScript
.32619 .46541 m
.32628 .46493 L
s
% Start of user PostScript
21. 30. 21.0055 29.9686 MAarrowhead1
% End of user PostScript
.3413 .46541 m
.3413 .46541 L
s
% Start of user PostScript
22. 30. MAarrowzero1
% End of user PostScript
.3564 .46541 m
.3564 .46541 L
s
% Start of user PostScript
23. 30. MAarrowzero1
% End of user PostScript
.37151 .46541 m
.37184 .46583 L
s
% Start of user PostScript
24. 30. 24.022 30.0279 MAarrowhead1
% End of user PostScript
.38661 .46541 m
.38661 .46541 L
s
% Start of user PostScript
25. 30. MAarrowzero1
% End of user PostScript
.40172 .46541 m
.40252 .46541 L
s
% Start of user PostScript
26. 30. 26.0533 30. MAarrowhead1
% End of user PostScript
.41682 .46541 m
.41732 .4659 L
s
% Start of user PostScript
27. 30. 27.0325 30.0325 MAarrowhead1
% End of user PostScript
.43193 .46541 m
.43198 .46507 L
s
% Start of user PostScript
28. 30. 28.0035 29.978 MAarrowhead1
% End of user PostScript
.44703 .46541 m
.44703 .46507 L
s
% Start of user PostScript
29. 30. 29. 29.9776 MAarrowhead1
% End of user PostScript
.46214 .46541 m
.46195 .46513 L
s
% Start of user PostScript
30. 30. 29.9871 29.9815 MAarrowhead1
% End of user PostScript
.47725 .46541 m
.47725 .46574 L
s
% Start of user PostScript
31. 30. 31. 30.0224 MAarrowhead1
% End of user PostScript
.49235 .46541 m
.49243 .46488 L
s
% Start of user PostScript
32. 30. 32.0055 29.9651 MAarrowhead1
% End of user PostScript
.50746 .46541 m
.50746 .46541 L
s
% Start of user PostScript
33. 30. MAarrowzero1
% End of user PostScript
.52256 .46541 m
.52256 .46541 L
s
% Start of user PostScript
34. 30. MAarrowzero1
% End of user PostScript
.53767 .46541 m
.53805 .46541 L
s
% Start of user PostScript
35. 30. 35.0254 30. MAarrowhead1
% End of user PostScript
.55277 .46541 m
.55348 .46577 L
s
% Start of user PostScript
36. 30. 36.0467 30.0243 MAarrowhead1
% End of user PostScript
.56788 .46541 m
.56842 .46584 L
s
% Start of user PostScript
37. 30. 37.036 30.0291 MAarrowhead1
% End of user PostScript
.58298 .46541 m
.58383 .46578 L
s
% Start of user PostScript
38. 30. 38.0561 30.0247 MAarrowhead1
% End of user PostScript
.59809 .46541 m
.59999 .46701 L
s
% Start of user PostScript
39. 30. 39.126 30.106 MAarrowhead1
% End of user PostScript
.61319 .46541 m
.61408 .46619 L
s
% Start of user PostScript
40. 30. 40.0587 30.0522 MAarrowhead1
% End of user PostScript
.6283 .46541 m
.62995 .46591 L
s
% Start of user PostScript
41. 30. 41.1094 30.0337 MAarrowhead1
% End of user PostScript
.6434 .46541 m
.64256 .46541 L
s
% Start of user PostScript
42. 30. 41.9444 30. MAarrowhead1
% End of user PostScript
.65851 .46541 m
.65757 .46482 L
s
% Start of user PostScript
43. 30. 42.938 29.9615 MAarrowhead1
% End of user PostScript
.67361 .46541 m
.67361 .46442 L
s
% Start of user PostScript
44. 30. 44. 29.9345 MAarrowhead1
% End of user PostScript
.68872 .46541 m
.68939 .46423 L
s
% Start of user PostScript
45. 30. 45.0444 29.9224 MAarrowhead1
% End of user PostScript
.70382 .46541 m
.70192 .46267 L
s
% Start of user PostScript
46. 30. 45.874 29.8192 MAarrowhead1
% End of user PostScript
.71893 .46541 m
.71822 .46541 L
s
% Start of user PostScript
47. 30. 46.9533 30. MAarrowhead1
% End of user PostScript
.73403 .46541 m
.73585 .46813 L
s
% Start of user PostScript
48. 30. 48.12 30.1807 MAarrowhead1
% End of user PostScript
.74914 .46541 m
.75079 .46792 L
s
% Start of user PostScript
49. 30. 49.1095 30.1667 MAarrowhead1
% End of user PostScript
.76424 .46541 m
.76396 .46389 L
s
% Start of user PostScript
50. 30. 49.9812 29.8997 MAarrowhead1
% End of user PostScript
.77935 .46541 m
.77724 .46305 L
s
% Start of user PostScript
51. 30. 50.8601 29.8441 MAarrowhead1
% End of user PostScript
.79445 .46541 m
.79445 .46488 L
s
% Start of user PostScript
52. 30. 52. 29.9652 MAarrowhead1
% End of user PostScript
.80956 .46541 m
.80956 .46541 L
s
% Start of user PostScript
53. 30. MAarrowzero1
% End of user PostScript
.82466 .46541 m
.82466 .46541 L
s
% Start of user PostScript
54. 30. MAarrowzero1
% End of user PostScript
.83977 .46541 m
.83977 .46541 L
s
% Start of user PostScript
55. 30. MAarrowzero1
% End of user PostScript
.85488 .46541 m
.85488 .46541 L
s
% Start of user PostScript
56. 30. MAarrowzero1
% End of user PostScript
.86998 .46541 m
.86998 .46513 L
s
% Start of user PostScript
57. 30. 57. 29.9815 MAarrowhead1
% End of user PostScript
.88509 .46541 m
.88536 .46541 L
s
% Start of user PostScript
58. 30. 58.0185 30. MAarrowhead1
% End of user PostScript
.90019 .46541 m
.90019 .46513 L
s
% Start of user PostScript
59. 30. 59. 29.9815 MAarrowhead1
% End of user PostScript
.9153 .46541 m
.91558 .46541 L
s
% Start of user PostScript
60. 30. 60.0185 30. MAarrowhead1
% End of user PostScript
.9304 .46541 m
.9304 .46541 L
s
% Start of user PostScript
61. 30. MAarrowzero1
% End of user PostScript
.94551 .46541 m
.94551 .46541 L
s
% Start of user PostScript
62. 30. MAarrowzero1
% End of user PostScript
.96061 .46541 m
.96033 .46541 L
s
% Start of user PostScript
63. 30. 62.9815 30. MAarrowhead1
% End of user PostScript
.97572 .46541 m
.97572 .46541 L
s
% Start of user PostScript
64. 30. MAarrowzero1
% End of user PostScript
.02409 .48051 m
.02437 .48023 L
s
% Start of user PostScript
1. 31. 1.01851 30.9815 MAarrowhead1
% End of user PostScript
.03919 .48051 m
.03919 .48079 L
s
% Start of user PostScript
2. 31. 2. 31.0185 MAarrowhead1
% End of user PostScript
.0543 .48051 m
.0543 .48079 L
s
% Start of user PostScript
3. 31. 3. 31.0185 MAarrowhead1
% End of user PostScript
.0694 .48051 m
.0694 .48051 L
s
% Start of user PostScript
4. 31. MAarrowzero1
% End of user PostScript
.08451 .48051 m
.08451 .48079 L
s
% Start of user PostScript
5. 31. 5. 31.0185 MAarrowhead1
% End of user PostScript
.09962 .48051 m
.09962 .48051 L
s
% Start of user PostScript
6. 31. MAarrowzero1
% End of user PostScript
.11472 .48051 m
.115 .48051 L
s
% Start of user PostScript
7. 31. 7.01851 31. MAarrowhead1
% End of user PostScript
.12983 .48051 m
.12983 .48051 L
s
% Start of user PostScript
8. 31. MAarrowzero1
% End of user PostScript
.14493 .48051 m
.14521 .48051 L
s
% Start of user PostScript
9. 31. 9.01851 31. MAarrowhead1
% End of user PostScript
.16004 .48051 m
.16676 .48782 L
s
% Start of user PostScript
10. 31. 10.4451 31.4836 MAarrowhead1
% End of user PostScript
.17514 .48051 m
.17752 .48153 L
s
% Start of user PostScript
11. 31. 11.1573 31.0676 MAarrowhead1
% End of user PostScript
.19025 .48051 m
.18913 .48 L
s
% Start of user PostScript
12. 31. 11.9262 30.9663 MAarrowhead1
% End of user PostScript
.20535 .48051 m
.2059 .48084 L
s
% Start of user PostScript
13. 31. 13.036 31.022 MAarrowhead1
% End of user PostScript
.22046 .48051 m
.21987 .48051 L
s
% Start of user PostScript
14. 31. 13.9615 31. MAarrowhead1
% End of user PostScript
.23556 .48051 m
.23285 .47121 L
s
% Start of user PostScript
15. 31. 14.8205 30.3843 MAarrowhead1
% End of user PostScript
.25067 .48051 m
.25076 .48032 L
s
% Start of user PostScript
16. 31. 16.006 30.9875 MAarrowhead1
% End of user PostScript
.26577 .48051 m
.26577 .48051 L
s
% Start of user PostScript
17. 31. MAarrowzero1
% End of user PostScript
.28088 .48051 m
.2804 .48051 L
s
% Start of user PostScript
18. 31. 17.9686 31. MAarrowhead1
% End of user PostScript
.29598 .48051 m
.29598 .48098 L
s
% Start of user PostScript
19. 31. 19. 31.0314 MAarrowhead1
% End of user PostScript
.31109 .48051 m
.31109 .48051 L
s
% Start of user PostScript
20. 31. MAarrowzero1
% End of user PostScript
.32619 .48051 m
.32611 .48093 L
s
% Start of user PostScript
21. 31. 20.9945 31.0279 MAarrowhead1
% End of user PostScript
.3413 .48051 m
.34082 .48051 L
s
% Start of user PostScript
22. 31. 21.9686 31. MAarrowhead1
% End of user PostScript
.3564 .48051 m
.3564 .48098 L
s
% Start of user PostScript
23. 31. 23. 31.0314 MAarrowhead1
% End of user PostScript
.37151 .48051 m
.37151 .48043 L
s
% Start of user PostScript
24. 31. 24. 30.9945 MAarrowhead1
% End of user PostScript
.38661 .48051 m
.38594 .48059 L
s
% Start of user PostScript
25. 31. 24.9556 31.0055 MAarrowhead1
% End of user PostScript
.40172 .48051 m
.40225 .4799 L
s
% Start of user PostScript
26. 31. 26.0349 30.9595 MAarrowhead1
% End of user PostScript
.41682 .48051 m
.41765 .48084 L
s
% Start of user PostScript
27. 31. 27.0549 31.022 MAarrowhead1
% End of user PostScript
.43193 .48051 m
.43116 .48002 L
s
% Start of user PostScript
28. 31. 27.9489 30.9675 MAarrowhead1
% End of user PostScript
.44703 .48051 m
.44653 .48051 L
s
% Start of user PostScript
29. 31. 28.9663 31. MAarrowhead1
% End of user PostScript
.46214 .48051 m
.46161 .48046 L
s
% Start of user PostScript
30. 31. 29.9652 30.9965 MAarrowhead1
% End of user PostScript
.47725 .48051 m
.47725 .48051 L
s
% Start of user PostScript
31. 31. MAarrowzero1
% End of user PostScript
.49235 .48051 m
.49201 .48051 L
s
% Start of user PostScript
32. 31. 31.9776 31. MAarrowhead1
% End of user PostScript
.50746 .48051 m
.50765 .4799 L
s
% Start of user PostScript
33. 31. 33.0125 30.9595 MAarrowhead1
% End of user PostScript
.52256 .48051 m
.52247 .48126 L
s
% Start of user PostScript
34. 31. 33.994 31.0499 MAarrowhead1
% End of user PostScript
.53767 .48051 m
.53767 .48084 L
s
% Start of user PostScript
35. 31. 35. 31.022 MAarrowhead1
% End of user PostScript
.55277 .48051 m
.55282 .48065 L
s
% Start of user PostScript
36. 31. 36.0035 31.0094 MAarrowhead1
% End of user PostScript
.56788 .48051 m
.56871 .48051 L
s
% Start of user PostScript
37. 31. 37.0549 31. MAarrowhead1
% End of user PostScript
.58298 .48051 m
.58351 .48098 L
s
% Start of user PostScript
38. 31. 38.0348 31.0314 MAarrowhead1
% End of user PostScript
.59809 .48051 m
.59937 .48098 L
s
% Start of user PostScript
39. 31. 39.0847 31.0314 MAarrowhead1
% End of user PostScript
.61319 .48051 m
.61509 .48101 L
s
% Start of user PostScript
40. 31. 40.1255 31.0329 MAarrowhead1
% End of user PostScript
.6283 .48051 m
.63035 .48129 L
s
% Start of user PostScript
41. 31. 41.1361 31.0514 MAarrowhead1
% End of user PostScript
.6434 .48051 m
.64306 .47993 L
s
% Start of user PostScript
42. 31. 41.9776 30.9615 MAarrowhead1
% End of user PostScript
.65851 .48051 m
.65736 .47988 L
s
% Start of user PostScript
43. 31. 42.9244 30.958 MAarrowhead1
% End of user PostScript
.67361 .48051 m
.6731 .4806 L
s
% Start of user PostScript
44. 31. 43.9663 31.006 MAarrowhead1
% End of user PostScript
.68872 .48051 m
.68821 .48183 L
s
% Start of user PostScript
45. 31. 44.9661 31.0875 MAarrowhead1
% End of user PostScript
.70382 .48051 m
.70458 .48051 L
s
% Start of user PostScript
46. 31. 46.0501 31. MAarrowhead1
% End of user PostScript
.71893 .48051 m
.71831 .48046 L
s
% Start of user PostScript
47. 31. 46.9592 30.9965 MAarrowhead1
% End of user PostScript
.73403 .48051 m
.73315 .48004 L
s
% Start of user PostScript
48. 31. 47.9418 30.9686 MAarrowhead1
% End of user PostScript
.74914 .48051 m
.74799 .48013 L
s
% Start of user PostScript
49. 31. 48.9239 30.9746 MAarrowhead1
% End of user PostScript
.76424 .48051 m
.7634 .4799 L
s
% Start of user PostScript
50. 31. 49.9439 30.9593 MAarrowhead1
% End of user PostScript
.77935 .48051 m
.77595 .47711 L
s
% Start of user PostScript
51. 31. 50.7752 30.7752 MAarrowhead1
% End of user PostScript
.79445 .48051 m
.79445 .48051 L
s
% Start of user PostScript
52. 31. MAarrowzero1
% End of user PostScript
.80956 .48051 m
.80956 .48051 L
s
% Start of user PostScript
53. 31. MAarrowzero1
% End of user PostScript
.82466 .48051 m
.82466 .48051 L
s
% Start of user PostScript
54. 31. MAarrowzero1
% End of user PostScript
.83977 .48051 m
.83977 .48051 L
s
% Start of user PostScript
55. 31. MAarrowzero1
% End of user PostScript
.85488 .48051 m
.85488 .48051 L
s
% Start of user PostScript
56. 31. MAarrowzero1
% End of user PostScript
.86998 .48051 m
.86998 .48051 L
s
% Start of user PostScript
57. 31. MAarrowzero1
% End of user PostScript
.88509 .48051 m
.88536 .48051 L
s
% Start of user PostScript
58. 31. 58.0185 31. MAarrowhead1
% End of user PostScript
.90019 .48051 m
.90047 .48051 L
s
% Start of user PostScript
59. 31. 59.0185 31. MAarrowhead1
% End of user PostScript
.9153 .48051 m
.9153 .48079 L
s
% Start of user PostScript
60. 31. 60. 31.0185 MAarrowhead1
% End of user PostScript
.9304 .48051 m
.9304 .48051 L
s
% Start of user PostScript
61. 31. MAarrowzero1
% End of user PostScript
.94551 .48051 m
.94551 .48051 L
s
% Start of user PostScript
62. 31. MAarrowzero1
% End of user PostScript
.96061 .48051 m
.96061 .48051 L
s
% Start of user PostScript
63. 31. MAarrowzero1
% End of user PostScript
.97572 .48051 m
.97572 .48051 L
s
% Start of user PostScript
64. 31. MAarrowzero1
% End of user PostScript
.02409 .49562 m
.02437 .49534 L
s
% Start of user PostScript
1. 32. 1.01851 31.9815 MAarrowhead1
% End of user PostScript
.03919 .49562 m
.03919 .49562 L
s
% Start of user PostScript
2. 32. MAarrowzero1
% End of user PostScript
.0543 .49562 m
.0543 .49562 L
s
% Start of user PostScript
3. 32. MAarrowzero1
% End of user PostScript
.0694 .49562 m
.06968 .4959 L
s
% Start of user PostScript
4. 32. 4.01851 32.0185 MAarrowhead1
% End of user PostScript
.08451 .49562 m
.08479 .49562 L
s
% Start of user PostScript
5. 32. 5.01851 32. MAarrowhead1
% End of user PostScript
.09962 .49562 m
.09962 .49562 L
s
% Start of user PostScript
6. 32. MAarrowzero1
% End of user PostScript
.11472 .49562 m
.11472 .49562 L
s
% Start of user PostScript
7. 32. MAarrowzero1
% End of user PostScript
.12983 .49562 m
.12983 .49562 L
s
% Start of user PostScript
8. 32. MAarrowzero1
% End of user PostScript
.14493 .49562 m
.14465 .49534 L
s
% Start of user PostScript
9. 32. 8.98149 31.9815 MAarrowhead1
% End of user PostScript
.16004 .49562 m
.16187 .49729 L
s
% Start of user PostScript
10. 32. 10.1214 32.1108 MAarrowhead1
% End of user PostScript
.17514 .49562 m
.1766 .4971 L
s
% Start of user PostScript
11. 32. 11.0969 32.098 MAarrowhead1
% End of user PostScript
.19025 .49562 m
.19171 .49673 L
s
% Start of user PostScript
12. 32. 12.0969 32.0738 MAarrowhead1
% End of user PostScript
.20535 .49562 m
.20664 .49748 L
s
% Start of user PostScript
13. 32. 13.0851 32.1236 MAarrowhead1
% End of user PostScript
.22046 .49562 m
.22079 .49444 L
s
% Start of user PostScript
14. 32. 14.022 31.9218 MAarrowhead1
% End of user PostScript
.23556 .49562 m
.23461 .49528 L
s
% Start of user PostScript
15. 32. 14.9373 31.9777 MAarrowhead1
% End of user PostScript
.25067 .49562 m
.24972 .49495 L
s
% Start of user PostScript
16. 32. 15.9373 31.9556 MAarrowhead1
% End of user PostScript
.26577 .49562 m
.26577 .49514 L
s
% Start of user PostScript
17. 32. 17. 31.9686 MAarrowhead1
% End of user PostScript
.28088 .49562 m
.28088 .49562 L
s
% Start of user PostScript
18. 32. MAarrowzero1
% End of user PostScript
.29598 .49562 m
.29607 .49609 L
s
% Start of user PostScript
19. 32. 19.0055 32.0314 MAarrowhead1
% End of user PostScript
.31109 .49562 m
.31067 .49595 L
s
% Start of user PostScript
20. 32. 19.9721 32.0224 MAarrowhead1
% End of user PostScript
.32619 .49562 m
.32544 .49614 L
s
% Start of user PostScript
21. 32. 20.9499 32.0348 MAarrowhead1
% End of user PostScript
.3413 .49562 m
.34091 .49567 L
s
% Start of user PostScript
22. 32. 21.9746 32.0035 MAarrowhead1
% End of user PostScript
.3564 .49562 m
.35565 .49562 L
s
% Start of user PostScript
23. 32. 22.9501 32. MAarrowhead1
% End of user PostScript
.37151 .49562 m
.37212 .49609 L
s
% Start of user PostScript
24. 32. 24.0405 32.0314 MAarrowhead1
% End of user PostScript
.38661 .49562 m
.38637 .49528 L
s
% Start of user PostScript
25. 32. 24.9836 31.978 MAarrowhead1
% End of user PostScript
.40172 .49562 m
.40164 .49553 L
s
% Start of user PostScript
26. 32. 25.9945 31.9945 MAarrowhead1
% End of user PostScript
.41682 .49562 m
.418 .49707 L
s
% Start of user PostScript
27. 32. 27.078 32.0965 MAarrowhead1
% End of user PostScript
.43193 .49562 m
.43188 .49604 L
s
% Start of user PostScript
28. 32. 27.9965 32.0279 MAarrowhead1
% End of user PostScript
.44703 .49562 m
.44626 .49567 L
s
% Start of user PostScript
29. 32. 28.9489 32.0035 MAarrowhead1
% End of user PostScript
.46214 .49562 m
.46172 .49442 L
s
% Start of user PostScript
30. 32. 29.9723 31.9208 MAarrowhead1
% End of user PostScript
.47725 .49562 m
.47725 .49547 L
s
% Start of user PostScript
31. 32. 31. 31.9906 MAarrowhead1
% End of user PostScript
.49235 .49562 m
.49182 .49648 L
s
% Start of user PostScript
32. 32. 31.9652 32.0572 MAarrowhead1
% End of user PostScript
.50746 .49562 m
.50656 .49614 L
s
% Start of user PostScript
33. 32. 32.9409 32.0348 MAarrowhead1
% End of user PostScript
.52256 .49562 m
.52251 .49581 L
s
% Start of user PostScript
34. 32. 33.9965 32.0129 MAarrowhead1
% End of user PostScript
.53767 .49562 m
.53752 .49567 L
s
% Start of user PostScript
35. 32. 34.9906 32.0035 MAarrowhead1
% End of user PostScript
.55277 .49562 m
.55282 .49576 L
s
% Start of user PostScript
36. 32. 36.0035 32.0094 MAarrowhead1
% End of user PostScript
.56788 .49562 m
.56824 .4962 L
s
% Start of user PostScript
37. 32. 37.0243 32.0385 MAarrowhead1
% End of user PostScript
.58298 .49562 m
.5838 .49572 L
s
% Start of user PostScript
38. 32. 38.0545 32.0069 MAarrowhead1
% End of user PostScript
.59809 .49562 m
.59921 .49604 L
s
% Start of user PostScript
39. 32. 39.0743 32.0282 MAarrowhead1
% End of user PostScript
.61319 .49562 m
.61497 .49676 L
s
% Start of user PostScript
40. 32. 40.118 32.0761 MAarrowhead1
% End of user PostScript
.6283 .49562 m
.62944 .49646 L
s
% Start of user PostScript
41. 32. 41.0758 32.0558 MAarrowhead1
% End of user PostScript
.6434 .49562 m
.64234 .49595 L
s
% Start of user PostScript
42. 32. 41.9297 32.022 MAarrowhead1
% End of user PostScript
.65851 .49562 m
.65767 .49478 L
s
% Start of user PostScript
43. 32. 42.9444 31.9444 MAarrowhead1
% End of user PostScript
.67361 .49562 m
.67361 .49601 L
s
% Start of user PostScript
44. 32. 44. 32.0258 MAarrowhead1
% End of user PostScript
.68872 .49562 m
.68872 .49562 L
s
% Start of user PostScript
45. 32. MAarrowzero1
% End of user PostScript
.70382 .49562 m
.70427 .49592 L
s
% Start of user PostScript
46. 32. 46.0293 32.0199 MAarrowhead1
% End of user PostScript
.71893 .49562 m
.71845 .49562 L
s
% Start of user PostScript
47. 32. 46.9686 32. MAarrowhead1
% End of user PostScript
.73403 .49562 m
.72761 .49176 L
s
% Start of user PostScript
48. 32. 47.5747 31.7446 MAarrowhead1
% End of user PostScript
.74914 .49562 m
.74835 .49442 L
s
% Start of user PostScript
49. 32. 48.9478 31.9208 MAarrowhead1
% End of user PostScript
.76424 .49562 m
.76338 .49408 L
s
% Start of user PostScript
50. 32. 49.943 31.8985 MAarrowhead1
% End of user PostScript
.77935 .49562 m
.77687 .49166 L
s
% Start of user PostScript
51. 32. 50.8359 31.7378 MAarrowhead1
% End of user PostScript
.79445 .49562 m
.79445 .49562 L
s
% Start of user PostScript
52. 32. MAarrowzero1
% End of user PostScript
.80956 .49562 m
.80928 .49562 L
s
% Start of user PostScript
53. 32. 52.9815 32. MAarrowhead1
% End of user PostScript
.82466 .49562 m
.82466 .49562 L
s
% Start of user PostScript
54. 32. MAarrowzero1
% End of user PostScript
.83977 .49562 m
.83977 .49562 L
s
% Start of user PostScript
55. 32. MAarrowzero1
% End of user PostScript
.85488 .49562 m
.85488 .49562 L
s
% Start of user PostScript
56. 32. MAarrowzero1
% End of user PostScript
.86998 .49562 m
.86998 .49562 L
s
% Start of user PostScript
57. 32. MAarrowzero1
% End of user PostScript
.88509 .49562 m
.88509 .49562 L
s
% Start of user PostScript
58. 32. MAarrowzero1
% End of user PostScript
.90019 .49562 m
.90047 .4959 L
s
% Start of user PostScript
59. 32. 59.0185 32.0185 MAarrowhead1
% End of user PostScript
.9153 .49562 m
.9153 .49562 L
s
% Start of user PostScript
60. 32. MAarrowzero1
% End of user PostScript
.9304 .49562 m
.9304 .49562 L
s
% Start of user PostScript
61. 32. MAarrowzero1
% End of user PostScript
.94551 .49562 m
.94551 .49562 L
s
% Start of user PostScript
62. 32. MAarrowzero1
% End of user PostScript
.96061 .49562 m
.96061 .49562 L
s
% Start of user PostScript
63. 32. MAarrowzero1
% End of user PostScript
.97572 .49562 m
.97572 .49562 L
s
% Start of user PostScript
64. 32. MAarrowzero1
% End of user PostScript
.02409 .51072 m
.02409 .51072 L
s
% Start of user PostScript
1. 33. MAarrowzero1
% End of user PostScript
.03919 .51072 m
.03919 .51072 L
s
% Start of user PostScript
2. 33. MAarrowzero1
% End of user PostScript
.0543 .51072 m
.0543 .51044 L
s
% Start of user PostScript
3. 33. 3. 32.9815 MAarrowhead1
% End of user PostScript
.0694 .51072 m
.0694 .51072 L
s
% Start of user PostScript
4. 33. MAarrowzero1
% End of user PostScript
.08451 .51072 m
.08451 .51044 L
s
% Start of user PostScript
5. 33. 5. 32.9815 MAarrowhead1
% End of user PostScript
.09962 .51072 m
.09934 .51072 L
s
% Start of user PostScript
6. 33. 5.98149 33. MAarrowhead1
% End of user PostScript
.11472 .51072 m
.11472 .51044 L
s
% Start of user PostScript
7. 33. 7. 32.9815 MAarrowhead1
% End of user PostScript
.12983 .51072 m
.13011 .51044 L
s
% Start of user PostScript
8. 33. 8.01851 32.9815 MAarrowhead1
% End of user PostScript
.14493 .51072 m
.14493 .51025 L
s
% Start of user PostScript
9. 33. 9. 32.9686 MAarrowhead1
% End of user PostScript
.16004 .51072 m
.15784 .50819 L
s
% Start of user PostScript
10. 33. 9.85459 32.8322 MAarrowhead1
% End of user PostScript
.17514 .51072 m
.17382 .51072 L
s
% Start of user PostScript
11. 33. 10.9125 33. MAarrowhead1
% End of user PostScript
.19025 .51072 m
.18977 .51044 L
s
% Start of user PostScript
12. 33. 11.9682 32.9812 MAarrowhead1
% End of user PostScript
.20535 .51072 m
.20502 .51014 L
s
% Start of user PostScript
13. 33. 12.978 32.9615 MAarrowhead1
% End of user PostScript
.22046 .51072 m
.21464 .50484 L
s
% Start of user PostScript
14. 33. 13.6152 32.6104 MAarrowhead1
% End of user PostScript
.23556 .51072 m
.23398 .51244 L
s
% Start of user PostScript
15. 33. 14.8951 33.114 MAarrowhead1
% End of user PostScript
.25067 .51072 m
.25019 .50997 L
s
% Start of user PostScript
16. 33. 15.9686 32.9501 MAarrowhead1
% End of user PostScript
.26577 .51072 m
.26577 .51072 L
s
% Start of user PostScript
17. 33. MAarrowzero1
% End of user PostScript
.28088 .51072 m
.28088 .51106 L
s
% Start of user PostScript
18. 33. 18. 33.0224 MAarrowhead1
% End of user PostScript
.29598 .51072 m
.29565 .51239 L
s
% Start of user PostScript
19. 33. 18.978 33.1106 MAarrowhead1
% End of user PostScript
.31109 .51072 m
.30807 .51421 L
s
% Start of user PostScript
20. 33. 19.8005 33.2309 MAarrowhead1
% End of user PostScript
.32619 .51072 m
.32567 .51262 L
s
% Start of user PostScript
21. 33. 20.9652 33.126 MAarrowhead1
% End of user PostScript
.3413 .51072 m
.33885 .51067 L
s
% Start of user PostScript
22. 33. 21.8376 32.9965 MAarrowhead1
% End of user PostScript
.3564 .51072 m
.35506 .51019 L
s
% Start of user PostScript
23. 33. 22.9114 32.9652 MAarrowhead1
% End of user PostScript
.37151 .51072 m
.37203 .51105 L
s
% Start of user PostScript
24. 33. 24.0348 33.022 MAarrowhead1
% End of user PostScript
.38661 .51072 m
.38594 .50997 L
s
% Start of user PostScript
25. 33. 24.9556 32.9501 MAarrowhead1
% End of user PostScript
.40172 .51072 m
.40172 .51064 L
s
% Start of user PostScript
26. 33. 26. 32.9945 MAarrowhead1
% End of user PostScript
.41682 .51072 m
.41816 .51135 L
s
% Start of user PostScript
27. 33. 27.0886 33.042 MAarrowhead1
% End of user PostScript
.43193 .51072 m
.43122 .51109 L
s
% Start of user PostScript
28. 33. 27.9533 33.0244 MAarrowhead1
% End of user PostScript
.44703 .51072 m
.44642 .50948 L
s
% Start of user PostScript
29. 33. 28.9593 32.9176 MAarrowhead1
% End of user PostScript
.46214 .51072 m
.461 .50972 L
s
% Start of user PostScript
30. 33. 29.9242 32.9338 MAarrowhead1
% End of user PostScript
.47725 .51072 m
.47663 .51192 L
s
% Start of user PostScript
31. 33. 30.9591 33.0792 MAarrowhead1
% End of user PostScript
.49235 .51072 m
.49145 .51278 L
s
% Start of user PostScript
32. 33. 31.9403 33.1365 MAarrowhead1
% End of user PostScript
.50746 .51072 m
.50508 .51303 L
s
% Start of user PostScript
33. 33. 32.8427 33.1529 MAarrowhead1
% End of user PostScript
.52256 .51072 m
.52191 .51179 L
s
% Start of user PostScript
34. 33. 33.9569 33.071 MAarrowhead1
% End of user PostScript
.53767 .51072 m
.53649 .51134 L
s
% Start of user PostScript
35. 33. 34.9221 33.0408 MAarrowhead1
% End of user PostScript
.55277 .51072 m
.55271 .51072 L
s
% Start of user PostScript
36. 33. 35.9961 33. MAarrowhead1
% End of user PostScript
.56788 .51072 m
.56716 .5115 L
s
% Start of user PostScript
37. 33. 36.9524 33.0515 MAarrowhead1
% End of user PostScript
.58298 .51072 m
.58303 .51154 L
s
% Start of user PostScript
38. 33. 38.0035 33.0545 MAarrowhead1
% End of user PostScript
.59809 .51072 m
.59899 .51132 L
s
% Start of user PostScript
39. 33. 39.0595 33.0396 MAarrowhead1
% End of user PostScript
.61319 .51072 m
.61453 .51145 L
s
% Start of user PostScript
40. 33. 40.0886 33.0482 MAarrowhead1
% End of user PostScript
.6283 .51072 m
.62892 .51213 L
s
% Start of user PostScript
41. 33. 41.0412 33.0934 MAarrowhead1
% End of user PostScript
.6434 .51072 m
.6464 .51123 L
s
% Start of user PostScript
42. 33. 42.1982 33.0337 MAarrowhead1
% End of user PostScript
.65851 .51072 m
.65793 .51049 L
s
% Start of user PostScript
43. 33. 42.9615 32.9847 MAarrowhead1
% End of user PostScript
.67361 .51072 m
.67313 .51125 L
s
% Start of user PostScript
44. 33. 43.9682 33.0353 MAarrowhead1
% End of user PostScript
.68872 .51072 m
.68956 .51165 L
s
% Start of user PostScript
45. 33. 45.0561 33.0616 MAarrowhead1
% End of user PostScript
.70382 .51072 m
.70229 .51116 L
s
% Start of user PostScript
46. 33. 45.8987 33.0289 MAarrowhead1
% End of user PostScript
.71893 .51072 m
.71813 .51072 L
s
% Start of user PostScript
47. 33. 46.9474 33. MAarrowhead1
% End of user PostScript
.73403 .51072 m
.72845 .50425 L
s
% Start of user PostScript
48. 33. 47.6306 32.5713 MAarrowhead1
% End of user PostScript
.74914 .51072 m
.74984 .51232 L
s
% Start of user PostScript
49. 33. 49.0464 33.106 MAarrowhead1
% End of user PostScript
.76424 .51072 m
.76337 .5101 L
s
% Start of user PostScript
50. 33. 49.9418 32.9592 MAarrowhead1
% End of user PostScript
.77935 .51072 m
.77764 .50849 L
s
% Start of user PostScript
51. 33. 50.8871 32.8523 MAarrowhead1
% End of user PostScript
.79445 .51072 m
.79445 .51072 L
s
% Start of user PostScript
52. 33. MAarrowzero1
% End of user PostScript
.80956 .51072 m
.80956 .51072 L
s
% Start of user PostScript
53. 33. MAarrowzero1
% End of user PostScript
.82466 .51072 m
.82466 .51072 L
s
% Start of user PostScript
54. 33. MAarrowzero1
% End of user PostScript
.83977 .51072 m
.84005 .51072 L
s
% Start of user PostScript
55. 33. 55.0185 33. MAarrowhead1
% End of user PostScript
.85488 .51072 m
.85488 .51072 L
s
% Start of user PostScript
56. 33. MAarrowzero1
% End of user PostScript
.86998 .51072 m
.86998 .51072 L
s
% Start of user PostScript
57. 33. MAarrowzero1
% End of user PostScript
.88509 .51072 m
.88509 .51072 L
s
% Start of user PostScript
58. 33. MAarrowzero1
% End of user PostScript
.90019 .51072 m
.90019 .51072 L
s
% Start of user PostScript
59. 33. MAarrowzero1
% End of user PostScript
.9153 .51072 m
.9153 .51072 L
s
% Start of user PostScript
60. 33. MAarrowzero1
% End of user PostScript
.9304 .51072 m
.93068 .51072 L
s
% Start of user PostScript
61. 33. 61.0185 33. MAarrowhead1
% End of user PostScript
.94551 .51072 m
.94551 .51072 L
s
% Start of user PostScript
62. 33. MAarrowzero1
% End of user PostScript
.96061 .51072 m
.96061 .51072 L
s
% Start of user PostScript
63. 33. MAarrowzero1
% End of user PostScript
.97572 .51072 m
.97572 .51072 L
s
% Start of user PostScript
64. 33. MAarrowzero1
% End of user PostScript
.02409 .52583 m
.02437 .52555 L
s
% Start of user PostScript
1. 34. 1.01851 33.9815 MAarrowhead1
% End of user PostScript
.03919 .52583 m
.03919 .52583 L
s
% Start of user PostScript
2. 34. MAarrowzero1
% End of user PostScript
.0543 .52583 m
.0543 .52583 L
s
% Start of user PostScript
3. 34. MAarrowzero1
% End of user PostScript
.0694 .52583 m
.0694 .52555 L
s
% Start of user PostScript
4. 34. 4. 33.9815 MAarrowhead1
% End of user PostScript
.08451 .52583 m
.08451 .52555 L
s
% Start of user PostScript
5. 34. 5. 33.9815 MAarrowhead1
% End of user PostScript
.09962 .52583 m
.09962 .52583 L
s
% Start of user PostScript
6. 34. MAarrowzero1
% End of user PostScript
.11472 .52583 m
.11444 .52583 L
s
% Start of user PostScript
7. 34. 6.98149 34. MAarrowhead1
% End of user PostScript
.12983 .52583 m
.12983 .52583 L
s
% Start of user PostScript
8. 34. MAarrowzero1
% End of user PostScript
.14493 .52583 m
.14979 .53193 L
s
% Start of user PostScript
9. 34. 9.32149 34.4041 MAarrowhead1
% End of user PostScript
.16004 .52583 m
.16243 .52632 L
s
% Start of user PostScript
10. 34. 10.1587 34.0325 MAarrowhead1
% End of user PostScript
.17514 .52583 m
.17599 .52725 L
s
% Start of user PostScript
11. 34. 11.0561 34.0942 MAarrowhead1
% End of user PostScript
.19025 .52583 m
.18962 .52457 L
s
% Start of user PostScript
12. 34. 11.9588 33.9168 MAarrowhead1
% End of user PostScript
.20535 .52583 m
.20303 .52631 L
s
% Start of user PostScript
13. 34. 12.8461 34.0318 MAarrowhead1
% End of user PostScript
.22046 .52583 m
.22136 .5263 L
s
% Start of user PostScript
14. 34. 14.0595 34.0314 MAarrowhead1
% End of user PostScript
.23556 .52583 m
.23592 .52467 L
s
% Start of user PostScript
15. 34. 15.0235 33.9235 MAarrowhead1
% End of user PostScript
.25067 .52583 m
.25067 .52535 L
s
% Start of user PostScript
16. 34. 16. 33.9686 MAarrowhead1
% End of user PostScript
.26577 .52583 m
.26543 .52669 L
s
% Start of user PostScript
17. 34. 16.9776 34.0572 MAarrowhead1
% End of user PostScript
.28088 .52583 m
.28088 .52965 L
s
% Start of user PostScript
18. 34. 18. 34.2529 MAarrowhead1
% End of user PostScript
.29598 .52583 m
.29592 .52271 L
s
% Start of user PostScript
19. 34. 18.9955 33.7939 MAarrowhead1
% End of user PostScript
.31109 .52583 m
.31348 .52988 L
s
% Start of user PostScript
20. 34. 20.1585 34.2684 MAarrowhead1
% End of user PostScript
.32619 .52583 m
.32586 .52682 L
s
% Start of user PostScript
21. 34. 20.978 34.0655 MAarrowhead1
% End of user PostScript
.3413 .52583 m
.33886 .52619 L
s
% Start of user PostScript
22. 34. 21.8387 34.0243 MAarrowhead1
% End of user PostScript
.3564 .52583 m
.35693 .5258 L
s
% Start of user PostScript
23. 34. 23.0346 33.9984 MAarrowhead1
% End of user PostScript
.37151 .52583 m
.37033 .52722 L
s
% Start of user PostScript
24. 34. 23.922 34.0921 MAarrowhead1
% End of user PostScript
.38661 .52583 m
.38576 .52488 L
s
% Start of user PostScript
25. 34. 24.9432 33.9373 MAarrowhead1
% End of user PostScript
.40172 .52583 m
.40172 .5263 L
s
% Start of user PostScript
26. 34. 26. 34.0314 MAarrowhead1
% End of user PostScript
.41682 .52583 m
.41767 .52662 L
s
% Start of user PostScript
27. 34. 27.0561 34.0526 MAarrowhead1
% End of user PostScript
.43193 .52583 m
.43207 .52655 L
s
% Start of user PostScript
28. 34. 28.0094 34.0479 MAarrowhead1
% End of user PostScript
.44703 .52583 m
.44513 .52633 L
s
% Start of user PostScript
29. 34. 28.874 34.0333 MAarrowhead1
% End of user PostScript
.46214 .52583 m
.46482 .5258 L
s
% Start of user PostScript
30. 34. 30.1777 33.9985 MAarrowhead1
% End of user PostScript
.47725 .52583 m
.47892 .52083 L
s
% Start of user PostScript
31. 34. 31.1108 33.6692 MAarrowhead1
% End of user PostScript
.49235 .52583 m
.49182 .53075 L
s
% Start of user PostScript
32. 34. 31.9652 34.3257 MAarrowhead1
% End of user PostScript
.50746 .52583 m
.50604 .52311 L
s
% Start of user PostScript
33. 34. 32.9062 33.8205 MAarrowhead1
% End of user PostScript
.52256 .52583 m
.52069 .52393 L
s
% Start of user PostScript
34. 34. 33.8762 33.8743 MAarrowhead1
% End of user PostScript
.53767 .52583 m
.53646 .52694 L
s
% Start of user PostScript
35. 34. 34.9205 34.0738 MAarrowhead1
% End of user PostScript
.55277 .52583 m
.55034 .52588 L
s
% Start of user PostScript
36. 34. 35.8392 34.0035 MAarrowhead1
% End of user PostScript
.56788 .52583 m
.5673 .52583 L
s
% Start of user PostScript
37. 34. 36.9617 34. MAarrowhead1
% End of user PostScript
.58298 .52583 m
.5834 .52635 L
s
% Start of user PostScript
38. 34. 38.0279 34.0348 MAarrowhead1
% End of user PostScript
.59809 .52583 m
.59861 .5263 L
s
% Start of user PostScript
39. 34. 39.0348 34.0316 MAarrowhead1
% End of user PostScript
.61319 .52583 m
.61423 .52703 L
s
% Start of user PostScript
40. 34. 40.0686 34.0795 MAarrowhead1
% End of user PostScript
.6283 .52583 m
.62923 .52729 L
s
% Start of user PostScript
41. 34. 41.0616 34.0969 MAarrowhead1
% End of user PostScript
.6434 .52583 m
.64277 .52725 L
s
% Start of user PostScript
42. 34. 41.958 34.0942 MAarrowhead1
% End of user PostScript
.65851 .52583 m
.6568 .52639 L
s
% Start of user PostScript
43. 34. 42.887 34.0373 MAarrowhead1
% End of user PostScript
.67361 .52583 m
.67361 .52535 L
s
% Start of user PostScript
44. 34. 44. 33.9682 MAarrowhead1
% End of user PostScript
.68872 .52583 m
.68634 .5249 L
s
% Start of user PostScript
45. 34. 44.8427 33.9384 MAarrowhead1
% End of user PostScript
.70382 .52583 m
.70302 .52583 L
s
% Start of user PostScript
46. 34. 45.9467 34. MAarrowhead1
% End of user PostScript
.71893 .52583 m
.71782 .52573 L
s
% Start of user PostScript
47. 34. 46.9267 33.9934 MAarrowhead1
% End of user PostScript
.73403 .52583 m
.72927 .52069 L
s
% Start of user PostScript
48. 34. 47.6847 33.6597 MAarrowhead1
% End of user PostScript
.74914 .52583 m
.74701 .5231 L
s
% Start of user PostScript
49. 34. 48.8592 33.8193 MAarrowhead1
% End of user PostScript
.76424 .52583 m
.7643 .52577 L
s
% Start of user PostScript
50. 34. 50.0035 33.9965 MAarrowhead1
% End of user PostScript
.77935 .52583 m
.77935 .52502 L
s
% Start of user PostScript
51. 34. 51. 33.9467 MAarrowhead1
% End of user PostScript
.79445 .52583 m
.79445 .52583 L
s
% Start of user PostScript
52. 34. MAarrowzero1
% End of user PostScript
.80956 .52583 m
.80956 .52583 L
s
% Start of user PostScript
53. 34. MAarrowzero1
% End of user PostScript
.82466 .52583 m
.82466 .52583 L
s
% Start of user PostScript
54. 34. MAarrowzero1
% End of user PostScript
.83977 .52583 m
.83977 .52583 L
s
% Start of user PostScript
55. 34. MAarrowzero1
% End of user PostScript
.85488 .52583 m
.85488 .52583 L
s
% Start of user PostScript
56. 34. MAarrowzero1
% End of user PostScript
.86998 .52583 m
.86998 .52611 L
s
% Start of user PostScript
57. 34. 57. 34.0185 MAarrowhead1
% End of user PostScript
.88509 .52583 m
.88509 .52583 L
s
% Start of user PostScript
58. 34. MAarrowzero1
% End of user PostScript
.90019 .52583 m
.90019 .52583 L
s
% Start of user PostScript
59. 34. MAarrowzero1
% End of user PostScript
.9153 .52583 m
.9153 .52583 L
s
% Start of user PostScript
60. 34. MAarrowzero1
% End of user PostScript
.9304 .52583 m
.9304 .52583 L
s
% Start of user PostScript
61. 34. MAarrowzero1
% End of user PostScript
.94551 .52583 m
.94551 .52583 L
s
% Start of user PostScript
62. 34. MAarrowzero1
% End of user PostScript
.96061 .52583 m
.96061 .52583 L
s
% Start of user PostScript
63. 34. MAarrowzero1
% End of user PostScript
.97572 .52583 m
.97572 .52583 L
s
% Start of user PostScript
64. 34. MAarrowzero1
% End of user PostScript
.02409 .54093 m
.02409 .54093 L
s
% Start of user PostScript
1. 35. MAarrowzero1
% End of user PostScript
.03919 .54093 m
.03919 .54093 L
s
% Start of user PostScript
2. 35. MAarrowzero1
% End of user PostScript
.0543 .54093 m
.0543 .54093 L
s
% Start of user PostScript
3. 35. MAarrowzero1
% End of user PostScript
.0694 .54093 m
.0694 .54093 L
s
% Start of user PostScript
4. 35. MAarrowzero1
% End of user PostScript
.08451 .54093 m
.08479 .54093 L
s
% Start of user PostScript
5. 35. 5.01851 35. MAarrowhead1
% End of user PostScript
.09962 .54093 m
.09962 .54093 L
s
% Start of user PostScript
6. 35. MAarrowzero1
% End of user PostScript
.11472 .54093 m
.11472 .54093 L
s
% Start of user PostScript
7. 35. MAarrowzero1
% End of user PostScript
.12983 .54093 m
.12983 .54093 L
s
% Start of user PostScript
8. 35. MAarrowzero1
% End of user PostScript
.14493 .54093 m
.13977 .54402 L
s
% Start of user PostScript
9. 35. 8.65831 35.2047 MAarrowhead1
% End of user PostScript
.16004 .54093 m
.16308 .54194 L
s
% Start of user PostScript
10. 35. 10.2015 35.0667 MAarrowhead1
% End of user PostScript
.17514 .54093 m
.1771 .54102 L
s
% Start of user PostScript
11. 35. 11.1294 35.006 MAarrowhead1
% End of user PostScript
.19025 .54093 m
.19025 .54093 L
s
% Start of user PostScript
12. 35. MAarrowzero1
% End of user PostScript
.20535 .54093 m
.20535 .53819 L
s
% Start of user PostScript
13. 35. 13. 34.8185 MAarrowhead1
% End of user PostScript
.22046 .54093 m
.22147 .54362 L
s
% Start of user PostScript
14. 35. 14.0674 35.178 MAarrowhead1
% End of user PostScript
.23556 .54093 m
.23466 .53983 L
s
% Start of user PostScript
15. 35. 14.9405 34.9269 MAarrowhead1
% End of user PostScript
.25067 .54093 m
.25039 .54051 L
s
% Start of user PostScript
16. 35. 15.9815 34.9721 MAarrowhead1
% End of user PostScript
.26577 .54093 m
.26621 .54283 L
s
% Start of user PostScript
17. 35. 17.0291 35.126 MAarrowhead1
% End of user PostScript
.28088 .54093 m
.28247 .54531 L
s
% Start of user PostScript
18. 35. 18.1055 35.2902 MAarrowhead1
% End of user PostScript
.29598 .54093 m
.29302 .53845 L
s
% Start of user PostScript
19. 35. 18.804 34.8357 MAarrowhead1
% End of user PostScript
.31109 .54093 m
.30774 .54913 L
s
% Start of user PostScript
20. 35. 19.7783 35.5431 MAarrowhead1
% End of user PostScript
.32619 .54093 m
.32847 .54612 L
s
% Start of user PostScript
21. 35. 21.1507 35.3436 MAarrowhead1
% End of user PostScript
.3413 .54093 m
.34344 .54165 L
s
% Start of user PostScript
22. 35. 22.1421 35.0478 MAarrowhead1
% End of user PostScript
.3564 .54093 m
.35575 .53883 L
s
% Start of user PostScript
23. 35. 22.9569 34.8612 MAarrowhead1
% End of user PostScript
.37151 .54093 m
.37118 .53839 L
s
% Start of user PostScript
24. 35. 23.978 34.8321 MAarrowhead1
% End of user PostScript
.38661 .54093 m
.38628 .54074 L
s
% Start of user PostScript
25. 35. 24.978 34.9871 MAarrowhead1
% End of user PostScript
.40172 .54093 m
.40205 .54126 L
s
% Start of user PostScript
26. 35. 26.022 35.022 MAarrowhead1
% End of user PostScript
.41682 .54093 m
.41739 .54136 L
s
% Start of user PostScript
27. 35. 27.0376 35.0282 MAarrowhead1
% End of user PostScript
.43193 .54093 m
.43404 .54175 L
s
% Start of user PostScript
28. 35. 28.14 35.0545 MAarrowhead1
% End of user PostScript
.44703 .54093 m
.44904 .54096 L
s
% Start of user PostScript
29. 35. 29.1329 35.002 MAarrowhead1
% End of user PostScript
.46214 .54093 m
.46044 .54255 L
s
% Start of user PostScript
30. 35. 29.8871 35.1075 MAarrowhead1
% End of user PostScript
.47725 .54093 m
.47412 .53924 L
s
% Start of user PostScript
31. 35. 30.793 34.888 MAarrowhead1
% End of user PostScript
.49235 .54093 m
.48504 .54332 L
s
% Start of user PostScript
32. 35. 31.5164 35.1584 MAarrowhead1
% End of user PostScript
.50746 .54093 m
.50455 .53865 L
s
% Start of user PostScript
33. 35. 32.8079 34.8493 MAarrowhead1
% End of user PostScript
.52256 .54093 m
.51773 .54209 L
s
% Start of user PostScript
34. 35. 33.6805 35.0769 MAarrowhead1
% End of user PostScript
.53767 .54093 m
.538 .5386 L
s
% Start of user PostScript
35. 35. 35.022 34.8458 MAarrowhead1
% End of user PostScript
.55277 .54093 m
.55179 .54033 L
s
% Start of user PostScript
36. 35. 35.9349 34.9604 MAarrowhead1
% End of user PostScript
.56788 .54093 m
.56597 .54073 L
s
% Start of user PostScript
37. 35. 36.874 34.9869 MAarrowhead1
% End of user PostScript
.58298 .54093 m
.58261 .54136 L
s
% Start of user PostScript
38. 35. 37.9753 35.0282 MAarrowhead1
% End of user PostScript
.59809 .54093 m
.59803 .54174 L
s
% Start of user PostScript
39. 35. 38.9963 35.0533 MAarrowhead1
% End of user PostScript
.61319 .54093 m
.61367 .5435 L
s
% Start of user PostScript
40. 35. 40.0314 35.1702 MAarrowhead1
% End of user PostScript
.6283 .54093 m
.62878 .54107 L
s
% Start of user PostScript
41. 35. 41.0318 35.0094 MAarrowhead1
% End of user PostScript
.6434 .54093 m
.64587 .54207 L
s
% Start of user PostScript
42. 35. 42.1633 35.0756 MAarrowhead1
% End of user PostScript
.65851 .54093 m
.65851 .53903 L
s
% Start of user PostScript
43. 35. 43. 34.874 MAarrowhead1
% End of user PostScript
.67361 .54093 m
.67214 .53987 L
s
% Start of user PostScript
44. 35. 43.9024 34.9297 MAarrowhead1
% End of user PostScript
.68872 .54093 m
.68604 .53889 L
s
% Start of user PostScript
45. 35. 44.8227 34.8646 MAarrowhead1
% End of user PostScript
.70382 .54093 m
.70363 .54126 L
s
% Start of user PostScript
46. 35. 45.9875 35.022 MAarrowhead1
% End of user PostScript
.71893 .54093 m
.71743 .54065 L
s
% Start of user PostScript
47. 35. 46.9008 34.9812 MAarrowhead1
% End of user PostScript
.73403 .54093 m
.73095 .53719 L
s
% Start of user PostScript
48. 35. 47.796 34.7521 MAarrowhead1
% End of user PostScript
.74914 .54093 m
.74676 .53723 L
s
% Start of user PostScript
49. 35. 48.8427 34.7552 MAarrowhead1
% End of user PostScript
.76424 .54093 m
.7622 .53722 L
s
% Start of user PostScript
50. 35. 49.8649 34.7544 MAarrowhead1
% End of user PostScript
.77935 .54093 m
.77935 .54093 L
s
% Start of user PostScript
51. 35. MAarrowzero1
% End of user PostScript
.79445 .54093 m
.79445 .54093 L
s
% Start of user PostScript
52. 35. MAarrowzero1
% End of user PostScript
.80956 .54093 m
.80956 .54093 L
s
% Start of user PostScript
53. 35. MAarrowzero1
% End of user PostScript
.82466 .54093 m
.82466 .54093 L
s
% Start of user PostScript
54. 35. MAarrowzero1
% End of user PostScript
.83977 .54093 m
.83977 .54093 L
s
% Start of user PostScript
55. 35. MAarrowzero1
% End of user PostScript
.85488 .54093 m
.85488 .54093 L
s
% Start of user PostScript
56. 35. MAarrowzero1
% End of user PostScript
.86998 .54093 m
.86998 .54093 L
s
% Start of user PostScript
57. 35. MAarrowzero1
% End of user PostScript
.88509 .54093 m
.88509 .54093 L
s
% Start of user PostScript
58. 35. MAarrowzero1
% End of user PostScript
.90019 .54093 m
.90019 .54093 L
s
% Start of user PostScript
59. 35. MAarrowzero1
% End of user PostScript
.9153 .54093 m
.9153 .54093 L
s
% Start of user PostScript
60. 35. MAarrowzero1
% End of user PostScript
.9304 .54093 m
.9304 .54121 L
s
% Start of user PostScript
61. 35. 61. 35.0185 MAarrowhead1
% End of user PostScript
.94551 .54093 m
.94551 .54093 L
s
% Start of user PostScript
62. 35. MAarrowzero1
% End of user PostScript
.96061 .54093 m
.96061 .54093 L
s
% Start of user PostScript
63. 35. MAarrowzero1
% End of user PostScript
.97572 .54093 m
.97572 .54093 L
s
% Start of user PostScript
64. 35. MAarrowzero1
% End of user PostScript
.02409 .55604 m
.02409 .55604 L
s
% Start of user PostScript
1. 36. MAarrowzero1
% End of user PostScript
.03919 .55604 m
.03919 .55604 L
s
% Start of user PostScript
2. 36. MAarrowzero1
% End of user PostScript
.0543 .55604 m
.05458 .55604 L
s
% Start of user PostScript
3. 36. 3.01851 36. MAarrowhead1
% End of user PostScript
.0694 .55604 m
.0694 .55604 L
s
% Start of user PostScript
4. 36. MAarrowzero1
% End of user PostScript
.08451 .55604 m
.08479 .55604 L
s
% Start of user PostScript
5. 36. 5.01851 36. MAarrowhead1
% End of user PostScript
.09962 .55604 m
.09962 .55604 L
s
% Start of user PostScript
6. 36. MAarrowzero1
% End of user PostScript
.11472 .55604 m
.11472 .55632 L
s
% Start of user PostScript
7. 36. 7. 36.0185 MAarrowhead1
% End of user PostScript
.12983 .55604 m
.12983 .55604 L
s
% Start of user PostScript
8. 36. MAarrowzero1
% End of user PostScript
.14493 .55604 m
.14892 .55504 L
s
% Start of user PostScript
9. 36. 9.26427 35.9339 MAarrowhead1
% End of user PostScript
.16004 .55604 m
.16088 .56067 L
s
% Start of user PostScript
10. 36. 10.0556 36.3066 MAarrowhead1
% End of user PostScript
.17514 .55604 m
.17333 .55604 L
s
% Start of user PostScript
11. 36. 10.88 36. MAarrowhead1
% End of user PostScript
.19025 .55604 m
.19025 .55751 L
s
% Start of user PostScript
12. 36. 12. 36.0976 MAarrowhead1
% End of user PostScript
.20535 .55604 m
.20357 .55265 L
s
% Start of user PostScript
13. 36. 12.882 35.776 MAarrowhead1
% End of user PostScript
.22046 .55604 m
.21993 .55704 L
s
% Start of user PostScript
14. 36. 13.9652 36.0665 MAarrowhead1
% End of user PostScript
.23556 .55604 m
.23399 .55561 L
s
% Start of user PostScript
15. 36. 14.896 35.9718 MAarrowhead1
% End of user PostScript
.25067 .55604 m
.25067 .55576 L
s
% Start of user PostScript
16. 36. 16. 35.9815 MAarrowhead1
% End of user PostScript
.26577 .55604 m
.26661 .55509 L
s
% Start of user PostScript
17. 36. 17.0556 35.9373 MAarrowhead1
% End of user PostScript
.28088 .55604 m
.28422 .5547 L
s
% Start of user PostScript
18. 36. 18.2215 35.9114 MAarrowhead1
% End of user PostScript
.29598 .55604 m
.3019 .55174 L
s
% Start of user PostScript
19. 36. 19.3917 35.7156 MAarrowhead1
% End of user PostScript
.31109 .55604 m
.31705 .55035 L
s
% Start of user PostScript
20. 36. 20.3949 35.6236 MAarrowhead1
% End of user PostScript
.32619 .55604 m
.33206 .54973 L
s
% Start of user PostScript
21. 36. 21.3882 35.5827 MAarrowhead1
% End of user PostScript
.3413 .55604 m
.34392 .55322 L
s
% Start of user PostScript
22. 36. 22.1733 35.8133 MAarrowhead1
% End of user PostScript
.3564 .55604 m
.35553 .55535 L
s
% Start of user PostScript
23. 36. 22.942 35.9546 MAarrowhead1
% End of user PostScript
.37151 .55604 m
.37146 .55523 L
s
% Start of user PostScript
24. 36. 23.9965 35.9467 MAarrowhead1
% End of user PostScript
.38661 .55604 m
.38628 .55579 L
s
% Start of user PostScript
25. 36. 24.978 35.9836 MAarrowhead1
% End of user PostScript
.40172 .55604 m
.40197 .55604 L
s
% Start of user PostScript
26. 36. 26.0164 36. MAarrowhead1
% End of user PostScript
.41682 .55604 m
.4173 .55576 L
s
% Start of user PostScript
27. 36. 27.0314 35.9815 MAarrowhead1
% End of user PostScript
.43193 .55604 m
.43283 .55688 L
s
% Start of user PostScript
28. 36. 28.0595 36.0561 MAarrowhead1
% End of user PostScript
.44703 .55604 m
.44698 .55641 L
s
% Start of user PostScript
29. 36. 28.9965 36.0247 MAarrowhead1
% End of user PostScript
.46214 .55604 m
.46295 .55494 L
s
% Start of user PostScript
30. 36. 30.0533 35.9274 MAarrowhead1
% End of user PostScript
.47725 .55604 m
.47985 .55189 L
s
% Start of user PostScript
31. 36. 31.1725 35.7258 MAarrowhead1
% End of user PostScript
.49235 .55604 m
.49391 .555 L
s
% Start of user PostScript
32. 36. 32.1036 35.9313 MAarrowhead1
% End of user PostScript
.50746 .55604 m
.51201 .55285 L
s
% Start of user PostScript
33. 36. 33.3017 35.7888 MAarrowhead1
% End of user PostScript
.52256 .55604 m
.52767 .54988 L
s
% Start of user PostScript
34. 36. 34.3381 35.5927 MAarrowhead1
% End of user PostScript
.53767 .55604 m
.5392 .55246 L
s
% Start of user PostScript
35. 36. 35.1015 35.7631 MAarrowhead1
% End of user PostScript
.55277 .55604 m
.55501 .55394 L
s
% Start of user PostScript
36. 36. 36.1479 35.8612 MAarrowhead1
% End of user PostScript
.56788 .55604 m
.5683 .55514 L
s
% Start of user PostScript
37. 36. 37.0282 35.9405 MAarrowhead1
% End of user PostScript
.58298 .55604 m
.58371 .55656 L
s
% Start of user PostScript
38. 36. 38.0479 36.0348 MAarrowhead1
% End of user PostScript
.59809 .55604 m
.59802 .55667 L
s
% Start of user PostScript
39. 36. 38.9955 36.042 MAarrowhead1
% End of user PostScript
.61319 .55604 m
.61509 .55732 L
s
% Start of user PostScript
40. 36. 40.1255 36.0851 MAarrowhead1
% End of user PostScript
.6283 .55604 m
.62914 .55652 L
s
% Start of user PostScript
41. 36. 41.0561 36.0318 MAarrowhead1
% End of user PostScript
.6434 .55604 m
.64289 .55751 L
s
% Start of user PostScript
42. 36. 41.9663 36.0976 MAarrowhead1
% End of user PostScript
.65851 .55604 m
.6577 .55522 L
s
% Start of user PostScript
43. 36. 42.9462 35.9462 MAarrowhead1
% End of user PostScript
.67361 .55604 m
.67503 .55495 L
s
% Start of user PostScript
44. 36. 44.0942 35.9278 MAarrowhead1
% End of user PostScript
.68872 .55604 m
.6855 .55366 L
s
% Start of user PostScript
45. 36. 44.787 35.8427 MAarrowhead1
% End of user PostScript
.70382 .55604 m
.70539 .55714 L
s
% Start of user PostScript
46. 36. 46.104 36.0733 MAarrowhead1
% End of user PostScript
.71893 .55604 m
.71743 .55392 L
s
% Start of user PostScript
47. 36. 46.9008 35.86 MAarrowhead1
% End of user PostScript
.73403 .55604 m
.73266 .55398 L
s
% Start of user PostScript
48. 36. 47.9089 35.8637 MAarrowhead1
% End of user PostScript
.74914 .55604 m
.74757 .5537 L
s
% Start of user PostScript
49. 36. 48.896 35.8452 MAarrowhead1
% End of user PostScript
.76424 .55604 m
.76349 .55136 L
s
% Start of user PostScript
50. 36. 49.9499 35.6905 MAarrowhead1
% End of user PostScript
.77935 .55604 m
.77935 .55604 L
s
% Start of user PostScript
51. 36. MAarrowzero1
% End of user PostScript
.79445 .55604 m
.79445 .55604 L
s
% Start of user PostScript
52. 36. MAarrowzero1
% End of user PostScript
.80956 .55604 m
.80956 .55604 L
s
% Start of user PostScript
53. 36. MAarrowzero1
% End of user PostScript
.82466 .55604 m
.82466 .55604 L
s
% Start of user PostScript
54. 36. MAarrowzero1
% End of user PostScript
.83977 .55604 m
.83977 .55604 L
s
% Start of user PostScript
55. 36. MAarrowzero1
% End of user PostScript
.85488 .55604 m
.85488 .55604 L
s
% Start of user PostScript
56. 36. MAarrowzero1
% End of user PostScript
.86998 .55604 m
.86998 .55604 L
s
% Start of user PostScript
57. 36. MAarrowzero1
% End of user PostScript
.88509 .55604 m
.88509 .55604 L
s
% Start of user PostScript
58. 36. MAarrowzero1
% End of user PostScript
.90019 .55604 m
.90019 .55604 L
s
% Start of user PostScript
59. 36. MAarrowzero1
% End of user PostScript
.9153 .55604 m
.9153 .55604 L
s
% Start of user PostScript
60. 36. MAarrowzero1
% End of user PostScript
.9304 .55604 m
.9304 .55604 L
s
% Start of user PostScript
61. 36. MAarrowzero1
% End of user PostScript
.94551 .55604 m
.94551 .55604 L
s
% Start of user PostScript
62. 36. MAarrowzero1
% End of user PostScript
.96061 .55604 m
.96061 .55604 L
s
% Start of user PostScript
63. 36. MAarrowzero1
% End of user PostScript
.97572 .55604 m
.97572 .55632 L
s
% Start of user PostScript
64. 36. 64. 36.0185 MAarrowhead1
% End of user PostScript
.02409 .57114 m
.02409 .57114 L
s
% Start of user PostScript
1. 37. MAarrowzero1
% End of user PostScript
.03919 .57114 m
.03947 .57114 L
s
% Start of user PostScript
2. 37. 2.01851 37. MAarrowhead1
% End of user PostScript
.0543 .57114 m
.0543 .57114 L
s
% Start of user PostScript
3. 37. MAarrowzero1
% End of user PostScript
.0694 .57114 m
.0694 .57086 L
s
% Start of user PostScript
4. 37. 4. 36.9815 MAarrowhead1
% End of user PostScript
.08451 .57114 m
.08451 .57114 L
s
% Start of user PostScript
5. 37. MAarrowzero1
% End of user PostScript
.09962 .57114 m
.09962 .57114 L
s
% Start of user PostScript
6. 37. MAarrowzero1
% End of user PostScript
.11472 .57114 m
.11472 .57086 L
s
% Start of user PostScript
7. 37. 7. 36.9815 MAarrowhead1
% End of user PostScript
.12983 .57114 m
.12935 .57195 L
s
% Start of user PostScript
8. 37. 7.96863 37.0533 MAarrowhead1
% End of user PostScript
.14493 .57114 m
.15542 .58214 L
s
% Start of user PostScript
9. 37. 9.69431 37.728 MAarrowhead1
% End of user PostScript
.16004 .57114 m
.16155 .57368 L
s
% Start of user PostScript
10. 37. 10.1001 37.1679 MAarrowhead1
% End of user PostScript
.17514 .57114 m
.17514 .5703 L
s
% Start of user PostScript
11. 37. 11. 36.9444 MAarrowhead1
% End of user PostScript
.19025 .57114 m
.1923 .57271 L
s
% Start of user PostScript
12. 37. 12.1361 37.104 MAarrowhead1
% End of user PostScript
.20535 .57114 m
.20446 .56971 L
s
% Start of user PostScript
13. 37. 12.9413 36.9054 MAarrowhead1
% End of user PostScript
.22046 .57114 m
.21903 .57155 L
s
% Start of user PostScript
14. 37. 13.9054 37.0272 MAarrowhead1
% End of user PostScript
.23556 .57114 m
.23396 .57017 L
s
% Start of user PostScript
15. 37. 14.894 36.9356 MAarrowhead1
% End of user PostScript
.25067 .57114 m
.25118 .57172 L
s
% Start of user PostScript
16. 37. 16.0337 37.0385 MAarrowhead1
% End of user PostScript
.26577 .57114 m
.2644 .57156 L
s
% Start of user PostScript
17. 37. 16.9091 37.0279 MAarrowhead1
% End of user PostScript
.28088 .57114 m
.28096 .57123 L
s
% Start of user PostScript
18. 37. 18.0055 37.0055 MAarrowhead1
% End of user PostScript
.29598 .57114 m
.2959 .57175 L
s
% Start of user PostScript
19. 37. 18.9945 37.0405 MAarrowhead1
% End of user PostScript
.31109 .57114 m
.30878 .57628 L
s
% Start of user PostScript
20. 37. 19.8471 37.3403 MAarrowhead1
% End of user PostScript
.32619 .57114 m
.32555 .57248 L
s
% Start of user PostScript
21. 37. 20.9576 37.0886 MAarrowhead1
% End of user PostScript
.3413 .57114 m
.34424 .56623 L
s
% Start of user PostScript
22. 37. 22.1946 36.6745 MAarrowhead1
% End of user PostScript
.3564 .57114 m
.35693 .56982 L
s
% Start of user PostScript
23. 37. 23.0348 36.9125 MAarrowhead1
% End of user PostScript
.37151 .57114 m
.37151 .57075 L
s
% Start of user PostScript
24. 37. 24. 36.9742 MAarrowhead1
% End of user PostScript
.38661 .57114 m
.38622 .57075 L
s
% Start of user PostScript
25. 37. 24.9742 36.9742 MAarrowhead1
% End of user PostScript
.40172 .57114 m
.40164 .57106 L
s
% Start of user PostScript
26. 37. 25.9945 36.9945 MAarrowhead1
% End of user PostScript
.41682 .57114 m
.41716 .57106 L
s
% Start of user PostScript
27. 37. 27.022 36.9945 MAarrowhead1
% End of user PostScript
.43193 .57114 m
.43283 .57147 L
s
% Start of user PostScript
28. 37. 28.0595 37.022 MAarrowhead1
% End of user PostScript
.44703 .57114 m
.45045 .57114 L
s
% Start of user PostScript
29. 37. 29.226 37. MAarrowhead1
% End of user PostScript
.46214 .57114 m
.46371 .5719 L
s
% Start of user PostScript
30. 37. 30.104 37.0502 MAarrowhead1
% End of user PostScript
.47725 .57114 m
.47397 .57243 L
s
% Start of user PostScript
31. 37. 30.7831 37.0851 MAarrowhead1
% End of user PostScript
.49235 .57114 m
.48769 .57236 L
s
% Start of user PostScript
32. 37. 31.6914 37.0804 MAarrowhead1
% End of user PostScript
.50746 .57114 m
.50647 .57128 L
s
% Start of user PostScript
33. 37. 32.9348 37.0094 MAarrowhead1
% End of user PostScript
.52256 .57114 m
.52307 .57063 L
s
% Start of user PostScript
34. 37. 34.0337 36.9663 MAarrowhead1
% End of user PostScript
.53767 .57114 m
.53781 .5708 L
s
% Start of user PostScript
35. 37. 35.0094 36.9776 MAarrowhead1
% End of user PostScript
.55277 .57114 m
.55277 .57202 L
s
% Start of user PostScript
36. 37. 36. 37.058 MAarrowhead1
% End of user PostScript
.56788 .57114 m
.56782 .57375 L
s
% Start of user PostScript
37. 37. 36.9963 37.1729 MAarrowhead1
% End of user PostScript
.58298 .57114 m
.58298 .57076 L
s
% Start of user PostScript
38. 37. 38. 36.9746 MAarrowhead1
% End of user PostScript
.59809 .57114 m
.59851 .57241 L
s
% Start of user PostScript
39. 37. 39.0282 37.084 MAarrowhead1
% End of user PostScript
.61319 .57114 m
.61319 .57178 L
s
% Start of user PostScript
40. 37. 40. 37.042 MAarrowhead1
% End of user PostScript
.6283 .57114 m
.62883 .5731 L
s
% Start of user PostScript
41. 37. 41.0353 37.1294 MAarrowhead1
% End of user PostScript
.6434 .57114 m
.64421 .57368 L
s
% Start of user PostScript
42. 37. 42.0538 37.1679 MAarrowhead1
% End of user PostScript
.65851 .57114 m
.65899 .57114 L
s
% Start of user PostScript
43. 37. 43.0318 37. MAarrowhead1
% End of user PostScript
.67361 .57114 m
.67361 .56966 L
s
% Start of user PostScript
44. 37. 44. 36.902 MAarrowhead1
% End of user PostScript
.68872 .57114 m
.68858 .56919 L
s
% Start of user PostScript
45. 37. 44.9906 36.8706 MAarrowhead1
% End of user PostScript
.70382 .57114 m
.70465 .57144 L
s
% Start of user PostScript
46. 37. 46.0545 37.02 MAarrowhead1
% End of user PostScript
.71893 .57114 m
.71597 .56877 L
s
% Start of user PostScript
47. 37. 46.8039 36.8427 MAarrowhead1
% End of user PostScript
.73403 .57114 m
.7312 .56977 L
s
% Start of user PostScript
48. 37. 47.8126 36.9091 MAarrowhead1
% End of user PostScript
.74914 .57114 m
.74864 .56913 L
s
% Start of user PostScript
49. 37. 48.967 36.8667 MAarrowhead1
% End of user PostScript
.76424 .57114 m
.76424 .57034 L
s
% Start of user PostScript
50. 37. 50. 36.9467 MAarrowhead1
% End of user PostScript
.77935 .57114 m
.77935 .57114 L
s
% Start of user PostScript
51. 37. MAarrowzero1
% End of user PostScript
.79445 .57114 m
.79445 .57114 L
s
% Start of user PostScript
52. 37. MAarrowzero1
% End of user PostScript
.80956 .57114 m
.80956 .57114 L
s
% Start of user PostScript
53. 37. MAarrowzero1
% End of user PostScript
.82466 .57114 m
.82466 .57114 L
s
% Start of user PostScript
54. 37. MAarrowzero1
% End of user PostScript
.83977 .57114 m
.83977 .57114 L
s
% Start of user PostScript
55. 37. MAarrowzero1
% End of user PostScript
.85488 .57114 m
.85488 .57114 L
s
% Start of user PostScript
56. 37. MAarrowzero1
% End of user PostScript
.86998 .57114 m
.86998 .57114 L
s
% Start of user PostScript
57. 37. MAarrowzero1
% End of user PostScript
.88509 .57114 m
.88509 .57114 L
s
% Start of user PostScript
58. 37. MAarrowzero1
% End of user PostScript
.90019 .57114 m
.90019 .57114 L
s
% Start of user PostScript
59. 37. MAarrowzero1
% End of user PostScript
.9153 .57114 m
.9153 .57114 L
s
% Start of user PostScript
60. 37. MAarrowzero1
% End of user PostScript
.9304 .57114 m
.9304 .57114 L
s
% Start of user PostScript
61. 37. MAarrowzero1
% End of user PostScript
.94551 .57114 m
.94551 .57114 L
s
% Start of user PostScript
62. 37. MAarrowzero1
% End of user PostScript
.96061 .57114 m
.96061 .57114 L
s
% Start of user PostScript
63. 37. MAarrowzero1
% End of user PostScript
.97572 .57114 m
.97572 .57114 L
s
% Start of user PostScript
64. 37. MAarrowzero1
% End of user PostScript
.02409 .58625 m
.02409 .58625 L
s
% Start of user PostScript
1. 38. MAarrowzero1
% End of user PostScript
.03919 .58625 m
.03919 .58625 L
s
% Start of user PostScript
2. 38. MAarrowzero1
% End of user PostScript
.0543 .58625 m
.0543 .58625 L
s
% Start of user PostScript
3. 38. MAarrowzero1
% End of user PostScript
.0694 .58625 m
.0694 .58625 L
s
% Start of user PostScript
4. 38. MAarrowzero1
% End of user PostScript
.08451 .58625 m
.08451 .58625 L
s
% Start of user PostScript
5. 38. MAarrowzero1
% End of user PostScript
.09962 .58625 m
.09962 .58625 L
s
% Start of user PostScript
6. 38. MAarrowzero1
% End of user PostScript
.11472 .58625 m
.11444 .58597 L
s
% Start of user PostScript
7. 38. 6.98149 37.9815 MAarrowhead1
% End of user PostScript
.12983 .58625 m
.13392 .5911 L
s
% Start of user PostScript
8. 38. 8.27137 38.3215 MAarrowhead1
% End of user PostScript
.14493 .58625 m
.14673 .5964 L
s
% Start of user PostScript
9. 38. 9.11882 38.6724 MAarrowhead1
% End of user PostScript
.16004 .58625 m
.16004 .58458 L
s
% Start of user PostScript
10. 38. 10. 37.8894 MAarrowhead1
% End of user PostScript
.17514 .58625 m
.1772 .58625 L
s
% Start of user PostScript
11. 38. 11.1361 38. MAarrowhead1
% End of user PostScript
.19025 .58625 m
.19016 .58688 L
s
% Start of user PostScript
12. 38. 11.994 38.042 MAarrowhead1
% End of user PostScript
.20535 .58625 m
.20473 .58625 L
s
% Start of user PostScript
13. 38. 12.9588 38. MAarrowhead1
% End of user PostScript
.22046 .58625 m
.21901 .58513 L
s
% Start of user PostScript
14. 38. 13.9043 37.9258 MAarrowhead1
% End of user PostScript
.23556 .58625 m
.23355 .58434 L
s
% Start of user PostScript
15. 38. 14.8667 37.874 MAarrowhead1
% End of user PostScript
.25067 .58625 m
.25019 .58583 L
s
% Start of user PostScript
16. 38. 15.9686 37.9721 MAarrowhead1
% End of user PostScript
.26577 .58625 m
.26857 .58328 L
s
% Start of user PostScript
17. 38. 17.1851 37.8039 MAarrowhead1
% End of user PostScript
.28088 .58625 m
.28125 .58695 L
s
% Start of user PostScript
18. 38. 18.0247 38.0468 MAarrowhead1
% End of user PostScript
.29598 .58625 m
.2978 .58455 L
s
% Start of user PostScript
19. 38. 19.1203 37.8875 MAarrowhead1
% End of user PostScript
.31109 .58625 m
.31405 .58038 L
s
% Start of user PostScript
20. 38. 20.196 37.6119 MAarrowhead1
% End of user PostScript
.32619 .58625 m
.32658 .58552 L
s
% Start of user PostScript
21. 38. 21.0258 37.9522 MAarrowhead1
% End of user PostScript
.3413 .58625 m
.3413 .58586 L
s
% Start of user PostScript
22. 38. 22. 37.9742 MAarrowhead1
% End of user PostScript
.3564 .58625 m
.3564 .58625 L
s
% Start of user PostScript
23. 38. MAarrowzero1
% End of user PostScript
.37151 .58625 m
.37151 .58625 L
s
% Start of user PostScript
24. 38. MAarrowzero1
% End of user PostScript
.38661 .58625 m
.38714 .58672 L
s
% Start of user PostScript
25. 38. 25.0348 38.0314 MAarrowhead1
% End of user PostScript
.40172 .58625 m
.40172 .58577 L
s
% Start of user PostScript
26. 38. 26. 37.9686 MAarrowhead1
% End of user PostScript
.41682 .58625 m
.41721 .58577 L
s
% Start of user PostScript
27. 38. 27.0258 37.9686 MAarrowhead1
% End of user PostScript
.43193 .58625 m
.43226 .58616 L
s
% Start of user PostScript
28. 38. 28.022 37.9945 MAarrowhead1
% End of user PostScript
.44703 .58625 m
.44728 .58592 L
s
% Start of user PostScript
29. 38. 29.0164 37.978 MAarrowhead1
% End of user PostScript
.46214 .58625 m
.46346 .58633 L
s
% Start of user PostScript
30. 38. 30.0875 38.0056 MAarrowhead1
% End of user PostScript
.47725 .58625 m
.48068 .58438 L
s
% Start of user PostScript
31. 38. 31.2275 37.8765 MAarrowhead1
% End of user PostScript
.49235 .58625 m
.49858 .58133 L
s
% Start of user PostScript
32. 38. 32.4125 37.6745 MAarrowhead1
% End of user PostScript
.50746 .58625 m
.51264 .58374 L
s
% Start of user PostScript
33. 38. 33.3435 37.8342 MAarrowhead1
% End of user PostScript
.52256 .58625 m
.52158 .58661 L
s
% Start of user PostScript
34. 38. 33.9349 38.0238 MAarrowhead1
% End of user PostScript
.53767 .58625 m
.53707 .5872 L
s
% Start of user PostScript
35. 38. 34.9604 38.0631 MAarrowhead1
% End of user PostScript
.55277 .58625 m
.55429 .58429 L
s
% Start of user PostScript
36. 38. 36.1003 37.8706 MAarrowhead1
% End of user PostScript
.56788 .58625 m
.56788 .58524 L
s
% Start of user PostScript
37. 38. 37. 37.9336 MAarrowhead1
% End of user PostScript
.58298 .58625 m
.58368 .58605 L
s
% Start of user PostScript
38. 38. 38.0461 37.9869 MAarrowhead1
% End of user PostScript
.59809 .58625 m
.59936 .58752 L
s
% Start of user PostScript
39. 38. 39.084 38.084 MAarrowhead1
% End of user PostScript
.61319 .58625 m
.61352 .58561 L
s
% Start of user PostScript
40. 38. 40.022 37.958 MAarrowhead1
% End of user PostScript
.6283 .58625 m
.62689 .58772 L
s
% Start of user PostScript
41. 38. 40.9066 38.0976 MAarrowhead1
% End of user PostScript
.6434 .58625 m
.64373 .58462 L
s
% Start of user PostScript
42. 38. 42.022 37.8924 MAarrowhead1
% End of user PostScript
.65851 .58625 m
.65793 .58891 L
s
% Start of user PostScript
43. 38. 42.9615 38.1762 MAarrowhead1
% End of user PostScript
.67361 .58625 m
.67275 .58681 L
s
% Start of user PostScript
44. 38. 43.9427 38.0373 MAarrowhead1
% End of user PostScript
.68872 .58625 m
.68815 .5853 L
s
% Start of user PostScript
45. 38. 44.9627 37.9373 MAarrowhead1
% End of user PostScript
.70382 .58625 m
.70289 .58606 L
s
% Start of user PostScript
46. 38. 45.9384 37.9875 MAarrowhead1
% End of user PostScript
.71893 .58625 m
.717 .58338 L
s
% Start of user PostScript
47. 38. 46.8721 37.8101 MAarrowhead1
% End of user PostScript
.73403 .58625 m
.73534 .58926 L
s
% Start of user PostScript
48. 38. 48.0863 38.1993 MAarrowhead1
% End of user PostScript
.74914 .58625 m
.74566 .57967 L
s
% Start of user PostScript
49. 38. 48.7696 37.5643 MAarrowhead1
% End of user PostScript
.76424 .58625 m
.76424 .58625 L
s
% Start of user PostScript
50. 38. MAarrowzero1
% End of user PostScript
.77935 .58625 m
.77935 .58625 L
s
% Start of user PostScript
51. 38. MAarrowzero1
% End of user PostScript
.79445 .58625 m
.79445 .58625 L
s
% Start of user PostScript
52. 38. MAarrowzero1
% End of user PostScript
.80956 .58625 m
.80956 .58625 L
s
% Start of user PostScript
53. 38. MAarrowzero1
% End of user PostScript
.82466 .58625 m
.82466 .58625 L
s
% Start of user PostScript
54. 38. MAarrowzero1
% End of user PostScript
.83977 .58625 m
.83977 .58625 L
s
% Start of user PostScript
55. 38. MAarrowzero1
% End of user PostScript
.85488 .58625 m
.85488 .58625 L
s
% Start of user PostScript
56. 38. MAarrowzero1
% End of user PostScript
.86998 .58625 m
.86998 .58625 L
s
% Start of user PostScript
57. 38. MAarrowzero1
% End of user PostScript
.88509 .58625 m
.88536 .58625 L
s
% Start of user PostScript
58. 38. 58.0185 38. MAarrowhead1
% End of user PostScript
.90019 .58625 m
.90019 .58653 L
s
% Start of user PostScript
59. 38. 59. 38.0185 MAarrowhead1
% End of user PostScript
.9153 .58625 m
.9153 .58625 L
s
% Start of user PostScript
60. 38. MAarrowzero1
% End of user PostScript
.9304 .58625 m
.9304 .58625 L
s
% Start of user PostScript
61. 38. MAarrowzero1
% End of user PostScript
.94551 .58625 m
.94551 .58625 L
s
% Start of user PostScript
62. 38. MAarrowzero1
% End of user PostScript
.96061 .58625 m
.96061 .58625 L
s
% Start of user PostScript
63. 38. MAarrowzero1
% End of user PostScript
.97572 .58625 m
.97572 .58625 L
s
% Start of user PostScript
64. 38. MAarrowzero1
% End of user PostScript
.02409 .60135 m
.02409 .60135 L
s
% Start of user PostScript
1. 39. MAarrowzero1
% End of user PostScript
.03919 .60135 m
.03919 .60163 L
s
% Start of user PostScript
2. 39. 2. 39.0185 MAarrowhead1
% End of user PostScript
.0543 .60135 m
.05458 .60135 L
s
% Start of user PostScript
3. 39. 3.01851 39. MAarrowhead1
% End of user PostScript
.0694 .60135 m
.0694 .60135 L
s
% Start of user PostScript
4. 39. MAarrowzero1
% End of user PostScript
.08451 .60135 m
.08451 .60135 L
s
% Start of user PostScript
5. 39. MAarrowzero1
% End of user PostScript
.09962 .60135 m
.09962 .60135 L
s
% Start of user PostScript
6. 39. MAarrowzero1
% End of user PostScript
.11472 .60135 m
.11472 .60135 L
s
% Start of user PostScript
7. 39. MAarrowzero1
% End of user PostScript
.12983 .60135 m
.13244 .60492 L
s
% Start of user PostScript
8. 39. 8.17333 39.2363 MAarrowhead1
% End of user PostScript
.14493 .60135 m
.14437 .60301 L
s
% Start of user PostScript
9. 39. 8.96278 39.1095 MAarrowhead1
% End of user PostScript
.16004 .60135 m
.15819 .59773 L
s
% Start of user PostScript
10. 39. 9.87773 38.76 MAarrowhead1
% End of user PostScript
.17514 .60135 m
.17628 .60253 L
s
% Start of user PostScript
11. 39. 11.0756 39.078 MAarrowhead1
% End of user PostScript
.19025 .60135 m
.19122 .60117 L
s
% Start of user PostScript
12. 39. 12.0644 38.9882 MAarrowhead1
% End of user PostScript
.20535 .60135 m
.20521 .60149 L
s
% Start of user PostScript
13. 39. 12.9906 39.0094 MAarrowhead1
% End of user PostScript
.22046 .60135 m
.21889 .59996 L
s
% Start of user PostScript
14. 39. 13.8964 38.9082 MAarrowhead1
% End of user PostScript
.23556 .60135 m
.23283 .59892 L
s
% Start of user PostScript
15. 39. 14.8192 38.8392 MAarrowhead1
% End of user PostScript
.25067 .60135 m
.25047 .60102 L
s
% Start of user PostScript
16. 39. 15.9871 38.978 MAarrowhead1
% End of user PostScript
.26577 .60135 m
.26577 .6013 L
s
% Start of user PostScript
17. 39. 17. 38.9965 MAarrowhead1
% End of user PostScript
.28088 .60135 m
.28088 .60135 L
s
% Start of user PostScript
18. 39. MAarrowzero1
% End of user PostScript
.29598 .60135 m
.29598 .60088 L
s
% Start of user PostScript
19. 39. 19. 38.9686 MAarrowhead1
% End of user PostScript
.31109 .60135 m
.31109 .60135 L
s
% Start of user PostScript
20. 39. MAarrowzero1
% End of user PostScript
.32619 .60135 m
.3258 .60135 L
s
% Start of user PostScript
21. 39. 20.9742 39. MAarrowhead1
% End of user PostScript
.3413 .60135 m
.3413 .60135 L
s
% Start of user PostScript
22. 39. MAarrowzero1
% End of user PostScript
.3564 .60135 m
.35601 .60135 L
s
% Start of user PostScript
23. 39. 22.9742 39. MAarrowhead1
% End of user PostScript
.37151 .60135 m
.37151 .6014 L
s
% Start of user PostScript
24. 39. 24. 39.0035 MAarrowhead1
% End of user PostScript
.38661 .60135 m
.38709 .60174 L
s
% Start of user PostScript
25. 39. 25.0314 39.0258 MAarrowhead1
% End of user PostScript
.40172 .60135 m
.40125 .60135 L
s
% Start of user PostScript
26. 39. 25.9686 39. MAarrowhead1
% End of user PostScript
.41682 .60135 m
.41682 .60183 L
s
% Start of user PostScript
27. 39. 27. 39.0314 MAarrowhead1
% End of user PostScript
.43193 .60135 m
.4324 .60135 L
s
% Start of user PostScript
28. 39. 28.0314 39. MAarrowhead1
% End of user PostScript
.44703 .60135 m
.44712 .60127 L
s
% Start of user PostScript
29. 39. 29.0055 38.9945 MAarrowhead1
% End of user PostScript
.46214 .60135 m
.46261 .60135 L
s
% Start of user PostScript
30. 39. 30.0314 39. MAarrowhead1
% End of user PostScript
.47725 .60135 m
.47697 .60121 L
s
% Start of user PostScript
31. 39. 30.9815 38.9906 MAarrowhead1
% End of user PostScript
.49235 .60135 m
.4924 .60135 L
s
% Start of user PostScript
32. 39. 32.0035 39. MAarrowhead1
% End of user PostScript
.50746 .60135 m
.50782 .60186 L
s
% Start of user PostScript
33. 39. 33.0243 39.0337 MAarrowhead1
% End of user PostScript
.52256 .60135 m
.5227 .60206 L
s
% Start of user PostScript
34. 39. 34.0094 39.0467 MAarrowhead1
% End of user PostScript
.53767 .60135 m
.53816 .60184 L
s
% Start of user PostScript
35. 39. 35.0325 39.0325 MAarrowhead1
% End of user PostScript
.55277 .60135 m
.55272 .60183 L
s
% Start of user PostScript
36. 39. 35.9965 39.0314 MAarrowhead1
% End of user PostScript
.56788 .60135 m
.5675 .60135 L
s
% Start of user PostScript
37. 39. 36.9753 39. MAarrowhead1
% End of user PostScript
.58298 .60135 m
.58346 .6013 L
s
% Start of user PostScript
38. 39. 38.0314 38.9963 MAarrowhead1
% End of user PostScript
.59809 .60135 m
.59936 .60196 L
s
% Start of user PostScript
39. 39. 39.084 39.0405 MAarrowhead1
% End of user PostScript
.61319 .60135 m
.61319 .60154 L
s
% Start of user PostScript
40. 39. 40. 39.0125 MAarrowhead1
% End of user PostScript
.6283 .60135 m
.62941 .60135 L
s
% Start of user PostScript
41. 39. 41.0738 39. MAarrowhead1
% End of user PostScript
.6434 .60135 m
.6453 .60241 L
s
% Start of user PostScript
42. 39. 42.126 39.0703 MAarrowhead1
% End of user PostScript
.65851 .60135 m
.6596 .60083 L
s
% Start of user PostScript
43. 39. 43.0722 38.9651 MAarrowhead1
% End of user PostScript
.67361 .60135 m
.67466 .60059 L
s
% Start of user PostScript
44. 39. 44.0691 38.9498 MAarrowhead1
% End of user PostScript
.68872 .60135 m
.69162 .60239 L
s
% Start of user PostScript
45. 39. 45.1922 39.0689 MAarrowhead1
% End of user PostScript
.70382 .60135 m
.69988 .59808 L
s
% Start of user PostScript
46. 39. 45.7391 38.7836 MAarrowhead1
% End of user PostScript
.71893 .60135 m
.71845 .60135 L
s
% Start of user PostScript
47. 39. 46.9686 39. MAarrowhead1
% End of user PostScript
.73403 .60135 m
.7378 .60507 L
s
% Start of user PostScript
48. 39. 48.2494 39.246 MAarrowhead1
% End of user PostScript
.74914 .60135 m
.74604 .59608 L
s
% Start of user PostScript
49. 39. 48.7951 38.6508 MAarrowhead1
% End of user PostScript
.76424 .60135 m
.76424 .60135 L
s
% Start of user PostScript
50. 39. MAarrowzero1
% End of user PostScript
.77935 .60135 m
.77935 .60135 L
s
% Start of user PostScript
51. 39. MAarrowzero1
% End of user PostScript
.79445 .60135 m
.79445 .60135 L
s
% Start of user PostScript
52. 39. MAarrowzero1
% End of user PostScript
.80956 .60135 m
.80956 .60135 L
s
% Start of user PostScript
53. 39. MAarrowzero1
% End of user PostScript
.82466 .60135 m
.82466 .60135 L
s
% Start of user PostScript
54. 39. MAarrowzero1
% End of user PostScript
.83977 .60135 m
.83977 .60135 L
s
% Start of user PostScript
55. 39. MAarrowzero1
% End of user PostScript
.85488 .60135 m
.85488 .60135 L
s
% Start of user PostScript
56. 39. MAarrowzero1
% End of user PostScript
.86998 .60135 m
.86998 .60135 L
s
% Start of user PostScript
57. 39. MAarrowzero1
% End of user PostScript
.88509 .60135 m
.88509 .60135 L
s
% Start of user PostScript
58. 39. MAarrowzero1
% End of user PostScript
.90019 .60135 m
.90019 .60135 L
s
% Start of user PostScript
59. 39. MAarrowzero1
% End of user PostScript
.9153 .60135 m
.9153 .60135 L
s
% Start of user PostScript
60. 39. MAarrowzero1
% End of user PostScript
.9304 .60135 m
.9304 .60135 L
s
% Start of user PostScript
61. 39. MAarrowzero1
% End of user PostScript
.94551 .60135 m
.94551 .60135 L
s
% Start of user PostScript
62. 39. MAarrowzero1
% End of user PostScript
.96061 .60135 m
.96061 .60135 L
s
% Start of user PostScript
63. 39. MAarrowzero1
% End of user PostScript
.97572 .60135 m
.97572 .60135 L
s
% Start of user PostScript
64. 39. MAarrowzero1
% End of user PostScript
.02409 .61646 m
.02409 .61646 L
s
% Start of user PostScript
1. 40. MAarrowzero1
% End of user PostScript
.03919 .61646 m
.03919 .61646 L
s
% Start of user PostScript
2. 40. MAarrowzero1
% End of user PostScript
.0543 .61646 m
.0543 .61646 L
s
% Start of user PostScript
3. 40. MAarrowzero1
% End of user PostScript
.0694 .61646 m
.06913 .61646 L
s
% Start of user PostScript
4. 40. 3.98149 40. MAarrowhead1
% End of user PostScript
.08451 .61646 m
.08451 .61646 L
s
% Start of user PostScript
5. 40. MAarrowzero1
% End of user PostScript
.09962 .61646 m
.09962 .61646 L
s
% Start of user PostScript
6. 40. MAarrowzero1
% End of user PostScript
.11472 .61646 m
.11472 .61646 L
s
% Start of user PostScript
7. 40. MAarrowzero1
% End of user PostScript
.12983 .61646 m
.13202 .61674 L
s
% Start of user PostScript
8. 40. 8.14541 40.0185 MAarrowhead1
% End of user PostScript
.14493 .61646 m
.1446 .61646 L
s
% Start of user PostScript
9. 40. 8.97804 40. MAarrowhead1
% End of user PostScript
.16004 .61646 m
.15829 .6173 L
s
% Start of user PostScript
10. 40. 9.88463 40.0561 MAarrowhead1
% End of user PostScript
.17514 .61646 m
.17467 .61646 L
s
% Start of user PostScript
11. 40. 10.9686 40. MAarrowhead1
% End of user PostScript
.19025 .61646 m
.18991 .61697 L
s
% Start of user PostScript
12. 40. 11.9776 40.0337 MAarrowhead1
% End of user PostScript
.20535 .61646 m
.2054 .61612 L
s
% Start of user PostScript
13. 40. 13.0035 39.9776 MAarrowhead1
% End of user PostScript
.22046 .61646 m
.21905 .61417 L
s
% Start of user PostScript
14. 40. 13.9066 39.8486 MAarrowhead1
% End of user PostScript
.23556 .61646 m
.23483 .61439 L
s
% Start of user PostScript
15. 40. 14.9518 39.8635 MAarrowhead1
% End of user PostScript
.25067 .61646 m
.24977 .6164 L
s
% Start of user PostScript
16. 40. 15.9405 39.9961 MAarrowhead1
% End of user PostScript
.26577 .61646 m
.26572 .61641 L
s
% Start of user PostScript
17. 40. 16.9965 39.9965 MAarrowhead1
% End of user PostScript
.28088 .61646 m
.28055 .61604 L
s
% Start of user PostScript
18. 40. 17.978 39.9721 MAarrowhead1
% End of user PostScript
.29598 .61646 m
.29607 .61654 L
s
% Start of user PostScript
19. 40. 19.0055 40.0055 MAarrowhead1
% End of user PostScript
.31109 .61646 m
.31061 .61646 L
s
% Start of user PostScript
20. 40. 19.9686 40. MAarrowhead1
% End of user PostScript
.32619 .61646 m
.32619 .61607 L
s
% Start of user PostScript
21. 40. 21. 39.9742 MAarrowhead1
% End of user PostScript
.3413 .61646 m
.3413 .61646 L
s
% Start of user PostScript
22. 40. MAarrowzero1
% End of user PostScript
.3564 .61646 m
.35601 .61685 L
s
% Start of user PostScript
23. 40. 22.9742 40.0258 MAarrowhead1
% End of user PostScript
.37151 .61646 m
.37151 .61646 L
s
% Start of user PostScript
24. 40. MAarrowzero1
% End of user PostScript
.38661 .61646 m
.38661 .61646 L
s
% Start of user PostScript
25. 40. MAarrowzero1
% End of user PostScript
.40172 .61646 m
.40172 .61693 L
s
% Start of user PostScript
26. 40. 26. 40.0314 MAarrowhead1
% End of user PostScript
.41682 .61646 m
.41635 .61693 L
s
% Start of user PostScript
27. 40. 26.9686 40.0314 MAarrowhead1
% End of user PostScript
.43193 .61646 m
.43193 .61646 L
s
% Start of user PostScript
28. 40. MAarrowzero1
% End of user PostScript
.44703 .61646 m
.44676 .61671 L
s
% Start of user PostScript
29. 40. 28.9815 40.0164 MAarrowhead1
% End of user PostScript
.46214 .61646 m
.46214 .61646 L
s
% Start of user PostScript
30. 40. MAarrowzero1
% End of user PostScript
.47725 .61646 m
.47705 .61693 L
s
% Start of user PostScript
31. 40. 30.9871 40.0314 MAarrowhead1
% End of user PostScript
.49235 .61646 m
.4924 .61646 L
s
% Start of user PostScript
32. 40. 32.0035 40. MAarrowhead1
% End of user PostScript
.50746 .61646 m
.50675 .61682 L
s
% Start of user PostScript
33. 40. 32.9533 40.0243 MAarrowhead1
% End of user PostScript
.52256 .61646 m
.52256 .61646 L
s
% Start of user PostScript
34. 40. MAarrowzero1
% End of user PostScript
.53767 .61646 m
.53816 .61695 L
s
% Start of user PostScript
35. 40. 35.0325 40.0325 MAarrowhead1
% End of user PostScript
.55277 .61646 m
.55324 .61679 L
s
% Start of user PostScript
36. 40. 36.0314 40.022 MAarrowhead1
% End of user PostScript
.56788 .61646 m
.56825 .61755 L
s
% Start of user PostScript
37. 40. 37.0247 40.0726 MAarrowhead1
% End of user PostScript
.58298 .61646 m
.58298 .61763 L
s
% Start of user PostScript
38. 40. 38. 40.0778 MAarrowhead1
% End of user PostScript
.59809 .61646 m
.59936 .61646 L
s
% Start of user PostScript
39. 40. 39.084 40. MAarrowhead1
% End of user PostScript
.61319 .61646 m
.61349 .61756 L
s
% Start of user PostScript
40. 40. 40.02 40.0733 MAarrowhead1
% End of user PostScript
.6283 .61646 m
.62893 .6185 L
s
% Start of user PostScript
41. 40. 41.042 40.1354 MAarrowhead1
% End of user PostScript
.6434 .61646 m
.64315 .61537 L
s
% Start of user PostScript
42. 40. 41.9835 39.9278 MAarrowhead1
% End of user PostScript
.65851 .61646 m
.65903 .61803 L
s
% Start of user PostScript
43. 40. 43.0349 40.104 MAarrowhead1
% End of user PostScript
.67361 .61646 m
.67309 .61489 L
s
% Start of user PostScript
44. 40. 43.9651 39.896 MAarrowhead1
% End of user PostScript
.68872 .61646 m
.68817 .61584 L
s
% Start of user PostScript
45. 40. 44.9636 39.9592 MAarrowhead1
% End of user PostScript
.70382 .61646 m
.70229 .61339 L
s
% Start of user PostScript
46. 40. 45.8987 39.7973 MAarrowhead1
% End of user PostScript
.71893 .61646 m
.7206 .61685 L
s
% Start of user PostScript
47. 40. 47.1107 40.026 MAarrowhead1
% End of user PostScript
.73403 .61646 m
.73356 .61512 L
s
% Start of user PostScript
48. 40. 47.9686 39.9114 MAarrowhead1
% End of user PostScript
.74914 .61646 m
.74914 .61618 L
s
% Start of user PostScript
49. 40. 49. 39.9815 MAarrowhead1
% End of user PostScript
.76424 .61646 m
.76424 .61646 L
s
% Start of user PostScript
50. 40. MAarrowzero1
% End of user PostScript
.77935 .61646 m
.77935 .61646 L
s
% Start of user PostScript
51. 40. MAarrowzero1
% End of user PostScript
.79445 .61646 m
.79445 .61646 L
s
% Start of user PostScript
52. 40. MAarrowzero1
% End of user PostScript
.80956 .61646 m
.80956 .61646 L
s
% Start of user PostScript
53. 40. MAarrowzero1
% End of user PostScript
.82466 .61646 m
.82466 .61646 L
s
% Start of user PostScript
54. 40. MAarrowzero1
% End of user PostScript
.83977 .61646 m
.83977 .61646 L
s
% Start of user PostScript
55. 40. MAarrowzero1
% End of user PostScript
.85488 .61646 m
.85488 .61646 L
s
% Start of user PostScript
56. 40. MAarrowzero1
% End of user PostScript
.86998 .61646 m
.86998 .61646 L
s
% Start of user PostScript
57. 40. MAarrowzero1
% End of user PostScript
.88509 .61646 m
.88509 .61646 L
s
% Start of user PostScript
58. 40. MAarrowzero1
% End of user PostScript
.90019 .61646 m
.89991 .61646 L
s
% Start of user PostScript
59. 40. 58.9815 40. MAarrowhead1
% End of user PostScript
.9153 .61646 m
.9153 .61646 L
s
% Start of user PostScript
60. 40. MAarrowzero1
% End of user PostScript
.9304 .61646 m
.9304 .61646 L
s
% Start of user PostScript
61. 40. MAarrowzero1
% End of user PostScript
.94551 .61646 m
.94551 .61646 L
s
% Start of user PostScript
62. 40. MAarrowzero1
% End of user PostScript
.96061 .61646 m
.96061 .61646 L
s
% Start of user PostScript
63. 40. MAarrowzero1
% End of user PostScript
.97572 .61646 m
.97572 .61646 L
s
% Start of user PostScript
64. 40. MAarrowzero1
% End of user PostScript
.02409 .63156 m
.02409 .63156 L
s
% Start of user PostScript
1. 41. MAarrowzero1
% End of user PostScript
.03919 .63156 m
.03919 .63156 L
s
% Start of user PostScript
2. 41. MAarrowzero1
% End of user PostScript
.0543 .63156 m
.0543 .63156 L
s
% Start of user PostScript
3. 41. MAarrowzero1
% End of user PostScript
.0694 .63156 m
.0694 .63156 L
s
% Start of user PostScript
4. 41. MAarrowzero1
% End of user PostScript
.08451 .63156 m
.08451 .63156 L
s
% Start of user PostScript
5. 41. MAarrowzero1
% End of user PostScript
.09962 .63156 m
.09962 .63156 L
s
% Start of user PostScript
6. 41. MAarrowzero1
% End of user PostScript
.11472 .63156 m
.11472 .63156 L
s
% Start of user PostScript
7. 41. MAarrowzero1
% End of user PostScript
.12983 .63156 m
.12935 .63109 L
s
% Start of user PostScript
8. 41. 7.96863 40.9686 MAarrowhead1
% End of user PostScript
.14493 .63156 m
.14594 .6317 L
s
% Start of user PostScript
9. 41. 9.06663 41.0094 MAarrowhead1
% End of user PostScript
.16004 .63156 m
.15967 .63024 L
s
% Start of user PostScript
10. 41. 9.97573 40.9125 MAarrowhead1
% End of user PostScript
.17514 .63156 m
.17514 .6324 L
s
% Start of user PostScript
11. 41. 11. 41.0556 MAarrowhead1
% End of user PostScript
.19025 .63156 m
.19076 .63241 L
s
% Start of user PostScript
12. 41. 12.0337 41.0561 MAarrowhead1
% End of user PostScript
.20535 .63156 m
.20553 .63058 L
s
% Start of user PostScript
13. 41. 13.0118 40.9349 MAarrowhead1
% End of user PostScript
.22046 .63156 m
.21956 .63067 L
s
% Start of user PostScript
14. 41. 13.9407 40.9407 MAarrowhead1
% End of user PostScript
.23556 .63156 m
.23476 .63107 L
s
% Start of user PostScript
15. 41. 14.9467 40.9675 MAarrowhead1
% End of user PostScript
.25067 .63156 m
.24936 .63068 L
s
% Start of user PostScript
16. 41. 15.9137 40.9416 MAarrowhead1
% End of user PostScript
.26577 .63156 m
.26539 .63142 L
s
% Start of user PostScript
17. 41. 16.9746 40.9906 MAarrowhead1
% End of user PostScript
.28088 .63156 m
.28055 .63189 L
s
% Start of user PostScript
18. 41. 17.978 41.022 MAarrowhead1
% End of user PostScript
.29598 .63156 m
.29598 .63156 L
s
% Start of user PostScript
19. 41. MAarrowzero1
% End of user PostScript
.31109 .63156 m
.3107 .63156 L
s
% Start of user PostScript
20. 41. 19.9742 41. MAarrowhead1
% End of user PostScript
.32619 .63156 m
.32658 .63165 L
s
% Start of user PostScript
21. 41. 21.0258 41.0055 MAarrowhead1
% End of user PostScript
.3413 .63156 m
.34091 .63156 L
s
% Start of user PostScript
22. 41. 21.9742 41. MAarrowhead1
% End of user PostScript
.3564 .63156 m
.3564 .63165 L
s
% Start of user PostScript
23. 41. 23. 41.0055 MAarrowhead1
% End of user PostScript
.37151 .63156 m
.37159 .63156 L
s
% Start of user PostScript
24. 41. 24.0055 41. MAarrowhead1
% End of user PostScript
.38661 .63156 m
.38622 .63204 L
s
% Start of user PostScript
25. 41. 24.9742 41.0314 MAarrowhead1
% End of user PostScript
.40172 .63156 m
.40172 .63195 L
s
% Start of user PostScript
26. 41. 26. 41.0258 MAarrowhead1
% End of user PostScript
.41682 .63156 m
.41682 .63148 L
s
% Start of user PostScript
27. 41. 27. 40.9945 MAarrowhead1
% End of user PostScript
.43193 .63156 m
.43193 .63156 L
s
% Start of user PostScript
28. 41. MAarrowzero1
% End of user PostScript
.44703 .63156 m
.4467 .63156 L
s
% Start of user PostScript
29. 41. 28.978 41. MAarrowhead1
% End of user PostScript
.46214 .63156 m
.46214 .63156 L
s
% Start of user PostScript
30. 41. MAarrowzero1
% End of user PostScript
.47725 .63156 m
.47725 .63137 L
s
% Start of user PostScript
31. 41. 31. 40.9871 MAarrowhead1
% End of user PostScript
.49235 .63156 m
.49235 .63161 L
s
% Start of user PostScript
32. 41. 32. 41.0035 MAarrowhead1
% End of user PostScript
.50746 .63156 m
.50825 .63137 L
s
% Start of user PostScript
33. 41. 33.0526 40.987 MAarrowhead1
% End of user PostScript
.52256 .63156 m
.52284 .63122 L
s
% Start of user PostScript
34. 41. 34.0185 40.9776 MAarrowhead1
% End of user PostScript
.53767 .63156 m
.53795 .63205 L
s
% Start of user PostScript
35. 41. 35.0185 41.0325 MAarrowhead1
% End of user PostScript
.55277 .63156 m
.55319 .63198 L
s
% Start of user PostScript
36. 41. 36.0279 41.0279 MAarrowhead1
% End of user PostScript
.56788 .63156 m
.56825 .63266 L
s
% Start of user PostScript
37. 41. 37.0247 41.0726 MAarrowhead1
% End of user PostScript
.58298 .63156 m
.58365 .63226 L
s
% Start of user PostScript
38. 41. 38.0445 41.0464 MAarrowhead1
% End of user PostScript
.59809 .63156 m
.59809 .63156 L
s
% Start of user PostScript
39. 41. MAarrowzero1
% End of user PostScript
.61319 .63156 m
.61319 .63244 L
s
% Start of user PostScript
40. 41. 40. 41.0584 MAarrowhead1
% End of user PostScript
.6283 .63156 m
.63025 .63268 L
s
% Start of user PostScript
41. 41. 41.1294 41.0738 MAarrowhead1
% End of user PostScript
.6434 .63156 m
.6448 .6338 L
s
% Start of user PostScript
42. 41. 42.0923 41.1479 MAarrowhead1
% End of user PostScript
.65851 .63156 m
.65798 .63271 L
s
% Start of user PostScript
43. 41. 42.9651 41.0756 MAarrowhead1
% End of user PostScript
.67361 .63156 m
.67213 .62804 L
s
% Start of user PostScript
44. 41. 43.902 40.7666 MAarrowhead1
% End of user PostScript
.68872 .63156 m
.68582 .63098 L
s
% Start of user PostScript
45. 41. 44.8078 40.9615 MAarrowhead1
% End of user PostScript
.70382 .63156 m
.70206 .62906 L
s
% Start of user PostScript
46. 41. 45.8835 40.8342 MAarrowhead1
% End of user PostScript
.71893 .63156 m
.72007 .6297 L
s
% Start of user PostScript
47. 41. 47.0758 40.8765 MAarrowhead1
% End of user PostScript
.73403 .63156 m
.73083 .62345 L
s
% Start of user PostScript
48. 41. 47.7877 40.463 MAarrowhead1
% End of user PostScript
.74914 .63156 m
.74914 .63156 L
s
% Start of user PostScript
49. 41. MAarrowzero1
% End of user PostScript
.76424 .63156 m
.76424 .63156 L
s
% Start of user PostScript
50. 41. MAarrowzero1
% End of user PostScript
.77935 .63156 m
.77935 .63156 L
s
% Start of user PostScript
51. 41. MAarrowzero1
% End of user PostScript
.79445 .63156 m
.79445 .63156 L
s
% Start of user PostScript
52. 41. MAarrowzero1
% End of user PostScript
.80956 .63156 m
.80956 .63156 L
s
% Start of user PostScript
53. 41. MAarrowzero1
% End of user PostScript
.82466 .63156 m
.82466 .63156 L
s
% Start of user PostScript
54. 41. MAarrowzero1
% End of user PostScript
.83977 .63156 m
.83977 .63156 L
s
% Start of user PostScript
55. 41. MAarrowzero1
% End of user PostScript
.85488 .63156 m
.85488 .63156 L
s
% Start of user PostScript
56. 41. MAarrowzero1
% End of user PostScript
.86998 .63156 m
.86998 .63156 L
s
% Start of user PostScript
57. 41. MAarrowzero1
% End of user PostScript
.88509 .63156 m
.88509 .63156 L
s
% Start of user PostScript
58. 41. MAarrowzero1
% End of user PostScript
.90019 .63156 m
.90019 .63156 L
s
% Start of user PostScript
59. 41. MAarrowzero1
% End of user PostScript
.9153 .63156 m
.9153 .63156 L
s
% Start of user PostScript
60. 41. MAarrowzero1
% End of user PostScript
.9304 .63156 m
.9304 .63156 L
s
% Start of user PostScript
61. 41. MAarrowzero1
% End of user PostScript
.94551 .63156 m
.94551 .63156 L
s
% Start of user PostScript
62. 41. MAarrowzero1
% End of user PostScript
.96061 .63156 m
.96061 .63156 L
s
% Start of user PostScript
63. 41. MAarrowzero1
% End of user PostScript
.97572 .63156 m
.97572 .63156 L
s
% Start of user PostScript
64. 41. MAarrowzero1
% End of user PostScript
.02409 .64667 m
.02409 .64667 L
s
% Start of user PostScript
1. 42. MAarrowzero1
% End of user PostScript
.03919 .64667 m
.03919 .64695 L
s
% Start of user PostScript
2. 42. 2. 42.0185 MAarrowhead1
% End of user PostScript
.0543 .64667 m
.0543 .64695 L
s
% Start of user PostScript
3. 42. 3. 42.0185 MAarrowhead1
% End of user PostScript
.0694 .64667 m
.0694 .64667 L
s
% Start of user PostScript
4. 42. MAarrowzero1
% End of user PostScript
.08451 .64667 m
.08451 .64667 L
s
% Start of user PostScript
5. 42. MAarrowzero1
% End of user PostScript
.09962 .64667 m
.09962 .64667 L
s
% Start of user PostScript
6. 42. MAarrowzero1
% End of user PostScript
.11472 .64667 m
.11472 .64667 L
s
% Start of user PostScript
7. 42. MAarrowzero1
% End of user PostScript
.12983 .64667 m
.12935 .64667 L
s
% Start of user PostScript
8. 42. 7.96863 42. MAarrowhead1
% End of user PostScript
.14493 .64667 m
.15037 .64437 L
s
% Start of user PostScript
9. 42. 9.35976 41.8482 MAarrowhead1
% End of user PostScript
.16004 .64667 m
.15973 .64872 L
s
% Start of user PostScript
10. 42. 9.98 42.1361 MAarrowhead1
% End of user PostScript
.17514 .64667 m
.17444 .64751 L
s
% Start of user PostScript
11. 42. 10.9533 42.0561 MAarrowhead1
% End of user PostScript
.19025 .64667 m
.18986 .64681 L
s
% Start of user PostScript
12. 42. 11.9742 42.0094 MAarrowhead1
% End of user PostScript
.20535 .64667 m
.20632 .64684 L
s
% Start of user PostScript
13. 42. 13.0639 42.0115 MAarrowhead1
% End of user PostScript
.22046 .64667 m
.21901 .64528 L
s
% Start of user PostScript
14. 42. 13.9043 41.9082 MAarrowhead1
% End of user PostScript
.23556 .64667 m
.23556 .64573 L
s
% Start of user PostScript
15. 42. 15. 41.9382 MAarrowhead1
% End of user PostScript
.25067 .64667 m
.24942 .64537 L
s
% Start of user PostScript
16. 42. 15.9176 41.9141 MAarrowhead1
% End of user PostScript
.26577 .64667 m
.26544 .64634 L
s
% Start of user PostScript
17. 42. 16.978 41.978 MAarrowhead1
% End of user PostScript
.28088 .64667 m
.28088 .64634 L
s
% Start of user PostScript
18. 42. 18. 41.978 MAarrowhead1
% End of user PostScript
.29598 .64667 m
.2959 .64667 L
s
% Start of user PostScript
19. 42. 18.9945 42. MAarrowhead1
% End of user PostScript
.31109 .64667 m
.31109 .64667 L
s
% Start of user PostScript
20. 42. MAarrowzero1
% End of user PostScript
.32619 .64667 m
.3258 .64619 L
s
% Start of user PostScript
21. 42. 20.9742 41.9686 MAarrowhead1
% End of user PostScript
.3413 .64667 m
.34091 .64667 L
s
% Start of user PostScript
22. 42. 21.9742 42. MAarrowhead1
% End of user PostScript
.3564 .64667 m
.35601 .64675 L
s
% Start of user PostScript
23. 42. 22.9742 42.0055 MAarrowhead1
% End of user PostScript
.37151 .64667 m
.37159 .64628 L
s
% Start of user PostScript
24. 42. 24.0055 41.9742 MAarrowhead1
% End of user PostScript
.38661 .64667 m
.38661 .64714 L
s
% Start of user PostScript
25. 42. 25. 42.0314 MAarrowhead1
% End of user PostScript
.40172 .64667 m
.40172 .64658 L
s
% Start of user PostScript
26. 42. 26. 41.9945 MAarrowhead1
% End of user PostScript
.41682 .64667 m
.41691 .64667 L
s
% Start of user PostScript
27. 42. 27.0055 42. MAarrowhead1
% End of user PostScript
.43193 .64667 m
.43193 .64667 L
s
% Start of user PostScript
28. 42. MAarrowzero1
% End of user PostScript
.44703 .64667 m
.44703 .64667 L
s
% Start of user PostScript
29. 42. MAarrowzero1
% End of user PostScript
.46214 .64667 m
.46233 .647 L
s
% Start of user PostScript
30. 42. 30.0129 42.022 MAarrowhead1
% End of user PostScript
.47725 .64667 m
.47744 .64686 L
s
% Start of user PostScript
31. 42. 31.0129 42.0129 MAarrowhead1
% End of user PostScript
.49235 .64667 m
.49235 .64667 L
s
% Start of user PostScript
32. 42. MAarrowzero1
% End of user PostScript
.50746 .64667 m
.5068 .64601 L
s
% Start of user PostScript
33. 42. 32.9568 41.9568 MAarrowhead1
% End of user PostScript
.52256 .64667 m
.52256 .64667 L
s
% Start of user PostScript
34. 42. MAarrowzero1
% End of user PostScript
.53767 .64667 m
.53767 .64672 L
s
% Start of user PostScript
35. 42. 35. 42.0035 MAarrowhead1
% End of user PostScript
.55277 .64667 m
.55319 .64667 L
s
% Start of user PostScript
36. 42. 36.0279 42. MAarrowhead1
% End of user PostScript
.56788 .64667 m
.56897 .64727 L
s
% Start of user PostScript
37. 42. 37.0726 42.0396 MAarrowhead1
% End of user PostScript
.58298 .64667 m
.58418 .64814 L
s
% Start of user PostScript
38. 42. 38.0793 42.0978 MAarrowhead1
% End of user PostScript
.59809 .64667 m
.59864 .64787 L
s
% Start of user PostScript
39. 42. 39.0364 42.0795 MAarrowhead1
% End of user PostScript
.61319 .64667 m
.6146 .64658 L
s
% Start of user PostScript
40. 42. 40.093 41.994 MAarrowhead1
% End of user PostScript
.6283 .64667 m
.62848 .64751 L
s
% Start of user PostScript
41. 42. 41.0118 42.0556 MAarrowhead1
% End of user PostScript
.6434 .64667 m
.64497 .64824 L
s
% Start of user PostScript
42. 42. 42.104 42.104 MAarrowhead1
% End of user PostScript
.65851 .64667 m
.65764 .64519 L
s
% Start of user PostScript
43. 42. 42.9427 41.902 MAarrowhead1
% End of user PostScript
.67361 .64667 m
.66928 .6411 L
s
% Start of user PostScript
44. 42. 43.7132 41.6316 MAarrowhead1
% End of user PostScript
.68872 .64667 m
.68863 .64625 L
s
% Start of user PostScript
45. 42. 44.994 41.9721 MAarrowhead1
% End of user PostScript
.70382 .64667 m
.70104 .6438 L
s
% Start of user PostScript
46. 42. 45.8156 41.8101 MAarrowhead1
% End of user PostScript
.71893 .64667 m
.71893 .64557 L
s
% Start of user PostScript
47. 42. 47. 41.9276 MAarrowhead1
% End of user PostScript
.73403 .64667 m
.73403 .64529 L
s
% Start of user PostScript
48. 42. 48. 41.9091 MAarrowhead1
% End of user PostScript
.74914 .64667 m
.74914 .64667 L
s
% Start of user PostScript
49. 42. MAarrowzero1
% End of user PostScript
.76424 .64667 m
.76424 .64667 L
s
% Start of user PostScript
50. 42. MAarrowzero1
% End of user PostScript
.77935 .64667 m
.77935 .64667 L
s
% Start of user PostScript
51. 42. MAarrowzero1
% End of user PostScript
.79445 .64667 m
.79445 .64667 L
s
% Start of user PostScript
52. 42. MAarrowzero1
% End of user PostScript
.80956 .64667 m
.80956 .64667 L
s
% Start of user PostScript
53. 42. MAarrowzero1
% End of user PostScript
.82466 .64667 m
.82466 .64667 L
s
% Start of user PostScript
54. 42. MAarrowzero1
% End of user PostScript
.83977 .64667 m
.83977 .64667 L
s
% Start of user PostScript
55. 42. MAarrowzero1
% End of user PostScript
.85488 .64667 m
.85488 .64667 L
s
% Start of user PostScript
56. 42. MAarrowzero1
% End of user PostScript
.86998 .64667 m
.86998 .64667 L
s
% Start of user PostScript
57. 42. MAarrowzero1
% End of user PostScript
.88509 .64667 m
.88509 .64667 L
s
% Start of user PostScript
58. 42. MAarrowzero1
% End of user PostScript
.90019 .64667 m
.90019 .64667 L
s
% Start of user PostScript
59. 42. MAarrowzero1
% End of user PostScript
.9153 .64667 m
.9153 .64667 L
s
% Start of user PostScript
60. 42. MAarrowzero1
% End of user PostScript
.9304 .64667 m
.9304 .64667 L
s
% Start of user PostScript
61. 42. MAarrowzero1
% End of user PostScript
.94551 .64667 m
.94551 .64667 L
s
% Start of user PostScript
62. 42. MAarrowzero1
% End of user PostScript
.96061 .64667 m
.96061 .64667 L
s
% Start of user PostScript
63. 42. MAarrowzero1
% End of user PostScript
.97572 .64667 m
.97572 .64667 L
s
% Start of user PostScript
64. 42. MAarrowzero1
% End of user PostScript
.02409 .66177 m
.02409 .66177 L
s
% Start of user PostScript
1. 43. MAarrowzero1
% End of user PostScript
.03919 .66177 m
.03919 .66177 L
s
% Start of user PostScript
2. 43. MAarrowzero1
% End of user PostScript
.0543 .66177 m
.0543 .66177 L
s
% Start of user PostScript
3. 43. MAarrowzero1
% End of user PostScript
.0694 .66177 m
.0694 .66177 L
s
% Start of user PostScript
4. 43. MAarrowzero1
% End of user PostScript
.08451 .66177 m
.08451 .66177 L
s
% Start of user PostScript
5. 43. MAarrowzero1
% End of user PostScript
.09962 .66177 m
.09962 .66177 L
s
% Start of user PostScript
6. 43. MAarrowzero1
% End of user PostScript
.11472 .66177 m
.11472 .66177 L
s
% Start of user PostScript
7. 43. MAarrowzero1
% End of user PostScript
.12983 .66177 m
.12983 .66177 L
s
% Start of user PostScript
8. 43. MAarrowzero1
% End of user PostScript
.14493 .66177 m
.15313 .66571 L
s
% Start of user PostScript
9. 43. 9.54294 43.2608 MAarrowhead1
% End of user PostScript
.16004 .66177 m
.16074 .66195 L
s
% Start of user PostScript
10. 43. 10.0467 43.0118 MAarrowhead1
% End of user PostScript
.17514 .66177 m
.17519 .66119 L
s
% Start of user PostScript
11. 43. 11.0035 42.9615 MAarrowhead1
% End of user PostScript
.19025 .66177 m
.19088 .66153 L
s
% Start of user PostScript
12. 43. 12.042 42.9839 MAarrowhead1
% End of user PostScript
.20535 .66177 m
.20426 .66195 L
s
% Start of user PostScript
13. 43. 12.9278 43.0118 MAarrowhead1
% End of user PostScript
.22046 .66177 m
.21898 .66089 L
s
% Start of user PostScript
14. 43. 13.902 42.9416 MAarrowhead1
% End of user PostScript
.23556 .66177 m
.23436 .6608 L
s
% Start of user PostScript
15. 43. 14.9207 42.9356 MAarrowhead1
% End of user PostScript
.25067 .66177 m
.24995 .66075 L
s
% Start of user PostScript
16. 43. 15.9524 42.9322 MAarrowhead1
% End of user PostScript
.26577 .66177 m
.2653 .6613 L
s
% Start of user PostScript
17. 43. 16.9686 42.9686 MAarrowhead1
% End of user PostScript
.28088 .66177 m
.28055 .66116 L
s
% Start of user PostScript
18. 43. 17.978 42.9595 MAarrowhead1
% End of user PostScript
.29598 .66177 m
.2959 .66177 L
s
% Start of user PostScript
19. 43. 18.9945 43. MAarrowhead1
% End of user PostScript
.31109 .66177 m
.31148 .66186 L
s
% Start of user PostScript
20. 43. 20.0258 43.0055 MAarrowhead1
% End of user PostScript
.32619 .66177 m
.32667 .66138 L
s
% Start of user PostScript
21. 43. 21.0314 42.9742 MAarrowhead1
% End of user PostScript
.3413 .66177 m
.3413 .66177 L
s
% Start of user PostScript
22. 43. MAarrowzero1
% End of user PostScript
.3564 .66177 m
.3564 .66225 L
s
% Start of user PostScript
23. 43. 23. 43.0314 MAarrowhead1
% End of user PostScript
.37151 .66177 m
.37198 .66169 L
s
% Start of user PostScript
24. 43. 24.0314 42.9945 MAarrowhead1
% End of user PostScript
.38661 .66177 m
.38653 .66177 L
s
% Start of user PostScript
25. 43. 24.9945 43. MAarrowhead1
% End of user PostScript
.40172 .66177 m
.40164 .66177 L
s
% Start of user PostScript
26. 43. 25.9945 43. MAarrowhead1
% End of user PostScript
.41682 .66177 m
.41674 .66177 L
s
% Start of user PostScript
27. 43. 26.9945 43. MAarrowhead1
% End of user PostScript
.43193 .66177 m
.43193 .66177 L
s
% Start of user PostScript
28. 43. MAarrowzero1
% End of user PostScript
.44703 .66177 m
.44765 .6621 L
s
% Start of user PostScript
29. 43. 29.0405 43.022 MAarrowhead1
% End of user PostScript
.46214 .66177 m
.46247 .66177 L
s
% Start of user PostScript
30. 43. 30.022 43. MAarrowhead1
% End of user PostScript
.47725 .66177 m
.47744 .66197 L
s
% Start of user PostScript
31. 43. 31.0129 43.0129 MAarrowhead1
% End of user PostScript
.49235 .66177 m
.49235 .66225 L
s
% Start of user PostScript
32. 43. 32. 43.0314 MAarrowhead1
% End of user PostScript
.50746 .66177 m
.50746 .66177 L
s
% Start of user PostScript
33. 43. MAarrowzero1
% End of user PostScript
.52256 .66177 m
.52256 .66219 L
s
% Start of user PostScript
34. 43. 34. 43.0279 MAarrowhead1
% End of user PostScript
.53767 .66177 m
.53777 .66182 L
s
% Start of user PostScript
35. 43. 35.0069 43.0035 MAarrowhead1
% End of user PostScript
.55277 .66177 m
.55277 .66182 L
s
% Start of user PostScript
36. 43. 36. 43.0035 MAarrowhead1
% End of user PostScript
.56788 .66177 m
.56793 .66267 L
s
% Start of user PostScript
37. 43. 37.0035 43.0595 MAarrowhead1
% End of user PostScript
.58298 .66177 m
.58398 .66221 L
s
% Start of user PostScript
38. 43. 38.0664 43.0289 MAarrowhead1
% End of user PostScript
.59809 .66177 m
.59809 .66248 L
s
% Start of user PostScript
39. 43. 39. 43.047 MAarrowhead1
% End of user PostScript
.61319 .66177 m
.61445 .66214 L
s
% Start of user PostScript
40. 43. 40.0836 43.0243 MAarrowhead1
% End of user PostScript
.6283 .66177 m
.62863 .66235 L
s
% Start of user PostScript
41. 43. 41.022 43.0385 MAarrowhead1
% End of user PostScript
.6434 .66177 m
.6434 .66143 L
s
% Start of user PostScript
42. 43. 42. 42.9776 MAarrowhead1
% End of user PostScript
.65851 .66177 m
.65805 .66063 L
s
% Start of user PostScript
43. 43. 42.9698 42.9244 MAarrowhead1
% End of user PostScript
.67361 .66177 m
.66838 .65585 L
s
% Start of user PostScript
44. 43. 43.6535 42.6081 MAarrowhead1
% End of user PostScript
.68872 .66177 m
.69064 .66261 L
s
% Start of user PostScript
45. 43. 45.1273 43.0556 MAarrowhead1
% End of user PostScript
.70382 .66177 m
.70162 .6589 L
s
% Start of user PostScript
46. 43. 45.8542 42.8101 MAarrowhead1
% End of user PostScript
.71893 .66177 m
.71822 .6582 L
s
% Start of user PostScript
47. 43. 46.9531 42.7637 MAarrowhead1
% End of user PostScript
.73403 .66177 m
.73403 .66205 L
s
% Start of user PostScript
48. 43. 48. 43.0185 MAarrowhead1
% End of user PostScript
.74914 .66177 m
.74914 .66177 L
s
% Start of user PostScript
49. 43. MAarrowzero1
% End of user PostScript
.76424 .66177 m
.76424 .66177 L
s
% Start of user PostScript
50. 43. MAarrowzero1
% End of user PostScript
.77935 .66177 m
.77935 .66177 L
s
% Start of user PostScript
51. 43. MAarrowzero1
% End of user PostScript
.79445 .66177 m
.79445 .66177 L
s
% Start of user PostScript
52. 43. MAarrowzero1
% End of user PostScript
.80956 .66177 m
.80956 .66177 L
s
% Start of user PostScript
53. 43. MAarrowzero1
% End of user PostScript
.82466 .66177 m
.82466 .66177 L
s
% Start of user PostScript
54. 43. MAarrowzero1
% End of user PostScript
.83977 .66177 m
.83977 .66177 L
s
% Start of user PostScript
55. 43. MAarrowzero1
% End of user PostScript
.85488 .66177 m
.85488 .66177 L
s
% Start of user PostScript
56. 43. MAarrowzero1
% End of user PostScript
.86998 .66177 m
.86998 .66177 L
s
% Start of user PostScript
57. 43. MAarrowzero1
% End of user PostScript
.88509 .66177 m
.88509 .66177 L
s
% Start of user PostScript
58. 43. MAarrowzero1
% End of user PostScript
.90019 .66177 m
.90019 .66177 L
s
% Start of user PostScript
59. 43. MAarrowzero1
% End of user PostScript
.9153 .66177 m
.9153 .66177 L
s
% Start of user PostScript
60. 43. MAarrowzero1
% End of user PostScript
.9304 .66177 m
.9304 .66177 L
s
% Start of user PostScript
61. 43. MAarrowzero1
% End of user PostScript
.94551 .66177 m
.94551 .66177 L
s
% Start of user PostScript
62. 43. MAarrowzero1
% End of user PostScript
.96061 .66177 m
.96061 .66177 L
s
% Start of user PostScript
63. 43. MAarrowzero1
% End of user PostScript
.97572 .66177 m
.97572 .66177 L
s
% Start of user PostScript
64. 43. MAarrowzero1
% End of user PostScript
.02409 .67688 m
.02409 .67688 L
s
% Start of user PostScript
1. 44. MAarrowzero1
% End of user PostScript
.03919 .67688 m
.03919 .6766 L
s
% Start of user PostScript
2. 44. 2. 43.9815 MAarrowhead1
% End of user PostScript
.0543 .67688 m
.0543 .67688 L
s
% Start of user PostScript
3. 44. MAarrowzero1
% End of user PostScript
.0694 .67688 m
.0694 .67688 L
s
% Start of user PostScript
4. 44. MAarrowzero1
% End of user PostScript
.08451 .67688 m
.08451 .67688 L
s
% Start of user PostScript
5. 44. MAarrowzero1
% End of user PostScript
.09962 .67688 m
.09962 .67688 L
s
% Start of user PostScript
6. 44. MAarrowzero1
% End of user PostScript
.11472 .67688 m
.11472 .67688 L
s
% Start of user PostScript
7. 44. MAarrowzero1
% End of user PostScript
.12983 .67688 m
.12983 .67688 L
s
% Start of user PostScript
8. 44. MAarrowzero1
% End of user PostScript
.14493 .67688 m
.14521 .67688 L
s
% Start of user PostScript
9. 44. 9.01851 44. MAarrowhead1
% End of user PostScript
.16004 .67688 m
.16296 .67688 L
s
% Start of user PostScript
10. 44. 10.1938 44. MAarrowhead1
% End of user PostScript
.17514 .67688 m
.17514 .67591 L
s
% Start of user PostScript
11. 44. 11. 43.9356 MAarrowhead1
% End of user PostScript
.19025 .67688 m
.19042 .67688 L
s
% Start of user PostScript
12. 44. 12.0118 44. MAarrowhead1
% End of user PostScript
.20535 .67688 m
.20577 .67672 L
s
% Start of user PostScript
13. 44. 13.0279 43.9894 MAarrowhead1
% End of user PostScript
.22046 .67688 m
.21889 .67646 L
s
% Start of user PostScript
14. 44. 13.896 43.9721 MAarrowhead1
% End of user PostScript
.23556 .67688 m
.23452 .67545 L
s
% Start of user PostScript
15. 44. 14.9311 43.9054 MAarrowhead1
% End of user PostScript
.25067 .67688 m
.25021 .67605 L
s
% Start of user PostScript
16. 44. 15.9698 43.9451 MAarrowhead1
% End of user PostScript
.26577 .67688 m
.26572 .6764 L
s
% Start of user PostScript
17. 44. 16.9965 43.9686 MAarrowhead1
% End of user PostScript
.28088 .67688 m
.28088 .6764 L
s
% Start of user PostScript
18. 44. 18. 43.9686 MAarrowhead1
% End of user PostScript
.29598 .67688 m
.29598 .67688 L
s
% Start of user PostScript
19. 44. MAarrowzero1
% End of user PostScript
.31109 .67688 m
.311 .67696 L
s
% Start of user PostScript
20. 44. 19.9945 44.0055 MAarrowhead1
% End of user PostScript
.32619 .67688 m
.32619 .67649 L
s
% Start of user PostScript
21. 44. 21. 43.9742 MAarrowhead1
% End of user PostScript
.3413 .67688 m
.34082 .67688 L
s
% Start of user PostScript
22. 44. 21.9686 44. MAarrowhead1
% End of user PostScript
.3564 .67688 m
.3564 .67688 L
s
% Start of user PostScript
23. 44. MAarrowzero1
% End of user PostScript
.37151 .67688 m
.37151 .67696 L
s
% Start of user PostScript
24. 44. 24. 44.0055 MAarrowhead1
% End of user PostScript
.38661 .67688 m
.38661 .67688 L
s
% Start of user PostScript
25. 44. MAarrowzero1
% End of user PostScript
.40172 .67688 m
.40172 .67688 L
s
% Start of user PostScript
26. 44. MAarrowzero1
% End of user PostScript
.41682 .67688 m
.41682 .67688 L
s
% Start of user PostScript
27. 44. MAarrowzero1
% End of user PostScript
.43193 .67688 m
.43193 .67679 L
s
% Start of user PostScript
28. 44. 28. 43.9945 MAarrowhead1
% End of user PostScript
.44703 .67688 m
.44703 .67721 L
s
% Start of user PostScript
29. 44. 29. 44.022 MAarrowhead1
% End of user PostScript
.46214 .67688 m
.46233 .67707 L
s
% Start of user PostScript
30. 44. 30.0129 44.0129 MAarrowhead1
% End of user PostScript
.47725 .67688 m
.47733 .67735 L
s
% Start of user PostScript
31. 44. 31.0056 44.0314 MAarrowhead1
% End of user PostScript
.49235 .67688 m
.4923 .67693 L
s
% Start of user PostScript
32. 44. 31.9965 44.0035 MAarrowhead1
% End of user PostScript
.50746 .67688 m
.50796 .67739 L
s
% Start of user PostScript
33. 44. 33.0337 44.0337 MAarrowhead1
% End of user PostScript
.52256 .67688 m
.52256 .67727 L
s
% Start of user PostScript
34. 44. 34. 44.0258 MAarrowhead1
% End of user PostScript
.53767 .67688 m
.53788 .67737 L
s
% Start of user PostScript
35. 44. 35.014 44.0325 MAarrowhead1
% End of user PostScript
.55277 .67688 m
.55319 .67721 L
s
% Start of user PostScript
36. 44. 36.0279 44.022 MAarrowhead1
% End of user PostScript
.56788 .67688 m
.56839 .6774 L
s
% Start of user PostScript
37. 44. 37.0341 44.0348 MAarrowhead1
% End of user PostScript
.58298 .67688 m
.58294 .67721 L
s
% Start of user PostScript
38. 44. 37.9975 44.022 MAarrowhead1
% End of user PostScript
.59809 .67688 m
.59839 .67776 L
s
% Start of user PostScript
39. 44. 39.02 44.0584 MAarrowhead1
% End of user PostScript
.61319 .67688 m
.61367 .67836 L
s
% Start of user PostScript
40. 44. 40.0318 44.098 MAarrowhead1
% End of user PostScript
.6283 .67688 m
.62863 .67688 L
s
% Start of user PostScript
41. 44. 41.022 44. MAarrowhead1
% End of user PostScript
.6434 .67688 m
.64397 .67722 L
s
% Start of user PostScript
42. 44. 42.0373 44.0224 MAarrowhead1
% End of user PostScript
.65851 .67688 m
.65851 .67797 L
s
% Start of user PostScript
43. 44. 43. 44.0722 MAarrowhead1
% End of user PostScript
.67361 .67688 m
.66796 .67193 L
s
% Start of user PostScript
44. 44. 43.6257 43.6724 MAarrowhead1
% End of user PostScript
.68872 .67688 m
.68905 .67836 L
s
% Start of user PostScript
45. 44. 45.022 44.098 MAarrowhead1
% End of user PostScript
.70382 .67688 m
.70229 .67469 L
s
% Start of user PostScript
46. 44. 45.8985 43.8553 MAarrowhead1
% End of user PostScript
.71893 .67688 m
.7184 .67473 L
s
% Start of user PostScript
47. 44. 46.9652 43.858 MAarrowhead1
% End of user PostScript
.73403 .67688 m
.73403 .67688 L
s
% Start of user PostScript
48. 44. MAarrowzero1
% End of user PostScript
.74914 .67688 m
.74914 .67688 L
s
% Start of user PostScript
49. 44. MAarrowzero1
% End of user PostScript
.76424 .67688 m
.76424 .67688 L
s
% Start of user PostScript
50. 44. MAarrowzero1
% End of user PostScript
.77935 .67688 m
.77935 .67688 L
s
% Start of user PostScript
51. 44. MAarrowzero1
% End of user PostScript
.79445 .67688 m
.79445 .67688 L
s
% Start of user PostScript
52. 44. MAarrowzero1
% End of user PostScript
.80956 .67688 m
.80956 .67688 L
s
% Start of user PostScript
53. 44. MAarrowzero1
% End of user PostScript
.82466 .67688 m
.82466 .67688 L
s
% Start of user PostScript
54. 44. MAarrowzero1
% End of user PostScript
.83977 .67688 m
.83977 .67688 L
s
% Start of user PostScript
55. 44. MAarrowzero1
% End of user PostScript
.85488 .67688 m
.85488 .67688 L
s
% Start of user PostScript
56. 44. MAarrowzero1
% End of user PostScript
.86998 .67688 m
.86998 .67688 L
s
% Start of user PostScript
57. 44. MAarrowzero1
% End of user PostScript
.88509 .67688 m
.88509 .67688 L
s
% Start of user PostScript
58. 44. MAarrowzero1
% End of user PostScript
.90019 .67688 m
.90019 .67688 L
s
% Start of user PostScript
59. 44. MAarrowzero1
% End of user PostScript
.9153 .67688 m
.9153 .67688 L
s
% Start of user PostScript
60. 44. MAarrowzero1
% End of user PostScript
.9304 .67688 m
.9304 .67688 L
s
% Start of user PostScript
61. 44. MAarrowzero1
% End of user PostScript
.94551 .67688 m
.94551 .67688 L
s
% Start of user PostScript
62. 44. MAarrowzero1
% End of user PostScript
.96061 .67688 m
.96061 .67688 L
s
% Start of user PostScript
63. 44. MAarrowzero1
% End of user PostScript
.97572 .67688 m
.97572 .67688 L
s
% Start of user PostScript
64. 44. MAarrowzero1
% End of user PostScript
.02409 .69198 m
.02409 .69198 L
s
% Start of user PostScript
1. 45. MAarrowzero1
% End of user PostScript
.03919 .69198 m
.03891 .69198 L
s
% Start of user PostScript
2. 45. 1.98149 45. MAarrowhead1
% End of user PostScript
.0543 .69198 m
.0543 .69198 L
s
% Start of user PostScript
3. 45. MAarrowzero1
% End of user PostScript
.0694 .69198 m
.0694 .69198 L
s
% Start of user PostScript
4. 45. MAarrowzero1
% End of user PostScript
.08451 .69198 m
.08451 .69198 L
s
% Start of user PostScript
5. 45. MAarrowzero1
% End of user PostScript
.09962 .69198 m
.09962 .69198 L
s
% Start of user PostScript
6. 45. MAarrowzero1
% End of user PostScript
.11472 .69198 m
.11444 .69198 L
s
% Start of user PostScript
7. 45. 6.98149 45. MAarrowhead1
% End of user PostScript
.12983 .69198 m
.12983 .69198 L
s
% Start of user PostScript
8. 45. MAarrowzero1
% End of user PostScript
.14493 .69198 m
.14493 .69198 L
s
% Start of user PostScript
9. 45. MAarrowzero1
% End of user PostScript
.16004 .69198 m
.16398 .69198 L
s
% Start of user PostScript
10. 45. 10.2608 45. MAarrowhead1
% End of user PostScript
.17514 .69198 m
.18206 .69262 L
s
% Start of user PostScript
11. 45. 11.4582 45.0424 MAarrowhead1
% End of user PostScript
.19025 .69198 m
.19025 .69297 L
s
% Start of user PostScript
12. 45. 12. 45.0651 MAarrowhead1
% End of user PostScript
.20535 .69198 m
.20602 .69146 L
s
% Start of user PostScript
13. 45. 13.0443 44.9651 MAarrowhead1
% End of user PostScript
.22046 .69198 m
.21864 .69126 L
s
% Start of user PostScript
14. 45. 13.88 44.9521 MAarrowhead1
% End of user PostScript
.23556 .69198 m
.23484 .69101 L
s
% Start of user PostScript
15. 45. 14.9521 44.9356 MAarrowhead1
% End of user PostScript
.25067 .69198 m
.24938 .69119 L
s
% Start of user PostScript
16. 45. 15.9148 44.9474 MAarrowhead1
% End of user PostScript
.26577 .69198 m
.26577 .69198 L
s
% Start of user PostScript
17. 45. MAarrowzero1
% End of user PostScript
.28088 .69198 m
.28102 .69198 L
s
% Start of user PostScript
18. 45. 18.0094 45. MAarrowhead1
% End of user PostScript
.29598 .69198 m
.29607 .69165 L
s
% Start of user PostScript
19. 45. 19.0055 44.978 MAarrowhead1
% End of user PostScript
.31109 .69198 m
.31084 .69198 L
s
% Start of user PostScript
20. 45. 19.9836 45. MAarrowhead1
% End of user PostScript
.32619 .69198 m
.32611 .6919 L
s
% Start of user PostScript
21. 45. 20.9945 44.9945 MAarrowhead1
% End of user PostScript
.3413 .69198 m
.34138 .69198 L
s
% Start of user PostScript
22. 45. 22.0055 45. MAarrowhead1
% End of user PostScript
.3564 .69198 m
.3564 .69237 L
s
% Start of user PostScript
23. 45. 23. 45.0258 MAarrowhead1
% End of user PostScript
.37151 .69198 m
.37151 .69198 L
s
% Start of user PostScript
24. 45. MAarrowzero1
% End of user PostScript
.38661 .69198 m
.38661 .69198 L
s
% Start of user PostScript
25. 45. MAarrowzero1
% End of user PostScript
.40172 .69198 m
.40205 .69198 L
s
% Start of user PostScript
26. 45. 26.022 45. MAarrowhead1
% End of user PostScript
.41682 .69198 m
.41716 .69231 L
s
% Start of user PostScript
27. 45. 27.022 45.022 MAarrowhead1
% End of user PostScript
.43193 .69198 m
.43193 .69198 L
s
% Start of user PostScript
28. 45. MAarrowzero1
% End of user PostScript
.44703 .69198 m
.44703 .69198 L
s
% Start of user PostScript
29. 45. MAarrowzero1
% End of user PostScript
.46214 .69198 m
.46167 .69218 L
s
% Start of user PostScript
30. 45. 29.9686 45.0129 MAarrowhead1
% End of user PostScript
.47725 .69198 m
.4773 .69193 L
s
% Start of user PostScript
31. 45. 31.0035 44.9965 MAarrowhead1
% End of user PostScript
.49235 .69198 m
.49235 .69193 L
s
% Start of user PostScript
32. 45. 32. 44.9965 MAarrowhead1
% End of user PostScript
.50746 .69198 m
.50754 .69213 L
s
% Start of user PostScript
33. 45. 33.0055 45.0094 MAarrowhead1
% End of user PostScript
.52256 .69198 m
.52261 .69226 L
s
% Start of user PostScript
34. 45. 34.0035 45.0185 MAarrowhead1
% End of user PostScript
.53767 .69198 m
.53767 .69204 L
s
% Start of user PostScript
35. 45. 35. 45.0035 MAarrowhead1
% End of user PostScript
.55277 .69198 m
.5524 .69193 L
s
% Start of user PostScript
36. 45. 35.9753 44.9965 MAarrowhead1
% End of user PostScript
.56788 .69198 m
.56835 .69308 L
s
% Start of user PostScript
37. 45. 37.0314 45.0726 MAarrowhead1
% End of user PostScript
.58298 .69198 m
.584 .69321 L
s
% Start of user PostScript
38. 45. 38.0676 45.0815 MAarrowhead1
% End of user PostScript
.59809 .69198 m
.59786 .69422 L
s
% Start of user PostScript
39. 45. 38.9851 45.1479 MAarrowhead1
% End of user PostScript
.61319 .69198 m
.6145 .69295 L
s
% Start of user PostScript
40. 45. 40.0863 45.0639 MAarrowhead1
% End of user PostScript
.6283 .69198 m
.62863 .69307 L
s
% Start of user PostScript
41. 45. 41.022 45.0722 MAarrowhead1
% End of user PostScript
.6434 .69198 m
.64374 .69246 L
s
% Start of user PostScript
42. 45. 42.0224 45.0318 MAarrowhead1
% End of user PostScript
.65851 .69198 m
.65889 .69274 L
s
% Start of user PostScript
43. 45. 43.0254 45.0502 MAarrowhead1
% End of user PostScript
.67361 .69198 m
.6729 .68797 L
s
% Start of user PostScript
44. 45. 43.953 44.734 MAarrowhead1
% End of user PostScript
.68872 .69198 m
.68752 .69121 L
s
% Start of user PostScript
45. 45. 44.9207 44.9486 MAarrowhead1
% End of user PostScript
.70382 .69198 m
.70221 .68898 L
s
% Start of user PostScript
46. 45. 45.8931 44.801 MAarrowhead1
% End of user PostScript
.71893 .69198 m
.71921 .69198 L
s
% Start of user PostScript
47. 45. 47.0185 45. MAarrowhead1
% End of user PostScript
.73403 .69198 m
.73403 .69198 L
s
% Start of user PostScript
48. 45. MAarrowzero1
% End of user PostScript
.74914 .69198 m
.74914 .69198 L
s
% Start of user PostScript
49. 45. MAarrowzero1
% End of user PostScript
.76424 .69198 m
.76424 .69198 L
s
% Start of user PostScript
50. 45. MAarrowzero1
% End of user PostScript
.77935 .69198 m
.77935 .69198 L
s
% Start of user PostScript
51. 45. MAarrowzero1
% End of user PostScript
.79445 .69198 m
.79445 .69198 L
s
% Start of user PostScript
52. 45. MAarrowzero1
% End of user PostScript
.80956 .69198 m
.80956 .69198 L
s
% Start of user PostScript
53. 45. MAarrowzero1
% End of user PostScript
.82466 .69198 m
.82466 .69198 L
s
% Start of user PostScript
54. 45. MAarrowzero1
% End of user PostScript
.83977 .69198 m
.83977 .69198 L
s
% Start of user PostScript
55. 45. MAarrowzero1
% End of user PostScript
.85488 .69198 m
.85488 .69198 L
s
% Start of user PostScript
56. 45. MAarrowzero1
% End of user PostScript
.86998 .69198 m
.86998 .69198 L
s
% Start of user PostScript
57. 45. MAarrowzero1
% End of user PostScript
.88509 .69198 m
.88509 .69198 L
s
% Start of user PostScript
58. 45. MAarrowzero1
% End of user PostScript
.90019 .69198 m
.90019 .69198 L
s
% Start of user PostScript
59. 45. MAarrowzero1
% End of user PostScript
.9153 .69198 m
.9153 .69198 L
s
% Start of user PostScript
60. 45. MAarrowzero1
% End of user PostScript
.9304 .69198 m
.9304 .69198 L
s
% Start of user PostScript
61. 45. MAarrowzero1
% End of user PostScript
.94551 .69198 m
.94551 .69198 L
s
% Start of user PostScript
62. 45. MAarrowzero1
% End of user PostScript
.96061 .69198 m
.96061 .69198 L
s
% Start of user PostScript
63. 45. MAarrowzero1
% End of user PostScript
.97572 .69198 m
.97572 .69198 L
s
% Start of user PostScript
64. 45. MAarrowzero1
% End of user PostScript
.02409 .70709 m
.02409 .70709 L
s
% Start of user PostScript
1. 46. MAarrowzero1
% End of user PostScript
.03919 .70709 m
.03919 .70709 L
s
% Start of user PostScript
2. 46. MAarrowzero1
% End of user PostScript
.0543 .70709 m
.0543 .70709 L
s
% Start of user PostScript
3. 46. MAarrowzero1
% End of user PostScript
.0694 .70709 m
.0694 .70709 L
s
% Start of user PostScript
4. 46. MAarrowzero1
% End of user PostScript
.08451 .70709 m
.08451 .70709 L
s
% Start of user PostScript
5. 46. MAarrowzero1
% End of user PostScript
.09962 .70709 m
.09962 .70709 L
s
% Start of user PostScript
6. 46. MAarrowzero1
% End of user PostScript
.11472 .70709 m
.11472 .70709 L
s
% Start of user PostScript
7. 46. MAarrowzero1
% End of user PostScript
.12983 .70709 m
.12983 .70709 L
s
% Start of user PostScript
8. 46. MAarrowzero1
% End of user PostScript
.14493 .70709 m
.14493 .70709 L
s
% Start of user PostScript
9. 46. MAarrowzero1
% End of user PostScript
.16004 .70709 m
.16004 .70709 L
s
% Start of user PostScript
10. 46. MAarrowzero1
% End of user PostScript
.17514 .70709 m
.18047 .70982 L
s
% Start of user PostScript
11. 46. 11.3529 46.1807 MAarrowhead1
% End of user PostScript
.19025 .70709 m
.18807 .70675 L
s
% Start of user PostScript
12. 46. 11.8557 45.9776 MAarrowhead1
% End of user PostScript
.20535 .70709 m
.20674 .70667 L
s
% Start of user PostScript
13. 46. 13.0918 45.9721 MAarrowhead1
% End of user PostScript
.22046 .70709 m
.22046 .7057 L
s
% Start of user PostScript
14. 46. 14. 45.9082 MAarrowhead1
% End of user PostScript
.23556 .70709 m
.2344 .70615 L
s
% Start of user PostScript
15. 46. 14.9232 45.9382 MAarrowhead1
% End of user PostScript
.25067 .70709 m
.24984 .70637 L
s
% Start of user PostScript
16. 46. 15.9451 45.9524 MAarrowhead1
% End of user PostScript
.26577 .70709 m
.26563 .70638 L
s
% Start of user PostScript
17. 46. 16.9906 45.9533 MAarrowhead1
% End of user PostScript
.28088 .70709 m
.28035 .70709 L
s
% Start of user PostScript
18. 46. 17.9652 46. MAarrowhead1
% End of user PostScript
.29598 .70709 m
.29618 .70689 L
s
% Start of user PostScript
19. 46. 19.0129 45.9871 MAarrowhead1
% End of user PostScript
.31109 .70709 m
.31142 .70709 L
s
% Start of user PostScript
20. 46. 20.022 46. MAarrowhead1
% End of user PostScript
.32619 .70709 m
.32577 .70709 L
s
% Start of user PostScript
21. 46. 20.9721 46. MAarrowhead1
% End of user PostScript
.3413 .70709 m
.3413 .70709 L
s
% Start of user PostScript
22. 46. MAarrowzero1
% End of user PostScript
.3564 .70709 m
.3564 .70709 L
s
% Start of user PostScript
23. 46. MAarrowzero1
% End of user PostScript
.37151 .70709 m
.37184 .70709 L
s
% Start of user PostScript
24. 46. 24.022 46. MAarrowhead1
% End of user PostScript
.38661 .70709 m
.38676 .70742 L
s
% Start of user PostScript
25. 46. 25.0094 46.022 MAarrowhead1
% End of user PostScript
.40172 .70709 m
.40214 .70709 L
s
% Start of user PostScript
26. 46. 26.0279 46. MAarrowhead1
% End of user PostScript
.41682 .70709 m
.41635 .70709 L
s
% Start of user PostScript
27. 46. 26.9686 46. MAarrowhead1
% End of user PostScript
.43193 .70709 m
.43165 .70709 L
s
% Start of user PostScript
28. 46. 27.9815 46. MAarrowhead1
% End of user PostScript
.44703 .70709 m
.44703 .70709 L
s
% Start of user PostScript
29. 46. MAarrowzero1
% End of user PostScript
.46214 .70709 m
.46209 .70709 L
s
% Start of user PostScript
30. 46. 29.9965 46. MAarrowhead1
% End of user PostScript
.47725 .70709 m
.47725 .70709 L
s
% Start of user PostScript
31. 46. MAarrowzero1
% End of user PostScript
.49235 .70709 m
.49235 .7076 L
s
% Start of user PostScript
32. 46. 32. 46.0341 MAarrowhead1
% End of user PostScript
.50746 .70709 m
.50788 .70728 L
s
% Start of user PostScript
33. 46. 33.0279 46.0129 MAarrowhead1
% End of user PostScript
.52256 .70709 m
.52251 .70753 L
s
% Start of user PostScript
34. 46. 33.9965 46.0291 MAarrowhead1
% End of user PostScript
.53767 .70709 m
.53761 .70737 L
s
% Start of user PostScript
35. 46. 34.9965 46.0188 MAarrowhead1
% End of user PostScript
.55277 .70709 m
.55205 .70751 L
s
% Start of user PostScript
36. 46. 35.9521 46.0282 MAarrowhead1
% End of user PostScript
.56788 .70709 m
.56855 .70899 L
s
% Start of user PostScript
37. 46. 37.0445 46.126 MAarrowhead1
% End of user PostScript
.58298 .70709 m
.58386 .70764 L
s
% Start of user PostScript
38. 46. 38.0584 46.0364 MAarrowhead1
% End of user PostScript
.59809 .70709 m
.59902 .70769 L
s
% Start of user PostScript
39. 46. 39.0616 46.0396 MAarrowhead1
% End of user PostScript
.61319 .70709 m
.61222 .70767 L
s
% Start of user PostScript
40. 46. 39.9356 46.0385 MAarrowhead1
% End of user PostScript
.6283 .70709 m
.63167 .70813 L
s
% Start of user PostScript
41. 46. 41.2236 46.0691 MAarrowhead1
% End of user PostScript
.6434 .70709 m
.6434 .70781 L
s
% Start of user PostScript
42. 46. 42. 46.0479 MAarrowhead1
% End of user PostScript
.65851 .70709 m
.65574 .70285 L
s
% Start of user PostScript
43. 46. 42.8169 45.7191 MAarrowhead1
% End of user PostScript
.67361 .70709 m
.67444 .70781 L
s
% Start of user PostScript
44. 46. 44.0545 46.0478 MAarrowhead1
% End of user PostScript
.68872 .70709 m
.68745 .70422 L
s
% Start of user PostScript
45. 46. 44.916 45.8101 MAarrowhead1
% End of user PostScript
.70382 .70709 m
.70178 .70394 L
s
% Start of user PostScript
46. 46. 45.8649 45.7916 MAarrowhead1
% End of user PostScript
.71893 .70709 m
.71921 .70737 L
s
% Start of user PostScript
47. 46. 47.0185 46.0185 MAarrowhead1
% End of user PostScript
.73403 .70709 m
.73451 .70681 L
s
% Start of user PostScript
48. 46. 48.0314 45.9815 MAarrowhead1
% End of user PostScript
.74914 .70709 m
.74914 .70709 L
s
% Start of user PostScript
49. 46. MAarrowzero1
% End of user PostScript
.76424 .70709 m
.76424 .70709 L
s
% Start of user PostScript
50. 46. MAarrowzero1
% End of user PostScript
.77935 .70709 m
.77935 .70709 L
s
% Start of user PostScript
51. 46. MAarrowzero1
% End of user PostScript
.79445 .70709 m
.79445 .70709 L
s
% Start of user PostScript
52. 46. MAarrowzero1
% End of user PostScript
.80956 .70709 m
.80956 .70709 L
s
% Start of user PostScript
53. 46. MAarrowzero1
% End of user PostScript
.82466 .70709 m
.82466 .70709 L
s
% Start of user PostScript
54. 46. MAarrowzero1
% End of user PostScript
.83977 .70709 m
.83977 .70709 L
s
% Start of user PostScript
55. 46. MAarrowzero1
% End of user PostScript
.85488 .70709 m
.85488 .70709 L
s
% Start of user PostScript
56. 46. MAarrowzero1
% End of user PostScript
.86998 .70709 m
.86998 .70709 L
s
% Start of user PostScript
57. 46. MAarrowzero1
% End of user PostScript
.88509 .70709 m
.88509 .70709 L
s
% Start of user PostScript
58. 46. MAarrowzero1
% End of user PostScript
.90019 .70709 m
.90019 .70709 L
s
% Start of user PostScript
59. 46. MAarrowzero1
% End of user PostScript
.9153 .70709 m
.9153 .70709 L
s
% Start of user PostScript
60. 46. MAarrowzero1
% End of user PostScript
.9304 .70709 m
.9304 .70709 L
s
% Start of user PostScript
61. 46. MAarrowzero1
% End of user PostScript
.94551 .70709 m
.94551 .70709 L
s
% Start of user PostScript
62. 46. MAarrowzero1
% End of user PostScript
.96061 .70709 m
.96061 .70709 L
s
% Start of user PostScript
63. 46. MAarrowzero1
% End of user PostScript
.97572 .70709 m
.97572 .70709 L
s
% Start of user PostScript
64. 46. MAarrowzero1
% End of user PostScript
.02409 .72219 m
.02409 .72219 L
s
% Start of user PostScript
1. 47. MAarrowzero1
% End of user PostScript
.03919 .72219 m
.03919 .72219 L
s
% Start of user PostScript
2. 47. MAarrowzero1
% End of user PostScript
.0543 .72219 m
.0543 .72219 L
s
% Start of user PostScript
3. 47. MAarrowzero1
% End of user PostScript
.0694 .72219 m
.0694 .72219 L
s
% Start of user PostScript
4. 47. MAarrowzero1
% End of user PostScript
.08451 .72219 m
.08451 .72219 L
s
% Start of user PostScript
5. 47. MAarrowzero1
% End of user PostScript
.09962 .72219 m
.09962 .72219 L
s
% Start of user PostScript
6. 47. MAarrowzero1
% End of user PostScript
.11472 .72219 m
.11472 .72219 L
s
% Start of user PostScript
7. 47. MAarrowzero1
% End of user PostScript
.12983 .72219 m
.12983 .72219 L
s
% Start of user PostScript
8. 47. MAarrowzero1
% End of user PostScript
.14493 .72219 m
.14493 .72219 L
s
% Start of user PostScript
9. 47. MAarrowzero1
% End of user PostScript
.16004 .72219 m
.16004 .72219 L
s
% Start of user PostScript
10. 47. MAarrowzero1
% End of user PostScript
.17514 .72219 m
.17918 .72705 L
s
% Start of user PostScript
11. 47. 11.2677 47.3215 MAarrowhead1
% End of user PostScript
.19025 .72219 m
.19449 .7249 L
s
% Start of user PostScript
12. 47. 12.2812 47.1793 MAarrowhead1
% End of user PostScript
.20535 .72219 m
.20459 .72202 L
s
% Start of user PostScript
13. 47. 12.9499 46.9882 MAarrowhead1
% End of user PostScript
.22046 .72219 m
.2187 .72274 L
s
% Start of user PostScript
14. 47. 13.8839 47.0364 MAarrowhead1
% End of user PostScript
.23556 .72219 m
.23398 .72176 L
s
% Start of user PostScript
15. 47. 14.8953 46.9711 MAarrowhead1
% End of user PostScript
.25067 .72219 m
.24949 .72195 L
s
% Start of user PostScript
16. 47. 15.9221 46.9836 MAarrowhead1
% End of user PostScript
.26577 .72219 m
.26493 .72219 L
s
% Start of user PostScript
17. 47. 16.9439 47. MAarrowhead1
% End of user PostScript
.28088 .72219 m
.28083 .72285 L
s
% Start of user PostScript
18. 47. 17.9965 47.0432 MAarrowhead1
% End of user PostScript
.29598 .72219 m
.29618 .72219 L
s
% Start of user PostScript
19. 47. 19.0129 47. MAarrowhead1
% End of user PostScript
.31109 .72219 m
.31114 .72267 L
s
% Start of user PostScript
20. 47. 20.0035 47.0314 MAarrowhead1
% End of user PostScript
.32619 .72219 m
.32577 .72267 L
s
% Start of user PostScript
21. 47. 20.9721 47.0314 MAarrowhead1
% End of user PostScript
.3413 .72219 m
.34102 .72219 L
s
% Start of user PostScript
22. 47. 21.9815 47. MAarrowhead1
% End of user PostScript
.3564 .72219 m
.3564 .72186 L
s
% Start of user PostScript
23. 47. 23. 46.978 MAarrowhead1
% End of user PostScript
.37151 .72219 m
.37076 .72234 L
s
% Start of user PostScript
24. 47. 23.9501 47.0094 MAarrowhead1
% End of user PostScript
.38661 .72219 m
.38642 .72239 L
s
% Start of user PostScript
25. 47. 24.9871 47.0129 MAarrowhead1
% End of user PostScript
.40172 .72219 m
.40167 .7229 L
s
% Start of user PostScript
26. 47. 25.9965 47.0467 MAarrowhead1
% End of user PostScript
.41682 .72219 m
.41668 .72304 L
s
% Start of user PostScript
27. 47. 26.9906 47.0561 MAarrowhead1
% End of user PostScript
.43193 .72219 m
.43122 .72225 L
s
% Start of user PostScript
28. 47. 27.9533 47.0035 MAarrowhead1
% End of user PostScript
.44703 .72219 m
.44703 .72257 L
s
% Start of user PostScript
29. 47. 29. 47.0247 MAarrowhead1
% End of user PostScript
.46214 .72219 m
.46149 .72257 L
s
% Start of user PostScript
30. 47. 29.9568 47.0247 MAarrowhead1
% End of user PostScript
.47725 .72219 m
.47654 .72304 L
s
% Start of user PostScript
31. 47. 30.9533 47.0561 MAarrowhead1
% End of user PostScript
.49235 .72219 m
.4924 .72353 L
s
% Start of user PostScript
32. 47. 32.0035 47.0886 MAarrowhead1
% End of user PostScript
.50746 .72219 m
.50712 .72263 L
s
% Start of user PostScript
33. 47. 32.978 47.0291 MAarrowhead1
% End of user PostScript
.52256 .72219 m
.52209 .72267 L
s
% Start of user PostScript
34. 47. 33.9686 47.0314 MAarrowhead1
% End of user PostScript
.53767 .72219 m
.53729 .72376 L
s
% Start of user PostScript
35. 47. 34.9753 47.104 MAarrowhead1
% End of user PostScript
.55277 .72219 m
.55277 .72267 L
s
% Start of user PostScript
36. 47. 36. 47.0314 MAarrowhead1
% End of user PostScript
.56788 .72219 m
.56878 .72309 L
s
% Start of user PostScript
37. 47. 37.0595 47.0595 MAarrowhead1
% End of user PostScript
.58298 .72219 m
.58428 .72253 L
s
% Start of user PostScript
38. 47. 38.0859 47.022 MAarrowhead1
% End of user PostScript
.59809 .72219 m
.5975 .72278 L
s
% Start of user PostScript
39. 47. 38.9615 47.0385 MAarrowhead1
% End of user PostScript
.61319 .72219 m
.61256 .72283 L
s
% Start of user PostScript
40. 47. 39.958 47.042 MAarrowhead1
% End of user PostScript
.6283 .72219 m
.62763 .72143 L
s
% Start of user PostScript
41. 47. 40.9555 46.9498 MAarrowhead1
% End of user PostScript
.6434 .72219 m
.64198 .71781 L
s
% Start of user PostScript
42. 47. 41.9058 46.7098 MAarrowhead1
% End of user PostScript
.65851 .72219 m
.65754 .71949 L
s
% Start of user PostScript
43. 47. 42.9356 46.8207 MAarrowhead1
% End of user PostScript
.67361 .72219 m
.67213 .71946 L
s
% Start of user PostScript
44. 47. 43.902 46.8192 MAarrowhead1
% End of user PostScript
.68872 .72219 m
.68734 .71936 L
s
% Start of user PostScript
45. 47. 44.9091 46.8126 MAarrowhead1
% End of user PostScript
.70382 .72219 m
.70382 .7191 L
s
% Start of user PostScript
46. 47. 46. 46.7951 MAarrowhead1
% End of user PostScript
.71893 .72219 m
.71893 .72295 L
s
% Start of user PostScript
47. 47. 47. 47.0499 MAarrowhead1
% End of user PostScript
.73403 .72219 m
.73403 .72219 L
s
% Start of user PostScript
48. 47. MAarrowzero1
% End of user PostScript
.74914 .72219 m
.74961 .72219 L
s
% Start of user PostScript
49. 47. 49.0314 47. MAarrowhead1
% End of user PostScript
.76424 .72219 m
.76424 .72219 L
s
% Start of user PostScript
50. 47. MAarrowzero1
% End of user PostScript
.77935 .72219 m
.77935 .72219 L
s
% Start of user PostScript
51. 47. MAarrowzero1
% End of user PostScript
.79445 .72219 m
.79445 .72219 L
s
% Start of user PostScript
52. 47. MAarrowzero1
% End of user PostScript
.80956 .72219 m
.80956 .72219 L
s
% Start of user PostScript
53. 47. MAarrowzero1
% End of user PostScript
.82466 .72219 m
.82466 .72219 L
s
% Start of user PostScript
54. 47. MAarrowzero1
% End of user PostScript
.83977 .72219 m
.83977 .72219 L
s
% Start of user PostScript
55. 47. MAarrowzero1
% End of user PostScript
.85488 .72219 m
.85488 .72219 L
s
% Start of user PostScript
56. 47. MAarrowzero1
% End of user PostScript
.86998 .72219 m
.86998 .72219 L
s
% Start of user PostScript
57. 47. MAarrowzero1
% End of user PostScript
.88509 .72219 m
.88556 .72219 L
s
% Start of user PostScript
58. 47. 58.0314 47. MAarrowhead1
% End of user PostScript
.90019 .72219 m
.90019 .72219 L
s
% Start of user PostScript
59. 47. MAarrowzero1
% End of user PostScript
.9153 .72219 m
.9153 .72219 L
s
% Start of user PostScript
60. 47. MAarrowzero1
% End of user PostScript
.9304 .72219 m
.9304 .72219 L
s
% Start of user PostScript
61. 47. MAarrowzero1
% End of user PostScript
.94551 .72219 m
.94551 .72219 L
s
% Start of user PostScript
62. 47. MAarrowzero1
% End of user PostScript
.96061 .72219 m
.96061 .72219 L
s
% Start of user PostScript
63. 47. MAarrowzero1
% End of user PostScript
.97572 .72219 m
.97572 .72219 L
s
% Start of user PostScript
64. 47. MAarrowzero1
% End of user PostScript
.02409 .7373 m
.02409 .7373 L
s
% Start of user PostScript
1. 48. MAarrowzero1
% End of user PostScript
.03919 .7373 m
.03919 .7373 L
s
% Start of user PostScript
2. 48. MAarrowzero1
% End of user PostScript
.0543 .7373 m
.0543 .7373 L
s
% Start of user PostScript
3. 48. MAarrowzero1
% End of user PostScript
.0694 .7373 m
.0694 .7373 L
s
% Start of user PostScript
4. 48. MAarrowzero1
% End of user PostScript
.08451 .7373 m
.08451 .7373 L
s
% Start of user PostScript
5. 48. MAarrowzero1
% End of user PostScript
.09962 .7373 m
.09962 .7373 L
s
% Start of user PostScript
6. 48. MAarrowzero1
% End of user PostScript
.11472 .7373 m
.11472 .7373 L
s
% Start of user PostScript
7. 48. MAarrowzero1
% End of user PostScript
.12983 .7373 m
.12983 .7373 L
s
% Start of user PostScript
8. 48. MAarrowzero1
% End of user PostScript
.14493 .7373 m
.14493 .7373 L
s
% Start of user PostScript
9. 48. MAarrowzero1
% End of user PostScript
.16004 .7373 m
.16004 .7373 L
s
% Start of user PostScript
10. 48. MAarrowzero1
% End of user PostScript
.17514 .7373 m
.17646 .7373 L
s
% Start of user PostScript
11. 48. 11.0875 48. MAarrowhead1
% End of user PostScript
.19025 .7373 m
.19697 .74169 L
s
% Start of user PostScript
12. 48. 12.4451 48.2904 MAarrowhead1
% End of user PostScript
.20535 .7373 m
.20412 .73599 L
s
% Start of user PostScript
13. 48. 12.9184 47.9137 MAarrowhead1
% End of user PostScript
.22046 .7373 m
.22003 .73645 L
s
% Start of user PostScript
14. 48. 13.9721 47.9439 MAarrowhead1
% End of user PostScript
.23556 .7373 m
.23403 .73767 L
s
% Start of user PostScript
15. 48. 14.8985 48.0243 MAarrowhead1
% End of user PostScript
.25067 .7373 m
.24904 .7373 L
s
% Start of user PostScript
16. 48. 15.8925 48. MAarrowhead1
% End of user PostScript
.26577 .7373 m
.26605 .7373 L
s
% Start of user PostScript
17. 48. 17.0185 48. MAarrowhead1
% End of user PostScript
.28088 .7373 m
.28049 .73744 L
s
% Start of user PostScript
18. 48. 17.9745 48.0094 MAarrowhead1
% End of user PostScript
.29598 .7373 m
.29514 .73725 L
s
% Start of user PostScript
19. 48. 18.9439 47.9965 MAarrowhead1
% End of user PostScript
.31109 .7373 m
.31109 .73716 L
s
% Start of user PostScript
20. 48. 20. 47.9906 MAarrowhead1
% End of user PostScript
.32619 .7373 m
.32619 .73777 L
s
% Start of user PostScript
21. 48. 21. 48.0314 MAarrowhead1
% End of user PostScript
.3413 .7373 m
.34079 .73781 L
s
% Start of user PostScript
22. 48. 21.9663 48.0337 MAarrowhead1
% End of user PostScript
.3564 .7373 m
.35589 .73786 L
s
% Start of user PostScript
23. 48. 22.9663 48.0371 MAarrowhead1
% End of user PostScript
.37151 .7373 m
.37066 .73853 L
s
% Start of user PostScript
24. 48. 23.9439 48.0817 MAarrowhead1
% End of user PostScript
.38661 .7373 m
.38565 .73864 L
s
% Start of user PostScript
25. 48. 24.9361 48.0886 MAarrowhead1
% End of user PostScript
.40172 .7373 m
.40161 .73832 L
s
% Start of user PostScript
26. 48. 25.9929 48.0674 MAarrowhead1
% End of user PostScript
.41682 .7373 m
.41614 .73836 L
s
% Start of user PostScript
27. 48. 26.9546 48.0701 MAarrowhead1
% End of user PostScript
.43193 .7373 m
.43045 .73864 L
s
% Start of user PostScript
28. 48. 27.902 48.0886 MAarrowhead1
% End of user PostScript
.44703 .7373 m
.44598 .73816 L
s
% Start of user PostScript
29. 48. 28.9299 48.0573 MAarrowhead1
% End of user PostScript
.46214 .7373 m
.46113 .73836 L
s
% Start of user PostScript
30. 48. 29.9333 48.0701 MAarrowhead1
% End of user PostScript
.47725 .7373 m
.47635 .73854 L
s
% Start of user PostScript
31. 48. 30.9405 48.082 MAarrowhead1
% End of user PostScript
.49235 .7373 m
.49145 .73888 L
s
% Start of user PostScript
32. 48. 31.9405 48.1049 MAarrowhead1
% End of user PostScript
.50746 .7373 m
.50656 .73867 L
s
% Start of user PostScript
33. 48. 32.9405 48.0909 MAarrowhead1
% End of user PostScript
.52256 .7373 m
.52156 .73887 L
s
% Start of user PostScript
34. 48. 33.9337 48.104 MAarrowhead1
% End of user PostScript
.53767 .7373 m
.53767 .73844 L
s
% Start of user PostScript
35. 48. 35. 48.0758 MAarrowhead1
% End of user PostScript
.55277 .7373 m
.55282 .73772 L
s
% Start of user PostScript
36. 48. 36.0035 48.0282 MAarrowhead1
% End of user PostScript
.56788 .7373 m
.56705 .73934 L
s
% Start of user PostScript
37. 48. 36.9455 48.1354 MAarrowhead1
% End of user PostScript
.58298 .7373 m
.58415 .73772 L
s
% Start of user PostScript
38. 48. 38.0776 48.0279 MAarrowhead1
% End of user PostScript
.59809 .7373 m
.598 .73632 L
s
% Start of user PostScript
39. 48. 38.994 47.9349 MAarrowhead1
% End of user PostScript
.61319 .7373 m
.61333 .73769 L
s
% Start of user PostScript
40. 48. 40.0094 48.0258 MAarrowhead1
% End of user PostScript
.6283 .7373 m
.62978 .73607 L
s
% Start of user PostScript
41. 48. 41.098 47.9184 MAarrowhead1
% End of user PostScript
.6434 .7373 m
.64187 .73673 L
s
% Start of user PostScript
42. 48. 41.8985 47.9627 MAarrowhead1
% End of user PostScript
.65851 .7373 m
.65763 .73564 L
s
% Start of user PostScript
43. 48. 42.9416 47.89 MAarrowhead1
% End of user PostScript
.67361 .7373 m
.67166 .73524 L
s
% Start of user PostScript
44. 48. 43.8706 47.8637 MAarrowhead1
% End of user PostScript
.68872 .7373 m
.68891 .73478 L
s
% Start of user PostScript
45. 48. 45.0127 47.8331 MAarrowhead1
% End of user PostScript
.70382 .7373 m
.70382 .73702 L
s
% Start of user PostScript
46. 48. 46. 47.9815 MAarrowhead1
% End of user PostScript
.71893 .7373 m
.71893 .7373 L
s
% Start of user PostScript
47. 48. MAarrowzero1
% End of user PostScript
.73403 .7373 m
.73403 .73777 L
s
% Start of user PostScript
48. 48. 48. 48.0314 MAarrowhead1
% End of user PostScript
.74914 .7373 m
.74914 .7373 L
s
% Start of user PostScript
49. 48. MAarrowzero1
% End of user PostScript
.76424 .7373 m
.76424 .7373 L
s
% Start of user PostScript
50. 48. MAarrowzero1
% End of user PostScript
.77935 .7373 m
.77935 .7373 L
s
% Start of user PostScript
51. 48. MAarrowzero1
% End of user PostScript
.79445 .7373 m
.79445 .7373 L
s
% Start of user PostScript
52. 48. MAarrowzero1
% End of user PostScript
.80956 .7373 m
.80956 .7373 L
s
% Start of user PostScript
53. 48. MAarrowzero1
% End of user PostScript
.82466 .7373 m
.82466 .7373 L
s
% Start of user PostScript
54. 48. MAarrowzero1
% End of user PostScript
.83977 .7373 m
.83977 .73702 L
s
% Start of user PostScript
55. 48. 55. 47.9815 MAarrowhead1
% End of user PostScript
.85488 .7373 m
.85488 .7373 L
s
% Start of user PostScript
56. 48. MAarrowzero1
% End of user PostScript
.86998 .7373 m
.86998 .7373 L
s
% Start of user PostScript
57. 48. MAarrowzero1
% End of user PostScript
.88509 .7373 m
.88509 .7373 L
s
% Start of user PostScript
58. 48. MAarrowzero1
% End of user PostScript
.90019 .7373 m
.90019 .7373 L
s
% Start of user PostScript
59. 48. MAarrowzero1
% End of user PostScript
.9153 .7373 m
.9153 .7373 L
s
% Start of user PostScript
60. 48. MAarrowzero1
% End of user PostScript
.9304 .7373 m
.9304 .7373 L
s
% Start of user PostScript
61. 48. MAarrowzero1
% End of user PostScript
.94551 .7373 m
.94551 .7373 L
s
% Start of user PostScript
62. 48. MAarrowzero1
% End of user PostScript
.96061 .7373 m
.96061 .7373 L
s
% Start of user PostScript
63. 48. MAarrowzero1
% End of user PostScript
.97572 .7373 m
.97572 .7373 L
s
% Start of user PostScript
64. 48. MAarrowzero1
% End of user PostScript
.02409 .7524 m
.02409 .7524 L
s
% Start of user PostScript
1. 49. MAarrowzero1
% End of user PostScript
.03919 .7524 m
.03919 .7524 L
s
% Start of user PostScript
2. 49. MAarrowzero1
% End of user PostScript
.0543 .7524 m
.0543 .7524 L
s
% Start of user PostScript
3. 49. MAarrowzero1
% End of user PostScript
.0694 .7524 m
.0694 .7524 L
s
% Start of user PostScript
4. 49. MAarrowzero1
% End of user PostScript
.08451 .7524 m
.08451 .7524 L
s
% Start of user PostScript
5. 49. MAarrowzero1
% End of user PostScript
.09962 .7524 m
.09962 .7524 L
s
% Start of user PostScript
6. 49. MAarrowzero1
% End of user PostScript
.11472 .7524 m
.11472 .7524 L
s
% Start of user PostScript
7. 49. MAarrowzero1
% End of user PostScript
.12983 .7524 m
.12983 .7524 L
s
% Start of user PostScript
8. 49. MAarrowzero1
% End of user PostScript
.14493 .7524 m
.14493 .7524 L
s
% Start of user PostScript
9. 49. MAarrowzero1
% End of user PostScript
.16004 .7524 m
.16004 .7524 L
s
% Start of user PostScript
10. 49. MAarrowzero1
% End of user PostScript
.17514 .7524 m
.17514 .7524 L
s
% Start of user PostScript
11. 49. MAarrowzero1
% End of user PostScript
.19025 .7524 m
.19435 .7524 L
s
% Start of user PostScript
12. 49. 12.2714 49. MAarrowhead1
% End of user PostScript
.20535 .7524 m
.21326 .75101 L
s
% Start of user PostScript
13. 49. 13.5233 48.9079 MAarrowhead1
% End of user PostScript
.22046 .7524 m
.22079 .75307 L
s
% Start of user PostScript
14. 49. 14.022 49.0443 MAarrowhead1
% End of user PostScript
.23556 .7524 m
.23436 .7524 L
s
% Start of user PostScript
15. 49. 14.9205 49. MAarrowhead1
% End of user PostScript
.25067 .7524 m
.24824 .75147 L
s
% Start of user PostScript
16. 49. 15.8392 48.9384 MAarrowhead1
% End of user PostScript
.26577 .7524 m
.26465 .7502 L
s
% Start of user PostScript
17. 49. 16.9255 48.8542 MAarrowhead1
% End of user PostScript
.28088 .7524 m
.2813 .7514 L
s
% Start of user PostScript
18. 49. 18.0277 48.9338 MAarrowhead1
% End of user PostScript
.29598 .7524 m
.29603 .75286 L
s
% Start of user PostScript
19. 49. 19.0035 49.0302 MAarrowhead1
% End of user PostScript
.31109 .7524 m
.31109 .75299 L
s
% Start of user PostScript
20. 49. 20. 49.0385 MAarrowhead1
% End of user PostScript
.32619 .7524 m
.32547 .75376 L
s
% Start of user PostScript
21. 49. 20.9524 49.0898 MAarrowhead1
% End of user PostScript
.3413 .7524 m
.34101 .75288 L
s
% Start of user PostScript
22. 49. 21.9812 49.0314 MAarrowhead1
% End of user PostScript
.3564 .7524 m
.35593 .7524 L
s
% Start of user PostScript
23. 49. 22.9686 49. MAarrowhead1
% End of user PostScript
.37151 .7524 m
.37151 .7537 L
s
% Start of user PostScript
24. 49. 24. 49.0859 MAarrowhead1
% End of user PostScript
.38661 .7524 m
.38661 .75359 L
s
% Start of user PostScript
25. 49. 25. 49.0784 MAarrowhead1
% End of user PostScript
.40172 .7524 m
.40177 .75403 L
s
% Start of user PostScript
26. 49. 26.0037 49.1075 MAarrowhead1
% End of user PostScript
.41682 .7524 m
.41685 .75371 L
s
% Start of user PostScript
27. 49. 27.002 49.0863 MAarrowhead1
% End of user PostScript
.43193 .7524 m
.43189 .75341 L
s
% Start of user PostScript
28. 49. 27.9975 49.0664 MAarrowhead1
% End of user PostScript
.44703 .7524 m
.44634 .75393 L
s
% Start of user PostScript
29. 49. 28.9538 49.1013 MAarrowhead1
% End of user PostScript
.46214 .7524 m
.46251 .75461 L
s
% Start of user PostScript
30. 49. 30.0247 49.146 MAarrowhead1
% End of user PostScript
.47725 .7524 m
.47614 .75274 L
s
% Start of user PostScript
31. 49. 30.9267 49.022 MAarrowhead1
% End of user PostScript
.49235 .7524 m
.49078 .75203 L
s
% Start of user PostScript
32. 49. 31.896 48.9753 MAarrowhead1
% End of user PostScript
.50746 .7524 m
.50631 .75325 L
s
% Start of user PostScript
33. 49. 32.9239 49.0561 MAarrowhead1
% End of user PostScript
.52256 .7524 m
.52191 .75311 L
s
% Start of user PostScript
34. 49. 33.9569 49.047 MAarrowhead1
% End of user PostScript
.53767 .7524 m
.53668 .75385 L
s
% Start of user PostScript
35. 49. 34.9349 49.0957 MAarrowhead1
% End of user PostScript
.55277 .7524 m
.55143 .7545 L
s
% Start of user PostScript
36. 49. 35.9114 49.1388 MAarrowhead1
% End of user PostScript
.56788 .7524 m
.56769 .75374 L
s
% Start of user PostScript
37. 49. 36.9875 49.0886 MAarrowhead1
% End of user PostScript
.58298 .7524 m
.58388 .75304 L
s
% Start of user PostScript
38. 49. 38.0593 49.0424 MAarrowhead1
% End of user PostScript
.59809 .7524 m
.59818 .75325 L
s
% Start of user PostScript
39. 49. 39.006 49.0561 MAarrowhead1
% End of user PostScript
.61319 .7524 m
.61319 .75352 L
s
% Start of user PostScript
40. 49. 40. 49.0738 MAarrowhead1
% End of user PostScript
.6283 .7524 m
.62971 .74919 L
s
% Start of user PostScript
41. 49. 41.0934 48.787 MAarrowhead1
% End of user PostScript
.6434 .7524 m
.64274 .75269 L
s
% Start of user PostScript
42. 49. 41.9565 49.0188 MAarrowhead1
% End of user PostScript
.65851 .7524 m
.659 .7493 L
s
% Start of user PostScript
43. 49. 43.0325 48.7946 MAarrowhead1
% End of user PostScript
.67361 .7524 m
.67361 .75324 L
s
% Start of user PostScript
44. 49. 44. 49.0556 MAarrowhead1
% End of user PostScript
.68872 .7524 m
.68872 .74931 L
s
% Start of user PostScript
45. 49. 45. 48.7951 MAarrowhead1
% End of user PostScript
.70382 .7524 m
.70382 .7524 L
s
% Start of user PostScript
46. 49. MAarrowzero1
% End of user PostScript
.71893 .7524 m
.71865 .7524 L
s
% Start of user PostScript
47. 49. 46.9815 49. MAarrowhead1
% End of user PostScript
.73403 .7524 m
.73403 .7524 L
s
% Start of user PostScript
48. 49. MAarrowzero1
% End of user PostScript
.74914 .7524 m
.74914 .75212 L
s
% Start of user PostScript
49. 49. 49. 48.9815 MAarrowhead1
% End of user PostScript
.76424 .7524 m
.76424 .7524 L
s
% Start of user PostScript
50. 49. MAarrowzero1
% End of user PostScript
.77935 .7524 m
.77935 .7524 L
s
% Start of user PostScript
51. 49. MAarrowzero1
% End of user PostScript
.79445 .7524 m
.79445 .7524 L
s
% Start of user PostScript
52. 49. MAarrowzero1
% End of user PostScript
.80956 .7524 m
.80956 .7524 L
s
% Start of user PostScript
53. 49. MAarrowzero1
% End of user PostScript
.82466 .7524 m
.82466 .7524 L
s
% Start of user PostScript
54. 49. MAarrowzero1
% End of user PostScript
.83977 .7524 m
.83977 .7524 L
s
% Start of user PostScript
55. 49. MAarrowzero1
% End of user PostScript
.85488 .7524 m
.8546 .7524 L
s
% Start of user PostScript
56. 49. 55.9815 49. MAarrowhead1
% End of user PostScript
.86998 .7524 m
.86998 .7524 L
s
% Start of user PostScript
57. 49. MAarrowzero1
% End of user PostScript
.88509 .7524 m
.88509 .75288 L
s
% Start of user PostScript
58. 49. 58. 49.0314 MAarrowhead1
% End of user PostScript
.90019 .7524 m
.90019 .7524 L
s
% Start of user PostScript
59. 49. MAarrowzero1
% End of user PostScript
.9153 .7524 m
.9153 .7524 L
s
% Start of user PostScript
60. 49. MAarrowzero1
% End of user PostScript
.9304 .7524 m
.9304 .7524 L
s
% Start of user PostScript
61. 49. MAarrowzero1
% End of user PostScript
.94551 .7524 m
.94551 .7524 L
s
% Start of user PostScript
62. 49. MAarrowzero1
% End of user PostScript
.96061 .7524 m
.96061 .7524 L
s
% Start of user PostScript
63. 49. MAarrowzero1
% End of user PostScript
.97572 .7524 m
.97572 .7524 L
s
% Start of user PostScript
64. 49. MAarrowzero1
% End of user PostScript
.02409 .76751 m
.02409 .76751 L
s
% Start of user PostScript
1. 50. MAarrowzero1
% End of user PostScript
.03919 .76751 m
.03919 .76779 L
s
% Start of user PostScript
2. 50. 2. 50.0185 MAarrowhead1
% End of user PostScript
.0543 .76751 m
.0543 .76751 L
s
% Start of user PostScript
3. 50. MAarrowzero1
% End of user PostScript
.0694 .76751 m
.0694 .76751 L
s
% Start of user PostScript
4. 50. MAarrowzero1
% End of user PostScript
.08451 .76751 m
.08451 .76723 L
s
% Start of user PostScript
5. 50. 5. 49.9815 MAarrowhead1
% End of user PostScript
.09962 .76751 m
.09962 .76723 L
s
% Start of user PostScript
6. 50. 6. 49.9815 MAarrowhead1
% End of user PostScript
.11472 .76751 m
.11472 .76751 L
s
% Start of user PostScript
7. 50. MAarrowzero1
% End of user PostScript
.12983 .76751 m
.12983 .76751 L
s
% Start of user PostScript
8. 50. MAarrowzero1
% End of user PostScript
.14493 .76751 m
.14493 .76751 L
s
% Start of user PostScript
9. 50. MAarrowzero1
% End of user PostScript
.16004 .76751 m
.16004 .76751 L
s
% Start of user PostScript
10. 50. MAarrowzero1
% End of user PostScript
.17514 .76751 m
.17514 .76751 L
s
% Start of user PostScript
11. 50. MAarrowzero1
% End of user PostScript
.19025 .76751 m
.19025 .76751 L
s
% Start of user PostScript
12. 50. MAarrowzero1
% End of user PostScript
.20535 .76751 m
.21136 .76704 L
s
% Start of user PostScript
13. 50. 13.3975 49.9686 MAarrowhead1
% End of user PostScript
.22046 .76751 m
.21982 .76714 L
s
% Start of user PostScript
14. 50. 13.9576 49.9757 MAarrowhead1
% End of user PostScript
.23556 .76751 m
.23442 .76804 L
s
% Start of user PostScript
15. 50. 14.9247 50.0353 MAarrowhead1
% End of user PostScript
.25067 .76751 m
.24852 .7689 L
s
% Start of user PostScript
16. 50. 15.8577 50.0921 MAarrowhead1
% End of user PostScript
.26577 .76751 m
.26362 .76751 L
s
% Start of user PostScript
17. 50. 16.8577 50. MAarrowhead1
% End of user PostScript
.28088 .76751 m
.28088 .7667 L
s
% Start of user PostScript
18. 50. 18. 49.9462 MAarrowhead1
% End of user PostScript
.29598 .76751 m
.2954 .76837 L
s
% Start of user PostScript
19. 50. 18.9616 50.0572 MAarrowhead1
% End of user PostScript
.31109 .76751 m
.31061 .76776 L
s
% Start of user PostScript
20. 50. 19.9686 50.0163 MAarrowhead1
% End of user PostScript
.32619 .76751 m
.32559 .76816 L
s
% Start of user PostScript
21. 50. 20.9604 50.0431 MAarrowhead1
% End of user PostScript
.3413 .76751 m
.3418 .76913 L
s
% Start of user PostScript
22. 50. 22.033 50.1075 MAarrowhead1
% End of user PostScript
.3564 .76751 m
.35531 .76848 L
s
% Start of user PostScript
23. 50. 22.9274 50.0644 MAarrowhead1
% End of user PostScript
.37151 .76751 m
.37145 .76848 L
s
% Start of user PostScript
24. 50. 23.9963 50.0644 MAarrowhead1
% End of user PostScript
.38661 .76751 m
.38661 .76881 L
s
% Start of user PostScript
25. 50. 25. 50.0863 MAarrowhead1
% End of user PostScript
.40172 .76751 m
.40258 .76852 L
s
% Start of user PostScript
26. 50. 26.0568 50.067 MAarrowhead1
% End of user PostScript
.41682 .76751 m
.41682 .76811 L
s
% Start of user PostScript
27. 50. 27. 50.0396 MAarrowhead1
% End of user PostScript
.43193 .76751 m
.43057 .7686 L
s
% Start of user PostScript
28. 50. 27.9102 50.0722 MAarrowhead1
% End of user PostScript
.44703 .76751 m
.44638 .76798 L
s
% Start of user PostScript
29. 50. 28.9565 50.0314 MAarrowhead1
% End of user PostScript
.46214 .76751 m
.46057 .76751 L
s
% Start of user PostScript
30. 50. 29.896 50. MAarrowhead1
% End of user PostScript
.47725 .76751 m
.47807 .76745 L
s
% Start of user PostScript
31. 50. 31.0545 49.9961 MAarrowhead1
% End of user PostScript
.49235 .76751 m
.49392 .77041 L
s
% Start of user PostScript
32. 50. 32.104 50.1922 MAarrowhead1
% End of user PostScript
.50746 .76751 m
.50691 .76871 L
s
% Start of user PostScript
33. 50. 32.9636 50.0795 MAarrowhead1
% End of user PostScript
.52256 .76751 m
.52284 .76751 L
s
% Start of user PostScript
34. 50. 34.0188 50. MAarrowhead1
% End of user PostScript
.53767 .76751 m
.53828 .76918 L
s
% Start of user PostScript
35. 50. 35.0408 50.1106 MAarrowhead1
% End of user PostScript
.55277 .76751 m
.55087 .76865 L
s
% Start of user PostScript
36. 50. 35.8745 50.0756 MAarrowhead1
% End of user PostScript
.56788 .76751 m
.56606 .76989 L
s
% Start of user PostScript
37. 50. 36.88 50.1573 MAarrowhead1
% End of user PostScript
.58298 .76751 m
.58154 .76916 L
s
% Start of user PostScript
38. 50. 37.9043 50.1094 MAarrowhead1
% End of user PostScript
.59809 .76751 m
.59668 .76827 L
s
% Start of user PostScript
39. 50. 38.9066 50.0502 MAarrowhead1
% End of user PostScript
.61319 .76751 m
.61196 .76751 L
s
% Start of user PostScript
40. 50. 39.9184 50. MAarrowhead1
% End of user PostScript
.6283 .76751 m
.62869 .76464 L
s
% Start of user PostScript
41. 50. 41.026 49.8101 MAarrowhead1
% End of user PostScript
.6434 .76751 m
.6434 .76383 L
s
% Start of user PostScript
42. 50. 42. 49.7565 MAarrowhead1
% End of user PostScript
.65851 .76751 m
.65756 .76781 L
s
% Start of user PostScript
43. 50. 42.9372 50.0199 MAarrowhead1
% End of user PostScript
.67361 .76751 m
.66949 .76364 L
s
% Start of user PostScript
44. 50. 43.7273 49.7438 MAarrowhead1
% End of user PostScript
.68872 .76751 m
.68872 .76751 L
s
% Start of user PostScript
45. 50. MAarrowzero1
% End of user PostScript
.70382 .76751 m
.70382 .76751 L
s
% Start of user PostScript
46. 50. MAarrowzero1
% End of user PostScript
.71893 .76751 m
.71893 .76798 L
s
% Start of user PostScript
47. 50. 47. 50.0314 MAarrowhead1
% End of user PostScript
.73403 .76751 m
.73403 .76751 L
s
% Start of user PostScript
48. 50. MAarrowzero1
% End of user PostScript
.74914 .76751 m
.74914 .76751 L
s
% Start of user PostScript
49. 50. MAarrowzero1
% End of user PostScript
.76424 .76751 m
.76424 .76751 L
s
% Start of user PostScript
50. 50. MAarrowzero1
% End of user PostScript
.77935 .76751 m
.77935 .76751 L
s
% Start of user PostScript
51. 50. MAarrowzero1
% End of user PostScript
.79445 .76751 m
.79445 .76751 L
s
% Start of user PostScript
52. 50. MAarrowzero1
% End of user PostScript
.80956 .76751 m
.80956 .76751 L
s
% Start of user PostScript
53. 50. MAarrowzero1
% End of user PostScript
.82466 .76751 m
.82466 .76751 L
s
% Start of user PostScript
54. 50. MAarrowzero1
% End of user PostScript
.83977 .76751 m
.83977 .76751 L
s
% Start of user PostScript
55. 50. MAarrowzero1
% End of user PostScript
.85488 .76751 m
.85488 .76751 L
s
% Start of user PostScript
56. 50. MAarrowzero1
% End of user PostScript
.86998 .76751 m
.86998 .76751 L
s
% Start of user PostScript
57. 50. MAarrowzero1
% End of user PostScript
.88509 .76751 m
.88509 .76751 L
s
% Start of user PostScript
58. 50. MAarrowzero1
% End of user PostScript
.90019 .76751 m
.90019 .76751 L
s
% Start of user PostScript
59. 50. MAarrowzero1
% End of user PostScript
.9153 .76751 m
.9153 .76751 L
s
% Start of user PostScript
60. 50. MAarrowzero1
% End of user PostScript
.9304 .76751 m
.9304 .76751 L
s
% Start of user PostScript
61. 50. MAarrowzero1
% End of user PostScript
.94551 .76751 m
.94551 .76751 L
s
% Start of user PostScript
62. 50. MAarrowzero1
% End of user PostScript
.96061 .76751 m
.96061 .76751 L
s
% Start of user PostScript
63. 50. MAarrowzero1
% End of user PostScript
.97572 .76751 m
.97572 .76751 L
s
% Start of user PostScript
64. 50. MAarrowzero1
% End of user PostScript
.02409 .78261 m
.02409 .78261 L
s
% Start of user PostScript
1. 51. MAarrowzero1
% End of user PostScript
.03919 .78261 m
.03919 .78261 L
s
% Start of user PostScript
2. 51. MAarrowzero1
% End of user PostScript
.0543 .78261 m
.0543 .78261 L
s
% Start of user PostScript
3. 51. MAarrowzero1
% End of user PostScript
.0694 .78261 m
.0694 .78261 L
s
% Start of user PostScript
4. 51. MAarrowzero1
% End of user PostScript
.08451 .78261 m
.08451 .78261 L
s
% Start of user PostScript
5. 51. MAarrowzero1
% End of user PostScript
.09962 .78261 m
.09962 .78261 L
s
% Start of user PostScript
6. 51. MAarrowzero1
% End of user PostScript
.11472 .78261 m
.11472 .78261 L
s
% Start of user PostScript
7. 51. MAarrowzero1
% End of user PostScript
.12983 .78261 m
.12983 .78261 L
s
% Start of user PostScript
8. 51. MAarrowzero1
% End of user PostScript
.14493 .78261 m
.14493 .78261 L
s
% Start of user PostScript
9. 51. MAarrowzero1
% End of user PostScript
.16004 .78261 m
.16004 .78261 L
s
% Start of user PostScript
10. 51. MAarrowzero1
% End of user PostScript
.17514 .78261 m
.17514 .78261 L
s
% Start of user PostScript
11. 51. MAarrowzero1
% End of user PostScript
.19025 .78261 m
.19025 .78261 L
s
% Start of user PostScript
12. 51. MAarrowzero1
% End of user PostScript
.20535 .78261 m
.20535 .78261 L
s
% Start of user PostScript
13. 51. MAarrowzero1
% End of user PostScript
.22046 .78261 m
.2259 .78742 L
s
% Start of user PostScript
14. 51. 14.3602 51.318 MAarrowhead1
% End of user PostScript
.23556 .78261 m
.23598 .78425 L
s
% Start of user PostScript
15. 51. 15.0277 51.1086 MAarrowhead1
% End of user PostScript
.25067 .78261 m
.24827 .7854 L
s
% Start of user PostScript
16. 51. 15.8415 51.1841 MAarrowhead1
% End of user PostScript
.26577 .78261 m
.26281 .78256 L
s
% Start of user PostScript
17. 51. 16.804 50.9965 MAarrowhead1
% End of user PostScript
.28088 .78261 m
.28074 .78281 L
s
% Start of user PostScript
18. 51. 17.9906 51.013 MAarrowhead1
% End of user PostScript
.29598 .78261 m
.29736 .78357 L
s
% Start of user PostScript
19. 51. 19.0909 51.0632 MAarrowhead1
% End of user PostScript
.31109 .78261 m
.31059 .78311 L
s
% Start of user PostScript
20. 51. 19.967 51.033 MAarrowhead1
% End of user PostScript
.32619 .78261 m
.32572 .78311 L
s
% Start of user PostScript
21. 51. 20.9686 51.033 MAarrowhead1
% End of user PostScript
.3413 .78261 m
.3413 .78359 L
s
% Start of user PostScript
22. 51. 22. 51.0644 MAarrowhead1
% End of user PostScript
.3564 .78261 m
.35612 .78337 L
s
% Start of user PostScript
23. 51. 22.9812 51.0502 MAarrowhead1
% End of user PostScript
.37151 .78261 m
.37103 .78327 L
s
% Start of user PostScript
24. 51. 23.9686 51.0431 MAarrowhead1
% End of user PostScript
.38661 .78261 m
.38727 .78261 L
s
% Start of user PostScript
25. 51. 25.0435 51. MAarrowhead1
% End of user PostScript
.40172 .78261 m
.40163 .7811 L
s
% Start of user PostScript
26. 51. 25.994 50.8999 MAarrowhead1
% End of user PostScript
.41682 .78261 m
.4164 .78443 L
s
% Start of user PostScript
27. 51. 26.9718 51.12 MAarrowhead1
% End of user PostScript
.43193 .78261 m
.43631 .78261 L
s
% Start of user PostScript
28. 51. 28.2902 51. MAarrowhead1
% End of user PostScript
.44703 .78261 m
.44703 .78261 L
s
% Start of user PostScript
29. 51. MAarrowzero1
% End of user PostScript
.46214 .78261 m
.46075 .78466 L
s
% Start of user PostScript
30. 51. 29.9082 51.1354 MAarrowhead1
% End of user PostScript
.47725 .78261 m
.47627 .78457 L
s
% Start of user PostScript
31. 51. 30.9356 51.1294 MAarrowhead1
% End of user PostScript
.49235 .78261 m
.49142 .78315 L
s
% Start of user PostScript
32. 51. 31.9384 51.0353 MAarrowhead1
% End of user PostScript
.50746 .78261 m
.50746 .78485 L
s
% Start of user PostScript
33. 51. 33. 51.1479 MAarrowhead1
% End of user PostScript
.52256 .78261 m
.52154 .78096 L
s
% Start of user PostScript
34. 51. 33.9324 50.8905 MAarrowhead1
% End of user PostScript
.53767 .78261 m
.53733 .78292 L
s
% Start of user PostScript
35. 51. 34.9776 51.02 MAarrowhead1
% End of user PostScript
.55277 .78261 m
.55269 .78261 L
s
% Start of user PostScript
36. 51. 35.9945 51. MAarrowhead1
% End of user PostScript
.56788 .78261 m
.56647 .78388 L
s
% Start of user PostScript
37. 51. 36.9066 51.084 MAarrowhead1
% End of user PostScript
.58298 .78261 m
.58252 .78181 L
s
% Start of user PostScript
38. 51. 37.9698 50.9467 MAarrowhead1
% End of user PostScript
.59809 .78261 m
.59996 .77972 L
s
% Start of user PostScript
39. 51. 39.1239 50.8085 MAarrowhead1
% End of user PostScript
.61319 .78261 m
.61235 .78028 L
s
% Start of user PostScript
40. 51. 39.9444 50.8452 MAarrowhead1
% End of user PostScript
.6283 .78261 m
.62926 .78074 L
s
% Start of user PostScript
41. 51. 41.0639 50.8761 MAarrowhead1
% End of user PostScript
.6434 .78261 m
.64521 .78633 L
s
% Start of user PostScript
42. 51. 42.12 51.2462 MAarrowhead1
% End of user PostScript
.65851 .78261 m
.65999 .78409 L
s
% Start of user PostScript
43. 51. 43.098 51.098 MAarrowhead1
% End of user PostScript
.67361 .78261 m
.67314 .78047 L
s
% Start of user PostScript
44. 51. 43.9686 50.858 MAarrowhead1
% End of user PostScript
.68872 .78261 m
.68872 .78261 L
s
% Start of user PostScript
45. 51. MAarrowzero1
% End of user PostScript
.70382 .78261 m
.70382 .78289 L
s
% Start of user PostScript
46. 51. 46. 51.0185 MAarrowhead1
% End of user PostScript
.71893 .78261 m
.71893 .78261 L
s
% Start of user PostScript
47. 51. MAarrowzero1
% End of user PostScript
.73403 .78261 m
.73403 .78261 L
s
% Start of user PostScript
48. 51. MAarrowzero1
% End of user PostScript
.74914 .78261 m
.74914 .78261 L
s
% Start of user PostScript
49. 51. MAarrowzero1
% End of user PostScript
.76424 .78261 m
.76424 .78261 L
s
% Start of user PostScript
50. 51. MAarrowzero1
% End of user PostScript
.77935 .78261 m
.77935 .78261 L
s
% Start of user PostScript
51. 51. MAarrowzero1
% End of user PostScript
.79445 .78261 m
.79445 .78261 L
s
% Start of user PostScript
52. 51. MAarrowzero1
% End of user PostScript
.80956 .78261 m
.80956 .78261 L
s
% Start of user PostScript
53. 51. MAarrowzero1
% End of user PostScript
.82466 .78261 m
.82466 .78261 L
s
% Start of user PostScript
54. 51. MAarrowzero1
% End of user PostScript
.83977 .78261 m
.83977 .78289 L
s
% Start of user PostScript
55. 51. 55. 51.0185 MAarrowhead1
% End of user PostScript
.85488 .78261 m
.85488 .78261 L
s
% Start of user PostScript
56. 51. MAarrowzero1
% End of user PostScript
.86998 .78261 m
.87045 .78261 L
s
% Start of user PostScript
57. 51. 57.0314 51. MAarrowhead1
% End of user PostScript
.88509 .78261 m
.88509 .78261 L
s
% Start of user PostScript
58. 51. MAarrowzero1
% End of user PostScript
.90019 .78261 m
.90019 .78261 L
s
% Start of user PostScript
59. 51. MAarrowzero1
% End of user PostScript
.9153 .78261 m
.9153 .78261 L
s
% Start of user PostScript
60. 51. MAarrowzero1
% End of user PostScript
.9304 .78261 m
.9304 .78261 L
s
% Start of user PostScript
61. 51. MAarrowzero1
% End of user PostScript
.94551 .78261 m
.94551 .78261 L
s
% Start of user PostScript
62. 51. MAarrowzero1
% End of user PostScript
.96061 .78261 m
.96061 .78261 L
s
% Start of user PostScript
63. 51. MAarrowzero1
% End of user PostScript
.97572 .78261 m
.97572 .78261 L
s
% Start of user PostScript
64. 51. MAarrowzero1
% End of user PostScript
.02409 .79772 m
.02409 .79772 L
s
% Start of user PostScript
1. 52. MAarrowzero1
% End of user PostScript
.03919 .79772 m
.03919 .79772 L
s
% Start of user PostScript
2. 52. MAarrowzero1
% End of user PostScript
.0543 .79772 m
.0543 .79772 L
s
% Start of user PostScript
3. 52. MAarrowzero1
% End of user PostScript
.0694 .79772 m
.0694 .79772 L
s
% Start of user PostScript
4. 52. MAarrowzero1
% End of user PostScript
.08451 .79772 m
.08451 .79772 L
s
% Start of user PostScript
5. 52. MAarrowzero1
% End of user PostScript
.09962 .79772 m
.09962 .79772 L
s
% Start of user PostScript
6. 52. MAarrowzero1
% End of user PostScript
.11472 .79772 m
.11472 .79772 L
s
% Start of user PostScript
7. 52. MAarrowzero1
% End of user PostScript
.12983 .79772 m
.12983 .79772 L
s
% Start of user PostScript
8. 52. MAarrowzero1
% End of user PostScript
.14493 .79772 m
.14493 .79772 L
s
% Start of user PostScript
9. 52. MAarrowzero1
% End of user PostScript
.16004 .79772 m
.16004 .79772 L
s
% Start of user PostScript
10. 52. MAarrowzero1
% End of user PostScript
.17514 .79772 m
.17514 .79772 L
s
% Start of user PostScript
11. 52. MAarrowzero1
% End of user PostScript
.19025 .79772 m
.19025 .79772 L
s
% Start of user PostScript
12. 52. MAarrowzero1
% End of user PostScript
.20535 .79772 m
.20535 .79772 L
s
% Start of user PostScript
13. 52. MAarrowzero1
% End of user PostScript
.22046 .79772 m
.21998 .79772 L
s
% Start of user PostScript
14. 52. 13.9686 52. MAarrowhead1
% End of user PostScript
.23556 .79772 m
.24242 .79562 L
s
% Start of user PostScript
15. 52. 15.4544 51.8612 MAarrowhead1
% End of user PostScript
.25067 .79772 m
.24769 .79825 L
s
% Start of user PostScript
16. 52. 15.8028 52.0353 MAarrowhead1
% End of user PostScript
.26577 .79772 m
.26616 .79624 L
s
% Start of user PostScript
17. 52. 17.0258 51.902 MAarrowhead1
% End of user PostScript
.28088 .79772 m
.27901 .7971 L
s
% Start of user PostScript
18. 52. 17.8761 51.9588 MAarrowhead1
% End of user PostScript
.29598 .79772 m
.29694 .79762 L
s
% Start of user PostScript
19. 52. 19.0632 51.9934 MAarrowhead1
% End of user PostScript
.31109 .79772 m
.31038 .79674 L
s
% Start of user PostScript
20. 52. 19.953 51.9349 MAarrowhead1
% End of user PostScript
.32619 .79772 m
.32474 .79809 L
s
% Start of user PostScript
21. 52. 20.9036 52.0243 MAarrowhead1
% End of user PostScript
.3413 .79772 m
.34125 .79923 L
s
% Start of user PostScript
22. 52. 21.9965 52.1003 MAarrowhead1
% End of user PostScript
.3564 .79772 m
.35511 .79691 L
s
% Start of user PostScript
23. 52. 22.9145 51.9466 MAarrowhead1
% End of user PostScript
.37151 .79772 m
.37188 .79896 L
s
% Start of user PostScript
24. 52. 24.0243 52.082 MAarrowhead1
% End of user PostScript
.38661 .79772 m
.38661 .79934 L
s
% Start of user PostScript
25. 52. 25. 52.1075 MAarrowhead1
% End of user PostScript
.40172 .79772 m
.40367 .80027 L
s
% Start of user PostScript
26. 52. 26.1294 52.1691 MAarrowhead1
% End of user PostScript
.41682 .79772 m
.41741 .79805 L
s
% Start of user PostScript
27. 52. 27.0385 52.022 MAarrowhead1
% End of user PostScript
.43193 .79772 m
.43102 .79881 L
s
% Start of user PostScript
28. 52. 27.9395 52.0722 MAarrowhead1
% End of user PostScript
.44703 .79772 m
.44555 .79582 L
s
% Start of user PostScript
29. 52. 28.902 51.8745 MAarrowhead1
% End of user PostScript
.46214 .79772 m
.46156 .79848 L
s
% Start of user PostScript
30. 52. 29.9615 52.0502 MAarrowhead1
% End of user PostScript
.47725 .79772 m
.47725 .79825 L
s
% Start of user PostScript
31. 52. 31. 52.0349 MAarrowhead1
% End of user PostScript
.49235 .79772 m
.4923 .79811 L
s
% Start of user PostScript
32. 52. 31.9965 52.0258 MAarrowhead1
% End of user PostScript
.50746 .79772 m
.50682 .79919 L
s
% Start of user PostScript
33. 52. 32.958 52.0976 MAarrowhead1
% End of user PostScript
.52256 .79772 m
.5218 .79805 L
s
% Start of user PostScript
34. 52. 33.9498 52.022 MAarrowhead1
% End of user PostScript
.53767 .79772 m
.53652 .79869 L
s
% Start of user PostScript
35. 52. 34.9243 52.0639 MAarrowhead1
% End of user PostScript
.55277 .79772 m
.55277 .79631 L
s
% Start of user PostScript
36. 52. 36. 51.9066 MAarrowhead1
% End of user PostScript
.56788 .79772 m
.56737 .79682 L
s
% Start of user PostScript
37. 52. 36.9663 51.9405 MAarrowhead1
% End of user PostScript
.58298 .79772 m
.58341 .79571 L
s
% Start of user PostScript
38. 52. 38.0282 51.8667 MAarrowhead1
% End of user PostScript
.59809 .79772 m
.5996 .79375 L
s
% Start of user PostScript
39. 52. 39.1003 51.7373 MAarrowhead1
% End of user PostScript
.61319 .79772 m
.61319 .79783 L
s
% Start of user PostScript
40. 52. 40. 52.0071 MAarrowhead1
% End of user PostScript
.6283 .79772 m
.62916 .79853 L
s
% Start of user PostScript
41. 52. 41.0568 52.0538 MAarrowhead1
% End of user PostScript
.6434 .79772 m
.64298 .79906 L
s
% Start of user PostScript
42. 52. 41.9723 52.0886 MAarrowhead1
% End of user PostScript
.65851 .79772 m
.65851 .79195 L
s
% Start of user PostScript
43. 52. 43. 51.6178 MAarrowhead1
% End of user PostScript
.67361 .79772 m
.67437 .79772 L
s
% Start of user PostScript
44. 52. 44.0499 52. MAarrowhead1
% End of user PostScript
.68872 .79772 m
.68872 .79772 L
s
% Start of user PostScript
45. 52. MAarrowzero1
% End of user PostScript
.70382 .79772 m
.70382 .79744 L
s
% Start of user PostScript
46. 52. 46. 51.9815 MAarrowhead1
% End of user PostScript
.71893 .79772 m
.71921 .79772 L
s
% Start of user PostScript
47. 52. 47.0185 52. MAarrowhead1
% End of user PostScript
.73403 .79772 m
.73403 .79772 L
s
% Start of user PostScript
48. 52. MAarrowzero1
% End of user PostScript
.74914 .79772 m
.74914 .79819 L
s
% Start of user PostScript
49. 52. 49. 52.0314 MAarrowhead1
% End of user PostScript
.76424 .79772 m
.76424 .79772 L
s
% Start of user PostScript
50. 52. MAarrowzero1
% End of user PostScript
.77935 .79772 m
.77888 .79772 L
s
% Start of user PostScript
51. 52. 50.9686 52. MAarrowhead1
% End of user PostScript
.79445 .79772 m
.79445 .79772 L
s
% Start of user PostScript
52. 52. MAarrowzero1
% End of user PostScript
.80956 .79772 m
.80956 .79772 L
s
% Start of user PostScript
53. 52. MAarrowzero1
% End of user PostScript
.82466 .79772 m
.82466 .79772 L
s
% Start of user PostScript
54. 52. MAarrowzero1
% End of user PostScript
.83977 .79772 m
.83977 .79772 L
s
% Start of user PostScript
55. 52. MAarrowzero1
% End of user PostScript
.85488 .79772 m
.85488 .79772 L
s
% Start of user PostScript
56. 52. MAarrowzero1
% End of user PostScript
.86998 .79772 m
.86998 .79772 L
s
% Start of user PostScript
57. 52. MAarrowzero1
% End of user PostScript
.88509 .79772 m
.88509 .79772 L
s
% Start of user PostScript
58. 52. MAarrowzero1
% End of user PostScript
.90019 .79772 m
.90019 .79772 L
s
% Start of user PostScript
59. 52. MAarrowzero1
% End of user PostScript
.9153 .79772 m
.9153 .79772 L
s
% Start of user PostScript
60. 52. MAarrowzero1
% End of user PostScript
.9304 .79772 m
.9304 .79772 L
s
% Start of user PostScript
61. 52. MAarrowzero1
% End of user PostScript
.94551 .79772 m
.94551 .79772 L
s
% Start of user PostScript
62. 52. MAarrowzero1
% End of user PostScript
.96061 .79772 m
.96061 .79772 L
s
% Start of user PostScript
63. 52. MAarrowzero1
% End of user PostScript
.97572 .79772 m
.97572 .79772 L
s
% Start of user PostScript
64. 52. MAarrowzero1
% End of user PostScript
.02409 .81282 m
.02409 .81282 L
s
% Start of user PostScript
1. 53. MAarrowzero1
% End of user PostScript
.03919 .81282 m
.03919 .81282 L
s
% Start of user PostScript
2. 53. MAarrowzero1
% End of user PostScript
.0543 .81282 m
.0543 .81282 L
s
% Start of user PostScript
3. 53. MAarrowzero1
% End of user PostScript
.0694 .81282 m
.06913 .81282 L
s
% Start of user PostScript
4. 53. 3.98149 53. MAarrowhead1
% End of user PostScript
.08451 .81282 m
.08451 .81282 L
s
% Start of user PostScript
5. 53. MAarrowzero1
% End of user PostScript
.09962 .81282 m
.09962 .81282 L
s
% Start of user PostScript
6. 53. MAarrowzero1
% End of user PostScript
.11472 .81282 m
.11472 .81282 L
s
% Start of user PostScript
7. 53. MAarrowzero1
% End of user PostScript
.12983 .81282 m
.12983 .81282 L
s
% Start of user PostScript
8. 53. MAarrowzero1
% End of user PostScript
.14493 .81282 m
.14493 .81282 L
s
% Start of user PostScript
9. 53. MAarrowzero1
% End of user PostScript
.16004 .81282 m
.16004 .81282 L
s
% Start of user PostScript
10. 53. MAarrowzero1
% End of user PostScript
.17514 .81282 m
.17514 .81282 L
s
% Start of user PostScript
11. 53. MAarrowzero1
% End of user PostScript
.19025 .81282 m
.19025 .81282 L
s
% Start of user PostScript
12. 53. MAarrowzero1
% End of user PostScript
.20535 .81282 m
.20535 .81282 L
s
% Start of user PostScript
13. 53. MAarrowzero1
% End of user PostScript
.22046 .81282 m
.22074 .81282 L
s
% Start of user PostScript
14. 53. 14.0185 53. MAarrowhead1
% End of user PostScript
.23556 .81282 m
.23509 .81282 L
s
% Start of user PostScript
15. 53. 14.9686 53. MAarrowhead1
% End of user PostScript
.25067 .81282 m
.25854 .81424 L
s
% Start of user PostScript
16. 53. 16.521 53.0938 MAarrowhead1
% End of user PostScript
.26577 .81282 m
.26324 .81383 L
s
% Start of user PostScript
17. 53. 16.8323 53.0666 MAarrowhead1
% End of user PostScript
.28088 .81282 m
.27839 .81229 L
s
% Start of user PostScript
18. 53. 17.8353 52.9647 MAarrowhead1
% End of user PostScript
.29598 .81282 m
.29598 .81316 L
s
% Start of user PostScript
19. 53. 19. 53.022 MAarrowhead1
% End of user PostScript
.31109 .81282 m
.31243 .81374 L
s
% Start of user PostScript
20. 53. 20.0886 53.0605 MAarrowhead1
% End of user PostScript
.32619 .81282 m
.32613 .81316 L
s
% Start of user PostScript
21. 53. 20.9961 53.022 MAarrowhead1
% End of user PostScript
.3413 .81282 m
.33934 .81445 L
s
% Start of user PostScript
22. 53. 21.8706 53.1075 MAarrowhead1
% End of user PostScript
.3564 .81282 m
.35738 .81454 L
s
% Start of user PostScript
23. 53. 23.0644 53.1134 MAarrowhead1
% End of user PostScript
.37151 .81282 m
.37012 .81363 L
s
% Start of user PostScript
24. 53. 23.9082 53.0534 MAarrowhead1
% End of user PostScript
.38661 .81282 m
.38597 .81249 L
s
% Start of user PostScript
25. 53. 24.9576 52.978 MAarrowhead1
% End of user PostScript
.40172 .81282 m
.40219 .81282 L
s
% Start of user PostScript
26. 53. 26.0314 53. MAarrowhead1
% End of user PostScript
.41682 .81282 m
.41624 .81372 L
s
% Start of user PostScript
27. 53. 26.9615 53.0593 MAarrowhead1
% End of user PostScript
.43193 .81282 m
.43299 .81273 L
s
% Start of user PostScript
28. 53. 28.0699 52.994 MAarrowhead1
% End of user PostScript
.44703 .81282 m
.44885 .80992 L
s
% Start of user PostScript
29. 53. 29.12 52.8078 MAarrowhead1
% End of user PostScript
.46214 .81282 m
.45927 .81364 L
s
% Start of user PostScript
30. 53. 29.8101 53.0538 MAarrowhead1
% End of user PostScript
.47725 .81282 m
.47795 .81282 L
s
% Start of user PostScript
31. 53. 31.0467 53. MAarrowhead1
% End of user PostScript
.49235 .81282 m
.49235 .81087 L
s
% Start of user PostScript
32. 53. 32. 52.8706 MAarrowhead1
% End of user PostScript
.50746 .81282 m
.50888 .81045 L
s
% Start of user PostScript
33. 53. 33.0942 52.8427 MAarrowhead1
% End of user PostScript
.52256 .81282 m
.52423 .81082 L
s
% Start of user PostScript
34. 53. 34.1107 52.8673 MAarrowhead1
% End of user PostScript
.53767 .81282 m
.54023 .80936 L
s
% Start of user PostScript
35. 53. 35.17 52.7705 MAarrowhead1
% End of user PostScript
.55277 .81282 m
.55434 .8099 L
s
% Start of user PostScript
36. 53. 36.1036 52.8062 MAarrowhead1
% End of user PostScript
.56788 .81282 m
.56744 .81124 L
s
% Start of user PostScript
37. 53. 36.9711 52.8949 MAarrowhead1
% End of user PostScript
.58298 .81282 m
.58569 .81216 L
s
% Start of user PostScript
38. 53. 38.1795 52.9561 MAarrowhead1
% End of user PostScript
.59809 .81282 m
.59862 .81612 L
s
% Start of user PostScript
39. 53. 39.0353 53.218 MAarrowhead1
% End of user PostScript
.61319 .81282 m
.61051 .81188 L
s
% Start of user PostScript
40. 53. 39.8228 52.9373 MAarrowhead1
% End of user PostScript
.6283 .81282 m
.6283 .81211 L
s
% Start of user PostScript
41. 53. 41. 52.9526 MAarrowhead1
% End of user PostScript
.6434 .81282 m
.64229 .80519 L
s
% Start of user PostScript
42. 53. 41.9264 52.4944 MAarrowhead1
% End of user PostScript
.65851 .81282 m
.65851 .81282 L
s
% Start of user PostScript
43. 53. MAarrowzero1
% End of user PostScript
.67361 .81282 m
.67361 .81282 L
s
% Start of user PostScript
44. 53. MAarrowzero1
% End of user PostScript
.68872 .81282 m
.68872 .81235 L
s
% Start of user PostScript
45. 53. 45. 52.9686 MAarrowhead1
% End of user PostScript
.70382 .81282 m
.70382 .81282 L
s
% Start of user PostScript
46. 53. MAarrowzero1
% End of user PostScript
.71893 .81282 m
.71893 .8133 L
s
% Start of user PostScript
47. 53. 47. 53.0314 MAarrowhead1
% End of user PostScript
.73403 .81282 m
.73403 .81282 L
s
% Start of user PostScript
48. 53. MAarrowzero1
% End of user PostScript
.74914 .81282 m
.74914 .81235 L
s
% Start of user PostScript
49. 53. 49. 52.9686 MAarrowhead1
% End of user PostScript
.76424 .81282 m
.76424 .81282 L
s
% Start of user PostScript
50. 53. MAarrowzero1
% End of user PostScript
.77935 .81282 m
.77935 .81282 L
s
% Start of user PostScript
51. 53. MAarrowzero1
% End of user PostScript
.79445 .81282 m
.79445 .81282 L
s
% Start of user PostScript
52. 53. MAarrowzero1
% End of user PostScript
.80956 .81282 m
.80956 .81255 L
s
% Start of user PostScript
53. 53. 53. 52.9815 MAarrowhead1
% End of user PostScript
.82466 .81282 m
.82514 .81282 L
s
% Start of user PostScript
54. 53. 54.0314 53. MAarrowhead1
% End of user PostScript
.83977 .81282 m
.83977 .81282 L
s
% Start of user PostScript
55. 53. MAarrowzero1
% End of user PostScript
.85488 .81282 m
.85488 .81282 L
s
% Start of user PostScript
56. 53. MAarrowzero1
% End of user PostScript
.86998 .81282 m
.86998 .81282 L
s
% Start of user PostScript
57. 53. MAarrowzero1
% End of user PostScript
.88509 .81282 m
.88509 .8133 L
s
% Start of user PostScript
58. 53. 58. 53.0314 MAarrowhead1
% End of user PostScript
.90019 .81282 m
.90019 .81282 L
s
% Start of user PostScript
59. 53. MAarrowzero1
% End of user PostScript
.9153 .81282 m
.9153 .81282 L
s
% Start of user PostScript
60. 53. MAarrowzero1
% End of user PostScript
.9304 .81282 m
.9304 .81282 L
s
% Start of user PostScript
61. 53. MAarrowzero1
% End of user PostScript
.94551 .81282 m
.94551 .81282 L
s
% Start of user PostScript
62. 53. MAarrowzero1
% End of user PostScript
.96061 .81282 m
.96061 .81282 L
s
% Start of user PostScript
63. 53. MAarrowzero1
% End of user PostScript
.97572 .81282 m
.97572 .81282 L
s
% Start of user PostScript
64. 53. MAarrowzero1
% End of user PostScript
.02409 .82793 m
.02409 .82793 L
s
% Start of user PostScript
1. 54. MAarrowzero1
% End of user PostScript
.03919 .82793 m
.03919 .82793 L
s
% Start of user PostScript
2. 54. MAarrowzero1
% End of user PostScript
.0543 .82793 m
.0543 .82793 L
s
% Start of user PostScript
3. 54. MAarrowzero1
% End of user PostScript
.0694 .82793 m
.0694 .82793 L
s
% Start of user PostScript
4. 54. MAarrowzero1
% End of user PostScript
.08451 .82793 m
.08451 .82793 L
s
% Start of user PostScript
5. 54. MAarrowzero1
% End of user PostScript
.09962 .82793 m
.09962 .82793 L
s
% Start of user PostScript
6. 54. MAarrowzero1
% End of user PostScript
.11472 .82793 m
.11472 .82793 L
s
% Start of user PostScript
7. 54. MAarrowzero1
% End of user PostScript
.12983 .82793 m
.12983 .82793 L
s
% Start of user PostScript
8. 54. MAarrowzero1
% End of user PostScript
.14493 .82793 m
.14493 .82793 L
s
% Start of user PostScript
9. 54. MAarrowzero1
% End of user PostScript
.16004 .82793 m
.16004 .82793 L
s
% Start of user PostScript
10. 54. MAarrowzero1
% End of user PostScript
.17514 .82793 m
.17514 .82793 L
s
% Start of user PostScript
11. 54. MAarrowzero1
% End of user PostScript
.19025 .82793 m
.19025 .82793 L
s
% Start of user PostScript
12. 54. MAarrowzero1
% End of user PostScript
.20535 .82793 m
.20535 .82793 L
s
% Start of user PostScript
13. 54. MAarrowzero1
% End of user PostScript
.22046 .82793 m
.22046 .82746 L
s
% Start of user PostScript
14. 54. 14. 53.9686 MAarrowhead1
% End of user PostScript
.23556 .82793 m
.23556 .82793 L
s
% Start of user PostScript
15. 54. MAarrowzero1
% End of user PostScript
.25067 .82793 m
.25371 .82793 L
s
% Start of user PostScript
16. 54. 16.2015 54. MAarrowhead1
% End of user PostScript
.26577 .82793 m
.26921 .82832 L
s
% Start of user PostScript
17. 54. 17.2276 54.0258 MAarrowhead1
% End of user PostScript
.28088 .82793 m
.28188 .82683 L
s
% Start of user PostScript
18. 54. 18.0666 53.9274 MAarrowhead1
% End of user PostScript
.29598 .82793 m
.29554 .8276 L
s
% Start of user PostScript
19. 54. 18.9707 53.978 MAarrowhead1
% End of user PostScript
.31109 .82793 m
.31449 .82888 L
s
% Start of user PostScript
20. 54. 20.2251 54.0632 MAarrowhead1
% End of user PostScript
.32619 .82793 m
.32524 .82793 L
s
% Start of user PostScript
21. 54. 20.9368 54. MAarrowhead1
% End of user PostScript
.3413 .82793 m
.34231 .82816 L
s
% Start of user PostScript
22. 54. 22.0667 54.0154 MAarrowhead1
% End of user PostScript
.3564 .82793 m
.35739 .82659 L
s
% Start of user PostScript
23. 54. 23.0651 53.9114 MAarrowhead1
% End of user PostScript
.37151 .82793 m
.37133 .82777 L
s
% Start of user PostScript
24. 54. 23.9882 53.9894 MAarrowhead1
% End of user PostScript
.38661 .82793 m
.38611 .82737 L
s
% Start of user PostScript
25. 54. 24.9663 53.9627 MAarrowhead1
% End of user PostScript
.40172 .82793 m
.40139 .82751 L
s
% Start of user PostScript
26. 54. 25.978 53.9721 MAarrowhead1
% End of user PostScript
.41682 .82793 m
.41598 .82643 L
s
% Start of user PostScript
27. 54. 26.9439 53.9008 MAarrowhead1
% End of user PostScript
.43193 .82793 m
.43101 .82689 L
s
% Start of user PostScript
28. 54. 27.9393 53.9311 MAarrowhead1
% End of user PostScript
.44703 .82793 m
.44768 .82673 L
s
% Start of user PostScript
29. 54. 29.0424 53.9205 MAarrowhead1
% End of user PostScript
.46214 .82793 m
.46351 .82679 L
s
% Start of user PostScript
30. 54. 30.0909 53.9244 MAarrowhead1
% End of user PostScript
.47725 .82793 m
.47778 .82745 L
s
% Start of user PostScript
31. 54. 31.0353 53.9682 MAarrowhead1
% End of user PostScript
.49235 .82793 m
.49277 .82784 L
s
% Start of user PostScript
32. 54. 32.0279 53.994 MAarrowhead1
% End of user PostScript
.50746 .82793 m
.50941 .82589 L
s
% Start of user PostScript
33. 54. 33.1294 53.8646 MAarrowhead1
% End of user PostScript
.52256 .82793 m
.52364 .82603 L
s
% Start of user PostScript
34. 54. 34.0715 53.874 MAarrowhead1
% End of user PostScript
.53767 .82793 m
.53826 .82598 L
s
% Start of user PostScript
35. 54. 35.0396 53.8706 MAarrowhead1
% End of user PostScript
.55277 .82793 m
.55369 .82891 L
s
% Start of user PostScript
36. 54. 36.0607 54.0651 MAarrowhead1
% End of user PostScript
.56788 .82793 m
.56592 .83137 L
s
% Start of user PostScript
37. 54. 36.8706 54.2275 MAarrowhead1
% End of user PostScript
.58298 .82793 m
.58047 .83289 L
s
% Start of user PostScript
38. 54. 37.8338 54.3286 MAarrowhead1
% End of user PostScript
.59809 .82793 m
.59791 .82863 L
s
% Start of user PostScript
39. 54. 38.9882 54.0462 MAarrowhead1
% End of user PostScript
.61319 .82793 m
.61286 .82765 L
s
% Start of user PostScript
40. 54. 39.978 53.9815 MAarrowhead1
% End of user PostScript
.6283 .82793 m
.6297 .82107 L
s
% Start of user PostScript
41. 54. 41.093 53.5457 MAarrowhead1
% End of user PostScript
.6434 .82793 m
.6434 .8284 L
s
% Start of user PostScript
42. 54. 42. 54.0314 MAarrowhead1
% End of user PostScript
.65851 .82793 m
.65803 .82793 L
s
% Start of user PostScript
43. 54. 42.9686 54. MAarrowhead1
% End of user PostScript
.67361 .82793 m
.67437 .82793 L
s
% Start of user PostScript
44. 54. 44.0499 54. MAarrowhead1
% End of user PostScript
.68872 .82793 m
.689 .82793 L
s
% Start of user PostScript
45. 54. 45.0185 54. MAarrowhead1
% End of user PostScript
.70382 .82793 m
.70382 .8284 L
s
% Start of user PostScript
46. 54. 46. 54.0314 MAarrowhead1
% End of user PostScript
.71893 .82793 m
.71893 .82765 L
s
% Start of user PostScript
47. 54. 47. 53.9815 MAarrowhead1
% End of user PostScript
.73403 .82793 m
.73403 .8284 L
s
% Start of user PostScript
48. 54. 48. 54.0314 MAarrowhead1
% End of user PostScript
.74914 .82793 m
.74914 .82793 L
s
% Start of user PostScript
49. 54. MAarrowzero1
% End of user PostScript
.76424 .82793 m
.76424 .82793 L
s
% Start of user PostScript
50. 54. MAarrowzero1
% End of user PostScript
.77935 .82793 m
.77935 .82793 L
s
% Start of user PostScript
51. 54. MAarrowzero1
% End of user PostScript
.79445 .82793 m
.79445 .82793 L
s
% Start of user PostScript
52. 54. MAarrowzero1
% End of user PostScript
.80956 .82793 m
.80956 .82793 L
s
% Start of user PostScript
53. 54. MAarrowzero1
% End of user PostScript
.82466 .82793 m
.82466 .82793 L
s
% Start of user PostScript
54. 54. MAarrowzero1
% End of user PostScript
.83977 .82793 m
.83977 .82793 L
s
% Start of user PostScript
55. 54. MAarrowzero1
% End of user PostScript
.85488 .82793 m
.8544 .82793 L
s
% Start of user PostScript
56. 54. 55.9686 54. MAarrowhead1
% End of user PostScript
.86998 .82793 m
.86998 .82793 L
s
% Start of user PostScript
57. 54. MAarrowzero1
% End of user PostScript
.88509 .82793 m
.88509 .82793 L
s
% Start of user PostScript
58. 54. MAarrowzero1
% End of user PostScript
.90019 .82793 m
.90019 .82793 L
s
% Start of user PostScript
59. 54. MAarrowzero1
% End of user PostScript
.9153 .82793 m
.9153 .82793 L
s
% Start of user PostScript
60. 54. MAarrowzero1
% End of user PostScript
.9304 .82793 m
.9304 .82793 L
s
% Start of user PostScript
61. 54. MAarrowzero1
% End of user PostScript
.94551 .82793 m
.94551 .82793 L
s
% Start of user PostScript
62. 54. MAarrowzero1
% End of user PostScript
.96061 .82793 m
.96061 .82793 L
s
% Start of user PostScript
63. 54. MAarrowzero1
% End of user PostScript
.97572 .82793 m
.97572 .82793 L
s
% Start of user PostScript
64. 54. MAarrowzero1
% End of user PostScript
.02409 .84304 m
.02409 .84304 L
s
% Start of user PostScript
1. 55. MAarrowzero1
% End of user PostScript
.03919 .84304 m
.03919 .84304 L
s
% Start of user PostScript
2. 55. MAarrowzero1
% End of user PostScript
.0543 .84304 m
.0543 .84304 L
s
% Start of user PostScript
3. 55. MAarrowzero1
% End of user PostScript
.0694 .84304 m
.0694 .84304 L
s
% Start of user PostScript
4. 55. MAarrowzero1
% End of user PostScript
.08451 .84304 m
.08451 .84304 L
s
% Start of user PostScript
5. 55. MAarrowzero1
% End of user PostScript
.09962 .84304 m
.09962 .84304 L
s
% Start of user PostScript
6. 55. MAarrowzero1
% End of user PostScript
.11472 .84304 m
.11472 .84304 L
s
% Start of user PostScript
7. 55. MAarrowzero1
% End of user PostScript
.12983 .84304 m
.12983 .84304 L
s
% Start of user PostScript
8. 55. MAarrowzero1
% End of user PostScript
.14493 .84304 m
.14493 .84304 L
s
% Start of user PostScript
9. 55. MAarrowzero1
% End of user PostScript
.16004 .84304 m
.16004 .84304 L
s
% Start of user PostScript
10. 55. MAarrowzero1
% End of user PostScript
.17514 .84304 m
.17514 .84304 L
s
% Start of user PostScript
11. 55. MAarrowzero1
% End of user PostScript
.19025 .84304 m
.19025 .84304 L
s
% Start of user PostScript
12. 55. MAarrowzero1
% End of user PostScript
.20535 .84304 m
.20535 .84304 L
s
% Start of user PostScript
13. 55. MAarrowzero1
% End of user PostScript
.22046 .84304 m
.22074 .84304 L
s
% Start of user PostScript
14. 55. 14.0185 55. MAarrowhead1
% End of user PostScript
.23556 .84304 m
.23556 .84304 L
s
% Start of user PostScript
15. 55. MAarrowzero1
% End of user PostScript
.25067 .84304 m
.25067 .84228 L
s
% Start of user PostScript
16. 55. 16. 54.9501 MAarrowhead1
% End of user PostScript
.26577 .84304 m
.26924 .84304 L
s
% Start of user PostScript
17. 55. 17.2294 55. MAarrowhead1
% End of user PostScript
.28088 .84304 m
.28779 .84119 L
s
% Start of user PostScript
18. 55. 18.4578 54.8777 MAarrowhead1
% End of user PostScript
.29598 .84304 m
.29409 .84557 L
s
% Start of user PostScript
19. 55. 18.8745 55.1679 MAarrowhead1
% End of user PostScript
.31109 .84304 m
.30941 .8417 L
s
% Start of user PostScript
20. 55. 19.8891 54.9114 MAarrowhead1
% End of user PostScript
.32619 .84304 m
.33002 .84295 L
s
% Start of user PostScript
21. 55. 21.2533 54.994 MAarrowhead1
% End of user PostScript
.3413 .84304 m
.34316 .84242 L
s
% Start of user PostScript
22. 55. 22.1235 54.9592 MAarrowhead1
% End of user PostScript
.3564 .84304 m
.35746 .8427 L
s
% Start of user PostScript
23. 55. 23.0701 54.978 MAarrowhead1
% End of user PostScript
.37151 .84304 m
.37253 .84158 L
s
% Start of user PostScript
24. 55. 24.0678 54.9036 MAarrowhead1
% End of user PostScript
.38661 .84304 m
.39138 .84085 L
s
% Start of user PostScript
25. 55. 25.3156 54.8553 MAarrowhead1
% End of user PostScript
.40172 .84304 m
.40077 .84122 L
s
% Start of user PostScript
26. 55. 25.9372 54.88 MAarrowhead1
% End of user PostScript
.41682 .84304 m
.41487 .84156 L
s
% Start of user PostScript
27. 55. 26.8706 54.9024 MAarrowhead1
% End of user PostScript
.43193 .84304 m
.43179 .84011 L
s
% Start of user PostScript
28. 55. 27.9906 54.8064 MAarrowhead1
% End of user PostScript
.44703 .84304 m
.44471 .84327 L
s
% Start of user PostScript
29. 55. 28.8463 55.0154 MAarrowhead1
% End of user PostScript
.46214 .84304 m
.46247 .84365 L
s
% Start of user PostScript
30. 55. 30.022 55.0408 MAarrowhead1
% End of user PostScript
.47725 .84304 m
.47777 .84082 L
s
% Start of user PostScript
31. 55. 31.0349 54.8535 MAarrowhead1
% End of user PostScript
.49235 .84304 m
.49474 .84092 L
s
% Start of user PostScript
32. 55. 32.1584 54.8601 MAarrowhead1
% End of user PostScript
.50746 .84304 m
.50684 .84369 L
s
% Start of user PostScript
33. 55. 32.9592 55.0431 MAarrowhead1
% End of user PostScript
.52256 .84304 m
.5208 .846 L
s
% Start of user PostScript
34. 55. 33.8831 55.1961 MAarrowhead1
% End of user PostScript
.53767 .84304 m
.53739 .8468 L
s
% Start of user PostScript
35. 55. 34.9815 55.2494 MAarrowhead1
% End of user PostScript
.55277 .84304 m
.55229 .84289 L
s
% Start of user PostScript
36. 55. 35.9682 54.9906 MAarrowhead1
% End of user PostScript
.56788 .84304 m
.56729 .84436 L
s
% Start of user PostScript
37. 55. 36.9615 55.0875 MAarrowhead1
% End of user PostScript
.58298 .84304 m
.58379 .84108 L
s
% Start of user PostScript
38. 55. 38.0533 54.8706 MAarrowhead1
% End of user PostScript
.59809 .84304 m
.59823 .84363 L
s
% Start of user PostScript
39. 55. 39.0094 55.0396 MAarrowhead1
% End of user PostScript
.61319 .84304 m
.61445 .83628 L
s
% Start of user PostScript
40. 55. 40.0836 54.5528 MAarrowhead1
% End of user PostScript
.6283 .84304 m
.6283 .84351 L
s
% Start of user PostScript
41. 55. 41. 55.0314 MAarrowhead1
% End of user PostScript
.6434 .84304 m
.64265 .84304 L
s
% Start of user PostScript
42. 55. 41.9501 55. MAarrowhead1
% End of user PostScript
.65851 .84304 m
.65851 .84331 L
s
% Start of user PostScript
43. 55. 43. 55.0185 MAarrowhead1
% End of user PostScript
.67361 .84304 m
.67333 .84304 L
s
% Start of user PostScript
44. 55. 43.9815 55. MAarrowhead1
% End of user PostScript
.68872 .84304 m
.68872 .84304 L
s
% Start of user PostScript
45. 55. MAarrowzero1
% End of user PostScript
.70382 .84304 m
.70382 .84304 L
s
% Start of user PostScript
46. 55. MAarrowzero1
% End of user PostScript
.71893 .84304 m
.71893 .84304 L
s
% Start of user PostScript
47. 55. MAarrowzero1
% End of user PostScript
.73403 .84304 m
.73356 .84351 L
s
% Start of user PostScript
48. 55. 47.9686 55.0314 MAarrowhead1
% End of user PostScript
.74914 .84304 m
.74914 .84331 L
s
% Start of user PostScript
49. 55. 49. 55.0185 MAarrowhead1
% End of user PostScript
.76424 .84304 m
.76424 .84304 L
s
% Start of user PostScript
50. 55. MAarrowzero1
% End of user PostScript
.77935 .84304 m
.77935 .84304 L
s
% Start of user PostScript
51. 55. MAarrowzero1
% End of user PostScript
.79445 .84304 m
.79445 .84304 L
s
% Start of user PostScript
52. 55. MAarrowzero1
% End of user PostScript
.80956 .84304 m
.80956 .84304 L
s
% Start of user PostScript
53. 55. MAarrowzero1
% End of user PostScript
.82466 .84304 m
.82466 .84304 L
s
% Start of user PostScript
54. 55. MAarrowzero1
% End of user PostScript
.83977 .84304 m
.83977 .84304 L
s
% Start of user PostScript
55. 55. MAarrowzero1
% End of user PostScript
.85488 .84304 m
.85488 .84304 L
s
% Start of user PostScript
56. 55. MAarrowzero1
% End of user PostScript
.86998 .84304 m
.86998 .84304 L
s
% Start of user PostScript
57. 55. MAarrowzero1
% End of user PostScript
.88509 .84304 m
.88509 .84304 L
s
% Start of user PostScript
58. 55. MAarrowzero1
% End of user PostScript
.90019 .84304 m
.90019 .84304 L
s
% Start of user PostScript
59. 55. MAarrowzero1
% End of user PostScript
.9153 .84304 m
.9153 .84304 L
s
% Start of user PostScript
60. 55. MAarrowzero1
% End of user PostScript
.9304 .84304 m
.9304 .84304 L
s
% Start of user PostScript
61. 55. MAarrowzero1
% End of user PostScript
.94551 .84304 m
.94551 .84304 L
s
% Start of user PostScript
62. 55. MAarrowzero1
% End of user PostScript
.96061 .84304 m
.96061 .84304 L
s
% Start of user PostScript
63. 55. MAarrowzero1
% End of user PostScript
.97572 .84304 m
.97572 .84304 L
s
% Start of user PostScript
64. 55. MAarrowzero1
% End of user PostScript
.02409 .85814 m
.02409 .85814 L
s
% Start of user PostScript
1. 56. MAarrowzero1
% End of user PostScript
.03919 .85814 m
.03919 .85814 L
s
% Start of user PostScript
2. 56. MAarrowzero1
% End of user PostScript
.0543 .85814 m
.0543 .85814 L
s
% Start of user PostScript
3. 56. MAarrowzero1
% End of user PostScript
.0694 .85814 m
.0694 .85814 L
s
% Start of user PostScript
4. 56. MAarrowzero1
% End of user PostScript
.08451 .85814 m
.08451 .85814 L
s
% Start of user PostScript
5. 56. MAarrowzero1
% End of user PostScript
.09962 .85814 m
.09962 .85814 L
s
% Start of user PostScript
6. 56. MAarrowzero1
% End of user PostScript
.11472 .85814 m
.11472 .85814 L
s
% Start of user PostScript
7. 56. MAarrowzero1
% End of user PostScript
.12983 .85814 m
.12983 .85814 L
s
% Start of user PostScript
8. 56. MAarrowzero1
% End of user PostScript
.14493 .85814 m
.14493 .85814 L
s
% Start of user PostScript
9. 56. MAarrowzero1
% End of user PostScript
.16004 .85814 m
.16004 .85814 L
s
% Start of user PostScript
10. 56. MAarrowzero1
% End of user PostScript
.17514 .85814 m
.17514 .85767 L
s
% Start of user PostScript
11. 56. 11. 55.9686 MAarrowhead1
% End of user PostScript
.19025 .85814 m
.19025 .85814 L
s
% Start of user PostScript
12. 56. MAarrowzero1
% End of user PostScript
.20535 .85814 m
.20535 .85814 L
s
% Start of user PostScript
13. 56. MAarrowzero1
% End of user PostScript
.22046 .85814 m
.22046 .85814 L
s
% Start of user PostScript
14. 56. MAarrowzero1
% End of user PostScript
.23556 .85814 m
.23556 .85814 L
s
% Start of user PostScript
15. 56. MAarrowzero1
% End of user PostScript
.25067 .85814 m
.25019 .85767 L
s
% Start of user PostScript
16. 56. 15.9686 55.9686 MAarrowhead1
% End of user PostScript
.26577 .85814 m
.26577 .85814 L
s
% Start of user PostScript
17. 56. MAarrowzero1
% End of user PostScript
.28088 .85814 m
.2804 .85814 L
s
% Start of user PostScript
18. 56. 17.9686 56. MAarrowhead1
% End of user PostScript
.29598 .85814 m
.30427 .8526 L
s
% Start of user PostScript
19. 56. 19.5489 55.6331 MAarrowhead1
% End of user PostScript
.31109 .85814 m
.3088 .85912 L
s
% Start of user PostScript
20. 56. 19.8486 56.0651 MAarrowhead1
% End of user PostScript
.32619 .85814 m
.32323 .85858 L
s
% Start of user PostScript
21. 56. 20.8037 56.0291 MAarrowhead1
% End of user PostScript
.3413 .85814 m
.3423 .85635 L
s
% Start of user PostScript
22. 56. 22.0666 55.8812 MAarrowhead1
% End of user PostScript
.3564 .85814 m
.3588 .85729 L
s
% Start of user PostScript
23. 56. 23.1585 55.9439 MAarrowhead1
% End of user PostScript
.37151 .85814 m
.3723 .85814 L
s
% Start of user PostScript
24. 56. 24.0522 56. MAarrowhead1
% End of user PostScript
.38661 .85814 m
.3864 .85552 L
s
% Start of user PostScript
25. 56. 24.9855 55.8262 MAarrowhead1
% End of user PostScript
.40172 .85814 m
.39952 .85895 L
s
% Start of user PostScript
26. 56. 25.8542 56.0538 MAarrowhead1
% End of user PostScript
.41682 .85814 m
.41634 .8597 L
s
% Start of user PostScript
27. 56. 26.9682 56.1035 MAarrowhead1
% End of user PostScript
.43193 .85814 m
.43241 .85739 L
s
% Start of user PostScript
28. 56. 28.0318 55.9501 MAarrowhead1
% End of user PostScript
.44703 .85814 m
.44758 .8573 L
s
% Start of user PostScript
29. 56. 29.0364 55.9444 MAarrowhead1
% End of user PostScript
.46214 .85814 m
.46269 .85912 L
s
% Start of user PostScript
30. 56. 30.0364 56.0651 MAarrowhead1
% End of user PostScript
.47725 .85814 m
.47448 .85865 L
s
% Start of user PostScript
31. 56. 30.8172 56.0337 MAarrowhead1
% End of user PostScript
.49235 .85814 m
.4935 .85962 L
s
% Start of user PostScript
32. 56. 32.076 56.098 MAarrowhead1
% End of user PostScript
.50746 .85814 m
.50866 .8613 L
s
% Start of user PostScript
33. 56. 33.0795 56.2089 MAarrowhead1
% End of user PostScript
.52256 .85814 m
.52261 .85943 L
s
% Start of user PostScript
34. 56. 34.0033 56.0851 MAarrowhead1
% End of user PostScript
.53767 .85814 m
.538 .85814 L
s
% Start of user PostScript
35. 56. 35.022 56. MAarrowhead1
% End of user PostScript
.55277 .85814 m
.55539 .85518 L
s
% Start of user PostScript
36. 56. 36.1737 55.804 MAarrowhead1
% End of user PostScript
.56788 .85814 m
.56913 .85716 L
s
% Start of user PostScript
37. 56. 37.0832 55.9349 MAarrowhead1
% End of user PostScript
.58298 .85814 m
.58298 .85608 L
s
% Start of user PostScript
38. 56. 38. 55.8637 MAarrowhead1
% End of user PostScript
.59809 .85814 m
.59761 .85139 L
s
% Start of user PostScript
39. 56. 38.9686 55.5528 MAarrowhead1
% End of user PostScript
.61319 .85814 m
.61291 .85814 L
s
% Start of user PostScript
40. 56. 39.9815 56. MAarrowhead1
% End of user PostScript
.6283 .85814 m
.6283 .85861 L
s
% Start of user PostScript
41. 56. 41. 56.0314 MAarrowhead1
% End of user PostScript
.6434 .85814 m
.6434 .85814 L
s
% Start of user PostScript
42. 56. MAarrowzero1
% End of user PostScript
.65851 .85814 m
.65851 .85814 L
s
% Start of user PostScript
43. 56. MAarrowzero1
% End of user PostScript
.67361 .85814 m
.67361 .85786 L
s
% Start of user PostScript
44. 56. 44. 55.9815 MAarrowhead1
% End of user PostScript
.68872 .85814 m
.68844 .85814 L
s
% Start of user PostScript
45. 56. 44.9815 56. MAarrowhead1
% End of user PostScript
.70382 .85814 m
.7041 .85814 L
s
% Start of user PostScript
46. 56. 46.0185 56. MAarrowhead1
% End of user PostScript
.71893 .85814 m
.71893 .85814 L
s
% Start of user PostScript
47. 56. MAarrowzero1
% End of user PostScript
.73403 .85814 m
.73403 .85861 L
s
% Start of user PostScript
48. 56. 48. 56.0314 MAarrowhead1
% End of user PostScript
.74914 .85814 m
.74942 .85814 L
s
% Start of user PostScript
49. 56. 49.0185 56. MAarrowhead1
% End of user PostScript
.76424 .85814 m
.76424 .85814 L
s
% Start of user PostScript
50. 56. MAarrowzero1
% End of user PostScript
.77935 .85814 m
.77935 .85786 L
s
% Start of user PostScript
51. 56. 51. 55.9815 MAarrowhead1
% End of user PostScript
.79445 .85814 m
.79445 .85861 L
s
% Start of user PostScript
52. 56. 52. 56.0314 MAarrowhead1
% End of user PostScript
.80956 .85814 m
.80956 .85814 L
s
% Start of user PostScript
53. 56. MAarrowzero1
% End of user PostScript
.82466 .85814 m
.82466 .85814 L
s
% Start of user PostScript
54. 56. MAarrowzero1
% End of user PostScript
.83977 .85814 m
.83977 .85814 L
s
% Start of user PostScript
55. 56. MAarrowzero1
% End of user PostScript
.85488 .85814 m
.85488 .85767 L
s
% Start of user PostScript
56. 56. 56. 55.9686 MAarrowhead1
% End of user PostScript
.86998 .85814 m
.86998 .85814 L
s
% Start of user PostScript
57. 56. MAarrowzero1
% End of user PostScript
.88509 .85814 m
.88556 .85814 L
s
% Start of user PostScript
58. 56. 58.0314 56. MAarrowhead1
% End of user PostScript
.90019 .85814 m
.89991 .85814 L
s
% Start of user PostScript
59. 56. 58.9815 56. MAarrowhead1
% End of user PostScript
.9153 .85814 m
.9153 .85814 L
s
% Start of user PostScript
60. 56. MAarrowzero1
% End of user PostScript
.9304 .85814 m
.9304 .85814 L
s
% Start of user PostScript
61. 56. MAarrowzero1
% End of user PostScript
.94551 .85814 m
.94551 .85814 L
s
% Start of user PostScript
62. 56. MAarrowzero1
% End of user PostScript
.96061 .85814 m
.96061 .85814 L
s
% Start of user PostScript
63. 56. MAarrowzero1
% End of user PostScript
.97572 .85814 m
.97572 .85814 L
s
% Start of user PostScript
64. 56. MAarrowzero1
% End of user PostScript
.02409 .87325 m
.02409 .87325 L
s
% Start of user PostScript
1. 57. MAarrowzero1
% End of user PostScript
.03919 .87325 m
.03919 .87325 L
s
% Start of user PostScript
2. 57. MAarrowzero1
% End of user PostScript
.0543 .87325 m
.0543 .87325 L
s
% Start of user PostScript
3. 57. MAarrowzero1
% End of user PostScript
.0694 .87325 m
.0694 .87325 L
s
% Start of user PostScript
4. 57. MAarrowzero1
% End of user PostScript
.08451 .87325 m
.08451 .87325 L
s
% Start of user PostScript
5. 57. MAarrowzero1
% End of user PostScript
.09962 .87325 m
.09962 .87325 L
s
% Start of user PostScript
6. 57. MAarrowzero1
% End of user PostScript
.11472 .87325 m
.11472 .87325 L
s
% Start of user PostScript
7. 57. MAarrowzero1
% End of user PostScript
.12983 .87325 m
.12983 .87325 L
s
% Start of user PostScript
8. 57. MAarrowzero1
% End of user PostScript
.14493 .87325 m
.14493 .87325 L
s
% Start of user PostScript
9. 57. MAarrowzero1
% End of user PostScript
.16004 .87325 m
.16004 .87325 L
s
% Start of user PostScript
10. 57. MAarrowzero1
% End of user PostScript
.17514 .87325 m
.17514 .87325 L
s
% Start of user PostScript
11. 57. MAarrowzero1
% End of user PostScript
.19025 .87325 m
.19025 .87325 L
s
% Start of user PostScript
12. 57. MAarrowzero1
% End of user PostScript
.20535 .87325 m
.20535 .87325 L
s
% Start of user PostScript
13. 57. MAarrowzero1
% End of user PostScript
.22046 .87325 m
.22046 .87325 L
s
% Start of user PostScript
14. 57. MAarrowzero1
% End of user PostScript
.23556 .87325 m
.23509 .87325 L
s
% Start of user PostScript
15. 57. 14.9686 57. MAarrowhead1
% End of user PostScript
.25067 .87325 m
.25019 .87325 L
s
% Start of user PostScript
16. 57. 15.9686 57. MAarrowhead1
% End of user PostScript
.26577 .87325 m
.26577 .87372 L
s
% Start of user PostScript
17. 57. 17. 57.0314 MAarrowhead1
% End of user PostScript
.28088 .87325 m
.28088 .87372 L
s
% Start of user PostScript
18. 57. 18. 57.0314 MAarrowhead1
% End of user PostScript
.29598 .87325 m
.29523 .87325 L
s
% Start of user PostScript
19. 57. 18.9501 57. MAarrowhead1
% End of user PostScript
.31109 .87325 m
.3179 .87244 L
s
% Start of user PostScript
20. 57. 20.4509 56.9467 MAarrowhead1
% End of user PostScript
.32619 .87325 m
.33214 .87208 L
s
% Start of user PostScript
21. 57. 21.3936 56.9228 MAarrowhead1
% End of user PostScript
.3413 .87325 m
.338 .87601 L
s
% Start of user PostScript
22. 57. 21.782 57.1832 MAarrowhead1
% End of user PostScript
.3564 .87325 m
.35567 .87268 L
s
% Start of user PostScript
23. 57. 22.9513 56.9624 MAarrowhead1
% End of user PostScript
.37151 .87325 m
.37151 .8727 L
s
% Start of user PostScript
24. 57. 24. 56.9636 MAarrowhead1
% End of user PostScript
.38661 .87325 m
.38656 .87358 L
s
% Start of user PostScript
25. 57. 24.9965 57.022 MAarrowhead1
% End of user PostScript
.40172 .87325 m
.40011 .87319 L
s
% Start of user PostScript
26. 57. 25.8933 56.9965 MAarrowhead1
% End of user PostScript
.41682 .87325 m
.41628 .87435 L
s
% Start of user PostScript
27. 57. 26.964 57.073 MAarrowhead1
% End of user PostScript
.43193 .87325 m
.43017 .87559 L
s
% Start of user PostScript
28. 57. 27.8835 57.1553 MAarrowhead1
% End of user PostScript
.44703 .87325 m
.44438 .87665 L
s
% Start of user PostScript
29. 57. 28.8244 57.2254 MAarrowhead1
% End of user PostScript
.46214 .87325 m
.46058 .87425 L
s
% Start of user PostScript
30. 57. 29.8965 57.0666 MAarrowhead1
% End of user PostScript
.47725 .87325 m
.47814 .8742 L
s
% Start of user PostScript
31. 57. 31.0593 57.0632 MAarrowhead1
% End of user PostScript
.49235 .87325 m
.49125 .87509 L
s
% Start of user PostScript
32. 57. 31.9274 57.1223 MAarrowhead1
% End of user PostScript
.50746 .87325 m
.5098 .87239 L
s
% Start of user PostScript
33. 57. 33.1553 56.9432 MAarrowhead1
% End of user PostScript
.52256 .87325 m
.5268 .87124 L
s
% Start of user PostScript
34. 57. 34.2808 56.8671 MAarrowhead1
% End of user PostScript
.53767 .87325 m
.539 .87129 L
s
% Start of user PostScript
35. 57. 35.0886 56.8706 MAarrowhead1
% End of user PostScript
.55277 .87325 m
.55188 .8725 L
s
% Start of user PostScript
36. 57. 35.9407 56.9503 MAarrowhead1
% End of user PostScript
.56788 .87325 m
.5724 .86724 L
s
% Start of user PostScript
37. 57. 37.2993 56.6025 MAarrowhead1
% End of user PostScript
.58298 .87325 m
.58298 .87192 L
s
% Start of user PostScript
38. 57. 38. 56.9125 MAarrowhead1
% End of user PostScript
.59809 .87325 m
.59809 .87325 L
s
% Start of user PostScript
39. 57. MAarrowzero1
% End of user PostScript
.61319 .87325 m
.61319 .87249 L
s
% Start of user PostScript
40. 57. 40. 56.9501 MAarrowhead1
% End of user PostScript
.6283 .87325 m
.6283 .87325 L
s
% Start of user PostScript
41. 57. MAarrowzero1
% End of user PostScript
.6434 .87325 m
.6434 .87372 L
s
% Start of user PostScript
42. 57. 42. 57.0314 MAarrowhead1
% End of user PostScript
.65851 .87325 m
.65823 .87372 L
s
% Start of user PostScript
43. 57. 42.9815 57.0314 MAarrowhead1
% End of user PostScript
.67361 .87325 m
.67389 .87277 L
s
% Start of user PostScript
44. 57. 44.0185 56.9686 MAarrowhead1
% End of user PostScript
.68872 .87325 m
.68872 .87277 L
s
% Start of user PostScript
45. 57. 45. 56.9686 MAarrowhead1
% End of user PostScript
.70382 .87325 m
.70382 .87325 L
s
% Start of user PostScript
46. 57. MAarrowzero1
% End of user PostScript
.71893 .87325 m
.71893 .87353 L
s
% Start of user PostScript
47. 57. 47. 57.0185 MAarrowhead1
% End of user PostScript
.73403 .87325 m
.73403 .87277 L
s
% Start of user PostScript
48. 57. 48. 56.9686 MAarrowhead1
% End of user PostScript
.74914 .87325 m
.74866 .87325 L
s
% Start of user PostScript
49. 57. 48.9686 57. MAarrowhead1
% End of user PostScript
.76424 .87325 m
.76424 .87325 L
s
% Start of user PostScript
50. 57. MAarrowzero1
% End of user PostScript
.77935 .87325 m
.77935 .87277 L
s
% Start of user PostScript
51. 57. 51. 56.9686 MAarrowhead1
% End of user PostScript
.79445 .87325 m
.79445 .87325 L
s
% Start of user PostScript
52. 57. MAarrowzero1
% End of user PostScript
.80956 .87325 m
.80909 .87325 L
s
% Start of user PostScript
53. 57. 52.9686 57. MAarrowhead1
% End of user PostScript
.82466 .87325 m
.82466 .87325 L
s
% Start of user PostScript
54. 57. MAarrowzero1
% End of user PostScript
.83977 .87325 m
.83977 .87325 L
s
% Start of user PostScript
55. 57. MAarrowzero1
% End of user PostScript
.85488 .87325 m
.85488 .87372 L
s
% Start of user PostScript
56. 57. 56. 57.0314 MAarrowhead1
% End of user PostScript
.86998 .87325 m
.86998 .87277 L
s
% Start of user PostScript
57. 57. 57. 56.9686 MAarrowhead1
% End of user PostScript
.88509 .87325 m
.88509 .87277 L
s
% Start of user PostScript
58. 57. 58. 56.9686 MAarrowhead1
% End of user PostScript
.90019 .87325 m
.89991 .87325 L
s
% Start of user PostScript
59. 57. 58.9815 57. MAarrowhead1
% End of user PostScript
.9153 .87325 m
.9153 .87325 L
s
% Start of user PostScript
60. 57. MAarrowzero1
% End of user PostScript
.9304 .87325 m
.9304 .87325 L
s
% Start of user PostScript
61. 57. MAarrowzero1
% End of user PostScript
.94551 .87325 m
.94551 .87277 L
s
% Start of user PostScript
62. 57. 62. 56.9686 MAarrowhead1
% End of user PostScript
.96061 .87325 m
.96061 .87325 L
s
% Start of user PostScript
63. 57. MAarrowzero1
% End of user PostScript
.97572 .87325 m
.97572 .87325 L
s
% Start of user PostScript
64. 57. MAarrowzero1
% End of user PostScript
.02409 .88835 m
.02409 .88835 L
s
% Start of user PostScript
1. 58. MAarrowzero1
% End of user PostScript
.03919 .88835 m
.03919 .88835 L
s
% Start of user PostScript
2. 58. MAarrowzero1
% End of user PostScript
.0543 .88835 m
.0543 .88835 L
s
% Start of user PostScript
3. 58. MAarrowzero1
% End of user PostScript
.0694 .88835 m
.0694 .88835 L
s
% Start of user PostScript
4. 58. MAarrowzero1
% End of user PostScript
.08451 .88835 m
.08451 .88835 L
s
% Start of user PostScript
5. 58. MAarrowzero1
% End of user PostScript
.09962 .88835 m
.09962 .88835 L
s
% Start of user PostScript
6. 58. MAarrowzero1
% End of user PostScript
.11472 .88835 m
.11472 .88835 L
s
% Start of user PostScript
7. 58. MAarrowzero1
% End of user PostScript
.12983 .88835 m
.12983 .88835 L
s
% Start of user PostScript
8. 58. MAarrowzero1
% End of user PostScript
.14493 .88835 m
.14493 .88835 L
s
% Start of user PostScript
9. 58. MAarrowzero1
% End of user PostScript
.16004 .88835 m
.16004 .88863 L
s
% Start of user PostScript
10. 58. 10. 58.0185 MAarrowhead1
% End of user PostScript
.17514 .88835 m
.17514 .88882 L
s
% Start of user PostScript
11. 58. 11. 58.0314 MAarrowhead1
% End of user PostScript
.19025 .88835 m
.19025 .88835 L
s
% Start of user PostScript
12. 58. MAarrowzero1
% End of user PostScript
.20535 .88835 m
.20535 .88835 L
s
% Start of user PostScript
13. 58. MAarrowzero1
% End of user PostScript
.22046 .88835 m
.22046 .88835 L
s
% Start of user PostScript
14. 58. MAarrowzero1
% End of user PostScript
.23556 .88835 m
.23556 .88835 L
s
% Start of user PostScript
15. 58. MAarrowzero1
% End of user PostScript
.25067 .88835 m
.25067 .88835 L
s
% Start of user PostScript
16. 58. MAarrowzero1
% End of user PostScript
.26577 .88835 m
.26577 .88835 L
s
% Start of user PostScript
17. 58. MAarrowzero1
% End of user PostScript
.28088 .88835 m
.2804 .88807 L
s
% Start of user PostScript
18. 58. 17.9686 57.9815 MAarrowhead1
% End of user PostScript
.29598 .88835 m
.29598 .88835 L
s
% Start of user PostScript
19. 58. MAarrowzero1
% End of user PostScript
.31109 .88835 m
.31109 .88882 L
s
% Start of user PostScript
20. 58. 20. 58.0314 MAarrowhead1
% End of user PostScript
.32619 .88835 m
.32619 .88788 L
s
% Start of user PostScript
21. 58. 21. 57.9686 MAarrowhead1
% End of user PostScript
.3413 .88835 m
.3413 .88788 L
s
% Start of user PostScript
22. 58. 22. 57.9686 MAarrowhead1
% End of user PostScript
.3564 .88835 m
.36173 .88349 L
s
% Start of user PostScript
23. 58. 23.3529 57.6785 MAarrowhead1
% End of user PostScript
.37151 .88835 m
.37087 .88923 L
s
% Start of user PostScript
24. 58. 23.958 58.0584 MAarrowhead1
% End of user PostScript
.38661 .88835 m
.38522 .88964 L
s
% Start of user PostScript
25. 58. 24.9079 58.0851 MAarrowhead1
% End of user PostScript
.40172 .88835 m
.40033 .88889 L
s
% Start of user PostScript
26. 58. 25.9079 58.036 MAarrowhead1
% End of user PostScript
.41682 .88835 m
.41628 .88807 L
s
% Start of user PostScript
27. 58. 26.964 57.9815 MAarrowhead1
% End of user PostScript
.43193 .88835 m
.43332 .88751 L
s
% Start of user PostScript
28. 58. 28.0921 57.9444 MAarrowhead1
% End of user PostScript
.44703 .88835 m
.45098 .88617 L
s
% Start of user PostScript
29. 58. 29.2612 57.8557 MAarrowhead1
% End of user PostScript
.46214 .88835 m
.46577 .88612 L
s
% Start of user PostScript
30. 58. 30.24 57.8521 MAarrowhead1
% End of user PostScript
.47725 .88835 m
.4778 .88698 L
s
% Start of user PostScript
31. 58. 31.0364 57.9091 MAarrowhead1
% End of user PostScript
.49235 .88835 m
.49314 .88782 L
s
% Start of user PostScript
32. 58. 32.0522 57.9651 MAarrowhead1
% End of user PostScript
.50746 .88835 m
.50559 .88944 L
s
% Start of user PostScript
33. 58. 32.8765 58.0724 MAarrowhead1
% End of user PostScript
.52256 .88835 m
.52575 .8843 L
s
% Start of user PostScript
34. 58. 34.2109 57.7318 MAarrowhead1
% End of user PostScript
.53767 .88835 m
.53847 .88526 L
s
% Start of user PostScript
35. 58. 35.0533 57.7951 MAarrowhead1
% End of user PostScript
.55277 .88835 m
.55277 .88835 L
s
% Start of user PostScript
36. 58. MAarrowzero1
% End of user PostScript
.56788 .88835 m
.5676 .88882 L
s
% Start of user PostScript
37. 58. 36.9815 58.0314 MAarrowhead1
% End of user PostScript
.58298 .88835 m
.58298 .88835 L
s
% Start of user PostScript
38. 58. MAarrowzero1
% End of user PostScript
.59809 .88835 m
.59809 .88882 L
s
% Start of user PostScript
39. 58. 39. 58.0314 MAarrowhead1
% End of user PostScript
.61319 .88835 m
.61319 .88835 L
s
% Start of user PostScript
40. 58. MAarrowzero1
% End of user PostScript
.6283 .88835 m
.62802 .88835 L
s
% Start of user PostScript
41. 58. 40.9815 58. MAarrowhead1
% End of user PostScript
.6434 .88835 m
.6434 .8891 L
s
% Start of user PostScript
42. 58. 42. 58.0499 MAarrowhead1
% End of user PostScript
.65851 .88835 m
.65851 .88835 L
s
% Start of user PostScript
43. 58. MAarrowzero1
% End of user PostScript
.67361 .88835 m
.67361 .88863 L
s
% Start of user PostScript
44. 58. 44. 58.0185 MAarrowhead1
% End of user PostScript
.68872 .88835 m
.689 .88835 L
s
% Start of user PostScript
45. 58. 45.0185 58. MAarrowhead1
% End of user PostScript
.70382 .88835 m
.70382 .88835 L
s
% Start of user PostScript
46. 58. MAarrowzero1
% End of user PostScript
.71893 .88835 m
.71893 .88835 L
s
% Start of user PostScript
47. 58. MAarrowzero1
% End of user PostScript
.73403 .88835 m
.73403 .88863 L
s
% Start of user PostScript
48. 58. 48. 58.0185 MAarrowhead1
% End of user PostScript
.74914 .88835 m
.74866 .88835 L
s
% Start of user PostScript
49. 58. 48.9686 58. MAarrowhead1
% End of user PostScript
.76424 .88835 m
.76377 .88835 L
s
% Start of user PostScript
50. 58. 49.9686 58. MAarrowhead1
% End of user PostScript
.77935 .88835 m
.77888 .88882 L
s
% Start of user PostScript
51. 58. 50.9686 58.0314 MAarrowhead1
% End of user PostScript
.79445 .88835 m
.79398 .8891 L
s
% Start of user PostScript
52. 58. 51.9686 58.0499 MAarrowhead1
% End of user PostScript
.80956 .88835 m
.80956 .88788 L
s
% Start of user PostScript
53. 58. 53. 57.9686 MAarrowhead1
% End of user PostScript
.82466 .88835 m
.82439 .88835 L
s
% Start of user PostScript
54. 58. 53.9815 58. MAarrowhead1
% End of user PostScript
.83977 .88835 m
.8393 .88835 L
s
% Start of user PostScript
55. 58. 54.9686 58. MAarrowhead1
% End of user PostScript
.85488 .88835 m
.85488 .88835 L
s
% Start of user PostScript
56. 58. MAarrowzero1
% End of user PostScript
.86998 .88835 m
.86923 .88835 L
s
% Start of user PostScript
57. 58. 56.9501 58. MAarrowhead1
% End of user PostScript
.88509 .88835 m
.88509 .88882 L
s
% Start of user PostScript
58. 58. 58. 58.0314 MAarrowhead1
% End of user PostScript
.90019 .88835 m
.90019 .8891 L
s
% Start of user PostScript
59. 58. 59. 58.0499 MAarrowhead1
% End of user PostScript
.9153 .88835 m
.9153 .88835 L
s
% Start of user PostScript
60. 58. MAarrowzero1
% End of user PostScript
.9304 .88835 m
.9304 .88835 L
s
% Start of user PostScript
61. 58. MAarrowzero1
% End of user PostScript
.94551 .88835 m
.94551 .88835 L
s
% Start of user PostScript
62. 58. MAarrowzero1
% End of user PostScript
.96061 .88835 m
.96061 .88835 L
s
% Start of user PostScript
63. 58. MAarrowzero1
% End of user PostScript
.97572 .88835 m
.97572 .88835 L
s
% Start of user PostScript
64. 58. MAarrowzero1
% End of user PostScript
.02409 .90346 m
.02409 .90346 L
s
% Start of user PostScript
1. 59. MAarrowzero1
% End of user PostScript
.03919 .90346 m
.03919 .90346 L
s
% Start of user PostScript
2. 59. MAarrowzero1
% End of user PostScript
.0543 .90346 m
.0543 .90346 L
s
% Start of user PostScript
3. 59. MAarrowzero1
% End of user PostScript
.0694 .90346 m
.0694 .90346 L
s
% Start of user PostScript
4. 59. MAarrowzero1
% End of user PostScript
.08451 .90346 m
.08451 .90346 L
s
% Start of user PostScript
5. 59. MAarrowzero1
% End of user PostScript
.09962 .90346 m
.09962 .90346 L
s
% Start of user PostScript
6. 59. MAarrowzero1
% End of user PostScript
.11472 .90346 m
.11472 .90346 L
s
% Start of user PostScript
7. 59. MAarrowzero1
% End of user PostScript
.12983 .90346 m
.12983 .90346 L
s
% Start of user PostScript
8. 59. MAarrowzero1
% End of user PostScript
.14493 .90346 m
.14493 .90346 L
s
% Start of user PostScript
9. 59. MAarrowzero1
% End of user PostScript
.16004 .90346 m
.16004 .90346 L
s
% Start of user PostScript
10. 59. MAarrowzero1
% End of user PostScript
.17514 .90346 m
.17514 .90421 L
s
% Start of user PostScript
11. 59. 11. 59.0499 MAarrowhead1
% End of user PostScript
.19025 .90346 m
.19025 .90346 L
s
% Start of user PostScript
12. 59. MAarrowzero1
% End of user PostScript
.20535 .90346 m
.20535 .90346 L
s
% Start of user PostScript
13. 59. MAarrowzero1
% End of user PostScript
.22046 .90346 m
.22046 .90346 L
s
% Start of user PostScript
14. 59. MAarrowzero1
% End of user PostScript
.23556 .90346 m
.23556 .90346 L
s
% Start of user PostScript
15. 59. MAarrowzero1
% End of user PostScript
.25067 .90346 m
.25067 .90346 L
s
% Start of user PostScript
16. 59. MAarrowzero1
% End of user PostScript
.26577 .90346 m
.26577 .90298 L
s
% Start of user PostScript
17. 59. 17. 58.9686 MAarrowhead1
% End of user PostScript
.28088 .90346 m
.2806 .90346 L
s
% Start of user PostScript
18. 59. 17.9815 59. MAarrowhead1
% End of user PostScript
.29598 .90346 m
.29598 .90346 L
s
% Start of user PostScript
19. 59. MAarrowzero1
% End of user PostScript
.31109 .90346 m
.31109 .90346 L
s
% Start of user PostScript
20. 59. MAarrowzero1
% End of user PostScript
.32619 .90346 m
.32572 .90346 L
s
% Start of user PostScript
21. 59. 20.9686 59. MAarrowhead1
% End of user PostScript
.3413 .90346 m
.34158 .90318 L
s
% Start of user PostScript
22. 59. 22.0185 58.9815 MAarrowhead1
% End of user PostScript
.3564 .90346 m
.3564 .90346 L
s
% Start of user PostScript
23. 59. MAarrowzero1
% End of user PostScript
.37151 .90346 m
.37179 .90346 L
s
% Start of user PostScript
24. 59. 24.0185 59. MAarrowhead1
% End of user PostScript
.38661 .90346 m
.38689 .9027 L
s
% Start of user PostScript
25. 59. 25.0185 58.9501 MAarrowhead1
% End of user PostScript
.40172 .90346 m
.40252 .90265 L
s
% Start of user PostScript
26. 59. 26.0533 58.9467 MAarrowhead1
% End of user PostScript
.41682 .90346 m
.41721 .90213 L
s
% Start of user PostScript
27. 59. 27.0254 58.9125 MAarrowhead1
% End of user PostScript
.43193 .90346 m
.43418 .90287 L
s
% Start of user PostScript
28. 59. 28.1493 58.9613 MAarrowhead1
% End of user PostScript
.44703 .90346 m
.4498 .90069 L
s
% Start of user PostScript
29. 59. 29.183 58.817 MAarrowhead1
% End of user PostScript
.46214 .90346 m
.46406 .90073 L
s
% Start of user PostScript
30. 59. 30.1269 58.8193 MAarrowhead1
% End of user PostScript
.47725 .90346 m
.47972 .90098 L
s
% Start of user PostScript
31. 59. 31.1639 58.8361 MAarrowhead1
% End of user PostScript
.49235 .90346 m
.49316 .90131 L
s
% Start of user PostScript
32. 59. 32.0533 58.858 MAarrowhead1
% End of user PostScript
.50746 .90346 m
.50746 .90318 L
s
% Start of user PostScript
33. 59. 33. 58.9815 MAarrowhead1
% End of user PostScript
.52256 .90346 m
.52303 .90298 L
s
% Start of user PostScript
34. 59. 34.0314 58.9686 MAarrowhead1
% End of user PostScript
.53767 .90346 m
.53767 .90346 L
s
% Start of user PostScript
35. 59. MAarrowzero1
% End of user PostScript
.55277 .90346 m
.5523 .90346 L
s
% Start of user PostScript
36. 59. 35.9686 59. MAarrowhead1
% End of user PostScript
.56788 .90346 m
.5674 .90346 L
s
% Start of user PostScript
37. 59. 36.9686 59. MAarrowhead1
% End of user PostScript
.58298 .90346 m
.58251 .90393 L
s
% Start of user PostScript
38. 59. 37.9686 59.0314 MAarrowhead1
% End of user PostScript
.59809 .90346 m
.59781 .90346 L
s
% Start of user PostScript
39. 59. 38.9815 59. MAarrowhead1
% End of user PostScript
.61319 .90346 m
.61367 .90346 L
s
% Start of user PostScript
40. 59. 40.0314 59. MAarrowhead1
% End of user PostScript
.6283 .90346 m
.62858 .90298 L
s
% Start of user PostScript
41. 59. 41.0185 58.9686 MAarrowhead1
% End of user PostScript
.6434 .90346 m
.6434 .90318 L
s
% Start of user PostScript
42. 59. 42. 58.9815 MAarrowhead1
% End of user PostScript
.65851 .90346 m
.65851 .90298 L
s
% Start of user PostScript
43. 59. 43. 58.9686 MAarrowhead1
% End of user PostScript
.67361 .90346 m
.67361 .90298 L
s
% Start of user PostScript
44. 59. 44. 58.9686 MAarrowhead1
% End of user PostScript
.68872 .90346 m
.689 .90298 L
s
% Start of user PostScript
45. 59. 45.0185 58.9686 MAarrowhead1
% End of user PostScript
.70382 .90346 m
.70335 .90374 L
s
% Start of user PostScript
46. 59. 45.9686 59.0185 MAarrowhead1
% End of user PostScript
.71893 .90346 m
.71893 .90318 L
s
% Start of user PostScript
47. 59. 47. 58.9815 MAarrowhead1
% End of user PostScript
.73403 .90346 m
.73375 .90346 L
s
% Start of user PostScript
48. 59. 47.9815 59. MAarrowhead1
% End of user PostScript
.74914 .90346 m
.74914 .90393 L
s
% Start of user PostScript
49. 59. 49. 59.0314 MAarrowhead1
% End of user PostScript
.76424 .90346 m
.76424 .90346 L
s
% Start of user PostScript
50. 59. MAarrowzero1
% End of user PostScript
.77935 .90346 m
.77935 .90346 L
s
% Start of user PostScript
51. 59. MAarrowzero1
% End of user PostScript
.79445 .90346 m
.79445 .90346 L
s
% Start of user PostScript
52. 59. MAarrowzero1
% End of user PostScript
.80956 .90346 m
.80956 .90346 L
s
% Start of user PostScript
53. 59. MAarrowzero1
% End of user PostScript
.82466 .90346 m
.82439 .90393 L
s
% Start of user PostScript
54. 59. 53.9815 59.0314 MAarrowhead1
% End of user PostScript
.83977 .90346 m
.83977 .90346 L
s
% Start of user PostScript
55. 59. MAarrowzero1
% End of user PostScript
.85488 .90346 m
.85488 .90346 L
s
% Start of user PostScript
56. 59. MAarrowzero1
% End of user PostScript
.86998 .90346 m
.86998 .90346 L
s
% Start of user PostScript
57. 59. MAarrowzero1
% End of user PostScript
.88509 .90346 m
.88556 .90346 L
s
% Start of user PostScript
58. 59. 58.0314 59. MAarrowhead1
% End of user PostScript
.90019 .90346 m
.89972 .90346 L
s
% Start of user PostScript
59. 59. 58.9686 59. MAarrowhead1
% End of user PostScript
.9153 .90346 m
.9153 .90346 L
s
% Start of user PostScript
60. 59. MAarrowzero1
% End of user PostScript
.9304 .90346 m
.9304 .90346 L
s
% Start of user PostScript
61. 59. MAarrowzero1
% End of user PostScript
.94551 .90346 m
.94551 .90346 L
s
% Start of user PostScript
62. 59. MAarrowzero1
% End of user PostScript
.96061 .90346 m
.96014 .90346 L
s
% Start of user PostScript
63. 59. 62.9686 59. MAarrowhead1
% End of user PostScript
.97572 .90346 m
.97572 .90346 L
s
% Start of user PostScript
64. 59. MAarrowzero1
% End of user PostScript
.02409 .91856 m
.02409 .91856 L
s
% Start of user PostScript
1. 60. MAarrowzero1
% End of user PostScript
.03919 .91856 m
.03919 .91856 L
s
% Start of user PostScript
2. 60. MAarrowzero1
% End of user PostScript
.0543 .91856 m
.0543 .91856 L
s
% Start of user PostScript
3. 60. MAarrowzero1
% End of user PostScript
.0694 .91856 m
.0694 .91856 L
s
% Start of user PostScript
4. 60. MAarrowzero1
% End of user PostScript
.08451 .91856 m
.08451 .91856 L
s
% Start of user PostScript
5. 60. MAarrowzero1
% End of user PostScript
.09962 .91856 m
.09962 .91856 L
s
% Start of user PostScript
6. 60. MAarrowzero1
% End of user PostScript
.11472 .91856 m
.11472 .91856 L
s
% Start of user PostScript
7. 60. MAarrowzero1
% End of user PostScript
.12983 .91856 m
.12983 .91856 L
s
% Start of user PostScript
8. 60. MAarrowzero1
% End of user PostScript
.14493 .91856 m
.14493 .91856 L
s
% Start of user PostScript
9. 60. MAarrowzero1
% End of user PostScript
.16004 .91856 m
.16004 .91856 L
s
% Start of user PostScript
10. 60. MAarrowzero1
% End of user PostScript
.17514 .91856 m
.17514 .91856 L
s
% Start of user PostScript
11. 60. MAarrowzero1
% End of user PostScript
.19025 .91856 m
.19072 .91856 L
s
% Start of user PostScript
12. 60. 12.0314 60. MAarrowhead1
% End of user PostScript
.20535 .91856 m
.20535 .91856 L
s
% Start of user PostScript
13. 60. MAarrowzero1
% End of user PostScript
.22046 .91856 m
.22046 .91856 L
s
% Start of user PostScript
14. 60. MAarrowzero1
% End of user PostScript
.23556 .91856 m
.23556 .91856 L
s
% Start of user PostScript
15. 60. MAarrowzero1
% End of user PostScript
.25067 .91856 m
.25067 .91856 L
s
% Start of user PostScript
16. 60. MAarrowzero1
% End of user PostScript
.26577 .91856 m
.26577 .91856 L
s
% Start of user PostScript
17. 60. MAarrowzero1
% End of user PostScript
.28088 .91856 m
.28088 .91856 L
s
% Start of user PostScript
18. 60. MAarrowzero1
% End of user PostScript
.29598 .91856 m
.29598 .91856 L
s
% Start of user PostScript
19. 60. MAarrowzero1
% End of user PostScript
.31109 .91856 m
.31109 .91828 L
s
% Start of user PostScript
20. 60. 20. 59.9815 MAarrowhead1
% End of user PostScript
.32619 .91856 m
.32695 .91809 L
s
% Start of user PostScript
21. 60. 21.0499 59.9686 MAarrowhead1
% End of user PostScript
.3413 .91856 m
.3413 .91904 L
s
% Start of user PostScript
22. 60. 22. 60.0314 MAarrowhead1
% End of user PostScript
.3564 .91856 m
.3564 .91884 L
s
% Start of user PostScript
23. 60. 23. 60.0185 MAarrowhead1
% End of user PostScript
.37151 .91856 m
.37151 .91828 L
s
% Start of user PostScript
24. 60. 24. 59.9815 MAarrowhead1
% End of user PostScript
.38661 .91856 m
.38709 .91828 L
s
% Start of user PostScript
25. 60. 25.0314 59.9815 MAarrowhead1
% End of user PostScript
.40172 .91856 m
.40125 .91856 L
s
% Start of user PostScript
26. 60. 25.9686 60. MAarrowhead1
% End of user PostScript
.41682 .91856 m
.4173 .91828 L
s
% Start of user PostScript
27. 60. 27.0314 59.9815 MAarrowhead1
% End of user PostScript
.43193 .91856 m
.43193 .91809 L
s
% Start of user PostScript
28. 60. 28. 59.9686 MAarrowhead1
% End of user PostScript
.44703 .91856 m
.44703 .91856 L
s
% Start of user PostScript
29. 60. MAarrowzero1
% End of user PostScript
.46214 .91856 m
.46167 .91884 L
s
% Start of user PostScript
30. 60. 29.9686 60.0185 MAarrowhead1
% End of user PostScript
.47725 .91856 m
.47725 .91856 L
s
% Start of user PostScript
31. 60. MAarrowzero1
% End of user PostScript
.49235 .91856 m
.49235 .91828 L
s
% Start of user PostScript
32. 60. 32. 59.9815 MAarrowhead1
% End of user PostScript
.50746 .91856 m
.50746 .91856 L
s
% Start of user PostScript
33. 60. MAarrowzero1
% End of user PostScript
.52256 .91856 m
.52228 .91856 L
s
% Start of user PostScript
34. 60. 33.9815 60. MAarrowhead1
% End of user PostScript
.53767 .91856 m
.53767 .91856 L
s
% Start of user PostScript
35. 60. MAarrowzero1
% End of user PostScript
.55277 .91856 m
.5523 .91809 L
s
% Start of user PostScript
36. 60. 35.9686 59.9686 MAarrowhead1
% End of user PostScript
.56788 .91856 m
.56835 .91856 L
s
% Start of user PostScript
37. 60. 37.0314 60. MAarrowhead1
% End of user PostScript
.58298 .91856 m
.58326 .91856 L
s
% Start of user PostScript
38. 60. 38.0185 60. MAarrowhead1
% End of user PostScript
.59809 .91856 m
.59781 .91904 L
s
% Start of user PostScript
39. 60. 38.9815 60.0314 MAarrowhead1
% End of user PostScript
.61319 .91856 m
.61272 .91931 L
s
% Start of user PostScript
40. 60. 39.9686 60.0499 MAarrowhead1
% End of user PostScript
.6283 .91856 m
.6283 .91809 L
s
% Start of user PostScript
41. 60. 41. 59.9686 MAarrowhead1
% End of user PostScript
.6434 .91856 m
.6434 .91856 L
s
% Start of user PostScript
42. 60. MAarrowzero1
% End of user PostScript
.65851 .91856 m
.65851 .91856 L
s
% Start of user PostScript
43. 60. MAarrowzero1
% End of user PostScript
.67361 .91856 m
.67409 .91856 L
s
% Start of user PostScript
44. 60. 44.0314 60. MAarrowhead1
% End of user PostScript
.68872 .91856 m
.68824 .91856 L
s
% Start of user PostScript
45. 60. 44.9686 60. MAarrowhead1
% End of user PostScript
.70382 .91856 m
.7041 .91828 L
s
% Start of user PostScript
46. 60. 46.0185 59.9815 MAarrowhead1
% End of user PostScript
.71893 .91856 m
.71921 .91856 L
s
% Start of user PostScript
47. 60. 47.0185 60. MAarrowhead1
% End of user PostScript
.73403 .91856 m
.73403 .91856 L
s
% Start of user PostScript
48. 60. MAarrowzero1
% End of user PostScript
.74914 .91856 m
.74961 .91884 L
s
% Start of user PostScript
49. 60. 49.0314 60.0185 MAarrowhead1
% End of user PostScript
.76424 .91856 m
.76424 .91856 L
s
% Start of user PostScript
50. 60. MAarrowzero1
% End of user PostScript
.77935 .91856 m
.77935 .91856 L
s
% Start of user PostScript
51. 60. MAarrowzero1
% End of user PostScript
.79445 .91856 m
.79493 .91904 L
s
% Start of user PostScript
52. 60. 52.0314 60.0314 MAarrowhead1
% End of user PostScript
.80956 .91856 m
.80956 .91809 L
s
% Start of user PostScript
53. 60. 53. 59.9686 MAarrowhead1
% End of user PostScript
.82466 .91856 m
.82466 .91856 L
s
% Start of user PostScript
54. 60. MAarrowzero1
% End of user PostScript
.83977 .91856 m
.83902 .91856 L
s
% Start of user PostScript
55. 60. 54.9501 60. MAarrowhead1
% End of user PostScript
.85488 .91856 m
.85488 .91856 L
s
% Start of user PostScript
56. 60. MAarrowzero1
% End of user PostScript
.86998 .91856 m
.87026 .91856 L
s
% Start of user PostScript
57. 60. 57.0185 60. MAarrowhead1
% End of user PostScript
.88509 .91856 m
.88461 .91884 L
s
% Start of user PostScript
58. 60. 57.9686 60.0185 MAarrowhead1
% End of user PostScript
.90019 .91856 m
.90066 .91904 L
s
% Start of user PostScript
59. 60. 59.0314 60.0314 MAarrowhead1
% End of user PostScript
.9153 .91856 m
.9153 .91856 L
s
% Start of user PostScript
60. 60. MAarrowzero1
% End of user PostScript
.9304 .91856 m
.9304 .91856 L
s
% Start of user PostScript
61. 60. MAarrowzero1
% End of user PostScript
.94551 .91856 m
.94551 .91856 L
s
% Start of user PostScript
62. 60. MAarrowzero1
% End of user PostScript
.96061 .91856 m
.96014 .91856 L
s
% Start of user PostScript
63. 60. 62.9686 60. MAarrowhead1
% End of user PostScript
.97572 .91856 m
.976 .91809 L
s
% Start of user PostScript
64. 60. 64.0185 59.9686 MAarrowhead1
% End of user PostScript
.02409 .93367 m
.02409 .93367 L
s
% Start of user PostScript
1. 61. MAarrowzero1
% End of user PostScript
.03919 .93367 m
.03919 .93367 L
s
% Start of user PostScript
2. 61. MAarrowzero1
% End of user PostScript
.0543 .93367 m
.0543 .93367 L
s
% Start of user PostScript
3. 61. MAarrowzero1
% End of user PostScript
.0694 .93367 m
.0694 .93367 L
s
% Start of user PostScript
4. 61. MAarrowzero1
% End of user PostScript
.08451 .93367 m
.08451 .93367 L
s
% Start of user PostScript
5. 61. MAarrowzero1
% End of user PostScript
.09962 .93367 m
.09962 .93367 L
s
% Start of user PostScript
6. 61. MAarrowzero1
% End of user PostScript
.11472 .93367 m
.11472 .93367 L
s
% Start of user PostScript
7. 61. MAarrowzero1
% End of user PostScript
.12983 .93367 m
.12983 .93367 L
s
% Start of user PostScript
8. 61. MAarrowzero1
% End of user PostScript
.14493 .93367 m
.14493 .93367 L
s
% Start of user PostScript
9. 61. MAarrowzero1
% End of user PostScript
.16004 .93367 m
.16004 .93414 L
s
% Start of user PostScript
10. 61. 10. 61.0314 MAarrowhead1
% End of user PostScript
.17514 .93367 m
.17542 .93367 L
s
% Start of user PostScript
11. 61. 11.0185 61. MAarrowhead1
% End of user PostScript
.19025 .93367 m
.19025 .93319 L
s
% Start of user PostScript
12. 61. 12. 60.9686 MAarrowhead1
% End of user PostScript
.20535 .93367 m
.20535 .93339 L
s
% Start of user PostScript
13. 61. 13. 60.9815 MAarrowhead1
% End of user PostScript
.22046 .93367 m
.22046 .93367 L
s
% Start of user PostScript
14. 61. MAarrowzero1
% End of user PostScript
.23556 .93367 m
.23556 .93367 L
s
% Start of user PostScript
15. 61. MAarrowzero1
% End of user PostScript
.25067 .93367 m
.25067 .93367 L
s
% Start of user PostScript
16. 61. MAarrowzero1
% End of user PostScript
.26577 .93367 m
.26577 .93367 L
s
% Start of user PostScript
17. 61. MAarrowzero1
% End of user PostScript
.28088 .93367 m
.28088 .93367 L
s
% Start of user PostScript
18. 61. MAarrowzero1
% End of user PostScript
.29598 .93367 m
.29551 .93339 L
s
% Start of user PostScript
19. 61. 18.9686 60.9815 MAarrowhead1
% End of user PostScript
.31109 .93367 m
.31109 .93367 L
s
% Start of user PostScript
20. 61. MAarrowzero1
% End of user PostScript
.32619 .93367 m
.32647 .93367 L
s
% Start of user PostScript
21. 61. 21.0185 61. MAarrowhead1
% End of user PostScript
.3413 .93367 m
.3413 .93367 L
s
% Start of user PostScript
22. 61. MAarrowzero1
% End of user PostScript
.3564 .93367 m
.3564 .93367 L
s
% Start of user PostScript
23. 61. MAarrowzero1
% End of user PostScript
.37151 .93367 m
.37076 .93339 L
s
% Start of user PostScript
24. 61. 23.9501 60.9815 MAarrowhead1
% End of user PostScript
.38661 .93367 m
.38661 .93339 L
s
% Start of user PostScript
25. 61. 25. 60.9815 MAarrowhead1
% End of user PostScript
.40172 .93367 m
.40219 .93395 L
s
% Start of user PostScript
26. 61. 26.0314 61.0185 MAarrowhead1
% End of user PostScript
.41682 .93367 m
.41682 .93367 L
s
% Start of user PostScript
27. 61. MAarrowzero1
% End of user PostScript
.43193 .93367 m
.43193 .93367 L
s
% Start of user PostScript
28. 61. MAarrowzero1
% End of user PostScript
.44703 .93367 m
.44703 .93414 L
s
% Start of user PostScript
29. 61. 29. 61.0314 MAarrowhead1
% End of user PostScript
.46214 .93367 m
.46261 .93339 L
s
% Start of user PostScript
30. 61. 30.0314 60.9815 MAarrowhead1
% End of user PostScript
.47725 .93367 m
.478 .93367 L
s
% Start of user PostScript
31. 61. 31.0499 61. MAarrowhead1
% End of user PostScript
.49235 .93367 m
.49235 .93367 L
s
% Start of user PostScript
32. 61. MAarrowzero1
% End of user PostScript
.50746 .93367 m
.50746 .93367 L
s
% Start of user PostScript
33. 61. MAarrowzero1
% End of user PostScript
.52256 .93367 m
.52256 .93395 L
s
% Start of user PostScript
34. 61. 34. 61.0185 MAarrowhead1
% End of user PostScript
.53767 .93367 m
.53767 .93319 L
s
% Start of user PostScript
35. 61. 35. 60.9686 MAarrowhead1
% End of user PostScript
.55277 .93367 m
.55277 .93367 L
s
% Start of user PostScript
36. 61. MAarrowzero1
% End of user PostScript
.56788 .93367 m
.56788 .93414 L
s
% Start of user PostScript
37. 61. 37. 61.0314 MAarrowhead1
% End of user PostScript
.58298 .93367 m
.58326 .93367 L
s
% Start of user PostScript
38. 61. 38.0185 61. MAarrowhead1
% End of user PostScript
.59809 .93367 m
.59761 .93367 L
s
% Start of user PostScript
39. 61. 38.9686 61. MAarrowhead1
% End of user PostScript
.61319 .93367 m
.61319 .93367 L
s
% Start of user PostScript
40. 61. MAarrowzero1
% End of user PostScript
.6283 .93367 m
.62858 .93367 L
s
% Start of user PostScript
41. 61. 41.0185 61. MAarrowhead1
% End of user PostScript
.6434 .93367 m
.64293 .93442 L
s
% Start of user PostScript
42. 61. 41.9686 61.0499 MAarrowhead1
% End of user PostScript
.65851 .93367 m
.65851 .93367 L
s
% Start of user PostScript
43. 61. MAarrowzero1
% End of user PostScript
.67361 .93367 m
.67314 .93339 L
s
% Start of user PostScript
44. 61. 43.9686 60.9815 MAarrowhead1
% End of user PostScript
.68872 .93367 m
.68872 .93367 L
s
% Start of user PostScript
45. 61. MAarrowzero1
% End of user PostScript
.70382 .93367 m
.70354 .93319 L
s
% Start of user PostScript
46. 61. 45.9815 60.9686 MAarrowhead1
% End of user PostScript
.71893 .93367 m
.71865 .93367 L
s
% Start of user PostScript
47. 61. 46.9815 61. MAarrowhead1
% End of user PostScript
.73403 .93367 m
.73403 .93367 L
s
% Start of user PostScript
48. 61. MAarrowzero1
% End of user PostScript
.74914 .93367 m
.74961 .93414 L
s
% Start of user PostScript
49. 61. 49.0314 61.0314 MAarrowhead1
% End of user PostScript
.76424 .93367 m
.76424 .93395 L
s
% Start of user PostScript
50. 61. 50. 61.0185 MAarrowhead1
% End of user PostScript
.77935 .93367 m
.77935 .93414 L
s
% Start of user PostScript
51. 61. 51. 61.0314 MAarrowhead1
% End of user PostScript
.79445 .93367 m
.79398 .93367 L
s
% Start of user PostScript
52. 61. 51.9686 61. MAarrowhead1
% End of user PostScript
.80956 .93367 m
.80956 .93367 L
s
% Start of user PostScript
53. 61. MAarrowzero1
% End of user PostScript
.82466 .93367 m
.82419 .93414 L
s
% Start of user PostScript
54. 61. 53.9686 61.0314 MAarrowhead1
% End of user PostScript
.83977 .93367 m
.83977 .93367 L
s
% Start of user PostScript
55. 61. MAarrowzero1
% End of user PostScript
.85488 .93367 m
.85488 .93414 L
s
% Start of user PostScript
56. 61. 56. 61.0314 MAarrowhead1
% End of user PostScript
.86998 .93367 m
.8697 .93367 L
s
% Start of user PostScript
57. 61. 56.9815 61. MAarrowhead1
% End of user PostScript
.88509 .93367 m
.88509 .93339 L
s
% Start of user PostScript
58. 61. 58. 60.9815 MAarrowhead1
% End of user PostScript
.90019 .93367 m
.90019 .93367 L
s
% Start of user PostScript
59. 61. MAarrowzero1
% End of user PostScript
.9153 .93367 m
.9153 .93367 L
s
% Start of user PostScript
60. 61. MAarrowzero1
% End of user PostScript
.9304 .93367 m
.9304 .93367 L
s
% Start of user PostScript
61. 61. MAarrowzero1
% End of user PostScript
.94551 .93367 m
.94475 .93319 L
s
% Start of user PostScript
62. 61. 61.9501 60.9686 MAarrowhead1
% End of user PostScript
.96061 .93367 m
.96061 .93367 L
s
% Start of user PostScript
63. 61. MAarrowzero1
% End of user PostScript
.97572 .93367 m
.97572 .93367 L
s
% Start of user PostScript
64. 61. MAarrowzero1
% End of user PostScript
.02409 .94877 m
.02409 .94877 L
s
% Start of user PostScript
1. 62. MAarrowzero1
% End of user PostScript
.03919 .94877 m
.03919 .94877 L
s
% Start of user PostScript
2. 62. MAarrowzero1
% End of user PostScript
.0543 .94877 m
.0543 .94877 L
s
% Start of user PostScript
3. 62. MAarrowzero1
% End of user PostScript
.0694 .94877 m
.0694 .94877 L
s
% Start of user PostScript
4. 62. MAarrowzero1
% End of user PostScript
.08451 .94877 m
.08451 .94877 L
s
% Start of user PostScript
5. 62. MAarrowzero1
% End of user PostScript
.09962 .94877 m
.09962 .94877 L
s
% Start of user PostScript
6. 62. MAarrowzero1
% End of user PostScript
.11472 .94877 m
.11472 .94877 L
s
% Start of user PostScript
7. 62. MAarrowzero1
% End of user PostScript
.12983 .94877 m
.12983 .94877 L
s
% Start of user PostScript
8. 62. MAarrowzero1
% End of user PostScript
.14493 .94877 m
.14493 .94877 L
s
% Start of user PostScript
9. 62. MAarrowzero1
% End of user PostScript
.16004 .94877 m
.16004 .94877 L
s
% Start of user PostScript
10. 62. MAarrowzero1
% End of user PostScript
.17514 .94877 m
.17467 .94877 L
s
% Start of user PostScript
11. 62. 10.9686 62. MAarrowhead1
% End of user PostScript
.19025 .94877 m
.19025 .9483 L
s
% Start of user PostScript
12. 62. 12. 61.9686 MAarrowhead1
% End of user PostScript
.20535 .94877 m
.20535 .94877 L
s
% Start of user PostScript
13. 62. MAarrowzero1
% End of user PostScript
.22046 .94877 m
.22046 .94877 L
s
% Start of user PostScript
14. 62. MAarrowzero1
% End of user PostScript
.23556 .94877 m
.23556 .94877 L
s
% Start of user PostScript
15. 62. MAarrowzero1
% End of user PostScript
.25067 .94877 m
.25067 .94877 L
s
% Start of user PostScript
16. 62. MAarrowzero1
% End of user PostScript
.26577 .94877 m
.26577 .94877 L
s
% Start of user PostScript
17. 62. MAarrowzero1
% End of user PostScript
.28088 .94877 m
.28116 .94877 L
s
% Start of user PostScript
18. 62. 18.0185 62. MAarrowhead1
% End of user PostScript
.29598 .94877 m
.29646 .94877 L
s
% Start of user PostScript
19. 62. 19.0314 62. MAarrowhead1
% End of user PostScript
.31109 .94877 m
.31109 .94905 L
s
% Start of user PostScript
20. 62. 20. 62.0185 MAarrowhead1
% End of user PostScript
.32619 .94877 m
.32619 .94905 L
s
% Start of user PostScript
21. 62. 21. 62.0185 MAarrowhead1
% End of user PostScript
.3413 .94877 m
.3413 .94877 L
s
% Start of user PostScript
22. 62. MAarrowzero1
% End of user PostScript
.3564 .94877 m
.3564 .94877 L
s
% Start of user PostScript
23. 62. MAarrowzero1
% End of user PostScript
.37151 .94877 m
.37179 .94849 L
s
% Start of user PostScript
24. 62. 24.0185 61.9815 MAarrowhead1
% End of user PostScript
.38661 .94877 m
.38709 .94877 L
s
% Start of user PostScript
25. 62. 25.0314 62. MAarrowhead1
% End of user PostScript
.40172 .94877 m
.40172 .94877 L
s
% Start of user PostScript
26. 62. MAarrowzero1
% End of user PostScript
.41682 .94877 m
.41635 .94849 L
s
% Start of user PostScript
27. 62. 26.9686 61.9815 MAarrowhead1
% End of user PostScript
.43193 .94877 m
.43193 .94925 L
s
% Start of user PostScript
28. 62. 28. 62.0314 MAarrowhead1
% End of user PostScript
.44703 .94877 m
.44628 .9483 L
s
% Start of user PostScript
29. 62. 28.9501 61.9686 MAarrowhead1
% End of user PostScript
.46214 .94877 m
.46214 .94849 L
s
% Start of user PostScript
30. 62. 30. 61.9815 MAarrowhead1
% End of user PostScript
.47725 .94877 m
.47725 .94877 L
s
% Start of user PostScript
31. 62. MAarrowzero1
% End of user PostScript
.49235 .94877 m
.49235 .94877 L
s
% Start of user PostScript
32. 62. MAarrowzero1
% End of user PostScript
.50746 .94877 m
.50746 .94925 L
s
% Start of user PostScript
33. 62. 33. 62.0314 MAarrowhead1
% End of user PostScript
.52256 .94877 m
.52284 .94849 L
s
% Start of user PostScript
34. 62. 34.0185 61.9815 MAarrowhead1
% End of user PostScript
.53767 .94877 m
.53767 .94905 L
s
% Start of user PostScript
35. 62. 35. 62.0185 MAarrowhead1
% End of user PostScript
.55277 .94877 m
.55305 .94877 L
s
% Start of user PostScript
36. 62. 36.0185 62. MAarrowhead1
% End of user PostScript
.56788 .94877 m
.5674 .9483 L
s
% Start of user PostScript
37. 62. 36.9686 61.9686 MAarrowhead1
% End of user PostScript
.58298 .94877 m
.58251 .94877 L
s
% Start of user PostScript
38. 62. 37.9686 62. MAarrowhead1
% End of user PostScript
.59809 .94877 m
.59809 .94905 L
s
% Start of user PostScript
39. 62. 39. 62.0185 MAarrowhead1
% End of user PostScript
.61319 .94877 m
.61367 .94953 L
s
% Start of user PostScript
40. 62. 40.0314 62.0499 MAarrowhead1
% End of user PostScript
.6283 .94877 m
.62877 .94925 L
s
% Start of user PostScript
41. 62. 41.0314 62.0314 MAarrowhead1
% End of user PostScript
.6434 .94877 m
.6434 .94877 L
s
% Start of user PostScript
42. 62. MAarrowzero1
% End of user PostScript
.65851 .94877 m
.65823 .94877 L
s
% Start of user PostScript
43. 62. 42.9815 62. MAarrowhead1
% End of user PostScript
.67361 .94877 m
.67361 .94925 L
s
% Start of user PostScript
44. 62. 44. 62.0314 MAarrowhead1
% End of user PostScript
.68872 .94877 m
.68872 .94877 L
s
% Start of user PostScript
45. 62. MAarrowzero1
% End of user PostScript
.70382 .94877 m
.70382 .94877 L
s
% Start of user PostScript
46. 62. MAarrowzero1
% End of user PostScript
.71893 .94877 m
.71893 .94802 L
s
% Start of user PostScript
47. 62. 47. 61.9501 MAarrowhead1
% End of user PostScript
.73403 .94877 m
.73375 .94953 L
s
% Start of user PostScript
48. 62. 47.9815 62.0499 MAarrowhead1
% End of user PostScript
.74914 .94877 m
.74914 .94877 L
s
% Start of user PostScript
49. 62. MAarrowzero1
% End of user PostScript
.76424 .94877 m
.76424 .94953 L
s
% Start of user PostScript
50. 62. 50. 62.0499 MAarrowhead1
% End of user PostScript
.77935 .94877 m
.77935 .94877 L
s
% Start of user PostScript
51. 62. MAarrowzero1
% End of user PostScript
.79445 .94877 m
.79445 .94925 L
s
% Start of user PostScript
52. 62. 52. 62.0314 MAarrowhead1
% End of user PostScript
.80956 .94877 m
.81003 .94925 L
s
% Start of user PostScript
53. 62. 53.0314 62.0314 MAarrowhead1
% End of user PostScript
.82466 .94877 m
.82419 .94877 L
s
% Start of user PostScript
54. 62. 53.9686 62. MAarrowhead1
% End of user PostScript
.83977 .94877 m
.83977 .94849 L
s
% Start of user PostScript
55. 62. 55. 61.9815 MAarrowhead1
% End of user PostScript
.85488 .94877 m
.85488 .94877 L
s
% Start of user PostScript
56. 62. MAarrowzero1
% End of user PostScript
.86998 .94877 m
.87045 .94877 L
s
% Start of user PostScript
57. 62. 57.0314 62. MAarrowhead1
% End of user PostScript
.88509 .94877 m
.88509 .94925 L
s
% Start of user PostScript
58. 62. 58. 62.0314 MAarrowhead1
% End of user PostScript
.90019 .94877 m
.89972 .94877 L
s
% Start of user PostScript
59. 62. 58.9686 62. MAarrowhead1
% End of user PostScript
.9153 .94877 m
.9153 .94877 L
s
% Start of user PostScript
60. 62. MAarrowzero1
% End of user PostScript
.9304 .94877 m
.9304 .94877 L
s
% Start of user PostScript
61. 62. MAarrowzero1
% End of user PostScript
.94551 .94877 m
.94551 .94877 L
s
% Start of user PostScript
62. 62. MAarrowzero1
% End of user PostScript
.96061 .94877 m
.96061 .94905 L
s
% Start of user PostScript
63. 62. 63. 62.0185 MAarrowhead1
% End of user PostScript
.97572 .94877 m
.976 .9483 L
s
% Start of user PostScript
64. 62. 64.0185 61.9686 MAarrowhead1
% End of user PostScript
.02409 .96388 m
.02409 .96388 L
s
% Start of user PostScript
1. 63. MAarrowzero1
% End of user PostScript
.03919 .96388 m
.03919 .96388 L
s
% Start of user PostScript
2. 63. MAarrowzero1
% End of user PostScript
.0543 .96388 m
.0543 .96388 L
s
% Start of user PostScript
3. 63. MAarrowzero1
% End of user PostScript
.0694 .96388 m
.0694 .96388 L
s
% Start of user PostScript
4. 63. MAarrowzero1
% End of user PostScript
.08451 .96388 m
.08451 .96388 L
s
% Start of user PostScript
5. 63. MAarrowzero1
% End of user PostScript
.09962 .96388 m
.09962 .96388 L
s
% Start of user PostScript
6. 63. MAarrowzero1
% End of user PostScript
.11472 .96388 m
.11472 .96388 L
s
% Start of user PostScript
7. 63. MAarrowzero1
% End of user PostScript
.12983 .96388 m
.12983 .96388 L
s
% Start of user PostScript
8. 63. MAarrowzero1
% End of user PostScript
.14493 .96388 m
.14493 .96388 L
s
% Start of user PostScript
9. 63. MAarrowzero1
% End of user PostScript
.16004 .96388 m
.16004 .96388 L
s
% Start of user PostScript
10. 63. MAarrowzero1
% End of user PostScript
.17514 .96388 m
.17514 .96388 L
s
% Start of user PostScript
11. 63. MAarrowzero1
% End of user PostScript
.19025 .96388 m
.19025 .96388 L
s
% Start of user PostScript
12. 63. MAarrowzero1
% End of user PostScript
.20535 .96388 m
.20535 .9636 L
s
% Start of user PostScript
13. 63. 13. 62.9815 MAarrowhead1
% End of user PostScript
.22046 .96388 m
.22046 .96388 L
s
% Start of user PostScript
14. 63. MAarrowzero1
% End of user PostScript
.23556 .96388 m
.23556 .96388 L
s
% Start of user PostScript
15. 63. MAarrowzero1
% End of user PostScript
.25067 .96388 m
.25067 .96388 L
s
% Start of user PostScript
16. 63. MAarrowzero1
% End of user PostScript
.26577 .96388 m
.26605 .96388 L
s
% Start of user PostScript
17. 63. 17.0185 63. MAarrowhead1
% End of user PostScript
.28088 .96388 m
.28088 .96435 L
s
% Start of user PostScript
18. 63. 18. 63.0314 MAarrowhead1
% End of user PostScript
.29598 .96388 m
.29626 .9634 L
s
% Start of user PostScript
19. 63. 19.0185 62.9686 MAarrowhead1
% End of user PostScript
.31109 .96388 m
.31109 .9634 L
s
% Start of user PostScript
20. 63. 20. 62.9686 MAarrowhead1
% End of user PostScript
.32619 .96388 m
.32647 .96388 L
s
% Start of user PostScript
21. 63. 21.0185 63. MAarrowhead1
% End of user PostScript
.3413 .96388 m
.34177 .9634 L
s
% Start of user PostScript
22. 63. 22.0314 62.9686 MAarrowhead1
% End of user PostScript
.3564 .96388 m
.35593 .96416 L
s
% Start of user PostScript
23. 63. 22.9686 63.0185 MAarrowhead1
% End of user PostScript
.37151 .96388 m
.37198 .96435 L
s
% Start of user PostScript
24. 63. 24.0314 63.0314 MAarrowhead1
% End of user PostScript
.38661 .96388 m
.38661 .96388 L
s
% Start of user PostScript
25. 63. MAarrowzero1
% End of user PostScript
.40172 .96388 m
.40172 .9636 L
s
% Start of user PostScript
26. 63. 26. 62.9815 MAarrowhead1
% End of user PostScript
.41682 .96388 m
.41682 .96388 L
s
% Start of user PostScript
27. 63. MAarrowzero1
% End of user PostScript
.43193 .96388 m
.43221 .9634 L
s
% Start of user PostScript
28. 63. 28.0185 62.9686 MAarrowhead1
% End of user PostScript
.44703 .96388 m
.44751 .96388 L
s
% Start of user PostScript
29. 63. 29.0314 63. MAarrowhead1
% End of user PostScript
.46214 .96388 m
.46214 .96435 L
s
% Start of user PostScript
30. 63. 30. 63.0314 MAarrowhead1
% End of user PostScript
.47725 .96388 m
.47677 .96312 L
s
% Start of user PostScript
31. 63. 30.9686 62.9501 MAarrowhead1
% End of user PostScript
.49235 .96388 m
.49235 .96388 L
s
% Start of user PostScript
32. 63. MAarrowzero1
% End of user PostScript
.50746 .96388 m
.50746 .96388 L
s
% Start of user PostScript
33. 63. MAarrowzero1
% End of user PostScript
.52256 .96388 m
.52209 .96388 L
s
% Start of user PostScript
34. 63. 33.9686 63. MAarrowhead1
% End of user PostScript
.53767 .96388 m
.53767 .96388 L
s
% Start of user PostScript
35. 63. MAarrowzero1
% End of user PostScript
.55277 .96388 m
.55305 .96388 L
s
% Start of user PostScript
36. 63. 36.0185 63. MAarrowhead1
% End of user PostScript
.56788 .96388 m
.56788 .96435 L
s
% Start of user PostScript
37. 63. 37. 63.0314 MAarrowhead1
% End of user PostScript
.58298 .96388 m
.58346 .96312 L
s
% Start of user PostScript
38. 63. 38.0314 62.9501 MAarrowhead1
% End of user PostScript
.59809 .96388 m
.59856 .96312 L
s
% Start of user PostScript
39. 63. 39.0314 62.9501 MAarrowhead1
% End of user PostScript
.61319 .96388 m
.61272 .96388 L
s
% Start of user PostScript
40. 63. 39.9686 63. MAarrowhead1
% End of user PostScript
.6283 .96388 m
.6283 .96388 L
s
% Start of user PostScript
41. 63. MAarrowzero1
% End of user PostScript
.6434 .96388 m
.64312 .9636 L
s
% Start of user PostScript
42. 63. 41.9815 62.9815 MAarrowhead1
% End of user PostScript
.65851 .96388 m
.65851 .96388 L
s
% Start of user PostScript
43. 63. MAarrowzero1
% End of user PostScript
.67361 .96388 m
.67314 .9636 L
s
% Start of user PostScript
44. 63. 43.9686 62.9815 MAarrowhead1
% End of user PostScript
.68872 .96388 m
.68947 .9634 L
s
% Start of user PostScript
45. 63. 45.0499 62.9686 MAarrowhead1
% End of user PostScript
.70382 .96388 m
.70458 .9634 L
s
% Start of user PostScript
46. 63. 46.0499 62.9686 MAarrowhead1
% End of user PostScript
.71893 .96388 m
.71893 .96435 L
s
% Start of user PostScript
47. 63. 47. 63.0314 MAarrowhead1
% End of user PostScript
.73403 .96388 m
.73403 .96435 L
s
% Start of user PostScript
48. 63. 48. 63.0314 MAarrowhead1
% End of user PostScript
.74914 .96388 m
.74914 .96388 L
s
% Start of user PostScript
49. 63. MAarrowzero1
% End of user PostScript
.76424 .96388 m
.76472 .96312 L
s
% Start of user PostScript
50. 63. 50.0314 62.9501 MAarrowhead1
% End of user PostScript
.77935 .96388 m
.77935 .96388 L
s
% Start of user PostScript
51. 63. MAarrowzero1
% End of user PostScript
.79445 .96388 m
.79445 .96388 L
s
% Start of user PostScript
52. 63. MAarrowzero1
% End of user PostScript
.80956 .96388 m
.80928 .96388 L
s
% Start of user PostScript
53. 63. 52.9815 63. MAarrowhead1
% End of user PostScript
.82466 .96388 m
.82466 .96388 L
s
% Start of user PostScript
54. 63. MAarrowzero1
% End of user PostScript
.83977 .96388 m
.83977 .96388 L
s
% Start of user PostScript
55. 63. MAarrowzero1
% End of user PostScript
.85488 .96388 m
.85488 .9634 L
s
% Start of user PostScript
56. 63. 56. 62.9686 MAarrowhead1
% End of user PostScript
.86998 .96388 m
.86998 .96388 L
s
% Start of user PostScript
57. 63. MAarrowzero1
% End of user PostScript
.88509 .96388 m
.88509 .9636 L
s
% Start of user PostScript
58. 63. 58. 62.9815 MAarrowhead1
% End of user PostScript
.90019 .96388 m
.90066 .96388 L
s
% Start of user PostScript
59. 63. 59.0314 63. MAarrowhead1
% End of user PostScript
.9153 .96388 m
.9153 .96388 L
s
% Start of user PostScript
60. 63. MAarrowzero1
% End of user PostScript
.9304 .96388 m
.9304 .9634 L
s
% Start of user PostScript
61. 63. 61. 62.9686 MAarrowhead1
% End of user PostScript
.94551 .96388 m
.94551 .9634 L
s
% Start of user PostScript
62. 63. 62. 62.9686 MAarrowhead1
% End of user PostScript
.96061 .96388 m
.96061 .96388 L
s
% Start of user PostScript
63. 63. MAarrowzero1
% End of user PostScript
.97572 .96388 m
.97619 .96388 L
s
% Start of user PostScript
64. 63. 64.0314 63. MAarrowhead1
% End of user PostScript
.02409 .97898 m
.02409 .97898 L
s
% Start of user PostScript
1. 64. MAarrowzero1
% End of user PostScript
.03919 .97898 m
.03919 .97898 L
s
% Start of user PostScript
2. 64. MAarrowzero1
% End of user PostScript
.0543 .97898 m
.0543 .97898 L
s
% Start of user PostScript
3. 64. MAarrowzero1
% End of user PostScript
.0694 .97898 m
.0694 .97898 L
s
% Start of user PostScript
4. 64. MAarrowzero1
% End of user PostScript
.08451 .97898 m
.08451 .97898 L
s
% Start of user PostScript
5. 64. MAarrowzero1
% End of user PostScript
.09962 .97898 m
.09962 .97898 L
s
% Start of user PostScript
6. 64. MAarrowzero1
% End of user PostScript
.11472 .97898 m
.11472 .97898 L
s
% Start of user PostScript
7. 64. MAarrowzero1
% End of user PostScript
.12983 .97898 m
.12983 .97898 L
s
% Start of user PostScript
8. 64. MAarrowzero1
% End of user PostScript
.14493 .97898 m
.14493 .97898 L
s
% Start of user PostScript
9. 64. MAarrowzero1
% End of user PostScript
.16004 .97898 m
.15956 .97851 L
s
% Start of user PostScript
10. 64. 9.96863 63.9686 MAarrowhead1
% End of user PostScript
.17514 .97898 m
.17467 .97898 L
s
% Start of user PostScript
11. 64. 10.9686 64. MAarrowhead1
% End of user PostScript
.19025 .97898 m
.19072 .97898 L
s
% Start of user PostScript
12. 64. 12.0314 64. MAarrowhead1
% End of user PostScript
.20535 .97898 m
.20535 .9787 L
s
% Start of user PostScript
13. 64. 13. 63.9815 MAarrowhead1
% End of user PostScript
.22046 .97898 m
.22046 .9787 L
s
% Start of user PostScript
14. 64. 14. 63.9815 MAarrowhead1
% End of user PostScript
.23556 .97898 m
.23556 .97898 L
s
% Start of user PostScript
15. 64. MAarrowzero1
% End of user PostScript
.25067 .97898 m
.25067 .97898 L
s
% Start of user PostScript
16. 64. MAarrowzero1
% End of user PostScript
.26577 .97898 m
.26577 .97946 L
s
% Start of user PostScript
17. 64. 17. 64.0314 MAarrowhead1
% End of user PostScript
.28088 .97898 m
.28088 .97898 L
s
% Start of user PostScript
18. 64. MAarrowzero1
% End of user PostScript
.29598 .97898 m
.29598 .97926 L
s
% Start of user PostScript
19. 64. 19. 64.0185 MAarrowhead1
% End of user PostScript
.31109 .97898 m
.31137 .97898 L
s
% Start of user PostScript
20. 64. 20.0185 64. MAarrowhead1
% End of user PostScript
.32619 .97898 m
.32647 .97898 L
s
% Start of user PostScript
21. 64. 21.0185 64. MAarrowhead1
% End of user PostScript
.3413 .97898 m
.34158 .97898 L
s
% Start of user PostScript
22. 64. 22.0185 64. MAarrowhead1
% End of user PostScript
.3564 .97898 m
.35688 .97898 L
s
% Start of user PostScript
23. 64. 23.0314 64. MAarrowhead1
% End of user PostScript
.37151 .97898 m
.37198 .97898 L
s
% Start of user PostScript
24. 64. 24.0314 64. MAarrowhead1
% End of user PostScript
.38661 .97898 m
.38661 .97898 L
s
% Start of user PostScript
25. 64. MAarrowzero1
% End of user PostScript
.40172 .97898 m
.402 .97898 L
s
% Start of user PostScript
26. 64. 26.0185 64. MAarrowhead1
% End of user PostScript
.41682 .97898 m
.41682 .97898 L
s
% Start of user PostScript
27. 64. MAarrowzero1
% End of user PostScript
.43193 .97898 m
.43193 .97898 L
s
% Start of user PostScript
28. 64. MAarrowzero1
% End of user PostScript
.44703 .97898 m
.44703 .97851 L
s
% Start of user PostScript
29. 64. 29. 63.9686 MAarrowhead1
% End of user PostScript
.46214 .97898 m
.46261 .97946 L
s
% Start of user PostScript
30. 64. 30.0314 64.0314 MAarrowhead1
% End of user PostScript
.47725 .97898 m
.47725 .97898 L
s
% Start of user PostScript
31. 64. MAarrowzero1
% End of user PostScript
.49235 .97898 m
.4916 .97898 L
s
% Start of user PostScript
32. 64. 31.9501 64. MAarrowhead1
% End of user PostScript
.50746 .97898 m
.50746 .97823 L
s
% Start of user PostScript
33. 64. 33. 63.9501 MAarrowhead1
% End of user PostScript
.52256 .97898 m
.52256 .97946 L
s
% Start of user PostScript
34. 64. 34. 64.0314 MAarrowhead1
% End of user PostScript
.53767 .97898 m
.53767 .97898 L
s
% Start of user PostScript
35. 64. MAarrowzero1
% End of user PostScript
.55277 .97898 m
.55277 .97898 L
s
% Start of user PostScript
36. 64. MAarrowzero1
% End of user PostScript
.56788 .97898 m
.56788 .97898 L
s
% Start of user PostScript
37. 64. MAarrowzero1
% End of user PostScript
.58298 .97898 m
.58298 .97898 L
s
% Start of user PostScript
38. 64. MAarrowzero1
% End of user PostScript
.59809 .97898 m
.59809 .97898 L
s
% Start of user PostScript
39. 64. MAarrowzero1
% End of user PostScript
.61319 .97898 m
.61319 .97851 L
s
% Start of user PostScript
40. 64. 40. 63.9686 MAarrowhead1
% End of user PostScript
.6283 .97898 m
.62877 .97898 L
s
% Start of user PostScript
41. 64. 41.0314 64. MAarrowhead1
% End of user PostScript
.6434 .97898 m
.6434 .97898 L
s
% Start of user PostScript
42. 64. MAarrowzero1
% End of user PostScript
.65851 .97898 m
.65879 .97898 L
s
% Start of user PostScript
43. 64. 43.0185 64. MAarrowhead1
% End of user PostScript
.67361 .97898 m
.67361 .97898 L
s
% Start of user PostScript
44. 64. MAarrowzero1
% End of user PostScript
.68872 .97898 m
.68872 .97898 L
s
% Start of user PostScript
45. 64. MAarrowzero1
% End of user PostScript
.70382 .97898 m
.70382 .97898 L
s
% Start of user PostScript
46. 64. MAarrowzero1
% End of user PostScript
.71893 .97898 m
.7194 .97898 L
s
% Start of user PostScript
47. 64. 47.0314 64. MAarrowhead1
% End of user PostScript
.73403 .97898 m
.73451 .97946 L
s
% Start of user PostScript
48. 64. 48.0314 64.0314 MAarrowhead1
% End of user PostScript
.74914 .97898 m
.74942 .97898 L
s
% Start of user PostScript
49. 64. 49.0185 64. MAarrowhead1
% End of user PostScript
.76424 .97898 m
.76377 .97898 L
s
% Start of user PostScript
50. 64. 49.9686 64. MAarrowhead1
% End of user PostScript
.77935 .97898 m
.77935 .97898 L
s
% Start of user PostScript
51. 64. MAarrowzero1
% End of user PostScript
.79445 .97898 m
.79398 .97898 L
s
% Start of user PostScript
52. 64. 51.9686 64. MAarrowhead1
% End of user PostScript
.80956 .97898 m
.80956 .97898 L
s
% Start of user PostScript
53. 64. MAarrowzero1
% End of user PostScript
.82466 .97898 m
.82466 .97898 L
s
% Start of user PostScript
54. 64. MAarrowzero1
% End of user PostScript
.83977 .97898 m
.83977 .97898 L
s
% Start of user PostScript
55. 64. MAarrowzero1
% End of user PostScript
.85488 .97898 m
.85535 .97898 L
s
% Start of user PostScript
56. 64. 56.0314 64. MAarrowhead1
% End of user PostScript
.86998 .97898 m
.8697 .9787 L
s
% Start of user PostScript
57. 64. 56.9815 63.9815 MAarrowhead1
% End of user PostScript
.88509 .97898 m
.88481 .9787 L
s
% Start of user PostScript
58. 64. 57.9815 63.9815 MAarrowhead1
% End of user PostScript
.90019 .97898 m
.90019 .97851 L
s
% Start of user PostScript
59. 64. 59. 63.9686 MAarrowhead1
% End of user PostScript
.9153 .97898 m
.9153 .97898 L
s
% Start of user PostScript
60. 64. MAarrowzero1
% End of user PostScript
.9304 .97898 m
.93087 .97926 L
s
% Start of user PostScript
61. 64. 61.0314 64.0185 MAarrowhead1
% End of user PostScript
.94551 .97898 m
.94551 .97898 L
s
% Start of user PostScript
62. 64. MAarrowzero1
% End of user PostScript
.96061 .97898 m
.96061 .97898 L
s
% Start of user PostScript
63. 64. MAarrowzero1
% End of user PostScript
.97572 .97898 m
.97572 .97898 L
s
% Start of user PostScript
64. 64. MAarrowzero1
% End of user PostScript
0 0 m
1 0 L
1 1.00335 L
0 1.00335 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[23]:=",
  ImageSize->{287, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004O000182000`400?l00000o`00003oo`3ooolP
0?ooo`00o`3ooolP0?ooo`00o`3ooolP0?ooo`005@3oool00d00000000000000000E0?ooo`04@000
000000000000000000l0oooo00<000000?ooo`3oool02`3oool00d000000oooo0?ooo`0A0?ooo`04
@000000000000000000001d0oooo00=000000?ooo`3oool0:03oool00d00000000000?ooo`0l0?oo
o`04@000003oool0oooo000001@0oooo0P00000H0?ooo`005@3oool3000001D0oooo1000000>0?oo
o`<000002`3oool300000180oooo1000000J0?ooo`03@000003oool00000008000001`3oool00d00
0000oooo0?ooo`060?ooo`03@000003oool0oooo01H0oooo1000000j0?ooo`H000004@3oool01400
0000000000000000000H0?ooo`005@3oool3000001H0oooo0`00000=0?ooo`04@000000000000000
000000/0oooo1000000B0?ooo`<000002P3oool00d000000oooo0?ooo`0<0?ooo`80000000<0oooo
0000000000000P0000050?ooo`<000001P3oool2000001P0oooo0`00000:0?ooo`030000003oool0
oooo02h0oooo0P00000014000000000000000000000B0?ooo`<00000603oool001H0oooo00<00000
0?ooo`3oool05@3oool2000000l0oooo100000090?ooo`@000004`3oool2000000X0oooo0P00000=
0?ooo`L000001@3oool4000000@0oooo1@00000F0?ooo`<000002P3oool3000002h0oooo2000000B
0?ooo`<000005`3oool001H0oooo00<000000?ooo`3oool0203oool400000004@000000000000000
000000H0oooo00<000000?oood0000000`0000001400000000000000000000030?ooo`T000001`3o
ool2000000@0oooo00A0000000000000000000000`3oool00`000000oooo0?ooo`060?ooo`04@000
000000000000000000D0oooo1`0000050?ooo`80000000=000000?ooo`0000000`00000014000000
00000000000000040?ooo`P000000P3oool6000001H0oooo0P00000:0?ooo`03@000000000000000
0080000000=000000?ooo`3oool0403oool200000003@000003oool0oooo00l0oooo0P0000000d00
0000oooo00000003000000@0oooo00A000000000000000000000303oool01D000000000000000000
0000oooo008000002P3oool200000003@000003oool0oooo00P0oooo000>0?ooo`05@000003oool0
oooo0?ooo`0000000`3oool00`000000oooo0?ooo`02000000<0oooo2`0000000`3oool000000?oo
o`030?ooo`030000003oool0000000L0000000<0oooo0000000000001@0000000`3oool000000000
0004000000<0oooo00@000000?ooo`3oool0oooo3@0000030?ooo`80000000<0oooo000000000000
0`000000103oool000000?ooo`3oool700000080oooo3`0000000`3oool000000000000800000080
oooo2P0000030?ooo`05@000003oool0oooo0?oood0000000`3oool01D000000oooo0?ooo`3ooom0
000000<0oooo00D000000?ooo`3oool0oooo@00000030?ooo`04@000003oool0oooo0?ooo`H00000
0P3oool500000005@000003oool0oooo0?oood0000000`3oool600000080oooo00D000000?ooo`3o
ool0oooo000000030?ooo`04@000003oool0oooo0?ooo`X000000P3oool00d000000oooo0?ooo`07
000000040?ooo`0000000000000000<0oooo00<000000?ooo`0000000`0000020?ooo`030000003o
ool0oooo008000000`3oool6000000X0oooo000C0?ooo`8000000P3oool3000000<0oooo10000000
14000000000000000400000300000080oooo0P0000060?ooo`<0000000@0oooo0000000000000000
1P3oool2000000040?oood0000000000000000/0oooo1@0000000d000000oooo@0000004000000<0
oooo0P0000020?ooo`03@00000000000000000@0000000@0oooo@0000000000000002@3oool30000
00050?ooo`00000000000000003oool00`0000050?ooo`04@000000000000000000000P0oooo00=0
00000000000000009P3oool4000000<0oooo1000000:0?ooo`@0000000<0oooo0000003oool00P3o
ool2000000T0oooo0`000000103oool000000000000000050?ooo`<0000000<0oooo000000000000
100000040?ooo`030000003oool0oooo00<000001P3oool4000000<0oooo0P0000000d000000oooo
0?ooo`080?ooo`004`3oool7000000@0oooo1P0000020?ooo`80000000<0oooo0000000000000`00
00040?ooo`8000000P3oool2000000<0oooo0P0000020?ooo`03000004000000000000h0oooo1@00
00030?ooo`D000000`3oool2000000030?ooo`000000000000H000005@3oool2000004<0oooo0P00
000<0?ooo`@000000`3oool3000001D0oooo0P0000020?ooo`<000001@3oool2000000030?ooo`00
0000000000<000001P3oool400000003@000003oool00000008000002P3oool00140oooo00=00000
0000000000001@0000001D000000oooo0?ooo`3ooom0000000<0000000T0oooo0000040000000000
0?ooo`000000oooo0000040000001@0000040?ooo`050000003oool0oooo0?ooo`0000000`3oool:
000000040?ooo`0000000000@00000L0oooo0P0000000`3oool000000?ooo`020?ooo`80000000A0
000000000000000000000T000004000000040?ooo`000000oooo@00000D000000`3oool3000000T0
oooo0`0000020?ooo`030000003oool0oooo00`0oooo100000060?ooo`03@00000000000000001P0
oooo00D000000?ooo`3oool0oooo@000000300000080oooo100000000d000000oooo0?ooo`0?0?oo
o`@000000`3oool3000000<0oooo0P0000001D000000oooo000000000010000000@0oooo00<00000
0?ooo`3oool00`3oool01@000000oooo@000003ooom0000000L0oooo10000002@00000<00000103o
ool010000000oooo000004000006000000X0oooo000>0?ooo`030000003oool0oooo00H0000000A0
000000000000000000000P3oool4000000030?oood000000000000`000000`3oool01@000000oooo
0?ooo`3oool000000080oooo1`0000000`3oool000000000000500000080oooo00D000000?ooo`3o
ool0oooo000000030?ooo`@0000000=000000000000000002@0000000d00000000000?ooo`070000
0080oooo1P0000030?ooo`L0000000<0oooo@000003oool00P3oool01D000000oooo0?ooo`3ooom0
000000<0oooo00<000000?ooo`3oool01`0000000`3oool0000000000005000000<0oooo00D00000
0?ooo`3oool0oooo@00000030?ooo`05@000003oool0oooo0?oood0000000`3oool2@00000800000
00=000000?ooo`3oool0100000000`3oool0000000000005000000030?ooo`000000000000@00000
00@0oooo00000000000000000`3oool00`000000oooo0000000300000080oooo3P0000020?ooo`05
@0000000000000000?oood0000000`3oool01P000000oooo000000000000oooo000000<0oooo00<0
00000?ooo`000000100000000d000000000000000003000000<0oooo0P0000000`3oool000000000
0005000000X0oooo000<0?ooo`8000000`3oool3000000040?ooo`000000oooo0?ooo`@0000000@0
oooo00000000000000000`3oool300000003@00000000000000000800000403oool00d0000000000
00000003000000050?oood00000000000000003oool00`0000020?ooo`030000003oool0oooo00P0
oooo300000030?ooo`D000001@3oool00d0000000000000000090?ooo`03@00000000000000000<0
00002`3oool010000000oooo0?oood000002000000030?ooo`000000000000P000000P3oool20000
0180oooo0P0000030?ooo`<000000`3oool00d000000000000000002000000@0oooo1`0000020?oo
o`8000000P3oool300000004@000003oool0oooo0?ooo`800000103oool3000000070?ooo`000000
00000000003oool00000@0000003000000D0oooo1@0000030?ooo`030000003oool0000000800000
00=000000000000000000`0000050?ooo`H000003P3oool000X0oooo100000040?ooo`040000003o
ool0oooo0?ooo`D000000`3oool3000000050?ooo`00000000000000003oool01@00000P0?ooo`03
0000003oool0oooo00h0oooo200000000`3oool0000000000002000001<0oooo1P00000:0?ooo`D0
00000`3oool8000000030?ooo`0000000000008000004`3oool2000000<0oooo0P00000>0?ooo`@0
000000<0oooo0000000000001P0000050?ooo`@000001`3oool8000000D0oooo1@0000020?ooo`80
00000P3oool400000004@000000000000000000000H0oooo1000000?0?ooo`002@3oool4000000@0
oooo0`0000000`3oool0000000000002000000D0oooo0`0000001400000000000000000000020?oo
o`X000004@3oool200000003@000003oool0oooo00<0oooo00=000000000000000001@3oool20000
0003@000003oool0oooo00@0oooo0P0000000d000000oooo0?ooo`0600000004@000000000000000
000000D0oooo0`000000103oool000000000000000070?ooo`<000000`3oool01D00000000000000
00000010000000P00000103oool20000009000000`0000000`3oool0000000000005000000040?oo
o`0000000000@00000T0oooo00A00000000000000000oooo0P0000000d000000oooo000000020000
00D0oooo00@000000?ooo`3oool0oooo0P0000000d000000oooo0?ooo`0?000000040?oood000000
oooo0?ooo`<0000000=000000?ooo`3oool00`3oool600000007@000000000000000@00000000000
oooo@0000003000000050?ooo`00000000000000003oool00P0000020?ooo`T00000103oool50000
00l0oooo000:0?ooo`<0000000@0oooo@000003oool0oooo100000001P3oool00000000000000000
oooo@00000<0oooo1`0000001@3ooom000000?oood000000oooo00X000000`3oool01@000000oooo
0?ooo`3oool0000000<0oooo1P0000000d000000000000000006000000030?ooo`000000000000@0
00000P3oool01T000000oooo0?ooo`3oool000000?ooo`80000000<0oooo0000000000000`000000
0`3oool000000000000200000080oooo00=000000?ooo`3oool02P0000030?ooo`8000000P3oool0
0`000000oooo0?ooo`0900000003@00000000000000000`000000P3oool:00000080oooo00E00000
0?ooo`3ooom00000000000020?ooo`L0000000<0oooo@000000000000`000002@00000P0000000<0
oooo0000000000004@000000103oool000000000040000030?ooo`03@000003oool0oooo00@00000
00<0oooo@000000000003`000002@00000@000000P3oool5000000<0oooo1@00000?0?ooo`002`3o
ool00d000000oooo0?ooo`030?ooo`07@0000000000000000000003oool00000@00000070?ooo`D0
00001P3oool0140000000000000004000002000000D0oooo0P0000050?ooo`8000000P3oool:0000
0003@00000000000000000P000001`3oool400000080oooo00<000000?ooo`3oool00P3oool30000
00D0oooo00E00000000000000000oooo@0000003000000030?ooo`000000oooo00P0oooo10000000
1@3oool00000000000000000oooo00<0000000=000000?ooo`3oool00P3oool00`00001000000000
0005000000<0oooo0P000002@00000030000003oool0000000800000103oool300000080oooo0`00
00000`3oool0000000000005000000040?ooo`00000000000?ooo``000000T000003000000<0oooo
00=000000?oood0000001P0000000`3oool000000?ooo`060?ooo`<0000000=000000?ooo`3oool0
0P0000000`3oool0000000000004000000030?ooo`000000000000T0000000A000000?ooo`3ooom0
0000100000030?ooo`8000004P3oool00180oooo1`0000090?ooo`8000001@3oool300000080oooo
100000000`3oool0000000000002000000D0oooo1`0000030?ooo`@0000000<0oooo000000000000
1@00000:0?ooo`<00000203oool2000000/0oooo1`0000060?ooo`D000000P3oool2000000T0oooo
200000030?ooo`@000001`3oool600000080oooo00<000000?ooo`3oool00P3oool4000000030?oo
o`00000000000080000000<0oooo0000000000000P0000000`3ooom0000000000002000000d0oooo
1@00000?0?ooo`<0000000<0oooo0000000000000P3oool2000000@0oooo1P0000060?ooo`<00000
103oool200000180oooo000C0?ooo`T000001P3oool010000000oooo0?oood00000700000003@000
00000000000000H000001`3oool500000004@0000000000000000?ooo`<000000P3oool00`000000
oooo00000003000000030?oood0000000000008000001@3oool2000000@0oooo00=000000?ooo`3o
ool00P3oool01400000000000000000000050?ooo`80000000M000000?ooo`0000000000@0000000
0010000000@000001@3oool500000080oooo00<000000?ooo`3oool01@3oool:000000@0oooo1@00
00001@3oool00000000004000000oooo00D000000`3oool200000004@000003oool0oooo0?ooo`80
00000P3oool3000000030?ooo`000000000000@000000`3oool300000003@000003oool0000000<0
00001@3oool4000000@0oooo0P0000001D000000oooo0?oood000000000000D0oooo0`0000020?oo
o`8000000P3oool00`000000oooo0?ooo`050?ooo`<0000000<0oooo0000003oool01@3oool30000
00<0oooo0`0000040?ooo`80000000=000000?ooo`3oool0203oool000h0oooo00A000000?ooo`3o
ool0oooo0`0000000d000000000000000007000000<0oooo00<000000?ooo`3oool0100000000`3o
ool000000?ooo`030?ooo`03@00000000000000000L000000P3oool00`000000oooo000000070000
00040?ooo`000000000000000080oooo00D000000?ooo`3oool0oooo000000020?ooo`@0000000H0
oooo@000003oool000000?ooo`0000040?ooo`<0000000<0oooo@000003oool0100000020?ooo`P0
000000A000000000003oool0oooo1@0000030?ooo`03000004000000000000@0000000<0oooo0000
003oool00P3oool:000000<0oooo00@000000?ooo`3oool0oooo3`0000000`3oool0000000000004
00000080oooo00@000000?ooo`3oool0oooo0P0000020?ooo`<0000000<0oooo0000000000000P3o
ool6000000030?ooo`000000000000D000000P3oool300000080oooo100000001400000000000?oo
o`3oool900000004@00000000000oooo000000<0oooo00@000000?ooo`3oool0oooo0P0000020?oo
o`80000000=000000000000000001`0000000`3oool000000?ooo`020?ooo`80000000=000000?oo
o`0000001@00000:0?ooo`006@3oool4000000P0oooo0`0000020?ooo`030000003oool0oooo0080
oooo1`0000000d00000000000000000<000000040?ooo`0000000000@00000T0oooo0`0000030?oo
o`<000001@3oool4000000<0oooo0`0000040?ooo`P0000000<0oooo@000000000000P0000070?oo
o`@0000000=000000?ooo`3oool01@3oool500000003@000003oool0oooo00X0oooo00<000000?oo
o`3oool0200000040?ooo`@000000P3oool00`000000oooo0?ooo`0?0?ooo`@0000000<0oooo0000
000000000`0000040?ooo`80000000=000000?ooo`3oool00P3oool200000004@00000000000oooo
0?ooo`<000000`3oool00d000000000000000004000000P0oooo100000020?ooo`/0000000=00000
0?ooo`3oool00P0000040?ooo`@000002P3oool001T0oooo00=000000000003oool02P3oool20000
0080oooo0P0000020?ooo`03@00000000000000000D0000000<0oooo0000000000001@0000000d00
000000000?ooo`020?ooo`030000003oool0oooo00d0oooo0P0000020?ooo`04@000000000000000
000000@0oooo100000040?ooo`8000001`3oool200000080oooo0P0000020?ooo`<00000203oool2
000000`0oooo0P00000B0?ooo`8000000P3oool2000000H0oooo0P0000020?ooo`<000004@3oool2
000000030?oood000000000000l0oooo0`0000000`3oool000000000000200000080oooo1P000000
0`3oool00000000000080?ooo`<0000000A000000?ooo`3ooom000001@0000000`3oool000000000
0002000000<0oooo0P0000050?ooo`8000002P3oool001D0oooo0`000000103oool0000000000400
000:0?ooo`80000000A0000000000000000000000`3oool200000003@00000000000000000T00000
1P3oool00`000000oooo0?ooo`04000000P0oooo0`0000040?ooo`03000004000000000000H00000
0`3oool4000000H0oooo0`000000103oool000000000040000040?ooo`8000001`3oool3000002D0
oooo00=000000?ooo`3oool01P3oool600000080oooo00A000000000000000000000103oool01D00
00000000000000000000oooo00<00000303oool200000003@00000000000000000L0000000<0oooo
@000000000002`0000070?ooo`<000000P3oool600000080oooo0P0000040?ooo`<00000403oool0
00h0oooo00D000000?ooo`3oool0oooo@00000020?ooo`L000000P3oool010000000oooo0?oood00
000:00000080oooo0`0000000`3oool0000000000006000000030?ooo`00000000000080oooo0`00
0000103oool000000?ooo`3oool700000080oooo2@0000020?ooo`P0000000<0oooo000000000000
1@0000020?ooo`030000003oool0oooo00L000000P3oool01D000000oooo0?ooo`3oool0000000<0
oooo00<000000?ooo`3oool01P0000030?ooo`8000000P3oool200000080oooo0P0000020?ooo`80
000000@0oooo@000003oool000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00<00000
0?ooo`0000000P0000030?ooo`040000003oool0oooo@00000H0000000<0oooo0000000000001@00
00000`3oool0000000000002000000030?ooo`000000000000@000000`3oool010000000oooo0000
0400000>000000030?ooo`00000000000080000000D0oooo000000000000oooo@000000600000080
oooo0P0000020?ooo`8000000`3oool00`000000oooo0000000200000080oooo0P0000030?ooo`D0
00003`3oool000`0oooo0P0000070?ooo`L000000P3oool00`000000oooo00000002000000030?oo
o`000000000000L000002`3oool00d000000oooo0?ooo`0300000080oooo1000000014000000oooo
000004000004000000@0oooo1P0000040?ooo`03000004000000000000@0000000=000000?ooo`3o
ool0203oool:000000X0oooo00<000000?ooo`3oool0100000040?ooo`H0000000D0oooo00000000
000000000?ooo`03000000030?ooo`00000000000080000000<0oooo0000000000000`3oool20000
00040?ooo`00000000000?ooo`@000000P3oool200000080oooo0P0000060?ooo`D000000`3oool4
000000030?ooo`000000000000800000103oool2000000030?ooo`000000000000D0000000=00000
0000000000000`3oool200000003@000003oool00000008000000P3oool01@000000oooo0?ooo`3o
ool0000000D0oooo00A0000000000000000000000`3oool01@000000oooo0?ooo`3ooom000000080
00001@3oool300000080oooo100000000d000000oooo0?ooo`0<0?ooo`002P3oool4000000L0oooo
00=000000000003oool00P3oool200000080oooo1P0000030?ooo`H000003@3oool0140000000000
0000000000030?ooo`@0000000<0oooo0000040000001P0000030?ooo`03000004000000000000L0
oooo1@00000=0?ooo`80000000=000000000003oool00P3oool2000000X0oooo0P0000000`3ooom0
0000000000040?ooo`l000000P3oool700000080oooo3P0000020?ooo`<00000103oool200000090
00000`0000000`3oool000000000000300000080oooo00=000000000000000000P0000001@3oool0
0000000000000000oooo00@000001@3oool2000000P0oooo0P0000060?ooo`8000000P3oool00`00
001000000?ooo`04000000030?ooo`000000000000@0oooo0`0000050?ooo`T000003P3oool000T0
oooo100000040?ooo`80000000E000000000000000000000@00000050?ooo`03@000000000000000
008000000`3oool01400000000000000000000020?ooo`<000000`3oool00d000000000000000005
00000003@00000000000000000<000000`3oool>000000<0oooo00@000000?ooo`3oool0oooo0P00
0000140000000000000004000003000000H0oooo00=000000?ooo`3oool00P3oool200000004@000
000000000000@00000H0oooo0P0000000d000000oooo00000002000000060?ooo`0000000000@000
003ooom000000`0000000`3oool00000@000000500000080oooo0P0000020?ooo`8000000P3oool6
00000003@0000000000000000080000000E0000000000000000000000?ooo`0300000003@0000000
000000000080000000@0oooo0000000000000000103oool5000000030?ooo`000000000000@00000
00<0oooo0000003oool00`3oool7000000060?ooo`000010000000000400000000001@3oool20000
00D0oooo100000050?ooo`L000000P3oool6000000D0oooo0P0000030?ooo`X0000000=000000000
003oool0303oool000X0oooo1@0000020?ooo`L000000P3oool00`000000oooo0?ooo`0600000080
oooo100000000`3ooom000000000000200000003@00000000000000000`0000000<0oooo00000000
00000`3oool700000003@00000000000000000@000000P3oool:00000080oooo0P0000030?ooo``0
000000A000000?ooo`3oool0oooo3P0000000`3oool000000000000300000003@000000000000000
0080000000I000000?ooo`3oool0oooo@000003oool3000000<0oooo0`0000000`3oool000000000
0009000000030?ooo`00001000000080oooo200000001D000000oooo0?ooo`3ooom0000000<00000
00A000000?ooo`000000oooo100000000`3oool000000?ooo`020?ooo`03@00000000010000000@0
000000<0oooo0000000000001P0000000d000000000000000002000000<0oooo1P0000020?ooo`03
0000003oool0oooo00L0000000=000000000000000002@0000020?ooo``0000000<0oooo@0000000
00000`00000;0?ooo`002`3oool3000000<0oooo2@0000030?ooo`@00000103oool4000000<0oooo
0P0000030?ooo``000002@3oool7000000L0oooo2@0000030?ooo`040000003oool0oooo0?ooo`D0
000000<0oooo0000000000000`0000070?oooaH000000`3oool6000000D0oooo00D00000@000003o
ool0oooo@000000400000004@000000000000000000000H0oooo00<000000?oood0000000`3oool0
0`00001000000?ooo`050?ooo`03@00000000000000000<000000P3oool00d000000oooo0?ooo`05
0?ooo`@0000000@0oooo@000003ooom000002P0000000`3oool000000?ooo`050?ooo`<000000P3o
ool2000000050?ooo`00000000000000040000000`0000000`3oool000000000000C00000080oooo
00A000000?ooo`3oool0oooo0`00000<0?ooo`002@3oool4000000@0oooo00E00000000000000000
0000@0000004000000<0oooo0T000003000000<0oooo1P0000000`3oool000000?ooo`040?ooo`<0
000000=000000000003oool00P3oool4000000P0oooo100000000`3oool00000000000060?ooo`05
@0000000000000000000003oool00P0000000`3oool00000000000070?ooo`@000000`3oool30000
00X0oooo0P0000001@3ooom00000000000000000oooo00<0000000A000000?ooo`00000000000P3o
ool3000000D0oooo0`00000:0?ooo`H000000P3oool2000000H0oooo00<000000?ooo`3oool02`3o
ool200000004@000000000000000000000X0oooo100000020?ooo`/000003`3oool2000000D0oooo
0P0000001@3oool00000000000000000oooo00<0000000=000000000000000001P000000103oool0
00000000000000060?ooo`<000003@3oool000X0oooo0P0000050?ooo`<0000000<0oooo00000000
00000P0000001D00000000000000003ooom0000000@000000`3oool00d0000000000000000030000
0003@000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00d0000000000000000020000
00<0oooo0`0000000`3ooom0000000000003000000T0oooo100000000d000000oooo0?ooo`020?oo
o`80000000=000000?ooo`3oool00P3oool400000003@000003oool0oooo0080000000=000000?oo
o`3oool02`3oool200000003@000003oool0oooo00@0oooo00@000000?ooo`3ooom000000`000003
0?ooo`06@000000000000000000004000000oooo0P0000000d000000oooo0?ooo`030?ooo`H00000
00A000000?ooo`3oool000001P3oool2000000/0oooo2@0000000`3ooom00000000000040?ooo``0
000000D0oooo00000000000000000?ooo`02000000d0oooo0P0000000d0000000000000000030?oo
o`<000000P3oool2000000D0oooo0`000000140000000000@000000000020?ooo`D00000103oool2
000000h0oooo000:0?ooo`03@000003oool0oooo008000000P3oool;000000030?ooo`0000000000
00@000000`3oool00`000000oooo00000003000000<0oooo00E000000?ooo`3oool0oooo00000003
0?ooo`060000003oool0oooo0?ooo`000000oooo0`0000020?ooo`l000000P3oool>00000080oooo
0P0000000`3oool000000000000600000080oooo00E000000?ooo`3oool0oooo@00000030?ooo`@0
000000=000000000003oool00T0000030?ooo`030000003oool0oooo00@0000000<0oooo00000000
00001`0000002400000000000?ooo`3ooom000000?oood000000oooo1P0000020?ooo`050000003o
ool0oooo0?ooo`0000000P3oool00`0000100000000000020?ooo`04@000003oool0oooo0?ooo`L0
000000<0oooo0000003oool00P3oool800000003@00000000010000000<000000T00000300000080
oooo00I000000000003oool0oooo0000003oool3000000<0oooo00@000000?ooo`3oool0oooo2@00
00020?ooo`<000000P3oool200000080oooo100000001400000000000000003oool200000080oooo
00=000000000000000000`0000030?ooo`030000003oool0oooo00d0oooo000;0?ooo`<000000`3o
ool400000080oooo00=000000?ooo`0000000P000000103oool000000000000000090?ooo`030000
003oool0oooo00/0oooo00<000000?ooo`3oool0203oool8000000030?ooo`000000000000800000
1@3oool7000000030?ooo`000000000000H000000P3oool010000000oooo0?ooo`3oool4000000`0
oooo1`0000060?ooo`<000000`3oool:000000@0oooo0P0000000`3ooom000000000000300000080
oooo00E000000?ooo`3oool0oooo000000020?ooo`<00000203oool500000080oooo0P0000020?oo
o`<000000`3oool<00000080oooo100000000d00000000000000000200000080oooo0P0000050?oo
o`D0000000@0oooo000000000000oooo100000020?ooo`050000003oool0oooo0?oood0000001@00
00020?ooo`@00000103oool00d000000oooo0?ooo`0A0?ooo`002@3oool4000000@0oooo00=00000
0000003oool01P3oool200000080oooo0P00000F0?ooo`8000002P3oool01D00000000000?ooo`3o
oom0000000<0000000<0oooo@000000000000`0000030?ooo`<0000000<0oooo@000000000000P00
00030?ooo`80000000<0oooo0000000000000P0000000d000000oooo0?ooo`020?ooo`@000003P3o
ool6000000D0oooo0`0000030?ooo`8000000P3oool200000080oooo0P0000030?ooo`@000000`3o
ool2000000030?ooo`000000000000<0oooo00<000000?ooo`3oool00P0000000d000000oooo0?oo
o`090?ooo`8000000P3oool6000000<0oooo3@0000020?ooo`<000000P3oool7000000P0oooo0P00
00020?ooo`80000000D0oooo0000000000000000@00000070?ooo`D000000P3oool4000000<0oooo
0P00000C0?ooo`002@3oool3000000D0oooo0`000000103oool000000000040000020?ooo`030000
003oool0oooo00<000001@3oool01@000000oooo0?ooo`3ooom0000000<000000`3oool00d000000
00000?ooo`030?ooo`8000000P3oool200000003@000003oool0oooo00<0oooo0`0000020?ooo`@0
000000<0oooo000000000000100000000d000000000000000002000000030?ooo`00000000000080
00001@3oool200000003@00000000000000000D0oooo0P0000060?ooo`<000001`3oool4000000D0
oooo00<00000@000000000000P0000020?ooo`800000103oool01D00000000000000000000100000
00D000001P3oool4000000060?ooo`0000000000@000003ooom000000P0000050?ooo`80000000=0
00000?ooo`0000000P0000000`3ooom000000000000700000080oooo1@0000020?ooo`D000000P3o
ool3000000@0oooo1@0000000d0000000000000000050?ooo`<000000P3oool500000003@000003o
ool0oooo00L0oooo0P0000000`3oool000000000000500000080oooo1000000B0?ooo`002@3oool6
00000080oooo1`0000020?ooo`030000003oool0oooo00H0000000A0000000000000001000000P3o
ool400000080oooo00=000000000000000000P0000020?ooo`L000000P3oool00`000000oooo0?oo
o`06000000040?ooo`000000000000000080oooo00A0000000000000001000001P0000020?ooo`80
00000P3oool700000080oooo00=000000000000000000P0000001D00000000000?ooo`3oool00000
0080oooo1`0000020?ooo`<0000000<0oooo@000003oool00P3oool7000000030?ooo`0000000000
00<0oooo00<000000?ooo`0000001`0000020?ooo`8000000P3oool:000000040?ooo`0000000000
00000080oooo1P0000000d00000000000000000800000004@0000000000000000?ooo`80000000Q0
000000000000000000000?ooo`000010000000000080oooo00<000000?ooo`3oool00`0000020?oo
o`030000003oool0oooo00L000000P3oool200000006@0000000001000000000003ooom000001P00
00020?ooo`8000000`3oool00`000000oooo0?ooo`0>000000<0oooo00<000000?ooo`3oool03@3o
ool000T0oooo100000040?ooo`L000000P3oool00`000000oooo0?ooo`04000000<0oooo0`000002
0?ooo`<00000103oool2000000030?ooo`000000000000P000000P3oool00`000000oooo0?ooo`04
000000D0oooo00<000000?ooo`0000002`0000030?ooo`040000003oool0oooo0?ooo`P0000000<0
oooo0000000000000P00000014000000oooo0?ooo`0000020?ooo`0500000400000000000000003o
ool00`0000000`3oool000000?ooo`060?ooo`80000000@0oooo00000000000000000P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00<0000000<0oooo0000000000001P000000103o
ool000000000000000030?ooo`@0000000@0oooo0000000000000000103oool?000000040?ooo`00
0000000000000080oooo100000000`3oool000000000000400000080oooo0P0000030?ooo`030000
003oool0oooo008000000T000006000000030?ooo`000000000000/000000P3oool200000080oooo
00@000000?ooo`3oool0oooo0P0000001P3oool0000000000400000000000?ooo`80000000<0oooo
0000000000000`3oool2000000h0oooo00090?ooo`03@00000000000oooo00D0oooo00=000000000
003oool00P3oool2000000D0oooo00=000000000003oool0103oool400000080oooo0P0000030?oo
o`<0000000<0oooo0000000000000`0000000d000000oooo0000000200000080oooo00D000000?oo
o`3ooom00000000000090?ooo`@0000000<0oooo000004000000100000030?ooo`030000003oool0
oooo00@0oooo0P0000000`3oool000000000000200000003@0000000000000000080000000<0oooo
0000000000000P3oool200000080oooo00A0000000000000000000003@3oool2000000H0oooo0P00
00020?ooo`<0000000<0oooo0000000000000P0000001D0000000000000000000010000000<00000
103oool300000080oooo0P0000060?ooo`H0000000=000000?ooo`0000000P0000020?ooo`@00000
0`3oool3000000030?oood000000000000800000103oool00`000000oooo0?ooo`020?ooo`800000
1P3oool>000000030?ooo`000000000000<0000000<0oooo0000000000000`0000070?ooo`<00000
0`3oool3000000@0oooo0P00000=0?ooo`004@3oool200000080oooo00=000000000000000002@3o
ool00d000000000000000003000000<0oooo0P0000030?ooo`03000004000000oooo0080oooo0P00
00040?ooo`03@00000000000000000<0000000=000000?ooo`3oool01`3oool400000003@0000000
0000000000L000000P3oool4000000L0oooo00<00000@000000000000P0000020?ooo`030000003o
ool0oooo0080000000=000000000000000000P0000020?ooo`@000000`3oool01D00000000000000
00000010000000H000001P3oool300000005@0000000000000000000040000000`0000000d000000
00000000000600000004@0000000000000000?ooo`80000000=000000?ooo`0000000P0000090?oo
o`<000000P3oool2000000<0oooo100000030?ooo`8000000P3oool5000000L0oooo0P0000000d00
0000oooo0?ooo`040?ooo`P0000000<0oooo0000000000000P0000040?ooo`@0000000<0oooo0000
000000000`0000060?ooo`D0000000A000000000000000000000103oool3000000`0oooo000>0?oo
o`0300000400000000000080000000<0oooo0000000000000P0000020?ooo`050000003oool0oooo
0?ooo`0000000P3oool6000000<0oooo00D000000?ooo`3ooom000000?ooo`03000000030?ooo`00
0000000000@0000000<0oooo0000000000001P0000000`3oool000000?ooo`030?ooo`03@0000000
0000000000X0000000=000000000000000000P0000000d000000000000000003000000<0oooo1000
0000103oool000000000000000030?ooo`H000001P3oool2000000<0oooo3@0000040?oooa400000
0P3oool4000000030?ooo`000000000000D0000000=000000000000000000`3oool01@000000oooo
0?ooo`3ooom0000000@0000000<0oooo@000000000000P0000020?ooo`03000004000000000000<0
00000P3oool2000000030?ooo`00000000000080oooo00=000000000000000000P3oool5000000@0
oooo00@00000@000003oool0oooo0P0000030?ooo`8000000P3oool00`000000oooo0?ooo`020?oo
o`T000000P3oool00`000000oooo0?ooo`020?ooo`P000000`3oool400000003@000003oool0oooo
00T0oooo000<0?ooo`<0000000<0oooo0000000000001P0000020?ooo`050000003oool0oooo0?oo
o`0000000P3oool300000080oooo00H000000?ooo`3oool0oooo0000003ooolH000000<0oooo00=0
00000?ooo`0000000P0000020?ooo`L0000000<0oooo000000000000100000000d00000000000000
000C00000080oooo00E000000?ooo`3oool0oooo@00000030?ooo`030000003oool0oooo00<00000
00D0oooo00000000000000000?ooo`07000000030?ooo`00000000000080000000D0oooo00000000
000000000?ooo`0700000080oooo00<000000?ooo`3oool00`0000000`3oool00000000000080000
00<0oooo0P0000020?ooo`<0000000<0oooo0000003oool0100000030?ooo`03@000000000000000
008000000P3oool2000000<0oooo00<000000?ooo`0000000P0000020?ooo`H000000`3oool01@00
0000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool00P0000030?ooo`07@000003oool0
00000000003oool000000?ooo`0300000004@000003oool00000000000<0oooo2@0000030?ooo`04
0000003oool00000000000`0oooo000:0?ooo`@000000P3oool300000080oooo0`0000020?ooo`04
0000003oool0oooo0?ooo`8000000P3oool2000000P0oooo2P0000000d0000000000000000030000
0003@000003oool0000000<0000000<0oooo0000003oool0103oool3000000<0oooo00=000000000
000000000`000000103oool000000000000000040?ooo`<00000103oool400000080oooo2000000>
0?ooo`8000000P3oool2000000040?oood0000000000000000D0oooo0`0000000d000000oooo0000
0002000000030?ooo`000000000000D000001P3oool2000000030?ooo`000000000000<0000000<0
oooo0000000000000P0000040?ooo`80000000@0oooo00000000000000000P3oool5000000<0oooo
1P0000070?ooo`@000000`3oool4000000d0oooo100000070?ooo`80000000<0oooo000000000000
0`3oool2000000D0oooo1@0000000d000000oooo0?ooo`020?ooo`030000003oool0000000d0oooo
00090?ooo`@00000103oool200000080oooo0P0000020?ooo`8000000P3oool300000080oooo0P00
00070?ooo`X0000000<0oooo0000000000000`0000030?ooo`H000001P3oool200000003@000003o
ool0oooo00D000000P3oool3000000D0oooo0P00000<0?ooo`030000003oool0oooo00`0oooo00=0
00000000000000000P3oool200000080oooo0P00000>0?ooo`8000000T000006000000L0oooo00@0
0000@000003oool0oooo0`0000020?ooo`H000000P3oool5000000<0oooo1@0000020?ooo`P00000
1P3oool5000000030?oood000000000000800000103oool2000000L0oooo100000080?ooo`800000
00<0oooo0000000000000P3oool3000000D0oooo100000050?ooo`8000003`3oool000X0oooo1@00
00020?ooo`8000000P3oool7000000040?ooo`000000000000000080oooo00<000000?ooo`3oool0
1P3oool7000000030?oood000000oooo0080oooo00@000000?ooo`00000000000`3oool7000000@0
oooo1@0000001D00000000000?ooo`3ooom0000000P00000103oool2000000<0oooo00<000000?oo
o`3oool0503oool700000080oooo00<000000?ooo`3oool01`3oool010000000oooo0?ooo`3oool:
000000030?ooo`000000oooo00@0oooo00=000000000000000000P0000001@3oool00000@0000000
0000oooo0080000000<0oooo0000000000000P0000000d00000000000000000400000080oooo0P00
0000140000000000@000000000020?ooo`8000000P3oool00d000000000000000002000000@0oooo
1P000000103oool000000000000000020?ooo`030000003oool0oooo00@000001@3oool4000000@0
oooo00@000000?ooo`3oool0oooo1P0000000`3oool000000000000200000080oooo100000000d00
0000oooo0?ooo`040?ooo`<000003P3oool000/0oooo100000030?ooo`030000003oool0oooo00L0
000000<0oooo0000040000000P0000000`3oool000000?ooo`020?ooo`050000003oool0oooo0?oo
o`0000000P3oool7000000<0oooo00E000000?ooo`3oool0oooo000000020?ooo`L000000P3oool9
00000080oooo2`0000030?ooo`030000003oool00000008000000`3oool01D000000oooo0?ooo`3o
ool0000000<0oooo00A000000?ooo`3oool0oooo0P0000020?ooo`030000003oool0oooo00L00000
0P3oool01@000000oooo0?ooo`3ooom0000000<0oooo00=0000000000000000020000000103oool0
00000000000000020?ooo`060000003oool0oooo0?oood000000oooo2`0000020?ooo`03@0000000
0000000000L000000`3oool00`000000oooo00000007000000<0oooo00<000000?ooo`0000000P00
00030?ooo`030000003oool0000000L000000P3oool00`000000oooo0?ooo`06000000<0oooo00D0
00000?oood000000oooo000000030?ooo`030000003oool0oooo0080000000A00000000000000000
oooo3@0000030?ooo`80000000@0oooo00000000000000003P3oool000T0oooo100000080?ooo`04
@0000000000000000?ooo`80000000=000000?ooo`0000000P00000014000000oooo0?ooo`3oool3
000000H0oooo00=000000000000000003P3oool01400000000000000003oool200000003@000003o
ool0oooo00<0oooo00<00000@00000000000100000001@3oool00000000000000000oooo00900000
1P0000020?ooo`@000001`3oool3000000L0oooo100000030?ooo`80000000@0oooo000000000000
00002P3oool01400000000000000000000030?ooo`@0000000@0oooo00000000000000001`3oool6
00000080oooo0`0000030?ooo`P000001P3oool7000001<0oooo100000020?ooo`040000003oool0
oooo@000008000001P3oool200000080oooo00@000000?ooo`3oool0oooo0P0000000`3oool00000
0000000200000006@0000000000000000?ooo`00001000001@0000000`3oool00000@00000020000
00<0oooo100000000d000000oooo0?ooo`0<0?ooo`002@3oool600000080oooo0P0000060?ooo`05
@0000000000000000?oood0000000`0000000`3oool0000000000002000000/0oooo00=000000000
00000000100000001D000000oooo0?ooo`000010000000H0oooo00<00000@000003oool00P000000
0d000000oooo0?ooo`0500000080oooo0`0000030?ooo`<0000000=000000000000000001@000003
0?ooo`8000000`3oool0140000000000000004000003000000@0oooo0`0000000d000000oooo@000
0002000000D0oooo0`0000000d000000oooo0?ooo`040?ooo`D0000000=000000?ooo`3oool00`3o
ool20000009000000`0000030?ooo`80000000D0oooo00000000000000000?ooo`03000000L0oooo
100000020?ooo`03@00000000000oooo0080oooo0P0000000`3ooom0000000000002000001@0oooo
0P00000014000000oooo0000000000030?ooo`030000003oool0oooo00@0oooo0`0000020?ooo`80
000000@0oooo00000000000000001P3oool2000000<0oooo1@0000000`3ooom00000000000030000
00<0oooo0`0000000d000000oooo0?ooo`0<0?ooo`002P3oool2000000030?ooo`000000000000H0
0000103oool3000000030?ooo`0000000000008000000P3oool3000000/0oooo300000040?ooo`T0
000000E000000000000000000000@000000800000080oooo00=000000000000000001`000000103o
ool000000?ooo`3oool3000000<0oooo1@0000040?ooo`P00000103oool500000004@00000000000
0000000000<0oooo00=000000000000000000P0000040?ooo`P000000P3oool2000000040?oood00
0000000000000080oooo0P0000001D00000000000?ooo`3ooom0000000H000000`3oool600000003
@000003oool0000000@00000203oool00`000000oooo0?ooo`070?ooo`@0000000D0oooo00000000
000000000?ooo`0300000080oooo00<000000?ooo`3oool00`0000001@3oool00000000000000000
oooo00<000001P3oool300000080oooo100000020?ooo`H000000P3oool4000000h0oooo000:0?oo
o`03@000003oool0oooo00X000000P3oool3000000040?ooo`000000000000000080oooo00D00000
0?oood000000oooo@00000030?ooo`03@000003oool0oooo0080oooo00<000000?ooo`3oool03000
00000`3oool000000000000300000003@00000000000000000H0000000<0oooo0000000000002@00
0000103oool000000000000000020?ooo`0600000400000000000000003oool000000P3oool40000
0004@00000000000oooo0?ooo`<000000P3oool:00000080oooo2`0000000`3oool0000000000005
00000080oooo100000000d00000000000?ooo`0300000080oooo00<000000?ooo`3oool00`000002
0?ooo`030000003oool000000080000000<0oooo0000000000000P0000000`3oool0000000000003
0?ooo`<0000000<0oooo0000003oool00`0000030?ooo`8000000P3oool600000003@000003oool0
000000X0000000<0oooo0000000000001@0000020?ooo`80000000<0oooo0000040000001`000000
1400000000000000003oool2000000030?ooo`0000000000008000000P3oool500000080oooo1P00
00020?ooo`<000003P3oool000d0oooo00E00000000000000000oooo@0000002000000H0oooo0`00
00000`3oool00000000000020?ooo`030000003oool0oooo00X0oooo0P000000103oool000000000
00000002@00000<0000000A000000000000000000000103oool7000000050?ooo`00000000000000
003oool0100000000d0000000000000000050?ooo`<00000103oool4000000030?ooo`000000oooo
00<0000000@0oooo0000003oool0oooo0`0000030?ooo`D0000000@0oooo00000000000000001@3o
ool00d000000000000000004000000<0oooo1P0000050?ooo`<0000000@0oooo0000000000000000
1@3oool3000000<0oooo100000020?ooo`<000001P3oool300000080oooo1@0000070?ooo`H00000
0P3oool6000000050?ooo`00001000000000003oool01`0000020?ooo`80000000D0oooo00000000
00000000@000000300000005@0000000000000000000040000000P3oool500000003@000003oool0
oooo00@000000`3oool3000000D0oooo0P0000000d000000oooo0?ooo`0<0?ooo`006P3oool00`00
0000oooo0000000300000080oooo0P0000000`3oool00000000000080?ooo`80000000<0oooo0000
000000000`3oool8000000L0oooo0P0000030?ooo`040000003oool0oooo@00000D000001`3oool2
000000D0oooo0`0000000`3oool000000000000500000080oooo0P0000050?ooo`<000000`3oool0
0`000000oooo0?ooo`090?ooo`80000000=000000?ooo`3oool00P0000040?ooo`80000000<0oooo
0000000000000`0000000`3oool00000000000050?ooo`@000000`3oool2000000040?ooo`000000
oooo0?ooo`8000001`3oool2000000<0oooo1@0000000`3oool00000000000060?ooo`<000001@3o
ool300000080oooo0P0000040?ooo`D000000P3oool00`0000100000000000040?ooo`<000001@3o
ool2000000030?ooo`000000000000800000103oool300000003@000003oool0oooo0080000000=0
00000?ooo`3oool0103oool00`000000oooo0?ooo`0=0?ooo`006P3oool00`000000oooo00000003
000000050?ooo`00000000000000003oool01@0000060?ooo`80000000<0oooo0000003oool00`3o
ool300000080oooo0P0000030?ooo`04@0000000000000000?ooo`8000000P3oool2000000030?oo
o`000000oooo00P00000103oool2000000030?oood00000000000080000000D0oooo000000000000
00000?ooo`03000000040?ooo`000000000000000080oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`02000000H0oooo00=000000000000000000`0000000d0000000000@00000030000
0003@00000000000000000D0000000A0000000000000000000000P3oool00`000000oooo@0000007
00000080oooo0P0000001P3ooom00000000000000000oooo@000008000000`3oool0240000000000
00000000001000000000003ooom000000P0000000`3oool0000000000006000000@0oooo0`000002
0?ooo`040000003oool0oooo0?ooo`H0000000<0oooo@000000000002P000000103oool000000?oo
o`3oool300000080oooo00<000000?ooo`3oool0100000001400000000000000000000040?ooo`03
@00000000000000000D000001@3oool3000000h0oooo000>0?ooo`05@000003oool0oooo0?ooo`00
00000`3oool01@000000oooo0?ooo`3oool000000080oooo1@0000000d0000000000000000070000
00<0oooo0`0000000d00000000000?ooo`020?ooo`<0000000<0oooo0000003oool00P3oool00`00
0000oooo0?ooo`0300000080oooo00D00000@000000000000000@0000002000000030?ooo`000000
000000P000000P3oool2000000030?ooo`000000000000H0000000D0oooo0000000000000000@000
000300000080oooo00D000000?ooo`3oool0oooo@00000030?ooo`03000004000000000000800000
0`3oool00d000000oooo0?ooo`0H00000080oooo00<000000?ooo`000000100000000`3oool00000
0?ooo`020?ooo`030000003oool0oooo00L000000P3oool00d000000000000000008000000030?oo
o`000000000000P0000000<0oooo0000000000000P0000020?ooo`040000003oool0oooo@00000D0
00000P3oool3000000030?ooo`000000000000<0000000A0000000000000001000000P0000000`3o
ool0000000000002000000040?ooo`000000oooo0?ooo`P000000P3oool:00000080oooo00<00000
0?ooo`3oool00`00000>0?ooo`004P3oool00`000000oooo0?ooo`020?ooo`800000103oool30000
0004@0000000000000000000009000000P0000070?ooo`L0000000A000000000000000000000203o
ool3000000@0oooo0P0000001@3oool00000000000000010000000D000002P3oool600000003@000
003oool0oooo00D0000000=000000?ooo`3oool01`3oool2000000030?ooo`000000000000L0oooo
0`0000000`3oool000000000000500000080oooo00=0000000000000000010000000103oool00000
0000000000050?ooo`04@000000000000000000000P0oooo1`0000030?ooo`H0000000<0oooo0000
000000000P3oool0140000000000000004000002000000D0oooo0`0000000d000000oooo0?ooo`05
00000080oooo0P0000020?ooo`<0000000D0oooo00000000000000000?ooo`0300000080oooo0P00
00001P3oool0000000000000001000000?ooo`80000000<0oooo@000000000001@00000014000000
oooo0?ooo`3oool;000000<0oooo0P0000000d000000oooo0?ooo`0<0?ooo`004P3oool00`000000
oooo0?ooo`030?ooo`<000005@3oool;000000P0oooo00<000000?ooo`3oool0103oool200000004
0?ooo`00000000000?ooo`@000002`3oool2000000@0oooo0P0000000`3oool000000?ooo`020?oo
o`800000203oool300000080oooo0P0000070?ooo`8000000P3oool3000000030?ooo`0000000000
0080oooo1P0000020?ooo`8000001P3oool5000000P0oooo00<000000?ooo`0000000P0000030?oo
o`<0000000D0oooo00000000000000000?ooo`0200000080oooo0P00000:0?ooo`8000000P3oool:
000000<0oooo00<000000?ooo`3oool01@0000050?ooo`@000000P3oool3000000<0oooo10000000
0d000000oooo0?ooo`030?ooo`<000000`3oool4000000@0oooo00<000000?ooo`3oool03@3oool0
0140oooo0`0000000`3ooom000000000000400000003@000003oool0oooo00L0oooo00=000000000
000000001@0000001D0000000000000000000010000000<0000000E000000000003oool0oooo@000
0003000000D0oooo0`0000050?ooo`80000000@0oooo00000000000000000P3oool2000000X0oooo
100000040?ooo`<000000`3oool2000000<0oooo00<000000?ooo`0000000`000000140000000000
0000003oool2000000@0oooo00=000000000040000000`0000000`3oool00000000000020?ooo`03
00000400000000000080oooo00<000000?ooo`0000000P0000030?ooo`030000003oool0oooo00<0
oooo00=000000000000000000d000002000000@0oooo00=000000?oood000000100000020?ooo`03
@0000000000000000080oooo0P0000000`3ooom00000000000030?ooo`<00000103oool400000005
0?ooo`00000000000000003oool00`0000001400000000000000003oool300000080oooo0`000000
0`3ooom0000000000004000000<0oooo1P0000001P3oool00000000000000000oooo@00000H00000
1@3oool4000000030?ooo`000000000000800000103oool3000000h0oooo000>0?ooo`03@000003o
ool0oooo00/000000P3oool01T000000oooo0?ooo`3ooom000000?oooa@0000000<0oooo00000000
00000P0000020?ooo`030000003oool0oooo00<000000P3oool00`000000oooo0?ooo`0400000003
0?ooo`00000000000080oooo0P0000020?ooo`06@000003oool0oooo0?ooo`000000oooo1@000000
0`3ooom000000000000500000006@000003oool00000000004000000oooo2P0000020?ooo`040000
003oool0oooo0?ooo`L0000000<0oooo0000003oool00P3oool6000000<0oooo00D000000?ooo`3o
ool0oooo@00000030?ooo`X000000P3oool00`000000oooo00000006000000040?ooo`0000000000
000000<0oooo00<000000?ooo`0000000P0000030?ooo`H0000000=000000000000000001P000000
0`3oool000000000000=000000030?ooo`000000000000D000000P3oool6000000030?ooo`000000
000000T000000`3oool00d000000oooo0000000:00000080oooo0`00000>0?ooo`004@3oool00d00
0000000000000004000000040?ooo`0000000000000000P0oooo10000000103ooom0000000000000
00020?ooo`@0000000<0oooo0000000000000`0000020?ooo`<000000P3oool00`000000oooo0?oo
o`0200000005@0000000000000000?oood0000000P0000000d000000000000000004000000040?oo
o`0000000000000000H0oooo00=000000000000000000P00000014000000oooo0?ooo`3oool50000
0080oooo00@000000?ooo`3ooom000000`0000000d000000000000000004000000L0oooo1P000006
0?ooo`<00000203oool2000000@0oooo2@0000030?ooo`H000000`3oool4000000@0oooo10000002
0?ooo`L0000000A00000000000000000oooo0`0000000d000000oooo00000006000000030?ooo`00
0000000000@0000000=000000?ooo`0000000P0000060?ooo`H0000000D0oooo0000000000000000
@0000006000000H0oooo00=000000000000000000P3oool00d0000000000000000050?ooo`800000
00=000000?ooo`3oool0303oool00180oooo1@00000<0?ooo`@000001`3oool200000080oooo1@00
00030?ooo`8000000`3oool010000000oooo0?ooo`3oool400000080oooo1P0000001D0000000000
000000000010000000<000001@3oool4000000H0oooo0P0000000d00000000000?ooo`0200000080
oooo1@0000040?ooo`030000003oool0oooo00D0oooo0`0000000`3oool00000000000060?ooo`<0
00001`3oool5000000<0oooo0`0000001@3oool000000000003oool0000000@0oooo1P0000020?oo
o`@00000103oool4000000H0oooo1000000;0?ooo`D00000103oool400000080oooo0P0000070?oo
o`80000000<0oooo0000000000000P3oool200000080oooo0`00000F0?ooo`030000003oool0oooo
00d0oooo000A0?ooo`D000003@3oool2000000@0oooo00A0000000000000000000000P3oool00`00
0000oooo0?ooo`0300000005@0000000000000000000040000000`0000001P3oool0000000000000
0000oooo@00000<0000000A00000000000000000oooo0P0000000d0000000000@000000500000003
0?ooo`000010000000@000000P3oool300000003@000003oool0oooo0080oooo100000020?ooo`<0
000000<0oooo000000000000100000001400000000000?ooo`0000020?ooo`050000003oool0oooo
0?oood0000000`000000303oool000000?ooo`3ooom000000?oood00000000000?ooo`0000100000
000000D0oooo0P000002@00000<0000000A0000000000000000000000P3oool3000000030?ooo`00
0000oooo0080oooo1`0000020?ooo`8000000P3oool00d0000000000@0000003000000T0oooo00<0
0000@000000000002P3oool2000000040?ooo`0000000000000000D0oooo00E00000000000000000
oooo@0000002000000D0oooo0P0000001400000000000000003oool200000080oooo0P000000103o
oom000000000003oool4000000T0oooo0`0000001@3oool00000000004000000oooo00<0000000@0
oooo00000000001000002P3oool000h0oooo00=000000?ooo`3oool00`0000020?ooo`050000003o
ool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00=000000?ooo`3o
ool01@0000000`3oool000000?ooo`0<000000030?ooo`000000000000P0000000=0000000000000
00000P0000000`3oool0000000000002000000040?ooo`00000000000?ooo`H0000000<0oooo0000
000000000P0000020?oooa40000000=000000000000000000P0000000d0000000000000000070000
00030?ooo`000000oooo01T000000P3oool3000000030?ooo`00000000000080oooo00<000000?oo
o`000000100000000`3oool000000?ooo`09000000030?ooo`00000000000080oooo00<000000?oo
o`3oool0100000000`3oool0000000000004000000<0oooo00<000000?ooo`3oool0100000000`3o
ool0000000000004000000030?ooo`00000000000080000000<0oooo0000000000000`0000000d00
000000000000000300000008@000000000000000000004000000oooo0000003oool7000000<0oooo
00=000000?ooo`3oool01`0000000`3oool0000000000005000000X0oooo000A0?ooo`80000000=0
00000?ooo`3oool0103oool2000000030?ooo`000000000000X0oooo00<00000@000000000002000
00000d000000oooo00000002000000050?ooo`00000000000000003oool00P0000000d0000000000
00000002000000030?ooo`000000000000D0000000<0oooo0000040000000`0000030?ooo`800000
00=00000000000000000100000000`3oool000000?ooo`040?ooo`@0000000=00000000000000000
100000000d000000oooo0000000400000080oooo0P0000030?ooo`<00000103oool500000080oooo
0P0000040?ooo`P0000000@0oooo00000000000000000P3oool00d000000000000000004000000@0
oooo00<00000@000000000001P0000000`3oool000000000000300000080oooo0P0000020?ooo`03
0000003oool0oooo00T00000203oool4000000@0oooo0`0000001@3oool000000000000000100000
00@0oooo200000000`3oool00000000000020?ooo`040000003oool0oooo@000008000002P3oool0
1400000000000000003oool3000000050?ooo`0000000000@000003oool00`00000:0?ooo`006P3o
ool5000000/0oooo200000040?ooo`<0000000<0oooo0000000000000P3oool700000080oooo00<0
00000?ooo`3oool00P0000030?ooo`@00000103oool400000004@000000000000000000000L0oooo
00@000000?ooo`0000000000103oool300000003@00000000000000000<00000103oool2000000<0
oooo0P0000030?ooo`H0000000@0oooo00000000000000001P3oool500000080oooo0P0000040?oo
o`80000000A0000000000000000000001P3oool500000080oooo0`000000103oool000000000003o
ool2000000<0oooo0P0000020?ooo`@0000000=000000000003oool02`3oool3000000@0oooo00D0
00000?ooo`3oool0oooo000000070?ooo`80000000<0oooo0000000000001@0000020?ooo`D00000
903oool00140oooo00=000000000000000000`3oool01400000000000?ooo`3oool3000000<0oooo
00A0000000000000000000001@3oool300000003@00000000000000000<00000103oool300000003
0?ooo`000000oooo00<0000000=000000000003oool01@0000020?ooo`8000000P3oool00d000000
000000000003000000<0oooo00<000000?ooo`3oool01P0000020?ooo`05@0000000000000000000
003oool00P0000050?ooo`P000001@3oool2000000<0oooo00<000000?ooo`3oool00P3oool20000
00030?ooo`00000000000080oooo0P0000000`3ooom000000?ooo`030?ooo`<000000P3oool01P00
0000oooo@000003oool000000?ooo`8000000P3oool6000000H0oooo0`0000030?ooo`80000000A0
00000?ooo`000000oooo0`0000020?ooo`<0000000<0oooo@000000000001@0000000d000000oooo
00000002000000<0oooo00=00000000000000000100000000d000000oooo0?ooo`0300000080oooo
00<000000?ooo`3oool0103oool3000000030?ooo`000000000000D0000000<0oooo000000000000
100000020?ooo`@0000000A0000000000000000000001@3oool200000003@000003oool0oooo00<0
oooo0P0000000d000000oooo0?ooo`080?ooo`00303oool3000000030?ooo`000000000000d00000
0P3oool700000080oooo00D000000?ooo`0000000000@0000005000000<0oooo0`0000000d000000
00000?ooo`0?00000080oooo100000000`3oool000000?ooo`020?ooo`030000003oool0oooo00@0
000000@0oooo000000000000oooo100000000`3oool0000000000002000000030?ooo`0000000000
00/000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo0000
00030?ooo`030000003oool0000000P0000000@0oooo@00000000000oooo0P0000001D0000000000
000000000010000000<0oooo00<000000?ooo`3oool00P0000030?ooo`0300000400000000000080
00000`3oool:000000030?ooo`000000000000X0000000<0oooo000000000000300000000`3oool0
00000000000200000080oooo00D000000?ooo`3oool0oooo000000020?ooo`@0000000<0oooo0000
003oool01@0000000d000000000000000004000000030?ooo`000000000000H000000P3oool40000
0004@00000000000oooo0?ooo`H000002P3oool000T0oooo1@0000020?ooo`@000000`3oool30000
00030?ooo`0000000000008000000P3oool3000000P0oooo00<000000?ooo`3oool01`3oool01400
000000000000000000020?ooo`80000000I0000000000000000000000?oood00000300000004@000
000000000000000000<0oooo00<00000@000000000000P0000000`3oool000000?ooo`020?ooo`03
@0000000000000000080000000=000000?ooo`3oool00`3oool300000080oooo0`00000014000000
oooo0?ooo`3oool3000000040?oood0000000000000001P0oooo10000000103oool0000000000400
000<000000@0oooo00A000000000000000100000103oool4000000<0oooo1@0000000`3oool00000
@000000600000003@00000000000000000H0000000D0oooo@0000000000000000?ooo`07000000<0
oooo100000000d000000oooo0?ooo`040?ooo`80000000D0oooo0000000000000000@00000030?oo
o`D000000P3oool200000005@000003oool0oooo0?oood0000001`0000050?ooo`<000001@3oool3
000000X0oooo00090?ooo`@000000P3oool4000000<0oooo100000020?ooo`<000000`3oool20000
01<0oooo100000040?ooo`<000000P3oool3000000030?ooo`0000000000008000000`3oool80000
0080oooo0`0000070?ooo`80000000<0oooo0000003oool00`00000I0?ooo`8000001`3oool40000
0080oooo2P0000000`3oool0000000000002000000D0oooo0`0000050?ooo`<0000000=000000?oo
o`3oool0100000030?ooo`03@00000000000000000800000103oool2000000<0oooo0P0000020?oo
o`80000000D0oooo00000000000000000?ooo`02000000<0oooo00A000000000000000000000203o
ool200000080oooo0P0000070?ooo`D00000203oool4000001/0oooo000:0?ooo`80000000<0oooo
0000000000000P0000040?ooo`04@000000000000000000000<0oooo0P0000040?ooo`040000003o
ool0oooo@00000<00000103oool01D0000000000000000000010000000<00000103oool2000000@0
oooo0P0000040?ooo`<0000000@0oooo@0000000000000000P3oool01D0000000000000000000010
000000D000000P3oool00d000000000000000002000000<0oooo0`0000020?ooo`030000003oool0
000001T0oooo1@0000050?ooo`8000000P3oool:00000080oooo0P0000001D000000000000000000
0000oooo00L000001@3oool01400000000000000003oool5000000<0oooo1P0000040?ooo`030000
003oool0oooo0080oooo1P00000014000000oooo0?ooo`3oool2000000040?oood000000oooo0?oo
o`<00000203oool300000004@000000000000000000000L0oooo00<00000@000000000000P000000
1@3oool00000000004000000oooo0080000000A0000000000000000000006`3oool000X0oooo00=0
00000?ooo`3oool01P0000020?ooo`X000000`3oool00`000000oooo0?ooo`04000000030?ooo`00
0000000000T000000P3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0
oooo@0000004000000040?ooo`000000000000000080oooo100000000`3oool000000?ooo`040000
00030?ooo`000000000000D0000000@0oooo00000000000000000P3oool3000000030?ooo`000000
000000@000000P3oool200000080oooo1P0000020?ooo`@0000000=0000000000000000010000002
0?ooo`040000003oool0oooo0?ooo`<0000000<0oooo000000000000100000030?ooo`030000003o
ool000000080000000=000000000000000001@0000030?ooo`030000003oool0oooo00<0000000<0
oooo@000000000001@0000000`3oool0000000000002000000030?ooo`000000000000<0oooo00<0
00000?ooo`3oool02P0000030?ooo`030000003oool0000000<0000000<0oooo0000000000000`3o
ool010000000oooo0?ooo`3oool7000000030?ooo`00000000000080oooo4P0000030?ooo`05@000
003oool0oooo0?oood0000000`3oool00d000000oooo0?ooo`0=0?ooo`003@3oool0140000000000
0000000000040?ooo`<00000103oool2000000L0oooo0`0000050?ooo`@0000000@0oooo00000000
000000000P3oool2000000H0oooo00E000000?ooo`3oool0oooo@000000400000080oooo0P000002
0?ooo`<000002@3oool200000005@0000000000000000000003oool00`00000014000000oooo0?oo
o`3oool8000000050?ooo`00000000000000003oool01`0000030?ooo`H000003`3oool00d000000
000000000003000000H0oooo1P0000030?ooo`040000003oool0oooo0?ooo`H000002@3oool40000
00T0oooo100000000d0000000000000000070?ooo`L0000000E000000?ooo`3oool0oooo00000003
0?ooo`80000000D0oooo0000000000000000@000000200000080oooo0P0000020?ooo`P0000000<0
oooo0000000000000P00000M0?ooo`003P3oool4000000@0oooo00<000000?ooo`3oool00P3oool3
000000P0oooo0P0000060?ooo`8000000P3oool2000000<0oooo0P0000050?ooo`800000103oool3
000000<0oooo0P0000030?ooo`8000002P3oool5000000P0oooo1P0000000`3oool0000000000006
000000040?ooo`000000000000000080oooo1P00000B0?ooo`@000001`3oool2000000040?ooo`00
00000000000000P0oooo100000070?ooo`04000004000000oooo0?ooo`D000001`3oool00d000000
000000000004000000L0oooo0`0000000`3oool0000000000002000000<0oooo00@000000?ooo`3o
ool0oooo0P0000020?ooo`T000000`3oool2000000H0oooo0P00000O0?ooo`003P3oool4000000<0
oooo00=000000000000000000P3oool3000000D0oooo0P000002@00000<000001P3oool01@000000
oooo0?ooo`3oool0000000@0oooo0P0000020?ooo`H000000`3oool300000080oooo0P0000030?oo
o`040000003oool0oooo@00000@00000103oool00`000000oooo0?ooo`03000000<0oooo00@00000
0?ooo`3oool0oooo1P0000000`3oool0000000000005000000030?ooo`000000000000T0000000<0
oooo@000000000000P0000040?ooo`@000001@3oool5000000H0oooo00=000000000000000001000
00060?ooo`80000000A0000000000000000000000P3oool00d00000000000000000400000080oooo
00=000000000000000000P0000000d000000oooo0?ooo`080?ooo`<00000103oool010000000oooo
0000000000050?ooo`040000003oool0oooo0?ooo`80000000=000000?ooo`0000000P0000000`3o
ool0000000000007000000D0oooo00<000000?oood0000000`0000000`3oool00000000000050000
00040?ooo`0000000000@00000D0oooo00A00000000000000000oooo0P0000000d000000oooo0?oo
o`080?ooo`003P3oool01@000000oooo0?ooo`3oool000000080oooo0`0000020?ooo`04@0000000
000000000?ooo`@0000000=00000000000000000100000000`3oool000000?ooo`030?ooo`050000
003oool0oooo0?ooo`0000000`3oool30000009000000`0000001D00000000000000003ooom00000
0080oooo1P0000030?ooo`030000003oool0oooo00L000000P3oool00`000000oooo0?ooo`020?oo
o`050000003oool0oooo0?ooo`0000000`3oool?00000003@00000000010000001P000000P3oool2
000000<0oooo00@000000?ooo`3oool0oooo2@0000030?ooo`T000000P3oool700000080oooo1P00
0000103oool000000000000000030?ooo`030000003oool0oooo00P0000000<0oooo0000003oool0
0P3oool300000003@00000000000000000@0000000<0oooo000000000000300000001P3oool00000
0?ooo`3oool000000?oooa0000000P3oool00d000000oooo0?ooo`07000000X0oooo000E0?ooo`<0
00000`3oool00d000000oooo0?ooo`020?ooo`P000000`3oool2000000X0oooo0P0000030?ooo`<0
000000I0000000000000000000000?oood00000200000003@00000000000000000800000103oool4
00000003@00000000000000000@00000203oool200000080oooo0P0000000`3ooom000000000000;
000000<0oooo5P00000=0?ooo`05@000003oool00000000004000000100000050?ooo`D00000103o
ool5000000D0oooo200000040?ooo`80000000<0oooo0000000000000P0000000`3ooom000000000
0002000000D0oooo100000000d00000000000000000600000006@000000000000000000004000000
oooo4P0000000d000000000000000006000000D0oooo1`00000:0?ooo`005P3oool00`000000oooo
0?ooo`0:0?ooo`80000000<0oooo0000000000000`3oool4000000P0oooo0P0000040?ooo`H00000
0P3ooolC000000050?ooo`00000000000000040000001P3oool3000000070?ooo`00000000000000
003ooom00000000000020?ooo`06@00000000000oooo0?oood00000000001P3oool200000080oooo
00E000000000003oool0oooo@000000200000080oooo00E000000000003ooom000000000000>0?oo
o`X00000203oool4000000<0oooo00=00000000000000000203oool5000000H0oooo0P0000000`3o
oom00000000000040?ooo`<000001@3oool500000080oooo1`0000050?ooo`05@000000000000000
000004000000300000020?ooo`03@00000000000oooo00<0oooo0P0000060?ooo`040000003oool0
oooo0?ooo`8000002P3oool001H0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`06
00000003@000003oool0oooo00H0oooo0P0000040?ooo`80000000A0000000000000000000000P3o
ool2000000040?ooo`0000000000@00000H0000000@0oooo0000003oool0oooo0P0000020?ooo`<0
00000`3oool00`000000oooo00000007000000030?ooo`00000000000080oooo0`000000103oool0
00000000000000020?ooo`03@00000000000oooo0080000000<0oooo@000003oool0103oool00`00
0000oooo0?ooo`0400000004@000000000000000000000X0oooo100000000d0000000000@0000005
000000<0oooo00<000000?ooo`3oool00P3oool01D0000000000000000000010000000<0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`030000003oool000000080oooo00=000000?ooo`3oool0
0P3oool010000000oooo0?ooo`3oool6000000@0oooo0P0000050?ooo`80000000=0000000000000
0000103oool5000000@0oooo2`0000020?ooo`L000003P3oool00`000000oooo0?ooo`0=0?ooo`00
3P3oool01D00000000000?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo@00000030?oo
o`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`07000000<0oooo00@00000
0?ooo`3oool0oooo0`000002@00000<0oooo00<00000@000000000000P0000000d00000000000000
0002000000030?oood000000000000D000000P3oool00`00001000000000000300000080oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0000000200000003@00000000000000000l0000000=0
00000000000000000`000000103oool000000000000000030?ooo`040000003oool0oooo@00000X0
00000`3oool00`000000oooo0?ooo`0:00000004@000000000000000000000<0oooo0P0000020?oo
o`D000000`3oool010000000oooo0?ooo`3oool6000000060?ooo`00000000000000003ooom00000
3P0000020?ooo`8000000`3oool2000000030?ooo`000000000000@000000P3oool600000003@000
00000000000000<0000000D0oooo00000000000000000?ooo`02000000<0oooo2@0000030?ooo`05
@000003oool0oooo0?oood0000000`3oool00`000000oooo0?ooo`0=0?ooo`003P3oool300000003
0?ooo`000000oooo0080oooo00<000000?ooo`3oool0103oool2000000<0oooo00<000000?ooo`3o
ool0103oool5000000D0oooo00@000000?ooo`3oool0oooo0P0000070?ooo`@0000000<0oooo0000
000000000P0000020?ooo`<0000000<0oooo0000003oool0103oool4000000<0oooo0P0000000`3o
ool00000000000030?ooo`8000000`3oool400000004@000000000000000@00000<0000000=00000
000000000000100000020?ooo`@000000P3oool=000000@0oooo0P0000070?ooo`T000000`3oool7
000000030?ooo`000000000000H0oooo00=000000000000000001P0000020?ooo`H0000000=00000
0000000000001P00000014000000oooo@000000000060?ooo`D00000103oool:00000003@000003o
ool0oooo0080000000=000000?ooo`3oool0103oool00d000000000000000003000001d0oooo000=
0?ooo`06@0000000000000000000003oool000000P3oool4000000<0oooo0`0000030?ooo`800000
1@3oool00d00000000000?ooo`060?ooo`8000000P3oool2000000L0oooo1@000000103oool00000
0000000000030?ooo`03@00000000000000000@00000103oool2000000@0oooo1@0000030?ooo`80
0000103oool4000000050?ooo`00000000000000003oool0200000020?ooo`D0000000<0oooo0000
000000001@000000103ooom000000000000000040?ooo`<00000203oool8000000D0oooo0`000000
0d00000000000000000:0?ooo`L00000103oool:000000030?ooo`000000000000D000001P3oool4
000000P0oooo00<00000@000000000000P0000050?ooo`030000003oool0oooo00L0oooo00=00000
0000000000007`3oool000l0oooo100000020?ooo`03@000000000000000008000000P3oool30000
0080oooo0`00000>0?ooo`8000000P3oool2000000L0oooo0P0000000`3oool00000000000020?oo
o`8000000`3oool300000003@00000000000000000<000000P3oool3000000@0oooo1@0000020?oo
o`<000000`3oool01D0000000000000000000010000000H0000000=000000000000000000P000003
0?ooo`D0000000=000000000000000000`0000030?ooo`X000000`3oool00`000000oooo0?ooo`02
0?ooo`80000000<0oooo0000000000000P3oool2000000<0oooo100000000`3oool000000000000:
0?ooo`D000001P3oool00d00000000000000000600000004@000003oool0oooo0?ooo`H000001@3o
ool200000003@00000000000000000H0oooo1P0000070?ooo`04@000000000000000000000@0oooo
2000000J0?ooo`003P3oool00`000000oooo0?ooo`0300000080oooo00=000000?ooo`0000001@00
00000d000000oooo0?ooo`06000000<0oooo0`0000020?ooo`03@000003oool0oooo00<0000000@0
oooo00000400000000000P3oool200000080oooo00<000000?ooo`0000000P000000103oool00000
0000000000030?ooo`030000003oool000000080000000<0oooo0000000000000P0000020?ooo`80
00000P3oool700000080oooo0`0000000`3ooom000000?ooo`0=000000050?ooo`00000000000?oo
od0000000P0000000`3ooom000000000000500000080oooo00=000000?ooo`3oool02`0000001400
000000000000000000030?ooo`0300000400000000000080000000A0000000000000000000000P3o
ool00`00001000000000000500000005@0000000000000000000003oool00P0000000`3oool00000
0000000500000080oooo3P0000030?ooo`H000000P3oool:00000080oooo2@0000030?ooo`03@000
003oool0oooo00@000000P3oool00d00000000000000000:000000<0oooo00E000000?ooo`3oool0
oooo0000000?0?ooo`00303oool2000000<0oooo0`0000080?ooo`8000000`3oool4000000@0oooo
1@0000000`3oool000000000000800000080oooo0`0000001P3ooom00000000000000000oooo@000
0080000000<0oooo0000000000000P3oool010000000oooo0?ooo`3oool4000000D0oooo00<00000
0?ooo`3oool00P0000000`3oool0000000000003000000050?ooo`00000000000000040000000`3o
ool7000000<0oooo100000001@3oool00000000000000000oooo00P000001@3oool>000000@0oooo
00<000000?ooo`0000000P000000103oool000000000000000030?oooa@0000000=000000000003o
ool00`3oool5000000@0oooo00<000000?ooo`0000000P3oool5000000H0oooo1@0000001@3oool0
0000000000000000oooo00@0000000=000000000000000000P0000070?ooo`<000000P3oool;0000
00T0oooo00<000000?ooo`3oool03@3oool000X0oooo100000030?ooo`80000000=000000?ooo`3o
ool01`3oool01D000000oooo0?ooo`3ooom000000080000000=000000?ooo`3oool00`0000000d00
000000000000000700000007@000000000000000000004000000oooo@0000008000000030?ooo`00
0000000000@000001@3oool01400000000000000000000080?ooo`8000000P3oool01D0000000000
000000000000oooo008000001@3oool700000080oooo0`0000030?ooo`<0000000<0oooo00000000
00001P0000050?ooo`04@00000000000oooo0?ooo`@0000000@0oooo@00000000000oooo0P000006
0?ooo`8000000P3oool2000000D0oooo3P00000>0?ooo`8000002P3oool3000000T0oooo0P000002
0?ooo`05@0000000000000000?oood0000000P0000030?ooo`@0000000=000000?ooo`3oool00`3o
ool400000003@00000000000000000<000000T0000000`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo00d0oooo00090?ooo`@00000303oool3000000050?ooo`00000000000000003oool00`00
00000`3oool000000000000300000080oooo1@0000090?ooo`T000000P3oool00`00001000000000
0002000000H0oooo100000000d000000oooo0?ooo`030?ooo`<0000000<0oooo0000000000001000
00000`3oool00000000000040?ooo`80000000A000000?ooo`00000000000`3oool300000080oooo
0`0000000`3oool0000000000004000000@0oooo0P0000000d000000oooo0?ooo`02000000900000
1@0000030?ooo`<000001@3oool200000080oooo0P0000050?ooo`<0000000A000000?ooo`3ooom0
00001`0000030?ooo`H0000000=000000?ooo`3oool03@3oool500000003@000003oool0oooo00P0
oooo200000030?ooo`<0000000<0oooo@000000000000P000000103oool000000000040000020000
0004@000000000000000000000/0oooo00A00000000000000000oooo0P00000?0?ooo`002P3oool3
000000030?oood000000oooo0080oooo00E000000?ooo`3oool0oooo@00000020?ooo`/0000000<0
oooo0000000000001@0000000`3ooom000000000000500000080oooo0`0000000`3oool000000000
000400000080oooo0P0000020?ooo`H000000P3oool00d00000000000000000400000080oooo00<0
00000?ooo`3oool00`0000001P3oool0000000000000001000000?ooo`@0000000=0000000000400
0000100000020?ooo`040000003oool0oooo0?ooo`8000000P3oool200000080oooo0`0000000`3o
ool00000000000020?ooo`P0000000=000000000000000000P3oool00d0000000000000000020000
0080oooo1P0000020?ooo`<0000000<0oooo0000000000000P3oool700000004@000003oool00000
@000010000000P3oool200000080oooo0`0000020?ooo`040000003oool0oooo@00000H000000P3o
ool01@000000oooo0?oood000000000000<0oooo2@0000020?ooo`8000000P3oool;00000080oooo
0P0000030?ooo`040000003oool0oooo0?ooo`H0000000@0oooo00000400000000003P3oool000/0
oooo00=000000?ooo`3oool02`3ooolA00000080oooo1P0000000`3oool000000000000800000080
oooo00<00000@000000000000P0000020?ooo`<0000000@0oooo000000000000oooo0`0000000`3o
ool000000000000200000080oooo00<000000?ooo`0000000`0000030?ooo`030000003oool0oooo
0080oooo0P0000020?ooo`D000000P3oool01@000000oooo0?ooo`3oool0000000<0oooo00D00000
0?ooo`3oool0oooo000000030?ooo`030000003oool0oooo00<0oooo2@0000090?ooo`03@0000000
0000000000<000000`3oool3000000030?ooo`000000oooo00<0oooo200000030?ooo`D000000P3o
ool700000080oooo0P0000030?ooo`<0000000<0oooo0000000000000`3oool500000080oooo1@00
00030?ooo`<0000000A0000000000000000000000P3oool3000000<0oooo2P0000080?ooo`03@000
003oool0oooo00<0oooo10000000103oool0000000000000000>0?ooo`006@3oool0140000000000
0?ooo`3oool2@00000D000000T000002000000@0oooo100000000`3oool000000000000300000003
@00000000000000000<0000000=000000?ooo`3oool00P3oool3000000<0oooo0P0000040?ooo`@0
00000P3oool2000000030?ooo`00000000000080oooo100000000`3oool00000000000040?ooo`03
0000003oool0oooo00H000006P3oool2000000030?ooo`0000000000008000002@3oool00`000000
oooo0?ooo`050?ooo`04@000000000000000000000T0oooo1@0000030?ooo`05@00000000000oooo
0?ooo`0000000P3oool00d00000000000?ooo`020?ooo`8000000P3oool200000080oooo00=00000
000000000000100000060?ooo`80000000<0oooo0000000000001@0000020?ooo`@0000000=00000
000000000000100000050?ooo`8000000`3oool4000000L0oooo0P0000070?ooo`80000000@0oooo
00000000001000003P3oool001d0oooo00=000000000000000000P0000030?ooo`<000000`3oool4
000000<0oooo0`0000020?ooo`D000001P3oool2000000<0oooo00<000000?ooo`3oool00P3oool4
000000@0oooo00@00000@0000000000000000P3oool00d000000000000000004000000L0oooo0`00
000<0?ooo`8000003`3oool01000001000000?oood0000060000009000001`0000020?ooo`800000
0P3oool4000000P0oooo100000080?ooo`<000002P3oool200000080oooo100000000d0000000000
000000050?ooo`03000004000000oooo00H000001@3oool8000000D0oooo00E00000000000000000
0000@0000004000000L0oooo100000060?ooo`030000003oool0oooo0140oooo000B0?ooo`800000
203oool700000080oooo0`0000030?ooo`8000001P3oool2000000@0oooo1P0000020?ooo`<00000
0P3oool2000000050?ooo`000000oooo0?oood000000300000000`3oool000000000000700000080
oooo00I000000?ooo`00001000000000003oool2000000<0oooo00D00000@00000000000oooo0000
00020?ooo`<0000000=000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`03@0000000
0000000000h0000000=000000000000000001`0000020?ooo`8000000P3oool00d00000000000000
000D000000<0oooo00<000000?ooo`3oool02P000000103oool00000@000040000020?ooo`@00000
00<0oooo0000040000000P0000000`3oool000000?ooo`020?ooo`030000003oool0000000800000
00@0oooo00000000001000000`3oool00`000000oooo0?ooo`09000000030?ooo`000000oooo00<0
oooo1@0000060?ooo`050000003oool0oooo0?ooo`0000003`3oool000h0oooo00A000000?ooo`3o
ool0oooo0`0000000`3ooom000000?ooo`020?ooo`H000000P3oool01@000000oooo0?ooo`000010
00000080000000<0oooo0000003oool00`3oool00d000000oooo0?ooo`04000000030?oood000000
000000<0000000A00000000000000010000010000000140000000000000004000002000000030?oo
o`000000oooo00`0000000D0oooo00000000000000000?ooo`0?000000030?oood000000000000D0
00000P3oool00d00000000000000000300000080oooo00E000000000003oool0oooo@000000H0000
0003@00000000000000000@000000P3oool00`000000oooo0000000>00000003@000000000000000
00H000000P3oool00`000010000000000009000000030?ooo`000000000000P0000000@0oooo0000
0000000000000P3oool200000080oooo1@0000030?ooo`030000003oool0oooo008000000P3oool3
00000080oooo0`0000020?ooo`8000000P3oool600000080oooo00E000000?ooo`3oool0oooo0000
00030?ooo`8000003P3oool00140oooo00A000000000000000000000203oool3000000D0oooo0`00
00000d000000oooo0?ooo`060?ooo`0300000400000000000080000000<0oooo@000000000001P00
0000103oool000000000000000020?ooo`H000000P3oool4000000030?ooo`000000000000D00000
0P3oool2000000050?oood00000000000000040000000P3oool7000000030?ooo`00000000000080
000000@0oooo00000000000000000P3oool;000000040?ooo`00000000000?ooo`D0000000<0oooo
0000000000000P0000001D0000000000000000000010000000<000001P3oool200000080oooo00<0
00000?ooo`3oool0103oool3000000030?ooo`000000000000<0000000E000000000000000000000
0?ooo`04000000050?ooo`00000000000000040000000P3oool6000000030?ooo`00000000000080
00000`3oool400000080oooo0`000000103oool000000000040000030?ooo`8000000P3oool50000
00@0oooo0`0000030?ooo`8000000P3oool300000080oooo0P0000040?ooo`<0000000=000000?oo
o`3oool0203oool3000000d0oooo000=0?ooo`8000000`3oool300000003@00000000000000000H0
oooo0P0000090?ooo`8000001P3oool6000000040?ooo`0000000000000000<0oooo0P000000103o
ool000000000000000020?ooo`80000000<0oooo0000040000000P0000000`3ooom0000000000002
000000@0oooo10000000103oool000000000040000060?ooo`H000000P3oool8000000030?ooo`00
00000000014000000`3oool00`00001000000?ooo`060?ooo`D000000`3oool8000000@0oooo0P00
00030?ooo`8000000`3oool4000000040?ooo`000000000000000080oooo0`0000001@3oool00000
000000000000oooo00<000000`3oool300000080oooo0`0000030?ooo`8000000P3oool200000004
@000003oool0oooo0?ooo`<0000000<0oooo0000000000000`0000030?ooo`040000040000000000
000000<0oooo0P0000000d000000000000000002000000<0oooo00<00000@000000000000P000000
0`3oool00000000000060?ooo`03@0000000000000000080oooo00H00000@00000000000oooo0000
0400000:0?ooo`003@3oool400000080oooo1@0000030?ooo`060000003oool0oooo0000003oool0
0000203oool500000080oooo100000000`3oool00000000000020?ooo`<000000P3oool200000004
@00000000000000000000080oooo0P0000020?ooo`<0000000<0oooo0000000000000P000000103o
ool000000?ooo`3oool300000004@000003oool000000?ooo`800000103oool200000080oooo0P00
00030?ooo`<0000000<0oooo000000000000200000020?ooo`L0000000<0oooo0000000000000`3o
ool400000080oooo0P0000000d00000000000000000800000005@000000000000000000004000000
1@0000030?ooo`040000003oool0oooo0?ooo`80000000<0oooo000000000000100000000d000000
oooo0000000200000080oooo1`0000000`3oool0000000000002000000050?ooo`00000000000000
040000000P0000000`3oool000000000000:00000003@0000000000000000080000000=000000?oo
o`0000002@0000020?ooo`X000000P3oool5000000040?ooo`0000000000000000D0oooo2`00000:
0?ooo`00303oool<00000080oooo0`0000001@3oool00000000000000000oooo008000000P3oool0
0d000000oooo0?ooo`09000000030?ooo`00000000000080oooo00=000000000000000000P000000
1D0000000000000000000000oooo00<000000`3oool00`000000oooo0?ooo`03000000040?ooo`00
0000000000000080oooo00@000000?ooo`3oool0oooo0P0000020?ooo`D0000000=000000?ooo`3o
ool00P0000020?ooo`8000000P3oool2000000<0oooo1P0000000d000000oooo000000020?ooo`80
000000@0oooo@0000000000000000`3oool00`000000oooo0?ooo`0K000000030?ooo`0000000000
008000000P3oool010000000oooo0?ooo`3oool:00000080oooo00A000000000003oool0oooo1P00
00000d000000oooo@000000600000080oooo00@000000?ooo`3oool0oooo<@0000001D0000000000
0?ooo`3ooom000000080oooo2`00000:0?ooo`002@3oool400000003@00000000000000000<0oooo
0P0000000`3oool00000000000020?ooo`05@0000000000000000?oood0000000`000000103oool0
00000000000000030?ooo`9000000`0000020?ooo`03000004000000oooo008000000`3oool30000
0080oooo0P0000020?ooo`800000203oool200000080oooo0P0000020?ooo`80000000@0oooo0000
0000000000000`3oool3000001<0oooo00=000000?ooo`3oool06P3oool00`000010000000000002
00000003@00000000000000000<000000P3oool01T0000000000000000000000oooo000000<0oooo
00<000000?ooo`3oool01`3oool300000004@00000000000000000000080oooo0P0000040?ooo`D0
00000`3oool4000000T0oooo0P0000001D000000000000000000001000000080000000<0oooo0000
000000000P0000000`3oool000000000000400000003@0000000000000000080000000A000000?oo
o`3oool0oooo100000001400000000000000000000030?ooo`030000003oool0000000D0000000=0
00000?ooo`3oool0103oool2000000030?ooo`000000000000D000002P3oool000X0oooo0P000005
0?ooo`03@0000000000000000080oooo00<00000@000003oool00P3oool3000000030?ooo`000000
00000080000000D0oooo0000000000000000@00000020?ooo`D000001@3oool2000000<0oooo0`00
000014000000oooo0000000000020?ooo`8000001`3oool010000000oooo0?ooo`3oool600000005
0?ooo`00000000000000003oool01000000?0?ooo`050000003oool0oooo0?ooo`0000001@3oool0
0d0000000000000000030?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo@000
0005000000@0oooo200000040?ooo`L0000000@0oooo0000000000000000203oool300000080oooo
00<00000@000000000000`0000030?ooo`04@000003oool0oooo000000@0oooo100000080?ooo`05
000004000000oooo0000040000000`0000040?ooo`030000003oool0oooo0080oooo0P0000000d00
0000000000000003000000X0oooo0P0000060?ooo`03@00000000000000000<000000P3oool01400
000000000000000000020?ooo`030000003oool0oooo0140oooo000:0?ooo`03@000003oool0oooo
00@0oooo0`0000020?ooo`@000000P3oool200000080oooo4P0000020?ooo`8000000`3oool40000
0005@0000000000000000000003oool00P0000020?ooo`03@0000000000000000080oooo00D00000
0?ooo`3oool0oooo000000020?ooo`d000001@3oool010000000oooo0?ooo`3oool2000000050?oo
o`00000000000000003oool00`0000001@3ooom000000?ooo`000000oooo00<000000P3oool20000
0080oooo100000000`3oool000000?ooo`0800000003@00000000000000000<0000000<0oooo0000
00000000100000030?ooo`/000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool00000
00X0000000E000000000000000000000@0000008000000040?ooo`000000oooo0?ooo`D0000000@0
oooo000000000000oooo0`0000020?ooo`03@0000000000000000080oooo2@00000:0?ooo`D00000
0`3oool<00000080oooo00<000000?ooo`3oool04@3oool000`0oooo0`0000020?ooo`<000000P3o
ool5000000<0oooo00<000000?ooo`3oool00P0000000d00000000000000000500000003@0000000
0000000000P0000000=00000000004000000200000020?ooo`030000003oool0oooo00<000000P3o
ool01@000000oooo0?ooo`3oool000000080oooo3`0000020?ooo`80000000<0oooo000000000000
2@0000000`3oool0000000000009000000050?ooo`00000000000000040000000`0000020?ooo`<0
000000<0oooo0000000000001P0000020?ooo`T000000P3oool01D00000000000000000000100000
00H0000000@0oooo00000000000000000P3oool00d000000000000000004000000030?ooo`000000
000000P0000000=000000000000000000`0000000`3oool000000000000800000080oooo1P000000
103oool000000000000000020?ooo`d000000`3oool2000000030?ooo`000000000000D000000P3o
ool;00000080oooo00D000000?ooo`3oool0oooo0000000?0?ooo`002@3oool5000000@0oooo0P00
00000`3oool0000000000003000000L0oooo00=00000000000000000100000000`3oool000000000
0005000000@0oooo00<000000?ooo`3oool00P3oool4000000030?ooo`000000000000800000103o
ool3000000T0oooo100000001D000000oooo0?ooo`3ooom0000000<000001@3oool=000000030?oo
o`0000000000018000000P3oool3000000040?oood000000000000000080oooo0`0000000`3ooom0
000000000004000000L0oooo0`0000020?ooo`030000003oool0oooo00@0oooo1@0000020?ooo`<0
00000P3oool00d00000000000000000600000080oooo100000000d000000oooo@000000900000080
oooo1@0000000d000000oooo00000002000000<0oooo0P0000000`3oool0000000000006000000D0
oooo0P0000000d0000000000000000060?ooo`<0000000=000000000000000000P3oool3000000H0
oooo00<000000?ooo`3oool03@3oool000X0oooo0P0000060?ooo`040000003oool0oooo0?ooo`<0
0000103oool2000000@0oooo00@00000@0000000000000001P3oool200000080oooo0P0000070?oo
o`8000000P3oool01400000000000000000000050?ooo`030000003oool0oooo00800000203oool0
0`000000oooo0?ooo`050?ooo`03000004000000oooo00<0oooo1@0000020?ooo`@0000000=00000
0000000000001@0000001@3oool00000000000000000oooo00/0000000<0oooo0000000000001@00
00030?ooo`8000000`3oool4000000L0oooo00E0000000000000000000000?ooo`04000000@0oooo
1P000000103oool0000000000400000300000080oooo100000000`3oool000000?ooo`04000000@0
oooo1P0000001@3oool00000000000000010000000D000000`3oool00`000000oooo0?ooo`020?oo
o`D000000P3oool3000000L0oooo0`0000000d000000oooo0?ooo`040?ooo`8000001P3oool20000
00L0oooo00<00000@000003oool03@3oool000X0oooo00=000000?ooo`3oool01@3oool010000000
oooo0?ooo`3oool2000000D0oooo2P0000020?ooo`05@0000000000000000000003oool00P000000
0`3ooom0000000000003000000@0oooo0P0000020?ooo`03@00000000000000000800000103oool0
0`000000oooo0?ooo`04000000@0oooo00A0000000000000000000000`3oool5000000@0oooo0`00
00000d000000oooo0?ooo`020?ooo`04@000000000000000@00000H0000000<0oooo@00000000000
0T00000600000080oooo100000000`3oool0000000000004000000<0oooo00A00000000000000000
00000`3oool3000000030?ooo`000000oooo00H0oooo0`0000000d000000000000000002000000@0
oooo0`0000000`3oool000000000000700000004@000000000000000000000<0oooo1`0000030?oo
o`03000004000000000000<0000000<0oooo0000000000001@0000040?ooo`030000003oool0oooo
0080oooo1@0000020?ooo`04@000000000000000000000<0oooo00=000000000000000000`000008
0?ooo`030000003ooom0000000<000000P3oool00`000000oooo0?ooo`030?ooo`@000003P3oool0
00h0oooo00E000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?oood0000000P3o
ool8000000040?ooo`000000oooo0?ooo`@000000P3oool00`000000oooo0000000600000004@000
00000000000000000080oooo0`0000000`3oool00000000000030?ooo`030000003oool0oooo00H0
00000P3oool4000000030?ooo`00000000000080000000A00000000000000000oooo1P0000030?oo
o`X0000000<0oooo@0000400000030000000103ooom000000?oood000009000000030?ooo`000000
000000<0000000D0oooo00000000000000000?ooo`03000000030?oood000000oooo00<000000P3o
ool3000000040?ooo`000000000000000080oooo0P0000000`3oool000000000000<000000<0oooo
200000000d00000000000?ooo`020?ooo`030000003oool0000000<0000000<0oooo@00000000000
100000030?ooo`040000003oool0oooo0?ooo`H000000P3oool01D00000000000000000000100000
0080oooo1@0000000`3ooom000000?ooo`03000000<0oooo00<000000?ooo`0000000`0000020?oo
o`040000003oool0oooo0?ooo`@0000000=000000000003oool03@3oool001d0oooo00A000000000
00000000oooo100000040?ooo`<00000103oool300000004@00000000000000000000080oooo0P00
00030?ooo`<000002@3oool00d0000000000000000050?ooo`<000001@3oool4000000030?ooo`00
000000000080oooo0`0000050?ooo`L000000`3oool2000000050?ooo`00000000000?oood000000
0P0000050?ooo`@0000000E000000000000000000000@00000040?ooo`05@0000000000000000000
040000000`0000000d00000000000000000800000080oooo0`00000;0?ooo`040000040000000000
000000<0oooo0`0000050?ooo`<0000000=000000000000000000`0000090?ooo`L0000000=00000
0?ooo`3oool01P3oool4000000<0oooo0P0000040?ooo`X000001`3oool3000000T0oooo0`00000>
0?ooo`00:P3oool2000000@0oooo0`000000103oool000000000000000020?ooo`8000000`3oool4
000000P0oooo0P0000060?ooo`<000002`3oool200000080oooo0P0000050?ooo`8000000P3oool2
000000<0oooo0`0000000`3oool00000000000020?ooo`030000003oool0oooo00<0oooo1000000:
0?ooo`l0000000<0oooo@000000000000P0000000d00000000000000000200000140oooo0P000008
0?ooo`03000004000000000000H000001P3oool8000001L0oooo1`0000090?ooo`8000006`3oool0
01T0oooo0`00000:0?ooo`80000000=000000?ooo`000000103oool2000000@0oooo0`0000020?oo
o`80000000<0oooo@00000000000100000070?ooo`0600000400000000000000003oool000000P3o
ool3000000/0oooo0`0000020?ooo`8000001@3oool00`000000oooo0?ooo`02000000<0oooo0P00
00020?ooo`030000003oool0oooo00<0000000<0oooo0000000000001P00000:0?ooo`030000003o
oom0000000D000000P3oool4000000<0oooo0`0000000`3oool0000000000002000000<0oooo00<0
00000?ooo`3oool02@3oool2000000030?ooo`000000000000<0oooo0`0000020?ooo`P000000P3o
ool00d000000oooo0?ooo`0200000003@00000000000000000<0000000=000000?ooo`0000000`3o
ool2000000h0oooo1@000002@00000030?ooo`0000000000008000001P3oool00`000000oooo0?oo
o`080?ooo`03@00000000000000000h0oooo000>0?ooo`05@000003oool0oooo0?ooo`0000000`3o
ool00`000000oooo0?ooo`06000000<0oooo100000001D00000000000000003oool0000000@0oooo
00H000000?ooo`3oool0oooo0000003oool300000005@0000000000000000000003oool00`000000
103oool000000000000000030?ooo`03@000003oool0oooo00@0000000@0oooo0000003oool0oooo
100000000`3oool000000?ooo`020?ooo`03@000003oool0oooo0080oooo0`000002@00000800000
0T0000030?ooo`0500000400000000000?ooo`0000000`3oool01`000000oooo0?ooo`3oool00000
0?oood0000003P0000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`0000000`000002
0?ooo`030000003oool0oooo00H000000P3oool4000000040?ooo`00000000000?ooo`8000000`3o
ool3000000030?ooo`000000000000<0000000=000000000000000000P0000020?ooo`D0000000=0
00000000000000000P0000001@3oool00000000000000000oooo00@000000P3oool6000000040?oo
o`0000000000@00000D0000000<0oooo0000003oool00P3oool01@000000oooo0?ooo`3ooom00000
0080oooo1`0000000`3oool0000000000005000000<0oooo00D000000?ooo`3oool0oooo@0000003
0?ooo`H000003P3oool00180oooo00@000000?ooo`00000000000`3oool00d000000000000000009
0?ooo`@00000203oool200000004@00000000000000000000080oooo0`0000020?ooo`8000001P3o
ool200000080oooo0`0000020?ooo`80000000D0oooo0000000000000000@00000020?ooo`800000
1@3oool3000000<0oooo00<000000?ooo`3oool01@3oool4000000P0oooo100000000d000000oooo
00000002000000030?oood000010000000D0000000=000000?ooo`0000001P3oool4000000D0oooo
00=000000000000000001P3oool00d0000000000000000020?ooo`040000003oool00000000000@0
oooo3`0000020?ooo`L000001@3oool400000080oooo00=00000000000000000100000020?ooo`@0
000000<0oooo0000000000000P0000030?ooo`030000003oool0oooo00@0oooo00=0000000000000
00001@3oool00d00000000000000000B0?ooo`<000003P3oool00180oooo1000000I0?ooo`@00000
00@0oooo00000000000000000P3oool300000080oooo0P0000050?ooo`@000000P3oool6000000L0
oooo100000020?ooo`800000303oool3000000040?ooo`0000000000000000H0oooo100000050?oo
o`<0000000<0oooo0000000000000P0000020?ooo`8000001P3oool200000100oooo200000050?oo
o`@0000000D0oooo00000000000000000?ooo`0600000004@000003oool0000000000080oooo0`00
00040?ooo`<00000103oool7000000030?ooo`000000000000<0000000<0oooo0000000000000P00
00020?ooo`8000008`3oool00`000000oooo0?ooo`0=0?ooo`004@3oool7000000040?oood000000
0000000000d0oooo2@0000030?ooo`<0000000<0oooo@000000000000P0000020?ooo`0300000400
000000000080oooo1@0000020?ooo`03@00000000000000000@000001`3oool7000000`0oooo0P00
00000`3oool0000000000003000000@0oooo100000030?ooo`03@00000000000000000@0000000D0
oooo0000000000000000@0000004000000@0oooo100000001400000000000000000000040?ooo`D0
00000`3oool200000003@000000000000000008000001`3oool00`000000oooo0?ooo`0200000003
@000003oool000000080000000H0oooo00000000000000000?oood000003000000030?ooo`000000
000000<0oooo0P0000050?ooo`80000000=00000000004000000100000000`3oool0000000000002
000000030?ooo`00000000000080000000D0oooo00000000000000000?ooo`04000000@0oooo00A0
000000000000000000005P3oool00`000000oooo0?ooo`0=0?ooo`00303oool300000080oooo00<0
0000@00000000000200000020?ooo`05@000003oool0oooo0?ooo`0000000`3oool00d000000oooo
0?ooo`0;000000050?ooo`00000000000000003oool0100000020?ooo`X000000P3oool700000090
00000`3oool:000000<0oooo00E000000?ooo`3oool0oooo000000020?ooo`80000000<0oooo0000
040000001@0000030?ooo`8000000P3ooolF000000030?ooo`00000000000100000000=000000000
000000001`0000020?ooo`D0000000=000000000000000001`0000000`3oool00000000000050000
0080oooo00D000000?ooo`3oool0oooo000000020?ooo`L000000P3oool00`000000oooo00000003
00000080oooo00<00000@000000000001@0000000d000000000000000007000000030?ooo`000000
0000008000000P3oool01D000000oooo0?ooo`3ooom0000000<0oooo00E000000?ooo`3oool0oooo
@00000030?ooo`050000003oool0oooo0?ooo`0000003`3oool000T0oooo1@0000030?ooo`800000
00=000000?oood0000000P000000103oool000000000000000060?ooo`030000003oool0oooo00@0
oooo00E00000000000000000oooo@000000200000004@000003oool0oooo0?ooo`@000000P3oool3
00000080oooo0`0000040?ooo`80000000=000000?ooo`3oool00`000000103oool0000000000000
00060?ooo`80000000E000000000000000000000@00000090?ooo`P000001`3oool00`000000oooo
0?ooo`040?ooo`@000000`3oool200000005@0000000000000000000040000000P0000000d000000
oooo0?ooo`020?ooo`03@00000000000000000@000000`3oool01D00000000000000000000100000
00<0000000@0oooo00000000000000000P3oool00`00001000000?ooo`040?ooo`L0000000=00000
0000000000001@0000000`3oool0000000000004000000`0oooo1`0000090?ooo`@0000000A00000
00000000000000000T000002000000H0oooo0`00000B0?ooo`030000003oool0oooo0140oooo000:
0?ooo`8000003P3oool00`000000oooo0?ooo`050?ooo`8000003`3oool014000000000000000000
00030?ooo`8000000P3oool4000000<0oooo0`0000030?ooo`80000000@0oooo0000003oool00000
203oool7000000T0oooo2@00000;0?ooo`D0000000<0oooo0000000000000`00000<0?ooo`D00000
1@3oool3000000040?ooo`000000000000000080oooo1P0000060?ooo`<000000P3oool500000004
@000000000000000000000<0oooo1@00000>0?ooo`H00000203oool3000000h0oooo0P00000C0?oo
o`030000003oool0oooo0140oooo000:0?ooo`03@000003oool0oooo00d0oooo00@000000?ooo`3o
oom000001P0000090?ooo`@0000000<0oooo000000000000100000000`3ooom00000000000020000
00040?oood0000000000@000008000000P3oool400000080oooo0P0000000`3oool0000000000002
0?ooo`04@000000000000000000000@0oooo1P0000000d000000oooo0?ooo`060?ooo`D0000000=0
00000000000000000`0000030?ooo`04@0000000000000000?ooo`@000001@3oool6000000030?oo
o`000000000000800000103oool8000000@0oooo0`000000103oool000000000000000020?ooo`80
000000=000000000000000001`3oool200000003@000003ooom0000000T000000P3oool00d000000
oooo00000003000000L0oooo00<000000?ooo`3oool0103oool00`000010000000000003000000@0
oooo00@000000?ooo`3ooom000000`0000040?ooo`04@000000000000000000000H0oooo00<00000
0?ooo`3oool02`3oool01D0000000000000000000000oooo00<000004P3oool000`0oooo0`000003
0?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`0:000000<0oooo00=0
00000?ooo`3oool020000000103oool000000000003oool400000080oooo1P000000140000000000
0000000000020?ooo`070000003oool0oooo0?oood00000000000?ooo`0800000003@00000000000
000000@000000`3oool014000000oooo0?ooo`3oool500000003@00000000000000000D0000000<0
oooo0000000000000P0000000`3oool000000000000500000080oooo00<00000@000003oool02`00
00000`3ooom0000000000009000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000
003oool00000008000000`3oool6000000030?ooo`000000000000D0000000@0oooo000000000000
oooo200000030?ooo`030000040000000000008000000`3oool3000000030?ooo`000000000000<0
00000`3oool2000000030?ooo`00000000000080000000<0oooo@000003oool0200000030?ooo`05
0000003oool0oooo0?oood0000000`3oool01P000000oooo0?ooo`3ooom000000?ooo`P000000P3o
ool00d000000oooo0?ooo`0=0?ooo`002@3oool5000000@0oooo00@000000?ooo`00000000001`3o
ool00`00001000000000000400000003@000003oool0oooo00H0oooo0T00000500000003@0000000
000000000080000000@0oooo00000000000000000`3oool2000000<0oooo100000050?ooo`L00000
00<0oooo0000000000001`00000:0?ooo`T0000000<0oooo0000000000001@000000103ooom00000
0000000000060?ooo`<0000000E00000000000000000oooo@0000002000000T0oooo00=000000000
000000001`3oool2000000040?ooo`0000000000000000H0oooo0P0000050?ooo`<0000000<0oooo
0000000000000`0000050?ooo`H000000P3oool200000080oooo1@0000040?ooo`L00000103oool6
00000004@000003oool0oooo0?ooo`@000003`3oool00`000000oooo0?ooo`040?ooo`<0000000@0
oooo00000000001000004P3oool000T0oooo100000050?ooo`@00000203oool4000000d0oooo1000
00020?ooo`<000000P3oool300000080oooo0`0000040?ooo`<00000103oool500000003@0000000
000000000080oooo1P00000=0?ooo`L000000P3oool4000000030?ooo`000000oooo00/0oooo0`00
000H0?ooo`@0000000E0000000000000000000000?ooo`02000000X0oooo0P0000020?ooo`04@000
000000000000000000D0oooo100000040?ooo`<000000P3oool4000000D0oooo1P0000000d000000
oooo0?ooo`020?ooo`D000000`3oool4000000l0oooo0P0000060?ooo`8000005`3oool000X0oooo
0P0000050?ooo`@0000000=000000000000000001P3oool00`000000oooo00000002000000L0oooo
0P0000001d000000oooo0?ooo`3oool00000@000000000000P3oool300000080oooo0P0000020?oo
o`<000001@3oool3000000<0oooo0`0000000`3oool000000?ooo`0300000080oooo00=000000?oo
o`3oool0200000070?ooo`030000003oool000000080000000@0oooo00000000000000000P3oool2
00000080oooo00<000000?ooo`3oool02P3oool300000003@000003oool0oooo00P0oooo10000003
0?ooo`030000003oool000000080000000<0oooo@000000000000`0000000`3oool0000000000005
000000P0oooo0`0000000`3oool0000000000003000000@0oooo0P0000050?ooo`03@00000000000
00000080000000<0oooo0000000000000`000000103ooom000000000000000020?ooo`040000003o
ool00000000000D0oooo100000040?ooo`H000003@3oool3000000H0oooo00<000000?ooo`3oool0
103oool00d00000000000000000>0?ooo`002P3oool01D000000oooo0?ooo`3ooom000000080oooo
00<00000@00000000000100000020?ooo`050000003oool0oooo0?ooo`0000000`3oool010000000
oooo0?ooo`3oool700000080oooo1@000000103oool000000000000000030?ooo`03000004000000
0000008000000`3oool00`000000oooo0?ooo`0300000080oooo0P0000020?ooo`030000003oool0
oooo00@0000000@0oooo@000003oool0oooo2`0000030?ooo`h000000P3oool01@000000oooo0?oo
o`3oool0000000<0oooo00H000000?ooo`3oool0oooo0000003oool300000080oooo0`0000030?oo
o`03@000003oool0000001D0000000=000000000000000000`0000020?ooo`040000003oool0oooo
0?ooo`<0000000@0oooo0000003oool0oooo0P0000030?ooo`040000003oool0oooo0?ooo`800000
0P3oool;000000040?ooo`000000000000000080oooo00<000000?ooo`000000100000001P3ooom0
0000000000000000oooo000000<0oooo00<000000?ooo`3oool01`0000030?ooo`06@000003oool0
oooo0?oood000000oooo0P0000001D00000000000?ooo`3ooom0000000<0oooo00D000000?ooo`3o
ool0oooo@00000020?ooo`<000003P3oool00140oooo0P0000000d000000oooo0000000200000080
oooo00<000000?ooo`3oool0303oool4000000030?oood000000000000P000000`3oool00`000000
oooo00000002000000<0oooo00<000000?ooo`3oool00P0000000d000000oooo0?ooo`040?ooo`03
0000003oool0oooo00<0000000=000000?ooo`3oool00P3oool01D00000000000000003ooom00000
008000001P3oool00d00000000000000000300000003@000003ooom0000000<0000000A000000000
0000000000001P3oool200000080oooo0P0000000`3oool0000000000007000000H0oooo00=00000
0000000000000P0000001D0000000000000000000010000000<0000000I000000000000000000000
0?oood000003000000P0oooo1@0000000d0000000000@00000050?ooo`030000003oool0oooo00D0
oooo0`0000000`3oool000000000000700000003@000003oool00000008000000P3oool200000080
oooo1@0000000d000000oooo0?ooo`070?ooo`03@00000000000000000d0oooo0`0000000d000000
oooo0?ooo`0;0?ooo`<000003P3oool001H0oooo00D000000?ooo`3oool0oooo0000000?0?ooo`80
000000<0oooo000000000000100000000d000000000000000002000000H0oooo0P0000030?ooo`03
0000003oool0oooo00D0oooo00@000000?ooo`3oool0oooo0P00000G0?ooo`@000000`3oool01D00
00000000000000000000oooo00<000001P3oool9000000030?ooo`000000000000<00000203oool0
1D0000000000000000000000oooo00L0000000@0oooo00000000000000000P3oool5000000L0oooo
1@00000@0?ooo`<0000000A0000000000000001000000`0000050?ooo`040000003oool0oooo0?oo
o`800000103oool4000002/0oooo00<000000?ooo`3oool03@3oool001D0oooo0`000000103oool0
000000000000000=0?ooo`X0000000<0oooo000004000000100000040?ooo`040000040000000000
0?ooo`<000001P3oool00`000000oooo0?ooo`03000000030?oood000000000000800000303oool4
000000040?ooo`0000000000@00000@000000`3oool300000080oooo0P0000060?ooo`<0000000=0
00000000000000000`0000001400000000000000000000090?ooo`D000000P3oool200000080oooo
0P0000020?ooo`8000000P3oool6000000@0oooo1P0000001@3oool00000000004000000oooo00@0
0000203oool:000000<0oooo0`0000020?ooo`<000001@3oool00`000000oooo0?ooo`0L0?ooo`@0
00002P3oool00`000000oooo0?ooo`0=0?ooo`00303oool3000000<0oooo00<000000?ooo`3oool0
0`000000103oool000000000000000020?ooo`05@000003oool0oooo0?oood0000000`3oool01D00
0000oooo0?ooo`000010000000<0000000<0oooo0000003oool00P3oool00`000000oooo00000006
000000<0oooo100000001D00000000000?ooo`3oool0000000<0oooo0P0000000`3oool000000000
0006000000030?oood000000oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0000
000>00000080oooo0`0000020?ooo`060000003oool0oooo0?ooo`000000oooo0`0000000`3oool0
000000000007000000030?ooo`000000oooo00<0oooo00L000000?ooo`0000000000@00000000000
oooo008000000`3oool200000080oooo00@000000?ooo`3oool0oooo0P0000000`3ooom000000000
000500000080oooo2P0000000`3oool000000000000500000080oooo0P0000020?ooo`80000000D0
oooo00000000000000000?ooo`0300000080oooo0`0000020?ooo`<0000000<0oooo0000003oool0
0P3oool01D000000oooo0?ooo`3ooom0000000<0oooo00E000000?ooo`3oool0oooo@00000030?oo
o`03@000003oool0oooo0080oooo00E000000?ooo`3oool0oooo@00000030?ooo`030000003oool0
000000H000000`3oool01@000000oooo0?ooo`3oool0000000l0oooo00090?ooo`D00000103oool0
0`000000oooo0?ooo`0200000005@000003oool000000000040000003@3oool400000003@000003o
ool0oooo0080oooo0P0000020?ooo`<000001P3oool500000004@000003oool0oooo00000080oooo
0`0000000`3oool0000000000005000000H0oooo00<000000?ooo`3oool00P0000020?ooo`d00000
1@3oool3000000D0oooo00<000000?ooo`3oool00P0000020?ooo`L0000000E000000?ooo`000000
00000?ooo`0200000080oooo0`0000000d000000oooo0000000200000080oooo0`0000000`3oool0
00000?ooo`020?ooo`<0000000@0oooo00000000000000001`3oool014000000oooo0?ooo`3oool4
000000030?ooo`000000000000@0000000=000000?ooo`3oool00`0000000`3oool00000@0000002
000000060?oood00000000000000003oool000000P3oool200000003@000003oool0oooo00<00000
00A0000000000000000000007P3oool00`000000oooo00000004000000D0oooo00<000000?ooo`3o
ool04@3oool000T0oooo100000050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
4`3oool01400000000000000000000020?ooo`<000001P3oool01400000000000000000000040?oo
o`030000003oool0oooo00@0000000E0000000000000000000000?ooo`02000000H0oooo1@000002
0?ooo`03@00000000000oooo0080oooo00I000000000000000000000@000000000060?ooo`04@000
000000000000000000D0oooo00@000000?ooo`3oool0oooo0P0000020?ooo`8000000P3oool20000
0080oooo1@0000070?ooo`05@0000000000000000000040000001`0000000`3ooom0000000000002
00000004@0000000000000000?ooo`8000002P3oool2000000040?oood00000000000?ooo`@00000
0`3oool8000000040?ooo`0000000000000000P0oooo0P0000030?ooo`<00000703oool200000003
0?oood000000000000P0oooo00<000000?ooo`3oool04@3oool000X0oooo0P0000001P3oool00000
000000000000oooo@0000080000000D0oooo@0000000000000000?ooo`0200000080oooo00=00000
0000000000001000000=0?ooo`<000000P3oool2000000L0oooo100000030?ooo`<0000000D0oooo
0000000000000000@00000020?ooo`@000000P3oool00d00000000000000000500000004@0000000
00000000000000@0oooo00=000000000000000000`0000030?ooo`<000000`3oool3000000<0oooo
0`0000001@3oool00000000000000000oooo00<0000000@0oooo00000000000000000P3oool40000
00<0oooo00E000000000000000000000@000000300000003@0000000000000000080000000=00000
0000000000000P0000001@3oool00000000000000000oooo00L000001`3oool200000003@000003o
ool0oooo00@0oooo00@00000@00000000000oooo2P0000000d0000000000000000080?ooo`800000
0`3oool300000003@000003oool0oooo00`0oooo100000040?ooo`@0000000A00000000000000000
00002@3oool200000080oooo0P0000000d000000oooo0?ooo`0<0?ooo`002P3oool00d000000oooo
0?ooo`07000000090?ooo`00000000000000003oool00000@00000000000oooo00X000000`3oool0
0d000000oooo0?ooo`020?ooo`030000003oool0oooo008000000`3oool00`000000oooo0?ooo`04
000000040?ooo`000000oooo0?ooo`8000000P3oool3000000030?ooo`000000000000<0oooo1@00
00020?ooo`D0000000=00000000000000000100000020?ooo`03@000003oool0000000<0000000<0
oooo0000000000000P3oool600000080oooo0P0000020?ooo`<0000000<0oooo0000000000002@00
00020?ooo`@0000000<0oooo@000003oool0300000000`3oool000000000000400000080oooo0P00
00020?ooo`03@00000000000000000@000000P3oool9000000<0oooo3`0000000`3oool000000000
00030?ooo`030000003oool0oooo00@0000000<0oooo0000003oool00P0000001D000000oooo0?oo
o`3ooom0000000<0oooo00E000000?ooo`3oool0oooo@00000020?ooo`L0000000<0oooo00000000
00001P0000020?ooo`05@000003oool0oooo0?oood0000000P3oool500000003@00000000000oooo
00d0oooo000=0?ooo`L0000000D0oooo00000000000000000?ooo`03000000050?ooo`0000000000
0000003oool0100000080?ooo`8000000`3oool2000000<0oooo00@000000?ooo`3oool0oooo1@00
000014000000oooo0?ooo`3oool400000003@000003oool0oooo008000000P3oool3000000@0oooo
0`0000001P3oool0000000000000001000000?ooo`<000001@3oool3000000D0oooo100000000`3o
ool000000?ooo`040?ooo`<0000000=000000?ooo`0000000P0000000d0000000000000000090000
009000000`3oool8000000040?ooo`000000000000000080oooo00=000000000000000000P000003
0?ooo`8000000P3oool00`000000oooo0?ooo`070?ooo`P0000000=000000?oood0000000P000002
0?ooo`8000000`3oool500000080oooo00@000000?ooo`3oool0oooo0P0000020?ooo`80000000E0
00000?ooo`000000oooo0000000@0?ooo`D000000`3oool8000000T0oooo1`00000>0?ooo`003@3o
ool01400000000000?ooo`3oool200000004@000003oool0oooo00000080oooo0P0000000d000000
oooo0?ooo`02000000030?oood000000000000P0oooo100000020?ooo`@000001@3oool00d000000
00000000000300000080oooo1@0000050?ooo`80000000<0oooo0000000000001P3oool2000000D0
oooo0`0000060?ooo`8000001P3oool01400000000000?ooo`3oool4000000030?ooo`0000000000
00800000103oool2000000<0oooo2@0000050?ooo`05@0000000000000000000003oool00P000002
0?ooo`800000103oool6000000050?ooo`00000000000000003oool00P00000:0?ooo`H0000000<0
oooo0000000000000P0000020?ooo`<000001@3oool2000000H0oooo0P0000020?ooo`D000004P3o
ool00d0000000000000000050?ooo`04@0000000000000000?ooo`<0000000=000000?ooo`3oool0
1`3oool200000003@000003oool0oooo008000003P3oool00180oooo00D000000?ooo`3oool0oooo
000000070?ooo`030000003oool0oooo00<000001@3oool500000080oooo00=00000000000000000
0`0000060?ooo`@000000`3oool500000004@000003oool0oooo0?ooo`D000001@3oool014000000
00000000000000030?ooo`@000001P3oool200000003@000003oool0oooo00D0oooo0P0000000d00
000000000000000500000004@0000000000000000?ooo`<0000000@0oooo00000000001000001000
00001T00000000000000003ooom000000?ooo`8000000T00000300000080oooo00<000000?ooo`3o
ool00`0000040?ooo`03000004000000000000/000002`3oool00d00000000000000000500000080
oooo0`00000014000000oooo0?ooo`3oool200000003@000003oool0oooo00@0oooo100000000`3o
ool000000000000200000180oooo200000000`3oool00000000000030?ooo`030000003oool0oooo
01d0oooo000<0?ooo`<000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00E000000?oo
o`3oool0oooo000000020?ooo`H000000P3oool900000003@00000000000000000@000000P3oool5
000000<0oooo1P0000020?ooo`06@000003oool0000000000400000000000P3oool7000000030?oo
od000000000000@000000P3oool00d00000000000000000400000080oooo00A000000?ooo`3oool0
oooo0`0000000`3oool000000?ooo`08000000030?ooo`000000000000L0000000=0000000000000
0000300000020?ooo`030000003oool0oooo00H000000`3oool010000000oooo0000040000030000
0003@00000000000000000<000000`3oool010000000oooo0?ooo`3ooolP000000030?ooo`000000
00000080000000E000000000003oool0oooo@00000030?ooo`05@000003oool0oooo0?oood000000
0`3oool00d000000oooo0?ooo`0<00000080oooo00D000000?ooo`3oool0oooo@00000030?ooo`05
@000003oool0oooo0?oood0000000`3oool00d000000oooo0?ooo`0=0?ooo`002@3oool5000000P0
oooo00<000000?ooo`3oool0203oool4000000@0oooo1@0000000`3oool000000000000900000003
0?oood000000000000<0000000=000000?ooo`3oool00P3oool4000000@0oooo1@0000030?ooo`D0
00000`3oool2000000030?oood000000oooo00<0000000<0oooo0000000000000P0000080?ooo`80
000000<0oooo0000000000000P3oool00d000000oooo0000000@000000030?ooo`000000000000@0
000000@0oooo00000000000000001@3oool4000000D0oooo00<000000?ooo`3oool00P3oool01000
0000oooo0?ooo`3oool500000080oooo0P0000030?ooo`D0000000=000000000000000000`000002
0?ooo`040000003oool0oooo0?oooaD000004@3oool<00000280oooo00090?ooo`@00000203oool4
000000P0oooo00=000000000003oool01@3oool00d00000000000?ooo`020?ooo`05@00000000000
00000000040000000`0000001400000000000000000000020?ooo`D000001P3oool2000000D0oooo
0`0000000d000000oooo0?ooo`020?ooo`@00000103oool700000080oooo100000050?ooo`@00000
00A000000000000000000000103oool500000090000000<0oooo0000000000000`3oool200000003
@000003oool0000000P000001P3oool01400000000000000000000040?ooo`<000000P3oool30000
00040?ooo`0000000000000000D0oooo0`000000103oool00000@000003oool40000009000000`00
00090?ooo`T0000000<0oooo00000000000010000002@0000140oooo00A000000000000000100000
1`0000000d000000oooo0?ooo`0P0?ooo`002P3oool2000000T0oooo00=000000000000000001000
000C0?ooo``000000P3oool3000000L0oooo0P0000000d000000oooo0?ooo`060?ooo`07@0000000
000000000000003ooom00000000000030?ooo`<0000000=00000000000000000100000000`3ooom0
00000000000400000003@000003oool0000000<000000P3oool3000000@0oooo00<000000?ooo`3o
ool00`000000103oool000000000040000030?ooo`04@00000000000oooo0?ooo`@0000000<0oooo
0000000000000P0000000d000000oooo0?ooo`040?ooo`H0000000<0oooo@000000000000P000000
1D0000000000000000000010000000@000001@3oool500000080oooo0P0000040?ooo`<000001P3o
ool300000004@000003oool00000000000<0oooo00<000000?ooo`3oool01@0000070?ooo`800000
00=000000?ooo`3oool02`3oool00d000000000000000003000002@0oooo000:0?ooo`03@000003o
ool0oooo008000000`3oool01T000000oooo0?ooo`3ooom000000?ooo`L000000`3oool01D000000
oooo0?ooo`3ooom0000000<0oooo00=000000?ooo`3oool00P3oool00`000000oooo000000020000
00050?ooo`00000000000000003oool00`0000020?ooo`8000000`3oool010000000oooo0?ooo`3o
ool200000004@000003oool0000000000080oooo00<000000?ooo`3oool0100000000`3oool00000
0000000400000003@000003oool0000000h000000P3oool3000000030?ooo`000000oooo00<00000
0`3oool010000000oooo0?ooo`3oool600000080oooo1@0000000d00000000000000000300000003
@0000000000000000080000000<0oooo@000003oool00P3oool00d000000oooo0000000300000003
@00000000000000000`000000`3oool7000000040?ooo`000000oooo0000009000000`3oool20000
00<0oooo2@0000030?ooo`030000003oool0oooo0080000000@0oooo0000003ooom000000`3oool4
00000005@00000000000oooo0?oood0000000`3oool01D000000oooo0?ooo`3ooom0000000@0oooo
00=000000000000000000P0000030?ooo`05@000003oool0oooo0?oood0000000`3oool01D000000
oooo0?ooo`3ooom0000000<0oooo00=000000?ooo`3oool03@3oool000/0oooo0`00000;0?ooo`@0
00004P3oool3000000030?ooo`000000oooo0080oooo00D000000?ooo`3oool0oooo000000030?oo
o`030000003oool0oooo00800000103oool800000080oooo0`0000020?ooo`<000000`3oool50000
00@0oooo200000020?ooo`8000000P3oool3000000030?ooo`000000oooo0080oooo00H000000?oo
o`3oool0oooo@000003oool400000080oooo0`0000000`3oool000000000000;000000<0oooo00A0
00000?ooo`3oool0oooo2P0000030?ooo`03000004000000000000800000103oool3000000030?oo
o`00000000000080oooo1000000:0?ooo`<0000000=000000000000000000P0000020?ooo`800000
0P3oool2000000P0oooo1000000g0?ooo`002@3oool4000000`0oooo00=000000000003oool0503o
ool3000000l0oooo0P0000040?ooo`T000000P3oool200000080oooo0`0000020?ooo`H000001@3o
ool300000080oooo0P0000020?ooo`80000000<0oooo000000000000100000060?ooo`8000000`3o
ool200000080oooo0`0000020?ooo`80000000=000000?ooo`3oool01P0000030?ooo`<000000P3o
ool01D0000000000000000000010000000H00000103oool3000000@0oooo00@000000?ooo`3oool0
oooo0`0000000d000000000000000003000000L0oooo00A000000?ooo`3oool0oooo1`0000000`3o
ool00000000000020?ooo`<000002@3oool2000003L0oooo000:0?ooo`8000006P3oool200000003
@000003oool0oooo00D0oooo0`0000000d000000oooo0?ooo`040?ooo`80000000=000000?ooo`3o
ool00P3oool3000000@0oooo100000001@3oool0000000000400000000000080oooo0P0000020?oo
o`8000000`3oool300000003@00000000000oooo00@0oooo00=000000000000000000P0000060?oo
o`80000000=000000000000000000`0000001D000000oooo000000000000oooo00@000000`3oool5
00000080oooo0P0000030?ooo`H000000`3oool5000000030?ooo`000000000000H0000000A00000
0000000000000000103oool4000000030?oood000000000000@0oooo1`0000060?ooo`<0000000D0
oooo0000000000000000@0000006000000040?ooo`00000000000?ooo`<0000000=000000?ooo`3o
ool01@3oool3000000T0oooo00A000000000000000000000203oool4000001h0oooo000:0?ooo`05
@000003oool0oooo0?oood0000000`3oool01D000000oooo0?ooo`3oool0000000<0oooo00E00000
0?ooo`3oool0oooo000000030?ooo`L0000000<0oooo0000000000000`3oool00`000000oooo0000
0002000000030?ooo`000000000000H000000P3oool00`000000oooo00000002000000<0oooo0P00
00020?ooo`030000003oool0000000@0000000E0000000000000000000000?ooo`0200000080oooo
0P0000020?ooo`h0000000<0oooo@000003oool02@0000000d000000000000000005000000<0oooo
1P000000103ooom000000000000000030?ooo`80000000<0oooo0000000000000`3oool200000003
@00000000000000000H0000000<0oooo0000000000001`0000020?oooa800000103oool:00000003
0?ooo`000000000000H0000000I0000000000000000000000?oood0000030?ooo`03@000003oool0
oooo00H000000`3oool00d000000oooo0?ooo`0400000080oooo00I000000?ooo`3oool0oooo@000
003oool7000000<0oooo00E000000?ooo`3oool0oooo@00000030?ooo`03@000003oool0oooo00d0
oooo000F0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool7000000<0oooo
0P000000103oool0000000000400000200000080oooo3P0000000`3oool000000?ooo`020?ooo`80
000000<0oooo0000000000001P0000000`3oool000000?ooo`03000000<0oooo0`0000030?oooa@0
000000<0oooo0000000000000P0000020?ooo`8000000`3oool:000000030?ooo`000000oooo0080
oooo00@000000?ooo`3oool0oooo1@0000020?ooo`80000000A00000000000000000oooo0`000000
0`3ooom000000000000300000003@00000000000000000L000000P3oool500000004@000003oool0
oooo00000080oooo0`0000030?ooo`H0000000@0oooo00000000000000000P3oool5000000T0oooo
100000080?ooo`<000002@3oool5000001d0oooo000F0?ooo`030000003oool0oooo00D0oooo0P00
00050?ooo`D000000P3oool4000000<0oooo100000040?ooo`P0000000A000000000000000100000
1@3oool9000000<0oooo00A0000000000000000000000`3oool3000000D0oooo00<00000@000003o
ool02@0000001400000000000000000000030?ooo`<00000103oool2000000030?oood0000000000
00@0000000=000000000000000000P00000;0?ooo`@000000`3oool300000004@000000000000000
00000080oooo0`0000020?ooo`800000103oool3000000@0oooo00@00000@0000000000000003P3o
ool300000003@000003oool0oooo00<0oooo1P0000080?ooo`03@00000000000oooo00X0oooo0P00
00090?ooo`03@00000000000oooo01l0oooo000E0?ooo`8000001P3oool3000000D0oooo0`000003
0?ooo`03@00000000000000000<000000P3oool400000003@000003oool0oooo00@0oooo00=00000
0000000000001@0000060?ooo`D000000P3oool2000000@0oooo0`0000030?ooo`80000000<0oooo
0000000000000P3oool3000000<0oooo100000000`3oool0000000000005000000<0oooo0P000003
0?ooo`D0000000<0oooo0000000000000P0000020?ooo`8000002`3oool4000000<0oooo00<00000
@000003oool01P0000001400000000000000000000030?ooo`8000000`3oool2000000D0oooo0`00
000;0?ooo`0700000400000000000?ooo`0000100000000000070?ooo`H00000503oool2000000d0
oooo00A0000000000000000000006P3oool000d0oooo0P0000060?ooo`<000000P3oool00`000000
oooo0?ooo`03000000D0oooo00<00000@000000000002`0000000`3oool0000000000002000000<0
oooo00@000000?ooo`3oool0oooo1P0000020?ooo`040000003oool0oooo0?ooo`80000000A00000
00000000000000000P3oool200000080oooo00<000000?ooo`3oool00`0000020?ooo`80000000<0
oooo0000000000001@0000030?ooo`8000000P3oool5000000030?ooo`000000000000<0oooo0P00
00030?ooo`L0000000=000000000000000000P3oool200000080oooo00D000000?ooo`3oool0oooo
000000040?ooo`8000000`3oool4000000030?ooo`000000000000<0000000A00000000000000010
00000`0000000`3oool00000000000030?ooo`8000000`3oool500000080oooo0`0000030?ooo`03
000004000000000000H0000000<0oooo0000003oool01@3oool600000003@000003oool0oooo0140
oooo00<000000?ooo`3oool0303oool4000001X0oooo000;0?ooo`@000000`3oool01T000000oooo
0?ooo`000010000000000080oooo00<000000?ooo`3oool010000000103ooom000000?ooo`3oool5
00000005@0000000000000000000040000001P0000020?ooo`040000003oool0oooo0?ooo`800000
00@0oooo0000000000100000100000020?ooo`060000003oool0oooo0?ooo`000000oooo0`000000
103ooom000000000000000030?ooo`060000003oool0oooo0?oood00000000000P3oool200000003
0?ooo`000000000000D000000P3oool2000000<0oooo1@0000030?ooo`050000003oool0oooo0?oo
o`0000000`3oool:00000080oooo00@000000?ooo`3oool0oooo0P0000030?ooo`80000000<0oooo
0000000000000P3ooolC00000080oooo00D000000?ooo`3oool0oooo000000030?ooo`<0000000<0
oooo0000003oool00P3oool@000000030?ooo`00000000000080oooo00=000000?ooo`3oool01000
00000`3ooom000000?ooo`020?ooo`05@000003oool0oooo0?oood0000000`3oool01D000000oooo
0?ooo`3ooom0000000<0oooo00<000000?ooo`3oool00P3oool01D000000oooo0?ooo`3ooom00000
00<0oooo00=000000?ooo`3oool00`0000020?ooo`05@000003oool0oooo0?oood0000000`3oool0
0d000000oooo0?ooo`0=0?ooo`002@3oool4000000P0oooo0P00000014000000oooo0?ooo`000002
0?ooo`<0000000=000000?ooo`3oool00P3oool300000003@00000000000000000H0000000=00000
0?ooo`3oool01`3oool3000000<0oooo0P0000030?ooo`8000000`3oool00`000000oooo00000002
00000080oooo0P0000030?ooo`8000000P3oool200000003@0000000000000000080oooo00=00000
0000000000002P3oool01D0000000000000000000000oooo008000000P3oool00`000000oooo0?oo
o`050?ooo`03@00000000000000000<0oooo100000020?ooo`050000003oool0oooo@000003oool0
0P0000020?ooo`<0000000=000000?ooo`3oool02@3oool;000000<0oooo00<000000?ooo`3oool0
203oool2000000@0oooo3P0000000d000000000000000002000000@0oooo00<000000?ooo`3oool0
9@3oool3000001X0oooo000:0?ooo`8000003@3oool200000080oooo0`0000050?ooo`04@0000000
00000000000000H0oooo1@0000080?ooo`<000000`3oool200000080oooo0P0000020?ooo`800000
0P3oool200000080oooo0P0000020?ooo`<000000P3oool7000000h0oooo3@0000040?ooo`04@000
003oool0oooo0?ooo`@00000103oool3000000040?ooo`000000000000000080oooo0`0000000d00
0000oooo0?ooo`0:0?ooo`<0000000=000000000003oool00P0000030?ooo`@000001`3oool30000
00D0oooo0P000000103oool000000000000000040?ooo`<000000P3oool300000003@000003oool0
oooo008000009`3oool2000000X0oooo00=000000000000000003P3oool000X0oooo00=000000?oo
o`3oool0303oool7000000D0oooo100000050?ooo`P000000`3oool00d0000000000000000040000
0080oooo0P0000001400000000000000000000020?ooo`<000000P3oool010000000oooo0?ooo`3o
ool2000000030?ooo`00000000000080000000H0oooo00000000000000000?oood000004000000@0
oooo00D000000?ooo`3oool0oooo000000050?ooo`0300000400000000000080000000=000000000
000000001P0000001@3oool00000000000000000oooo00D0000000<0oooo0000000000003@000002
0?ooo`8000001P3oool4000000030?ooo`000000000000D0000000=000000000000000000P000000
0d00000000000000000200000080oooo0`0000020?ooo`8000000P3oool3000000D0oooo00H00000
0?ooo`000000oooo0000003oool3000000<0oooo0`00000W0?ooo`030000003oool0oooo00P0oooo
0`00000>0?ooo`003P3oool01D000000oooo0?ooo`3ooom0000000<0oooo00=000000?ooo`3oool0
20000000103ooom000000?ooo`3oool300000080oooo00M000000?ooo`3oool00000@00000000010
000000L0000000<0oooo0000000000001@0000030?ooo`H0000000@0oooo00000000000000000P3o
ool010000000oooo0?ooo`3oool2000000030?ooo`000000000000D000000P3oool2000000040?oo
o`0000000000000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`<0000000<0oooo0000
003oool03`0000020?oooa<000000`3oool:00000080oooo2@0000000`3oool00000000000030000
00040?ooo`000000oooo0?ooo`@0000000<0oooo0000000000000P000000103oool000000?ooo`3o
ool7000000040?ooo`00000000000?ooo`<000000P3oool00`0000100000000000020?ooo`05@000
003oool0oooo0?oood0000000`3oool01D000000oooo0?ooo`3ooom0000000<0oooo00E000000?oo
o`3oool0oooo@00000040?ooo`05@000003oool0oooo0?oood0000000`3oool01D000000oooo0?oo
o`3oool0000000<0oooo00E000000?ooo`3oool0oooo@00000020?ooo`<000003P3oool001T0oooo
00A00000000000000000oooo0`0000000d000000oooo0?ooo`030?ooo`8000002@3oool4000000D0
oooo0`0000020?ooo`030000003oool0oooo0080oooo0`0000000d000000000000000003000000L0
oooo00@000000?ooo`3oool0oooo1@0000030?ooo`030000003oool0oooo00D0oooo0P0000020?oo
o`8000000`3oool3000000@0oooo00A0000000000000001000000P0000020?ooo`@000001P3oool3
00000003@000003oool0oooo0080oooo0`0000000d000000oooo0?ooo`02000000@0oooo2@000002
0?ooo`<0000000=000000000000000001P3oool3000000040?ooo`00000000000?ooo`X0000000=0
00000?ooo`3oool00P3oool6000000030?ooo`00000000000080oooo0P000000103oool000000000
0400000c0?ooo`8000003P3oool00140oooo0P0000060?ooo`8000002`3oool2000000T0oooo0`00
00060?ooo`80000000=000000?ooo`0000000P0000020?ooo`<000000P3oool6000000X0oooo00I0
000000000000000000000?ooo`0000030?ooo`030000003oool0oooo00@0oooo0P0000001@3oool0
0000000000000000oooo0080000000D0oooo0000000000000000@00000030?ooo`<00000103oool3
000000L0oooo0`0000050?ooo`<0000000<0oooo0000000000000P0000050?ooo`03000004000000
00000080000000D0oooo000000000000oooo@0000007000000D0oooo0P000000103oool000000000
000000040?ooo`80000000=000000000000000000P0000070?ooo`@0000000E00000000000000000
00000?ooo`03000003H0oooo00<000000?ooo`3oool03@3oool00140oooo100000040?ooo`@00000
2@3oool010000000oooo0?ooo`3oool200000003@00000000000000000D00000103oool500000004
0?ooo`000000000000000080oooo0P0000040?ooo`80000000=000000000000000000`000000103o
ool000000000000000030?ooo`D000000P3oool200000004@00000000000oooo000000<0oooo3@00
00050?ooo`800000103oool200000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0000
0002000000<0oooo2@0000000`3ooom000000000000200000003@00000000000000000<000000P3o
ool00d00000000000000000200000004@000000000000000@000008000000P3oool3000000040?oo
o`0000000000000000<0oooo200000030?ooo`060000003oool0oooo0?ooo`000000oooo0`000000
103oool0000000000400000300000003@000003oool0oooo03<0oooo00<000000?ooo`3oool03@3o
ool000h0oooo00=000000?ooo`3oool01P0000020?ooo`H000000`3oool01D000000oooo0?ooo`3o
ool0000000<0oooo2P0000020?ooo`L0000000@0oooo00000000001000000P3oool01@000000oooo
0?ooo`3ooom0000000@0000000=000000000000000001@0000020?ooo`H0000000=0000000000000
00001P0000020?ooo`<0000000E000000000000000000000@0000006000000040?ooo`0000000000
000000<0oooo00D000000?ooo`3oool0oooo000000020?ooo`8000000`3oool500000080oooo2`00
00000`3oool0000000000006000000040?ooo`00000000000?ooo`@0000000<0oooo000000000000
100000001400000000000000000000020?ooo`H000000P3oool700000080oooo0P0000020?ooo`<0
000000@0oooo00000000000000000P3oool200000080oooo00E000000?ooo`3oool0oooo@0000003
0?ooo`05@000003oool0oooo0?oood0000000`3oool01D000000oooo0?ooo`3ooom0000000<0oooo
00=000000?ooo`3oool00P3oool01D000000oooo0?ooo`3ooom0000000<0oooo00E000000?ooo`3o
ool0oooo@00000030?ooo`05@000003oool0oooo0?oood0000000`3oool00`000000oooo0?ooo`0=
0?ooo`004@3oool00d0000000000000000050?ooo`03@00000000000000000l0oooo0`0000000`3o
oom0000000000003000000<0oooo1P0000020?ooo`8000001P3oool00d0000000000000000050000
0006@0000000000000000000003ooom000003`0000040?ooo`D000000P3oool00d00000000000000
0008000000H0oooo00<000000?ooo`0000000P0000020?ooo`D0000000=000000000000000001P00
00000d000000oooo0000000;000000D0oooo0`0000001@3oool00000000000000000oooo00800000
00@0oooo00000000000000000P3oool6000000<0oooo1@00000014000000oooo0?ooo`3oool30000
00030?ooo`00000000000080oooo0P000000103oool000000000000000170?ooo`003@3oool20000
01`0oooo0P0000020?ooo`@000000`3oool01400000000000000000000050?ooo`<00000103oool2
000000030?ooo`000000000000@0000000<0oooo0000000000004`0000040?ooo`@0000000=00000
0?ooo`3oool00P3oool4000000030?ooo`00000000000080000000@0oooo000000000000oooo1P00
00000`3oool0000000000005000000050?ooo`0000000000@000003oool0100000000`3oool00000
00000005000000030?ooo`0000000000008000001@3oool2000000<0oooo00<000000?ooo`3oool0
0P0000020?ooo`8000000`3oool500000004@000003oool0oooo@00000@00000103oool700000003
0?ooo`000000000000@00000A`3oool000d0oooo1000000I0?ooo`8000000P3oool2000000040?oo
o`0000000000000000@0oooo0`000000103ooom000000000003oool300000003@000003oool00000
00@0000000<0oooo0000000000000P0000020?ooo`D0000000I000000?ooo`00000000000?oood00
000300000003@00000000000000000@000000`3oool00`000000oooo00000003000000@0oooo1@00
00000d00000000000000000500000003@00000000000000001L0000000@0oooo@00000000000oooo
1@0000040?ooo`040000003oool0oooo000000<0oooo00D000000?ooo`3oool0oooo000000020?oo
o`@0000000<0oooo@000000000000`0000030?ooo`030000003oool00000008000000`3oool80000
0003@00000000000000000D00000803oool014000000000000000000000R0?ooo`003@3oool60000
00<0oooo00E000000?ooo`3oool0oooo000000030?ooo`05@000003oool0oooo0?oood0000000`3o
ool00`000000oooo0?ooo`0200000080oooo00A0000000000000000000000P3oool01@000000oooo
0?ooo`3oool000000080oooo1`0000020?ooo`X0000000=000000?oood0000001@0000020?ooo`04
0000003oool0oooo0?ooo`8000000P3oool2000000040?oood000000000000000080oooo0P000000
0`3oool000000000000200000080oooo00<000000?ooo`3oool05`0000000`3oool000000000000;
00000003@00000000000000000L000000`3oool3000000030?ooo`000000oooo0080oooo00D00000
0?ooo`3oool0oooo000000020?ooo`03@00000000000000000L000000`3oool014000000oooo0?oo
o`3oool2000000<0oooo00<00000@0000000000010000000103oool000000000003oool300000003
@000003ooom0000000<0oooo00E000000?ooo`3oool0oooo@00000030?ooo`05@000003oool0oooo
0?oood0000000`3oool01D000000oooo0?ooo`3ooom0000000@0oooo00=000000?ooo`0000000`00
00020?ooo`05@000003oool0oooo0?oood0000000`3oool01D000000oooo0?ooo`3ooom0000000<0
oooo00=000000?ooo`3oool03@3oool000d0oooo00=000000000000000002P3oool00`000000oooo
0?ooo`090?ooo`030000003oool00000008000000`3oool3000000H0oooo00<000000?ooo`3oool0
0P3oool200000080oooo0P0000060?ooo`@0000000A000000?ooo`3oool0oooo0`0000080?ooo`03
0000003oool0oooo00@0oooo0`0000020?ooo`80000000<0oooo0000000000000P0000030?ooo`80
000000A00000000000000000oooo0`0000020?ooo`03@00000000000000000@0oooo00=000000?oo
o`3oool03@3oool200000080oooo0P0000000d0000000000000000030?ooo`030000040000000000
00<0oooo00=000000000000000002`3oool400000080oooo0`000000103oool000000000003oool3
000000L0oooo100000000d00000000000000000300000080oooo00<000000?ooo`3oool08@3oool3
00000280oooo000J0?ooo`030000003oool0oooo00T0oooo00<00000@000000000000P0000020?oo
o`03@00000000000000000800000103oool2000000<0oooo0`0000020?ooo`<000001P3oool40000
00@0oooo0`0000080?ooo`030000003oool0oooo00<0oooo0P0000020?ooo`<000000P3oool01400
000000000000000000020?ooo`@00000703oool;000000T0oooo100000090?ooo`@000000`3oool:
000000P0oooo0`0000020?ooo`@000000P3oool00`000000oooo0?ooo`0Q0?ooo`8000008`3oool0
0140oooo00=000000000000000001@3oool3000000T0oooo1`000000103oool00000000004000005
000000040?ooo`000000000000000080oooo0P0000030?ooo`@0000000A000000?ooo`3oool00000
0`3oool00`000000oooo0?ooo`020?ooo`040000003oool00000000000@0oooo00<000000?ooo`3o
ool00P0000040?ooo`<000000P3oool2000000<0oooo1@0000020?ooo`<0000000=000000?oood00
00000P0000050?ooo`@000001@3oool2000000<0oooo1@0000000d00000000000000000600000080
oooo00<00000@00000000000103oool5000000<0oooo00=000000000000000000`3oool200000003
0?ooo`000000oooo0080oooo0P0000000`3oool0000000000006000000D0oooo00<000000?ooo`00
00000`0000020?ooo`L000006@3oool4000000H0oooo00<000000?ooo`3oool08@3oool000h0oooo
00=000000?ooo`3oool00`0000020?ooo`06@000003oool0oooo00000400000000000P3oool01D00
0000oooo0?ooo`3ooom000000080oooo1`0000020?ooo`/000000P3oool010000000oooo0?ooo`3o
ool600000080oooo0`000000103oool000000?ooo`3oool2000000<0oooo00<000000?ooo`3oool0
0P0000030?ooo`8000000`3oool010000000oooo00000400000400000003@000003oool0000000<0
000000@0oooo000000000000oooo0`0000020?ooo`H000000P3oool:00000080oooo0P0000000d00
000000000000000200000003@00000000000000000H0000000<0oooo0000000000002@0000020?oo
o`030000003oool0oooo00<000000P3oool01@000000oooo0?ooo`3oool0000000<0oooo0P000000
0`3oool0000000000006000000030?ooo`000000000000@0000000A0000000000000000000000P3o
ool300000004@00000000010000000000080oooo00E000000?ooo`3oool0oooo@00000030?ooo`05
@000003oool0oooo0?oood0000000`3oool01D000000oooo0?ooo`3ooom000000080oooo1`000003
0?ooo`050000003oool0oooo0?oood0000000`3oool01D000000oooo0?ooo`3ooom0000000<0oooo
00E000000?ooo`3oool0oooo@000000?0?ooo`004@3oool3000000D0oooo0P0000000d000000oooo
0?ooo`070?ooo`D0000000@0oooo000000000000oooo100000000d00000000000000000300000003
@000003oool0oooo00H0oooo1P0000001@3oool00000000000000000oooo00@00000103oool40000
0080oooo0`0000020?ooo`8000000`3oool010000000oooo0000040000020?ooo`@000001@3oool2
00000080oooo1@0000030?ooo`03@0000000000000000080oooo100000000`3oool0000000000006
00000080oooo00<00000@000000000000P0000030?ooo`80000000<0oooo0000000000001P000000
0d000000oooo0?ooo`030?ooo`<000000P3oool00`000000oooo0?ooo`02000000<0oooo00<00000
0?ooo`3oool00`0000001D0000000000000000000010000000<0oooo200000030?ooo`80000000@0
oooo00000000001000006@3oool00d00000000000000000[0?ooo`004P3oool00`000000oooo0?oo
o`0B0?ooo`04@000000000000000000000<0oooo0`0000000`3oool0000000000002000000l0oooo
2`0000030?ooo`@000000`3oool200000080oooo0P0000030?ooo`8000001P3oool4000000D0oooo
1P0000040?ooo`<00000103oool2000000<0oooo1`0000030?ooo`D0000000<0oooo000000000000
1`0000000`3oool0000000000002000000<0oooo0`0000020?ooo`H000001`3oool3000000040?oo
o`0000000000000000D0oooo00<00000@000000000000P0000040?ooo`80000000=000000?ooo`3o
ool0B03oool00140oooo0`00000C0?ooo`@000000`3oool200000080oooo1@0000070?ooo`04@000
003oool0oooo0?ooo`80000000E0000000000000000000000?ooo`02000000030?ooo`0000000000
0080000000A000000?ooo`3oool0oooo0`0000020?ooo`<0000000@0oooo00000000000000000`3o
ool200000003@000003oool0oooo0080oooo0T000004000000<0oooo00=000000000000000001000
0000103ooom000000?ooo`3oool4000000<0oooo00M000000?ooo`0000000000@000000000100000
0080oooo00A000000?ooo`00000000000P3oool;000000060?ooo`00000000000000003ooom00000
100000020?ooo`05@0000000000000000000003oool01P0000030?ooo`040000003oool0oooo0?oo
o`T000001@3oool400000003@000003oool0000000800000B`3oool000h0oooo00=000000?ooo`3o
ool01P0000030?ooo`05@000003oool0oooo0?oood0000000`3oool01T000000oooo0?ooo`3ooom0
00000?ooo`@000000P3oool2000000030?ooo`000000000000<0000000=000000000000000000`00
00000`3oool0000000000006000000030?ooo`00000000000080000000H0oooo0000003ooom00000
0000040000030?ooo`05@000003ooom000000?ooo`0000000P3oool00`0000100000000000070000
0004@00000000000oooo0?ooo`@0000000=000000000000000000P0000020?oooa40000000=00000
0?ooo`3oool01P0000040?ooo`040000003oool0oooo@00000<0000000L0oooo0000000000000000
0?ooo`000010000000l0000000E0000000000000000000000?ooo`0400000004@000000000000000
00000080oooo00=000000000000000001@0000000d0000000000000000020?ooo`H0000000<0oooo
0000000000000`3oool01D000000oooo0?ooo`3ooom0000000<0oooo00E000000?ooo`3oool0oooo
@00000030?ooo`05@000003oool0oooo0?oood0000000`3oool01D000000oooo0?ooo`3ooom00000
00@0oooo00E000000?ooo`3oool0oooo@00000030?ooo`05@000003oool0oooo0?oood0000000`3o
ool01D000000oooo0?ooo`3ooom0000000<0oooo00=000000?ooo`3oool03@3oool00140oooo00=0
0000000000000000503oool010000000oooo0?ooo`0000050?ooo`X000000P3oool300000080oooo
2`0000000`3oool000000?ooo`070?ooo`030000003oool0oooo00<0oooo00<00000@000003oool0
0P3oool4000000<0oooo1@0000050?ooo`<000000T00000700000004@0000000000000000?ooo`<0
000000<0oooo@000000000000`0000070?ooo`0300000400000000000080000000A0000000000000
000000000`3oool4000000040?ooo`0000000000000000D0oooo1P0000020?ooo`X00000103oool2
000000030?ooo`000000000000<000000`3oool3000000040?ooo`0000000000000004/0oooo000V
0?ooo`8000002`3oool6000000<0oooo0`0000060?ooo`80000000=0000000000000000010000009
0?ooo`800000403oool3000000P0oooo00<000000?ooo`3oool00P3oool4000000<0oooo1P000002
0?ooo`D000001@3oool;000000<0oooo0P0000030?ooo`030000003oool0oooo00@0oooo0P000000
103oool000000000000000030?ooo`P00000203oool500000003@000003oool0oooo00D0oooo0`00
001:0?ooo`007@3oool200000003@000003oool0oooo00@0oooo100000080?ooo`<0000000=00000
0000000000001@0000060?ooo`030000003oool0000000D0000000<0oooo0000000000000P000000
1D000000oooo0?ooo`3ooom0000000@000001P3oool200000003@000003oool0oooo0080oooo00A0
000000000000000000001`3oool00d0000000000@0000002000000<0oooo0P0000040?ooo``00000
00A0000000000000000000000P3oool400000080oooo0P0000020?ooo`8000000`3oool200000080
oooo0`0000050?ooo`04@0000000000000000?ooo`8000000P3oool00`00001000000?ooo`020?oo
o`80000000=000000000003oool01P3oool6000000P0oooo0`0000000d000000oooo0?ooo`0V0?oo
o`80000000=000000?ooo`3oool0703oool000h0oooo00E000000?ooo`3oool0oooo@00000030?oo
o`04@000003oool0oooo0?ooo`@0000000E000000000003oool0oooo@00000030?ooo`H000000P3o
ool900000003@00000000000000000<000000P3oool010000000oooo0?ooo`3oool2000000030?oo
o`00000000000080000000<0oooo0000000000000P0000001400000000000?ooo`3oool700000003
0?ooo`000000000000D000000P3oool00d000000oooo0000000300000080oooo00E000000?ooo`3o
ool0oooo@000000500000080oooo00D000000?ooo`3oool0oooo@00000020?ooo`@0000000@0oooo
@000003oool0oooo200000000`3oool00000000000030?ooo`05@0000000000000000?oood000000
100000000d000000000000000002000000030?ooo`000000000000@000000P3oool3000000040?oo
o`00000000000?ooo`<000000`3oool00`000010000000000002000000<0oooo00@000000?ooo`3o
oom000001P0000030?ooo`040000003oool0oooo0?ooo`8000000P3oool01D000000oooo0?ooo`3o
oom0000000<0oooo00E000000?ooo`3oool0oooo@00000030?ooo`05@000003oool0oooo0?oood00
00000`3oool01D000000oooo0?ooo`3ooom0000000@0oooo00A000000?ooo`3oool0oooo10000000
1D00000000000?ooo`3ooom0000000<0oooo00E000000?ooo`3oool0oooo@00000030?ooo`03@000
003oool0oooo00d0oooo000M0?ooo`<000001P3oool00d0000000000000000080?ooo`@0000000<0
oooo0000000000001@0000020?ooo`040000003oool0oooo0?ooo`<0000000<0oooo000000000000
0`3oool500000080oooo1P0000000d000000oooo000000020?ooo`@000001@3oool3000000L0oooo
1@0000090?ooo`<0000000=000000?ooo`3oool00P3oool01400000000000000003oool3000000L0
oooo00E0000000000000000000000?ooo`0300000080oooo00<00000@000000000000P0000000d00
00000000000000050?ooo`<000000P3oool00`000010000000000003000000<0oooo1@0000020?oo
o`8000000P3oool3000000H0oooo0P0000020?ooo`030000003oool0oooo02T0oooo0`00000N0?oo
o`00:P3oool2000000X0oooo0P000000103oool000000000000000030?ooo`030000003oool0oooo
0080oooo0`0000000`3oool00000000000090?ooo`<00000103oool4000000030?ooo`0000000000
00H0oooo0P0000070?ooo`<0000000<0oooo0000003oool05P3oool2000000P0oooo0`0000020?oo
o`<000000P3oool4000000T0oooo100000020?ooo`@000000`3oool2000000030?ooo`0000000000
00<0oooo0P0000020?ooo`<00000103oool3000000030?ooo`000000000004`0oooo000A0?ooo`05
@0000000000000000?oood0000000P00000A0?ooo`D00000103oool00d00000000000?ooo`020?oo
o`030000003oool0oooo008000000P3oool3000000<0oooo0`0000000d0000000000000000080?oo
o`D000000`3oool00d00000000000000000400000003@000003oool0oooo00<0oooo0P0000000d00
0000oooo0?ooo`020?ooo`04@00000000000000000000080oooo00<000000?ooo`3oool0303oool2
00000003@000003oool0oooo00<0oooo100000080?ooo`<000000P3oool200000080oooo0P000000
0`3oool00000000000030?ooo`050000003oool0oooo0?oood0000001@0000020?ooo`@0000000<0
oooo0000000000000P3oool300000080oooo1`00000014000000oooo0?ooo`3oool7000004/0oooo
000>0?ooo`03@000003oool0oooo00<0000000@0oooo00000000000000000P3oool01D000000oooo
0?ooo`3ooom0000000<0oooo00E000000?ooo`3oool0oooo@00000020?ooo`03@000000000000000
00@000000P3oool4000000060?ooo`000000oooo@000003oool000000P3oool300000080oooo1`00
00001D0000000000000000000000oooo00P0000000A000000?ooo`3oool0oooo1`0000020?ooo`H0
00000P3oool00d000000oooo0000000300000080oooo00D000000?ooo`3oool0oooo@00000030?oo
o`04@000003oool0oooo0?ooo`@0000000E00000000000000000oooo@00000020?ooo`L000000`3o
ool01@000000oooo0?ooo`3oool0000000<0oooo00X000000?ooo`3oool0oooo0000003oool00000
0?ooo`00001000000P0000001T000000oooo0?ooo`3oool00000@00000@000000P3oool300000003
0?ooo`000000oooo0080oooo0`0000000d000000000000000006000000040?ooo`000000oooo0?oo
o`D0000000E000000000003oool0oooo@00000030?ooo`05@000003oool0oooo0?oood0000000`3o
ool01D000000oooo0?ooo`3ooom0000000<0oooo00E000000?ooo`3oool0oooo@00000030?ooo`03
@000003oool0oooo0080oooo00E000000?ooo`3oool0oooo@00000030?ooo`05@000003oool0oooo
0?oood0000000`3oool01D000000oooo0?ooo`3ooom0000000<0oooo00=000000?ooo`3oool03@3o
ool00140oooo0`000000103oool0000000000000000C0?ooo`8000001@3oool400000080oooo0`00
00030?ooo`80000000A000000?ooo`3oool0oooo0`0000000`3oool000000000000600000003@000
003oool0000000<00000203oool4000000D0oooo0`0000050?ooo`<000003P3oool01D0000000000
000000000010000000800000103oool00d0000000000000000050?ooo`800000203oool01@000000
oooo0?ooo`3ooom00000008000000`3oool2000000H0oooo1@0000001@3oool00000000000000010
000000@0oooo0P0000040?ooo`D0000000<0oooo0000000000000`3oool500000003@000003oool0
oooo04T0oooo000B0?ooo`050000003oool0oooo0?ooo`000000503oool4000000@0oooo0P000003
0?ooo`@000000P3oool2000000D0oooo0`0000000d000000000000000006000001h0oooo0P00000@
0?ooo`8000000P3oool3000000T0oooo100000080?ooo`<000000P3oool300000080oooo0P000007
0?ooo`030000040000000000008000002@3oool2000000D0oooo1@0000040?ooo`80000000=00000
0?ooo`3oool0C03oool00180oooo00D000000?ooo`3oool0oooo0000000E0?ooo`@0000000=00000
0?ooo`3oool00`0000000`3oool000000000000700000003@000003oool0oooo0080oooo0`000002
0?ooo`8000000P3oool2000000/0oooo0P0000000d000000oooo0?ooo`060?ooo`05@00000000000
00000000003oool00P00000014000000oooo0?ooo`00000A0?ooo`8000000P3oool2000000<0oooo
00E0000000000000000000000?ooo`0300000003@00000000000000000D0000000D0oooo00000000
00000000@0000005000000<0oooo00=000000000000000001@3oool5000000L0oooo00@000000?oo
o`00000000001@3oool500000080oooo00A000000000000000000000C`3oool000h0oooo00E00000
0?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?oood0000000`3oool01D000000oooo
0?ooo`3ooom0000000<0oooo00A000000?ooo`3oool0oooo1`0000020?ooo`<0000000A000000000
003oool0oooo1`0000020?ooo`030000003oool0oooo008000000`3oool01@000000oooo0?ooo`3o
ool0000000<0oooo00@000000?ooo`3oool0oooo100000001400000000000000003oool2000000<0
oooo2P0000020?ooo`050000003oool0oooo0?ooo`0000000`3oool01D000000oooo0?ooo`3ooom0
000000<0oooo00U000000?ooo`3oool0oooo0000003oool000000?ooo`0000000P3oool400000003
0?ooo`000000000000X0000000=00000000000000000100000000`3oool00000000000020?ooo`L0
00000P3oool00`000000oooo0?ooo`02000000<0oooo00<000000?ooo`3oool0100000000d000000
00000?ooo`020?ooo`@0000000<0oooo0000003oool0100000020?ooo`05@000003oool0oooo0?oo
od0000000`3oool01D000000oooo0?ooo`3ooom0000000<0oooo00E000000?ooo`3oool0oooo@000
00030?ooo`05@000003oool0oooo0?oood0000000`3oool00d000000oooo0?ooo`020?ooo`05@000
003oool0oooo0?oood0000000`3oool01D000000oooo0?ooo`3ooom0000000<0oooo00E000000?oo
o`3oool0oooo@00000030?ooo`03@000003oool0oooo00d0oooo000[0?ooo`H000000P3oool20000
00D0oooo1`0000020?ooo`<0000000<0oooo0000003oool00`3oool2000000030?ooo`0000000000
0080oooo00<000000?ooo`3oool00`3oool5000000030?ooo`000000000000D0oooo200000060?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool2000000@0oooo0`0000030?oo
o`80000000<0oooo0000000000001P0000040?ooo`<000000P3oool00`000000oooo0?ooo`040000
00040?ooo`0000000000000000H0oooo00<000000?ooo`3oool00P0000020?ooo`D00000103oool3
000000040?ooo`000000oooo0?ooo`<00000C`3oool002`0oooo1@0000090?ooo`03@00000000000
oooo0080oooo0P0000020?ooo`03000004000000000000800000103oool6000000030?ooo`000000
000000L0oooo0P0000020?ooo`8000001@3oool3000000040?ooo`0000000000000000H0oooo00<0
00000?ooo`3oool0103oool4000000D0oooo00A000000000000000000000103oool2000000<0oooo
1@0000000`3ooom00000000000070?ooo`@00000103oool01D0000000000000000000010000000<0
00002P3oool2000000030?ooo`000000000000@000000`3oool500000080oooo0P00001@0?ooo`00
:`3oool8000000h0oooo200000040?ooo`P0000000<0oooo0000000000000P000000140000000000
0000000000020?ooo`<000000`3oool400000004@000000000000000000000D0oooo0P0000020?oo
o`80000000=000000?oood0000000`0000001400000000000000000000020?ooo`<00000103oool0
0`000000oooo0?ooo`030?ooo`03000004000000000000<000000`3oool200000080oooo1@000000
1400000000000000003oool9000000L0oooo00=00000000000000000200000040?ooo`D0000000@0
oooo0000000000000000C`3oool000h0oooo00E000000?ooo`3oool0oooo@00000030?ooo`05@000
003oool0oooo0?oood0000000`3oool01D000000oooo0?ooo`3ooom0000000<0oooo00A000000?oo
o`3oool0oooo0T0000000`000010000000000005000000<0oooo00<000000?ooo`0000000P000003
0?ooo`X000000P3oool00`000000oooo00000007000000030?ooo`000000000000H000000P3oool3
00000090000000<0oooo0000000000001P0000020?ooo`03@000003oool0oooo00D0000000I00000
0000003oool0oooo@000003oool700000004@000000000000000000000<0oooo00<000000?ooo`00
00000P3oool01D0000000000000000000010000000<0000000E000000000000000000000@0000002
00000003@00000000000000000<0000000E000000000000000000000@000000300000080oooo0`00
00020?ooo`030000003oool0oooo00D0000000=000000000040000000`0000020?ooo`/000000P3o
ool01D000000oooo0?ooo`3ooom0000000<0oooo00E000000?ooo`3oool0oooo@00000030?ooo`05
@000003oool0oooo0?oood0000000`3oool01D000000oooo0?ooo`3ooom0000000<0oooo00=00000
0?ooo`3oool00P3oool01D000000oooo0?ooo`3ooom0000000<0oooo00E000000?ooo`3oool0oooo
@00000030?ooo`05@000003oool0oooo0?oood0000000`3oool00d000000oooo0?ooo`0=0?ooo`00
;P3oool4000000@0oooo1@0000070?ooo`/0000000<0oooo0000003oool0400000000`3oool00000
000000030?ooo`P000001@3oool7000000D0oooo100000030?ooo`8000001@3oool3000000<0oooo
1P0000001@3oool00000000000000010000000@000000P3oool6000000040?ooo`00000000000000
00<0oooo0`000000103oool000000?ooo`3oool4000000030?ooo`000000000000D0000000<0oooo
000000000000100000001D0000000000000000000010000004l0oooo000f0?ooo`@000002`3oool3
00000003@00000000000000000<000000P3oool500000090000000@000000?ooo`3oool0oooo1@00
00000`3oool000000?ooo`030?ooo`04@00000000000oooo0?ooo`<0000000=000000?ooo`3oool0
0`3oool200000003@000003oool0oooo008000001@3oool2@00000800000103oool2000000<0oooo
00A0000000000000000000000`3oool01400000000000000003oool200000080oooo1P0000040?oo
o`030000003oool000000080000000@0oooo00000000000000000`3oool3000000030?ooo`000000
00000080oooo0P0000030?ooo`D0000000=000000?ooo`3oool01P00001C0?ooo`00:@3oool40000
00040?ooo`0000000000000000@0oooo100000001400000000000000000000080?ooo`<0000000<0
oooo000000000000100000020?ooo`D000001@3oool4000000L0oooo00A000000000000000000000
0P3oool00`000000oooo0?ooo`0A0?ooo`@000000`3oool2000000D0oooo0`0000020?ooo`05@000
0000000000000000003oool00P0000020?ooo`80000000<0oooo000000000000103oool00`000000
oooo0?ooo`0200000080oooo0`0000000`3oool0000000000005000000030?ooo`000000000000<0
000000<0oooo0000000000000`0000030?ooo`H00000D`3oool000h0oooo00E000000?ooo`3oool0
oooo000000030?ooo`05@000003oool0oooo0?oood0000000`3oool01D000000oooo0?ooo`3ooom0
000000<0oooo00=000000?ooo`3oool02`0000001@3oool00000000000000000oooo00L000000`3o
ool500000005@000003oool000000000003oool00`0000000`3oool0000000000003000000030?oo
od000000oooo0080oooo100000001@3oool000000?ooo`3ooom0000000H000000P3oool01@000000
oooo0?ooo`3ooom0000000<0oooo00E000000000003oool0oooo@00000030?ooo`05@000003oool0
oooo0?ooo`0000000P3oool2000000<0oooo00D000000?ooo`3oool0oooo@00000030?ooo`800000
00<0oooo0000000000000P0000020?ooo`040000003oool0oooo0?ooo`H000000P3oool010000000
oooo0?oood00000=00000003@00000000000000000<0000000D0oooo00000000000000000?ooo`02
00000080oooo1`0000000d000000oooo@00000030?ooo`05@000003oool0oooo0?oood0000000`3o
ool01D000000oooo0?ooo`3ooom0000000<0oooo00E000000?ooo`3oool0oooo@00000030?ooo`05
@000003oool0oooo0?oood0000000`3oool00d000000oooo0?ooo`020?ooo`05@000003oool0oooo
0?oood0000000`3oool01D000000oooo0?ooo`3ooom0000000<0oooo00E000000?ooo`3oool0oooo
@00000030?ooo`03@000003oool0oooo00d0oooo000B0?ooo`030000003oool0oooo01@0oooo2@00
00020?ooo`@000000P3oool4000000H0oooo1P0000001P3oool00000000000000000oooo00000080
oooo100000000d000000oooo0?ooo`040?ooo`04@000003oool0oooo000000D0oooo1000000:0?oo
o`<000007@3oool3000000H0oooo00=00000000000000000100000040?ooo`H0000000=000000000
000000002`0000000d000000000000000002000000040?ooo`000000oooo0?ooo`<0000000<0oooo
000000000000E03oool00180oooo00<000000?ooo`3oool0503oool00d00000000000?ooo`020?oo
o`03@00000000000oooo00@0oooo0`0000020?ooo`<00000203oool6000000040?ooo`0000000000
0?ooo`8000000P3oool2000000X0oooo0P0000060?ooo`<000002@3oool014000000000000000000
000M0?ooo`<000001`3oool200000004@000000000000000000000@0oooo00M00000000000000000
0000@00000000000oooo0080000000=000000000000000001`0000030?ooo`<0000000=000000?oo
o`3oool00P3oool6000005<0oooo000A0?ooo`8000000P3oool200000003@000003oool0oooo0100
oooo0P0000000d000000oooo00000003000000040?ooo`00000000000?ooo`8000000P3oool20000
00/0oooo100000000d000000000000000003000000040?ooo`0000000000000000X0oooo0P000000
0d000000oooo0?ooo`030?ooo`8000001P3oool300000080oooo1000000@0?ooo`8000000T000003
000000@0oooo00E000000000000000000000@0000003000000@0oooo1P0000040?ooo`@000000`3o
ool400000003@00000000000000000<000000`3oool4000000<0oooo2000001C0?ooo`003P3oool0
0d000000oooo0?ooo`0500000005@00000000000oooo0?oood0000000`3oool01D000000oooo0?oo
o`3ooom0000000<0oooo100000001400000000000000003oool;00000080oooo00D000000?ooo`3o
ool0oooo000000020?ooo`@0000000<0oooo0000003oool0300000020?ooo`040000003oool0oooo
0?ooo`L000000P3oool01D000000oooo0?ooo`3oool0000000<0oooo00=000000000003oool01P00
0000103oool000000000000000030?ooo`05@000003oool0oooo0?oood0000000`3oool;00000080
oooo00=000000?ooo`0000001`0000020?ooo`0300000400000000000080000000@0oooo00000000
000000000`3oool00`000000oooo0000000200000080oooo0P0000000`3oool00000000000060000
0080oooo00D000000?ooo`000000oooo000000020?ooo`T0000000<0oooo@000003oool00P3oool0
1D000000oooo0?ooo`3ooom0000000<0oooo00E000000?ooo`3oool0oooo@00000030?ooo`05@000
003oool0oooo0?oood0000000`3oool01D000000oooo0?ooo`3ooom0000000<0oooo00=000000?oo
o`3oool00P3oool01D000000oooo0?ooo`3ooom0000000<0oooo00E000000?ooo`3oool0oooo@000
00030?ooo`05@000003oool0oooo0?oood0000000`3oool00d000000oooo0?ooo`0=0?ooo`004@3o
ool700000100oooo1@0000000`3oool000000000000:000000030?ooo`000000oooo00800000103o
ool700000080oooo2P0000000`3oool000000?ooo`040?ooo`D000001P3oool010000000oooo0?oo
o`3oool7000000D0oooo00<000000?ooo`3oool02`3oool8000000H0oooo0`000000103oool00000
0000000000030?ooo`@000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?oo
o`3oool0oooo@00000020?ooo`<000000P3oool3000000030?ooo`000000000000<0oooo2P000000
0d000000oooo0?ooo`1@0?ooo`004@3oool200000003@000003oool0oooo008000004`3oool20000
00030?oood000000000000<0oooo00=000000000000000000P0000000d000000oooo0?ooo`040000
00D0oooo1P0000030?ooo`030000040000000000009000000`00000014000000oooo000000000005
0?ooo`@000002@3oool01T00000000000000000000100000000001L0oooo1P0000060?ooo`<00000
00@0oooo0000000000000000103oool4000000040?ooo`0000000000000000H0oooo00<000000?oo
o`3oool00P0000030?ooo`8000000P3oool6000000@0oooo00<00000@000040000000`00001F0?oo
o`00<`3oool4000000<0oooo100000080?ooo`D000000P3oool300000080oooo00=0000000000000
000010000002@00000<0000000<0oooo0000000000000`3oool01000001000000000000000040?oo
o`80000000A0000000000000000000000P3oool01T00000000000?ooo`3ooom0000000000080oooo
00@00000@000003ooom000000`0000040?ooo`<0000000<0oooo@000000000000`0000040?ooo`80
00000P3oool2000000030?oood000000000000<0000000E000000000000000000000@00000030000
00D0oooo1P0000020?ooo`80000000<0oooo@000000000001P0000030?ooo`D0000000A000000000
000000000000D`3oool003<0oooo00=000000000000000000P0000020?ooo`H0000000A000000?oo
o`3oool000000`3oool500000080oooo0P0000020?ooo``0000000D0oooo0000000000000000@000
0008000000<0oooo1@0000000`3oool000000000000=000000@0oooo0`0000000d00000000000000
000400000080oooo00A000000?ooo`000000oooo0T00000<000000040?ooo`0000000000000000<0
oooo00I000000000000000000000@000000000030?ooo`040000003oool0oooo0?ooo`H0000000=0
00000?ooo`0000000P3oool8000000030?ooo`00000000000500oooo000>0?ooo`05@000003oool0
oooo0?oood0000000`3oool01D000000oooo0?ooo`3ooom0000000<0oooo00E000000?ooo`3oool0
oooo@00000030?ooo`05@000003oool0oooo0?oood000000103oool01T000000oooo0?ooo`3ooom0
00000?ooo`@0000000<0oooo0000000000001@0000020?ooo`050000003oool0oooo0?oood000000
1P000000103oool000000000003oool;000000030?ooo`000000000000@0000000=0000000000000
00001P0000020?ooo`P0000000<0oooo000000000000200000020?ooo`05@000003oool0oooo0000
040000001P0000000`3oool000000000000>000000040?ooo`000000oooo0?ooo`8000000P3oool2
000000030?ooo`000000000000H000000P3oool010000000oooo0?ooo`3oool3000000030?ooo`00
000000000080oooo0P0000020?ooo`<0000000<0oooo000000000000100000030?ooo`05@000003o
ool0oooo0?oood0000000`3oool01D000000oooo0?ooo`3ooom0000000<0oooo00E000000?ooo`3o
ool0oooo@00000030?ooo`05@000003oool0oooo0?oood0000000`3oool00d000000oooo0?ooo`02
0?ooo`05@000003oool0oooo0?oood0000000`3oool01D000000oooo0?ooo`3ooom0000000<0oooo
00E000000?ooo`3oool0oooo@00000030?ooo`03@000003oool0oooo00d0oooo000d0?ooo`H00000
00<0oooo0000000000000`0000030?ooo`030000003oool0oooo0080000000<0oooo000000000000
1P0000020?ooo`<0000000E0000000000000000000000?ooo`02000000030?ooo`000000000000H0
000000=000000000000000001P3oool300000080oooo0`0000000`3oool000000000000400000004
0?ooo`0000000000000000D0oooo1`00000014000000oooo0?ooo`3oool9000000030?oood000000
00000080000000<0oooo0000003oool0203oool8000000L0oooo0`0000040?ooo`8000000`3oool7
00000580oooo000c0?ooo`05@0000000000000000000040000000`0000001D000000oooo0?ooo`3o
ool000000080oooo0P0000000`3oool0000000000005000000030?ooo`000000000000P00000103o
ool2000000030?oood000000000000@00000103oool00`00001000000?ooo`040?ooo`8000000`3o
ool01400000000000?ooo`3oool2000000H0oooo0P0000040?ooo`L00000103oool:00000003@000
00000000000000H000001P3oool200000003@00000000000000000<000000`3oool00`000000oooo
0?ooo`020?ooo`<0000000=000000?ooo`3oool00P3oool200000080oooo1P000000140000000000
00000000000Q0?ooo`800000;03oool003@0oooo10000000103oool000000000000000060?ooo`T0
00000P3oool300000003@00000000000000000<0000000=000000?ooo`3oool00P3oool00`000000
oooo0?ooo`04000000@0oooo00E000000000000000100000000000020?ooo`07@000000000000000
00000400000000000?ooo`03000000040?ooo`0000100000000000<0oooo00@00000@00000000000
00000`3oool00`00001000000000000200000005@000000000000000@000000000000P3oool01@00
001000000000003oool0000000900000200000000d0000000000@0000002000000D0oooo1P000000
0`3oool000000?ooo`020?ooo`8000000P3oool5000000<0oooo0`0000000d000000oooo00000002
00000003@00000000000oooo00D00000803oool5000002T0oooo000>0?ooo`05@000003oool0oooo
0?oood0000000`3oool01D000000oooo0?ooo`3ooom0000000<0oooo00E000000?ooo`3oool0oooo
@00000030?ooo`05@000003oool0oooo0?oood000000103oool01D000000oooo0?ooo`3ooom00000
0080oooo0P0000030?ooo`8000000P3oool7000000030?ooo`000000000000l000000`3oool01000
0000oooo0?ooo`3oool300000080oooo4`0000000`3oool0000000000008000000030?oood000000
000000@0000000<0oooo0000000000003`000000103oool000000000000000020?ooo`D000000`3o
ool00`000000oooo0?ooo`0300000080oooo0`0000000`3oool00000000000020?ooo`8000000P3o
ool200000080oooo0P0000030?ooo`8000000P3oool00`000000oooo00000006000000<0oooo00E0
00000?ooo`3oool0oooo@00000030?ooo`05@000003oool0oooo0?oood0000000`3oool01D000000
oooo0?ooo`3ooom0000000<0oooo00=000000?ooo`3oool01`0000030?ooo`05@000003oool0oooo
0?oood0000000`3oool01D000000oooo0?ooo`3ooom0000000<0oooo00E000000?ooo`3oool0oooo
@000000?0?ooo`00>03oool2000000H0oooo1@0000040?ooo`80000000=000000000000000000`00
00000`3ooom0000000000005000000H0oooo0`0000030?ooo`L0000000D0oooo0000000000000000
0?ooo`05000000<0oooo0`0000020?ooo`h0000000D0oooo00000000000000000?ooo`0300000003
0?ooo`000000000000@0000000@0oooo00000000000000000P3oool3000000T0oooo0P0000030?oo
o`H0000000<0oooo0000000000000P3oool3000000050?ooo`00000000000000003oool00P000005
0?ooo`04@00000000000000000000240oooo00=00000000000000000:`3oool00380oooo0P000004
0?ooo`<000001P3oool3000000H0oooo0P0000030?ooo`03000004000000oooo0080oooo10000004
0?ooo`03000004000000oooo008000000`3oool7000000050?ooo`00000000000000003oool00`00
00000`3oool00000000000020?ooo`<000000P3oool3000000030?ooo`000000000000D0000000@0
oooo000000000000oooo0`0000020?ooo`8000000P3oool2000000030?ooo`00000000000080oooo
0P0000020?ooo`@000002@3oool00`000000oooo0?ooo`030?ooo`D000000P3oool200000080oooo
0`0000000`3oool0000000000004000000D0oooo0P00001@0?ooo`00<P3oool4000000030?oood00
0000000000<000000`3oool01@000000oooo0000003oool0000000@0oooo2@0000030?ooo`800000
00E000000000000000000000@000000300000080oooo00@00000@00000000000oooo0P0000001D00
00000000000000000010000000<0000000I0000000000000000000000?oood000002000000060?oo
od00000000000000003ooom000000P0000030?ooo`9000000`0000020?ooo`8000000P3oool20000
0080oooo0P0000020?ooo`80000000/0oooo@000003oool00000@00000000000oooo000004000000
oooo@0000004000000<0oooo00E00000000000000000oooo@0000002000000<0oooo1P0000001D00
00000000000000000010000000@0000000=00000000000000000100000060?ooo`030000003oool0
oooo02@0oooo00A0000000000000000000009P3oool000h0oooo00E000000?ooo`3oool0oooo@000
00030?ooo`05@000003oool0oooo0?oood0000000`3oool01D000000oooo0?ooo`3ooom0000000<0
oooo00E000000?ooo`3oool0oooo@00000040?ooo`03@000003oool0oooo00H0000000<0oooo0000
000000000P0000020?ooo`04@0000000000000000?ooo`8000000P3oool:00000080oooo00<00000
0?ooo`3oool0200000020?ooo`D0000000<0oooo0000000000002P0000001@3oool0000000000000
0000oooo00<0000000@0oooo00000000000000000P3oool600000080oooo00D000000?ooo`3oool0
oooo000000030?ooo`8000000P3oool00d00000000000000000?00000080oooo0`0000001@3oool0
0000000000000000oooo008000000P3oool500000003@00000000000oooo00@0000000<0oooo0000
000000001000000014000000oooo0?oood0000030?ooo`050000003oool0oooo0?oood0000000`3o
ool01D000000oooo0?ooo`3ooom0000000<0oooo00E000000?ooo`3oool0oooo@00000030?ooo`05
@000003oool0oooo0?ooo`0000000`3oool01D000000oooo0?ooo`3ooom000000080oooo10000002
0?ooo`05@000003oool0oooo0?oood0000000`3oool01D000000oooo0?ooo`3ooom0000000<0oooo
00E000000?ooo`3oool0oooo@000000?0?ooo`00<P3oool00d0000000000000000070?ooo`800000
0P3oool3000000030?ooo`000000000000@0oooo00A00000000000000000oooo0`0000050?ooo`<0
000000<0oooo0000000000000P0000020?ooo`<000000P3oool400000003@000003oool000000080
000000D0oooo00000000000000000?ooo`03000000050?ooo`00000000000000003oool00`000003
0?ooo`D000001`3oool00d000000oooo0?ooo`030?ooo`T0000000<0oooo00000000000010000005
0?ooo`<0000000<0oooo0000000000000`0000050?ooo`d000000`3oool00`000000oooo0?ooo`0Q
0?ooo`030000003oool0oooo00T0oooo0`00000V0?ooo`00=P3oool2000000P0oooo0`0000001400
000000000000000000040?ooo`03000004000000oooo00T0oooo0P0000020?ooo`8000000`3oool2
000000<0oooo0`0000030?ooo`80000000A000000?ooo`00000000000`3oool01@000000oooo0?oo
o`3oool0000000<0oooo00@000000?ooo`3oool0oooo1@0000060?ooo`<00000103oool900000080
oooo1`0000050?ooo`P000001P3oool<00000080oooo0P0000070?ooo`03000004000000oooo01T0
oooo0P0000070?ooo`03000004000000oooo008000009`3oool00140oooo00=00000000000000000
8P3ooolA00000003@000003oool0000000<000000P3oool01@000000oooo0?ooo`3oool0000000<0
oooo00D000000?oood000000oooo000000030?ooo`80000000=000000000000000000P0000040?oo
o`05@000000000000000000004000000100000001@3oool000000?ooo`3ooom00000008000000P3o
ool010000000oooo0?ooo`3oool200000080oooo00<000000?ooo`3oool00P3oool600000080oooo
00<00000@000000000001P0000020?ooo`8000000P3oool01D000000000000000400000000000080
oooo00=000000?ooo`0000000P000000103oool000000000000000020?ooo`040000003oool0oooo
0?ooo`P0000000<0oooo0000000000000P0000020?ooo`<0000000=000000000000000001@00000I
0?ooo`<00000103oool500000080oooo00<000000?ooo`3oool09@3oool000h0oooo00=000000?oo
o`3oool00`0000020?ooo`05@000003oool0oooo0?oood0000000`3oool01D000000oooo0?ooo`3o
oom0000000<0oooo00E000000?ooo`3oool0oooo@00000040?ooo`05@000003oool0oooo0?oood00
00000P3oool<000000030?ooo`000000oooo00T0000000A00000000000000000oooo0P0000030?oo
o`030000003oool00000008000000`3oool00`000010000000000003000000<0oooo2`000000103o
ool000000?ooo`3oool300000080oooo00D000000?ooo`3ooom00000000000030?ooo`04@000003o
ool0oooo0?ooo`d0000000=000000000000000000P0000020?ooo`8000000P3oool00d0000000000
00000003000000030?ooo`000000000000<0000000=000000000040000000P3oool200000080oooo
0`0000000`3oool000000?ooo`0300000080oooo0`000000103oool0000000000400000700000005
@00000000000oooo0?ooo`0000000`3oool01D000000oooo0?ooo`3ooom0000000<0oooo00E00000
0?ooo`3oool0oooo@00000030?ooo`05@000003oool0oooo0000040000000P0000000`3oool00000
0000000200000003@0000000000000000080oooo00D000000?ooo`3oool0oooo@00000030?ooo`05
@000003oool0oooo0?oood0000000`3oool01D000000oooo0?ooo`3ooom0000000<0oooo00=00000
0?ooo`3oool03@3oool00140oooo0`00000R0?ooo`03@00000000000000000<0oooo0`0000060?oo
o`030000003oool0oooo0080oooo00<00000@000000000001`0000040?ooo`D000000P3oool60000
00D0oooo100000000`3oool00000@0000003000000<0oooo0`0000040?ooo`<000000P3oool20000
00@0oooo00=00000000000000000200000020?ooo`<000001P3oool<00000080oooo00=000000?oo
o`3oool00`0000050?ooo`80000000D0oooo0000003oool0oooo@00000020?ooo`80000000H0oooo
0000000000000000@000003oool3000000040?ooo`000000000000000080oooo00<000000?ooo`3o
ool0503oool300000003@000003oool0oooo0080oooo1000000Z0?ooo`004P3oool00`000000oooo
0?ooo`0W0?ooo`03@000003oool0oooo00/0oooo2P0000040?ooo`@0000000<0oooo000000000000
0`0000000`3oool00000000000040?ooo`@000000P3oool5000000@0oooo00<000000?ooo`3oool0
0P3oool9000000@0oooo0`0000020?ooo`@00000103oool3000000@0oooo1`000000103oool00000
0000000000030?ooo`80000000@0oooo00000000000000001P3oool3000000050?ooo`0000000000
0000003oool00`0000060?ooo`8000001P3oool2000004`0oooo000B0?ooo`030000003oool0oooo
02H0oooo100000060?ooo`03@00000000000000000X0000000E0000000000000000000000?ooo`03
00000080oooo0P0000001D0000000000000000000010000000<000000P3oool01d00000000000000
003oool000000?oood0000000P000000103oool000000000000000030?ooo`03@00000000000oooo
0080oooo0`0000000`3oool000000000000300000004@000000000000000@00000<000000P3oool0
1400000000000000000000050?ooo`80000000=000000000003oool01P0000020?ooo`8000000`3o
ool800000005@000003oool000000000003oool03@0000001400000000000000000000020?ooo`03
0000003oool0oooo00@0oooo0`00000E0?ooo`04@00000000000000000000380oooo000>0?ooo`05
@000003oool0oooo0?ooo`0000000`3oool01D000000oooo0?ooo`3ooom0000000<0oooo00D00000
0?ooo`3oool0oooo000000030?ooo`05@000003oool0oooo0?oood000000103oool01D000000oooo
0?ooo`3ooom0000000<0oooo00A000000?ooo`3oool0oooo1`0000000`3oool00000000000050000
00050?ooo`0000000000@000003oool01`0000000`3oool000000?ooo`020?ooo`/0000000<0oooo
0000000000000P0000000`3oool000000?ooo`03000000<0oooo00@000000?ooo`3oool0oooo0`00
00000`3oool00000000000020?ooo`80000000<0oooo0000000000002@0000000`3oool000000000
0005000000<0oooo1P0000001@3oool000000000003ooom00000008000000`3oool3000000030?oo
o`00000000000180000000=00000000004000000100000020?ooo`060000003oool0oooo0?oood00
0000oooo0P0000001D00000000000?ooo`3ooom0000000<0oooo00E000000?ooo`3oool0oooo@000
00030?ooo`05@000003oool0oooo0?oood0000000P3oool4000000030?oood000000oooo0080oooo
00=000000?ooo`3oool00P3oool01D000000oooo0?ooo`3ooom0000000<0oooo00E000000?ooo`3o
ool0oooo@00000030?ooo`05@000003oool0oooo0?oood0000000`3oool00d000000oooo0?ooo`0=
0?ooo`007P3oool01@000000oooo0?ooo`3oool0000001P0oooo1@000000103oool000000?ooo`3o
ool5000000<0oooo0`0000000`3oool000000?ooo`04000000L0oooo2@0000020?ooo`8000000`3o
ool3000000P0oooo0`0000080?ooo`03@00000000000000000D000000P3oool00`000000oooo0000
0003000000L0oooo0P0000060?ooo`@000002P3oool200000004@000000000000000@00000<00000
103oool4000000@0oooo0`0000080?ooo`<0000000=000000?ooo`3oool04`3oool3000003<0oooo
000N0?ooo`8000000P3oool2000001L0oooo00=000000000003oool00P3oool300000080oooo0`00
000014000000oooo0?ooo`3oool4000000<0oooo00A0000000000000000000001@3oool9000000<0
oooo0P0000030?ooo`8000002@3oool2000000/0oooo1P0000030?ooo`D000001P3oool3000000D0
oooo1000000;0?ooo`80000000<0oooo0000000000001@0000040?ooo`<0000000A000000?ooo`3o
ool0oooo0P00000S0?ooo`800000<`3oool001d0oooo0`000000103oool0000000000000000K0?oo
o`04@00000000000000000000080oooo0`0000030?ooo`@000000`3oool200000004@00000000000
0000000000@0oooo0P0000020?ooo`80000000<0oooo@000000000000P000000103oool000000?oo
o`3oool300000004@000000000000000000000H0oooo0`0000090?ooo`80000000<0oooo@0000000
00000P0000000d00000000000000000400000003@00000000000000000@0oooo0P0000050?ooo`<0
00001`3oool01@000000oooo0?ooo`000000oooo00@0000000<0oooo000004000000100000030?oo
o`@000001@3oool00`000000oooo0?ooo`070?ooo`04@000000000000000000001H0oooo00<00000
0?ooo`3oool01000000^0?ooo`003P3oool01D000000oooo0?ooo`3ooom0000000<0oooo00E00000
0?ooo`3oool0oooo@00000020?ooo`0300000400000000000080000000E00000000000000000oooo
@00000030?ooo`03@000003oool0oooo0080oooo00E000000?ooo`3oool0oooo@00000030?ooo`05
@000003oool0oooo0?oood0000000`3oool00d000000oooo0000000200000080oooo0P0000030?oo
o`80000000<0oooo0000000000001P0000000`3oool00000000000020?ooo`040000003oool0oooo
0?ooo`8000000P3oool4000000030?ooo`000010000000T0000000<0oooo0000003oool00P3oool6
000000030?oood000000000000<0oooo00<000000?ooo`000000200000020?ooo`D000000`3oool0
10000000oooo0?oood00000600000080oooo00@000000?ooo`3oool0oooo0P0000020?ooo`H00000
00<0oooo0000000000000P0000000`3oool00000000000020?ooo`<0000000<0oooo@000003oool0
0`3oool01@000000oooo0?ooo`3ooom0000000<0oooo00=000000?ooo`0000000`0000020?ooo`05
@000003oool0oooo0?oood0000000`3oool01D000000oooo0?ooo`3ooom0000000<0oooo00E00000
0?ooo`3oool0oooo000000020?ooo`L000000`3oool01D000000oooo0?ooo`3ooom0000000<0oooo
00E000000?ooo`3oool0oooo@00000030?ooo`05@000003oool0oooo0?oood0000000`3oool00d00
0000oooo0?ooo`0=0?ooo`007@3oool300000005@0000000000000000000040000007P3oool20000
00D0oooo00<000000?ooo`3oool0103oool400000003@000003oool0oooo00/0oooo0`0000040?oo
o`@0000000<0oooo000004000000100000030?ooo`03@00000000000000000<0oooo100000040?oo
o`@0000000@0oooo00000000000000000`3oool3000000030?ooo`00000000000080oooo00A00000
0?ooo`00000000000`3oool300000080oooo1@0000030?ooo`D0000000=000000?ooo`3oool00`00
00050?ooo`8000004P3oool3000001T0oooo00=00000000000000000;`3oool004h0oooo00<00000
@000003oool04P3oool3000000D0oooo0P0000020?ooo`L000001`3oool4000000@0oooo1@000002
0?ooo`8000000`3oool200000080oooo2@0000080?ooo`@000000P3oool00d000000000000000003
000000<0oooo0P0000020?ooo`040000003oool0oooo0?ooo`<000004@3oool2000004`0oooo0016
0?ooo`@000000P3oool4000000H0oooo00A000000000000000000000103oool00d00000000000000
0004000000030?ooo`000000oooo00<0oooo0P0000030?ooo`030000003oool0000000D000000P3o
ool00d000000oooo0?ooo`02000000030?ooo`000000oooo00<0oooo0P0000000`3oool000000?oo
o`020?ooo`040000003oool0oooo0?ooo`8000000`3oool7000000T0oooo1P0000030?ooo`<00000
103oool2000000030?ooo`00000000000080000000@0oooo0000000000000000103oool400000004
@000000000000000000000H0oooo00<000000?ooo`3oool0203oool200000003@000003oool0oooo
01<0oooo00A0000000000000000000009P3oool000h0oooo00E000000?ooo`3oool0oooo@0000003
0?ooo`05@000003oool0oooo0?oood0000000`3oool01D000000oooo0?ooo`3ooom0000000<0oooo
00E000000?ooo`3oool0oooo@00000040?ooo`05@000003oool0oooo0?oood0000000`3oool01D00
0000oooo0?ooo`3ooom0000000<0oooo00A000000?ooo`3oool0oooo1P0000000`3oool000000000
0005000000030?ooo`000000000000H0000000@0oooo0000003oool0oooo2@0000000d0000000000
0?ooo`020?ooo`050000003oool0oooo0?ooo`0000000P3oool00d00000000000000000300000004
0?ooo`0000000000000000<0oooo0P0000020?ooo`050000003oool0oooo0?ooo`0000000`3oool0
10000000oooo0?ooo`3oool200000080oooo1`0000020?ooo`050000003oool0oooo0?ooo`000000
0`3oool00`000000oooo@000000300000080oooo00=000000000000000000P0000030?ooo`030000
003oool0oooo00P000000T0000020?ooo`P000000P3oool01D000000oooo0?ooo`3oool0000000<0
oooo00A000000?ooo`3oool0oooo100000001D00000000000?ooo`3ooom0000000<0oooo00E00000
0?ooo`3oool0oooo@00000030?ooo`05@000003oool0oooo0?oood0000000P3oool400000080oooo
00E000000?ooo`3oool0oooo@00000030?ooo`05@000003oool0oooo0?oood0000000`3oool01D00
0000oooo0?ooo`3ooom0000000l0oooo00140?ooo`D00000103oool4000000030?ooo`0000100000
00H0000000<0oooo0000000000000P3oool500000003@00000000000000000D00000103oool00d00
0000oooo0?ooo`0300000003@000003oool0oooo00@00000103oool2000001<0oooo00<000000?oo
o`3oool0103oool010000000oooo0?ooo`3oool2000000040?ooo`00000000000?ooo`@000000`3o
ool200000003@000003oool0oooo00D0oooo00=000000000000000000P3oool2000000D0oooo00=0
00000000000000000P3oool300000140oooo0`00000F0?ooo`<000009P3oool004@0oooo00A00000
0?ooo`3oool0oooo0P0000040?ooo`8000000P3oool500000005@0000000000000000000003oool0
0P0000000`3oool00000000000040?ooo`P0000000A000000000000000000000203oool3000000D0
oooo0`0000030?ooo`03000004000000oooo0180oooo0P0000030?ooo`80000000@0oooo00000000
0000oooo1000000:0?ooo`030000003oool0oooo00<000002P3oool200000080oooo0P00000[0?oo
o`8000009`3oool001d0oooo0P0000000d000000oooo0?ooo`0L0?ooo`<000001`3oool400000003
@00000000000000000H000000P3oool00`000000oooo00000005000000030?ooo`000000oooo00<0
oooo0`0000020?ooo`P000001P3oool2000000L0oooo200000080?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool00`0000030?ooo`@0000000D0oooo0000000000100000000000090?oo
o`03@00000000000000000D00000203oool01400000000000000000000020?ooo`030000003ooom0
000000<000004@3oool3000001<0oooo00<000000?ooo`3oool09@3oool000h0oooo00E000000?oo
o`3oool0oooo@00000030?ooo`04@000003oool0oooo0?ooo`@0000000E000000000003oool0oooo
@00000030?ooo`05@000003oool0oooo0?oood000000103oool01D000000oooo0?ooo`3ooom00000
00<0oooo00E000000?ooo`3oool0oooo@00000020?ooo`H000000`3ooolA00000003@000003oool0
oooo00@0000000=000000000003oool00P3oool2000000030?ooo`00000000000080oooo0`000000
0`3oool000000000000400000080oooo1P0000030?ooo`X000000P3oool010000000oooo0?ooo`3o
ool2000000<0oooo00<000000?ooo`3oool01`000000103oool0000000000400000200000003@000
00000000000000X0000000=000000?ooo`000000100000001D0000000000@000003ooom0000000<0
oooo00<000000?ooo`3oool0100000020?ooo`030000003oool0000000<000000P3oool01@000000
oooo0?ooo`3ooom0000000<0oooo00E000000?ooo`3oool0oooo@00000020?ooo`H000000`3oool0
1D000000oooo0?ooo`3ooom0000000<0oooo00=000000?ooo`3oool00P3oool01@000000oooo0?oo
o`3ooom0000000<0oooo00E000000?ooo`3oool0oooo@00000030?ooo`05@000003oool0oooo0?oo
od0000000`3oool00d000000oooo0?ooo`0=0?ooo`007@3oool3000001h0oooo00=0000000000000
00001`3oool00d000000000000000002000000030?ooo`000010000000D0oooo100000040?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`04
@000000000000000000000@0oooo100000040?ooo`80000000<0oooo0000040000000P0000060?oo
o`030000003oool0oooo008000000`3oool2000000030?ooo`000000000000D0000000=000000?oo
o`0000002`0000000`3oool0000000000004000000040?ooo`0000000000000000X0oooo00<00000
0?ooo`3oool0100000050?ooo`<000000P3oool00`000000oooo0?ooo`0<0?ooo`03@00000000000
000003/0oooo001;0?ooo`8000002P3oool3000000D0oooo0P00000@0?ooo`<000000`3oool00d00
000000000?ooo`040?ooo`<000002`3oool5000000050?ooo`00000000000000003oool00P000000
0d000000000000000003000000<0oooo0`0000001@3oool00000000000000000oooo00<000000`3o
ool4000000030?ooo`0000000000008000002@3oool200000080oooo0P0000060?ooo`8000000P3o
ool2000000l0oooo00<000000?ooo`3oool0>P3oool004L0oooo0`0000000`3oool0000000000002
000000P0oooo1@0000020?ooo`L0000000=000000?ooo`3oool02P3oool200000003@000003oool0
oooo00H0oooo100000020?ooo`8000000P3ooolA00000080oooo0`0000040?ooo`03000004000000
000000<0000000@0oooo@0000000000000001@3oool01400000000000000003oool3000000900000
2P0000030?ooo`030000003oool0oooo00D0oooo00<00000@000040000000`00000=0?ooo`<00000
3P3oool200000003@000003oool0oooo02P0oooo000>0?ooo`05@000003oool0oooo0?oood000000
0`3oool01D000000oooo0?ooo`3ooom0000000<0oooo00E000000?ooo`3oool0oooo@00000030?oo
o`05@000003oool0oooo0?oood000000103oool01D000000oooo0?ooo`3ooom0000000<0oooo00E0
00000?ooo`3oool0oooo@00000030?ooo`05@000003oool0oooo0?ooo`0000000`3oool:00000080
oooo0P0000020?ooo`03@00000000010000000<0000000<0oooo@000000000001P0000020?ooo`05
0000003oool0oooo0?ooo`0000000`3oool00`000000oooo00000002000000<0oooo00H000000?oo
o`3oool0oooo0000003oool300000003@0000000000000000080000000<0oooo0000000000001`00
00002@3oool00000000004000000oooo0000040000000000@000000500000080oooo1`000000103o
ool000000000000000020?ooo`H0000000<0oooo0000000000000P3oool<00000080oooo00D00000
0?ooo`3oool0oooo000000030?ooo`H000000P3oool01D000000oooo0?ooo`3ooom0000000<0oooo
00I000000?ooo`3oool00000@000000000020?ooo`05@000003oool0oooo0?oood0000000`3oool4
00000003@0000000000000000080oooo00E000000?ooo`3oool0oooo@00000030?ooo`05@000003o
ool0oooo0?oood0000000`3oool01D000000oooo0?ooo`3ooom0000000<0oooo00=000000?ooo`3o
ool03@3oool004<0oooo00@000000?ooo`3oool0oooo100000000d0000000000000000040?ooo`80
0000103oool500000004@000003oool0oooo0?ooo`D0000000<0oooo000000000000103oool20000
0080oooo0`000000103oool000000000003oool2000000<0oooo10000000103oool0000000000000
00020?ooo`L0000000A00000000000000000oooo2P00000014000000oooo0?ooo`3oool600000080
oooo0`0000030?ooo`D000001@3oool;00000003@000003oool0oooo00@0oooo00<000000?ooo`3o
ool00P3oool5000000d0oooo0P0000000d000000oooo0?ooo`0:0?ooo`D00000:P3oool004<0oooo
00H000000?ooo`3oool0oooo@000000000070?ooo`@00000103oool5000000L0oooo100000050?oo
o`<0000000D0oooo00000000000000000?ooo`0600000080oooo20000000140000000000@0000000
00040?ooo`h000001P3oool4000000@0oooo00H000000?ooo`3oool0oooo0000003oool4000000D0
oooo00E00000000000000000oooo@0000003000000T0oooo0P0000030?ooo`D00000803oool20000
02X0oooo000n0?ooo`<0000000@0oooo00000000000000001P3oool3000000030?ooo`0000000000
008000001@3oool7000000H0oooo0`0000060?ooo`80000000I000000?ooo`0000000000@000003o
ool200000003@0000000000000000080000000<0oooo000000000000200000040?ooo`@0000000@0
oooo00000000001000001P0000060?ooo`<000001P3oool020000000oooo0?ooo`3oool000000?oo
o`00001000000P0000050?ooo`80000000=000000?ooo`3oool0103oool200000003@000003oool0
oooo00<0oooo0P0000000`3ooom000000000000200000080oooo00<000000?ooo`3oool0203oool0
0d00000000000000000o0?ooo`003P3oool01D000000oooo0?ooo`3ooom0000000<0oooo00E00000
0?ooo`3oool0oooo@00000030?ooo`05@000003oool0oooo0?oood0000000`3oool01D000000oooo
0?ooo`3ooom0000000@0oooo00E000000?ooo`3oool0oooo@00000030?ooo`05@000003oool0oooo
0?oood0000000P3oool700000080oooo00A000000?ooo`3oool0oooo2`0000000`3oool000000000
00020?ooo`h000000`3oool00`000000oooo00000006000000030?ooo`000000000000T0000000=0
00000000000000000`0000001@3oool000000?ooo`000000oooo00h000000`3oool600000080oooo
00D000000?ooo`3oool0oooo000000020?ooo`8000000P3oool300000080oooo1P0000020?ooo`@0
000000=000000000000000000P3oool01D000000oooo0?ooo`000010000000D000000P3oool01@00
0000oooo0?ooo`3ooom0000000<0oooo00=000000?ooo`3oool00`0000020?ooo`05@000003oool0
oooo0?oood0000000`3oool01D000000oooo0?ooo`3ooom0000000<0oooo00=000000?ooo`3oool0
0P3oool01D000000oooo0?ooo`3ooom0000000<0oooo00E000000?ooo`3oool0oooo@00000030?oo
o`05@000003oool0oooo0?oood0000000`3oool00d000000oooo0?ooo`0=0?ooo`00?P3oool60000
0003@000003oool0oooo00@0oooo100000000`3oool0000000000002000000<0oooo00@000000?oo
o`3oool0oooo100000000d000000000000000006000000<0oooo1P0000020?ooo`<0000000<0oooo
000000000000100000020?ooo`03000004000000oooo00@0000000=000000?oood00000010000000
1`3ooom00000000000000000oooo000004000000100000000d00000000000?ooo`040?ooo`@00000
00<0oooo0000000000001P3oool200000080oooo0`0000040?ooo`@00000103oool5000000@0oooo
10000000103oool0000000000000000=0?ooo`<00000?`3oool003h0oooo00=000000000003oool0
2P3oool00d00000000000?ooo`020?ooo`03@00000000000oooo00P0oooo00=00000000000000000
10000000103oool00000@000000000030?ooo`<0000000<0oooo0000000000001@3oool300000003
0?ooo`000000000000<0000000=000000?ooo`3oool00P3oool2000000<0oooo1P00000014000000
oooo0000000000030?ooo`<000002P3oool5000000H0oooo0`0000020?ooo`030000003oool0oooo
00D0oooo0P0000070?ooo`800000103oool300000004@000003oool00000000000l0oooo00<00000
0?ooo`3oool0?P3oool004X0oooo0`0000000`3ooom000000000000200000005@000000000000000
0000003oool0100000020?ooo`P000000P3oool5000000030?oood000010000000<000000`3oool4
00000003@000000000000000008000001@3oool200000080oooo1P0000000d000000oooo0?ooo`02
000000030?ooo`000000000000800000303oool2000000@0oooo00<000000?ooo`0000000`000000
1P3oool00000000004000000oooo@00000<00000203oool4000000030?ooo`000000000000900000
1`00000>0?ooo`030000003oool0oooo00`0oooo00=000000000000000001@0000090?ooo`800000
00=000000?ooo`3oool0703oool000h0oooo00E000000?ooo`3oool0oooo@00000030?ooo`05@000
003oool0oooo0?oood0000000`3oool01D000000oooo0?ooo`3ooom0000000<0oooo00E000000?oo
o`3oool0oooo@00000040?ooo`05@000003oool0oooo0?oood0000000`3oool01@000000oooo0?oo
o`3ooom0000000<0oooo00E000000?ooo`3oool0oooo@00000030?ooo`03@000003oool0oooo00<0
000000<0oooo0000000000002P0000000`3oool0000000000008000000030?ooo`000000000000D0
000000<0oooo0000000000000P0000020?ooo`X0000000E00000000000000000oooo@00000020000
00030?ooo`000000000000X0000000<0oooo0000000000001@0000030?ooo`030000003oool0oooo
00H000000`3oool00`000000oooo00000007000000030?ooo`00000000000080000000H0oooo@000
003oool0oooo@000000000020?oooa<000000`3oool01D000000oooo0?ooo`3oool0000000<0oooo
00D000000?ooo`3oool0oooo@00000030?ooo`05@000003oool0oooo0?oood0000000P3oool;0000
00<0oooo100000001D00000000000?ooo`3ooom0000000<0oooo00E000000?ooo`3oool0oooo@000
00030?ooo`03@000003oool0oooo00d0oooo000g0?ooo`030000003oool0oooo0100oooo1`000000
0`3oool0000000000006000000040?ooo`0000000000000000@0oooo100000000d00000000000000
0002000000@0oooo0`0000000`3oool0000000000002000000030?ooo`000000000000<0000000=0
000000000000000020000002@00000030?ooo`000000000000D0000000<0oooo0000000000000`00
00040?ooo`D000000P3oool00`0000100000000000030?ooo`800000103oool4000000040?ooo`00
00000000000000@0oooo0`0000020?ooo`P0000000<0oooo0000000000001P0000090?ooo`030000
003oool0oooo0100oooo0`0000000`3oool0000000000003000000L0oooo1000000N0?ooo`00=P3o
ool2000001@0oooo1@0000020?ooo`L00000203oool7000000H0oooo0`0000060?ooo``0000000=0
00000000000000000P0000030?ooo`@000000`3oool00d00000000000?ooo`040?ooo`L00000103o
ool00`000000oooo0?ooo`03000000H0oooo0P0000020?ooo`800000103oool4000000030?oood00
0000000000@0oooo0P0000001P3oool000000000003ooom00000000000`0oooo00<000000?ooo`3o
ool04@3oool2000000030?oood000000000000`0oooo0P00000N0?ooo`00<@3oool01D0000000000
000000000010000000<000004@3oool200000003@000000000000000008000000P3oool200000003
0?oood000000oooo0080000000A0000000000000000000000`3oool8000000H0oooo0`0000050?oo
o`d0000000<0oooo0000000000000`0000020?ooo`<000002P3oool700000080oooo00=000000000
000000000P0000000`3ooom0000000000002000000P0oooo00A0000000000000000000000P3oool2
00000004@000000000000000000000X0oooo00<000000?oood0000000`0000050?ooo`80000000A0
00000?ooo`0000000000103oool00d000000oooo0?ooo`030?ooo`80000000=000000?ooo`3oool0
0`3oool3000000D0oooo00E000000000000000000000@0000003000000040?ooo`0000000000@000
01h0oooo000>0?ooo`05@000003oool0oooo0?oood0000000`3oool01D000000oooo0?ooo`3ooom0
000000<0oooo00E000000?ooo`3oool0oooo@00000030?ooo`05@000003oool0oooo0?oood000000
103oool00d000000oooo0000000700000080oooo00E000000?ooo`3oool0oooo@00000030?ooo`04
@000003oool0oooo0?ooo`X000000P3oool010000000oooo0?ooo`3oool@000000030?ooo`000000
00000080oooo00<000000?oood0000000`0000000d000000oooo0000000=00000080oooo1@000003
0?ooo`80000000@0oooo00000000000000000P3oool300000080oooo0`0000001@3oool000000000
00000000oooo00H0000000L0oooo0000000000000000@000003oool0000000<0oooo00=000000?oo
o`3oool0100000000`3oool0000000000005000000030?ooo`000000oooo00<0oooo00I000000?oo
o`3oool0oooo0000003oool400000080oooo100000000d00000000000?ooo`03000000030?oood00
0010000000L0000000E000000000003oool0oooo@00000020?ooo`<000000P3oool00`000000oooo
0?ooo`0:00000005@00000000000oooo0?oood0000000`3oool01@000000oooo0?ooo`3ooom00000
00<0oooo00=000000?ooo`3oool03@3oool00380oooo1`00000@0?ooo`P000000P3oool00`000000
oooo0?ooo`020?ooo`P000000P3oool3000000@0oooo100000000`3oool000000000000400000080
oooo0P0000000d000000000000000002000000030?ooo`000000000000@0oooo0P0000030?ooo`03
0000003oool0oooo00P0000000A000000000003oool0oooo0P000000103ooom000000?ooo`3oool8
00000003@000003oool00000008000000P3oool00`000000oooo0?ooo`040?ooo`<000000P3oool0
0`000000oooo0?ooo`04000000030?ooo`000000oooo00X0oooo0`0000040?ooo`@0000000<0oooo
000000000000200000000`3oool0000000000002000000D0oooo100000000`3oool000000?ooo`02
0?ooo`<0000000<0oooo0000000000001@0000060?ooo`030000003oool0oooo01D0oooo000b0?oo
o`L000004P3oool200000080oooo0P0000070?ooo`03@00000000000oooo00<00000303oool60000
00030?ooo`0000000000008000000P3oool3000000030?oood000000oooo0080oooo00=000000?oo
o`3oool02`3oool200000080oooo10000000103oool000000000000000050?ooo`H0000000<0oooo
0000003oool00P3oool200000080oooo00<000000?ooo`3oool01@3oool2000000D0oooo0`000000
14000000oooo00000000000:0?ooo`<000001P3oool2000000040?ooo`0000000000@00000H00000
103oool2000000D0oooo0`00000014000000oooo0000000000020?ooo`<0000000@0oooo00000000
000000000P3oool2000000D0oooo0P00000G0?ooo`00<P3oool2000000030?oood00000000000080
00008P3oool2000000`0oooo1P0000000`3oool000000000000200000080oooo1000000C0?ooo`05
@000003oool0oooo0?oood0000001`0000060?ooo`@0000000@0oooo00000000000000000P3oool0
0`000000oooo0?ooo`02000000H0oooo0`0000040?ooo`P000002P3oool2000000030?oood000000
00000080000000D0oooo00000000001000000?ooo`08000000H0oooo00=000000?ooo`3oool00P00
00001D000000oooo000000000010000000<000000P3oool200000004@000003oool00000000000X0
oooo0P00000G0?ooo`003P3oool01D000000oooo0?ooo`3ooom0000000<0oooo00E000000?ooo`3o
ool0oooo@00000030?ooo`05@000003oool0oooo0?oood0000000`3oool01D000000oooo0?ooo`3o
oom0000000@0oooo00I000000?ooo`3oool0oooo0000003oool400000080oooo00E000000?ooo`3o
ool0oooo@00000030?ooo`05@000003oool0oooo0?oood0000000`3oool01D000000oooo0?ooo`3o
oom0000000<0oooo0P0000020?ooo`05@000003oool0oooo0?ooo`000000103oool01@000000oooo
0?ooo`3oool000000080oooo0P0000020?ooo`<000000P3oool200000080oooo1P0000000`3oool0
0000000000020?ooo`<0000000@0oooo00000000000000000P3oool200000080oooo0P0000030?oo
o`L0000000<0oooo0000003oool00P3oool014000000oooo000004000002000000070?ooo`000010
00000000003ooom00000000000020?ooo`0300000400000000000080oooo1P0000020?ooo`03@000
003oool0000000L000000`3oool01D000000oooo0?ooo`3ooom000000080oooo400000000`3oool0
0000000000020?ooo`040000003oool0oooo0?ooo`P0000000=00000000000000000200000020?oo
o`050000003oool0oooo0?oood0000000`3oool01T000000oooo0?ooo`000010000000000080oooo
00E000000?ooo`3oool0oooo@000000?0?ooo`00<`3oool00`000000oooo0?ooo`03000001/0oooo
100000030?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool0oooo1@0000000`3oool0
000000000002000000030?ooo`000000oooo00<0oooo0P0000030?ooo``000000`3oool5000000<0
oooo0P0000000`3oool00000000000020?ooo`03@00000000000000000H0oooo0P0000020?ooo`80
000000A0000000000000000000000P3oool3000000@0oooo100000030?ooo`X00000203oool40000
00030?ooo`000000000000T000000P3oool01@000000oooo0?ooo`3oool0000000@0oooo4P000002
0?ooo`030000003oool0oooo00L0oooo1000000F0?ooo`00=P3oool3000001`0oooo100000000d00
0000oooo0?ooo`030?ooo`8000000P3oool500000080oooo0`0000000d000000oooo0?ooo`070?oo
o`d000000`3oool5000000H0oooo0`0000020?ooo`<000003@3oool4000000040?ooo`0000000000
@00000H0oooo0P0000040?ooo`0300000400000000000080oooo0`0000000d000000oooo0?ooo`04
0?ooo`03@000003oool000000080000000=000000?ooo`0000000P0000020?ooo`80000000@0oooo
00000000000000001P3oool010000000oooo0?ooo`3oool4000000030?ooo`00000000000080oooo
1@0000000d000000000000000002000000`0oooo0`0000000d000000oooo0?ooo`0D0?ooo`00=P3o
ool2000001h0oooo0`0000000d000000oooo0?ooo`030?ooo`80000000<0oooo@000000000000P00
000014000000000000000000000>0?ooo`80000000<0oooo0000000000000P0000020?ooo`800000
0`3oool4000000L0oooo0`0000030?ooo`<000001`3oool01000001000000?ooo`3oool5000000<0
oooo00<00000@000003oool0603oool3000000H0oooo0P0000000d000000oooo0?ooo`0;0?ooo`80
00000`3oool3000000P0oooo0P00000<0?ooo`03000004000000oooo00d0oooo00<00000@000003o
ool03@3oool003L0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`030?ooo`D00000
1@3oool<000000D0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo00<0
00000`3oool010000000oooo0?ooo`3oool300000003@00000000000oooo0080oooo00@000000?oo
o`3oool0oooo0P0000000d000000oooo00000004000000D0oooo3@00000014000000000000000400
0002000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo0080oooo
00@000000?ooo`3oool0oooo1P0000040?ooo`@000001`3oool00`000000oooo0?ooo`030?ooo`<0
00000P3oool2000000T0oooo1@0000020?ooo`040000003oool0oooo0?ooo`D00000303oool40000
00h0oooo000>0?ooo`05@000003oool0oooo0?oood0000000`3oool01D000000oooo0?ooo`3ooom0
000000<0oooo00E000000?ooo`3oool0oooo@00000030?ooo`05@000003oool0oooo0?oood000000
103oool01D000000oooo0?ooo`3ooom0000000<0oooo00D000000?ooo`3oool0oooo@00000030?oo
o`05@000003oool0oooo0?oood0000000`3oool01D000000oooo0?ooo`3ooom0000000<0oooo00@0
00000?ooo`3oool0oooo100000001D00000000000000003ooom000000080oooo3`0000020?ooo`80
00000P3oool200000080oooo1P0000020?ooo`8000000`3oool400000004@000003oool0oooo0?oo
o`8000000`3oool00`000000oooo0000000200000080oooo00<00000@000003oool00P3oool:0000
00030?ooo`000000000000P000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00@00000
0?ooo`3oool0oooo0P0000020?ooo`<000000P3oool010000000oooo0?ooo`3oool600000080oooo
00A000000?ooo`3oool0oooo0`0000001`3ooom000000?ooo`3oool00000@000000000000P3oool0
1@000000oooo0?ooo`3ooom0000000<0oooo00=000000?ooo`3oool02P0000001T00000000000000
00000010000000000080oooo00E000000?ooo`3oool0oooo@00000030?ooo`@0000000=000000000
003oool03@3oool004l0oooo0P0000050?ooo`@00000103oool300000003@0000000000000000080
000000A000000000000000000000103oool3000000030?ooo`000000000000<0oooo100000020?oo
o`@000000P3oool7000000040?ooo`000000000000000080oooo1@00000;0?ooo`<0000000H0oooo
00000000000000000?oood000009000000<0oooo0P0000020?ooo`8000000P3oool2000000030?oo
o`000000000000L0oooo0P0000020?ooo`<0000000@0oooo00000000000000001@3oool014000000
00000000000000040?ooo`80000000=000000?ooo`3oool02`3oool00d0000000000000000020?oo
o`03@00000000000000000<0000000<0oooo0000000000000P00000=0?ooo`<000003P3oool00340
oooo00E0000000000000000000000?ooo`02000001H0oooo0`00000A0?ooo`<000000P3oool20000
00D0oooo1P0000020?ooo`<0000000=000000?ooo`3oool00`0000000d0000000000000000080000
00040?ooo`000000000000000080oooo0`0000001400000000000000000000020?ooo`0300000400
0000oooo0080000000<0oooo@000000000000P0000070?ooo`P000000P3oool3000000050?ooo`00
000000000000003oool00`0000000`3oool00000000000020?ooo`<0000000A000000?ooo`000000
00000P3oool4000000@0oooo00E00000000000000000oooo@0000004000000l0oooo00A000000000
0000000000001P3oool600000180oooo00<00000@000003oool03@3oool00340oooo100000000`3o
ool0000000000002000001@0oooo0`00000@0?ooo`@000000`3oool00`000000oooo0?ooo`020?oo
o`L000000P3oool4000000<0oooo1`0000000`3oool0000000000006000000<0oooo2`0000000`3o
ool0000000000006000000H0oooo0P0000000`3oool0000000000002000000<0oooo0`0000000d00
0000000000000008000000030?ooo`000000000000L0000000=000000000000000000`0000030?oo
o`<0000000<0oooo0000000000000`00000;0?ooo`03@000003oool0oooo00H000001@3oool60000
0100oooo1000000>0?ooo`003P3oool01D000000oooo0?ooo`3ooom0000000<0oooo00E000000?oo
o`3oool0oooo@00000030?ooo`05@000003oool0oooo0?oood0000000`3oool01D000000oooo0?oo
o`3ooom0000000@0oooo00=000000?ooo`3oool00`0000000`3oool0000000000004000000<0oooo
00E000000?ooo`3oool0oooo@00000030?ooo`05@000003oool0oooo0?oood0000000P3oool01P00
00100000000000000000oooo@00000<0oooo00E000000?ooo`3oool0oooo000000020?ooo`D00000
00<0oooo0000003oool00P3oool010000000oooo0?ooo`3oool7000000030?ooo`000000000000@0
00000P3oool00`000000oooo@000000400000006@0000000000000000000003ooom0000010000002
0?ooo`8000000T0000000`3oool000000000000300000003@00000000000oooo00X000000`3oool0
10000000oooo0?ooo`3oool500000080oooo00<00000@000000000005@0000020?ooo`D000000P3o
ool3000000040?ooo`000000000000000080oooo00D000000?ooo`3oool0oooo000000030?ooo`03
@000003oool0000000/000000P3oool300000080oooo00D000000?ooo`3oool0oooo@00000030?oo
o`05@000003oool0oooo0?oood0000000`3oool6000000h0oooo000b0?ooo`<0000000@0oooo@000
0000000000005@3oool300000003@000003oool0oooo00H0oooo1P0000000`3oool00000@0000008
0?ooo`L0000000=000000000000000001@0000020?ooo`040000003oool0oooo0?ooo`8000002@3o
ool200000080oooo0`0000000d000000oooo00000002000000060?ooo`00000000000000003ooom0
00001P00000<0?ooo`0300000400000000000080oooo1`0000000d00000000000000000200000005
@000003oool0oooo0000040000001P0000000d000000oooo@0000003000000D0oooo0P0000020?oo
o`8000001P3oool00`000000oooo0?ooo`030?ooo`@0000000@0oooo@0000000000000007P3oool3
000000h0oooo000a0?ooo`<000009P3oool4000000d0oooo0`0000000`3oool00000000000020000
00030?ooo`000000000000H0oooo00@000000?ooo`3oool0oooo0P0000000`3oool0000000000007
0?ooo`8000001P3oool2000000P0oooo1000000:0?ooo`80000000A000000?ooo`3oool00000103o
ool2000000T0oooo1@0000080?ooo`@00000103oool01@000000oooo0?ooo`3oool0000000L0oooo
00<00000@000003oool00P3oool4000000<0oooo0P0000070?ooo`03000004000000oooo01<0oooo
0`00000?0?ooo`00<@3oool5000002@0oooo00E000000000000000000000@0000003000000T0oooo
00D00000@00000000000oooo@000000400000003@000003oool0oooo00@0oooo00=0000000000000
00000P3oool00`000000oooo0?ooo`05000000<0oooo0`0000000`3ooom000000000000200000080
oooo00<000000?oood0000000`0000040?ooo`D00000103oool00d00000000000000000800000080
oooo0P0000050?ooo`04@00000000000000000000080oooo0`0000070?ooo`80000000A000000000
0000000000000`3oool00d0000000000000000020?ooo`040000003oool0oooo@00000H000000`3o
ool2000000D0oooo00<000000?ooo`3oool00`3oool00`00001000000000000200000140oooo00=0
00000000000000000P00000@0?ooo`003P3oool01D000000oooo0?ooo`3ooom0000000<0oooo00E0
00000?ooo`3oool0oooo@00000030?ooo`05@000003oool0oooo0?oood0000000`3oool01D000000
oooo0?ooo`3ooom0000000@0oooo00=000000?ooo`0000001P0000030?ooo`050000003oool0oooo
0?ooo`0000000`3oool01D000000oooo0?ooo`3ooom0000000<0oooo00E000000?ooo`3oool0oooo
@00000030?ooo`04@000003oool0oooo0?ooo`/000000P3oool01T000000oooo0?ooo`3ooom00000
0?ooo`L0000000A0000000000000000000000`3oool00d000000oooo0?ooo`0300000080oooo00<0
00000?ooo`0000001`0000000`3oool00000@000000600000080oooo00<000000?ooo`0000000`00
00020?ooo`03@000003oool0000000H000000P3oool00`00001000000000000800000080oooo00D0
00000?ooo`3oool0oooo@00000020?ooo`D0000000A000000?oood000000oooo0P0000030?ooo`L0
000000@0oooo0000003oool0oooo0`0000020?ooo`030000003oool0oooo00D0000000E000000000
003oool0oooo000000030?ooo`05@000003oool0oooo0?ooo`0000000`3oool700000080oooo00E0
00000?ooo`3oool0oooo@00000030?ooo`04@000003oool0oooo0?ooo`P0000000=000000?ooo`3o
ool03@3oool00340oooo00=000000000000000001`3oool01@000000oooo0?ooo`3oool0000001P0
oooo1@0000000d000000oooo00000002000000P0oooo200000090?ooo`<0000000<0oooo00000000
00000P0000000d0000000000000000050?ooo`<0000000=000000?ooo`0000000P0000050?ooo`<0
00001@3oool00d0000000000000000050?ooo`@0000000=000000000000000000`0000000d000000
oooo0?ooo`070?ooo`L0000000=000000?ooo`3oool00`0000040?ooo`@00000103oool3000000D0
oooo00=000000000000000001000000A0?ooo`@000003`3oool600000003@000003oool0oooo00h0
oooo000j0?ooo`8000000`3oool00`000000oooo0?ooo`0G0?ooo`@000000P3oool2000000d0oooo
0`00000;0?ooo`040000003oool0oooo0?ooo`8000003P3oool2000000H0oooo0P00000?0?ooo`03
0000003oool0000000D00000303oool6000000@0oooo0`00000014000000oooo0?ooo`3oool20000
00H0oooo00<000000?ooo`3oool01@3oool4000001@0oooo0P00000A0?ooo`<000004`3oool003X0
oooo0P0000000d000000oooo00000002000000d0oooo0`0000000`3ooom0000000000002000000D0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool000000080
000000@0oooo00000000000000002P3oool01@000000oooo0?ooo`3ooom000000080oooo00A00000
00000000000000002P3oool00`000000oooo0?ooo`030?ooo`@00000103oool01400000000000000
000000050?ooo`80000000E000000?ooo`00000000000?ooo`02000000`0oooo0P0000000d000000
oooo000000050?ooo`0300000400000000000080000000A0000000000000000000001P3oool00`00
0000oooo0?ooo`050?ooo`040000003oool00000000000L0oooo0P0000000d000000oooo00000003
000000D0oooo0`0000050?ooo`80000000=000000?ooo`3oool01P3oool3000001<0oooo000>0?oo
o`05@000003oool0oooo0?oood0000000`3oool01D000000oooo0?ooo`3ooom0000000<0oooo00E0
00000?ooo`3oool0oooo@00000030?ooo`05@000003oool0oooo0?oood000000103oool01D000000
oooo0?ooo`3ooom0000000<0oooo1P000000103oool00000@000000000020?ooo`05@000003oool0
oooo0?oood0000000`3oool00d000000oooo0?ooo`0;00000080oooo00<000000?ooo`3oool00P3o
ool01@000000oooo0?ooo`3ooom0000000<0oooo100000000d00000000000000000300000080oooo
00E000000?ooo`3oool0oooo000000030?ooo`040000003oool0oooo0?ooo`80000000<0oooo0000
000000000P0000000`3ooom000000?ooo`020?ooo`03@000003oool0oooo0080oooo00H000000?oo
o`3oool0oooo0000003oool7000000030?ooo`0000000000008000000P3oool600000080oooo00D0
00000?ooo`3oool0oooo000000030?ooo`04@000003oool0oooo0?ooo`L0000000<0oooo@000003o
ool00`3oool00d000000oooo0000000700000080oooo00E000000?ooo`3oool0oooo000000030?oo
o`05@000003oool0oooo0?ooo`0000000`3oool010000000oooo0?ooo`3oool6000000030?ooo`00
0000000000D0000000<0oooo0000000000000P0000000`3oool000000000000300000005@0000000
0000oooo0?oood0000000`3oool00d000000oooo0?ooo`02000000<0oooo00<000000?ooo`3oool0
3@3oool003T0oooo10000000103oool0000000000400000=0?ooo`04@0000000000000000?ooo`<0
00004P3oool00d00000000000000000700000003@000003oool0oooo00D0oooo0P0000060?ooo`D0
00003P3oool2000000050?oood00000000000000040000001@3oool4000000@0oooo0`00000A0?oo
o`@000002@3oool3000000040?ooo`0000000000000001T0oooo0`000000103ooom0000000000000
00050?ooo`<0000000=000000?ooo`3oool00P3oool4000000d0oooo0P00000?0?ooo`00>P3oool2
000001L0oooo0P00000C0?ooo`H000002`3oool4000000D0oooo1000000=0?ooo`8000002`3oool5
000002@0oooo0P0000020?ooo`8000006`3oool200000240oooo0`00000?0?ooo`00>P3oool30000
00d0oooo0`0000000`3ooom0000000000002000000050?ooo`000000oooo0?oood0000001`00000;
0?ooo`D00000303oool4000000@0oooo1000000<0?ooo`03000004000000000000H000001P3oool4
00000003@000003oool0oooo00P0oooo0P0000000d000000oooo0?ooo`0D0?ooo`<000000P3oool0
0`000000oooo0?ooo`0D0?ooo`80000000=000000?ooo`0000000P0000090?ooo`@000004@3oool6
000000l0oooo000>0?ooo`05@000003oool0oooo0?oood0000000`3oool01D000000oooo0?ooo`3o
oom0000000<0oooo00E000000?ooo`3oool0oooo@00000030?ooo`05@000003oool0oooo0?oood00
0000103oool01D000000oooo0?ooo`3ooom0000000<0oooo00I000000?ooo`0000000000@0000000
00020?ooo`050000003oool0oooo0?oood0000000`3oool00d000000oooo0?ooo`08000000040?oo
o`000000oooo0?ooo`/000000`3oool010000000oooo0?ooo`3oool5000000<0oooo00E000000?oo
o`3oool0oooo000000030?ooo`03@000003oool0000000`0000000<0oooo0000003oool00P3oool0
0d000000oooo0?ooo`020?ooo`03@00000000000000000X000000`3oool00`000000oooo00000002
000000<0oooo00@000000?ooo`3oool0oooo100000001D00000000000?ooo`3oool0000000<0oooo
00A000000?ooo`3oool0oooo1P0000020?ooo`80000000<0oooo0000000000000`0000000`3oool0
00000?ooo`020?ooo`05@000003oool0oooo0?ooo`0000000`3oool01D000000oooo0?ooo`3ooom0
000000<0oooo100000001D00000000000?ooo`00001000000080000000<0oooo0000003oool00P3o
ool00d000000oooo0?ooo`07000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000
003oool0oooo00H000003`3oool003T0oooo0`00000014000000oooo0?ooo`00000:0?ooo`04@000
0000000000000?ooo`<000001@3oool3000000040?oood0000000000000000D0oooo0P0000060?oo
o`03000004000000oooo00L0oooo00<000000?ooo`3oool00`3oool0100000100000000000000002
0?ooo`03@00000000000000000<0000000=000000?ooo`0000000P0000070?ooo`03000004000000
00000080000000A000000000000000000000203oool300000080oooo0P0000060?ooo`<000000`3o
ool2000000@0oooo2P0000020?ooo`03000004000000000000800000203oool2000000h0oooo0`00
00001`3oool0000000000000001000000?ooo`0000001P3oool00d0000000000000000060?ooo`<0
00000P3oool01@000000oooo0?ooo`3oool000000080oooo00I00000000000000000oooo00000400
000?0?ooo`00?`3oool00`000000oooo0?ooo`0=0?ooo`800000103oool400000080oooo0P000003
0?ooo`@00000403oool010000000oooo0?ooo`3oool4000000D0oooo0`0000050?ooo`<00000203o
ool2000000`0oooo0`000000103oool0000000000000000=0?ooo`@000000`3oool8000000D0oooo
100000050?ooo`<00000603oool2000000H0oooo0P0000060?ooo`H000000P3oool2000001L0oooo
000f0?ooo`<0000000D0oooo00000000001000000?ooo`03000000h0oooo00<000000?ooo`3oool0
0`3ooolE000000D0oooo0`0000001@3oool00000000000000000oooo00@000001`3oool3000000@0
oooo0`00000014000000oooo0?ooo`3oool200000004@000003oool0oooo000000/0oooo20000003
0?ooo`<000001@3oool600000004@000003oool0oooo@00000<0oooo1`0000040?ooo`@000000P3o
ool4000000<0oooo0P0000000d000000oooo0?ooo`030?ooo`80000000=000000?ooo`3oool00`3o
ool7000000H0oooo0`0000040?ooo`03@00000000000000000D0000000@0oooo0000000000000000
5P3oool000h0oooo00E000000?ooo`3oool0oooo@00000030?ooo`05@000003oool0oooo0?oood00
00000`3oool01D000000oooo0?ooo`3ooom0000000<0oooo00E000000?ooo`3oool0oooo@0000004
0?ooo`05@000003oool0oooo0?ooo`0000000P3oool7000000040?ooo`000000000000000080oooo
00D000000?ooo`3oool0oooo@00000030?ooo`05@000003oool0oooo0?ooo`0000000`3oool00d00
000000000000000G00000080oooo1`0000020?ooo`05@0000000000000000?oood0000000`3oool0
1@000000oooo0?ooo`3oool0000000<0oooo00=000000?ooo`000000200000020?ooo`050000003o
ool0oooo0?oood0000000`3oool01D000000oooo0?ooo`3ooom000000080000000H0oooo@0000000
000000000?oood0000020?ooo`H000000P3oool6000000<0oooo00A000000?ooo`3oool0oooo0T00
00000`3oool0000000000005000000030?ooo`000000000000L0000000<0oooo0000000000000P00
00001400000000000?ooo`3oool400000005@00000000000oooo0?oood0000000P3oool800000004
0?ooo`000000oooo0?ooo`@000000P3oool01@000000oooo0?ooo`3ooom0000000L0000000E00000
0000003oool0oooo@00000030?ooo`03@000003oool0oooo00d0oooo000c0?ooo`<0000000A00000
000000000000oooo0`000000103oool000000000040000020?ooo`030000003oool0oooo00l0oooo
00H00000@0000000000000000?oood0000020000009000000P000002@0000080000000@0oooo@000
0000000000001P3oool01400000000000000003oool200000005@000003oool0oooo0?oood000000
1P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo1000000@0?ooo`05@000
003oool0oooo0?oood000000103oool00d0000000000000000050?ooo`05@0000000000000000?oo
o`0000002`3oool00d0000000000000000050?ooo`03@00000000000000000D0oooo00=000000?oo
o`3oool00P3oool3000000D0oooo0`0000050?ooo`04@0000000000000000?ooo`<0000000=00000
0?ooo`3oool01P0000020?ooo`030000003oool0oooo00<0oooo0`0000001D000000000000000000
0010000001H0oooo000d0?ooo`<00000203oool01@000000oooo0?ooo`3oool0000003`0oooo0P00
000>0?ooo`8000006`3oool00`000000oooo0?ooo`130?ooo`T000008`3oool003@0oooo0`000000
0d000000oooo0?ooo`040?ooo`<0000000@0oooo0000000000000000>P3oool3000000h0oooo0`00
000I0?ooo`<00000A@3oool300000003@00000000000000000<000008P3oool003D0oooo0P000007
0?ooo`<0000000@0oooo0000000000000000>P3oool4000000`0oooo1000000I0?ooo`<00000A@3o
ool3000000030?ooo`000000000000<000008P3oool003D0oooo00<000000?ooo`3oool01P3oool2
00000005@000003oool00000000004000000>P3oool300000003@000003oool0oooo00X0oooo0`00
00000d000000oooo0?ooo`0G0?ooo`80000000=000000?ooo`3oool0A03oool010000000oooo0?oo
o`3oool300000003@000003oool0oooo0200oooo003o0?ooob00oooo003o0?ooob00oooo003o0?oo
ob00oooo003o0?ooob00oooo003o0?ooob00oooo003o0?ooob00oooo003o0?ooob00oooo000S0?oo
o`900000nP3oool002D0oooo00=000000?ooo`3oool0m`3oool001L0oooo0d0000030?ooo`=00000
0`3oool3@00000D0oooo00A000000?ooo`3oool0oooo0T0000060?ooo`03@000003oool0oooo00<0
oooo0T0000001`3ooom00000@00004000000oooo@000003oool014000000103ooom00000@0000400
00020?ooo`A0000000@0oooo@0000400001000000`3oool2@00000<0oooo0T0000020?ooo`=00000
0P3oool3@0000080oooo0T0000040?ooo`9000000P3oool3@0000080oooo0d00000G0?ooo`900000
0`3oool2@0000080oooo0d0000030?ooo`9000000`3oool2@0000080oooo0d00000?0?ooo`=00000
00@0oooo@0000400001000000P3oool2@00000@0oooo0T0000020?ooo`=000000P3oool3@0000003
0?oood0000100000009000000`3oool3@0000080oooo0T0000020?ooo`=000000`3oool2@0000003
0?oood00001000000080oooo00=000000?ooo`3oool08P3oool001P0oooo00=000000?ooo`3oool0
0`3oool01D000000oooo0?ooo`3ooom000000080oooo00=000000?ooo`3oool02@3oool00d000000
oooo0?ooo`080?ooo`03@000003oool0oooo0080oooo00E000000?ooo`3ooom000000?ooo`03@000
00<0oooo00A000000?ooo`3oool0oooo0d0000020?ooo`03@000003oool0oooo0080oooo00I00000
0?ooo`3ooom000000?oood0000050?ooo`03@000003oool0oooo0080oooo00=000000?ooo`3oool0
0`3oool014000000oooo0?oood0000020?ooo`04@000003oool0oooo@00000<0oooo00=000000?oo
o`3oool05`3oool2@0000080oooo00=000000?ooo`3oool00P3oool00d000000oooo0?ooo`020?oo
o`06@000003oool0oooo@000003ooom000000P3oool014000000oooo0?oood00000?0?ooo`04@000
003oool0oooo@0000080oooo00=000000?ooo`3oool00`3oool014000000oooo0?oood0000020?oo
o`04@000003oool0oooo@00000@0oooo00E000000?ooo`3oool0oooo@00000020?ooo`03@000003o
oom000000080oooo00=000000?oood0000000P3oool014000000oooo0?oood0000030?ooo`06@000
003oool0oooo@000003ooom000000P3oool00d000000oooo0?ooo`0R0?ooo`00603oool00d000000
oooo0?ooo`030?ooo`05@000003oool0oooo0?oood0000000P3oool00d000000oooo0?ooo`080?oo
o`03@000003oool0oooo00T0oooo00=000000?ooo`3oool00P3oool014000000oooo0?oood000003
0?ooo`05@000003oool0oooo0?oood0000001@3oool014000000oooo0?oood0000040?ooo`03@000
003oool0oooo0080oooo0d0000030?ooo`03@000003oool0oooo0080oooo00=000000?ooo`3oool0
0P3oool01D000000oooo0?ooo`3ooom0000000D0oooo00E000000?ooo`3oool0oooo@000000H0?oo
o`05@000003oool0oooo@000003oool00d0000020?ooo`03@000003oool0oooo0080oooo00=00000
0?ooo`3oool00P3oool014000000oooo0?oood0000020?ooo`03@000003oool0oooo00d0oooo00A0
00000?ooo`3ooom000000P3oool00d000000oooo0?ooo`020?ooo`05@000003oool0oooo0?oood00
00001@3oool00d000000oooo0?ooo`020?ooo`05@000003oool0oooo0?oood0000000P3oool00d00
0000oooo@00000020?ooo`03@000003ooom0000000D0oooo00E000000?ooo`3oool0oooo@0000002
0?ooo`03@000003ooom000000080oooo00=000000?ooo`3oool08P3oool001P0oooo0T0000030?oo
o`900000103oool3@00000/0oooo00=000000?ooo`3oool0203oool00d000000oooo0?ooo`020?oo
o`=000000`3oool2@0000080oooo140000020?ooo`9000000P3oool3@00000030?oood0000100000
009000000P3oool3@0000080oooo140000000`3ooom00000@00000040?ooo`90000000<0oooo@000
040000000T0000020?ooo`9000000`3oool3@00001D0oooo0T0000020?ooo`03@000003ooom00000
009000000P3oool3@00000030?oood0000100000009000000`3oool2@0000080oooo1400000>0?oo
o`=0000000<0oooo@00004000000103oool2@00000030?oood0000100000009000000P3oool4@000
00030?oood000010000000<0oooo0d000000103ooom00000@000003oool6@0000080oooo0T000004
0?ooo`90000000<0oooo@000040000000T00000U0?ooo`00603oool014000000oooo0?oood00000C
0?ooo`03@000003ooom0000000X0oooo00=000000?oood0000000P3oool00d000000oooo0?ooo`0F
0?ooo`03@000003oool0oooo01H0oooo00=000000?ooo`3oool0;`3oool00d000000oooo0?ooo`0K
0?ooo`03@000003oool0oooo00T0oooo00=000000?ooo`3oool0303oool00d000000oooo0?ooo`07
0?ooo`03@000003oool0oooo03@0oooo000G0?ooo`E000000P3oool00d000000oooo0?ooo`0?0?oo
o`03@000003oool0oooo00T0oooo0d0000000`3ooom00000@000000X0?ooo`03@000003oool0oooo
00`0oooo00=000000?ooo`3oool0AP3oool2@0000080oooo00=000000?ooo`3oool04@3oool00d00
0000oooo0?ooo`02@00000l0oooo00=000000?ooo`3oool0;P3oool00?l0oooo803oool00?l0oooo
803oool00001\
\>"],
  ImageRangeCache->{{{0, 286}, {287, 0}} -> {-2.53647, -0.811269, 0.245055, 
  0.245055}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["2.5 Sketch generation",
  FontFamily->"Times New Roman"]], "Section"],

Cell[TextData[{
  StyleBox["\t",
    FontFamily->"Times New Roman",
    FontSize->10.5],
  StyleBox[
  "Sketch is one of the art works extracting the characteristics of a target \
object and then depicting by a set of monochrome lines. From such a \
viewpoint, it is difficult to work out a sketch art by means of computers. \
However, we have succeeded in extracting the characteristic vector \
distribution of the monochrome image. If this characteristic vector \
distribution exactly representing the distinct characteristics of the image, \
then it is possible to sketch the image. One of the simplest ways for \
sketching the monochrome image is to plot the magnitudes of the \
characteristic vectors distribution. In order to do this, we define a \
function \[OpenCurlyDoubleQuote]vectMag2D\[CloseCurlyDoubleQuote], which \
compute the vector magnitudes distribution at each position. A parameter \
\[OpenCurlyDoubleQuote]vector2D\[CloseCurlyDoubleQuote] is a \
three-dimensional array containing the two-dimensional vector components. ",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Mathematica function",
    FontFamily->"Century",
    FontSize->10.5],
  StyleBox[" vectorMag2D",
    FontFamily->"Century",
    FontSize->10.5],
  ""
}], "Subsubsection"],

Cell["\<\
vectorMag2D=Compile[{{vector2D,_Real,3}},
\tModule[{i=0,j=0,dim=Dimensions[vector2D]},
\t\tSqrt[Table[vector2D[[i,j,1]]^2+vector2D[[i,j,2]]^2,
\t\t{i,dim[[1]],1,-1},{j,dim[[2]]}]]]];\
\>", "Input",
  CellLabel->"In[25]:=",
  FormatType->InputForm],

Cell[TextData[{
  StyleBox["\t",
    FontFamily->"Times New Roman",
    FontSize->10.5],
  StyleBox[
  "After computing the vector magnitude distribution of Fig. 3, we plot this \
in reversing the black and white mode. Thus, an obtained sketch is shown in \
Fig. 4. Obviously, this figure extracts the characteristics of the monochrome \
image in Fig. 1, and also represents them by a set of monochrome lines.",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell[CellGroupData[{

Cell["\<\
sketch=vectorMag2D[chractV];
ListDensityPlot[Max[sketch]-sketch,
\tPlotRange->All,Mesh->False,Frame->False,
\tPlotLabel->\"Fig.4. Sketch\"];\
\>", "Input",
  CellLabel->"In[26]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00751202 0.0192308 0.00751202 [
[.5 1.0125 -41 0 ]
[.5 1.0125 41 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Fig) show
81.000000 12.812500 moveto
(.4) show
93.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(.) show
105.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Sketch) show
141.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
128 string
128 128 8 [128 0 0 128 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFF6FFF5FFFCFFF3F3FCD9FFFFFEF7F7FFFFFFFFDAF786
B0F3F3FFF7F5FFF3F3FEFEFEF3FFF5FFF8FFF9FFFEFFFFFE
EFEFFFFFF4FFFFFFFFFFFFFBFBF4FFFBF9F4FFFFFFFFFEFF
FFFFFEFFFCFCFFFEFEFFFEE2EDEDA1CAFFF5FFF5FFFFF7FF
FFFFFFFFF4FEFAFAF3F8F8FFFFF5F5F4F5FEF1FFFAFFFEFB
D4FFC6D9E1F3F9F5
FFFDFAF5F9F8F5F6F8FEF9E4E7FEFFFAFAFFFFFFFEE4E998
BFF5F4FFF9FEF5F8F7F8FFFFF8F4FEF9F7FBFBFFFFF5F3F8
F4FCF7FFF7F4F7FAF6F4F8F7F6FFF8FCF7F8FFFCFCFFFEFF
FFFEFFFFFDFFF7F8FFFFFFEBDEFFA3EDD5F8FFF5FFFFF9F7
F9FDFCFCF6FAFEFEF2F7F7F5F5FFFFF8F4FFF4F1F8FFF9DC
D8E3E1EBD7F3FAF9
FDFBFAFEFEF8F5F9FFF8FFF5DEE3FFFEFEFCFCFFFBFBE5CC
D2B7FBFCF9F4FAF8F6F9FEFEFEFEF6F6EDFBFBFEF9F8FDF6
F0F1F1F0F9FEFBFCFAFFF8F8FFF7F8FAF6F4F6FCFAF8FFFE
FFFFFFFFFFFDF7F7FFFFFFFFEBDBDEA0E9C5F5F8F8F6F9FF
F5F8F3F7F8FAFAFAFAFFFEFAF6FAF6FDF7FDFEFDF9F1EBED
EFDAEBFDD5ECFAF9
FCFDFBF6F8F8F5F9F9F5FFF6F9E5DDE5F6FDFCF8FAFAEAE4
A0D0E9FDF8F3FAF8F5F5F7FFFFFEF5FCEEF8FBFFF6F9F6FB
FFF9FBF8F1F7FEFAFBFFFFFFFFFFFBF2F9FFFCF5F8F8F6F6
F4F8FFFFFEFEFEFFFEFFFFFFFFF9DFF2A3E1D5F3F7FDF7F0
F5F7F3F7F8FAFAFBFBFFF8FAFEF8FFF6FCFBF7F7E3E6FAF1
ECEAE3F9D5F5F1F6
FFFEFFF8FDFDF9F7F4FFF9F6F9F9F6EDDFF6F9F8FBFBF8DE
F0C4E2FCF9F1FFFFF8F8F8F7FEFFF7F5F7FFF8F5F8F7F7F0
F0F3F2F8F8F7F8F4EFEFF4FFFEFEFBF1F6F8F4F1FAF6FCFE
FBF6FCFAF9FBFFFAF9F8FAFAFAFFF9DFF2A2D8EDFBF9F9FF
FBFFFBF9FBFBF8F8FBFDF6FEFFFAFFF8F8F7F0E3E4F0EBEB
D2DFDDF8CDF2F0FB
FFFCFBFBFAF9FEFAFEF5F9F5FDF9F7F8E6E2F6FAF9FAF9EA
EBCFDFFAFBF0F6F9F8FFF6F7FEF8F4F8F8EFF6FFFDF5FFFF
FFFFF9F0F6FAF1F9FAF4FCF7FFFFFFFFF8FBF7F6F1F8FBFC
FCFDF7F8FDFBF8FFFBFBFBFBFAFBFBF9DFE2CAF7E8FBFEFA
FBFBFBFCFBFBFDFCFDFFF8FAFFFFF7F8F2EFE7E8FDE2E1DE
E7E5D1EBD1F5FAFB
FFF8F5F5F7F8FAF7F9F7F9FBF7F8FDFBFBE9DAE6F8F5F5F6
F0F3DCF9FBF7F5F3F6FEF6F4F2F7F9ECECF9F7F7F8EFFFFA
F8F8F8F6ECEEF2F5F8F4F2F2F3F1F4FEFFFCF7F7F8F9F7F8
F8F6F6F8FDFBF8FBFBFAFEFEFFFAFAFFF9DCEBC4E5F8F8F8
FAF9FEFAFFFDFDFCF7F8FAFAFFF2EFE3E0EDD7FAEED0F2F7
F9EAD9D7E6FEFAF6
FFF8F7F9F9F5F5F7FAF8F6F6F5FFFDFBFFFFF7E9EAF5F5F5
F8F0F9DFCCC7F9FBF8F9FFFFFFF2F0FFF8FFFFFAFAF0F7FA
FBFFFFFBF4FEEDFBF6F6F8F8FBF9F1ECEFF3F0F5F7F3F4F4
F6F6F7F9EFF3FCFDF6F3F3F3F3F5F5F7F7EAD6F5DBFEFDFF
FFFBFAF7FDFCFDFAF8F5FAF7F0EBDBE2FAE0DDE3CCD3F3F0
F0F7EFCEF2FBF7F8
FFF8FBFAF9FBF7F8FBFCF7F7FDF8FBFFFBFFF7FBEDEAE7EB
E6E1EDE9A8D2EFFDF7F9FFFFFAF7F2F2F8F6EFEBEFFEF1F8
F8FFFFFCFBF6EFF2F8EFF2F8F8F6F6FAF9EFEBE5E0E7EAE9
E4E0E0E1E6E7E2E1E6ECECF1FAFAFEF7F2F7E5CDE1F6E7C8
C8E7F3F1F6F6FAF7F5FEFAF8CACAF1EEF8EADDF2EAF3F6EE
F0EBF2DBF3FEFEFD
F5FDFDFFF9FFF8F9FEFBF6F8FDFEF5F7F7F7F5F5F7F7F9FD
F7FBFBFEFBCBDDDBDBECF2F2FAFBF3F7F0EFF1F5F9F4F6F5
FAF9FCFCFFF8FBF1FAF9F8F5F9F9F5EFEFEAE4E9E6ECF0EF
F3EEEAEFF3EEEBEBEBECE6E8F1F1F3F3F2F1F5F1EBF3E5C1
CDAE9FECE8F7F7F4DEB3989DC8E3E3EDF0F3EFF5F9F0F1D2
F5DED3F7EEFDF9F6
F3F7F7F6F8F5F4FAFFF9F9FDF8F6FEFAFBF5F7F7F9F9F7FF
FAF8FAF9F8FAC3D7CDD8F1EEFEFFF7F2F2F7F8FCFFF4F8F3
FFF8F6F8FCFBF9F4F9FFF9F9F9F9FFFFF9FFF5F8F5F0F0F2
F8F7F8F4EDF6FDFDFEF8F8FFF2F2F9F9F6F6F8F4F5FDF3F8
F8938ADCDEC1C8C1B7E3F0F8E2EAE1F3EDCDDDFDF0DDF4D6
E8F0EAEAF6F6F6FE
F3F8F8FFFBFAF4FAFBF9FDF9F9F8FDFAFDFBFFFDFDFBF8F7
FAFDF8F6FBFBCADAE9EBFAE1DAFFFBFAF0F5FAF9F8F7FBF2
FFFFFEFBFBFAFAF8F9F9F9F9FFFFFFFFFFF9F3FFF3F7F9F8
F4F9FDF9F2F8F9F7F6F2FFFFFFF9F9F7F6F6F7F6FFF8F8F7
F1EFEBE1C0BDD2BFECF8F8ECF0F4DAE1FBC3BBE0EADAD1EC
DDCFDEDFFBF9FDF4
F5FFF6FFF8F5F9FDF5F6FFFDFBF7FBFFF7F9FBF6F9FBFFFB
F8FFFDFBFDFDD5F8CCFFEBD2B9B1F8FFF7F3FCFFFCF7FBF3
FFFFFFFEF8F8FAFAFFF9F7F9FFFFFFFFFFFFFFF3FBFFF7F9
F7FDF9FBFEFBF9F5F7F2FFFFFFF3F8F9F6F9F9F5FFF8F5F8
FFF1DCC8AB98C8E1EEF7EAF8FAFEE9E8F8D5C5F0E6E2D2FF
F6D3FFF6F8F4F5FD
F5FDF7FBFDF6F6F6F7F7F5F5F9FEF9F6FFFFF8FBF9FBF8FD
F8FEFBFBF8FFE1E4CCC0E5D1E8BD9BF3F7F7F1F3FEF9FAF3
FFFFFFFFFAFAFFFFFFFFF9F7F7F7F8F8F9FFFFF7FFFFF9F9
FDF6F7FCFBFFFFFCFDF9F8F6F5F8F3FFF7FDFDF9F7F1F9F1
ECE3E6D1D1FFE2EBE6EAF3F0FAEFE7FFF1F8DBF0F2F7E6F3
F2DDF8FBF7F4F9F7
F5FAFAFAFBF5F8F8F5F5F7FBFFFFFFF8F9F6FBFFF7F7FEFD
F9F9F7FAF6FEE5EBDCAFF0EBE5DE9D8EECF2F2F7F9FAFAF6
F8FFFFFFF9F9FFFFFFFFF9F7F9F9FFF9F9F9FFF9F7F7F8FA
FDFCFCFDFBFDF9FBFCFAF3F5F7F9F9F7F9F7FDFDF7F8F6F1
EFF0E1D8EEE1FFF1F0E9F0ECEEFFE7F0E2EBF0E0ECD5E2EA
DDEAFFFCFAFCF9F7
FFFEF8F9FCF4F7F5F7F5FBF7FFFFFFF6FFF8F8F8FBFEFEF9
FBFFFEFBFBFFE7EBD4CBC7F8DFDEDD9691FFF1F2F2FAFFF4
F8FFFFFFF9FFF7F9FFF9F7F7F9F7F5FDF9F9FFF9F7F7F9FD
F9F7F8FBFBF9FFF7F4FDF5F9F9F9FDF9F4E8E7E4DFDEE4EB
DCC2B3E8CFECDADDEFF3D7DBFFE9E5F1EDF8E4FFDCF8E7DC
DFF8F5FDFAFDF4F9
FCF9F8FEF9FFF8FBF8FBF9FBF7F7F7F9F9F7F7F9FDF9FFF9
FBF7F6F9FFFBF3F7ECD9C0FFDCDFE4F49086F4F1EAFAFFF3
F9F9F7F7F7FFF9F9F9F7FFF9F9FAFDFAF6F7F5FDF9FAF7FC
FCFBF8F4F7F7F9F3F4F0F2FAF2F2EEEEF8F2F9FAF3F8E8D3
B6D8F2C8E2F7D9D1EFECF4F5F1E9F7ECF5FFE8FEDEE4ECE4
F2F6F6F4FDFDF5FB
FCF9FBF7F8F4F8F7FBF7FDF7F7F9F7F7F7F8F7FBF7F9FAFF
F8FEFCFFFFF6F6E1F3ADDDF5DAE9F3E7E98464F7F3F7FBF7
F7F9FFFFFFF7F7F9FFF9FFF9F7FDFAFCF9F9FAF3F9F9F9FC
FCFDF9F5F1F9F9FAF8F8F2FBF1F1F8FBF0F6F5F8E9D9D5DF
E5E7D7D2F8F6FFEDF7E4DBE8E9FFE3EEFFEBF0FEF9DDE0F8
F7F2EDF2F9F7F8FF
FCF9FBFBFFF7FDF7FBF9F8FBF7FBF9F5F7F5FDF7F7FBFFF9
F7FCFDFFFEF8F6E5F1A0F1F5DAE9FFEEDCEB876BFFF1FAF8
FFFCFFFFFFF9FFF9F7FFFFFFFDFDFFF9FCFAF9F9F9FAFAFA
FDFDF6FCFCF8F4F6EEF7F5F6EDF9F7F6F1F1F1DAC2D8CFDE
EDE2D9FBF8FBFEE8EFE8E1E1E4E8F9F9EBEAFDFFEFE8F1FF
F3F7FBFEFBFBF7F8
F3F7F5F5FBFBF9F7FFF9F7FEF7FAF7F5F9FBFBF8FDFBFAF8
FAFBFBFCFFFDF5EEFBADEDE8E6EDF1E4DEF6F441FFF1FFFB
FFFEF9F9F9F9F9F7F9FFFAFAFFFCFCF9FDFCF8F9F4F6FCFF
FFFAFAFCF6F3F5FAF7F0F0ECE1EFEDEFE4E4D6E3C6E1E2D7
F1E1E7F3F6F4F5EEFBECF0F5EBEBF9F1EFFDFFF0EBFAEAEE
F1F5FEFBF9F7FBF8
FFFBF8F9FAFAF8F9FEFAFCF6FBF7F7FAFAFFF9FAF9FDF8F8
F7FFFFF8FDFBF9EDD4C7EDE3EBF7E2E6DCECDE949CF2FAF7
F8FFF3F7F9F9FFFFFFFDFCFCF7F9FAF9FFFCFCF8FBFAF6FB
FBF8FFF6FBEEEDF5EBFFD5E5F7F7F5F5E0E9DADFE7D4E0DD
D7CEEAF2F6FAE9F1E4E5F0F4EAE1EAF2FFFDF3EAEDEEE8F9
FFF4FBF9FFFAF7FB
FFFBF9F9FBFFFAFEF9F6F9F8FFFBFDFBF7F7FDFBF6FFF8F8
FBF7F9F9FDF6FAE1D1D8F3E3F1F3D6F8E0EBEAE85CEEFEF4
F3FFF6F4F9FCFAF9FCFDFFFAFDFDFAFDF8FCFAFAFCFDFDF1
F1F6F6F1EDF6F8E0F2D3E8F2F8F0E4CFCCE4E5F7E7FEEEF0
E5EFFFF6FAE7D0E4E5F4E2ECFFE2E3FFFFF7F5E7F2FEF2F9
F4F8F7FFF7FAFBFB
FFF8FFFFFFF7F9FBFFF7F7FFFFFFF7FFF7F8FAFBFDF4F7F8
FDF8F9F7F7F6FFCAE3D0EFE6F0EAD5FAEDE3F0CD33F8F9F8
F9FDFCF8FDF9F8FDF9F8F9FDFCFDFDF9FCFBFFF5F2F4F8FF
FDFFF3F6EDF1ECEAD4CEF1E9E5DFE5DDF5DFEAF8F7F0E9F0
E0EDFFF4FAE8D3E9EAEADBEAF8EBECFEFDE8DAE4FEFBF1FB
F5F5FFF8FBFBF8FF
FFF8F8F6F6FFFBFBFBFFFFFBFFFFFBF9FAF9FBFFF9F7F9F9
F5F8F8FFF6F4F1C2EFDAE9F0F2E8E2F1F3F6DFDE2EF7F0F7
FAFAFFFCF9FFFBFDFDF8F8FFF7F1F2F6F5F1F5F6FFFCFAF5
F8F0F0E8F1FBE5E4D9F8FFFAEFDBE6EDECDBE1E9F0FDE6E0
E8F2F3FBE0E4F7F2F5F8FFEEEAE2E2F7EAE5ECFDFBF8F6F5
FBFBFBFDF7F7F8FF
FFFBFBF8F8FBFBF9FBFFFFFBFFFFFBFFFBFFFBF9FFFBF9FB
FAFAF9F7F8F5EBCCE8E7E9F0FCDBEAD8EDD8E4F23BF7F1EA
F8F7FDF4EEF6FDF5F2F8F7F1F8FCFAFCF4F6FBF6F8F6F6FF
F6F7F7EDFEEDF8DEDCE9ECECDAF9EEF9FBDAFFEFE6EDEDF5
F3EFE7F9E0F4EFE8FDECECF4D8FDF5F1DEEAF5F7F7F6FDF9
F7FFF9FAF7F7F7FB
FFFBFBFBFBFBFBF9FFFBFFFBFFFFFBFBFBF9FBFFF9F9F9FF
FBFAFDFBF6EFDBCCF0E7E5F4FFDBF4F6D8D2F6F036FBFBF3
F3F9F8F2F5F4F7F6FCFCF7F7F6FAFBF6F7F6F9FBF9F5F8F8
F8FFF4F0F9F4DEE5F9F5ECE1ECF1DEE5F4DCF1F8E4E9FCF9
E9FFE3FADAFBF5E7EBE8E5E8E0FFE8E9F2F4F4F7F8F5FDF7
FBFBFBF7FAFDF8FF
FFFFFFFBFFF9FFFFF7F8FBFBFFFBFBFFFFFFFFFBFFFBF9FB
F7F6F9FDF7F5BDDFF0EAD5EFECE2E5EAE9E5E8E73BF3F3FA
FAF8F6F5F1F8F8FAFAF6FBF7F2F4F4F7F9FAF7F1F9FCF7F7
FEF1F1F0ECF1E4F1F4F2F2F8F0F0EFEFEEDEF0F8F2ECF3E9
FFEBDEF5E8F2FEE5E9EBEEEBEBF7E0FBF6F4EFFFF5FBFBF9
FBFBFFFFF9FBFBF9
FFFBF9FBF9FFF9FBF7FDF7F8FFF9F9FFFBF9F7F8F7FBFBF9
F5F7F5F5FDE8BAEFE5EFDCECDDF7F0EED4E6E7F545EDF1F2
F3FAF8F5F5F7F6F6F4F9F9F9FFF3EBF0EEF3F5F6FDF5F4F4
F0F2F8FAECD5E4EDF8FBF2FEF3F5F0EAF2EAEAE8E0DBDEDB
F3FCDFF0E9F5F4FEEAEBF7DBEAF7E5F8FEEFF7F7F5F9FBFB
FFFBFBFFFBFDF8F9
F9FFF9FFFBFEF9F5F7FFF7F8F8FDFFFBF9FBF9F9F8FBF9FB
FBF8F8F8FDD0D7E5EAEAE5ECDDE6E8E0C7F6F1FA46EDF4F8
F8FAFAF7F3F6FAFAF7F9F7FCFCF7F8FFF8F4F4FCF8F8FFF3
F1F5EDF2E1EDEAF7FBF4FFD3D2D9E5E7EAF1EEE2F4EFF7C4
E1E6EEF8F8DCFEECEBFFFFCBF4E4ECF3F8F6FDEFF5F6F9FF
FBFFFBFFFBFDF8FB
F9FBFFFBFBFAF6F5F7FBFFFFF8FFFAF9F7F7F7F7FBFBFBF7
FAFAFAFDEFC7ECDAEAE3EFF7F0EBDAEDE3EAEDF452F3F8F3
F5F7F7FDF9FEF8F6F9F5F4F2E8E7F1F2F4FFF1EAF8FFF3F2
FFFEECE7D9DBF1F0F3F2D3D5E8CECEFFEAF1E9E8EDF0E7D3
ECE2F2EEF2D7EBEBF2F1E9D0E9E8F8F8F5F6F8F6F5FBF7FF
FBFDF8FBFFFFFBFF
FFFFFBFBF9FBF7F7F9FBFBFBFFF9F7FBF6F8FAFAFDFBF9FA
F7FDFAFFD9D2E8D1F2E8FBEFF7F7D4EAF4F7FFFC5FFFFFF1
F3FCF6F6F6F9F1F0F5EEF5F1FAF8F0F7F2ECFAF7F1ECF2F4
F0E7EEE2CED5D8F8E2DDE2F9DDC6DAEAF3FAFCD4EDFBF6E5
F7F2F8F8EAE9E3F7EADDE5E0D9F0FAF3F6F4F6F9FBFBF9FF
FFF8F8FBFBF9F9FB
F9FBFBFBF6F9F8F8F9FFFBF9FFF8F8FBFDF9FDFDF6FFF9FB
F7F8FDF5D4DEE4DBF9EDF7F3E0F8BDE7F1FAFAE76CEBE1E7
EAE4E1E9F1EEF3F5F3EDE1DDF0F2FAF7F8F4EAE5F2FAF4F8
F8F1F7E5C0EADEF1D6E5F2D2EDE0D7FFF3F3F7D3EEEDE9DF
DEF3EEE0C0FFE1F5F4EBEEC6E2F0F0F0FAF5FBFBFBFBFBFF
FBFBFFFFFFFBFFF8
F9FFF9FBF3F7F9F9FFFBF9FBFFF7F7FBFFFEF7F8F5FBFFFA
FDFDFCE2D4DCE2E5F5E3F2EBEBEFC4D7F5F7F7AB86E8F0F2
FBFBFEF3ECEFEDF5F6F6F6F1DBDCEBF6F3FEFBF9F4EDFEFF
F4F4F3E0C9E7D8D7E2EBEBC0CCD8E0F1EDF6F3E2E9E0FEFB
E6F5DCF1CAEFF0F2D9EBDEC7F2EFF0FCF4FAF9F7F8F7F7F9
FFFBFBFBFFFFFBF7
F9FFFAF7FBF7FEFDF8FFFFFFFBF9F7FBFBF9FBF9F5F9FAF8
FFFDFFD4D9DFECE4F1EBF2F3F3C1F3E0F3F7AF6FB7F0F8FB
F5F5F2F8F8FCF4EFF1F7F4F6F1EDD9D4E7F4F2F0FBFAF6F6
ECF2E2D2EBEDD3A9EDE4D9B2DBEDE1DEDCE5EAE8E9DFF2E9
E1CEF6ECEAEEF0F3ECE9BCE4E7F8E8F5F1FBFEFFF7F7F7FB
FBFBFBFBFFFBFBFF
F9FFFEF9FBF7F9F5F8F7F9FFFBF9F9FFFBFBFBFFF9FBF7F5
F9F8E5DACCE9E8DEE5E9F5F3EEBFDFF0E97763C1F8F8FAFB
F7F7F2FBFBFAF7FFF4F0ECF4F8F5EEEED8E1F7F4EEEEF1F1
F2F9D8F1ADBEACA6D0E1E4B0D1C5CFDEDCDBEEEFE6E8E0FD
E6C1F3F2F2F9E2F3FEEFC5F0FBE6F9F8FEF9F7F7FFFBF9FF
FBFBFBFFFFFBFBFF
FFFBFBFFF8F8FFF8F7F7F9FFF8FBFFF7FBFBFBF9FBFFFFFB
F6F7E2E9C8F0E6E8EBF7F7F7DBE4E0EFCA61F6F7F7FAFAFE
FEFEF5F2F5FBF7FFFEF8F2F7F0F9F7F0EED3D4D9F2F6FAF6
F3EAE5F5A4C3C3DCB2E1FBBEBFC8C4F0EEFEE6F9F1F2E0ED
EECAE5E8F2EDDAEEEEF5D5F0E8EFFBF5F7F7F9F9FBFBFBFB
FBF9FFFBFFFFFBFB
F5F8FBFBF8F8F9F9FBF9FBFBFAFDFDF6FBFBFAF9FFF7F7F7
FBF0E3DFD4F5E8EBE2EDEAF3C2F3EEE771BAF8F8F8FFF8F5
F5F5F2F5F1FFFBFFFFF7EFF7FBF9F8F9F1E2F1D3E0F5FBF2
F7E4F5DEA2E0CDD19CA9D1C4E0C7DFE7F8EDEBF6F2D8F7D6
F0B1E3E3F5E5E6E2EFF5D5E3F7F8FDF7FFFFFFFBF9FFF9FB
F9FBF9FBFBFBFFFB
FCF7F9F9FFFFF7FAFFF9FBFBFBFFFAFEFFF9F7F9FFF7FBF2
F7E3F0CCE3E3ECE8EAF7F0E9D4DBDF7D97FBF8FFFFFBF5F2
F2F2FBF2F1F0ECF2F7F6F4F0FFF6FAFDF9F1EEECCEDAE9F5
F2EAECEBC1AEBBDBF6CDE6D3F4D1F2FAEDF1D8D0F0D3F1DB
DBDABDFAE3EBF7E6EFDBD6FAF4F8FCF6FFFBF9FBFFF9FFFF
FBF9FBF9FFFFFBFF
F9FBF9F9FFFFF9FBFFF9F9F9FFF9FFFFFFF7F6F7F9FBFBEF
F0E9E7C8E2E6EDE4F8FFD3E6F7E78293F8FAFAF4F6F8F4EB
E7E3E1DEDFE1EBEDE4E5EEF7FEF7F5F8FFF8F4F4EFC6C2EF
EAFCE9F7E3BBE3D3EBD0BFDAE3D5E2E6EDEAEFE3E8F7F5EF
ECEAB7E5D2F6F2DCE7D0F9FBF1FCFCF3FBFBF9F7F8FBF9FB
FFFBFFFFFBFBFFFB
FFFBFFFBFFFBFFFBFBF9FBFBFBFFFBFBF9FEFDF8F9FFF9EF
E9F5DADADDF9E8E8F4F6CCF4EC6F6AF9F8FBF9FFFCF4ECF1
F1EEE6E5E5E9E9ECF2F2F2EFF2FFFFF4FFF8F9F9F7F6DCCC
EAF6EBE5DFD0B7DED0B0D2EBB2DEDCEDF1EAE2F2D2F0E7FF
E1E6C3E2F8F7EFE1E7CAF4ECFBFBF8FBFBFBFDFFF7FBF9FB
FBFBFBFFFFFFFFFB
FFF9F9FFFBFFFBFFFFFFF9F9FFFFFFFFFBFBFEF9F9F9FBE7
EAF8CCD2E1EDF1DCF6DEE7F6EA55FAF8F6F6FBFFF4C2B3C0
D2E1EEF4F4F4E0CAC6C6CEF7F6F7FFF8F7F9F8F5F7F7EED1
BDF2EAE5E5CCBAF7BBC7F5E3E7C2D1EFF3ECF7E6D7F7F1ED
F3E3EEDEF4EFF5E1E4E1F1F6F8F7F6FEFDF7FDFDFBFFFBFF
FBFBFFFBFFFBFBFF
FFF9F9FBFFFFFBFFFFFFF9F9FFFBF7F9FFF9FAF6FFFEF3EB
F3E1CAD7EDEDF5DEFDE5F7EF7384FFFFFFFBFBD5C6D7E6B6
B7D6F4E4D1D9E9E4EAF0E2CEF1F7F8FFF4FEFAF1F9F3F3F6
C0BCE5F2F3C6C980DCD0B3CFDBE9D6EAE2DFF9E9E8EBF4E2
F4E8F7C6DFE4F1E1D2E4ECFBF8F1F5FFFBFDF9F9F9FBF9FF
FBFBFFFBFBFBF9FB
F9FFFFFFFFFFFFFBFBF9FFFFF9FBFEFAF9F9F7FFF6F6E1E7
D3C5D9E3D7E9EBFAE1DEF7B86BFBF8FAFEFAFABAF5FFF9C5
AFC9EAD8B2B1D0D8E4E5FADFC0F7F7FFF8F4F7F4F7F7F3F2
E7C0B1E6E2C0F18AD3BDC4F2F5DDD2BFECECE0E5E4E8FFF2
F3DDF8C6E9E9FCE6B6FFF6FAFBECFFF8F7F9FBFBFFFFF9FB
FFFBFBFFFBF9FBFB
F9FBFBFBF9FBFFFFFBFFF9F9FFFFFBF9FBFEF7FBFAFADBEB
D2E8DEDED4F1ECE0E7F3DE6BB5FFFAFAFED6BFB2C2ADBDD8
DBD1CCCDD1C3C8D4ADA0BDBFA0AADCFFFFF7F7F8F0FFF7F4
E6EAB7D2DBD0D9C4C5E9D5AECBCCD3D0ADDEE4FEEEE5F5E5
DDDEFEDEDBE9E8DDC2F4FDFDF5F9F7FFFBFBFBFBFBFBFFFF
FFFFFFFBFBFBFBFF
F9F9F9FBFBFBFBFFFBFBFFFFFBFBFFF9FBFFFBF9FEF7E3E2
CDDFCFDAF8FEEEEAE9EA6891FAFBF9F8FED5C7B1B9C8DEE9
E9E5D6D5DDC8C5D4C69D908184ACDBFFFAF9FDFDEEF7FFFF
E9E7D0A2DFDBCDD9C8C8BAE8ECFFBCF1DAC2F1E8F1EDFDEB
C1EFEDF8CCE6EDC8D3F5FAFAF5FBF9F9FFFBFBFBFBFBFFFB
FBFFFBFFFBF9F9FF
F9FBFFF9FBFFF9FBF9F9F9F9FBFBFBF9FAFAFBFBFBF3E4D8
C7D8EBE3FFF1F3F8FDF74EF9FEFCF9FCFAF3EBCDA28B8992
8989A4987D828C929CB3DEE8EEF3F7FFF9FAFBFDF6F7F7FE
F4F3D9B2C2E9B0EDD7BAD8C7BFD0B3CDF0AED9F1EAEBECEE
DAE8D5F7C3EFE4ABEEFEFFFFEEF9F9FBF9FFFFFFFBFBFBFF
FFFBFBFBFBFFFBFF
F9FFF9FBFBFBFBFBFBFBF9F9FBF9FBFFF7FBFAFBFADADDD1
C6DDE6E5F1E5F1F8F99486FAFAFDFBFCFCFCF7FFF8FAF8F0
F1ECFFF7F0E4EBF0FAF8F8FBF0F2FEFAFAF8FCFCF8FFF3F3
F7FFDDCABAE6ACF9C8E3CEBDDBEBE3C3F3E1D0DEEEE3FDDE
D7E6CAF7CAF0E299F6F7F6F8F0FFFFF9F9FFFBF9F9FBFBFB
FBFBFFFFFBFBFFFB
FFF9FBF9F9F9FFFEF9FFFBFBF9FBFFFBF9FEFFFEF7D2D8C2
C9F5DEF8E8F9EAFFFA56E8FBFBFCFFFAF6F7F7FFFAFAFAFA
F9F0FFFEFEECFBF7F8F8F8F1FBFFF1FBF5FAFBF6F8F9FDEA
F7FFE4D0B3D7EBC3CFD6C6DAE6CAE7CAD9F6CFEDEAF9E1EB
F1D3DCE7D8F5F4A9F0F7F9E4FEFBFFF9F9FBFFF9F9FBFBFB
FFFFFBF9FBFFFFFB
F9FFFFFBFFFBFBF9FEFBFFFFFBFBFBFBFBFBFEFFDFD6C1D6
E5E8F0E9FCFAEAFDF03FFBFBF9FCFBF9FFFDFDFFFFFDFDFF
F6F9F1F2F2ECF4F8F7F9FDF1EEF4FDECEDF8FFF9F6F9FDF6
F1F3F3DDC1DBEDC0EAE9F1E0DEEBD8C7D7CFEDD5D3F4D8D5
E3D4F5DCE5DBCCCEEAFEEFE3FFFBFFFBFBFBFFFBFFFFF9F9
FBFBFBF9FBFFFFFF
FFFBFBFBF9FBFFFFFBFFFBFFFFFFFBF9F9FFF9F5D4DBD2D0
EDE7F6E9F0EAEAF0C866FAFFF7FDFFFFF8F8FDFDFFFDFAF4
E9E5E2E3E9F1F1F1F8FCF7F9FCEFF4F4F4FDF8FCF6FFF3FF
F3EBF1E7CCC4E4E6D8EAE1E8F0DAEDCFC0D3F3E0D1EDD2DF
F0E6FCD6EBD3A8F6D5F7F2F1FBFFFFFFFBFBFBFBFFFFFBFF
FBF9FFFBFBFFFFFF
F9FBFFFFFFFFFBFBFBFBF9FFFBFBFBF9FAF7FBF5CBCBD3CF
E4E4E5F2E9F1FEE562BEFDFDF7FFFFFFFAFAFBFBFFFFF4F4
ECFBEDF0F4F0F1F4F6F6F8FAF8F4FEF4F5F4ECF5F6FAF3FF
FEEAF1E9D7C9D5C9CAF3D9E1D6D6EDE081D7DCD3C1FFEAEF
EDEFE9CFF6DBC5F4E1DEDBFFFFFFFFFFF9F9FFFFFFFFFFFB
F9FBFFF9F9FFFFFF
F9FBFFFFFFFFFBFFFFF9FBFBFFFBFFFFF9F9FBF5B9C4CEDC
ECEAEFEEEEF2EAE632FFFCFCF6FBF8F8FAFFFCFEF9D4B6D3
E9EFE6CBADC6E4D7CEE8F6F0F3F4FEFEF4FFF2F6FCF6F7F7
FEEAF3E7E3C5C0E3DADEDDEDD9F2ECF5C3CCD7E2E1DFF9D4
DAEFE1CFFCD9E3D2DFDADDFFFFFFFFFFFBFBFFFFFFFFFFFF
FFFFFFFBFBFFFBFB
F9F9FBFBF9FBFFFBFBFBF9FFFFFBFFFFFFFFFBE8A9C9DAEF
E9EFFFF5F6F0E7E144FCF8F6F2F5FAF5F4FBFCFEF4CEB8C4
FBF0E7B7A4B4D2C8EBE3E6ECFEFFFFFFF4FFEEECF7F7FAF3
F7F8EEE9E7CFA7E7E5D9E9F3EFE7D8E5BD82FAE5DABBF2CD
E6F0E3D7F0E0C4C8F2C6FBFBFFFFFFFFFBFBFFFFFFFBFBFF
FFFFFFFBF9FBFBFB
F9F9FBFBF9FBFBFBFFF9FFF9FBFBFFF9F9FFFBDFA0CBE8D6
E0FCEBF0F6DCF1AD7AFCFBFAF4FBF4F5F5F9FCFEF4F1F9F1
F3F3EDE9F7FCFBF5E3E7E2EDFFFCFCFFF4FFF0F4F6F7F7F0
EFFAF0F3E8E789EAFACAE9EAE2CCD8F2BC5EE1E4D6A9EDD9
EDECEEDFE0FFE5E1BAFFF9F9FFFFFFFFFBFBFBFBFFFBFBFF
FFFFFFFBFBF9FFFF
FFFFFFFBFBFBFFFBFBFFFBF9FFF9F9F7FAFBFBD693CCF8DC
EDFCF8F2F9D3F55BB4F5F9F4F5FEFEFEFEFBF8F8EEF3F4F7
F7F3FAEFF4FAFBFEF8F6EDEFFFFAFAFCFCF4F0F5FCF5FCF0
EAF0F0EFEBE99CF2EBC2DCC3DAD0D2E8DEA7E9D9EBCEEDF8
F2F1EACDDFF1F5D0D9FFFBFBFFFFFFFBF9FBFBFBFFFFFFFF
FFFFFFFFFBFBFFFF
FFFFFFFBFBFBFBFBFBF9F9FBFBF9FEFFF9FBF7A795EBDEDD
EFF8FBFCCEE6F227FBF8FBF4FFFEFFFEFEFEF5F1F6F4F6F7
F7F6F7EAEAF5F9F8FEF1EBF3FEF9F9FBFCFEFFF4F5F4FEF7
F4EEE8EEEFE5BBB2E2CDE8D2F6E9D3EFF2CEDDE0EEE5B6EC
E4F0EABFE6D5CDD0FFFBFBF9F9FBFFFBFBF9FFFFFFFFFFFF
FFFFFBFBFFFFFFFF
F9F9FBFFFFFBFBFBF9FBFBF9FFFBF9F9FFFFF681C5E9D3E5
ECF4FFC8DDFAF526F7F5F4F6FEFEFEFEFEFEFEFAF8FEFAF6
F6F3ECEFECF8F9F7EFE9F1FFFFFAFAF5FCFBFFFFEFF8F7FC
F4F8E1E7EBF0D4A2DDEAD0EAEDEDF7ECF6C6E1EFDEE099FF
ECEBE4C5E6DAB3D9FBFBFBF9F9FBFFFFFBFBFFFFFFFBFBFF
FFFFF9FBFBFFFFFF
F9F9FBFFFBFFFBFFFFFFFFFBFFFFFFFFF9F9FA76CAE2F0E5
F3F9FFBFF7FC7969F9F6FEFFFFFFF8F4F4F8FEFFF5F7F8EF
F5F2EEF5F4F8F7F4F2EFFAFAFCFDF4F3FCFBFEFFEFFDF9F8
F3F9F2E7E2F2E39BF4E0EDDCEDF3E3F6EDCFD4ECE4D78FEF
D3D9FCB5DFF9CDFBFFFFFFFFFFFFFFFFFFFFFFFFFFFBFBFF
FFFFFBF9FBFFFBFB
F9F9F9FBFBFBFFFFFFFFFBFBFBFFFBF9FFFBDA7AD1E1F5F7
F4FCDED1ED655DE1F7F1F7FFF8F8F8F4F4F8FEFEFEFBF3F2
FFEEF0E9F7F8F7FEF7F3FBF9F0F5F2F4F8F2F7F9F3EEF3F5
F2F1F8EAD4EBF5B3C4CEE2DEE7E5E3FFE9D3BCF8EDDCA2FC
BEC6F8AEDDE4D8FFFFFFFFFFFFFFFFFBFBFFFBF9FBFFFBFB
FBFBFFFFFFFFFBFB
FFFBFBF9FFFFFFFFFFFBFFF9FBF9FFFBF9FB7E99E1D2D9F5
F4FECDEBD426F1F9F5F9F8F8F8F4FFFEF7F8FFFFFFFEF6F6
FFF5F2E9F4F4FAF7FAF4FAF1FAFCF6F6FFF8FFFAF9FCF2F9
F4F7F0FED6E6ECD9E2F2F1EEEDFEEFF4E9CBC7F8F4E1C8DB
CDC5E6CBCADFF7FFFFFFFFFFFFFFFFFBFBFFFBF9FBFFFBFF
FFFBFFFBFBFFFFFF
FFF9FBFBFFFFFFFFFFFBFBFFF9F9FFFFFBFB55E3E5DECCEC
F5F9DFFFB85FF9F3FEFEF8F8F8F9FEFEF9F7F8F4F8FEFAF8
FEF5F5E7F4F7F2FEF7F7F5F8F8F6FEF6F5F5F8FEF8FEF7F1
EFFEEFF8DEE5E1E6DFF2F6E3F4E3FFF6F3C1E7FFFFF2E8BD
DDD5E1D1BAE7FFFFFFFFFFFFFFFFFFFFFFFFFBFBFBFBFFFB
FBFFFFFBFBFFFFFF
F9FBFBFBFBFBFFFFFBFBFFFFFBFBFFFFFBFF58F2D4E7EBED
F5E4F6DB5CB4FCF7FFFFF8F4F8FEFFFFF8FAF8F4F8FEFEF3
F4F7F2E1F0FDF0FAF7F7F7FAFFFAFAF5F5FCF3F7FAFFFDF5
F2F1F4F6E9DBDEE3DAEDF4F1E9EAF7EEE88FF3F5F5F9EF9C
EBF9EEC6AFF5FFFFFFFFFFFFFFFFFFFFFFFFFBFBFBFBFBFB
FFFFFFFFFFFFFFFF
F9FBFBFBF9F9FBFBF9F9FFFFFFFFFFFBFBBA6AE6DEF3E5F2
E7E6E98081FAF8FAFFFFFFF8F8FFFEF8F4F3F3F7FAFEF5F9
F3FFFEE6E9FBF6F0F2F1E9F7F9F8FFFAF8F3F8FDFEFFFDF5
FFECF6F1ECE8DCE3E4DEEDFFE3E1F6F5EF90E8FFF5CCB775
CFE8E0D1A6F9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFBFBFB
FFFFFFFFFFFFFFFF
F9FBFFFBFFFBF9F9FBFBFFFFFFFFFFF9F97BD6D4DCE1E1F8
D9F0EB51EFEFECFEF8F8FFF7F7FAF6E6F0FCF9F7F3F8F2FA
F9FEFEECE0FCF8F7F2FEEAF9FDF9EEEEEEF6FCFCFDFFFDF9
F4FCF2F4EBE9DCE2E8CEEDE8EBD8F9F6FFA6F6F7F8A18177
E7C9E2D1B1FFFFFBFBFFFFFFFFFFFFFFFFFFFFFFF9F9FFFF
FFFFFFFFFFFFFFFF
FFFFFFF9F9FFFBFFFBFFFFFBF9F9F9FFFB3FC1C4EDEFE9F4
D1C39584EEEEECFEF8F8FFFAF4F4F8F1F5E2E7F6F7F3F0F4
F2FEFEE3E6F5FAFCF6ECEEFCF3EFEEECE9E2DCDDE2E7F4F7
F3F7ECF4EFE8E2E6E1D3DBDAE4DAF6F9EEA5FAE6DE9A6F8F
EBB3D7D0CCFFFFFBFBFFFFFFFBFBFFFFFFFFFFFFFBFBFFFF
FBFBFFFFFFFFFFFF
FFFFFFFBFBFFFFFBFBFBFBF9FBF9F9FBF82FC7BBE9E9F6C3
F4D674E5D8D8F1FEFFFFFAF2E3C5B2BEDEE2D6E8E7FAF5FC
EFFEFEE3E7ECF2EFE8F5E6EFE9E3DACCC8D9EAE9E9E5FFF2
EEEEF2F4EDEBE6E3E6ECCCE2F5CEF3E6EAB5E5DCF2BC6F85
E29BEDC2D0F8FFFFFFFFFFFFFBFBFFFFFFFFFFFFFFFFFFFF
FBFBFFFFFFFFFFFF
F9FBFFFFFFFBFBFBFBFBFBFBFBFFFFFFAD7CFAC6EDEDE8B5
BD9994C6EBCDF7FAFFF4E0B7B9F8D6D7A4C8D1DDC0C6FAFC
EBFFFFECE6E4F8F5D79980A7D9ECC3BAC9DBD0D0D0CAE6F1
FFFFF6F8EDEBE6E3E8EAEED9F4C8FFEFF6CFF0E3F9CC7680
E29DEDB5DCF8FFFFFFFFFFFFFFFFFFFFFFFFFFFBFBFFFFFF
FFFFFFFFFFFFFFFF
F9FBFFFFFFFBFBFBFBFFFFFBFBFFFFFF7CF4D6D5E4E8E8C3
D84CEEE7EBD1F8FEF0E0BFD8CBBBB0BAEECED6E8F7C4E1EB
EAFFF8F0ECE4F3DFDEC9D29CA7C1ACDFCCDDD3DEE4C1D7F3
F6FEF4F8F4E5E5F2E2EAE5B8E1BCF7EFD5DCF2D6EDD8897C
C5C1FEACF2FFFFFFFFFFFFFFFFFFFFFFFBFBFFFBFFFBFFFF
FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFBFBFFFBFBFFFFF891B1B7D6C8CFF5DF
C440D7EAECDCF0F2E3D0BCAC7DC28FBC869ACEA7D6D3E4E1
EFFFF6F6EEECD7F0EBD5CACB8C5EB5848DCC9E89BAC7D4DF
E4F4F8EBF0E6E7E5E5F4CDDFEACACDE7C2EFE9EEEDE8A47A
A2DEE7B1FFFFFFFFFFFFFFFFFFFFFFFFFBFBFFFFFBFBFFFF
FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFBFBFFFFFFFFFFA39A8BC9DADFDBFFF5
D18DCFF7E8DFF7EBDFD7B1E8BE8C6A6BA0A5D9C7DBD4D4E6
F9FAF8F4F4F6D9E3DEFAD8F4C46F7E82C1D7ACB8D8C5ECF0
DFEEF6E9F2E9D3E5F7EED2DBDFE1E1EEC7FAF9E7E6EBAE8B
B5E4B8D2FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FBFBFFFFFFFFFFFF
FFFFFFFFFBFBFFFFFBFBFFFFFFFFFF6AB5D2C6D8F0EEF5EA
BEC0E0FBEBDDFAF0E1CD9ABDECD8CECBE2DDDAB9C1CDEAEE
FAFAF8F4F8F0E3DDE0D6D9EFD5BC91A9D3F8FFCBC1C4EEED
E6F7F3F7EDE9D9FCF7F2E6D7E5F9F2E6C7ECECF2DCF0C3A1
CCE0A6EEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FBFBFFFFFFFFFFFF
FFFFFFFFFBFBFFFFFBFBFFFFFBFBFF89BACDB0E7E1E4E7D7
BFDBECF3E4D9FBF5EAD8C3A0847875756E82BFE1EDE8F2F6
F9FEFBF2F6FAEBE4F9ECE9B2ADD4E0C7A2827995BECDCCDB
EFF9F0F7F5E4D9FBEFE7E5E0ECECE1F6BCDFDFF2D4EBD6A8
D0B2B0F4FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFBFB
FFFFFBFBFFFBFBFFFFFFFFFBFFFBF8E843C6C4E8EFE1D0BF
CBDCF7EFDED1F8F1F6F8F1EEE6DDDFD7B19FAFC7E3DEF1FA
F3F8FEFAF8F4E2E0E6C8BCB7C7E7C1BBBDCCDAE3ECF4F7F4
EDDDECF0F3EAE1F6EEE8E3EDF2DFD8E7D0CFDEF5C8F3CFA4
CE9FE1F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFBFB
FFFFFBFBFFFBFBFFFFFFFFFBFBFFF0EA00DECEF2F1DBD4CA
E3D9E6F4E0C7F2F3E7F3FEFEF5B2A1C1E6D49FA6E8F0F9F9
F6F4FEFEFAFFEFE3C6BAE2DBC49FAEDEEFF9F3F1F9F5F1E4
D3F4F9EFE9EDF5E9DDDDD3FCF7F1E7C9DEE0F1EBC0F7CBC0
DD96F2FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFBFBF8B7B00AF4EDE4F6DBF1DF
EDDCD2EEE4C6F8CFC4C0BCB094ACE5A07B97CAE7EEF2F9F9
FEF8FEFEFEFAFBF7E2BA8C86A5E3C29A948EA3B5B7B1BAD5
F4E6F7F2E5F0FFE3E2C8F3DFE3E8D9C9EBEDF1EBC2EDF1C3
BCA6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFBFFFFFFFF
FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFF9F9F8949D52F4E3E7DDE5F5EA
F5FBE1EBD1CEF5C8BBDFF2F1D69291C4F2F6F9FFFFFFFFFF
F4FFF8F4F5F8FAF9F9F7E9DABE987A7D9EDDEEE5EDF1D6DE
EFF4F3F3E1F4F3D6DDD3E4EBD2D7EEA7EDEEF0EAC5EDC8F8
82D7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFBFBFBFFFF
FFFFFFFFFFFFFFFF
FFFFFFFFFBFBFFFFFBFBFFFBFBFFAA9FD4F2CBDAE1EEF5EA
F7F7E6F9C3D0F9FBFAD8B7ABB8DEF4FFFFFFFFFFFFFFFFFF
F4F8F8FFF8F7FEFEFEFBF5F9F6F8FDFCD6B3979FB0C6E5EC
EBF8ECE7E9F9F9DBCEFFDAD9E5FFF381E4EBB7CAD3DBB1C6
8AF2FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFBFFFF
FFFFFFFFFFFFFFFF
FFFFFBFBFBFBFFFBFFFBFFFFFFFFB57AE2F8BBDEE4FDEFEE
FCF7DCF9C2CCF9FBFFF5FFFEF8F4FFF5F9FFFFF9F9FFFFFF
F5F9F8F8F8F8F8FEFEFEF8F7FAF5FFFDF5F5F3F4F4F7F7F6
F9E9F7EAE8FAFCE3EDCFDBECEBE4EA64CCE1A9C7F8B3A6A5
98F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF
FFFFFBFBFFFFFFFBFBFFFFFFFFFFB967E5E8D4DBF1EBF4FC
F7F4D6F6CBC1F0FBFFF8F8FEF9F8F8F9F6FFFFF9F9FFFFFF
F9F5F8F8F4FFF8FEFAF8F8F8FBF5FEFDF9FFF4FBF4F7F7F8
F9F3F5E7E8F5F6E8EDC5F4ECE6E4EA5EDBDEB2CFE8ADB56E
CAF8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF
FFFFFFFFFFFBFBFFFFFFFFFFFFFFDA4CFAE7DFE9F8ECF5F7
FAF9D2EBDBC4F0F1FEFDF6FFFEF8F8F9F9FFFFF9F6F9FFFF
FFFFF8F4F4F8FFF7F9FFFFFCF7F8FFF4F2F6FFF7F4FFF6FD
ECF1ECEFEAFFECE2DBE1EDDFE4FFE47FF2CCC6CDE3DEE871
FBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFBFFFFFF
FFFFFFFFFFFFFFFF
FFFFFFFFFFFBFBFFFFFFFFFFFFFFF62EFAECF1EBF4E9F5FA
FFF7DAE9E9D4F0ECFEF8FAFFFEF7F8F9F6F9FFF6F9F9F8F8
FFFFF4FFFFFEFEF5F4FAFFFBF9FFFFEFFBF8F8FAF5FDF6FD
ECF6EFF9F6F1EDE3E0FBEBDBF7F7E19DC6D0CFE2E5DF84B4
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFBFFFFFF
FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFF434EEF3E8F7F1F4EFF9
EFEFEADEF0DFE5EFF9FAF8FAFFF9F9F9F9F8F9F9FEF5FEFE
F5F4F9FEFEFEFFFAFAF8FFF7FCF8FFF4F2F8F8FAF6FCF5FE
ECF6EFF7FFE5F1E9DAFFD3F2EAEABFBCCEE2CCF0DBB56DDD
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFF435FBCCF0EFF2FCF4EE
ECE0E3E3F6DFE0F3F6FDFAFAFFF9F9F8FFF5F9F9FEF9F9FE
F8FEFEFFFFFEFEFAFAFAF6FBF9F6FFF4FCF5F8F1F8FEF5FE
E5F4E9F7ECE4EDDDF7DDD9E8F1E793E7EDE7C0F8E7D5A4FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF
FFFFFBFBFBFBFFFFFFFFFFFFFFFFF8649CDCDCF2EDF0F9F3
EFE1DEE7F0E2E1F2F8F7FAFEFEF6FFF5F5F9F9F6F9F9F9FE
F8FEFEFEFEFEFFFEFFF5F9F6FBFBFFEFF0EDFFF4FFFFF8F7
EAF3DFEFE9F8E8DDF1DCDAF5E3E389F5F8F0BCF8EDA2E8FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF
FFFFFBFBFBFBFFFFFFFFFFFFFFFFFFE857DAFCF2F5FBF2F4
EDF6DAEDE6EEE5F2F6F9F5FEFEF9F6F9F9FEF9F9F5F9F7FE
F8FEFEFFFFFFFEFEF5FAFBFFF4F8F8F4F5F1F8F4FEF8F8F4
F5F5E2F5EBEEE8CFDAE4ECF2E6F080F2F7F2B7E3D3B0FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF866A4F3F5F6FCF4F8
EDE6E2EEE6E9EAF3F4FBF4FEFEF9F9F9F5F8FFFFF8FFF7F9
FEF9FEFEFEFFFFFFF4F5FAFBFBFCF8FEFFF1F8F4FEF8FFF8
F0F0EDF3F4E6E9CEF4E7FAE4EBF67AEADCEDC3D5C2DAFBFB
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF
FFFBFBFFFFFFFFFFFFFFFFFFFFFFFFFFC565E1F0F5FAFBFA
FCDCE2E6E4EAE6F7F7F8F8FBFEF9F9F9F9F9F9F8F9F9F8FF
F9F8FEFEFEFEFEFFF8FAF7FEFCFAFFFFF8F6F8F3F7FFF5F9
F4F1F5E7F6E8E1D0F8EAFFF4E9F382E4CFD2CFC7C3FFFBFB
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF
FFFBFBFFFFFFFFFFFFFFFFFFFFFFFFFFFB54CEE0EFF3FCF8
F8E0E4DAE2E8F0F7F7F8F8FAFFFEFEF9F9F5F8F9FFFEFEFE
FFFEFFFEFFFEFEFAFAFFFBFCF7FBFEFFF3FFF9F5F6FFF6F7
F3E8FAE7F0E8E5DDFAECF4F2EDE381E4E6D4D3BCDAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8D689CD5E6DFEB
FDE6E8DFDEE0F6F7F8F8F9F6FAFEFFF8F5F9FFF9F8FEFEFE
FEFFFAFAFAF8F8FAFAF8FEF9FAFFFFF4F6FEF8F7FBF4F7FC
DFF4EEF3E7E7E5F3ECF6ECF3E0DF7CEAF7D0DAAAFBFBFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF
FFFBFBFFFFFFFFFFFFFFFFFBFBFFFFFFFFF4BD7E8AFAEFF7
F1F0DFE4EBE0E6FEFFF4FDF8FAFBFBFFFEFFFEF9F9FEFFFE
FFFFFAFAF8FFFFFAFFF1F7F7FEFFFFF2FDF8FBF7FFE8F9ED
EBF7E5E3DAF7E4F2ECF2F6E8F187BBDCE7DFC6B4FBFBFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF
FFFBFBFFFFFFFFFFFFFFFFFBFBFFFFFFFFF8F4F26AC8F4F5
F0FDE1DEECE7E6F2F4F8F8F9F3F9FBFBFEFFFAFAFFFFFAFA
F8F6F6F6FAFFFCF4F0F8FFFFFFFEFFF2F8FFFFF7F8EFFFF3
EBE7DFE9F0F9EAD8F8EDF1E28A91F1E7CFCBACDAFBF9FBFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF49B6ADAE4
E7E6E8E6E6E7EDF9F3FFF7FBFBF7FAFAF8FAFFFAFFFFFAFF
F9F8F8F9F8F8FBF6FFFFFFFFFFFFF7F9F8FEF8F6FBE4F1F5
DEECEEF2EDEDECDDC4E3F3BDAADAEDF2CBC6C0F1F9F3F6FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF4AD6FDDD9
E6D4FFE6E6E7F2ECF7FEFEF7F6F1F5FEFAFAFAF8F8F8FAF4
F9F2F0F8F1F1F7F7FEFFFFFFFEFFEFF6F8F8F8FEF7E2F3E6
DFEBE9E7EDEEF4DED7C8C7D6D8E2F3DCCAD7BCF3F3F6F8FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF495CAABEF
F2DCE1E3E4E4EBF3F1F8F4F0FCF4F7FBF5F6FBFFFAF6F3F2
FBFBF4EDF1F1F4FFF9F3F3F2EDEDE9F6F6EFF4EFE4EDF8F1
EAF9E9E5F2EFF0E3EEE4B2BACFF1CBE7CBBECBF8F3FBFFF8
F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8F8FFFFFFFFFF
FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8B0BD5ADE
E0F0DBE7ECE6E9F7F2F2F5EDFAF8F6FFFAFCF7F5F1F1F9FA
F8F0EBF5F8F8F1E8E7EFEFE8EDF5EEF4F4F7F4F7EFF2F0F9
EDFAE1EAF3F2E0D3E9D4A8DFEFE1C2DEDBBBFBFFFBF3F8F8
F8FFFFFFFFFFFFFFFFFFFFFBFBFFFFFFFFF8F8FFFFFFFFFF
FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE9BD78BE
E1FAF0E1E5D3E4F0FBF5F9F2F1FDFDFAF8F7F3F3F3EFE6E0
E4EEEEF0EAE3DEE1E8E9E7EBE6DAE1E4E4E1E0EAECF1F8E6
DAEEEBEEEFDFF9F1DFDDE4E6E0F5D0E6D5CBFBFFFFF8F8FF
FFFFFFFFFFFFFFFFFFFFFFFBFBFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFB68CAF
E9EDFFE7EBF2D4CBE0FAF5F1F4F7F3F3F4EBECE5E5F7EBF5
F5F4E4EAE4E9EAEDE3E0DEDADEE0E5EBE6EEF8EAEDF6EAE9
D9E5EAF0E4EECBEFCDE1E3E3DDE1D1F2BDF9FFFFFFFFFFFB
FBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8F8FFFFFFFFFF
FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBA77
78D4F3DCEBDCD4EDD6EAEDF8F8F9F6EFE6ECF6F7F8E8EAFD
ECE6E4EDEAEFEFDEE3EEDAE0ECF1E4E5E7EDEFF4E2C5D6E7
E9F2EDEBF1D3EDCFC4D8F3EFCBD8F1BFCBFFFFFBFBFFFFFB
FBFFFFFFFFFFFFFFFFFFFFFFFFFBFBFFFFF8F8FFFFFFFFFF
FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFBFBFBFBFFFFFFFFFFFFFFFFFFFFFFFFF2
7AE5D9E2EAC9B9EEDBE4DBE8F3F2F1F3F6FBE9E9F5F5EAEB
ECF6F0F7E6E2EAF1ECF5F4DEF4F1EFF7EEFCF9F1D3F2EFF7
EFF6F6F0EFE8EDFBF1EACEC4EAF4E3A8FFFFFFF6F6FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFBFBFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF
FFFFFBFBFFFFFFFBFBFBFBFFFFFFFFFFFFFFFFFFFFFFFFFF
9A84F3EFEAC7D4E2DBF4F2FAEEEDF7ECF1F1E3EFE7E7EFEF
EAFAE9E9F5E4E2EDF2E6E5EDF2D0C8DBE9F2FBE6E2F9DAC5
CDDFDBD6E5E7EBF3CFC4C2E7EFDAA0DDFFFFFFF8F8FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF
FFFFFBFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F88388E1EDCFE1E3D7E6FCFBEBEEECF0F7F7EDF8F0F1FAF9
E6E4D0F0EFD9D7CFDCE7F2FFFFD8D7E7D1B2C5E2EAF1F3E1
D8E9F0F0EEE6ACBBCCDBB7BBE1E28AF8FFFFFFFFFFFFFBFB
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFF885D5E3C4C2C2CEF0FBFCE3F5F4EDF4F7EFEBF2FAF2EE
F4E6E6E2E0EDB6E2FFF2D6E3DBE1EDC8DAECDFECF8F4FEED
E0E5F0D3C5C4D6EEDCD5BABFDC7EDBF8FFFFFBFBFFFBFFFB
FFFFFFFFFFFFFFFFFFFFFFFFFBFBFFF8F8FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFB675F2C5D1EAD9E0F8F6EFD5E3ECEBFFF0E7ECFAECEC
F4E7EED0EEDCE6DEDDE9F7EFEEF5F7EFEFF5DFE8FBF2EDF6
F0D4E1F2F0D7E9E2A6CDDDE4B898F9FBFFFBFFFBFBFFFBF8
F8FFFFFFF8F8FFFFFFFFFFFFFBFBFFF8F8FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF86887C6CDDFE6F1DEF3EFC2EBF0E6E3E6E9E6F9EAE4
E4EBC9D8F4F4E8CED7E3EFF7F7F6F9F0E4DFF2EFE6EFE8E6
EED9DDD5B8C0FECAECD5E8B79EE6F3F9FFFBFBFFFBFBFFF8
F8FFFFFFF8F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFBFB8C54EAA6D1EED1F9ECBEE8EEE9ECEADDF9E9EDF2
F2F5D7DEFAF0DFD4B7DCD6DFF9E4F1F3EFF5EDE9E6DDDCEA
BED8E3EBF39EAEE5E4E5F770F0F4F6FBFFFBFBF8F8FFFFFF
FFFFFFFFFFFFFFFBFBFFFFFFFFFFFFFFFFF8F8FFFFFFFFFF
FFFFFFFFFFFFFFFF
FFFFFFFFFFFBFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFBFBF88679E8D2CED5E0FABAE4D6FAF5D5E1DEE5E4EC
F3E7F8EFEEF2EEC0C6F4CDE4F4E7DFE7D1C0D4CDB7B2C8CF
E4CDD0DFC7B4D0E8F3D77DB7FFFFFFFFF8F3FFF3F8FFFFFF
F8F8FFFFFFFFFFFBFBF8F8FFFFFFFFFFFFF8F8FFFFFFFFFF
FFFFFFFFFFFFFFFF
FFFFFFFFFFFBFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFDB769CE0E7BBB3C5F8B1E8DCF5EBF3DEEDE1E1
F1F7EEE7F2DEF5E7EED7CDE4F3E4E2E8ECEFD2C6BCCFDEC7
E5D8C5EABBF1C2EEEF9AA3F8F4F8FBF6FBFBF3FFFBF8F8FF
F8F8FFFFFFFFFFFFFFF8F8FFFFFFF8F8FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF8F8FFFFCC88C5F0E6DCF6D0C4C4EFE1EEE8E4D5FBF7
F3F7F6E0E3F0E8E5E9C6E1DBF3DBF8E1D0D0DBD3DDE4E9C2
BDBBA2ACF3D5F8F0898FF8F8F8F8F3F6FBFBF8FBFBF8F8FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFF8F8FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF6F6FFFBFBBA82BDEDE7F0EAF4C4BFE1E1F7FAE3D8EE
E7D6D7E2CFF5D5E7B9B1A09C979FB4C0B9ADBFDADEBCD1EF
DDDEEBBDC2F0FA81A6F8F8F8F8F4F8FFF8F8FBFBFFF8F4F8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFBFBFFFBF3F8C56B87F9CAC1DBF0BFD3DEDFEDEEE2AB
A7D0DDE8D6E2CEE7D8C3F4E1D9D6CAD8F0C0C5C9C0E7F7D7
E7E9DCCDF5FF8C8EF8FBF3F8FBF9FBFFFFFBFFFBFFF8F4F8
FBFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFF4F4FFF8927CDECCCED6EDBECFC4C1B3AFE4
C56B4A425891BBCBBDC4F4F4EFEEB3C0CDDADDE6DFEFE5EE
BDCDECED9E68A4F8F6FFFBFFFBFBF9FFFFFBFFFBFFF8F8FF
F9F9FFFBFBF8F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8F8FFFF
FFFFFFFFFFFFF4F4FFFFF88C57A8D6C5CDF3DDD6D5E0F2DA
D3F6D8D8E4F9F0E0EFF9EDD6D0CFE0E8C7EFEAE3FADCBDB3
E5F4DD8C8DF3FBF6F8FBFFFFFFFBFBFBFBFFFBFBFFF8F8FF
FBFBFFFBFBF8F8FFFFFFFFFFFFFFF8F8FFF8F8FBFBFFFFFF
FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8F8FFFF
FFFFFFFFF8F8F4F8F8F8F8FFE86C8AE9DDCCE8DDE9F7F6F2
F6F1E0E4ECF3F6F1F6F2F0D5DADDDED1D3E5D4DACCD5EAED
FCB089B7FFF9F9FBFBF8F8F8F8FFFBFFFBFFFFFFFFFFFFFF
F8F8FFFFFFFFFFFFF8F8FFFFFFF8FFF8FFF8FFF3FBFFFFFF
FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF8F8F8F4F8F8F8FBF3F28C6799DEB7C8F0EEF6FF
FAF1E4E9EBE5CEBAB7CAE0D6E9D8DBE0D5C7B0A9D8EAECA9
81ACE9FFFFFBF3F8FFF8F8F6F6FFF6F6F8F8FFFFFBFBF8F8
F8F8FFFFF8F8FFFFF8F8FFFFFFF8F8FFF8F4F8F1FBFFFFFF
FFFFF8F8FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8F8FFFFFF
FFFFFFFFFFFFFFFFFFFBF6F3FBF4F4FFA66D62C0CDC0D4DB
EEF0F3F7EFE5D8DCD6EFEEF6C19DA6B1BBE6E4DCCE8C7BB2
F6FFFFF8F8FFF8F8FFF8F8FBFBFFF8F8F6F6FFFFFBFBF8F8
F8F8F8F4F8F8F4F8FFFFFFFFF8F8FFFFF4FFF8FBF6FFFFFF
FFFFF8F8FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBF3F8FFFFFF
FFFFFFFFFFFFFFFFFFFBF6F8FFF8F8FFF8F8F8A686BFEDE6
E0CCE6F3F5FAE4C6B4B4B8BFE7D3F0D3DBE6A99CCAE9FFF3
F6FFFFF8F8FFFFFBFBF8F3FBFFFFFBFBFBFBFFFFFFFFFBFB
F8F8F8F4F4F4F1F6F8F6FBFFF8F8FFFBF3F4F8F8F3FBFFFF
FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBF3F8FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFBFBFFF4F1F2F6FFBA9CAB
ADB4D2E4E1E8F5CFC6DFF7F6F2FCD39E9CB8D7F2FFF4FFF1
F3F4F4F8FFFFFFFBFFF9FFFBFFFFFBFBFBFBF8F6FBFFFBF3
F8FFFFFFFFFFFBFBF8FBF6F8F8FFFFFBFBFFFFFFF6F6FFFF
FFFFFFFFF8F8FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8F3FBFFFF
FFFFFFFFFFFFFFFFF8F6FBFFFFFBFFFBF8F6F9FBFFFFFBF9
F2E9ECE5E8F0D8C6BEC6C7C2C5C8D9F1FBF8F4F8FFF8F8F4
F8F4F4F3FBF8F8FFF6F2FBFFF8F8F8F8F6F6F6F8FBFBFBF8
F8FFFFFFFFFFFFFFFFF6F6F8FFF8FFFFFFF8F8FFF8F8FFFF
FFFFFFFFF8F8FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFBFFFF
FFFFFFFFFFFFFFFFF8F6FBFFFFFBFFFBFBF6F8FFFFFBFBFB
F3F8F8F6FBFFFBF9F9F9F1F4FFFBFBFFFFF8F4F8F8F8F4F4
FFFFFBF8F6F4F8F8F8F8FFFFF8F8F8F8F4F1FBF9FBFFFBFF
FFFFFFFFFFF8F8FFFFFBFBFFF4F4FFFFFBF3FFF4F8FFFFFF
FFFFFFFFF8F8FBFB
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8F8FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFBFBF8F1FBF8FFFBFFFBF6
F6FFF8FBF6FFF8F8FFFFF6F6FFFBFBFFFFFBFBF8FFF8F4F8
F8FFFBF8F6F8F1F6F8F8FFFFFFF8F8FFF8F6F9FBFBFBFFF8
F6FBFFFFFFF4F4FFF8F8FFFBF3F8FFFFFBFBF6F3F4FFFFFF
FFFFFFFFF8F8F6F6
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8F8FFFBF3F8FB
FBFFFFFFFFFFFFFFFFFFFFFBF6F8FFF8F1F6FFFFFBFFF6FB
F6FFFFF4F4FFF8FFF8FBFFFBFBFBFFFFFFFBFBF8F8FFF8F8
F4FFFBFFF3F8FBFBF6FBF4F8FFF6FBF8FFFFFFF8F8FFFFF4
F1FBFFF8F8F8FFF8F8FFF4F3FBF8F8FFFFFBFFF6F8FFFFFF
FFFFF8F8FFFFF8F8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8F8FFFBFBF8F3
FBFFFFFFFFFFFFFFFFFFFFFBF6F8FFFFFBFBFFFFFFF9F2F6
FBF8F6F3FFF8FFF8F8F6F6F8F3FBFFFFFFFFFBFBF8F8FFF8
F8FFFBFBF8F8FFFFFBF6F1F6FFFBF6F8FFFBF6FBFBF8FFF4
F4FFFBF3F8FFF8F8FFF8F4F8FFF8F8FBFBFBFBFFFFFFFFFF
FFFBF1F4FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8F8F8F8
FFFFFFFFFFFFFFFFFFFFFBFBFFFFFFFFFFFFFFFFFFF9FBFB
FFF8F6FFF1F8F8FFF8FBF6F8F8FFFFF8F8FBFBF9F8FFF6FB
F8F8F8F8FFF8F8F8F8FFFBFBFFF8F8FFFFFBF6F2F2FFF8F8
F8F8F3FBFFF8F8F8F8FFF8F6FBFFFFFBFBF8F8FFF8F8FFFF
FFFBF6F8FFFFFBF9
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8F8F8F8
FFFFFFFFFFFFFFFFFFFFFBF3F8FFFBFBFBFBFFFFFFFBF9F3
F8FFFFFBF6F4F8FBF1F1FBFFFFFFFFF8F8FBF9FBFBF3FBF6
F4F4F8F8FBF1F1F1F4FFFFFBFBF8F8FFFFFFFFFBF3FBF2FB
FFF8F3FBFFF8F8F4F4FFF8F6FBFFFFF8F8F8F8FFF8F8FFFF
FFFFFFFFFBFBF6F2
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8F3
FBFFFFFFFFFFFFFFFBF6F8F8F3FBFBFFFBF9FFFFF8F4F8F8
F8FBFBFFFFFFFBFFF6FFF8FBF6F8FFFFFFFFF8F8F6F6F6FB
FFF3FBFBFFF6FBFBF8FBFBFBF3F6F6F8FBFBFBF6FFFBF2FB
FFFBFFFBFFFFFFF8F8FFFFFFFFFFFFF8F8FBFBFFFFFFFFFF
FFFFFFFFFBFBF8F8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFB
FBFFFFFFFFFFFFFFFBF6F8FFF6F6F8F3FBF2F4F8F6F3F4FF
FFFBFBFFFFFFF6F1F8F8F8FBF1F4FFFFFFFFF8FFFFF8FBF6
F8F6F1F1F1F8F8F8FFF9F9F8FFF6F6FFF1F1F1FBF8F8F8FF
FFF6F1F8FFFFFFFBFBFFFFFFFFFFF8F8FFFBFBF8F8FFFFFF
F8F8F8F8FFF8F8FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8F8F8F8FFFB
FBFBFBFFFFFFFFF8F8FFFFFFF8F8F6F6F9F2F1F6FBF6F8FF
FFFFFBFBFFFFF8F4F8F8F8FFF8F8F8F6FBF8F4FFF8FFFFFF
FFF8F4F4F4F8F8F8FFFBFBF8F3FBFFF8F4F4F4FFF8F8F8FF
FBF3F8F4FFFFF8F3FBFFFFFFFFFFF8F3FBFBFBF8F8FFFFFF
F8F8F8F8FFF8F8FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF4F4F8FFF8FB
FBFBFBFFFFFFFFF8F8FFFFFFFBFBFBFBFBFBFBF3F8F8F8FF
FFFFFBFBFFFFFFFFF8F8F4FFFFFBF3F6F3F8F8F8FFFFFFFF
FFFFFFFFFFF8F8F8F8FFFFFFFBFBFFFFFFFFFFF4F8F8F4FF
FBFBF8F8FFFFF8F8FFFFFFFFFFF8F8F9F9F9F9FFF8F8FFF8
F6FBFFFFFFFFFFFF
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[26]:=",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`004@3oool20?KfmP80oooo0P3emOD20?ooo`80o?cl0P3oool40??cl`80
o?cl0P3IfMT40?ooo`80o_kn1@3gmoL80?ooo`80f][J0P3gmoL208J6QP80/;2`103clo<20?ooo`80
moOg0P3emOD20?ooo`@0lo?c1P3no_h20??cl`80oooo0P3emOD20?ooo`80n?Sh0P3oool20?Win@80
oooo0P3no_h40?ooo`<0o_kn103_knl40?ooo`80m?Cd303oool40?_kn`80m?Cd0P3oool20?_kn`80
nOWi0P3dm?@80?ooo`80o_kn1P3oool20?knoP80oooo103lo?`20?ooo`D0o_kn0P3oool20?knoP80
h^;R103]kNd20:6QX@80b/[:0P3oool20?Gem@80oooo0P3emOD40?ooo`80moOg2P3oool20?Cdm080
o_kn103jn_X20??cl`@0n?Sh103oool40?Gem@<0m?Cd0P3emOD20?knoP80lO7a0P3oool20?[jnP80
oooo0P3no_h20?_kn`80e=CD0P3oool20<K6aP80fMWI0P3QhN420??cl`80nOWi0P3emOD?0?ooo`00
4@3oool20?KfmP80oooo0P3emOD20?ooo`80o?cl0P3oool40??cl`80o?cl0P3IfMT40?ooo`80o_kn
1@3gmoL80?ooo`80f][J0P3gmoL208J6QP80/;2`103clo<20?ooo`80moOg0P3emOD20?ooo`@0lo?c
1P3no_h20??cl`80oooo0P3emOD20?ooo`80n?Sh0P3oool20?Win@80oooo0P3no_h40?ooo`<0o_kn
103_knl40?ooo`80m?Cd303oool40?_kn`80m?Cd0P3oool20?_kn`80nOWi0P3dm?@80?ooo`80o_kn
1P3oool20?knoP80oooo103lo?`20?ooo`D0o_kn0P3oool20?knoP80h^;R103]kNd20:6QX@80b/[:
0P3oool20?Gem@80oooo0P3emOD40?ooo`80moOg2P3oool20?Cdm080o_kn103jn_X20??cl`@0n?Sh
103oool40?Gem@<0m?Cd0P3emOD20?knoP80lO7a0P3oool20?[jnP80oooo0P3no_h20?_kn`80e=CD
0P3oool20<K6aP80fMWI0P3QhN420??cl`80nOWi0P3emOD?0?ooo`003`3oool20?gmo@80n_[j0P3e
mOD20?Win@80n?Sh0P3emOD20?KfmP80n?Sh0P3no_h20?Win@80i>CT0P3WinL20?knoP80oooo1@3j
n_X60?ooo`80o_kn0P3Ti>@20>WYj@80V9RH0P2o_kl20?Gem@80m?Cd0P3oool20?Win@80o_kn0P3e
mOD20?Shn080moOg0P3hn?P40?ooo`80n?Sh0P3dm?@20?knoP80nOWi0P3gmoL40?_kn`@0oooo0P3e
mOD20??cl`<0n?Sh0P3dm?@20?clo080moOg0P3oool20?Ogm`80m?Cd0P3gmoL20?[jnP80m_Kf0P3d
m?@20?Shn080moOg0P3fm_H20?ooo`80n?Sh0P3lo?`20?Ogm`80n?Sh0P3oool40?clo080oooo0P3n
o_h40?ooo`80o_kn103oool20?gmo@80oooo0P3gmoL30?Shn0H0oooo0P3[jn/20=kNgP80oooo0P2S
Xj<20>g]k@80eMGE0P3hn?P20?ooo`80mOGe103oool20?Win@80moOg0P3inOT20?gmo@@0o?cl0P3f
m_H20?[jnP@0o_kn0P3bl_840?Ogm`@0mOGe103oool30?Shn080m?Cd0P3oool20?Cdm080lO7a0P3h
n?P20?ooo`80nOWi0P3Lg=`20=SHf080hn?S0P3QhN420>_[j`80emOG0P3clo<20?[jnP80nOWi3`3o
ool000l0oooo0P3moOd20?[jnP80mOGe0P3inOT20?Shn080mOGe0P3fm_H20?Shn080o_kn0P3inOT2
0>CTi080inOW0P3no_h20?ooo`D0n_[j1P3oool20?knoP80i>CT0P3YjNT209RHV080_kno0P3emOD2
0?Cdm080oooo0P3inOT20?knoP80mOGe0P3hn?P20?Ogm`80n?Sh103oool20?Shn080m?Cd0P3no_h2
0?Win@80moOg103kno/40?ooo`80mOGe0P3clo<30?Shn080m?Cd0P3lo?`20?Ogm`80oooo0P3gmoL2
0?Cdm080moOg0P3jn_X20?KfmP80m?Cd0P3hn?P20?Ogm`80m_Kf0P3oool20?Shn080o?cl0P3gmoL2
0?Shn080oooo103lo?`20?ooo`80o_kn103oool20?knoP@0oooo0P3moOd20?ooo`80moOg0`3hn?P6
0?ooo`80jn_[0P3Ng]h20?ooo`80Xj>S0P3]kNd20=GEe@80n?Sh0P3oool20?Gem@@0oooo0P3inOT2
0?Ogm`80nOWi0P3moOd40?clo080m_Kf0P3jn_X40?knoP80l_;b103gmoL40?Gem@@0oooo0`3hn?P2
0?Cdm080oooo0P3dm?@20?7al@80n?Sh0P3oool20?Win@80g=cL0P3Hf=P20>?Sh`80hN7Q0P3[jn/2
0=OGe`80lo?c0P3jn_X20?Win@l0oooo000=0?ooo`80oOgm0P3kno/20?[jnP@0o_kn0P3hn?P20?Ge
m@80nOWi0P3oool20?Shn080oooo0P3emOD20=kNgP80hn?S0P3oool50?knoP@0o?cl0P3oool40?_k
n`80iNGU0P3<c<`20=;BdP80]kNg0P3kno/20?clo080nOWi0P3dm?@20?[jnP80n?Sh0P3fm_H20?Wi
n@P0o_kn103fm_H20>g]k@@0no_k0P3no_h20?Win@80n?Sh0P3moOd30?KfmP80l?3`103alO420?3`
l080nOWi0P3no_h20?_kn`80o?cl0P3jn_X20?ooo`@0n?Sh0P3oool20?Ogm`80n?Sh0P3jn_X20?Kf
mP80m?Cd0P3fm_H20?clo080n_[j0P3hn?P20?ooo`80o_kn2P3oool20?gmo@D0moOg203oool20>_[
j`80fm_K0P3Ng]h20:2PX080jNWY0P35aLD20?Gem@@0n?Sh0P3fm_H20?Win@80oooo0P3emOD20?Sh
n080lo?c0P3gmoL20?Shn0P0n_[j0P3oool20?knoP80n_[j0P3fm_H20?[jnP80m_Kf0`3moOd20?Og
m`80oOgm0P3no_h20?gmo@80nOWi0P3alO420>_[j`80kNg]0P3_knl20=[JfP80jn_[0P3moOd20=GE
e@80k>c/0P3jn_X20?Win@l0oooo000=0?ooo`80oOgm0P3kno/20?[jnP@0o_kn0P3hn?P20?Gem@80
nOWi0P3oool20?Shn080oooo0P3emOD20=kNgP80hn?S0P3oool50?knoP@0o?cl0P3oool40?_kn`80
iNGU0P3<c<`20=;BdP80]kNg0P3kno/20?clo080nOWi0P3dm?@20?[jnP80n?Sh0P3fm_H20?Win@P0
o_kn103fm_H20>g]k@@0no_k0P3no_h20?Win@80n?Sh0P3moOd30?KfmP80l?3`103alO420?3`l080
nOWi0P3no_h20?_kn`80o?cl0P3jn_X20?ooo`@0n?Sh0P3oool20?Ogm`80n?Sh0P3jn_X20?KfmP80
m?Cd0P3fm_H20?clo080n_[j0P3hn?P20?ooo`80o_kn2P3oool20?gmo@D0moOg203oool20>_[j`80
fm_K0P3Ng]h20:2PX080jNWY0P35aLD20?Gem@@0n?Sh0P3fm_H20?Win@80oooo0P3emOD20?Shn080
lo?c0P3gmoL20?Shn0P0n_[j0P3oool20?knoP80n_[j0P3fm_H20?[jnP80m_Kf0`3moOd20?Ogm`80
oOgm0P3no_h20?gmo@80nOWi0P3alO420>_[j`80kNg]0P3_knl20=[JfP80jn_[0P3moOd20=GEe@80
k>c/0P3jn_X20?Win@l0oooo000=0?ooo`80o?cl0P3moOd20?_kn`80m_Kf103hn?P20?Gem@@0nOWi
0P3emOD20?ooo`80m_Kf0P3inOT20>GUi@80gMgM0`3UiND20?KfmP80oOgm0P3lo?`20?Shn0@0n_[j
0P3Zj^X20>CTi080X:2P0P3@d=020>WYj@80oOgm0P3hn?P20??cl`80n_[j0P3hn?P40?Gem@80moOg
103oool20?knoP80mOGe0P3lo?`20>k^kP80n?Sh0P3kno/20?ooo`80m_Kf0P3inOT20?KfmP<0no_k
0P3oool20?Win@80no_k0P3hn?P20?7al@80moOg0P3no_h20?[jnP80no_k2P3oool20?_kn`80l_;b
0P3inOT20?ooo`80o?cl0P3emOD40?Shn0@0m_Kf0P3dm?@20?Shn0@0oooo1P3no_h30?ooo`80o_kn
203oool20?Win@80gmoO0P3bl_820:>SX`80hN7Q0P3EeMD20??cl`80moOg0P3moOd20?Ogm`80l?3`
0P3emOD20?Ogm`80lo?c0P3gmoL20?Shn0@0n_[j103kno/20?ooo`80n?Sh0P3jn_X20?knoP80n?Sh
0P3oool30?KfmP80o?cl0P3kno/40?Ogm`80hn?S0P3Vi^H20?[jnP80lO7a0P3/k>`20>[ZjP80hn?S
0P3inOT20=GEe@80mOGe0P3alO420?KfmPl0oooo000=0?ooo`80o?cl0P3moOd20?_kn`80m_Kf103h
n?P20?Gem@@0nOWi0P3emOD20?ooo`80m_Kf0P3inOT20>GUi@80gMgM0`3UiND20?KfmP80oOgm0P3l
o?`20?Shn0@0n_[j0P3Zj^X20>CTi080X:2P0P3@d=020>WYj@80oOgm0P3hn?P20??cl`80n_[j0P3h
n?P40?Gem@80moOg103oool20?knoP80mOGe0P3lo?`20>k^kP80n?Sh0P3kno/20?ooo`80m_Kf0P3i
nOT20?KfmP<0no_k0P3oool20?Win@80no_k0P3hn?P20?7al@80moOg0P3no_h20?[jnP80no_k2P3o
ool20?_kn`80l_;b0P3inOT20?ooo`80o?cl0P3emOD40?Shn0@0m_Kf0P3dm?@20?Shn0@0oooo1P3n
o_h30?ooo`80o_kn203oool20?Win@80gmoO0P3bl_820:>SX`80hN7Q0P3EeMD20??cl`80moOg0P3m
oOd20?Ogm`80l?3`0P3emOD20?Ogm`80lo?c0P3gmoL20?Shn0@0n_[j103kno/20?ooo`80n?Sh0P3j
n_X20?knoP80n?Sh0P3oool30?KfmP80o?cl0P3kno/40?Ogm`80hn?S0P3Vi^H20?[jnP80lO7a0P3/
k>`20>[ZjP80hn?S0P3inOT20=GEe@80mOGe0P3alO420?KfmPl0oooo000?0?ooo`80o_kn0P3oool2
0?Shn0@0oOgm0P3inOT20?Ogm`80m?Cd0P3oool20?Win@80m_Kf103inOT20?KfmP<0kNg]0P3Ogml2
0?KfmP80nOWi0P3hn?P40?_kn`80n?Sh0P3Ng]h20?3`l080a<C40P3Rh^820?clo080nOWi0P3alO44
0?ooo`H0n?Sh0P3gmoL20?knoP80oooo0P3gmoL20?Gem@80moOg0P3oool20?Shn080mOGe0P3hn?P4
0?Ogm`D0l?3`0P3clo<20?;blP@0n?Sh0P3gmoL20?Shn080m?Cd103_knl20?Cdm080oooo103no_h2
0?_kn`80lO7a0P3fm_H20?Shn080m?Cd0P3alO420?[jnP80m_Kf0P3lo?`20?knoP80no_k0P3fm_H2
0?clo080n_[j0P3inOT20?_kn`80oooo0`3jn_X20?Win@80n?Sh1P3jn_X20?ooo`80nOWi0P3Ogml2
0?;blP80XZ:R0P3Hf=P20>g]k@80no_k103inOT20?ooo`80no_k0P3oool20?_kn`80nOWi103kno/4
0?Shn080no_k0P3moOd20?KfmP80o_kn0P3oool20?[jnP80oooo1@3hn?P20?Ogm`80l?3`0P3Shn<2
0>CTi080l?3`103[jn/20=;BdP80gmoO0P3MgMd20?Shn080cLg=0P3bl_820?3`l080no_k3`3oool0
00l0oooo0P3no_h20?ooo`80n?Sh103moOd20?Win@80moOg0P3dm?@20?ooo`80nOWi0P3fm_H40?Wi
n@80m_Kf0`3]kNd20=oOg`80m_Kf0P3inOT20?Shn0@0no_k0P3hn?P20=kNgP80l?3`0P34a<@20>;R
hP80o?cl0P3inOT20?7al@@0oooo1P3hn?P20?Ogm`80o_kn0P3oool20?Ogm`80mOGe0P3gmoL20?oo
o`80n?Sh0P3emOD20?Shn0@0moOg1@3`l?020??cl`80l_;b103hn?P20?Ogm`80n?Sh0P3dm?@40>o_
k`80m?Cd0P3oool40?knoP80no_k0P3alO420?KfmP80n?Sh0P3dm?@20?7al@80n_[j0P3fm_H20?cl
o080o_kn0P3kno/20?KfmP80o?cl0P3jn_X20?Win@80no_k0P3oool30?[jnP80nOWi0P3hn?P60?[j
nP80oooo0P3inOT20=oOg`80l_;b0P2RXZ820=SHf080kNg]0P3kno/40?Win@80oooo0P3kno/20?oo
o`80no_k0P3inOT40?_kn`@0n?Sh0P3kno/20?gmo@80m_Kf0P3no_h20?ooo`80n_[j0P3oool50?Sh
n080moOg0P3`l?020>?Sh`80i>CT0P3`l?040>_[j`80d];B0P3Ogml20=gMg@80n?Sh0P3=cLd20?;b
lP80l?3`0P3kno/?0?ooo`003`3oool20?clo0@0no_k0P3jn_X20?Win@80o_kn0P3jn_X20?knoP80
mOGe0P3inOT20?Gem@80oOgm0P3inOT20?Ogm`<0n?Sh0P3Vi^H20>;RhP80m_Kf0P3jn_X20?Win@80
n_[j0P3inOT20>[ZjP80jn_[0P3?cll20=oOg`80n_[j0P3kno/20?3`l080m_Kf0P3inOT20?Shn080
oooo0P3fm_H20?Ogm`80o_kn0P3hn?P20?Cdm0@0n?Sh0P3_knl20?KfmP80oooo0P3moOd20?Gem@T0
oooo0P3inOT20?3`l080m_Kf0P3jn_X20?7al@80nOWi0P3jn_X20?Cdm080o?cl0P3gmoL80?ooo`80
n?Sh0P3kno/20?Ogm`80m_Kf0P3alO420?Shn080no_k103lo?`20?gmo@80moOg0P3hn?P20?gmo@80
no_k0P3hn?P30?ooo`P0no_k0P3jn_X40?_kn`80nOWi0P3Ogml20>;RhP80b/[:0P3gmoL20>SXj080
no_k0P3no_h20?[jnPH0no_k0P3lo?`40?_kn`80oOgm0P3lo?`20?gmo@80oooo0P3hn?P20?[jnP@0
oooo0P3gmoL30?Shn080l_;b0P3_knl20>OWi`80j>SX0P3moOd20>;RhP80hN7Q0P3Ng]h20>OWi`80
iNGU0P3AdM420>_[j`80dM7A0P3emOD20?[jnP80no_k3`3oool000l0oooo0P3lo?`40?_kn`80n_[j
0P3inOT20?knoP80n_[j0P3no_h20?Gem@80nOWi0P3emOD20?gmo@80nOWi0P3gmoL30?Shn080i^KV
0P3Rh^820?KfmP80n_[j0P3inOT20?[jnP80nOWi0P3Zj^X20>_[j`80clo?0P3Ogml20?[jnP80no_k
0P3`l?020?KfmP80nOWi0P3hn?P20?ooo`80m_Kf0P3gmoL20?knoP80n?Sh0P3dm?@40?Shn080kno_
0P3fm_H20?ooo`80oOgm0P3emOD90?ooo`80nOWi0P3`l?020?KfmP80n_[j0P3alO420?Win@80n_[j
0P3dm?@20?clo080moOg203oool20?Shn080no_k0P3gmoL20?KfmP80lO7a0P3hn?P20?_kn`@0o?cl
0P3moOd20?Ogm`80n?Sh0P3moOd20?_kn`80n?Sh0`3oool80?_kn`80n_[j103kno/20?Win@80gmoO
0P3Rh^820<[:bP80moOg0P3Xj>P20?_kn`80o_kn0P3jn_X60?_kn`80o?cl103kno/20?gmo@80o?cl
0P3moOd20?ooo`80n?Sh0P3jn_X40?ooo`80moOg0`3hn?P20?;blP80kno_0P3WinL20>SXj080oOgm
0P3Rh^820>7Qh@80g]kN0P3WinL20>GUi@80dM7A0P3[jn/20=7Ad@80mOGe0P3jn_X20?_kn`l0oooo
000?0?ooo`80n?Sh103emOD20?Ogm`80n?Sh0P3jn_X20?Ogm`80nOWi0P3gmoL20?Win@80no_k0P3g
moL20?Shn080oOgm1@3kno/20>WYj@80f][J0P3Vi^H20?Shn0@0mOGe0P3fm_H20?3`l080lo?c0P3L
g=`20?Win@80no_k0P3gmoL20?Gem@80lo?c0P3fm_H20?knoP80m_Kf0P3dm?@20?;blP80moOg0P3i
nOT40>c/k080nOWi103gmoL20?Shn080kno_0P3oool30?[jnPH0n?Sh0P3fm_H20>c/k080k^k^0P3b
l_820?Gem@80n?Sh0P3dm?@40?;blP80lo?c0P3alO420?Cdm080o_kn0P3oool20?clo0@0moOg0P3h
n?P20?Win@80moOg103hn?P40?KfmP80n?Sh0P3moOd20?_kn`80n?Sh1@3kno/20?[jnP@0o_kn0P3o
ool40?[jnP80oooo0P3inOT20=cLg080jn_[0P34a<@20>GUi@H0n?Sh0P3jn_X20?Win@80o_kn0P3j
n_X20?ooo`@0oOgm0P3lo?`20?Ogm`80n?Sh103jn_X20?ooo`80l_;b0P3_knl30>?Sh`80h>3P0P3]
kNd20=OGe`80n_[j0P3^k^h20=3@d080l_;b0P3gmoL20?Win@80j^[Z0P3IfMT20=OGe`80i^KV0P3n
o_h20?[jnP80m_Kf3`3oool000l0oooo0P3hn?P40?Gem@80moOg0P3hn?P20?[jnP80moOg0P3inOT2
0?Ogm`80nOWi0P3kno/20?Ogm`80n?Sh0P3moOd50?_kn`80jNWY0P3Jf]X20>KViP80n?Sh103emOD2
0?KfmP80l?3`0P3clo<20=cLg080nOWi0P3kno/20?Ogm`80mOGe0P3clo<20?KfmP80o_kn0P3fm_H2
0?Cdm080l_;b0P3gmoL20?Win@@0k>c/0P3inOT40?Ogm`80n?Sh0P3_knl20?ooo`<0n_[j1P3hn?P2
0?KfmP80k>c/0P3^k^h20?;blP80mOGe0P3hn?P20?Cdm0@0l_;b0P3clo<20?7al@80m?Cd0P3no_h2
0?ooo`80o?cl103gmoL20?Shn080nOWi0P3gmoL40?Shn0@0m_Kf0P3hn?P20?gmo@80no_k0P3hn?P5
0?_kn`80n_[j103no_h20?ooo`@0n_[j0P3oool20?Win@80g=cL0P3[jn/20<C4a080iNGU1P3hn?P2
0?[jnP80nOWi0P3no_h20?[jnP80oooo103moOd20?clo080moOg0P3hn?P40?[jnP80oooo0P3bl_82
0>o_k`<0hn?S0P3Ph>020>g]k@80emOG0P3jn_X20>k^kP80d=3@0P3bl_820?Ogm`80nOWi0P3Zj^X2
0=WIf@80emOG0P3Vi^H20?knoP80n_[j0P3fm_H?0?ooo`003`3oool20?Shn080moOg103inOT40?Ge
m@80moOg0P3jn_X20?Shn0@0m_Kf0P3emOD20?ooo`80oOgm0`3kno/40?ooo`80moOg0P3YjNT20>[Z
jPH0mOGe0P3hn?P20?3`l080nOWi0P3Ogml20<c<c080alO70P3inOT20?_kn`80n?Sh0P3inOT60?oo
o`80l_;b0P3`l?020?ooo`80n?Sh103oool40?[jnP80l?3`0P3gmoL30?[jnP80no_k103oool20?_k
n`80m?Cd0P3no_h20>g]k@80no_k103fm_H40?Shn080no_k0P3inOT20?7al@80k>c/0P3_knl20??c
l`80l?3`0P3emOD20?Ogm`80lo?c103dm?@40?KfmP80moOg0P3inOT20>o_k`80lo?c0P3lo?`30?gm
o@80m_Kf203clo<40?Gem@@0moOg0P3Zj^X20=KFeP80mOGe0P3Kfm/20?knoP80oOgm103oool20?_k
n`80n_[j0P3gmoL20?gmo@80o?cl0P3moOd20?[jnP80n?Sh0P3emOD20?[jnP80moOg0P3`l?020>_[
j`80fm_K0`3Rh^820?[jnP80h>3P0P3MgMd20>?Sh`80c<c<0P3Cdm<20??cl`@0l?3`0P3gmoL20>o_
k`80c/k>0P3bl_820?_kn`80moOg0P3hn?P?0?ooo`003`3oool20?Shn080moOg103inOT40?Gem@80
moOg0P3jn_X20?Shn0@0m_Kf0P3emOD20?ooo`80oOgm0`3kno/40?ooo`80moOg0P3YjNT20>[ZjPH0
mOGe0P3hn?P20?3`l080nOWi0P3Ogml20<c<c080alO70P3inOT20?_kn`80n?Sh0P3inOT60?ooo`80
l_;b0P3`l?020?ooo`80n?Sh103oool40?[jnP80l?3`0P3gmoL30?[jnP80no_k103oool20?_kn`80
m?Cd0P3no_h20>g]k@80no_k103fm_H40?Shn080no_k0P3inOT20?7al@80k>c/0P3_knl20??cl`80
l?3`0P3emOD20?Ogm`80lo?c103dm?@40?KfmP80moOg0P3inOT20>o_k`80lo?c0P3lo?`30?gmo@80
m_Kf203clo<40?Gem@@0moOg0P3Zj^X20=KFeP80mOGe0P3Kfm/20?knoP80oOgm103oool20?_kn`80
n_[j0P3gmoL20?gmo@80o?cl0P3moOd20?[jnP80n?Sh0P3emOD20?[jnP80moOg0P3`l?020>_[j`80
fm_K0`3Rh^820?[jnP80h>3P0P3MgMd20>?Sh`80c<c<0P3Cdm<20??cl`@0l?3`0P3gmoL20>o_k`80
c/k>0P3bl_820?_kn`80moOg0P3hn?P?0?ooo`003`3oool20?Shn080no_k0P3jn_X20?Win@80no_k
0P3gmoL20?Shn080no_k0P3lo?`40?Ogm`80oOgm0P3hn?P20?_kn`<0oooo0P3kno/20?ooo`80moOg
0P3kno/20>g]k@80j^[Z0P3WinL20>_[j`80i^KV0P3QhN420>g]k@80jNWY0P2XZ:P20=;BdP80kno_
0P3moOd20?Ogm`80nOWi103oool20?[jnP80moOg103bl_820?Shn080m_Kf0P3_knl20>_[j`80kno_
0P3no_h20?7al@D0n?Sh103oool20?clo080no_k0P3fm_H20>o_k`80l_;b0P3hn?P20>o_k`80l_;b
103hn?P40?KfmP80n_[j0P3inOT20>o_k`80jn_[0P3UiND20>3Ph080inOW0P3Zj^X20>WYj@80i>CT
103Ph>020>7Qh@80i^KV0P3WinL20>;RhP<0hN7Q0P3Vi^H40>c/k080lO7a103jn_X20?knoP80moOg
0P3bl_820?Ogm`80iNGU0P3=cLd20>7Qh@80m_Kf0P3WinL40<S8b080inOW0P3clo<20?7al@@0m_Kf
0P3jn_X20?Ogm`80mOGe0P3no_h20?[jnP80n?Sh103:b/X20?7al@<0k^k^0P3hn?P20>[ZjP80gMgM
0P3bl_820>[ZjP80lo?c0P3fm_H20>k^kP80l?3`0P3[jn/20?;blP80fm_K0P3clo<40?knoP80oOgm
3`3oool000l0oooo0P3hn?P20?_kn`80n_[j0P3inOT20?_kn`80moOg0P3hn?P20?_kn`80o?cl103g
moL20?gmo@80n?Sh0P3kno/30?ooo`80no_k0P3oool20?Ogm`80no_k0P3]kNd20>[ZjP80inOW0P3[
jn/20>KViP80hN7Q0P3]kNd20>WYj@80Z:RX0P3Bd]820>o_k`80oOgm0P3gmoL20?Win@@0oooo0P3j
n_X20?Ogm`@0l_;b0P3hn?P20?KfmP80kno_0P3[jn/20>o_k`80o_kn0P3alO450?Shn0@0oooo0P3l
o?`20?_kn`80m_Kf0P3_knl20?;blP80n?Sh0P3_knl20?;blP@0n?Sh103fm_H20?[jnP80nOWi0P3_
knl20>_[j`80iNGU0P3Ph>020>OWi`80j^[Z0P3YjNT20>CTi0@0h>3P0P3QhN420>KViP80inOW0P3R
h^830>7Qh@80i^KV103/k>`20?7al@@0n_[j0P3no_h20?Ogm`80l_;b0P3gmoL20>GUi@80cLg=0P3Q
hN420?KfmP80inOW1038b<P20>OWi`80lo?c0P3alO440?KfmP80n_[j0P3gmoL20?Gem@80o_kn0P3j
n_X20?Shn0@0b/[:0P3alO430>k^kP80n?Sh0P3Zj^X20=gMg@80l_;b0P3Zj^X20??cl`80m_Kf0P3^
k^h20?3`l080jn_[0P3bl_820=_Kf`80lo?c103no_h20?gmo@l0oooo000=0?ooo`80mOGe103moOd2
0?ooo`80nOWi0P3oool20?Shn080nOWi0P3no_h20?_kn`80m_Kf0P3hn?P20?gmo@80o_kn0P3emOD7
0?Ogm`@0mOGe103gmoL20?Win@80oOgm0P3gmoL40?_kn`80o_kn0P3kno/20<_;b`80gMgM103Kfm/2
0>c/k0@0l_;b0P3jn_X20?_kn`80lo?c0P3gmoL20?3`l080kno_0P3alO420?Gem@80nOWi0P3dm?@2
0?KfmP<0mOGe0P3jn_X20?Win@@0o?cl0P3oool20?Shn080no_k0P3alO420?[jnP80nOWi0P3hn?P2
0?Gem@@0nOWi0P3emOD40>o_k`80j^[Z0P3Ti>@20>WYj@80i^KV0P3/k>`20?3`l080kno_0P3clo<2
0>k^kP80j^[Z0P3_knl20??cl`80k^k^1`3[jn/20>c/k080i^KV0P3Xj>P40?7al@@0lo?c0P3bl_82
0?7al@80mOGe0P3alO420>_[j`80lo?c0P3UiND20<71`@80cLg=0P2^[Zh209nOW`80k>c/0P3Xj>P4
0?Ogm`80m?Cd0P3Ng]h20;>c/`80V9RH0P2MWId20<S8b0@0hn?S0`3]kNd20?3`l080lo?c0P3_knl2
0?Gem@80nOWi0P3`l?020?7al@80d];B0P3emOD20=kNgP80dm?C0P3gmoL20>k^kP80oOgm0P3inOT2
0?KfmPl0oooo000=0?ooo`80mOGe103moOd20?ooo`80nOWi0P3oool20?Shn080nOWi0P3no_h20?_k
n`80m_Kf0P3hn?P20?gmo@80o_kn0P3emOD70?Ogm`@0mOGe103gmoL20?Win@80oOgm0P3gmoL40?_k
n`80o_kn0P3kno/20<_;b`80gMgM103Kfm/20>c/k0@0l_;b0P3jn_X20?_kn`80lo?c0P3gmoL20?3`
l080kno_0P3alO420?Gem@80nOWi0P3dm?@20?KfmP<0mOGe0P3jn_X20?Win@@0o?cl0P3oool20?Sh
n080no_k0P3alO420?[jnP80nOWi0P3hn?P20?Gem@@0nOWi0P3emOD40>o_k`80j^[Z0P3Ti>@20>WY
j@80i^KV0P3/k>`20?3`l080kno_0P3clo<20>k^kP80j^[Z0P3_knl20??cl`80k^k^1`3[jn/20>c/
k080i^KV0P3Xj>P40?7al@@0lo?c0P3bl_820?7al@80mOGe0P3alO420>_[j`80lo?c0P3UiND20<71
`@80cLg=0P2^[Zh209nOW`80k>c/0P3Xj>P40?Ogm`80m?Cd0P3Ng]h20;>c/`80V9RH0P2MWId20<S8
b0@0hn?S0`3]kNd20?3`l080lo?c0P3_knl20?Gem@80nOWi0P3`l?020?7al@80d];B0P3emOD20=kN
gP80dm?C0P3gmoL20>k^kP80oOgm0P3inOT20?KfmPl0oooo000=0?ooo`80lo?c103gmoL20?KfmP80
n?Sh0P3emOD20?Cdm080n_[j0P3oool40?Win@80oOgm0P3hn?P20?KfmP80o_kn0`3jn_X20?_kn`80
mOGe103gmoL40?Win@80moOg0P3oool20?[jnP80n?Sh0P3jn_X20?Win@80n?Sh0P3jn_X20<?3``80
emOG0P3=cLd20=SHf080lO7a0P3^k^h20?knoP80oooo0P3gmoL40?;blP80moOg0P3hn?P20?clo080
oooo0P3dm?@20?Shn0<0lo?c0P3oool20?Shn080m_Kf0P3hn?P20?clo080no_k0P3inOT20?Cdm080
nOWi0P3oool80?Win@@0oooo0P3inOT20?ooo`80mOGe0P3hn?P20?Gem@@0l?3`0P3bl_820?Shn080
moOg0P3hn?P20?Cdm080kNg]0P3fm_H50?gmo@80o_kn103hn?P20?ooo`@0l_;b103inOT40?KfmP80
n?Sh0P3dm?@20?Gem@80oOgm0P3clo<40?Shn080Ti>C0P2:RXX20=cLg080g]kN0P31`L420<S8b080
`L710P2g]kL20>?Sh`80l?3`0P3hn?P20>;RhP80j^[Z0P3QhN430??cl`80kNg]0P3=cLd20=gMg@80
oOgm0P3`l?020=gMg@80m?Cd0P3Fe]H20>SXj080l?3`103Zj^X60?KfmP80o_kn3`3oool000d0oooo
0P3clo<40?Ogm`80m_Kf0P3hn?P20?Gem@80m?Cd0P3jn_X20?ooo`@0nOWi0P3moOd20?Shn080m_Kf
0P3no_h30?[jnP80no_k0P3emOD40?Ogm`@0nOWi0P3gmoL20?ooo`80n_[j0P3hn?P20?[jnP80nOWi
0P3hn?P20?[jnP80`l?30P3GemL20<g=c@80f=SH0P3alO420>k^kP80o_kn0P3oool20?Ogm`@0l_;b
0P3gmoL20?Shn080o?cl0P3oool20?Cdm080n?Sh0`3clo<20?ooo`80n?Sh0P3fm_H20?Shn080o?cl
0P3kno/20?Win@80m?Cd0P3inOT20?ooo`P0nOWi103oool20?Win@80oooo0P3emOD20?Shn080mOGe
103`l?020?;blP80n?Sh0P3gmoL20?Shn080m?Cd0P3]kNd20?KfmPD0oOgm0P3no_h40?Shn080oooo
103bl_840?Win@@0m_Kf0P3hn?P20?Cdm080mOGe0P3moOd20??cl`@0n?Sh0P2CTi<208Z:RP80g=cL
0P3Ng]h20<71`@80b<S80P31`L420;Ng]`80hn?S0P3`l?020?Shn080h^;R0P3Zj^X20>7Qh@<0lo?c
0P3]kNd20<g=c@80gMgM0P3moOd20?3`l080gMgM0P3dm?@20=KFeP80j>SX0P3`l?040>[ZjPH0m_Kf
0P3no_h?0?ooo`003@3oool20??cl`@0n?Sh0P3oool20?_kn`80n_[j0P3dm?@20?[jnP80no_k0P3i
nOT20?gmo@@0nOWi0P3hn?P20?gmo@<0n_[j0P3moOd20?_kn`80oooo103moOd20?_kn`80n?Sh0P3g
moL20?[jnP80oOgm0P3hn?P20?KfmP@0no_k0P3:b/X20=[JfP80jNWY0P3[jn/20?[jnP80hN7Q0P3J
f]X20?ooo`80no_k0P3jn_X20?3`l080mOGe0P3jn_X20?Win@80n?Sh0P3gmoL20?_kn`<0l_;b103o
ool20?knoP@0no_k103jn_X20?Shn0P0nOWi2P3oool20?Win@80lo?c0P3oool20??cl`80moOg0P3i
nOT20?Shn080m?Cd0P3inOT20?gmo@80nOWi0P3bl_820?Shn080nOWi0`3gmoL20?KfmP80l_;b1P3o
ool40?Win@80moOg103fm_H20?Ogm`80m_Kf0P3oool40?Shn080moOg0P3alO420>o_k`80jn_[0P3Q
hN420<30`080_Kfm0P3Bd]820;no_`80k>c/103hn?P20>c/k080l?3`0P3dm?@20=[JfP<0hN7Q0P3k
no/20<?3``80^k^k0P3Ph>020>[ZjP80f][J0P3AdM420>c/k080gMgM0P3?cll20=kNgP80gmoO0P3k
no/20?Win@80oOgm0P3dm?@?0?ooo`003@3oool20??cl`@0n?Sh0P3oool20?_kn`80n_[j0P3dm?@2
0?[jnP80no_k0P3inOT20?gmo@@0nOWi0P3hn?P20?gmo@<0n_[j0P3moOd20?_kn`80oooo103moOd2
0?_kn`80n?Sh0P3gmoL20?[jnP80oOgm0P3hn?P20?KfmP@0no_k0P3:b/X20=[JfP80jNWY0P3[jn/2
0?[jnP80hN7Q0P3Jf]X20?ooo`80no_k0P3jn_X20?3`l080mOGe0P3jn_X20?Win@80n?Sh0P3gmoL2
0?_kn`<0l_;b103oool20?knoP@0no_k103jn_X20?Shn0P0nOWi2P3oool20?Win@80lo?c0P3oool2
0??cl`80moOg0P3inOT20?Shn080m?Cd0P3inOT20?gmo@80nOWi0P3bl_820?Shn080nOWi0`3gmoL2
0?KfmP80l_;b1P3oool40?Win@80moOg103fm_H20?Ogm`80m_Kf0P3oool40?Shn080moOg0P3alO42
0>o_k`80jn_[0P3QhN420<30`080_Kfm0P3Bd]820;no_`80k>c/103hn?P20>c/k080l?3`0P3dm?@2
0=[JfP<0hN7Q0P3kno/20<?3``80^k^k0P3Ph>020>[ZjP80f][J0P3AdM420>c/k080gMgM0P3?cll2
0=kNgP80gmoO0P3kno/20?Win@80oOgm0P3dm?@?0?ooo`003@3oool20?Gem@80oooo0P3fm_H20?oo
o`80n?Sh0P3emOD20?Win@80oOgm0P3emOD20?KfmP80oooo0P3moOd20?_kn`80moOg0P3kno/30?oo
o`80moOg0P3inOT20?_kn`80m_Kf0P3inOT20?_kn`80oooo0P3kno/20?Shn080oooo0P3moOd20?_k
n`@0oOgm0P3EeMD20?Shn080c<c<0P3oool20>_[j`80d];B0P2i^KT20;6a/@80n?Sh0P3oool20?Og
m`80lo?c0P3lo?`20?ooo`80o?cl0P3gmoL20?_kn`<0lo?c1P3oool20?knoP@0n?Sh103jn_X20?oo
o`80nOWi0P3gmoL20?Win@h0oooo0P3clo<20?_kn`80oooo0P3gmoL20?Win@80moOg0P3moOd20?Wi
n@80no_k0P3no_h20?_kn`80nOWi0`3emOD20?Ogm`80l_;b1P3oool20??cl`80n?Sh0P3inOT20?Kf
mP@0nOWi0P3emOD20?ooo`80n?Sh0P3emOD20?Shn080oooo0P3alO420=cLg080b<S80P2[Zj/209RH
V080b<S80P3QhN420>k^kP80moOg0P3Zj^X20?Shn080n_[j0P3no_h20>WYj@<0j>SX0P3hn?P20=GE
e@80aLG50P3`l?020>KViP80h^;R0P3Bd]820?ooo`80m_Kf0P3Cdm<20?ooo`80m_Kf0P3hn?P20?Cd
m080mOGe0P3moOd?0?ooo`003@3oool20?Gem@80oooo0P3fm_H20?ooo`80n?Sh0P3emOD20?Win@80
oOgm0P3emOD20?KfmP80oooo0P3moOd20?_kn`80moOg0P3kno/30?ooo`80moOg0P3inOT20?_kn`80
m_Kf0P3inOT20?_kn`80oooo0P3kno/20?Shn080oooo0P3moOd20?_kn`@0oOgm0P3EeMD20?Shn080
c<c<0P3oool20>_[j`80d];B0P2i^KT20;6a/@80n?Sh0P3oool20?Ogm`80lo?c0P3lo?`20?ooo`80
o?cl0P3gmoL20?_kn`<0lo?c1P3oool20?knoP@0n?Sh103jn_X20?ooo`80nOWi0P3gmoL20?Win@h0
oooo0P3clo<20?_kn`80oooo0P3gmoL20?Win@80moOg0P3moOd20?Win@80no_k0P3no_h20?_kn`80
nOWi0`3emOD20?Ogm`80l_;b1P3oool20??cl`80n?Sh0P3inOT20?KfmP@0nOWi0P3emOD20?ooo`80
n?Sh0P3emOD20?Shn080oooo0P3alO420=cLg080b<S80P2[Zj/209RHV080b<S80P3QhN420>k^kP80
moOg0P3Zj^X20?Shn080n_[j0P3no_h20>WYj@<0j>SX0P3hn?P20=GEe@80aLG50P3`l?020>KViP80
h^;R0P3Bd]820?ooo`80m_Kf0P3Cdm<20?ooo`80m_Kf0P3hn?P20?Cdm080mOGe0P3moOd?0?ooo`00
3@3oool20?Gem@80oOgm0P3gmoL20?_kn`80oOgm1P3fm_H40?Ogm`@0mOGe0P3inOT20?knoP80nOWi
0`3fm_H40?ooo`80n?Sh0P3kno/20?Win@80no_k0P3hn?P20?gmo@80n?Sh0P3no_h40?_kn`80n?Sh
0P3oool20>7Qh@80i>CT0P3<c<`20<30`080iNGU0P3AdM420>SXj080_Kfm0P2KVi/20??cl`@0moOg
0P3alO420??cl`80o_kn0P3inOT20?[jnP<0lo?c203oool40?[jnPP0oooo0P3inOT60?Ogm`@0n?Sh
0P3inOT40?ooo`80moOg103oool40?Win@80oOgm0P3fm_H20?Ogm`80o?cl0P3kno/40?ooo`<0o?cl
0P3moOd20?Win@80n?Sh0P3fm_H20?Gem@80n?Sh0P3clo<20?ooo`80moOg103moOd20?Win@80moOg
0P3alO420?Win@80lO7a0P3/k>`20>?Sh`80i^KV103AdM420?ooo`80h^;R0P3[jn/20>KViP80j^[Z
0P3clo<20?3`l080n_[j0P3_knl20>OWi`<0oooo0P3alO420?Shn080fm_K0P3`l?020?;blP80moOg
0P3Vi^H20??cl`80l_;b0P3MgMd20?Shn080no_k0P3gmoL20?Cdm080nOWi0P3gmoL?0?ooo`003@3o
ool20?Gem@80oOgm0P3gmoL20?_kn`80oOgm1P3fm_H40?Ogm`@0mOGe0P3inOT20?knoP80nOWi0`3f
m_H40?ooo`80n?Sh0P3kno/20?Win@80no_k0P3hn?P20?gmo@80n?Sh0P3no_h40?_kn`80n?Sh0P3o
ool20>7Qh@80i>CT0P3<c<`20<30`080iNGU0P3AdM420>SXj080_Kfm0P2KVi/20??cl`@0moOg0P3a
lO420??cl`80o_kn0P3inOT20?[jnP<0lo?c203oool40?[jnPP0oooo0P3inOT60?Ogm`@0n?Sh0P3i
nOT40?ooo`80moOg103oool40?Win@80oOgm0P3fm_H20?Ogm`80o?cl0P3kno/40?ooo`<0o?cl0P3m
oOd20?Win@80n?Sh0P3fm_H20?Gem@80n?Sh0P3clo<20?ooo`80moOg103moOd20?Win@80moOg0P3a
lO420?Win@80lO7a0P3/k>`20>?Sh`80i^KV103AdM420?ooo`80h^;R0P3[jn/20>KViP80j^[Z0P3c
lo<20?3`l080n_[j0P3_knl20>OWi`<0oooo0P3alO420?Shn080fm_K0P3`l?020?;blP80moOg0P3V
i^H20??cl`80l_;b0P3MgMd20?Shn080no_k0P3gmoL20?Cdm080nOWi0P3gmoL?0?ooo`003@3oool2
0?Gem@H0n_[j0P3kno/20?Gem@@0n?Sh103emOD20?Ogm`80no_k1P3oool30?Shn080nOWi0P3fm_H2
0?_kn`80oooo103gmoL20?knoP80oOgm103inOT20?Ogm`80n_[j0P3fm_H20?knoP80iNGU0P3[jn/2
0=cLg080[jn_0P3`l?020>_[j`80iNGU0P3Ng]h209fMW@80SXj>0P3/k>`40?;blP80moOg0P3inOT4
0?[jnP<0m_Kf0P3hn?P60?ooo`@0nOWi203oool20?Win@80moOg103inOT20?ooo`H0nOWi0P3oool2
0?Win@@0moOg0P3hn?P20?[jnP80oOgm103lo?`20?gmo@80no_k0P3moOd20?Win@<0no_k0P3lo?`2
0?[jnP80lo?c0P3emOD20?Ogm`@0nOWi0P3gmoL20?Win@80moOg103moOd20?Ogm`80n?Sh0P3fm_H2
0?7al@80kno_0P3`l?020>7Qh@80f=SH0P3^k^h20>7Qh@80oooo0P3alO420?3`l080jNWY0P3`l?02
0>c/k080k^k^0P3oool20>OWi`<0l?3`0P3Rh^820>_[j`80l?3`0P3Ph>020>c/k080eMGE0P3Rh^82
0>[ZjP80gMgM0P3Zj^X20?ooo`80o?cl0P3jn_X20?clo080nOWi0P3gmoL?0?ooo`003@3oool20?Ge
m@H0n_[j0P3kno/20?Gem@@0n?Sh103emOD20?Ogm`80no_k1P3oool30?Shn080nOWi0P3fm_H20?_k
n`80oooo103gmoL20?knoP80oOgm103inOT20?Ogm`80n_[j0P3fm_H20?knoP80iNGU0P3[jn/20=cL
g080[jn_0P3`l?020>_[j`80iNGU0P3Ng]h209fMW@80SXj>0P3/k>`40?;blP80moOg0P3inOT40?[j
nP<0m_Kf0P3hn?P60?ooo`@0nOWi203oool20?Win@80moOg103inOT20?ooo`H0nOWi0P3oool20?Wi
n@@0moOg0P3hn?P20?[jnP80oOgm103lo?`20?gmo@80no_k0P3moOd20?Win@<0no_k0P3lo?`20?[j
nP80lo?c0P3emOD20?Ogm`@0nOWi0P3gmoL20?Win@80moOg103moOd20?Ogm`80n?Sh0P3fm_H20?7a
l@80kno_0P3`l?020>7Qh@80f=SH0P3^k^h20>7Qh@80oooo0P3alO420?3`l080jNWY0P3`l?020>c/
k080k^k^0P3oool20>OWi`<0l?3`0P3Rh^820>_[j`80l?3`0P3Ph>020>c/k080eMGE0P3Rh^820>[Z
jP80gMgM0P3Zj^X20?ooo`80o?cl0P3jn_X20?clo080nOWi0P3gmoL?0?ooo`003`3oool20?knoP80
n?Sh0P3inOT20?clo080m?Cd0P3gmoL20?Gem@80moOg0P3emOD20?_kn`80moOg1P3oool30?KfmP80
oooo1P3hn?P20?_kn`@0o_kn0P3inOT20?_kn`80oooo0P3no_h40?_kn`80oooo0P3WinL20>_[j`80
e=CD0P3;bl/20<O7a`80n?Sh0P3Ogml20=kNgP80gMgM0P2FUYH2096AT@80oooo0P3alO440?;blP80
n_[j0P3oool30?Cdm080n?Sh1P3oool20?Win@80oooo0P3gmoL20?Win@80oooo0P3inOT40?Ogm`80
nOWi0P3gmoL20?Gem@80oOgm103inOT20?ooo`80nOWi103gmoL20?Win@80oOgm0P3inOT20?Ogm`80
n?Sh103kno/20?Win@80oooo0`3gmoL20?Cdm080oOgm0P3emOD60?Win@80oOgm0P3inOT20?Cdm080
j>SX0P3WinL20>CTi080gmoO0P3Ng]h20>CTi080jn_[0P3Lg=`20<;2`P80/k>c0P3Xj>P20<o?c`80
k>c/0P3Jf]X20=gMg@80kno_0P3clo<20=OGe`80fm_K0P3oool20>WYj@80iNGU0`3alO420>g]k@80
n?Sh0P3Ti>@20?ooo`80g=cL0P3hn?P20>OWi`80g=cL0P3Ogml20?Shn080mOGe0P3moOd20?[jnP80
oOgm0P3dm?@20?Win@l0oooo000?0?ooo`80o_kn0P3hn?P20?Win@80o?cl0P3dm?@20?Ogm`80mOGe
0P3gmoL20?Gem@80no_k0P3gmoL60?ooo`<0m_Kf0P3oool60?Shn080no_k103no_h20?Win@80no_k
0P3oool20?knoP@0no_k0P3oool20>OWi`80jn_[0P3De=@20<_;b`80alO70P3hn?P20=oOg`80g]kN
0P3MgMd209JFUP80TI6A0P3oool20?7al@@0l_;b0P3jn_X20?ooo`<0m?Cd0P3hn?P60?ooo`80nOWi
0P3oool20?Ogm`80nOWi0P3oool20?Win@@0moOg0P3inOT20?Ogm`80mOGe0P3moOd40?Win@80oooo
0P3inOT40?Ogm`80nOWi0P3moOd20?Win@80moOg0P3hn?P40?_kn`80nOWi0P3oool30?Ogm`80m?Cd
0P3moOd20?Gem@H0nOWi0P3moOd20?Win@80m?Cd0P3Xj>P20>OWi`80i>CT0P3Ogml20=kNgP80i>CT
0P3[jn/20=cLg080`/;20P2c/k<20>SXj080clo?0P3/k>`20=[JfP80gMgM0P3_knl20??cl`80emOG
0P3Kfm/20?ooo`80jNWY0P3UiND30?7al@80kNg]0P3hn?P20>CTi080oooo0P3Lg=`20?Shn080inOW
0P3Lg=`20=oOg`80n?Sh0P3emOD20?gmo@80n_[j0P3moOd20?Cdm080nOWi3`3oool000l0oooo0P3n
o_h20?Shn080nOWi0P3lo?`20?Cdm080moOg0P3emOD20?Ogm`80mOGe0P3kno/20?Ogm`H0oooo0`3f
m_H20?ooo`H0n?Sh0P3kno/40?knoP80nOWi0P3kno/20?ooo`80o_kn103kno/20?ooo`80inOW0P3[
jn/20=CDe080bl_;0P37alL20?Shn080gmoO0P3Ng]h20=gMg@80UYJF0P2ATI420?ooo`80lO7a103b
l_820?[jnP80oooo0`3dm?@20?Shn0H0oooo0P3inOT20?ooo`80moOg0P3inOT20?ooo`80nOWi103g
moL20?Win@80moOg0P3emOD20?gmo@@0nOWi0P3oool20?Win@@0moOg0P3inOT20?gmo@80nOWi0P3g
moL20?Shn0@0no_k0P3inOT20?ooo`<0moOg0P3dm?@20?gmo@80mOGe1P3inOT20?gmo@80nOWi0P3d
m?@20>SXj080inOW0P3Ti>@20=oOg`80g]kN0P3Ti>@20>_[j`80g=cL0P32`/820;>c/`80j>SX0P3?
cll20>c/k080f][J0P3MgMd20>o_k`80lo?c0P3GemL20=_Kf`80oooo0P3YjNT20>GUi@<0lO7a0P3]
kNd20?Shn080i>CT0P3oool20=cLg080n?Sh0P3WinL20=cLg080gmoO0P3hn?P20?Gem@80oOgm0P3j
n_X20?gmo@80m?Cd0P3inOT?0?ooo`003@3oool20?clo080nOWi0P3hn?P20?knoP80nOWi0P3oool2
0?Shn080no_k0P3hn?P20?_kn`80nOWi0P3kno/60?Ogm`D0nOWi103gmoL20?Win@80oOgm0P3inOT2
0?ooo`80nOWi0P3kno/20?Ogm`80m_Kf0P3inOT20?ooo`80no_k0P3clo<20?Ogm`80k>c/0P3IfMT2
0<30`080oooo0P3Lg=`20=oOg`80i>CT0P3dm?@2092@T080QXJ60P3dm?@20?7al@80j^[Z0P3jn_X2
0?ooo`<0lo?c103inOT60?Ogm`80oooo1P3inOT20?Ogm`80oooo103inOT20?[jnP80oOgm0P3jn_X2
0?KfmP80moOg0P3emOD20?gmo@80nOWi0P3jn_X20?Ogm`@0o?cl0P3kno/20?Shn080m?Cd103gmoL2
0?Win@<0lo?c0P3dm?@20?3`l080l_;b0P3jn_X40?;blP@0k^k^0P3hn?P20?;blP80nOWi0P3jn_X2
0??cl`80n?Sh0P3Xj>P20=?Cd`80][Jf0P3Hf=P20?;blP80b<S80P3Rh^820?Ogm`80fMWI0P3AdM42
0>o_k`80k>c/0P3dm?@20?Gem@80lO7a0P3YjNT20?Ogm`<0k>c/0P3emOD20?ooo`80j>SX0P3no_h2
0=kNgP80i>CT0P3/k>`20>CTi080l_;b103fm_H20?Cdm0@0oOgm0P3emOD20?_kn`l0oooo000=0?oo
o`80o?cl0P3inOT20?Shn080o_kn0P3inOT20?ooo`80n?Sh0P3kno/20?Shn080no_k0P3inOT20?_k
n`H0moOg1@3inOT40?Ogm`80nOWi0P3moOd20?Win@80oooo0P3inOT20?_kn`80moOg0P3fm_H20?Wi
n@80oooo0P3kno/20??cl`80moOg0P3/k>`20=WIf@80`<300P3oool20=cLg080gmoO0P3Ti>@20?Cd
m080T92@0P26QXH20?Cdm080lO7a0P3Zj^X20?[jnP80oooo0`3clo<40?Win@H0moOg0P3oool60?Wi
n@80moOg0P3oool40?Win@80n_[j0P3moOd20?[jnP80m_Kf0P3gmoL20?Gem@80oOgm0P3inOT20?[j
nP80moOg103lo?`20?_kn`80n?Sh0P3dm?@40?Ogm`80nOWi0`3clo<20?Cdm080l?3`0P3bl_820?[j
nP@0l_;b103^k^h20?Shn080l_;b0P3inOT20?[jnP80lo?c0P3hn?P20>SXj080dm?C0P2f][H20=SH
f080l_;b0P38b<P20>;RhP80moOg0P3IfMT20=7Ad@80kno_0P3/k>`20?Cdm080mOGe0P3alO420>WY
j@80moOg0`3/k>`20?Gem@80oooo0P3Xj>P20?knoP80g]kN0P3Ti>@20>c/k080i>CT0P3bl_840?Kf
mP80m?Cd103moOd20?Gem@80no_k3`3oool000d0oooo0P3lo?`20?Win@80no_k0P3gmoL20?Shn080
m?Cd0P3hn?P20?Ogm`80no_k0P3gmoL20?gmo@@0moOg0P3inOT70?Ogm`80n?Sh0P3gmoL20?_kn`80
moOg0P3inOT20?[jnP80oooo0P3hn?P20?knoP80o?cl103oool40?KfmP80hN7Q0P3clo<20:f][@80
gMgM0P3emOD20=[JfP80jNWY0P3clo<20>OWi`80jNWY0P24Q8@206ATI080moOg0P3clo<20?Ogm`80
no_k1@3gmoL20?Win@H0oooo103gmoL20?Win@80oooo0P3inOT20?ooo`80nOWi0P3gmoL20?gmo@80
n_[j0P3lo?`40?Win@80n_[j0P3clo<60?Win@@0o?cl0P3moOd20?Win@80mOGe0P3alO440?Win@<0
n_[j103hn?P20?;blP80no_k103alO420?Shn080no_k0P3`l?020?KfmP80mOGe0P3hn?P20>WYj@80
fMWI0P3EeMD20=oOg`80iNGU0P3WinL20=OGe`80d];B0P3hn?P20?KfmP80oooo0P3]kNd20?Ogm`80
i>CT0P3Kfm/20>SXj080jNWY0P3oool20>?Sh`<0k^k^0P3oool20>_[j`80l?3`0P3no_h20?Win@80
gMgM0P3Ph>020?Shn080moOg0P3bl_820>g]k@80l_;b0P3inOT20?Ogm`80n?Sh4@3oool000d0oooo
0P3lo?`20?Win@80no_k0P3gmoL20?Shn080m?Cd0P3hn?P20?Ogm`80no_k0P3gmoL20?gmo@@0moOg
0P3inOT70?Ogm`80n?Sh0P3gmoL20?_kn`80moOg0P3inOT20?[jnP80oooo0P3hn?P20?knoP80o?cl
103oool40?KfmP80hN7Q0P3clo<20:f][@80gMgM0P3emOD20=[JfP80jNWY0P3clo<20>OWi`80jNWY
0P24Q8@206ATI080moOg0P3clo<20?Ogm`80no_k1@3gmoL20?Win@H0oooo103gmoL20?Win@80oooo
0P3inOT20?ooo`80nOWi0P3gmoL20?gmo@80n_[j0P3lo?`40?Win@80n_[j0P3clo<60?Win@@0o?cl
0P3moOd20?Win@80mOGe0P3alO440?Win@<0n_[j103hn?P20?;blP80no_k103alO420?Shn080no_k
0P3`l?020?KfmP80mOGe0P3hn?P20>WYj@80fMWI0P3EeMD20=oOg`80iNGU0P3WinL20=OGe`80d];B
0P3hn?P20?KfmP80oooo0P3]kNd20?Ogm`80i>CT0P3Kfm/20>SXj080jNWY0P3oool20>?Sh`<0k^k^
0P3oool20>_[j`80l?3`0P3no_h20?Win@80gMgM0P3Ph>020?Shn080moOg0P3bl_820>g]k@80l_;b
0P3inOT20?Ogm`80n?Sh4@3oool000d0oooo0P3lo?`20?Win@@0no_k0P3oool20?Ogm`80oOgm0P3g
moL20?_kn`80nOWi0P3hn?P20?_kn`80moOg0P3kno/20?Win@<0mOGe0P3gmoL20?Gem@80oOgm103g
moL20?_kn`80oooo0P3inOT20?Ogm`80o?cl0P3moOd20?ooo`80o_kn0P3hn?P20?KfmP80iNGU0P3a
lO420:2PX080lO7a0P3emOD20=[JfP80jNWY0P3oool20>k^kP80g=cL0P3[jn/208N7Q`80Jf][0P3o
ool20?7al@80n_[j0`3hn?P20?ooo`80o?cl1P3oool20?Win@80oooo0P3inOT20?Ogm`H0oooo103m
oOd20?ooo`80nOWi0P3lo?`20?[jnPH0nOWi1P3jn_X40?gmo@80m_Kf103lo?`20?Shn080m?Cd0`3f
m_H20>k^kP80moOg0P3emOD20?KfmP80kNg]0P3inOT20?Ogm`80m_Kf1P3alO420=[JfP80`/;20P3H
f=P20<o?c`80g]kN0P3]kNd20>;RhP80fMWI0P3kno/20?Shn080no_k0P3no_h20>SXj080kno_0P3X
j>P40>7Qh@80i>CT0P3Xj>P50?Win@80jn_[0P3Zj^X20?gmo@80oooo0P3_knl20>SXj080lO7a0P3o
ool20??cl`80moOg0P3kno/20?knoP@0no_k0P3gmoL20?Shn0l0oooo000=0?ooo`80o?cl0P3inOT4
0?_kn`80oooo0P3gmoL20?gmo@80moOg0P3kno/20?Win@80n?Sh0P3kno/20?Ogm`80no_k0P3inOT3
0?Gem@80moOg0P3emOD20?gmo@@0moOg0P3kno/20?ooo`80nOWi0P3gmoL20?clo080oOgm0P3oool2
0?knoP80n?Sh0P3fm_H20>GUi@80lO7a0P2PX:020?7al@80mOGe0P3Jf]X20>WYj@80oooo0P3^k^h2
0=cLg080jn_[0P27QhL206][J`80oooo0P3alO420?[jnP<0n?Sh0P3oool20?clo0H0oooo0P3inOT2
0?ooo`80nOWi0P3gmoL60?ooo`@0oOgm0P3oool20?Win@80o?cl0P3jn_X60?Win@H0n_[j103moOd2
0?KfmP@0o?cl0P3hn?P20?Cdm0<0m_Kf0P3^k^h20?Ogm`80mOGe0P3fm_H20>g]k@80nOWi0P3gmoL2
0?KfmPH0lO7a0P3Jf]X20<;2`P80f=SH0P3?cll20=kNgP80kNg]0P3Rh^820=WIf@80no_k0P3hn?P2
0?_kn`80o_kn0P3Xj>P20>o_k`80j>SX103QhN420>CTi080j>SX1@3inOT20>_[j`80j^[Z0P3moOd2
0?ooo`80kno_0P3Xj>P20?7al@80oooo0P3clo<20?Ogm`80no_k0P3no_h40?_kn`80moOg0P3hn?P?
0?ooo`003@3oool20??cl`80moOg103emOD40?_kn`80nOWi0P3gmoL20?ooo`80nOWi0P3gmoL20?kn
oP80moOg0P3jn_X20?Ogm`<0mOGe0P3inOT40?_kn`80n?Sh0P3moOd20?_kn`80n_[j0P3hn?P20?[j
nP@0no_k0P3lo?`20?ooo`80oOgm0P3emOD20>k^kP80no_k0P2][Jd20>g]k@80j>SX0P3Vi^H20>g]
k@80lO7a0P3Ti>@20=kNgP80m_Kf0P3dm?@20451@@80oooo0P3alO420?ooo`<0no_k0P3oool20?kn
oPX0nOWi0P3gmoL20?Win@80oooo103jn_X20?ooo`@0o?cl0P3inOT20?gmo@80o?cl0P3hn?P20?Wi
n@80m?Cd0P3fm_H20?clo0@0oooo103jn_X20?clo080m_Kf0P3clo<20?Gem@<0n_[j0P3gmoL40?3`
l080k>c/0P3QhN420>o_k`80kNg]0P3_knl40>CTi080e]KF0P3Shn<20<K6aP80hN7Q0P3Rh^820=OG
e`80lO7a0P3QhN420>OWi`80lo?c0P3fm_H20?Cdm080mOGe0P3^k^h20?_kn`80k>c/0P3`l?020?Ge
m@@0jn_[0P3inOT30?7al@80kno_0P3moOd20?ooo`80l?3`0P3[jn/20?[jnP80j^[Z0P3^k^h20?7a
l@80mOGe0P3no_h20?_kn`80nOWi0P3gmoL20?_kn`80n?Sh3`3oool000d0oooo0P3clo<20?Ogm`@0
mOGe103kno/20?Win@80moOg0P3oool20?Win@80moOg0P3no_h20?Ogm`80n_[j0P3gmoL30?Gem@80
nOWi103kno/20?Shn080oOgm0P3kno/20?[jnP80n?Sh0P3jn_X40?_kn`80o?cl0P3oool20?gmo@80
mOGe0P3^k^h20?_kn`80[Jf]0P3]kNd20>SXj080i^KV0P3]kNd20?7al@80i>CT0P3Ng]h20?KfmP80
m?Cd0P11@D420?ooo`80lO7a0P3oool30?_kn`80oooo0P3no_h:0?Win@80moOg0P3inOT20?ooo`@0
n_[j0P3oool40?clo080nOWi0P3moOd20?clo080n?Sh0P3inOT20?Cdm080m_Kf0P3lo?`40?ooo`@0
n_[j0P3lo?`20?KfmP80lo?c0P3emOD30?[jnP80moOg103`l?020>c/k080hN7Q0P3_knl20>g]k@80
kno_103Ti>@20=KFeP80hn?S0P36a/H20>7Qh@80h^;R0P3GemL20?7al@80hN7Q0P3WinL20??cl`80
m_Kf0P3dm?@20?Gem@80k^k^0P3kno/20>c/k080l?3`0P3emOD40>_[j`80nOWi0`3alO420>o_k`80
oOgm0P3oool20?3`l080jn_[0P3jn_X20>[ZjP80k^k^0P3alO420?Gem@80o_kn0P3kno/20?Win@80
moOg0P3kno/20?Shn0l0oooo000?0?ooo`80no_k0P3hn?P20?Win@@0n_[j0P3hn?P20?Win@80o_kn
0P3jn_X20?clo080m_Kf0P3kno/40?Ogm`D0n_[j0P3oool20?Win@80n_[j0P3inOT20?gmo@@0n?Sh
0P3gmoL40?ooo`80n?Sh0P3moOd20?_kn`80nOWi0P3]kNd20=CDe080alO70P3]kNd20>?Sh`80jn_[
0P3gmoL20>;RhP80i^KV0P3Lg=`20>c/k080g]kN0P2DU9@209bLW080l_;b0P3jn_X30?Ogm`80n?Sh
0P3oool20??cl`80moOg103inOT60?ooo`80oOgm103lo?`20?Ogm`80nOWi0P3jn_X20?Win@80oooo
103lo?`20?Shn080no_k0P3jn_X20?KfmP@0no_k0P3hn?P20?ooo`80m_Kf0P3kno/20>k^kP80kNg]
0`3emOD20>_[j`80oooo0P3EeMD20>GUi@@0moOg103emOD20>3Ph080jNWY0P3Jf]X20=oOg`80inOW
0P3De=@20>3Ph080gMgM0P3GemL20<k>cP80j^[Z0P3bl_820?KfmP80n_[j0P3YjNT20?7al@80i>CT
0P3UiND20?3`l080m?Cd0P3Zj^X20>7Qh@80j^[Z0`3bl_820?ooo`80oOgm0P3clo<20>[ZjP80kNg]
0P3^k^h20>SXj080nOWi0P3oool20?Cdm080no_k0P3inOT20?ooo`80n_[j0P3gmoL20?_kn`l0oooo
000?0?ooo`80no_k0P3hn?P20?Win@@0n_[j0P3hn?P20?Win@80o_kn0P3jn_X20?clo080m_Kf0P3k
no/40?Ogm`D0n_[j0P3oool20?Win@80n_[j0P3inOT20?gmo@@0n?Sh0P3gmoL40?ooo`80n?Sh0P3m
oOd20?_kn`80nOWi0P3]kNd20=CDe080alO70P3]kNd20>?Sh`80jn_[0P3gmoL20>;RhP80i^KV0P3L
g=`20>c/k080g]kN0P2DU9@209bLW080l_;b0P3jn_X30?Ogm`80n?Sh0P3oool20??cl`80moOg103i
nOT60?ooo`80oOgm103lo?`20?Ogm`80nOWi0P3jn_X20?Win@80oooo103lo?`20?Shn080no_k0P3j
n_X20?KfmP@0no_k0P3hn?P20?ooo`80m_Kf0P3kno/20>k^kP80kNg]0`3emOD20>_[j`80oooo0P3E
eMD20>GUi@@0moOg103emOD20>3Ph080jNWY0P3Jf]X20=oOg`80inOW0P3De=@20>3Ph080gMgM0P3G
emL20<k>cP80j^[Z0P3bl_820?KfmP80n_[j0P3YjNT20?7al@80i>CT0P3UiND20?3`l080m?Cd0P3Z
j^X20>7Qh@80j^[Z0`3bl_820?ooo`80oOgm0P3clo<20>[ZjP80kNg]0P3^k^h20>SXj080nOWi0P3o
ool20?Cdm080no_k0P3inOT20?ooo`80n_[j0P3gmoL20?_kn`l0oooo000?0?ooo`80no_k103inOT2
0?_kn`80oooo0P3jn_X20?knoP80nOWi0P3fm_H20?Win@80n?Sh0P3oool20?_kn`80oOgm0`3kno/4
0?Ogm`80oOgm0P3kno/20?KfmP80oooo103hn?P20?_kn`80moOg103inOT20?gmo@80m_Kf0P3jn_X2
0>7Qh@80dM7A0P3Hf=P20??cl`80hn?S0P3alO420??cl`80e]KF0P3hn?P20>3Ph080jn_[0P3Zj^X2
0>SXj080G5aL0P3^k^h20?knoP<0m?Cd0P3clo<20?ooo`80m_Kf0P3dm?@20?Win@80o?cl0P3jn_X2
0?Win@80o?cl0P3moOd20?ooo`80n_[j103moOd20?[jnP80oOgm0P3hn?P20?clo0@0n_[j0P3lo?`4
0?gmo@@0lO7a103fm_H20?7al@80kNg]0P3fm_H20?Shn0<0h>3P0P3bl_820=?Cd`80j>SX0P3bl_82
0?Shn080l?3`0P3Ti>@20<o?c`80c<c<0P3Ti>@20>GUi@80moOg0P3WinL20?knoP80k^k^0P3`l?02
0>GUi@80kno_0P3oool20?KfmP80n_[j0P3WinL20=3@d080i>CT0P3UiND20?Cdm080h^;R0P3/k>`2
0?ooo`80h^;R0P3Shn<50?ooo`80moOg0P3emOD20>OWi`80l_;b0P3no_h20?;blP80nOWi0P3dm?@2
0?Shn080moOg0P3oool20?Ogm`80n_[j103kno/?0?ooo`003`3oool20?_kn`@0nOWi0P3kno/20?oo
o`80n_[j0P3no_h20?Win@80m_Kf0P3inOT20?Shn080oooo0P3kno/20?gmo@<0no_k103gmoL20?gm
o@80no_k0P3fm_H20?ooo`@0n?Sh0P3kno/20?Ogm`@0nOWi0P3moOd20?KfmP80n_[j0P3QhN420=7A
d@80f=SH0P3clo<20>?Sh`80lO7a0P3clo<20=KFeP80n?Sh0P3Ph>020>_[j`80j^[Z0P3Xj>P205aL
G080k^k^0P3no_h30?Cdm080lo?c0P3oool20?KfmP80m?Cd0P3inOT20?clo080n_[j0P3inOT20?cl
o080oOgm0P3oool20?[jnP@0oOgm0P3jn_X20?gmo@80n?Sh0P3lo?`40?[jnP80o?cl103moOd40?7a
l@@0m_Kf0P3alO420>g]k@80m_Kf0P3hn?P30>3Ph080l_;b0P3Cdm<20>SXj080l_;b0P3hn?P20?3`
l080i>CT0P3?cll20<c<c080i>CT0P3UiND20?Ogm`80inOW0P3no_h20>k^kP80l?3`0P3UiND20>o_
k`80oooo0P3fm_H20?[jnP80inOW0P3@d=020>CTi080iNGU0P3dm?@20>;RhP80k>c/0P3oool20>;R
hP80hn?S1@3oool20?Ogm`80mOGe0P3WinL20?;blP80o_kn0P3bl_820?Win@80m?Cd0P3hn?P20?Og
m`80oooo0P3gmoL20?[jnP@0no_k3`3oool000l0oooo0P3hn?P60?ooo`80moOg0P3inOT20?_kn`80
oooo103gmoL60?ooo`80moOg0`3oool20?Ogm`80n?Sh0P3jn_X20?_kn`80oOgm0P3dm?@20?Ogm`80
n?Sh0P3moOd20?Shn080nOWi103gmoL20?KfmP80oooo0P3:b/X20>?Sh`80d=3@0P3_knl20>KViP80
l?3`0P3Zj^X20=GEe@80n_[j0P3]kNd20>?Sh`80l?3`0P3=cLd203<c<`80n?Sh0P3inOT30?Shn080
nOWi0P3moOd20?clo080n?Sh0P3moOd20?Win@80n?Sh0P3moOd20?Win@80n?Sh0P3inOT20?gmo@80
o?cl103moOd20?Win@80o?cl0P3kno/20?ooo`80mOGe0P3bl_820?Cdm080n?Sh0P3oool20?gmo@80
oooo0P3clo<20?KfmP80kNg]0P3alO420>c/k0<0j^[Z0P3De=@20<k>cP80lO7a0P3YjNT20>GUi@80
gmoO0P3UiND20=gMg@80mOGe0P3Ogml20>[ZjP80n?Sh0P3gmoL20?3`l080jNWY0P3`l?020>3Ph080
kNg]0P3oool20?Cdm080n_[j0P3Xj>P20=?Cd`80jNWY103Zj^X20=_Kf`80j^[Z0P3hn?P20>_[j`80
k>c/0`3no_h20?gmo@80j>SX0P3Jf]X20>CTi080o_kn0P3kno/20?7al@80no_k103emOD20?ooo`80
n?Sh103kno/20?Shn140oooo000?0?ooo`80n?Sh1P3oool20?Ogm`80nOWi0P3kno/20?ooo`@0moOg
1P3oool20?Ogm`<0oooo0P3gmoL20?Shn080n_[j0P3kno/20?gmo@80m?Cd0P3gmoL20?Shn080oOgm
0P3hn?P20?Win@@0moOg0P3fm_H20?ooo`80b/[:0P3Shn<20=3@d080kno_0P3Vi^H20?3`l080j^[Z
0P3EeMD20?[jnP80kNg]0P3Shn<20?3`l080cLg=0P0c<c<20?Shn080nOWi0`3hn?P20?Win@80oOgm
0P3lo?`20?Shn080oOgm0P3inOT20?Shn080oOgm0P3inOT20?Shn080nOWi0P3moOd20?clo0@0oOgm
0P3inOT20?clo080no_k0P3oool20?Gem@80l_;b0P3dm?@20?Shn080oooo0P3moOd20?ooo`80lo?c
0P3fm_H20>g]k@80lO7a0P3/k>`30>[ZjP80e=CD0P3>c/h20?7al@80jNWY0P3UiND20=oOg`80iNGU
0P3MgMd20?Gem@80gmoO0P3Zj^X20?Shn080moOg0P3`l?020>WYj@80l?3`0P3Ph>020>g]k@80oooo
0P3dm?@20?[jnP80j>SX0P3Cdm<20>WYj@@0j^[Z0P3Kfm/20>[ZjP80n?Sh0P3[jn/20>c/k0<0o_kn
0P3moOd20>SXj080f][J0P3Ti>@20?knoP80no_k0P3alO420?_kn`@0mOGe0P3oool20?Shn0@0no_k
0P3hn?PA0?ooo`003`3oool40?Shn0@0m_Kf0P3oool60?_kn`@0oooo0P3kno/40?ooo`80no_k0`3i
nOT20?[jnP80nOWi0P3kno/20?ooo`80nOWi0P3gmoL40?Win@80mOGe103hn?P20?ooo`80m_Kf0P3d
m?@20?7al@80`/;20P3_knl20=[JfP80jNWY0P3`l?020?;blP80j>SX0P3Rh^820?7al@80lo?c0P3f
m_H20=oOg`80g]kN0P0^;Rh20?Ogm`80l?3`0`3gmoL40?[jnP80oooo0P3lo?`20?Win@80oooo0P3k
no/40?gmo@@0n?Sh0P3oool20?Ogm`80lO7a0P3bl_820?KfmP80mOGe0P3alO420?Gem@80m_Kf0P3o
ool20?clo080n_[j0P3emOD20?Shn0@0l?3`0P3Xj>P20?7al@80no_k0P3UiND30>CTi080fMWI0P3h
n?P20?ooo`80n_[j0P3_knl20=_Kf`80i^KV0P3]kNd20>c/k080fm_K0P3QhN420>WYj@80l?3`0P3m
oOd20>KViP80h>3P0P3Xj>P20?;blP80lo?c0P3kno/20>3Ph080i>CT0P3gmoL20?;blP80mOGe0P3h
n?P20?ooo`80k^k^0P3Zj^X40>;RhP<0moOg0P3Zj^X20>GUi@80k>c/0P3moOd20?_kn`80n?Sh0P3f
m_H20?Gem@H0no_k0P3moOd40?Ogm`80n?Sh4@3oool000l0oooo103hn?P40?KfmP80oooo1P3kno/4
0?ooo`80no_k103oool20?_kn`<0nOWi0P3jn_X20?Win@80no_k0P3oool20?Win@80moOg103inOT2
0?Gem@@0n?Sh0P3oool20?KfmP80m?Cd0P3alO420<;2`P80kno_0P3Jf]X20>WYj@80l?3`0P3bl_82
0>SXj080h^;R0P3alO420??cl`80m_Kf0P3Ogml20=kNgP80;Rh^0P3gmoL20?3`l0<0moOg103jn_X2
0?ooo`80o?cl0P3inOT20?ooo`80no_k103moOd40?Shn080oooo0P3gmoL20?7al@80l_;b0P3fm_H2
0?Gem@80lO7a0P3emOD20?KfmP80oooo0P3lo?`20?[jnP80mOGe0P3hn?P40?3`l080j>SX0P3alO42
0?_kn`80iNGU0`3Ti>@20=WIf@80n?Sh0P3oool20?[jnP80kno_0P3Kfm/20>KViP80kNg]0P3/k>`2
0=_Kf`80hN7Q0P3YjNT20?3`l080oOgm0P3Vi^H20>3Ph080j>SX0P3bl_820??cl`80no_k0P3Ph>02
0>CTi080moOg0P3bl_820?Gem@80n?Sh0P3oool20>k^kP80j^[Z103Rh^830?Ogm`80j^[Z0P3UiND2
0>c/k080oOgm0P3kno/20?Shn080m_Kf0P3emOD60?_kn`80oOgm103gmoL20?Shn140oooo000?0?oo
o`@0no_k103hn?P40?_kn`80nOWi0P3kno/40?ooo`80no_k103oool20?_kn`<0oooo0P3kno/20?oo
o`80no_k0P3inOT20?ooo`80no_k0P3inOT20?_kn`@0n_[j0P3inOT20?Ogm`80n?Sh0P3emOD20>_[
j`80c<c<0P3Xj>P20>OWi`80jNWY0P3`l?020?clo080fm_K0P3Zj^X20=SHf080kNg]0P3Hf=P20>CT
i080l_;b0P0k>c/20?Ogm`80lO7a0`3Zj^X20?Shn080moOg0P3moOd20?Cdm080k^k^0P3fm_H20?gm
o@80mOGe0P3bl_820?Shn080moOg0P3alO420?Shn080o?cl0P3jn_X20?clo080m?Cd0P3fm_H20?_k
n`80m_Kf0P3hn?P40?KfmP80oooo0P3fm_H40?Ogm`80kNg]0P3no_h20>g]k@80n?Sh0`3Ng]h20=cL
g080jNWY103/k>`20=[JfP80nOWi0P3^k^h20?Win@80no_k0P3Jf]X20?ooo`80kno_0P3Vi^H40>g]
k@80mOGe0P3clo<20>o_k`80inOW0P3inOT20>3Ph080m?Cd0P3_knl20>SXj080oOgm103/k>`20?Cd
m080f=SH0P3moOd20?Gem@<0lO7a0P3Ng]h20>[ZjP80mOGe103gmoL20?KfmP80oOgm0P3inOT20?Og
m`80oooo0P3inOT20?[jnPH0moOg0P3kno/?0?ooo`003`3oool40?_kn`@0n?Sh103kno/20?Win@80
no_k103oool20?_kn`@0oooo0P3kno/30?ooo`80no_k0P3oool20?_kn`80nOWi0P3oool20?_kn`80
nOWi0P3kno/40?[jnP80nOWi0P3gmoL20?Shn080mOGe0P3[jn/20<c<c080j>SX0P3WinL20>WYj@80
l?3`0P3lo?`20=_Kf`80j^[Z0P3Hf=P20>g]k@80f=SH0P3Ti>@20?;blP80>c/k0P3gmoL20?7al@<0
j^[Z0P3hn?P20?Ogm`80oOgm0P3dm?@20>k^kP80m_Kf0P3moOd20?Gem@80l_;b0P3hn?P20?Ogm`80
lO7a0P3hn?P20?clo080n_[j0P3lo?`20?Cdm080m_Kf0P3kno/20?KfmP80n?Sh103fm_H20?ooo`80
m_Kf103gmoL20>g]k@80o_kn0P3]kNd20?Shn0<0g]kN0P3Lg=`20>WYj@@0k>c/0P3Jf]X20?Win@80
k^k^0P3inOT20?_kn`80f][J0P3oool20>o_k`80i^KV103]kNd20?Gem@80lo?c0P3_knl20>OWi`80
nOWi0P3Ph>020?Cdm080kno_0P3Xj>P20?gmo@@0k>c/0P3dm?@20=SHf080oOgm0P3emOD30?7al@80
g]kN0P3Zj^X20?Gem@@0moOg0P3fm_H20?gmo@80nOWi0P3gmoL20?ooo`80nOWi0P3jn_X60?Ogm`80
no_k3`3oool000l0oooo303kno/20?Win@80oooo0P3kno/20?ooo`80no_k103oool70?_kn`80nOWi
0P3kno/20?ooo`H0nOWi0P3oool20?_kn`80n_[j0P3moOd20?_kn`80m_Kf0P3_knl20=_Kf`80c<c<
0P3`l?020>OWi`80iNGU0P3dm?@20?ooo`80fm_K0P3dm?@20?KfmP80f=SH0P3Bd]820?KfmP80l?3`
0P0f=SH40?_kn`D0lo?c0P3inOT20?Shn080l_;b0P3emOD20?Cdm080moOg0P3fm_H40?clo0@0moOg
0P3fm_H20?[jnP80no_k0P3fm_H20?Ogm`80m_Kf0P3inOT20?_kn`80nOWi0P3emOD60?Shn080oooo
0P3dm?@20?3`l080nOWi0P3dm?@20=kNgP<0iNGU0P3inOT20?Gem@80k>c/0P3QhN420>c/k080lO7a
0P3Ng]h20>GUi@80m?Cd0P3Lg=`20?7al@80n?Sh0P3Ti>@20>WYj@80o?cl0P3inOT20>WYj@80oooo
0P3Shn<20?[jnP80f][J0P3kno/20?Gem@80inOW0P3[jn/20>SXj080iNGU0P3Xj>P20>3Ph080oooo
0P3Xj>P30>WYj@80l_;b103dm?@20?Ogm`80n?Sh0P3emOD20?gmo@80moOg1P3kno/20?Ogm`80n_[j
0P3moOd20?Shn140oooo000?0?ooo``0no_k0P3inOT20?ooo`80no_k0P3oool20?_kn`@0oooo1`3k
no/20?Win@80no_k0P3oool60?Win@80oooo0P3kno/20?[jnP80oOgm0P3kno/20?KfmP80kno_0P3K
fm/20<c<c080l?3`0P3WinL20>GUi@80m?Cd0P3oool20=_Kf`80m?Cd0P3fm_H20=SHf080d];B0P3f
m_H20?3`l080=SHf103kno/50??cl`80nOWi0P3hn?P20?;blP80mOGe0P3dm?@20?Ogm`80m_Kf103l
o?`40?Ogm`80m_Kf0P3jn_X20?_kn`80m_Kf0P3gmoL20?KfmP80nOWi0P3kno/20?Win@80mOGe1P3h
n?P20?ooo`80m?Cd0P3`l?020?Win@80m?Cd0P3Ng]h30>GUi@80nOWi0P3emOD20>c/k080hN7Q0P3/
k>`20?7al@80g]kN0P3UiND20?Cdm080g=cL0P3alO420?Shn080i>CT0P3YjNT20?clo080nOWi0P3Y
jNT20?ooo`80hn?S0P3jn_X20=[JfP80no_k0P3emOD20>OWi`80jn_[0P3Xj>P20>GUi@80j>SX0P3P
h>020?ooo`80j>SX0`3YjNT20?;blP@0m?Cd0P3gmoL20?Shn080mOGe0P3moOd20?Ogm`H0no_k0P3g
moL20?[jnP80oOgm0P3hn?PA0?ooo`004`3oool20?_kn`80oooo0P3inOT40?ooo`80moOg0P3hn?P4
0?_kn`80oooo103kno/90?ooo`80no_k0P3oool20?_kn`80nOWi0P3kno/20?Ogm`80m_Kf0P3inOT2
0?gmo@80moOg0P3emOD20;fm_@80gmoO0P3`l?020>[ZjP80eMGE0P3_knl20>c/k080h^;R0P3UiND2
0>[ZjP80jNWY0P3UiND20>SXj080inOW0P0k>c/40??cl`D0n_[j0P3hn?P20?KfmP80mOGe0P3alO44
0?Shn0@0n_[j0P3fm_H20?_kn`80moOg0P3bl_840?Cdm080moOg0P3inOT20?[jnP80moOg0P3alO42
0?Win@80o?cl103gmoL20?knoP@0lO7a0P3`l?020>c/k080lO7a0P3Ti>@30?7al@80m?Cd103bl_82
0?Shn0@0l?3`103_knl20>k^kP80g]kN0P3`l?020?Shn080l_;b0P3/k>`20??cl`80jNWY0P3oool2
0>_[j`80g]kN0P3emOD20>SXj080l_;b0P3no_h20>GUi@80jNWY0P3[jn/20>k^kP@0jn_[0P3gmoL2
0>3Ph0<0no_k0P3fm_H20?Cdm080kno_0P3oool20?Gem@@0no_k0P3inOT40?_kn`@0oooo0P3inOT4
0?_kn`80nOWi3`3oool001<0oooo0P3kno/20?ooo`80nOWi103oool20?Ogm`80n?Sh103kno/20?oo
o`@0no_k2@3oool20?_kn`80oooo0P3kno/20?Win@80no_k0P3gmoL20?KfmP80nOWi0P3moOd20?Og
m`80mOGe0P2m_Kd20=oOg`80l?3`0P3Zj^X20=GEe@80kno_0P3/k>`20>;RhP80iNGU0P3Zj^X20>WY
j@80iNGU0P3Xj>P20>OWi`80>c/k103clo<50?[jnP80n?Sh0P3fm_H20?Gem@80lO7a103hn?P40?[j
nP80m_Kf0P3kno/20?Ogm`80l_;b103dm?@20?Ogm`80nOWi0P3jn_X20?Ogm`80lO7a0P3inOT20?cl
o0@0moOg0P3no_h40?7al@80l?3`0P3/k>`20?7al@80i>CT0`3alO420?Cdm0@0l_;b0P3hn?P40?3`
l0@0kno_0P3^k^h20=kNgP80l?3`0P3hn?P20?;blP80k>c/0P3clo<20>WYj@80oooo0P3[jn/20=kN
gP80mOGe0P3Xj>P20?;blP80o_kn0P3UiND20>WYj@80jn_[0P3^k^h40>_[j`80moOg0P3Ph>030?_k
n`80m_Kf0P3dm?@20>o_k`80oooo0P3emOD40?_kn`80nOWi103kno/40?ooo`80nOWi103kno/20?Wi
n@l0oooo000?0?ooo`80no_k0P3inOT20?_kn`80nOWi0P3oool20?Win@80no_k0P3gmoL20?gmo@80
moOg0P3hn?P20?ooo`@0nOWi0`3oool20?_kn`80nOWi0P3gmoL20?Shn080moOg103kno/20?Win@80
mOGe0P3gmoL40?Gem@80oOgm0P3Xj>P20;Zj^P80kno_0P3UiND20>o_k`80g=cL0P3/k>`20=gMg@80
moOg0P3`l?020>k^kP80e=CD0P3Vi^H20>OWi`80mOGe0P15ADD20>g]k@80lO7a0`3bl_820??cl`80
n_[j0P3hn?P40?Gem@80moOg103fm_H20?Cdm0H0nOWi0P3oool20??cl`80jn_[0P3`l?020>k^kP80
lo?c0P3emOD20?KfmP80oOgm0P3emOD40?Cdm080l?3`0P3bl_820?Shn080n_[j0P3/k>`20=GEe@80
i>CT0`3]kNd20?Shn080no_k0P3bl_820?knoP80lo?c0P3emOD20?3`l080j^[Z0P3bl_840>[ZjP80
j>SX0P3Ph>020=_Kf`80g]kN0P3Kfm/20??cl`80o?cl0P3Ogml20?3`l080jNWY0P3emOD20?Cdm080
o_kn0P3Zj^X20>_[j`80moOg0P3Kfm/20>[ZjP80moOg0P3UiND30?Shn080o_kn0P3_knl40?Ogm`80
mOGe0P3inOT40?_kn`80oooo103kno/20?ooo`80no_k0P3moOd20?Shn080nOWi3`3oool000l0oooo
0P3kno/20?Win@80no_k0P3inOT20?ooo`80nOWi0P3kno/20?Ogm`80oOgm0P3gmoL20?Shn080oooo
103inOT30?ooo`80no_k0P3inOT20?Ogm`80n?Sh0P3gmoL40?_kn`80nOWi0P3emOD20?Ogm`@0mOGe
0P3moOd20>SXj080^[Zj0P3_knl20>GUi@80kno_0P3Lg=`20>c/k080gMgM0P3gmoL20?3`l080k^k^
0P3De=@20>KViP80inOW0P3emOD204E5A@80kNg]0P3alO430?;blP80lo?c0P3jn_X20?Shn0@0mOGe
0P3gmoL40?KfmP80m?Cd1P3inOT20?ooo`80lo?c0P3[jn/20?3`l080k^k^0P3clo<20?Gem@80m_Kf
0P3moOd20?Gem@@0m?Cd0P3`l?020?;blP80n?Sh0P3jn_X20>c/k080eMGE0P3Ti>@30>g]k@80n?Sh
0P3kno/20?;blP80o_kn0P3clo<20?Gem@80l?3`0P3Zj^X20?;blP@0j^[Z0P3Xj>P20>3Ph080fm_K
0P3Ng]h20=_Kf`80lo?c0P3lo?`20=oOg`80l?3`0P3YjNT20?Gem@80m?Cd0P3no_h20>[ZjP80jn_[
0P3gmoL20=_Kf`80j^[Z0P3gmoL20>GUi@<0n?Sh0P3no_h20>o_k`@0moOg0P3emOD20?Win@@0no_k
0P3oool40?_kn`80oooo0P3kno/20?gmo@80n?Sh0P3inOT?0?ooo`003@3oool20?Win@80oooo0P3i
nOT20?ooo`80no_k0P3no_h20?Win@80mOGe0P3gmoL20?ooo`80moOg103hn?P20?gmo@80oooo0`3k
no/20?Win@80no_k103inOT20?Shn080no_k0P3inOT40?_kn`H0n?Sh0P3moOd20=3@d080emOG0P3U
iND40>[ZjP80iNGU0P3/k>`20=gMg@80i^KV0P3Xj>P20>3Ph080alO70P3fm_H20?7al@80n_[j0P16
ATH20>g]k@80m?Cd1@3hn?P40?[jnP80moOg0P3clo<20?KfmP@0n_[j0P3gmoL20?Win@80moOg103l
o?`20?Ogm`80n?Sh0P3oool20?Shn0@0m?Cd0P3lo?`40?Shn080oooo0P3clo<20?7al@80mOGe0P3]
kNd20?;blP80hN7Q0P3]kNd20>[ZjP<0moOg0P3kno/20?Cdm080oooo0P3Cdm<20=;BdP80fMWI0P3U
iND20>OWi`80j^[Z0P3alO420>k^kP80h^;R0P3dm?@20>o_k`80moOg0P34a<@20>7Qh@80i^KV0P3^
k^h40?Shn080g=cL0P3no_h20>c/k080jn_[103oool20<_;b`80m?Cd0P3Ti>@20>c/k0<0lo?c0P3h
n?P20?KfmP80oOgm0P3_knl20?Gem@80m_Kf0P3inOT20?ooo`80no_k0P3oool20?_kn`80oooo0P3k
no/20?gmo@80n?Sh0P3kno/?0?ooo`003@3oool20?Win@80oooo0P3inOT20?ooo`80no_k0P3no_h2
0?Win@80mOGe0P3gmoL20?ooo`80moOg103hn?P20?gmo@80oooo0`3kno/20?Win@80no_k103inOT2
0?Shn080no_k0P3inOT40?_kn`H0n?Sh0P3moOd20=3@d080emOG0P3UiND40>[ZjP80iNGU0P3/k>`2
0=gMg@80i^KV0P3Xj>P20>3Ph080alO70P3fm_H20?7al@80n_[j0P16ATH20>g]k@80m?Cd1@3hn?P4
0?[jnP80moOg0P3clo<20?KfmP@0n_[j0P3gmoL20?Win@80moOg103lo?`20?Ogm`80n?Sh0P3oool2
0?Shn0@0m?Cd0P3lo?`40?Shn080oooo0P3clo<20?7al@80mOGe0P3]kNd20?;blP80hN7Q0P3]kNd2
0>[ZjP<0moOg0P3kno/20?Cdm080oooo0P3Cdm<20=;BdP80fMWI0P3UiND20>OWi`80j^[Z0P3alO42
0>k^kP80h^;R0P3dm?@20>o_k`80moOg0P34a<@20>7Qh@80i^KV0P3^k^h40?Shn080g=cL0P3no_h2
0>c/k080jn_[103oool20<_;b`80m?Cd0P3Ti>@20>c/k0<0lo?c0P3hn?P20?KfmP80oOgm0P3_knl2
0?Gem@80m_Kf0P3inOT20?ooo`80no_k0P3oool20?_kn`80oooo0P3kno/20?gmo@80n?Sh0P3kno/?
0?ooo`003@3oool20?Win@80no_k0P3oool40?_kn`80n_[j0P3fm_H20?Gem@80moOg0P3kno/40?oo
o`80n?Sh0P3oool20?[jnP<0nOWi203gmoL60?_kn`80moOg1P3jn_X20?gmo@80kno_0P37alL20>c/
k080f][J0P3Zj^X20>?Sh`80kno_0P3gmoL20?3`l080jn_[0P3Jf]X20>g]k@80hn?S0P3Zj^X20>g]
k@80m?Cd0P1BDU820??cl`80n?Sh0`3clo<20?Gem@@0moOg0P3moOd20?Win@80o_kn0P3hn?P20?Kf
mP80nOWi0P3emOD20?Cdm080l_;b0P3Xj>P20>OWi`80lO7a0P3bl_820?Cdm080oooo0P3alO420>[Z
jP80n?Sh0P3oool20??cl`80l_;b0P3oool20?knoP80k>c/0P3WinL20=WIf@80fm_K0P3alO430?3`
l080lo?c0P3bl_820=?Cd`80eMGE0P3Xj>P40<k>cP80oooo0P3Zj^X20?7al@80jNWY0P3Xj>P20>g]
k@80l?3`0P3WinL20=?Cd`80k>c/0P3Rh^820?;blP80k^k^0P3bl_820=OGe`@0jn_[0P3bl_820?7a
l@80jNWY0P3@d=020>WYj@80j>SX1@3hn?P20?Gem@80m_Kf0P3hn?P20?KfmP80mOGe0P3kno/20?Og
m`80oooo0P3kno/20?gmo@80n?Sh0P3kno/40?ooo`80no_k4@3oool000d0oooo0P3inOT20?_kn`80
oooo103kno/20?[jnP80m_Kf0P3emOD20?Ogm`80no_k103oool20?Shn080oooo0P3jn_X30?Win@P0
moOg1P3kno/20?Ogm`H0n_[j0P3moOd20>o_k`80alO70P3/k>`20=[JfP80j^[Z0P3Shn<20>o_k`80
moOg0P3`l?020>_[j`80f][J0P3]kNd20>?Sh`80j^[Z0P3]kNd20?Cdm080DU9B0P3clo<20?Shn0<0
lo?c0P3emOD40?Ogm`80oOgm0P3inOT20?knoP80n?Sh0P3fm_H20?Win@80mOGe0P3dm?@20?;blP80
j>SX0P3WinL20?7al@80l_;b0P3dm?@20?ooo`80lO7a0P3Zj^X20?Shn080oooo0P3clo<20?;blP80
oooo0P3no_h20>c/k080inOW0P3IfMT20=_Kf`80lO7a0`3`l?020??cl`80l_;b0P3Cdm<20=GEe@80
j>SX103>c/h20?ooo`80j^[Z0P3alO420>WYj@80j>SX0P3]kNd20?3`l080inOW0P3Cdm<20>c/k080
h^;R0P3bl_820>k^kP80l_;b0P3GemL40>_[j`80l_;b0P3alO420>WYj@80d=3@0P3YjNT20>SXj0D0
n?Sh0P3emOD20?KfmP80n?Sh0P3fm_H20?Gem@80no_k0P3gmoL20?ooo`80no_k0P3moOd20?Shn080
no_k103oool20?_kna40oooo000A0?ooo`@0no_k0P3inOT20?_kn`@0moOg0P3inOT60?_kn`80oooo
0P3inOT20?Ogm`<0no_k0P3fm_H20?Shn0@0n_[j0P3moOd20?_kn`80nOWi0P3jn_X20?Ogm`80oOgm
0P3jn_X20?ooo`80fMWI0P3Bd]820>SXj080dM7A0P3bl_820>SXj080no_k0P3_knl40?Ogm`80e=CD
0P3Zj^X20?Cdm080moOg0P3oool20?clo080GemO103oool30?7al@80lo?c0P3lo?`60?KfmP80nOWi
0P3alO420?3`l080mOGe0P3^k^h20?Gem@80lO7a0P3jn_X20?Shn080l?3`0P3gmoL20?;blP80k>c/
0P3jn_X20?Ogm`80lO7a0P3/k>`20?;blP80m?Cd0P3`l?020>OWi`80k^k^0P3Rh^820<k>cP80eMGE
0P3Hf=P30?Shn080h^;R0P3MgMd20>;RhP80nOWi0P3MgMd20<K6aP80f][J0P3Zj^X20??cl`80n_[j
0P3lo?`20=CDe080kNg]0P3kno/20?KfmP80iNGU0P3gmoL20?;blP@0n?Sh0P3Zj^X20>WYj@80hn?S
0P3gmoL20>[ZjP80gMgM0P3UiND20>3Ph080fMWI0P3`l?020?[jnP<0lo?c0P3fm_H20?Cdm080m_Kf
0P3inOT40?_kn`80nOWi103oool40?Shn0@0no_k103inOT20?_kn`l0oooo000A0?ooo`@0no_k0P3i
nOT20?_kn`@0moOg0P3inOT60?_kn`80oooo0P3inOT20?Ogm`<0no_k0P3fm_H20?Shn0@0n_[j0P3m
oOd20?_kn`80nOWi0P3jn_X20?Ogm`80oOgm0P3jn_X20?ooo`80fMWI0P3Bd]820>SXj080dM7A0P3b
l_820>SXj080no_k0P3_knl40?Ogm`80e=CD0P3Zj^X20?Cdm080moOg0P3oool20?clo080GemO103o
ool30?7al@80lo?c0P3lo?`60?KfmP80nOWi0P3alO420?3`l080mOGe0P3^k^h20?Gem@80lO7a0P3j
n_X20?Shn080l?3`0P3gmoL20?;blP80k>c/0P3jn_X20?Ogm`80lO7a0P3/k>`20?;blP80m?Cd0P3`
l?020>OWi`80k^k^0P3Rh^820<k>cP80eMGE0P3Hf=P30?Shn080h^;R0P3MgMd20>;RhP80nOWi0P3M
gMd20<K6aP80f][J0P3Zj^X20??cl`80n_[j0P3lo?`20=CDe080kNg]0P3kno/20?KfmP80iNGU0P3g
moL20?;blP@0n?Sh0P3Zj^X20>WYj@80hn?S0P3gmoL20>[ZjP80gMgM0P3UiND20>3Ph080fMWI0P3`
l?020?[jnP<0lo?c0P3fm_H20?Cdm080m_Kf0P3inOT40?_kn`80nOWi103oool40?Shn0@0no_k103i
nOT20?_kn`l0oooo000=0?ooo`80nOWi1P3kno/20?KfmP80nOWi103hn?P20?Win@80oooo0P3kno/2
0?Win@80oooo103hn?P30?_kn`80oOgm0P3inOT40?gmo@80m_Kf0P3oool20?Win@80no_k0P3gmoL2
0?Shn080oOgm0P3emOD20=CDe080g]kN0P3Ti>@20=_Kf`80nOWi0P3]kNd20?Ogm`80lo?c0P3Ph>02
0?Shn080_Kfm0P3WinL20?7al@@0n_[j0P3WinL206a/K080jn_[0P3QhN430>OWi`80j^[Z0P3Ti>@2
0>7Qh@80jNWY0P3alO420>k^kP80lo?c0P3emOD20??cl`80kNg]0P3QhN420=gMg@80l?3`0P3bl_82
0?[jnP80moOg0P3hn?P20?Cdm080j^[Z0P3UiND20?;blP80n_[j0P3dm?@40?Shn080lO7a0P3gmoL2
0>GUi@80`<300P3Zj^X20=kNgP<0lO7a0P3Fe]H20>GUi@80l_;b0P3Bd]820>g]k@80h>3P0P3GemL2
0?ooo`@0lo?c0P3gmoL20=?Cd`80k^k^0P3]kNd20>WYj@80gmoO0P3Ng]h20??cl`80k^k^0P3Ph>02
0<30`080oooo0P3QhN420?Gem@80m?Cd0P3[jn/20>k^kP80a/K60P3Rh^870?3`l080n_[j0P3emOD:
0?_kn`80oooo103kno/60?ooo`80no_k0P3oool20?Shn0l0oooo000=0?ooo`80nOWi1P3kno/20?Kf
mP80nOWi103hn?P20?Win@80oooo0P3kno/20?Win@80oooo103hn?P30?_kn`80oOgm0P3inOT40?gm
o@80m_Kf0P3oool20?Win@80no_k0P3gmoL20?Shn080oOgm0P3emOD20=CDe080g]kN0P3Ti>@20=_K
f`80nOWi0P3]kNd20?Ogm`80lo?c0P3Ph>020?Shn080_Kfm0P3WinL20?7al@@0n_[j0P3WinL206a/
K080jn_[0P3QhN430>OWi`80j^[Z0P3Ti>@20>7Qh@80jNWY0P3alO420>k^kP80lo?c0P3emOD20??c
l`80kNg]0P3QhN420=gMg@80l?3`0P3bl_820?[jnP80moOg0P3hn?P20?Cdm080j^[Z0P3UiND20?;b
lP80n_[j0P3dm?@40?Shn080lO7a0P3gmoL20>GUi@80`<300P3Zj^X20=kNgP<0lO7a0P3Fe]H20>GU
i@80l_;b0P3Bd]820>g]k@80h>3P0P3GemL20?ooo`@0lo?c0P3gmoL20=?Cd`80k^k^0P3]kNd20>WY
j@80gmoO0P3Ng]h20??cl`80k^k^0P3Ph>020<30`080oooo0P3QhN420?Gem@80m?Cd0P3[jn/20>k^
kP80a/K60P3Rh^870?3`l080n_[j0P3emOD:0?_kn`80oooo103kno/60?ooo`80no_k0P3oool20?Sh
n0l0oooo000=0?ooo`80nOWi0P3oool20?Win@80no_k0P3clo<20?Ogm`@0nOWi0P3oool20?_kn`80
nOWi0P3kno/20?ooo`@0moOg0`3kno/20?ooo`80o_kn0P3gmoL20?Shn080mOGe0P3kno/20?ooo`80
n_[j103moOd20?clo080h^;R0P3De=@20=cLg080h^;R0P3UiND20?Gem@80hn?S0P3bl_840>_[j`80
kno_0P34a<@20=OGe`80mOGe103gmoL20:^[Z`80QXJ60P3Xj>P20?3`l0<0l_;b103kno/20?knoP80
lo?c0P3/k>`20>o_k`80kNg]0P3emOD60?KfmP80lO7a0P3Kfm/20=cLg080jn_[0P3fm_H20??cl`80
o_kn0P3kno/20?Win@80m?Cd0P3]kNd20?knoP80oooo103dm?@20??cl`80h>3P0P39bLT20>OWi`80
f=SH0`3GemL20>;RhP@0jn_[0P30`<020<c<c080f=SH0P3Ph>020?7al@80kNg]0P3fm_H20??cl`80
h^;R0P3YjNT20>3Ph080o_kn0P3kno/20>KViP80mOGe0P3Lg=`20?7al@80b/[:0P3_knl20?3`l080
l_;b0P3IfMT20>_[j`80g]kN0P37alL20?;blP80kno_0P3`l?030?clo080m?Cd0P3jn_X20?Win@80
moOg0P3hn?P40?Ogm`80nOWi0P3oool60?_kn`@0oooo0P3kno/20?Ogm`l0oooo000=0?ooo`80nOWi
0P3oool20?Win@80no_k0P3clo<20?Ogm`@0nOWi0P3oool20?_kn`80nOWi0P3kno/20?ooo`@0moOg
0`3kno/20?ooo`80o_kn0P3gmoL20?Shn080mOGe0P3kno/20?ooo`80n_[j103moOd20?clo080h^;R
0P3De=@20=cLg080h^;R0P3UiND20?Gem@80hn?S0P3bl_840>_[j`80kno_0P34a<@20=OGe`80mOGe
103gmoL20:^[Z`80QXJ60P3Xj>P20?3`l0<0l_;b103kno/20?knoP80lo?c0P3/k>`20>o_k`80kNg]
0P3emOD60?KfmP80lO7a0P3Kfm/20=cLg080jn_[0P3fm_H20??cl`80o_kn0P3kno/20?Win@80m?Cd
0P3]kNd20?knoP80oooo103dm?@20??cl`80h>3P0P39bLT20>OWi`80f=SH0`3GemL20>;RhP@0jn_[
0P30`<020<c<c080f=SH0P3Ph>020?7al@80kNg]0P3fm_H20??cl`80h^;R0P3YjNT20>3Ph080o_kn
0P3kno/20>KViP80mOGe0P3Lg=`20?7al@80b/[:0P3_knl20?3`l080l_;b0P3IfMT20>_[j`80g]kN
0P37alL20?;blP80kno_0P3`l?030?clo080m?Cd0P3jn_X20?Win@80moOg0P3hn?P40?Ogm`80nOWi
0P3oool60?_kn`@0oooo0P3kno/20?Ogm`l0oooo000=0?ooo`80nOWi0P3oool20?[jnP80moOg0P3k
no/20?Ogm`80o_kn0P3moOd20?Shn0H0oooo0P3kno/20?Win@80moOg1@3kno/20?Win@80no_k0P3i
nOT20?Gem@80nOWi0P3jn_X20?Shn080oooo0P3moOd20?ooo`80e=CD0P3IfMT20=oOg`80k>c/0P3T
i>@20?7al@80jn_[0P3bl_840??cl`80`L710P3clo<20>3Ph080lo?c0P3gmoL20:n_[`80Kfm_0P2g
]kL20?3`l080n?Sh0`3kno/40?Gem@80l_;b103hn?P20?clo080m?Cd0P3_knl20?7al@80moOg0P3d
m?@20?KfmP80lO7a0P3]kNd20=WIf@80e=CD0P3WinL20?Cdm080l_;b0P3`l?020?_kn`80n_[j103f
m_H20>c/k080l_;b0P3Rh^820=;BdP80jn_[0P3]kNd20=?Cd`<0ZJVY0P3]kNd20>CTi080fMWI0P2b
/[820=_Kf`80kNg]0P3QhN420=kNgP80g=cL0P3UiND20>[ZjP80j>SX0P3YjNT20=oOg`80l_;b0P3Y
jNT20>7Qh@80c/k>0P3fm_H20>c/k080j^[Z0P3^k^h20?3`l080lo?c0P3/k>`20>WYj@80_;bl0P3T
i>@20>OWi`80n?Sh0P3Xj>P30?Gem@80lO7a0P3kno/20?knoP80oooo1P3gmoL:0?_kn`80oooo103k
no/A0?ooo`003@3oool20?Win@80oooo0P3jn_X20?Ogm`80no_k0P3gmoL20?knoP80oOgm0P3hn?P6
0?ooo`80no_k0P3inOT20?Ogm`D0no_k0P3inOT20?_kn`80nOWi0P3emOD20?Win@80n_[j0P3hn?P2
0?ooo`80oOgm0P3oool20=CDe080fMWI0P3Ogml20>c/k080i>CT0P3alO420>_[j`80l_;b103clo<2
0<71`@80lo?c0P3Ph>020??cl`80moOg0P2_[jl206m_K`80]kNg0P3`l?020?Shn0<0no_k103emOD2
0?;blP@0n?Sh0P3lo?`20?Cdm080kno_0P3alO420?Ogm`80m?Cd0P3fm_H20?7al@80kNg]0P3IfMT2
0=CDe080inOW0P3dm?@20?;blP80l?3`0P3kno/20?[jnP@0m_Kf0P3/k>`20?;blP80h^;R0P3Bd]82
0>_[j`80kNg]0P3Cdm<30:VYZ@80kNg]0P3Ti>@20=WIf@80/[:b0P3Kfm/20>g]k@80hN7Q0P3Ng]h2
0=cLg080iNGU0P3Zj^X20>SXj080jNWY0P3Ogml20?;blP80jNWY0P3QhN420<k>cP80m_Kf0P3/k>`2
0>[ZjP80k^k^0P3`l?020??cl`80k>c/0P3YjNT20;bl_080i>CT0P3WinL20?Shn080j>SX0`3emOD2
0?7al@80no_k0P3no_h20?ooo`H0moOg2P3kno/20?ooo`@0no_k4@3oool000d0oooo0P3inOT20?oo
o`80o_kn0P3inOT20?_kn`80moOg0P3inOT20?Gem@80n?Sh0P3gmoL20?Win@80oooo0P3kno/40?Wi
n@<0oooo1P3kno/20?ooo`80nOWi0P3kno/20?Ogm`80mOGe0P3inOT20?Shn080iNGU0P3Jf]X20<c<
c080jNWY0P3Xj>P20=kNgP80iNGU0P3YjNT20?Gem@80lo?c0P3^k^h20;no_`80gmoO0P3`l?020>WY
j@80MgMg0P1SHf<20<71`@@0n?Sh0P3jn_X30?_kn`@0moOg0P3bl_840?_kn`80n_[j0P3gmoL20?oo
o`80m?Cd0P3`l?020>c/k080m?Cd0P3hn?P20?Gem@@0k^k^0P3Hf=P20>7Qh@80moOg0P3dm?@40>k^
kP@0lO7a0P3bl_820?Win@80f=SH0P3alO420:f][@80_[jn0P2/[:`30:JVYP80d=3@0P3QhN420>CT
i080/;2`0P3AdM420<G5a@80clo?0P3Ng]h20=cLg080fm_K0P3^k^h20>o_k`80i^KV0P3Xj>P20>3P
h080oOgm0P3Vi^H20<71`@80lo?c103bl_820?Win@80h^;R0P3clo<20?knoP80kno_0P35aLD20?3`
l080no_k0P3Vi^H20?Win@<0n?Sh0P3no_h20?Win@@0moOg0P3oool20?_kn`80nOWi0P3oool60?_k
n`@0oooo103kno/A0?ooo`003@3oool20?Win@80oooo0P3no_h20?Win@80no_k0P3gmoL20?Win@80
mOGe0P3hn?P20?Ogm`80nOWi0P3oool20?_kn`@0nOWi0`3oool60?_kn`80oooo0P3inOT20?_kn`80
moOg0P3emOD20?Win@80n?Sh0P3UiND20=[JfP80c<c<0P3YjNT20>SXj080g]kN0P3UiND20>WYj@80
mOGe0P3clo<20>k^kP80_kno0P3Ogml20?3`l080jNWY0P1gMgL206=SH`80`L71103hn?P20?[jnP<0
no_k103gmoL20?;blP@0no_k0P3jn_X20?Ogm`80oooo0P3dm?@20?3`l080k>c/0P3dm?@20?Shn080
mOGe103^k^h20=SHf080hN7Q0P3gmoL20?Cdm0@0k^k^103alO420?;blP80nOWi0P3Hf=P20?7al@80
[Jf]0P2n_[h20:b/[0<0YZJV0P3@d=020>7Qh@80i>CT0P2`/;020=7Ad@80aLG50P3?cll20=kNgP80
g=cL0P3Kfm/20>k^kP80kno_0P3Vi^H20>SXj080h>3P0P3moOd20>KViP80`L710P3clo<40?;blP80
nOWi0P3Rh^820??cl`80o_kn0P3_knl20<G5a@80l?3`0P3kno/20>KViP80nOWi0`3hn?P20?knoP80
nOWi103gmoL20?ooo`80no_k0P3inOT20?ooo`H0no_k103oool40?_kna40oooo000?0?ooo`@0no_k
0P3oool40?Shn080oooo0P3hn?P40?Ogm`80nOWi0P3oool20?Shn080no_k0P3oool30?Ogm`H0no_k
0P3inOT20?_kn`@0oooo0P3kno/20?KfmP80moOg0P3Rh^820>WYj@80b<S80P3`l?020>KViP80j>SX
0P3[jn/60?Ogm`80fm_K0P3Ti>@20>3Ph080kno_0P3:b/X2065QH@80m_Kf103gmoL40?[jnPL0o_kn
0P3emOD20?;blP80mOGe0P3kno/20?Ogm`80oooo0P3no_h20?Shn080l_;b0P3gmoL20?3`l080nOWi
0P3gmoL20?3`l080k^k^0P3Cdm<20=CDe080fMWI0P3bl_820?KfmP80n_[j0P3fm_H20??cl`80j^[Z
0P3UiND20?Gem@80Y:BT1033`l<30=cLg080/[:b0P3QhN420?_kn`80_[jn0P2o_kl20<S8b080a<C4
0P3`l?020>k^kP80o_kn0P3Vi^H20?Win@80lO7a0P3bl_820>3Ph080kNg]0P3^k^h20<[:bP80iNGU
0P3Xj>P20?;blP80kNg]0P3Jf]X40>k^kP80mOGe0P3EeMD20?3`l080j>SX0P3_knl20?_kn`<0mOGe
103gmoL40?Win@X0no_k0P3inOT20?ooo`80no_k103oool40?_kn`l0oooo000?0?ooo`@0no_k0P3o
ool40?Shn080oooo0P3hn?P40?Ogm`80nOWi0P3oool20?Shn080no_k0P3oool30?Ogm`H0no_k0P3i
nOT20?_kn`@0oooo0P3kno/20?KfmP80moOg0P3Rh^820>WYj@80b<S80P3`l?020>KViP80j>SX0P3[
jn/60?Ogm`80fm_K0P3Ti>@20>3Ph080kno_0P3:b/X2065QH@80m_Kf103gmoL40?[jnPL0o_kn0P3e
mOD20?;blP80mOGe0P3kno/20?Ogm`80oooo0P3no_h20?Shn080l_;b0P3gmoL20?3`l080nOWi0P3g
moL20?3`l080k^k^0P3Cdm<20=CDe080fMWI0P3bl_820?KfmP80n_[j0P3fm_H20??cl`80j^[Z0P3U
iND20?Gem@80Y:BT1033`l<30=cLg080/[:b0P3QhN420?_kn`80_[jn0P2o_kl20<S8b080a<C40P3`
l?020>k^kP80o_kn0P3Vi^H20?Win@80lO7a0P3bl_820>3Ph080kNg]0P3^k^h20<[:bP80iNGU0P3X
j>P20?;blP80kNg]0P3Jf]X40>k^kP80mOGe0P3EeMD20?3`l080j>SX0P3_knl20?_kn`<0mOGe103g
moL40?Win@X0no_k0P3inOT20?ooo`80no_k103oool40?_kn`l0oooo000=0?ooo`80mOGe0P3hn?P4
0?_kn`@0n?Sh103inOT20?_kn`80nOWi103kno/20?[jnP@0oOgm0`3fm_H40?_kn`80n_[j0P3inOT2
0?ooo`H0moOg0P3kno/20?3`l080hn?S0P3Ogml20=CDe080mOGe0P3Xj>P20>_[j`80h^;R0P3]kNd2
0>[ZjP80lo?c0P32`/820??cl`80k^k^0P3WinL2075aL@80^[Zj1P3hn?P20?ooo`80n?Sh1`3emOD2
0?;blP80mOGe0P3alO420?ooo`80no_k103oool20?Ogm`80kno_0P3gmoL20?_kn`80nOWi0P3hn?P2
0?Win@80lO7a0P3Rh^820?7al@80dm?C0P3Ph>020?Gem@80no_k0P3bl_820?Ogm`80i>CT0P3emOD2
0=kNgP80XZ:R0P3Ph>020<g=c@<0dM7A0P2LW9`20:VYZ@80dM7A0P34a<@20>3Ph080alO70P3Ogml2
0>OWi`80n?Sh0P3]kNd20>_[j`80m_Kf0P3bl_820=SHf080moOg0P3Fe]H20?3`l080/K6a103Shn<2
0?Gem@80iNGU0P3Vi^H20>;RhP80kno_0P3emOD20=GEe@80hn?S0P3gmoL20?Shn080oOgm0`3gmoL6
0?ooo`80no_k0P3inOT20?ooo`80nOWi0P3kno/20?Win@80no_k0P3inOT60?_kn`80oooo0P3kno/?
0?ooo`003@3oool20?Gem@80n?Sh103kno/40?Shn0@0nOWi0P3kno/20?Win@@0no_k0P3jn_X40?gm
o@<0m_Kf103kno/20?[jnP80nOWi0P3oool60?Ogm`80no_k0P3`l?020>?Sh`80gmoO0P3De=@20?Ge
m@80j>SX0P3[jn/20>;RhP80kNg]0P3Zj^X20??cl`80`/;20P3clo<20>k^kP80inOW0P1aLG420;Zj
^PH0n?Sh0P3oool20?Shn0L0mOGe0P3bl_820?Gem@80lO7a0P3oool20?_kn`@0oooo0P3gmoL20>o_
k`80moOg0P3kno/20?Win@80n?Sh0P3inOT20?7al@80h^;R0P3alO420=?Cd`80h>3P0P3emOD20?_k
n`80l_;b0P3gmoL20>CTi080mOGe0P3Ng]h20::RXP80h>3P0P3=cLd30=7Ad@80W9bL0P2YZJT20=7A
d@80a<C40P3Ph>020<O7a`80gmoO0P3WinL20?Shn080kNg]0P3[jn/20?KfmP80l_;b0P3Hf=P20?Og
m`80e]KF0P3`l?020;6a/@@0hn?S0P3emOD20>GUi@80i^KV0P3Rh^820>o_k`80mOGe0P3EeMD20>?S
h`80moOg0P3hn?P20?gmo@<0moOg1P3oool20?_kn`80nOWi0P3oool20?Win@80no_k0P3inOT20?_k
n`80nOWi1P3kno/20?ooo`80no_k3`3oool000d0oooo0P3lo?`20?Ogm`@0nOWi103oool20?Ogm`80
n_[j0P3oool20?Win@H0no_k0P3oool20?[jnP<0o_kn0P3oool20?Win@80moOg0P3inOT20?ooo`80
moOg0P3kno/20?;blP80moOg0P3Shn<20?3`l080c<c<103Shn<20>c/k080j>SX0P3Zj^X20?Ogm`80
l?3`0P3YjNT20=CDe080fm_K0P3Ogml207emO@80UiNG0P3kno/20?Shn0@0oooo0P3kno/20?Gem@L0
l_;b0P3kno/20?;blP80lO7a0P3`l?020>c/k080l_;b0P3gmoL20?KfmP80m?Cd0P3`l?020?ooo`80
m_Kf0P3jn_X20?gmo@80nOWi0P3alO420>k^kP80k>c/0P3>c/h20=[JfP80jNWY0P3emOD20?;blP80
j^[Z0P3/k>`20>_[j`80`L710P2^[Zh20;^k^`<0fm_K0P3fm_H20<g=c@80i^KV0P3Cdm<20?Cdm080
dM7A0P3bl_820?[jnP80kNg]0P3alO420=SHf080d=3@0P3`l?020=?Cd`80lO7a103Kfm/20=[JfP80
_Kfm0P3jn_X20>?Sh`80jn_[0P3gmoL20>KViP80kno_0P3Kfm/20=KFeP80n_[j0P3dm?@20?Shn080
o?cl0`3fm_H20?ooo`80no_k0P3inOT20?_kn`80oooo0P3inOT40?ooo`80no_k0P3inOT20?_kn`80
nOWi103oool20?_kna40oooo000=0?ooo`80o?cl0P3gmoL40?Win@@0oooo0P3gmoL20?[jnP80oooo
0P3inOT60?_kn`80oooo0P3jn_X30?knoP80oooo0P3inOT20?Ogm`80nOWi0P3oool20?Ogm`80no_k
0P3bl_820?Ogm`80hn?S0P3`l?020<c<c0@0hn?S0P3/k>`20>SXj080j^[Z0P3gmoL20?3`l080jNWY
0P3De=@20=_Kf`80gmoO0P1mOGd209NGU`80no_k0P3hn?P40?ooo`80no_k0P3emOD70?;blP80no_k
0P3bl_820?7al@80l?3`0P3/k>`20?;blP80moOg0P3fm_H20?Cdm080l?3`0P3oool20?KfmP80n_[j
0P3moOd20?Win@80lO7a0P3^k^h20>c/k080c/k>0P3Jf]X20>WYj@80mOGe0P3bl_820>[ZjP80k>c/
0P3[jn/20<71`@80[Zj^0P2k^k/30=_Kf`80m_Kf0P3=cLd20>KViP80dm?C0P3dm?@20=7Ad@80l_;b
0P3jn_X20>g]k@80lO7a0P3Hf=P20=3@d080l?3`0P3Cdm<20?7al@@0fm_K0P3Jf]X20;fm_@80n_[j
0P3Shn<20>_[j`80moOg0P3Vi^H20>o_k`80fm_K0P3Fe]H20?[jnP80m?Cd0P3hn?P20?clo0<0m_Kf
0P3oool20?_kn`80nOWi0P3kno/20?ooo`80nOWi103oool20?_kn`80nOWi0P3kno/20?Win@@0oooo
0P3kno/A0?ooo`003@3oool20?Win@80no_k103inOT40?ooo`80nOWi0P3kno/20?ooo`H0nOWi0P3o
ool20?Win@L0oooo0P3gmoL20?KfmP80moOg0P3inOT40?_kn`80kno_0P3`l?020>WYj@80inOW0P38
b<P20>;RhP80i^KV0P3]kNd20>CTi080n?Sh0P3oool20=?Cd`80i^KV0P3gmoL20>OWi`80PX:20P2C
Ti<20?Shn0@0n_[j0P3dm?@20?KfmP80n?Sh0P3dm?@30>_[j`80inOW0P3Shn<20>7Qh@80g]kN0P3O
gml20>7Qh@80jn_[0P3]kNd20>CTi080iNGU0P3^k^h20?Ogm`80o_kn0P3gmoL20?Gem@80n?Sh0P3o
ool20?Shn0@0m?Cd0P3_knl20<K6aP80`/;20P3_knl20>[ZjP80o?cl0P3YjNT20?Ogm`80hn?S0P2k
^k/20>?Sh`<0dm?C0P3[jn/20=3@d080_kno0P3Jf]X20>?Sh`80eMGE0P3Rh^820>KViP80kNg]0P3Z
j^X20>o_k`80hn?S0P3Xj>P20?Ogm`80mOGe0P3_knl20>c/k080j^[Z0P2g]kL20>GUi@80d];B0P3f
m_H20?;blP80g=cL0P3WinL20=3@d080nOWi0P3kno/20?7al@@0o?cl0`3clo<40?_kn`80nOWi0P3g
moL20?Shn080no_k0P3inOT20?_kn`80oooo0P3kno/40?ooo`@0no_k0P3oool20?_kn`l0oooo000=
0?ooo`80nOWi0P3kno/40?Win@@0oooo0P3inOT20?_kn`80oooo1P3inOT20?ooo`80nOWi1`3oool2
0?Ogm`80m_Kf0P3gmoL20?Win@@0no_k0P3_knl20?3`l080jNWY0P3WinL20<S8b080h^;R0P3Vi^H2
0>g]k@80i>CT0P3hn?P20?ooo`80dm?C0P3Vi^H20?Ogm`80inOW0P22PX8209>CT`80n?Sh103jn_X2
0?Cdm080m_Kf0P3hn?P20?Cdm0<0jn_[0P3WinL20>?Sh`80hN7Q0P3Ng]h20=oOg`80hN7Q0P3[jn/2
0>g]k@80i>CT0P3UiND20>k^kP80moOg0P3no_h20?Ogm`80mOGe0P3hn?P20?ooo`80n?Sh103dm?@2
0>o_k`80a/K60P32`/820>o_k`80j^[Z0P3lo?`20>WYj@80moOg0P3Shn<20;^k^`80hn?S0`3Cdm<2
0>_[j`80d=3@0P2o_kl20=[JfP80hn?S0P3EeMD20>;RhP80i^KV0P3]kNd20>[ZjP80kno_0P3Shn<2
0>SXj080moOg0P3emOD20>o_k`80k>c/0P3Zj^X20;Ng]`80iNGU0P3Bd]820?KfmP80l_;b0P3Lg=`2
0>OWi`80d=3@0P3inOT20?_kn`80lO7a103lo?`30??cl`@0no_k0P3inOT20?Ogm`80n?Sh0P3kno/2
0?Win@80no_k0P3oool20?_kn`@0oooo103kno/20?ooo`80no_k3`3oool000l0oooo0P3kno/20?oo
o`80no_k0P3oool20?_kn`80oooo103kno/20?Win@H0no_k0P3oool50?_kn`80nOWi0P3no_h20?gm
o@80n?Sh0P3inOT20?ooo`80nOWi0P3_knl20>WYj@80mOGe103Jf]X20=gMg@80nOWi103Xj>P20?Cd
m080m_Kf0P3<c<`20?Cdm080k>c/0P1_Kfl206YZJP80nOWi0P3hn?P20?_kn`80nOWi0P3oool20?cl
o080m?Cd0P3/k>`50?7al@80k^k^0P3Vi^H40>GUi@@0jNWY0P3/k>`60?;blP80kno_0P3bl_840?oo
o`80m?Cd0P3oool20?Shn0@0nOWi0P3gmoL20?KfmP80g=cL0P3<c<`20>[ZjP80m_Kf0P3[jn/20>GU
i@80gmoO0P3@d=020;Ng]`<0g]kN0P3@d=020;2`/080d];B0P3[jn/20;:b/P80g]kN0P3Lg=`20>g]
k@80lO7a0P3Zj^X20>;RhP80l_;b0P3Bd]820?3`l080inOW0P3oool20>7Qh@80i^KV0P33`l<20>;R
hP80n?Sh0P3gmoL20>o_k`80hN7Q0P3WinL20<[:bP80m?Cd0P3/k>`40?_kn`80n?Sh1`3kno/20?gm
o@80oooo0P3gmoL20?_kn`80nOWi203kno/80?ooo`80no_k3`3oool000l0oooo0P3kno/20?ooo`80
no_k0P3oool20?_kn`80oooo103kno/20?Win@H0no_k0P3oool50?_kn`80nOWi0P3no_h20?gmo@80
n?Sh0P3inOT20?ooo`80nOWi0P3_knl20>WYj@80mOGe103Jf]X20=gMg@80nOWi103Xj>P20?Cdm080
m_Kf0P3<c<`20?Cdm080k>c/0P1_Kfl206YZJP80nOWi0P3hn?P20?_kn`80nOWi0P3oool20?clo080
m?Cd0P3/k>`50?7al@80k^k^0P3Vi^H40>GUi@@0jNWY0P3/k>`60?;blP80kno_0P3bl_840?ooo`80
m?Cd0P3oool20?Shn0@0nOWi0P3gmoL20?KfmP80g=cL0P3<c<`20>[ZjP80m_Kf0P3[jn/20>GUi@80
gmoO0P3@d=020;Ng]`<0g]kN0P3@d=020;2`/080d];B0P3[jn/20;:b/P80g]kN0P3Lg=`20>g]k@80
lO7a0P3Zj^X20>;RhP80l_;b0P3Bd]820?3`l080inOW0P3oool20>7Qh@80i^KV0P33`l<20>;RhP80
n?Sh0P3gmoL20>o_k`80hN7Q0P3WinL20<[:bP80m?Cd0P3/k>`40?_kn`80n?Sh1`3kno/20?gmo@80
oooo0P3gmoL20?_kn`80nOWi203kno/80?ooo`80no_k3`3oool000l0oooo103inOT20?ooo`80no_k
0P3oool20?_kn`H0oooo103inOT90?ooo`@0no_k0P3no_h60?Win@80no_k0P3WinL20>[ZjP80n?Sh
0P3<c<`20=;BdP80hN7Q0P3]kNd20?7al@80g=cL0P3fm_H20=kNgP80inOW0P3fm_H20>[ZjP80EEEE
0P3jn_X20?Shn0@0m_Kf0P3kno/20?ooo`80m?Cd0P32`/820;>c/`<0`<300P3Bd]820>7Qh@80k^k^
1P3dm?@20>3Ph080b/[:1036a/H20<k>cP80moOg0P3fm_H20?Ogm`80oooo0P3hn?P20?Ogm`80nOWi
0P3hn?P20?Gem@@0moOg0P3^k^h20=7Ad@80_Kfm0P3bl_820>[ZjP@0iNGU0P3<c<`20;Zj^P<0moOg
0P2k^k/20<O7a`80mOGe0P3Shn<20>OWi`80`/;20P3AdM420>o_k`80lo?c0P3/k>`20?Ogm`80i^KV
0P3GemL20?Ogm`80lO7a0P3]kNd20??cl`80hn?S0P3^k^h20=kNgP80m?Cd0P3_knl20?Gem@80hN7Q
0P3Ti>@20>7Qh@80lO7a0P3fm_H20?Shn080moOg0P3fm_H30?knoP80oOgm0P3gmoL40?gmo@80no_k
0P3oool20?_kn`80oooo103kno/20?ooo`80no_k0P3oool40?_kna40oooo000?0?ooo`@0nOWi0P3o
ool20?_kn`80oooo0P3kno/60?ooo`@0nOWi2@3oool40?_kn`80o_kn1P3inOT20?_kn`80inOW0P3Z
j^X20?Shn080c<c<0P3Bd]820>7Qh@80kNg]0P3alO420=cLg080m_Kf0P3Ng]h20>OWi`80m_Kf0P3Z
j^X205EEE@80n_[j0P3hn?P40?KfmP80no_k0P3oool20?Cdm080`/;20P2c/k<30<30`080d];B0P3Q
hN420>k^kPH0m?Cd0P3Ph>020<[:bP@0a/K60P3>c/h20?Ogm`80m_Kf0P3gmoL20?ooo`80n?Sh0P3g
moL20?Win@80n?Sh0P3emOD40?Ogm`80k^k^0P3AdM420;fm_@80l_;b0P3Zj^X40>GUi@80c<c<0P2j
^[X30?Ogm`80^k^k0P37alL20?Gem@80hn?S0P3WinL20<;2`P80dM7A0P3_knl20??cl`80k>c/0P3g
moL20>KViP80emOG0P3gmoL20?7al@80kNg]0P3clo<20>?Sh`80k^k^0P3Ng]h20?Cdm080kno_0P3e
mOD20>7Qh@80i>CT0P3QhN420?7al@80m_Kf0P3hn?P20?Ogm`80m_Kf0`3no_h20?gmo@80moOg103m
oOd20?_kn`80oooo0P3kno/20?ooo`@0no_k0P3oool20?_kn`80oooo103kno/A0?ooo`003`3oool4
0?Win@80no_k103oool20?_kn`H0oooo103inOT20?ooo`80no_k0P3gmoL30?Win@80oooo0P3inOT2
0?[jnP80m_Kf0P3oool20?knoP80lo?c0P3[jn/20??cl`80hN7Q0P3:b/X20=OGe`@0kNg]0P3emOD2
0=kNgP80oOgm0P3UiND20?Ogm`80kno_0P1cLg<208B4Q0H0oooo103kno/20=GEe@80a/K60P3GemL2
0>KViP<0][Jf0P2g]kL20=KFeP80m?Cd0P3Ti>@20=7Ad@80fMWI0P3YjNT20>CTi080j^[Z0P3`l?02
0>;RhP80c/k>0P3alO420?Ogm`80n?Sh0P3oool20?Cdm080o_kn0P3jn_X20?7al@80nOWi103clo<2
0?KfmP80`<300P2l_;`20>GUi@80l_;b0P3clo<20<K6aP80bLW90`20P8020=cLg080d=3@0P2c/k<2
0<o?c`80fm_K0P3YjNT20=KFeP80j^[Z0P3Rh^820=oOg`80nOWi0P3YjNT20>SXj080jn_[0P3dm?@2
0>;RhP80m?Cd0P3Xj>P20?Ogm`80a/K60P3Ogml20>CTi080lO7a0P3QhN420=;BdP80i>CT0P3/k>`2
0?_kn`80n?Sh0P3alO420?Gem@<0oooo0P3kno/20?gmo@H0nOWi0P3kno/20?Win@80oooo103kno/2
0?ooo`H0no_k0P3inOT20?_kn`l0oooo000?0?ooo`@0nOWi0P3kno/40?ooo`80no_k1P3oool40?Wi
n@80oooo0P3kno/20?Ogm`<0nOWi0P3oool20?Win@80n_[j0P3fm_H20?ooo`80o_kn0P3clo<20>_[
j`80lo?c0P3QhN420<[:bP80emOG103]kNd20?Gem@80g]kN0P3moOd20>GUi@80moOg0P3_knl207=c
L`80Q8B41P3oool40?_kn`80eMGE0P36a/H20=OGe`80i^KV0`2f][H20;Ng]`80e]KF0P3dm?@20>CT
i080dM7A0P3IfMT20>WYj@80i>CT0P3Zj^X20?3`l080h^;R0P3>c/h20?7al@80moOg0P3hn?P20?oo
o`80m?Cd0P3no_h20?[jnP80lO7a0P3inOT40??cl`80m_Kf0P30`<020;bl_080iNGU0P3bl_820??c
l`80a/K60P39bLT30820P080g=cL0P3@d=020;>c/`80clo?0P3Kfm/20>WYj@80e]KF0P3Zj^X20>;R
hP80gmoO0P3inOT20>WYj@80j>SX0P3[jn/20?Cdm080h^;R0P3dm?@20>SXj080moOg0P36a/H20=oO
g`80i>CT0P3alO420>7Qh@80d];B0P3Ti>@20>c/k080no_k0P3hn?P20?7al@80mOGe0`3oool20?_k
n`80oOgm1P3inOT20?_kn`80nOWi0P3oool40?_kn`80oooo1P3kno/20?Win@80no_k3`3oool000d0
oooo0P3inOT<0?ooo`@0no_k0P3inOT40?ooo`80nOWi0P3kno/20?knoP<0n_[j103inOT20?Ogm`80
oooo103fm_H20>7Qh@80inOW0P3Cdm<20<G5a@80fMWI0P3Shn<20=OGe`80jNWY0P3[jn/20?[jnP80
hN7Q0P3Ng]h20?Ogm`80^;Rh0P1[Jf/20?_kn`80n?Sh0P3jn_X20?knoP@0n_[j0P2j^[X20?Gem@80
oooo0P3inOT30<G5a@80[jn_0P39bLT20>[ZjP80f=SH0P2b/[820;6a/@80d=3@0P3Hf=P20>CTi080
iNGU0P3jn_X20=oOg`80`<30103gmoL20?ooo`80n?Sh0P3dm?@20?Ogm`80m?Cd103gmoL20??cl`80
l_;b0P3WinL20<30`080/K6a0P3Vi^H20>;RhP80`<300P3alO4308Z:RP80dm?C0P2m_Kd20<C4a080
l_;b0P3emOD20=gMg@80d];B0P2o_kl40>c/k080h>3P0P3UiND20>CTi080j>SX0P3oool20?;blP80
lo?c0P3MgMd20?Shn080a/K6103YjNT20?clo080i^KV0P2f][H20?ooo`80m_Kf0P3jn_X20?_kn`80
k>c/0P3oool30?Shn080moOg0P3inOT40?_kn`@0oooo0P3inOT20?_kn`80oooo103kno/20?ooo`80
no_k0P3inOT40?_kn`l0oooo000=0?ooo`80nOWi303oool40?_kn`80nOWi103oool20?Win@80no_k
0P3no_h30?[jnP@0nOWi0P3gmoL20?ooo`@0m_Kf0P3QhN420>OWi`80dm?C0P35aLD20=WIf@80hn?S
0P3GemL20>WYj@80jn_[0P3jn_X20>7Qh@80g]kN0P3gmoL20;Rh^080Jf][0P3kno/20?Shn080n_[j
0P3no_h40?[jnP80^[Zj0P3emOD20?ooo`80nOWi0`35aLD20:n_[`80bLW90P3Zj^X20=SHf080/[:b
0P2a/K420=3@d080f=SH0P3Ti>@20>GUi@80n_[j0P3Ogml20<30`0@0moOg0P3oool20?Shn080m?Cd
0P3gmoL20?Cdm0@0moOg0P3clo<20?;blP80inOW0P30`<020;6a/@80i^KV0P3Rh^820<30`080lO7a
0`2:RXX20=?Cd`80_Kfm0P34a<@20?;blP80mOGe0P3MgMd20=;BdP80_kno103/k>`20>3Ph080iNGU
0P3Ti>@20>SXj080oooo0P3bl_820??cl`80gMgM0P3hn?P20<K6aP@0jNWY0P3lo?`20>KViP80][Jf
0P3oool20?KfmP80n_[j0P3kno/20>c/k080oooo0`3hn?P20?Ogm`80nOWi103kno/40?ooo`80nOWi
0P3kno/20?ooo`@0no_k0P3oool20?_kn`80nOWi103kno/?0?ooo`003@3oool20?Win@H0no_k0P3i
nOT20?_kn`@0oooo0P3kno/20?ooo`@0nOWi103oool20?_kn`<0nOWi0P3kno/20?knoP80moOg0P3k
no/40?[jnP80fm_K0P3[jn/20=;BdP80j>SX103Ng]h20=CDe080lO7a0P3/k>`20>3Ph080inOW0P3c
lo<20=kNgP80Jf][0P2e]KD20?ooo`@0n_[j0P3no_h20=KFeP80_kno0P2b/[820<;2`P80[Jf]0P2m
_Kd30=SHf080fm_K0P3AdM420<c<c080cLg=0P3AdM420<?3``80b<S80P3De=@20:f][@80X:2P0P2m
_Kd20;no_`80X:2P0P2ZZZX20=cLg0@0oooo103gmoL20?Shn080l?3`0P3oool20?Ogm`80m?Cd0P3V
i^H20>[ZjP80]kNg0P3Bd]820=_Kf`80d=3@0P3IfMT30<C4a080aLG50P3YjNT20=GEe@80[Zj^0P3;
bl/20<c<c080dm?C0P3@d=020:f][@80g]kN0P3Ti>@20?knoP80k^k^0P3UiND20?Gem@80iNGU0P3M
gMd20=kNgP80o_kn0P3Ng]h20=_Kf`80jNWY0P3Xj>P20=gMg@80`/;20P3dm?@40?gmo@80mOGe0P3i
nOT20?Ogm`<0oooo303kno/:0?ooo`P0no_k4@3oool000d0oooo0P3inOT60?_kn`80nOWi0P3kno/4
0?ooo`80no_k0P3oool40?Win@@0oooo0P3kno/30?Win@80no_k0P3no_h20?Ogm`80no_k103jn_X2
0=_Kf`80jn_[0P3Bd]820>SXj0@0g]kN0P3De=@20?7al@80k>c/0P3Ph>020>OWi`80lo?c0P3Ng]h2
06][J`80]KFe0P3oool40?[jnP80o_kn0P3Fe]H20;no_`80/[:b0P32`/820:f][@80_Kfm0`3Hf=P2
0=_Kf`80dM7A0P3<c<`20<g=c@80dM7A0P33`l<20<S8b080e=CD0P2][Jd20:2PX080_Kfm0P2o_kl2
0:2PX080ZZZZ0P3Lg=`40?ooo`@0moOg0P3hn?P20?3`l080oooo0P3gmoL20?Cdm080i^KV0P3Zj^X2
0;Ng]`80d];B0P3Kfm/20=3@d080fMWI0`34a<@20<G5a@80jNWY0P3EeMD20:j^[P80bl_;0P3<c<`2
0=?Cd`80d=3@0P2][Jd20=kNgP80i>CT0P3no_h20>k^kP80iNGU0P3emOD20>GUi@80gMgM0P3Ng]h2
0?knoP80g]kN0P3Kfm/20>WYj@80j>SX0P3MgMd20<;2`P80m?Cd103moOd20?Gem@80nOWi0P3gmoL3
0?ooo``0no_k2P3oool80?_kna40oooo000=0?ooo`H0nOWi203kno/20?ooo`@0no_k103oool40?_k
n`80oooo0`3inOT20?_kn`80oooo0P3kno/20?Win@80o_kn0P3gmoL20>?Sh`80h^;R0P3=cLd20=oO
g`80clo?0P3Jf]X20?Shn080o_kn0P3^k^h20>[ZjP80jNWY0P3Zj^X206QXJ080TI6A0P3jn_X20?_k
n`80nOWi0P3hn?P20?knoP80eMGE0P37alL20;6a/@80^KVi0P38b<P20=kNgPD0jNWY0P3UiND20=KF
eP80eMGE0P3MgMd20<S8b080aLG50P3De=@20<K6aP80WIfM0P2@T9020861P@80Q8B40P2/[:`20=_K
f`80oooo0P3jn_X20?Win@@0oOgm0P3^k^h20?Ogm`@0oooo0P3YjNT20>OWi`80d=3@0P2RXZ820=oO
g`80fm_K0P3=cLd30=WIf@@0b<S80P2j^[X20>SXj080k>c/0P3oool20;bl_080lO7a0P3Jf]X20<;2
`P80lO7a0P3Xj>P20?7al@80kNg]0P3moOd20>_[j`80`L710P3_knl20>g]k@80n?Sh0P3<c<`20>KV
iP80kNg]0P38b<P20=?Cd`80mOGe103jn_X20?Gem@80no_k1@3inOT20?ooo`X0no_k0P3oool40?_k
n`80oooo0P3kno/20?ooo`80no_k103inOTA0?ooo`003@3oool60?Win@P0no_k0P3oool40?_kn`@0
oooo103kno/20?ooo`<0nOWi0P3kno/20?ooo`80no_k0P3inOT20?knoP80moOg0P3Shn<20>;RhP80
cLg=0P3Ogml20<o?c`80f][J0P3hn?P20?knoP80k^k^0P3Zj^X20>WYj@80j^[Z0P1XJ6P2096AT@80
n_[j0P3kno/20?Win@80n?Sh0P3no_h20=GEe@80alO70P2a/K420;Vi^@80b<S80P3Ng]h50>WYj@80
iNGU0P3Fe]H20=GEe@80gMgM0P38b<P20<G5a@80e=CD0P36a/H209fMW@80T92@0P21PH4208B4Q080
[:b/0P3Kfm/20?ooo`80n_[j0P3inOT40?gmo@80k^k^0P3gmoL40?ooo`80jNWY0P3WinL20=3@d080
XZ:R0P3Ogml20=_Kf`80cLg=0`3IfMT40<S8b080^[Zj0P3Xj>P20>c/k080oooo0P2l_;`20?7al@80
f][J0P32`/820?7al@80j>SX0P3alO420>g]k@80oOgm0P3[jn/20<71`@80kno_0P3]kNd20?Shn080
c<c<0P3Vi^H20>g]k@80b<S80P3Cdm<20?Gem@@0n_[j0P3emOD20?_kn`D0nOWi0P3oool:0?_kn`80
oooo103kno/20?ooo`80no_k0P3oool20?_kn`@0nOWi4@3oool000d0oooo0P3inOT20?_kn`80oooo
0P3inOT20?_kn`80oooo0P3inOT20?_kn`P0nOWi1P3kno/30?Win@@0n_[j1P3kno/20??cl`80i>CT
0P3Hf=P20<O7a`80f=SH0P3[jn/20>?Sh`80oooo0P3alO420??cl`80n?Sh0P3moOd20?Ogm`80CTi>
0P3inOT20?knoP80o?cl0P3inOT20?clo080n_[j0P3clo<20>_[j`80cLg=0P2RXZ8208^;R`80RHV9
0`2BTY8408V9R@80Y:BT0P2HV9P207emO@80PX:20P2<S8`209:BTP80W9bL0P2c/k<20=kNgP80j>SX
0P3^k^h20??cl`80moOg0P3oool20?Win@80n_[j0P3kno/20?gmo@80m_Kf103gmoL20?knoP80m?Cd
0P3clo<20=WIf@80/[:b0P32`/820>WYj@80/;2`0`3]kNd20=OGe`80^[Zj0P3Hf=P20<O7a`80_kno
0P3@d=020;>c/`80cLg=0P3`l?020:j^[P80fMWI0P3alO420>[ZjP80jn_[0P3/k>`20>k^kP80f][J
0P3Xj>P20=GEe@80moOg0P33`l<20>o_k`80i>CT0P2[Zj/20>k^kP80o_kn103oool20>k^kP@0nOWi
0`3kno/20?Win@H0oooo1P3kno/40?ooo`P0no_k0P3oool20?_kna40oooo000=0?ooo`80nOWi0P3k
no/20?ooo`80nOWi0P3kno/20?ooo`80nOWi0P3kno/80?Win@H0no_k0`3inOT40?[jnPH0no_k0P3c
lo<20>CTi080f=SH0P37alL20=SHf080jn_[0P3Shn<20?ooo`80lO7a0P3clo<20?Shn080oOgm0P3g
moL204i>CP80nOWi0P3no_h20?clo080nOWi0P3lo?`20?[jnP80lo?c0P3[jn/20<g=c@80XZ:R0P2;
Rh/208V9R@<0TY:B1029RHT20:BTY080V9RH0P1mOGd208:2PP80S8b<0P2BTY8209bLW080/k>c0P3N
g]h20>SXj080k^k^0P3clo<20?Ogm`80oooo0P3inOT20?[jnP80no_k0P3moOd20?KfmP@0moOg0P3n
o_h20?Cdm080lo?c0P3IfMT20;:b/P80`/;20P3YjNT20;2`/0<0kNg]0P3GemL20;Zj^P80f=SH0P37
alL20;no_`80d=3@0P2c/k<20<g=c@80l?3`0P2^[Zh20=WIf@80lO7a0P3Zj^X20>_[j`80k>c/0P3^
k^h20=[JfP80j>SX0P3EeMD20?Ogm`80`l?30P3_knl20>CTi080Zj^[0P3^k^h20?knoP@0oooo0P3^
k^h40?Win@<0no_k0P3inOT60?ooo`H0no_k103oool80?_kn`80oooo0P3kno/A0?ooo`003@3oool2
0?Win@80oooo0P3inOT>0?_kn`@0nOWi0P3kno/20?Win@80no_k0`3oool20?Ogm`80no_k0P3jn_X2
0?_kn`80n_[j0P3Jf]X20=gMg@80dM7A0P36a/H20=gMg@80i^KV0P3UiND20?7al@80iNGU0P3alO42
0?Shn080nOWi0P2DU9@208J6QP@0n_[j0P3moOd20?_kn`H0o?cl0P3gmoL20?ooo`80n?Sh0P3jn_X2
0?Shn0<0l?3`0P3alO420>c/k080oooo0P3gmoL20?3`l080i>CT0P3[jn/20?3`l080n_[j103hn?P2
0?_kn`80l?3`0P3bl_820?knoP@0n_[j0P3hn?P40?clo080n?Sh0P3oool40??cl`80moOg0P3oool2
0=gMg@80b/[:0P2j^[X20>KViP80[:b/0`3inOT20<S8b080hn?S0P3>c/h20;fm_@80fm_K0P3[jn/2
0>?Sh`80`l?30P3clo<20>7Qh@80d=3@0P3Ng]h20>k^kP80hn?S0P3moOd20=kNgP80emOG0P3Vi^H2
0<[:bP80moOg0P3:b/X20?3`l080h^;R0P2IVIT20?KfmP80moOg0P3fm_H20?Shn080l?3`103oool5
0?Win@80oooo0P3kno/40?Win@X0no_k103oool40?_kn`80oooo0P3kno/?0?ooo`003@3oool20?Wi
n@80oooo0P3inOT>0?_kn`@0nOWi0P3kno/20?Win@80no_k0`3oool20?Ogm`80no_k0P3jn_X20?_k
n`80n_[j0P3Jf]X20=gMg@80dM7A0P36a/H20=gMg@80i^KV0P3UiND20?7al@80iNGU0P3alO420?Sh
n080nOWi0P2DU9@208J6QP@0n_[j0P3moOd20?_kn`H0o?cl0P3gmoL20?ooo`80n?Sh0P3jn_X20?Sh
n0<0l?3`0P3alO420>c/k080oooo0P3gmoL20?3`l080i>CT0P3[jn/20?3`l080n_[j103hn?P20?_k
n`80l?3`0P3bl_820?knoP@0n_[j0P3hn?P40?clo080n?Sh0P3oool40??cl`80moOg0P3oool20=gM
g@80b/[:0P2j^[X20>KViP80[:b/0`3inOT20<S8b080hn?S0P3>c/h20;fm_@80fm_K0P3[jn/20>?S
h`80`l?30P3clo<20>7Qh@80d=3@0P3Ng]h20>k^kP80hn?S0P3moOd20=kNgP80emOG0P3Vi^H20<[:
bP80moOg0P3:b/X20?3`l080h^;R0P2IVIT20?KfmP80moOg0P3fm_H20?Shn080l?3`103oool50?Wi
n@80oooo0P3kno/40?Win@X0no_k103oool40?_kn`80oooo0P3kno/?0?ooo`003`3oool20?Win@80
no_k1P3inOT20?ooo`80o_kn0P3inOT20?ooo`@0no_k0P3inOT20?_kn`80oooo0`3kno/20?Win@80
o_kn0P3oool20?knoP80moOg0P3Bd]820=SHf080`/;20P39bLT20?Gem@80g]kN0P3hn?P20>SXj080
nOWi0P3Zj^X20?ooo`80n_[j0P1FEUH20>SXj0@0no_k0P3lo?`20?ooo`80n_[j0P3fm_H40?Ogm`80
oooo2@3jn_X20?Win@80l?3`0P3oool40?knoP80k>c/0P3kno/20?Ogm`H0n?Sh0P3alO420?_kn`80
oooo0P3alO420?_kn`80mOGe0P3jn_X20?_kn`80m_Kf0P3hn?P20?Win@80oOgm0P3Zj^X20?Ogm`80
oooo0P3Ti>@20=3@d080/k>c0P3GemL20>_[j`<0`l?30P3?cll20=KFeP80a/K60P3Jf]X20>KViP80
b/[:0P3WinL20<[:bP80fMWI0P3fm_H20<o?c`80kNg]0P3Zj^X20?Win@80hN7Q0P3[jn/20?7al@80
dm?C0P3Lg=`20>OWi`80f=SH0P3emOD20?Cdm080ZJVY0P3`l?020?Ogm`80nOWi0P3Ti>@20?knoP80
no_k0P3oool50?Win@80no_k0P3oool40?Win@H0no_k103oool20?_kn`80nOWi0P3kno/40?ooo`80
no_k3`3oool000l0oooo0P3inOT20?_kn`H0nOWi0P3oool20?knoP80nOWi0P3oool40?_kn`80nOWi
0P3kno/20?ooo`<0no_k0P3inOT20?knoP80oooo0P3no_h20?Ogm`80d];B0P3Hf=P20<;2`P80bLW9
0P3emOD20=kNgP80n?Sh0P3Xj>P20?Win@80j^[Z0P3oool20?[jnP80EUIF0P3Xj>P40?_kn`80o?cl
0P3oool20?[jnP80m_Kf103gmoL20?ooo`T0n_[j0P3inOT20?3`l080oooo103no_h20>c/k080no_k
0P3gmoL60?Shn080lO7a0P3kno/20?ooo`80lO7a0P3kno/20?Gem@80n_[j0P3kno/20?KfmP80n?Sh
0P3inOT20?gmo@80j^[Z0P3gmoL20?ooo`80i>CT0P3@d=020;>c/`80emOG0P3[jn/30<?3``80clo?
0P3Fe]H20<K6aP80f][J0P3Vi^H20<[:bP80inOW0P3:b/X20=WIf@80m_Kf0P3?cll20>g]k@80j^[Z
0P3inOT20>7Qh@80jn_[0P3alO420=?Cd`80g=cL0P3WinL20=SHf080mOGe0P3dm?@20:VYZ@80l?3`
0P3gmoL20?Win@80i>CT0P3no_h20?_kn`80oooo1@3inOT20?_kn`80oooo103inOT60?_kn`@0oooo
0P3kno/20?Win@80no_k103oool20?_kn`l0oooo000?0?ooo`80nOWi0P3kno/60?Win@80oooo0P3n
o_h20?Win@80oooo103kno/20?Win@80no_k0P3oool30?_kn`80nOWi0P3no_h20?ooo`80o_kn0P3g
moL20=;BdP80f=SH0P32`/820<W9b@80mOGe0P3Ng]h20?Shn080j>SX0P3inOT20>[ZjP80oooo0P3j
n_X205IFEP80j>SX103kno/20?clo080oooo0P3jn_X20?KfmP@0moOg0P3oool90?[jnP80nOWi0P3`
l?020?ooo`@0o_kn0P3/k>`20?_kn`80moOg1P3hn?P20?7al@80no_k0P3oool20?7al@80no_k0P3e
mOD20?[jnP80no_k0P3fm_H20?Shn080nOWi0P3moOd20>[ZjP80moOg0P3oool20>CTi080d=3@0P2c
/k<20=OGe`80jn_[0`33`l<20<o?c`80e]KF0P36a/H20=[JfP80i^KV0P3:b/X20>OWi`80b/[:0P3I
fMT20?KfmP80clo?0P3]kNd20>[ZjP80nOWi0P3QhN420>_[j`80lO7a0P3Cdm<20=cLg080inOW0P3H
f=P20?Gem@80m?Cd0P2YZJT20?3`l080moOg0P3inOT20>CTi080o_kn0P3kno/20?ooo`D0nOWi0P3k
no/20?ooo`@0nOWi1P3kno/40?ooo`80no_k0P3inOT20?_kn`@0oooo0P3kno/?0?ooo`003@3oool2
0?Win@@0oooo0P3kno/20?ooo`@0no_k0P3inOT20?knoP80no_k103oool=0?_kn`80o_kn0P3oool2
0=oOg`80e]KF0P31`L420=KFeP80iNGU0P3Xj>P20?3`l080jNWY0P3lo?`20?[jnP80j^[Z0P3moOd2
0?3`l080?clo103kno/20?Win@80o?cl0P3kno/20?Win@80oooo103moOd40?ooo`@0oOgm0`3oool2
0?KfmP80nOWi0P3alO440?;blP80k>c/0P3dm?@20?Shn080moOg0P3inOT20?gmo@80lO7a0P3^k^h2
0?Cdm080oOgm0P3/k>`20>g]k@80n?Sh0P3oool20?Win@80m_Kf0P3inOT20?gmo@80m_Kf0P3alO44
0??cl`80gMgM0P31`L420=_Kf`80kNg]0`30`<020>[ZjP80jNWY0P3alO420>3Ph080g]kN0P3[jn/2
0=SHf080alO70P3GemL20<o?c`80kNg]0P3EeMD20=?Cd`80m?Cd0P3Hf=P20=GEe@80hn?S0P3De=@2
0?Gem@80g=cL0P3UiND20=_Kf`80c<c<0P3>c/h20>[ZjP80o_kn0P3_knl20>?Sh`80oooo0P3kno/2
0?ooo`L0no_k0P3oool20?_kn`@0oooo103inOT60?_kn`80nOWi0P3kno/E0?ooo`003@3oool20?Wi
n@@0oooo0P3kno/20?ooo`@0no_k0P3inOT20?knoP80no_k103oool=0?_kn`80o_kn0P3oool20=oO
g`80e]KF0P31`L420=KFeP80iNGU0P3Xj>P20?3`l080jNWY0P3lo?`20?[jnP80j^[Z0P3moOd20?3`
l080?clo103kno/20?Win@80o?cl0P3kno/20?Win@80oooo103moOd40?ooo`@0oOgm0`3oool20?Kf
mP80nOWi0P3alO440?;blP80k>c/0P3dm?@20?Shn080moOg0P3inOT20?gmo@80lO7a0P3^k^h20?Cd
m080oOgm0P3/k>`20>g]k@80n?Sh0P3oool20?Win@80m_Kf0P3inOT20?gmo@80m_Kf0P3alO440??c
l`80gMgM0P31`L420=_Kf`80kNg]0`30`<020>[ZjP80jNWY0P3alO420>3Ph080g]kN0P3[jn/20=SH
f080alO70P3GemL20<o?c`80kNg]0P3EeMD20=?Cd`80m?Cd0P3Hf=P20=GEe@80hn?S0P3De=@20?Ge
m@80g=cL0P3UiND20=_Kf`80c<c<0P3>c/h20>[ZjP80o_kn0P3_knl20>?Sh`80oooo0P3kno/20?oo
o`L0no_k0P3oool20?_kn`@0oooo103inOT60?_kn`80nOWi0P3kno/E0?ooo`003`3oool60?_kn`80
nOWi0P3kno/40?ooo`80no_k0P3oool20?_kn`H0oooo0P3kno/50?Win@80oooo0P3inOT20?Gem@80
e=CD0P3Kfm/20=;BdP80d=3@0P3]kNd20>OWi`80m_Kf0P3YjNT20?3`l0@0j^[Z0P3`l?020<S8b080
IVIV0P3jn_X20?ooo`80moOg0P3moOd40?ooo`@0n?Sh103moOd20?ooo`80oOgm0P3jn_X30?Cdm080
jNWY0P3UiND20>;RhP80hn?S0P3YjNT60?7al@80n?Sh0P3lo?`20?Ogm`80nOWi0P3lo?`20>o_k`H0
m?Cd0P3moOd20?Shn080o?cl0P3fm_H20?ooo`80lo?c0P3oool20??cl`80jn_[0P3alO420>OWi`80
c<c<0P34a<@20>CTi0<0i^KV0P3Hf=P20>[ZjP80hN7Q0P3Xj>P20?3`l080f][J0P3]kNd20<o?c`80
`<300P3Cdm<20??cl`80h>3P0P3AdM420>g]k@80d];B0P3Ogml20?3`l080i^KV0P3lo?`20=KFeP80
jn_[0P3Cdm<20:RXZ080m_Kf0P3EeMD20?Ogm`80l_;b0P3alO420?_kn`L0oooo203kno/40?ooo`80
no_k0P3oool20?_kn`80nOWi0P3oool40?_knaD0oooo000?0?ooo`H0no_k0P3inOT20?_kn`@0oooo
0P3kno/20?ooo`80no_k1P3oool20?_kn`D0nOWi0P3oool20?Win@80mOGe0P3De=@20=_Kf`80d];B
0P3@d=020>g]k@80inOW0P3fm_H20>WYj@80l?3`103Zj^X20?3`l080b<S80P1VIVH20?[jnP80oooo
0P3gmoL20?gmo@@0oooo103hn?P40?gmo@80oooo0P3moOd20?[jnP<0m?Cd0P3YjNT20>GUi@80h^;R
0P3Shn<20>WYj@H0lO7a0P3hn?P20?clo080moOg0P3inOT20?clo080kno_1P3dm?@20?gmo@80n?Sh
0P3lo?`20?KfmP80oooo0P3clo<20?ooo`80lo?c0P3[jn/20?7al@80inOW0P3<c<`20<C4a080i>CT
0`3Vi^H20=SHf080j^[Z0P3QhN420>SXj080l?3`0P3Jf]X20>g]k@80clo?0P30`<020=?Cd`80lo?c
0P3Ph>020=7Ad@80kNg]0P3Bd]820=oOg`80l?3`0P3Vi^H20?clo080e]KF0P3[jn/20=?Cd`80Z:RX
0P3fm_H20=GEe@80moOg0P3bl_820?7al@80no_k1`3oool80?_kn`@0oooo0P3kno/20?ooo`80no_k
0P3inOT20?ooo`@0no_k5@3oool000d0oooo0P3inOT20?_kn`P0oooo203kno/20?Win@80oooo1P3k
no/30?Win@80n_[j0P3gmoL20?_kn`80mOGe103;bl/20=?Cd`80clo?103Ti>@20>GUi@80l_;b0P3Y
jNT20?7al@80o_kn0P3UiND2069RHP80_[jn103moOd20?Ogm`H0oooo103jn_X40?_kn`@0oooo1@3d
m?@20>c/k080no_k0P3]kNd20?3`l080m?Cd0P3`l?020?7al@80m?Cd103fm_H20?Shn080n_[j0P3h
n?P20?Cdm080o_kn0P3dm?@20?Gem@80m?Cd0P3/k>`20?Gem@80m_Kf0P3jn_X20??cl`80oooo0P3n
o_h20>[ZjP80lO7a0P3YjNT20=OGe`80bLW90P3EeMD30<W9b@80b/[:0P3clo<20=WIf@80hN7Q103F
e]H20>g]k@80h>3P0P21PH420=OGe`80g=cL0P3Cdm<20<71`@80oooo0P3Zj^X20>o_k`80kNg]0P3_
knl20>WYj@80clo?0P3fm_H20=_Kf`80aLG50P3dm?@20>7Qh@80g]kN0P3Kfm/;0?ooo`@0nOWi2P3o
ool20?_kn`80nOWi0P3kno/20?ooo`@0nOWi5@3oool000d0oooo0P3inOT20?_kn`P0oooo203kno/2
0?Win@80oooo1P3kno/30?Win@80n_[j0P3gmoL20?_kn`80mOGe103;bl/20=?Cd`80clo?103Ti>@2
0>GUi@80l_;b0P3YjNT20?7al@80o_kn0P3UiND2069RHP80_[jn103moOd20?Ogm`H0oooo103jn_X4
0?_kn`@0oooo1@3dm?@20>c/k080no_k0P3]kNd20?3`l080m?Cd0P3`l?020?7al@80m?Cd103fm_H2
0?Shn080n_[j0P3hn?P20?Cdm080o_kn0P3dm?@20?Gem@80m?Cd0P3/k>`20?Gem@80m_Kf0P3jn_X2
0??cl`80oooo0P3no_h20>[ZjP80lO7a0P3YjNT20=OGe`80bLW90P3EeMD30<W9b@80b/[:0P3clo<2
0=WIf@80hN7Q103Fe]H20>g]k@80h>3P0P21PH420=OGe`80g=cL0P3Cdm<20<71`@80oooo0P3Zj^X2
0>o_k`80kNg]0P3_knl20>WYj@80clo?0P3fm_H20=_Kf`80aLG50P3dm?@20>7Qh@80g]kN0P3Kfm/;
0?ooo`@0nOWi2P3oool20?_kn`80nOWi0P3kno/20?ooo`@0nOWi5@3oool000d0oooo0P3inOT20?_k
n`P0oooo0P3kno/40?ooo`80nOWi103kno/20?ooo`80no_k1@3oool40?Win@80no_k0P3emOD20;Vi
^@80a<C40P3>c/h20=cLg080k>c/0P3Zj^X20>o_k`@0k^k^0P3bl_820>[ZjP80i^KV0P0b<S820?oo
o`@0o?cl0P3fm_H20?_kn`@0n?Sh0P3jn_X20?ooo`80o?cl0P3no_h20?Win@80e=CD0P2f][H30=?C
d`80jNWY0P3_knl20>KViP80bl_;0P2][Jd20<K6aP80i>CT0P3GemL20<k>cP80j>SX0P3fm_H20?3`
l080lo?c0P3dm?@40?knoP80m?Cd0P3oool20?;blP80m_Kf0P3lo?`20?KfmP@0moOg0P3no_h20>[Z
jP80lo?c0P3WinL20>?Sh`80aLG50P30`<030>?Sh`80f][J0P3Ng]h20=gMg@80kNg]0P3IfMT20?;b
lP80k>c/0P3emOD20<?3``80c<c<0P3GemL20>;RhP80hN7Q0P3Ogml20?Win@80e=CD0P3Jf]X20>o_
k`80hN7Q0P3?cll20?clo080fMWI0P3Shn<20=;BdP80gmoO0P3Jf]X20=gMg@/0oooo103kno/B0?oo
o`@0no_k0P3oool40?_kn`l0oooo000=0?ooo`80nOWi0P3kno/80?ooo`80no_k103oool20?Win@@0
no_k0P3oool20?_kn`D0oooo103inOT20?_kn`80mOGe0P2i^KT20<C4a080c/k>0P3Lg=`20>c/k080
j^[Z0P3_knl40>k^kP80l_;b0P3Zj^X20>KViP80<S8b0P3oool40?clo080m_Kf0P3kno/40?Shn080
n_[j0P3oool20?clo080o_kn0P3inOT20=CDe080][Jf0`3Cdm<20>WYj@80kno_0P3Vi^H20<_;b`80
[Jf]0P36a/H20>CTi080emOG0P3>c/h20>SXj080m_Kf0P3`l?020??cl`80m?Cd103no_h20?Cdm080
oooo0P3bl_820?KfmP80o?cl0P3fm_H40?Ogm`80o_kn0P3Zj^X20??cl`80inOW0P3Shn<20<G5a@80
`<300`3Shn<20=[JfP80g]kN0P3MgMd20>g]k@80fMWI0P3bl_820>c/k080mOGe0P33`l<20<c<c080
emOG0P3Rh^820>7Qh@80gmoO0P3inOT20=CDe080f][J0P3_knl20>7Qh@80clo?0P3lo?`20=WIf@80
hn?S0P3Bd]820=oOg`80f][J0P3MgMd;0?ooo`@0no_k4P3oool40?_kn`80oooo103kno/?0?ooo`00
3@3oool40?Win@@0no_k0P3inOT20?_kn`80oooo1P3kno/20?Win@@0oooo0P3kno/90?ooo`80no_k
0P3Xj>P20:VYZ@80bLW90P3Jf]X20>o_k`80jNWY0P3_knl20?ooo`80mOGe0P3fm_H20?3`l080inOW
0P3QhN4204A4A080o?cl0P3hn?P20?KfmP80l_;b0P3emOD20?[jnP80mOGe0P3dm?@20?_kn`80o?cl
0P3no_h20?Cdm080c/k>0P2h^;P30<C4a080no_k0P3`l?020>OWi`80]kNg0P2TY:@20;Bd]080d];B
0P38b<P20>_[j`80hn?S0P3Vi^H20>c/k080o_kn1P3oool20?Cdm080oooo0P3^k^h20>c/k0@0moOg
0P3jn_X20??cl`80moOg0P3hn?P20>k^kP80jNWY0P3WinL20<o?c`80YjNW0`3WinL20>GUi@80fMWI
0P3YjNT20??cl`80kno_0P3WinL20=SHf080iNGU0P2m_Kd208:2PP80n_[j0P3UiND20=[JfP80^k^k
0P3bl_820<g=c@80i^KV0P3`l?020>?Sh`80emOG0P3`l?020>3Ph080a<C40P38b<P20?;blP80a/K6
103kno/90?ooo`@0no_k1P3oool40?_kn`P0oooo0P3kno/20?Win@H0no_k3`3oool000d0oooo103i
nOT40?_kn`80nOWi0P3kno/20?ooo`H0no_k0P3inOT40?ooo`80no_k2@3oool20?_kn`80j>SX0P2Y
ZJT20<W9b@80f][J0P3_knl20>WYj@80kno_0P3oool20?Gem@80m_Kf0P3`l?020>OWi`80hN7Q0P14
A4@20?clo080n?Sh0P3fm_H20?;blP80mOGe0P3jn_X20?Gem@80m?Cd0P3kno/20?clo080o_kn0P3d
m?@20<k>cP80^;Rh0`34a<@20?_kn`80l?3`0P3WinL20;Ng]`80Y:BT0P2d];@20=;BdP80b<S80P3[
jn/20>?Sh`80i^KV0P3/k>`20?knoPH0oooo0P3dm?@20?ooo`80k^k^0P3/k>`40?Ogm`80n_[j0P3c
lo<20?Ogm`80n?Sh0P3^k^h20>WYj@80inOW0P3?cll20:NWY`<0inOW0P3UiND20=WIf@80jNWY0P3c
lo<20>o_k`80inOW0P3Hf=P20>GUi@80_Kfm0P22PX820?[jnP80iNGU0P3Jf]X20;^k^`80l_;b0P3=
cLd20>KViP80l?3`0P3Shn<20=OGe`80l?3`0P3Ph>020<C4a080b<S80P3bl_820<K6aP@0no_k2@3o
ool40?_kn`H0oooo103kno/80?ooo`80no_k0P3inOT60?_kn`l0oooo000=0?ooo`@0nOWi103kno/2
0?Win@H0no_k0P3oool20?Win@80oooo0P3inOT40?_kn`80oooo1@3inOT20?ooo`80no_k0P3Ogml2
0:2PX080bl_;0P3Xj>P20=KFeP80h>3P0P3lo?`20>_[j`80l?3`0P3fm_H20=cLg080lO7a0P2][Jd2
07YjNP80o?cl0P3kno/20?[jnP80m?Cd0P3kno/20?Cdm0@0mOGe0P3inOT20?clo080o_kn0P3dm?@2
0?7al@80nOWi0`3alO440??cl`80kNg]0P3YjNT20?Ogm`80o?cl0P3kno/20?Gem@80hn?S0P3WinL2
0>;RhP80kNg]0P3oool40?clo080oooo0P3dm?@20?ooo`80l?3`0P3dm?@20?KfmP@0moOg0P3`l?02
0>o_k`80n_[j0P3`l?020??cl`80j>SX0P3WinL208V9R@<0j^[Z0P3jn_X20<[:bP80jNWY0P3Zj^X2
0>;RhP80c<c<0P3Hf=P20?;blP80_;bl0P1NGUh20>7Qh@80i>CT0P3Fe]H20:VYZ@80kNg]0P3IfMT2
0>g]k@80k>c/0P3^k^h20=oOg`80h>3P0P3oool20>GUi@80hN7Q0P2j^[X20?ooo`@0nOWi2@3oool8
0?_kn`80oooo103kno/80?ooo`@0no_k0P3inOTC0?ooo`003@3oool40?Win@@0no_k0P3inOT60?_k
n`80oooo0P3inOT20?ooo`80nOWi103kno/20?ooo`D0nOWi0P3oool20?_kn`80gmoO0P2PX:020<_;
b`80j>SX0P3Fe]H20>3Ph080o?cl0P3[jn/20?3`l080m_Kf0P3Lg=`20?7al@80[Jf]0P1jNWX20?cl
o080no_k0P3jn_X20?Cdm080no_k0P3dm?@40?Gem@80nOWi0P3lo?`20?knoP80m?Cd0P3alO420?Wi
n@<0lO7a103clo<20>g]k@80jNWY0P3gmoL20?clo080no_k0P3emOD20>?Sh`80inOW0P3Rh^820>g]
k@80oooo103lo?`20?ooo`80m?Cd0P3oool20?3`l080m?Cd0P3fm_H40?Ogm`80l?3`0P3_knl20?[j
nP80l?3`0P3clo<20>SXj080inOW0P29RHT30>[ZjP80n_[j0P3:b/X20>WYj@80j^[Z0P3Rh^820<c<
c080f=SH0P3bl_820;bl_080GUiN0P3QhN420>CTi080e]KF0P2YZJT20>g]k@80fMWI0P3]kNd20>c/
k080k^k^0P3Ogml20>3Ph080oooo0P3UiND20>7Qh@80^[Zj0P3oool40?Win@T0oooo203kno/20?oo
o`@0no_k203oool40?_kn`80nOWi4`3oool001<0oooo1P3kno/20?ooo`@0no_k0P3oool20?_kn`80
nOWi0P3oool40?Win@<0moOg0P3jn_X40?_kn`80e]KF0P2CTi<20<c<c080n?Sh0P3Lg=`20>g]k@80
o?cl0P3hn?P20?;blP80nOWi0P3Cdm<20?Gem@80Fe]K0P2d];@20?Gem@80nOWi0P3dm?@20?Gem@P0
o_kn0P3kno/40?Shn080k^k^0P3clo<20?Cdm0D0moOg0P3clo<20?[jnP80kno_0P3dm?@20?[jnP80
no_k0P3no_h20?Shn080m_Kf0P3]kNd20>o_k`80oooo103jn_X40?clo080m?Cd0P3`l?020?Gem@80
o?cl0P3emOD20?clo080l?3`0P3Zj^X40?3`l080kno_0P3[jn/20>WYj@80W9bL0`3bl_820>_[j`80
`/;20P3Lg=`20<?3``80f][J0P3@d=020=;BdP80j>SX0P3Ng]h20:NWY`80jNWY0P3IfMT20>_[j`80
c/k>0P3]kNd20?Shn080l_;b0P3alO420>[ZjP80cLg=0P3Ogml20?7al@80mOGe0P3@d=020=WIf@80
oooo103kno/60?ooo`<0no_k0P3inOT60?_kna00oooo103kno/C0?ooo`004`3oool60?_kn`80oooo
103kno/20?ooo`80no_k0P3inOT20?ooo`@0nOWi0`3gmoL20?[jnP@0no_k0P3Fe]H209>CT`80c<c<
0P3hn?P20=cLg080kNg]0P3lo?`20?Shn080l_;b0P3inOT20=?Cd`80mOGe0P1KFe/20;Bd]080mOGe
0P3inOT20?Cdm080mOGe203no_h20?_kn`@0n?Sh0P3^k^h20??cl`80m?Cd1@3gmoL20??cl`80n_[j
0P3_knl20?Cdm080n_[j0P3kno/20?knoP80n?Sh0P3fm_H20>g]k@80kno_0P3oool40?[jnP@0o?cl
0P3dm?@20?3`l080mOGe0P3lo?`20?Gem@80o?cl0P3`l?020>[ZjP@0l?3`0P3_knl20>_[j`80jNWY
0P2LW9`30?;blP80jn_[0P32`/820=cLg080`l?30P3Jf]X20=3@d080d];B0P3Xj>P20=kNgP80YjNW
0P3YjNT20=WIf@80jn_[0P3>c/h20>g]k@80n?Sh0P3bl_820?7al@80j^[Z0P3=cLd20=oOg`80lO7a
0P3emOD20=3@d080fMWI0P3oool40?_kn`H0oooo0`3kno/20?Win@H0no_k403oool40?_kna<0oooo
000C0?ooo``0no_k103inOT40?_kn`80nOWi0P3no_h30?ooo`80nOWi0P3kno/20?Ogm`80YjNW0P2E
UID20>_[j`80g]kN0P3MgMd20>o_k`80n?Sh0P3kno/20?clo080c/k>0P3Vi^H20?;blP809bLW0P3k
no/20?Shn080no_k0P3dm?@20?ooo`80o_kn0P3oool60?knoP80mOGe0P3alO420?KfmP80m?Cd0P3f
m_H50?Ogm`80m_Kf0P3gmoL40>[ZjP80mOGe0P3inOT20?Shn080o_kn0P3alO420>_[j`80lo?c0P3n
o_h40?Win@80no_k0P3lo?`20?knoP80oooo0P3dm?@20?Gem@80m?Cd0P3no_h20?Ogm`80m?Cd0P3^
k^h20>SXj080k^k^0P3_knl20>GUi@80^k^k0`2b/[820>;RhP80cLg=0P3Xj>P20=;BdP80m_Kf0P3Y
jNT20=?Cd`80kno_0P3bl_820<k>cP80gMgM0P3Ph>020>k^kP80iNGU0P2f][H20>c/k080i>CT0P3`
l?020>[ZjP80_kno0P3Vi^H20=GEe@80cLg=0P3@d=020?ooo`@0no_k103inOT20?_kn`80oooo1@3k
no/20?WinA00oooo103kno/G0?ooo`004`3oool<0?_kn`@0nOWi103kno/20?Win@80o_kn0`3oool2
0?Win@80no_k0P3gmoL20:NWY`80UIFE0P3[jn/20=kNgP80gMgM0P3_knl20?Shn080no_k0P3lo?`2
0<k>cP80i^KV0P3bl_8202LW9`80no_k0P3hn?P20?_kn`80m?Cd0P3oool20?knoP80oooo1P3no_h2
0?Gem@80lO7a0P3fm_H20?Cdm080m_Kf1@3gmoL20?KfmP80moOg103Zj^X20?Gem@80nOWi0P3hn?P2
0?knoP80lO7a0P3[jn/20??cl`80o_kn103inOT20?_kn`80o?cl0P3no_h20?ooo`80m?Cd0P3emOD2
0?Cdm080o_kn0P3gmoL20?Cdm080k^k^0P3Xj>P20>k^kP80kno_0P3UiND20;^k^`<0/[:b0P3Rh^82
0<g=c@80j>SX0P3Bd]820?KfmP80jNWY0P3Cdm<20>o_k`80l_;b0P3>c/h20=gMg@80h>3P0P3^k^h2
0>GUi@80][Jf0P3/k>`20>CTi080l?3`0P3Zj^X20;no_`80i^KV0P3EeMD20<g=c@80d=3@0P3oool4
0?_kn`@0nOWi0P3kno/20?ooo`D0no_k0P3inOT@0?ooo`@0no_k5`3oool000d0oooo103inOT20?_k
n`@0oooo1P3kno/20?Win@@0no_k0P3inOT20?ooo`80no_k1@3inOT40?ooo`80m_Kf0P21PH420<G5
a@80jNWY0P3Cdm<20>GUi@80k>c/0P3dm?@20?ooo`80b<S80P3MgMd20?[jnP80mOGe0P0V9RH20?Og
m`80mOGe0P3dm?@20?KfmPh0o_kn0P3jn_X20?Shn080o_kn0P3jn_X50?KfmP80lo?c0P3/k>`20>o_
k`80k>c/0P3hn?P20?Win@80moOg0P3_knl20>WYj@80lO7a103oool40?[jnP80mOGe0P3lo?`20?_k
n`@0oooo0P3_knl20?Shn080moOg0P3lo?`20?Cdm080n?Sh0P3QhN420>OWi`80jn_[0P3`l?020=CD
e0<0XZ:R0P3MgMd20>[ZjP80d=3@0P3Zj^X40>g]k@80moOg0P3/k>`20?KfmP80a/K60P3QhN420>o_
k`80g]kN0P3Ph>0209VIV@80oooo0P3/k>`20>_[j`80i>CT0P35aLD20>KViP80f][J0P2c/k<20=WI
f@H0no_k103inOT20?_kn`D0oooo103kno/60?ooo`@0no_k1P3oool20?Win@@0no_k5@3oool000d0
oooo103inOT20?_kn`@0oooo1P3kno/20?Win@@0no_k0P3inOT20?ooo`80no_k1@3inOT40?ooo`80
m_Kf0P21PH420<G5a@80jNWY0P3Cdm<20>GUi@80k>c/0P3dm?@20?ooo`80b<S80P3MgMd20?[jnP80
mOGe0P0V9RH20?Ogm`80mOGe0P3dm?@20?KfmPh0o_kn0P3jn_X20?Shn080o_kn0P3jn_X50?KfmP80
lo?c0P3/k>`20>o_k`80k>c/0P3hn?P20?Win@80moOg0P3_knl20>WYj@80lO7a103oool40?[jnP80
mOGe0P3lo?`20?_kn`@0oooo0P3_knl20?Shn080moOg0P3lo?`20?Cdm080n?Sh0P3QhN420>OWi`80
jn_[0P3`l?020=CDe0<0XZ:R0P3MgMd20>[ZjP80d=3@0P3Zj^X40>g]k@80moOg0P3/k>`20?KfmP80
a/K60P3QhN420>o_k`80g]kN0P3Ph>0209VIV@80oooo0P3/k>`20>_[j`80i>CT0P35aLD20>KViP80
f][J0P2c/k<20=WIf@H0no_k103inOT20?_kn`D0oooo103kno/60?ooo`@0no_k1P3oool20?Win@@0
no_k5@3oool000d0oooo103inOT20?_kn`80oooo0P3kno/20?ooo`80no_k203oool20?_kn`T0oooo
103inOT20?[jnP80MWIf0P3:b/X20>;RhP80l?3`0P3UiND20??cl`80nOWi0P3oool20;no_`80moOg
0P3lo?`207UiN@80JFUY0P3inOT20?KfmP80o_kn1P3oool20?Shn0@0m?Cd0P3hn?P20?knoP80oooo
0P3emOD20?Ogm`80n?Sh0`3_knl20?Gem@80l_;b0P3^k^h20?Gem@80m?Cd0P3hn?P20?Ogm`80m?Cd
0P3bl_820>o_k`@0n_[j0P3lo?`20?gmo@80m?Cd0P3clo<20?clo080no_k0P3no_h20?ooo`80kno_
0P3moOd20?Win@80n?Sh0P3clo<20?Win@80l_;b0P3WinL20>;RhP80l_;b0P3Shn<309^KV`80m?Cd
0P3Ph>020>g]k@80g=cL0P3]kNd20??cl`80hn?S0P3fm_H20>g]k@80clo?0P3De=@20>c/k080i>CT
0P3GemL208n?S`80kno_0P3Cdm<20=WIf@80o?cl0P2e]KD20=oOg`80nOWi0P3=cLd20?_kna/0oooo
103kno/60?ooo`80no_k0P3inOT20?_kn`80oooo103kno/?0?ooo`003@3oool40?Win@80no_k0P3o
ool20?_kn`80oooo0P3kno/80?ooo`80no_k2@3oool40?Win@80n_[j0P1fMWH20<[:bP80h^;R0P3`
l?020>GUi@80lo?c0P3inOT20?ooo`80_kno0P3gmoL20?clo080NGUi0P1YJFT20?Win@80m_Kf0P3n
o_h60?ooo`80n?Sh103dm?@20?Shn080o_kn0P3oool20?Gem@80moOg0P3hn?P30>o_k`80mOGe0P3b
l_820>k^kP80mOGe0P3dm?@20?Shn080moOg0P3dm?@20?;blP80kno_103jn_X20?clo080oOgm0P3d
m?@20??cl`80o?cl0P3kno/20?knoP80oooo0P3_knl20?gmo@80nOWi0P3hn?P20??cl`80nOWi0P3b
l_820>OWi`80h^;R0P3bl_820>?Sh`<0Vi^K0P3dm?@20>3Ph080kNg]0P3Lg=`20>g]k@80lo?c0P3S
hn<20?KfmP80kNg]0P3?cll20=CDe080k>c/0P3Ti>@20=OGe`80Shn?0P3_knl20=?Cd`80fMWI0P3l
o?`20;Fe]@80gmoO0P3inOT20<g=c@80no_k6`3oool40?_kn`H0oooo0P3kno/20?Win@80no_k0P3o
ool40?_kn`l0oooo000=0?ooo`H0nOWi1P3kno/80?ooo`H0no_k0P3oool20?_kn`<0nOWi0P3oool2
0?_kn`80f][J0P1jNWX20=7Ad@80hN7Q0P3emOD20?Ogm`80m?Cd0P3lo?`20=kNgP80dM7A0P3]kNd2
06EUI@80GEeM0P3QhN420?Ogm`80lO7a0P3gmoL20?ooo`H0n?Sh103dm?@20?Shn0H0o_kn0P3kno/2
0??cl`<0l_;b0P3oool20>k^kP80l?3`0P3YjNT20?Ogm`80n?Sh0P3gmoL20?knoP80moOg0P3clo<2
0?_kn`80nOWi0P3`l?020?Gem@80l_;b0P3dm?@20?Shn080l_;b0P3gmoL20?Win@80lo?c0P3^k^h2
0??cl`80mOGe0P3bl_820?7al@80n?Sh0P3Zj^X20=CDe080jn_[0P3emOD30;>c/`80a<C40P3>c/h2
0>;RhP80g]kN0P3WinL20>GUi@80hn?S0P3oool20>WYj@80dm?C0P2l_;`20?Shn080kNg]0P3Lg=`2
0::RXP80o?cl0P2n_[h20<K6aP80n?Sh0P2^[Zh20=gMg@80i>CT0P3Hf=P@0?ooo`D0no_k0P3oool2
0?_kn`80nOWi0P3kno/20?ooo`P0no_k203oool40?_kn`l0oooo000=0?ooo`H0nOWi1P3kno/80?oo
o`H0no_k0P3oool20?_kn`<0nOWi0P3oool20?_kn`80f][J0P1jNWX20=7Ad@80hN7Q0P3emOD20?Og
m`80m?Cd0P3lo?`20=kNgP80dM7A0P3]kNd206EUI@80GEeM0P3QhN420?Ogm`80lO7a0P3gmoL20?oo
o`H0n?Sh103dm?@20?Shn0H0o_kn0P3kno/20??cl`<0l_;b0P3oool20>k^kP80l?3`0P3YjNT20?Og
m`80n?Sh0P3gmoL20?knoP80moOg0P3clo<20?_kn`80nOWi0P3`l?020?Gem@80l_;b0P3dm?@20?Sh
n080l_;b0P3gmoL20?Win@80lo?c0P3^k^h20??cl`80mOGe0P3bl_820?7al@80n?Sh0P3Zj^X20=CD
e080jn_[0P3emOD30;>c/`80a<C40P3>c/h20>;RhP80g]kN0P3WinL20>GUi@80hn?S0P3oool20>WY
j@80dm?C0P2l_;`20?Shn080kNg]0P3Lg=`20::RXP80o?cl0P2n_[h20<K6aP80n?Sh0P2^[Zh20=gM
g@80i>CT0P3Hf=P@0?ooo`D0no_k0P3oool20?_kn`80nOWi0P3kno/20?ooo`P0no_k203oool40?_k
n`l0oooo000?0?ooo`@0no_k0P3inOT:0?ooo`80no_k0P3oool20?Win@80no_k0P3inOT20?ooo`<0
no_k0P3inOT20?_kn`80OWin0P2IVIT20>7Qh@80d];B0P3IfMT20?Gem@80m?Cd0P3no_h20<g=c@80
jn_[0P3De=@202HV9P80lO7a0P3inOT20?Gem@80nOWi1P3hn?P20?Cdm080oooo0P3no_h20?Ogm`80
n?Sh1P3oool20?knoPD0m_Kf0P3oool20?Gem@80l_;b0P3YjNT40?Cdm080n_[j0P3gmoL20?[jnP80
m?Cd0P3jn_X20?7al@80n_[j0P3lo?`40?KfmP80oooo0P3hn?P20?ooo`80n_[j0P3inOT20?clo080
l_;b0P3inOT20?Cdm080moOg0P3`l?020?knoP80e]KF0P3Vi^H20>c/k0<0fMWI0P3Rh^820?;blP80
lO7a0P3^k^h20>g]k@80o_kn0P3_knl20?Cdm080jNWY0P3;bl/20<O7a`80n?Sh0P3dm?@20>7Qh@80
b<S80P3Kfm/20<g=c@80aLG50P3Vi^H20<_;b`80b/[:0P3Ogml20?Ogma00oooo1@3kno/20?ooo`80
no_k0P3inOT20?_kn`80oooo0P3kno/40?ooo`80no_k0P3oool40?_knaD0oooo000?0?ooo`@0no_k
0P3inOT:0?ooo`80no_k0P3oool20?Win@80no_k0P3inOT20?ooo`<0no_k0P3inOT20?_kn`80OWin
0P2IVIT20>7Qh@80d];B0P3IfMT20?Gem@80m?Cd0P3no_h20<g=c@80jn_[0P3De=@202HV9P80lO7a
0P3inOT20?Gem@80nOWi1P3hn?P20?Cdm080oooo0P3no_h20?Ogm`80n?Sh1P3oool20?knoPD0m_Kf
0P3oool20?Gem@80l_;b0P3YjNT40?Cdm080n_[j0P3gmoL20?[jnP80m?Cd0P3jn_X20?7al@80n_[j
0P3lo?`40?KfmP80oooo0P3hn?P20?ooo`80n_[j0P3inOT20?clo080l_;b0P3inOT20?Cdm080moOg
0P3`l?020?knoP80e]KF0P3Vi^H20>c/k0<0fMWI0P3Rh^820?;blP80lO7a0P3^k^h20>g]k@80o_kn
0P3_knl20?Cdm080jNWY0P3;bl/20<O7a`80n?Sh0P3dm?@20>7Qh@80b<S80P3Kfm/20<g=c@80aLG5
0P3Vi^H20<_;b`80b/[:0P3Ogml20?Ogma00oooo1@3kno/20?ooo`80no_k0P3inOT20?_kn`80oooo
0P3kno/40?ooo`80no_k0P3oool40?_knaD0oooo000?0?ooo`80nOWi103kno/:0?ooo`@0no_k0P3o
ool40?Win@D0oooo103kno/205EEE@80hn?S0P3UiND20=kNgP80c<c<0P3/k>`20?Gem@80nOWi0P3O
gml20?ooo`80^;Rh0P1OGel20?Win@80lo?c103no_h60?Shn080nOWi103no_h20?Win@80moOg0P3h
n?P20?Cdm080n?Sh0P3no_h20?[jnP<0n?Sh0P3no_h40?Gem@80inOW0P3dm?@20?Ogm`80l_;b0P3n
o_h40?Ogm`80mOGe103hn?P20?KfmP80o_kn0P3fm_H40?Gem@80n?Sh0P3no_h20?Shn080o_kn0P3g
moL20?7al@80kno_0P3no_h20>o_k`80n?Sh0P3Ng]h20>GUi@80hN7Q0`3Vi^H20=oOg`80l_;b0P3f
m_H20>?Sh`80m?Cd0P3Shn<20?ooo`80m_Kf0P3clo<20<71`@80inOW103oool20?;blP80j>SX0P2m
_Kd20=gMg@80eMGE0P3QhN420=7Ad@80^[Zj0P3WinLI0?ooo`P0no_k0P3oool40?_kn`@0oooo103k
no/E0?ooo`003`3oool20?Win@@0no_k2P3oool40?_kn`80oooo103inOT50?ooo`@0no_k0P1EEED2
0>?Sh`80iNGU0P3Ng]h20<c<c080k>c/0P3emOD20?Win@80gmoO0P3oool20;Rh^080GemO0P3inOT2
0??cl`@0o_kn1P3hn?P20?Win@@0o_kn0P3inOT20?Ogm`80n?Sh0P3dm?@20?Shn080o_kn0P3jn_X3
0?Shn080o_kn103emOD20>OWi`80m?Cd0P3gmoL20?;blP80o_kn103gmoL20?Gem@@0n?Sh0P3fm_H2
0?knoP80m_Kf103emOD20?Shn080o_kn0P3hn?P20?knoP80moOg0P3alO420>o_k`80o_kn0P3_knl2
0?Shn080g]kN0P3UiND20>7Qh@<0i^KV0P3Ogml20?;blP80m_Kf0P3Shn<20?Cdm080hn?S0P3oool2
0?KfmP80lo?c0P31`L420>OWi`@0oooo0P3bl_820>SXj080_Kfm0P3MgMd20=GEe@80hN7Q0P3AdM42
0;Zj^P80inOW6@3oool80?_kn`80oooo103kno/40?ooo`@0no_k5@3oool000d0oooo0P3inOT:0?_k
n`@0oooo103kno/40?ooo`@0no_k1@3oool20?_kn`80oooo0P1HF5P20?;blP80e=CD0P3WinL20>_[
j`80kNg]0P3emOD20>CTi080m_Kf0P3Kfm/205aLG080];Bd0P3lo?`20?Ogm`@0oooo0P3hn?P20?Cd
m080n?Sh0P3no_h40?ooo`80n?Sh0P3jn_X20?Shn080m?Cd0P3hn?P40?knoP<0lo?c0P3dm?@20?Og
m`80l_;b0P3QhN420?3`l080oOgm0P3`l?020?[jnPH0moOg0P3jn_X20?ooo`@0n_[j103emOD20?cl
o080lo?c0P3gmoL20?[jnP80oooo0P3moOd20?Gem@80l_;b0P3alO420?Cdm080m_Kf0P3YjNT20=_K
f`80g]kN0`3Shn<20=[JfP80kNg]0P3dm?@20?7al@80jNWY0P3Zj^X20?Ogm`80k^k^0P3Xj>P208n?
S`80lo?c103emOD20?Win@80kno_0P2LW9`20>_[j`80nOWi0P3^k^h20<K6aP80[jn_0P3emODI0?oo
o``0no_k7`3oool000d0oooo0P3inOT:0?_kn`@0oooo103kno/40?ooo`@0no_k1@3oool20?_kn`80
oooo0P1HF5P20?;blP80e=CD0P3WinL20>_[j`80kNg]0P3emOD20>CTi080m_Kf0P3Kfm/205aLG080
];Bd0P3lo?`20?Ogm`@0oooo0P3hn?P20?Cdm080n?Sh0P3no_h40?ooo`80n?Sh0P3jn_X20?Shn080
m?Cd0P3hn?P40?knoP<0lo?c0P3dm?@20?Ogm`80l_;b0P3QhN420?3`l080oOgm0P3`l?020?[jnPH0
moOg0P3jn_X20?ooo`@0n_[j103emOD20?clo080lo?c0P3gmoL20?[jnP80oooo0P3moOd20?Gem@80
l_;b0P3alO420?Cdm080m_Kf0P3YjNT20=_Kf`80g]kN0`3Shn<20=[JfP80kNg]0P3dm?@20?7al@80
jNWY0P3Zj^X20?Ogm`80k^k^0P3Xj>P208n?S`80lo?c103emOD20?Win@80kno_0P2LW9`20>_[j`80
nOWi0P3^k^h20<K6aP80[jn_0P3emODI0?ooo``0no_k7`3oool000d0oooo0P3inOT60?_kn`@0nOWi
103kno/40?Win@X0oooo1@3kno/20;Zj^P80JVYZ0P3Vi^H20=kNgP80lo?c0P3UiND20?;blP80inOW
0P3Vi^H20>WYj@80P8200P21PH420?[jnP80n?Sh0P3jn_X60?ooo`@0n?Sh0P3oool20?knoP80n?Sh
0P3dm?@40??cl`80moOg0P3jn_X20?knoP80mOGe0`3inOT20??cl`80oooo0P3no_h20>KViP80jNWY
0P3kno/20?KfmP80l?3`0P3bl_820?7al@80jNWY0P3gmoL20?Win@80n?Sh0P3oool20?[jnP80n?Sh
0P3clo<20?Shn080oOgm0P3no_h20?ooo`80oOgm0P3emOD20?ooo`80k>c/0P3fm_H20?7al@80k>c/
0P3Xj>P20=cLg0<0hn?S0P3Ti>@20=kNgP80kNg]0P3oool20>?Sh`80hN7Q0P3fm_H20?Gem@80kno_
0P2@T9020>SXj080oooo0P3emOD20<c<c080]kNg0P1eMGD20<o?c`80j>SX0P3Ph>020=7Ad@80YZJV
0P3inOTM0?ooo`P0no_k7`3oool000d0oooo0P3inOT60?_kn`@0nOWi103kno/40?Win@X0oooo1@3k
no/20;Zj^P80JVYZ0P3Vi^H20=kNgP80lo?c0P3UiND20?;blP80inOW0P3Vi^H20>WYj@80P8200P21
PH420?[jnP80n?Sh0P3jn_X60?ooo`@0n?Sh0P3oool20?knoP80n?Sh0P3dm?@40??cl`80moOg0P3j
n_X20?knoP80mOGe0`3inOT20??cl`80oooo0P3no_h20>KViP80jNWY0P3kno/20?KfmP80l?3`0P3b
l_820?7al@80jNWY0P3gmoL20?Win@80n?Sh0P3oool20?[jnP80n?Sh0P3clo<20?Shn080oOgm0P3n
o_h20?ooo`80oOgm0P3emOD20?ooo`80k>c/0P3fm_H20?7al@80k>c/0P3Xj>P20=cLg0<0hn?S0P3T
i>@20=kNgP80kNg]0P3oool20>?Sh`80hN7Q0P3fm_H20?Gem@80kno_0P2@T9020>SXj080oooo0P3e
mOD20<c<c080]kNg0P1eMGD20<o?c`80j>SX0P3Ph>020=7Ad@80YZJV0P3inOTM0?ooo`P0no_k7`3o
ool000d0oooo0P3inOT20?_kn`80oooo0P3kno/20?ooo`80no_k103inOT40?_kn`X0oooo1@3inOT2
07]kN`80e]KF0P3De=@20=cLg0@0hN7Q0P3hn?P20=WIf@80l?3`0P3[jn/2055AD@@0kno_0P3/k>`2
0?knoP@0n?Sh0P3oool40?Ogm`80n_[j0P3fm_H20>KViP80l?3`0P3lo?`20?Win@80moOg0P3clo<2
0?Shn080l_;b0`3jn_X20?Win@@0o_kn0P3/k>`20>3Ph080o?cl0P3hn?P20?Ogm`80l_;b0P3no_h2
0>[ZjP80nOWi0P3moOd20?Win@H0k^k^0P3fm_H40?clo080oOgm0P3oool20?gmo@80nOWi0P3dm?@2
0?clo080l_;b0P3dm?@20>_[j`80jNWY0P3Lg=`30>;RhP80j>SX0P3>c/h20>g]k@80j>SX0P3[jn/2
0=SHf080nOWi0P3fm_H20?ooo`80YZJV0P3fm_H20?Ogm`80n?Sh0P2QXJ420861P@80MgMg0P3WinL2
0<W9b@80h^;R0P3AdM420;6a/@@0oooo103kno/G0?ooo`@0nOWi8`3oool000d0oooo0P3inOT20?_k
n`80oooo0P3kno/20?ooo`80no_k103inOT40?_kn`X0oooo1@3inOT207]kN`80e]KF0P3De=@20=cL
g0@0hN7Q0P3hn?P20=WIf@80l?3`0P3[jn/2055AD@@0kno_0P3/k>`20?knoP@0n?Sh0P3oool40?Og
m`80n_[j0P3fm_H20>KViP80l?3`0P3lo?`20?Win@80moOg0P3clo<20?Shn080l_;b0`3jn_X20?Wi
n@@0o_kn0P3/k>`20>3Ph080o?cl0P3hn?P20?Ogm`80l_;b0P3no_h20>[ZjP80nOWi0P3moOd20?Wi
n@H0k^k^0P3fm_H40?clo080oOgm0P3oool20?gmo@80nOWi0P3dm?@20?clo080l_;b0P3dm?@20>_[
j`80jNWY0P3Lg=`30>;RhP80j>SX0P3>c/h20>g]k@80j>SX0P3[jn/20=SHf080nOWi0P3fm_H20?oo
o`80YZJV0P3fm_H20?Ogm`80n?Sh0P2QXJ420861P@80MgMg0P3WinL20<W9b@80h^;R0P3AdM420;6a
/@@0oooo103kno/G0?ooo`@0nOWi8`3oool001<0oooo103inOT20?ooo`80no_k0P3oool20?_kn`@0
oooo0P3kno/60?Win@<0oooo0P3kno/203lo?`80`L710P34a<@20>g]k@80kno_0P3YjNT20?Cdm080
dM7A0P33`l<209FEU@80Q8B4103^k^h20>c/k080o_kn103hn?P20?ooo`80n_[j103dm?@20?Shn080
lO7a0P3emOD20>;RhP80inOW0P3fm_H20?Ogm`80lo?c0P3`l?030?Cdm080l_;b103no_h20>?Sh`80
i^KV0P3emOD20?[jnP80o?cl0P3fm_H20>c/k080k^k^0P3lo?`20??cl`80kno_0P3^k^h20>c/k080
jNWY0P3Rh^820=cLg080gMgM0P3Rh^820>OWi`80m?Cd0P3gmoL20??cl`80moOg0P3/k>`20?Cdm080
kno_0P3Xj>P20>;RhP<0i^KV0P3QhN420=?Cd`80fm_K0P3Jf]X20>CTi080f][J0P3fm_H20?Win@80
k^k^0P2UYJD20?[jnP80i^KV0P3Ng]h209ZJVP80Kfm_0P2?Shl20>_[j`80/k>c0P3GemL20=3@d080
c<c<103oool40?_kn`H0oooo103kno/=0?ooo`@0no_k103oool40?_kna/0oooo000C0?ooo`@0nOWi
0P3oool20?_kn`80oooo0P3kno/40?ooo`80no_k1P3inOT30?ooo`80no_k0P0o?cl20<71`@80a<C4
0P3]kNd20>o_k`80jNWY0P3dm?@20=7Ad@80`l?30P2EUID208B4Q0@0k^k^0P3/k>`20?knoP@0n?Sh
0P3oool20?[jnP@0m?Cd0P3hn?P20?7al@80mOGe0P3Rh^820>OWi`80m_Kf0P3gmoL20??cl`80l?3`
0`3dm?@20?;blP@0o_kn0P3Shn<20>KViP80mOGe0P3jn_X20?clo080m_Kf0P3/k>`20>k^kP80o?cl
0P3clo<20>o_k`80k^k^0P3/k>`20>WYj@80h^;R0P3Lg=`20=gMg@80h^;R0P3WinL20?Cdm080moOg
0P3clo<20?Ogm`80k>c/0P3dm?@20>o_k`80j>SX0P3Rh^830>KViP80hN7Q0P3Cdm<20=_Kf`80f][J
0P3Ti>@20=[JfP80m_Kf0P3inOT20>k^kP80YJFU0P3jn_X20>KViP80g]kN0P2JVYX206m_K`80Shn?
0P3[jn/20;>c/`80emOG0P3@d=020<c<c0@0oooo103kno/60?ooo`@0no_k3@3oool40?_kn`@0oooo
103kno/K0?ooo`004`3oool40?_kn`@0oooo203kno/20?Win@80no_k103inOT30?_kn`80n?Sh0P0_
;bl20<O7a`80^k^k103YjNT20?KfmP80`l?30P3dm?@20=KFeP80M7Ad0P3UiND40=SHf080lO7a0P3n
o_h40?ooo`80n_[j0P3bl_820>?Sh`80aLG50P2b/[820;jn_P80g]kN0P3Rh^820=KFeP80j>SX0P3W
inL20?[jnP80mOGe0`3lo?`20>o_k`@0o_kn0P3Shn<20>OWi`80k>c/0P3bl_820>o_k`80j>SX0P3e
mOD20>KViP80kno_0P3YjNT20>?Sh`80f][J0P3<c<`20<S8b080fMWI0P3Zj^X40>WYj@80iNGU0P3o
ool20?;blP@0k^k^0P3bl_820?Cdm080kNg]0P3[jn/20>KViP<0hn?S0P3Vi^H20>c/k080c<c<0P3R
h^820?Gem@80c/k>0P3clo<20>KViP80j^[Z0P2e]KD20>GUi@80g=cL0P3bl_820;bl_080Kfm_0P25
QHD20>;RhP80Vi^K0P3]kNd20<;2`P80d=3@0P3hn?P<0?ooo`@0no_k5@3oool40?_kna/0oooo000C
0?ooo`@0no_k103oool80?_kn`80nOWi0P3kno/40?Win@<0no_k0P3hn?P202l_;`80alO70P2k^k/4
0>WYj@80m_Kf0P33`l<20?Cdm080e]KF0P1dM7@20>GUi@@0f=SH0P3alO420?knoP@0oooo0P3jn_X2
0?;blP80hn?S0P35aLD20;:b/P80_[jn0P3Ng]h20>;RhP80e]KF0P3Xj>P20>OWi`80n_[j0P3emOD3
0?clo080kno_103no_h20>?Sh`80inOW0P3/k>`20?;blP80kno_0P3Xj>P20?Gem@80i^KV0P3_knl2
0>WYj@80hn?S0P3Jf]X20<c<c080b<S80P3IfMT20>[ZjP@0jNWY0P3UiND20?ooo`80l_;b103^k^h2
0?;blP80m?Cd0P3]kNd20>_[j`80i^KV0`3Shn<20>KViP80k>c/0P3<c<`20>;RhP80mOGe0P3>c/h2
0??cl`80i^KV0P3Zj^X20;Fe]@80iNGU0P3Lg=`20?;blP80_;bl0P1_Kfl208F5Q@80h^;R0P2KVi/2
0>g]k@80`/;20P3@d=020?Shn0`0oooo103kno/E0?ooo`@0no_k6`3oool000d0oooo0P3inOT20?_k
n`H0oooo403kno/70?ooo`80[Jf]0P1lO7`20?[jnP80a/K6103]kNd20>SXj080]KFe0P2m_Kd209VI
V@80U9BD0P36a/H20>_[j`80cLg=0P3gmoL20?[jnP80oooo0P3dm?@20>3Ph080]kNg0P2i^KT20?Sh
n080e]KF0P3GemL20:BTY080b<S80P3AdM420=gMg@80`<300P36a/H20?[jnP<0o?cl0P3[jn/40?oo
o`80k>c/0P3Vi^H20>CTi080n?Sh0P3emOD20=OGe`80VIVI0P20P8020:NWY`80fMWI0P3/k>`20<?3
``80^[Zj0P39bLT20=_Kf`H0d=3@0P3:b/X20>KViP80lO7a103oool20?KfmP80n?Sh0P3]kNd20>_[
j`80i^KV0`3Shn<20>SXj080j^[Z0P3^k^h20=WIf@80m?Cd0P38b<P20?ooo`80kno_0P3fm_H20<o?
c`80l?3`0P3Shn<20?Win@80c<c<0P1fMWH20820P080h^;R0P2MWId20>g]k@80]KFe0P3Lg=`20?Sh
n1/0oooo103kno/U0?ooo`003@3oool20?Win@80no_k1P3oool@0?_kn`L0oooo0P2][Jd207alO080
n_[j0P36a/H40>g]k@80j>SX0P2e]KD20;fm_@80VIVI0P2DU9@20<K6aP80jn_[0P3=cLd20?Ogm`80
n_[j0P3oool20?Cdm080h>3P0P2g]kL20;Vi^@80n?Sh0P3Fe]H20=OGe`80Y:BT0P38b<P20=7Ad@80
gMgM0P30`<020<K6aP80n_[j0`3lo?`20>_[j`@0oooo0P3/k>`20>KViP80i>CT0P3hn?P20?Gem@80
emOG0P2IVIT20820P080YjNW0P3IfMT20>c/k080`l?30P2j^[X20<W9b@80fm_K1P3@d=020<[:bP80
i^KV0P3alO440?ooo`80m_Kf0P3hn?P20>g]k@80jn_[0P3Vi^H30>?Sh`80j>SX0P3Zj^X20>k^kP80
fMWI0P3dm?@20<S8b080oooo0P3_knl20?KfmP80clo?0P3`l?020>?Sh`80nOWi0P3<c<`207IfMP80
P8200P3Rh^8209fMW@80kNg]0P2e]KD20=cLg080n?Sh6`3oool40?_knbD0oooo000=0?ooo`80nOWi
0P3kno/60?ooo`P0no_k103oool40?_kn`L0oooo0P1lO7`20?Cdm080e]KF0P3EeMD20>CTi0@0j>SX
0P33`l<20=SHf080C4a<0P3^k^h20>OWi`80jn_[0P3AdM420?Shn080o_kn0P3`l?020>3Ph080_kno
0P3Hf=P20<_;b`80^k^k0P2`/;020;Zj^P80k^k^0P3>c/h20=KFeP80j>SX0P3gmoL20<C4a080hN7Q
0`3[jn/20>[ZjP80oooo0P3hn?P20?3`l080k>c/0P3Ti>@20??cl`80gmoO0P3Ng]h20<W9b@80d];B
0P2LW9`20:NWY`80`L710P2/[:`20=oOg`80c<c<0P3MgMd20=?Cd`80g]kN0P3Ti>@20<71`@80emOG
0P3clo<20?KfmP80o_kn0P3dm?@20?Shn080m?Cd103UiND30?;blP80h^;R0P3Zj^X20>GUi@80^;Rh
0P3QhN420;bl_080moOg0P3_knl20=GEe@80g=cL0P3bl_820=KFeP80kNg]0P3Hf=P208V9R@80O7al
0P35aLD20<71`@80o_kn0P2/[:`20?;blQL0oooo103kno/20?ooo`80no_k0P3oool20?_knb<0oooo
000=0?ooo`80nOWi0P3kno/60?ooo`P0no_k103oool40?_kn`L0oooo0P1lO7`20?Cdm080e]KF0P3E
eMD20>CTi0@0j>SX0P33`l<20=SHf080C4a<0P3^k^h20>OWi`80jn_[0P3AdM420?Shn080o_kn0P3`
l?020>3Ph080_kno0P3Hf=P20<_;b`80^k^k0P2`/;020;Zj^P80k^k^0P3>c/h20=KFeP80j>SX0P3g
moL20<C4a080hN7Q0`3[jn/20>[ZjP80oooo0P3hn?P20?3`l080k>c/0P3Ti>@20??cl`80gmoO0P3N
g]h20<W9b@80d];B0P2LW9`20:NWY`80`L710P2/[:`20=oOg`80c<c<0P3MgMd20=?Cd`80g]kN0P3T
i>@20<71`@80emOG0P3clo<20?KfmP80o_kn0P3dm?@20?Shn080m?Cd103UiND30?;blP80h^;R0P3Z
j^X20>GUi@80^;Rh0P3QhN420;bl_080moOg0P3_knl20=GEe@80g=cL0P3bl_820=KFeP80kNg]0P3H
f=P208V9R@80O7al0P35aLD20<71`@80o_kn0P2/[:`20?;blQL0oooo103kno/20?ooo`80no_k0P3o
ool20?_knb<0oooo000M0?ooo`@0no_k0P3oool40?_kn`@0oooo0`3hn?P2096AT@80/K6a0P2g]kL2
0=KFeP80b<S80P3?cll20?Gem@80gmoO0P34a<@20410@080emOG0P3Zj^X20>c/k080g=cL0P3`l?02
0?;blP80hn?S0P3@d=020;bl_080[:b/0P1mOGd20<;2`P80Shn?0P2l_;`208J6QP80VYZJ0P3>c/h2
0:NWY`80e]KF0P3Cdm<20>CTi0<0hN7Q0P3_knl20?ooo`@0m_Kf0P3^k^h20>c/k080emOG0P3`l?02
0>_[j`80eMGE0P3:b/X20<_;b`80S8b<0P1NGUh20;Fe]@80Q8B40P2=SHd20<c<c080WYjN0P29RHT2
0;Zj^P80alO70P3De=@20=oOg`80i>CT0P3dm?@20?Shn080jn_[0P3`l?020>KViP80inOW1@3UiND2
0?Cdm080cLg=0P3Ogml20>[ZjP80b/[:0P3=cLd20>OWi`80`/;20P3_knl20>WYj@80k^k^0P3]kNd2
0>SXj080Y:BT0P1jNWX20::RXP80g]kN0P3WinL20;6a/AT0oooo103kno/40?ooo`@0no_k8`3oool0
01d0oooo103kno/20?ooo`@0no_k103oool30?Shn080TI6A0P2a/K420;Ng]`80e]KF0P38b<P20<o?
c`80mOGe0P3Ogml20<C4a080@4100P3GemL20>[ZjP80k>c/0P3Lg=`20?3`l080l_;b0P3Shn<20=3@
d080_;bl0P2/[:`207emO@80`/;20P2?Shl20;bl_080QXJ60P2JVYX20<k>cP80YjNW0P3Fe]H20=?C
d`80i>CT0`3QhN420>o_k`80oooo103fm_H20>k^kP80k>c/0P3GemL20?3`l080jn_[0P3EeMD20<[:
bP80bl_;0P2<S8`205iNGP80]KFe0P24Q8@208f=S@80c<c<0P2NWYh208V9R@80^[Zj0P37alL20=CD
e080gmoO0P3Ti>@20?Cdm080n?Sh0P3[jn/20?3`l080i^KV0P3WinL50>GUi@80m?Cd0P3=cLd20=oO
g`80j^[Z0P3:b/X20<g=c@80inOW0P32`/820>o_k`80jNWY0P3^k^h20>g]k@80j>SX0P2TY:@207Yj
NP80XZ:R0P3Ng]h20>OWi`80/K6a6@3oool40?_kn`@0oooo103kno/S0?ooo`007@3oool40?_kn`X0
oooo0`2SXj<209ZJVP80Rh^;0P39bLT20=[JfP80gmoO0P3Kfm/20?ooo`80mOGe0P3AdM4208f=S@80
clo?0P3gmoL20>SXj080gmoO0P3gmoL20>_[j`80gmoO0P3GemL20;6a/@80j>SX0P2n_[h208b<S080
JVYZ0P1[Jf/20:2PX080YJFU0P3IfMT20<O7a`80fm_K103De=@30>KViP80nOWi0P3jn_X20?Shn0@0
m?Cd0P3fm_H20=WIf@80hn?S0P3Ng]h20?[jnP80f=SH0P3dm?@20<C4a080Kfm_0P1nOWh208:2PP80
`L710P3GemL20:b/[080^;Rh0P3Hf=P20<G5a@80k>c/0P3`l?020=oOg`80k^k^0P3fm_H20>WYj@80
l_;b0P3YjNT20=?Cd`<0iNGU0P3gmoL20>k^kP80d];B0P3Kfm/20=oOg`@0hN7Q0P3^k^h20<O7a`80
n_[j0P3inOT20>OWi`80i^KV0P3[jn/20:j^[P80Rh^;0P2e]KD20>CTi080^;Rh0P3Bd]8Y0?ooo`@0
no_k6`3oool001d0oooo103kno/:0?ooo`<0Xj>S0P2JVYX208^;R`80bLW90P3Jf]X20=oOg`80fm_K
0P3oool20?Gem@80dM7A0P2=SHd20<o?c`80moOg0P3Xj>P20=oOg`80moOg0P3[jn/20=oOg`80emOG
0P2a/K420>SXj080_[jn0P2<S8`206YZJP80Jf][0P2PX:020:FUY@80fMWI0P37alL20=_Kf`@0e=CD
0`3Vi^H20?Win@80n_[j0P3hn?P40?Cdm080m_Kf0P3IfMT20>?Sh`80g]kN0P3jn_X20=SHf080m?Cd
0P34a<@206m_K`80OWin0P22PX820<71`@80emOG0P2/[:`20;Rh^080f=SH0P35aLD20>c/k080l?3`
0P3Ogml20>k^kP80m_Kf0P3YjNT20?;blP80jNWY0P3Cdm<30>GUi@80moOg0P3^k^h20=;BdP80fm_K
0P3Ogml40>7Qh@80k^k^0P37alL20?[jnP80nOWi0P3WinL20>KViP80jn_[0P2^[Zh208^;R`80]KFe
0P3Ti>@20;Rh^080d];B:@3oool40?_kna/0oooo000E0?ooo`@0no_k103oool40?_kn`X0oooo0`1Z
JVX20;Fe]@80d];B0P36a/H20=SHf080l?3`0P3^k^h20?Gem@80j^[Z0P2n_[h20<30`080h>3P0P3k
no/20>_[j`80gMgM0P3jn_X20?3`l080hN7Q0P3=cLd209ZJVP80_Kfm0P3/k>`20=SHf080c/k>0P3;
bl/20>;RhP80gMgM0P3Jf]X20;Vi^@80`L710P3=cLd20>[ZjP<0k^k^103jn_X20?Shn080m?Cd0P3h
n?P20?3`l080hn?S0P3MgMd20>3Ph080e]KF0P3IfMT20>o_k`80eMGE0P2l_;`2096AT@80ZJVY0P3C
dm<20?Shn080oooo0P3;bl/20<71`@80a<C40P3^k^h20>g]k@80i^KV0P3gmoL20??cl`80moOg0P3]
kNd20>WYj@80fMWI0`3lo?`20?Ogm`80l_;b0P3Vi^H20=OGe`80iNGU0P3inOT20?;blP80i^KV0P37
alL40>c/k080l_;b0P3Lg=`20?3`l080`l?30P2QXJ420<c<c080h>3P0P2VYZH20>k^kRT0oooo103k
no/K0?ooo`005@3oool40?_kn`@0oooo103kno/:0?ooo`<0JVYZ0P2e]KD20=;BdP80a/K60P3Hf=P2
0?3`l080k^k^0P3emOD20>[ZjP80_[jn0P30`<020>3Ph080no_k0P3[jn/20=gMg@80n_[j0P3`l?02
0>7Qh@80cLg=0P2JVYX20;fm_@80k>c/0P3Hf=P20<k>cP80bl_;0P3Rh^820=gMg@80f][J0P2i^KT2
0<71`@80cLg=0P3Zj^X30>k^kP@0n_[j0P3hn?P20?Cdm080n?Sh0P3`l?020>?Sh`80gMgM0P3Ph>02
0=KFeP80fMWI0P3_knl20=GEe@80_;bl0P2ATI420:VYZ@80dm?C0P3hn?P20?ooo`80bl_;0P31`L42
0<C4a080k^k^0P3]kNd20>KViP80moOg0P3clo<20?Ogm`80kNg]0P3YjNT20=WIf@<0o?cl0P3gmoL2
0?;blP80i^KV0P3GemL20>GUi@80nOWi0P3bl_820>KViP80alO7103/k>`20?;blP80g=cL0P3`l?02
0<?3``80XJ6Q0P3<c<`20>3Ph080YZJV0P3^k^hY0?ooo`@0no_k6`3oool001D0oooo103kno/40?oo
o`@0no_k103oool40?_kn`80oooo0`29RHT20;Zj^P80cLg=0P2`/;020>OWi`80hN7Q0P3Ti>@20>OW
i`80emOG0P2o_kl20=_Kf`80k>c/0P3clo<20>CTi080fMWI0P3kno/20?Gem@80j^[Z0P3Hf=P20<?3
``80X:2P0P24Q8@207QhN0@0MGEe0P1^KVh208:2PP80_kno0P3QhN420>g]k@80j>SX0P3bl_830?Kf
mP80nOWi0P3no_h20?_kn`80l_;b0P3fm_H20?[jnP80jn_[0P3Ti>@20?Win@80k>c/0P3YjNT20;:b
/P80[Jf]0P3De=@20>3Ph080alO70P2RXZ8208:2PP80NGUi0P2EUID20;jn_P80cLg=0P3<c<`20=_K
f`80kno_0P3inOT20?3`l080moOg0P3emOD20>CTi080fMWI0`3kno/20>o_k`80inOW0P3UiND20>3P
h0@0k>c/0P3QhN420?KfmP80_;bl103Ogml20?;blP80e=CD0P3[jn/20=KFeP80Z:RX0P3@d=020;:b
/P80/;2`0P3dm?@e0?ooo`@0no_k3`3oool001D0oooo103kno/40?ooo`@0no_k103oool40?_kn`80
oooo0`29RHT20;Zj^P80cLg=0P2`/;020>OWi`80hN7Q0P3Ti>@20>OWi`80emOG0P2o_kl20=_Kf`80
k>c/0P3clo<20>CTi080fMWI0P3kno/20?Gem@80j^[Z0P3Hf=P20<?3``80X:2P0P24Q8@207QhN0@0
MGEe0P1^KVh208:2PP80_kno0P3QhN420>g]k@80j>SX0P3bl_830?KfmP80nOWi0P3no_h20?_kn`80
l_;b0P3fm_H20?[jnP80jn_[0P3Ti>@20?Win@80k>c/0P3YjNT20;:b/P80[Jf]0P3De=@20>3Ph080
alO70P2RXZ8208:2PP80NGUi0P2EUID20;jn_P80cLg=0P3<c<`20=_Kf`80kno_0P3inOT20?3`l080
moOg0P3emOD20>CTi080fMWI0`3kno/20>o_k`80inOW0P3UiND20>3Ph0@0k>c/0P3QhN420?KfmP80
_;bl103Ogml20?;blP80e=CD0P3[jn/20=KFeP80Z:RX0P3@d=020;:b/P80/;2`0P3dm?@e0?ooo`@0
no_k3`3oool00140oooo103kno/20?ooo`@0no_k203oool20?_kn`80oooo0P3kno/20?Shn0<0j>SX
0P13@d<20<K6aP80a<C40P3Xj>P20>o_k`80hN7Q0P3@d=020;no_`80bl_;0P3Lg=`20?Ogm`80kno_
0P3Ng]h20=7Ad@80n?Sh0P3alO420?KfmP80n?Sh0P3alO420>k^kP80i^KV0P3MgMd20=oOg`80emOG
0P2a/K4209nOW`80[jn_0P37alL20>?Sh`80g]kN0P3alO430?[jnP80lo?c0P3hn?P20?knoP80n_[j
0P3hn?P20?Cdm080h^;R0P3Ph>020>KViP80b<S80P2l_;`20;Ng]`80alO70P3WinL20<71`@80^k^k
0P2m_Kd20<c<c080f][J0P3Shn<20>c/k080m?Cd0P3gmoL20?Cdm080kNg]0P3MgMd20>c/k080l?3`
0P3clo<20>[ZjP80hN7Q0`3fm_H20>k^kP80j>SX0P3Shn<20>g]k@80l_;b0P3Ogml20=SHf080inOW
0P3@d=020<o?c`80g]kN0P3emOD20<S8b080lo?c0P3?cll20:BTY080c/k>0P2OWil20>7Qh@80n?Sh
=@3oool40?_kn`l0oooo000A0?ooo`@0no_k0P3oool40?_kn`P0oooo0P3kno/20?ooo`80no_k0P3h
n?P30>SXj080@d=30P36a/H20<C4a080j>SX0P3_knl20>7Qh@80d=3@0P2o_kl20<_;b`80g=cL0P3g
moL20>o_k`80g]kN0P3AdM420?Shn080lO7a0P3fm_H20?Shn080lO7a0P3^k^h20>KViP80gMgM0P3O
gml20=OGe`80/K6a0P2OWil20:n_[`80alO70P3Shn<20=kNgP80lO7a0`3jn_X20??cl`80n?Sh0P3n
o_h20?[jnP80n?Sh0P3dm?@20>;RhP80h>3P0P3Vi^H20<S8b080_;bl0P2g]kL20<O7a`80inOW0P31
`L420;^k^`80_Kfm0P3<c<`20=[JfP80hn?S0P3/k>`20?Cdm080moOg0P3dm?@20>g]k@80gMgM0P3/
k>`20?3`l080lo?c0P3Zj^X20>7Qh@<0m_Kf0P3^k^h20>SXj080hn?S0P3]kNd20?;blP80gmoO0P3H
f=P20>OWi`80d=3@0P3?cll20=kNgP80mOGe0P38b<P20??cl`80clo?0P2TY:@20<k>cP80WinO0P3Q
hN420?Shn3D0oooo103kno/?0?ooo`004@3oool40?_kn`80oooo103kno/80?ooo`@0no_k0P3oool2
0?3`l0<0j^[Z0P0000020=kNgP80c/k>0P3bl_820?7al@80fm_K0P3De=@20<[:bP80hn?S0P3IfMT2
0>KViP80m?Cd0P3Ph>020<O7a`80l_;b0P3clo<20>OWi`80lo?c103no_h20?Gem@80/[:b0P2QXJ42
0<71`@80i^KV0P3De=@209nOW`80YZJV0P3Xj>P20?3`l0D0nOWi0P3fm_H20?Cdm0@0o_kn0P3jn_X2
0?ooo`80kno_0P3Shn<20<K6aP80^[Zj0P3Rh^820=_Kf`80a<C40P2OWil20:j^[P80g]kN0P3_knl2
0?Win@80lo?c0P3alO420?Win@80mOGe0P3alO420>CTi080dm?C0P3dm?@20?Win@80kno_0P3YjNT2
0>g]k@80mOGe0`3YjNT40=gMg@80dm?C0P3lo?`20?Ogm`80lO7a0P3WinL20<W9b@80g]kN0P3Ph>02
0?7al@80jn_[0P30`<020?Ogm`80bl_;0P30`<020=gMg@80UYJF0P3bl_9:0?ooo`004@3oool40?_k
n`80oooo103kno/80?ooo`@0no_k0P3oool20?3`l0<0j^[Z0P0000020=kNgP80c/k>0P3bl_820?7a
l@80fm_K0P3De=@20<[:bP80hn?S0P3IfMT20>KViP80m?Cd0P3Ph>020<O7a`80l_;b0P3clo<20>OW
i`80lo?c103no_h20?Gem@80/[:b0P2QXJ420<71`@80i^KV0P3De=@209nOW`80YZJV0P3Xj>P20?3`
l0D0nOWi0P3fm_H20?Cdm0@0o_kn0P3jn_X20?ooo`80kno_0P3Shn<20<K6aP80^[Zj0P3Rh^820=_K
f`80a<C40P2OWil20:j^[P80g]kN0P3_knl20?Win@80lo?c0P3alO420?Win@80mOGe0P3alO420>CT
i080dm?C0P3dm?@20?Win@80kno_0P3YjNT20>g]k@80mOGe0`3YjNT40=gMg@80dm?C0P3lo?`20?Og
m`80lO7a0P3WinL20<W9b@80g]kN0P3Ph>020?7al@80jn_[0P30`<020?Ogm`80bl_;0P30`<020=gM
g@80UYJF0P3bl_9:0?ooo`008`3oool40?_kn`80n?Sh0P2g]kL30;2`/0802PX:0P3dm?@20>g]k@80
i>CT0P3fm_H20=_Kf`80lO7a0P3Ogml20>g]k@80g=cL0P3Bd]820>k^kP80i>CT0P36a/H20?Shn080
clo?0P34a<@20<30`080_;bl0P2`/;0209BDU080[:b/0P3UiND20:2PX080Ng]k0P2GUiL20<[:bP80
inOW0P3^k^h20?;blPD0nOWi0P3no_h20?Shn0H0o_kn0P3jn_X20?_kn`80moOg0P3Rh^820;Zj^P80
S8b<0P26QXH20:FUY@80hn?S0P32`/8209ZJVP80U9BD0P2>SXh20:>SX`80]KFe0P2g]kL20;6a/@80
^[Zj0P3EeMD20?Cdm080i^KV0P3gmoL20?;blP80iNGU0P3`l?020?ooo`<0hn?S0P3Rh^820<S8b080
lo?c0P3Ogml20>?Sh`80j>SX0P3IfMT20<W9b@80jn_[0P3]kNd20?7al@80jn_[0P32`/820>g]k@80
lO7a0P33`l<20;bl_080YZJV8@3oool40?_knbL0oooo000S0?ooo`@0no_k0P3hn?P20;Ng]`<0/;2`
0P0:2PX20?Cdm080kNg]0P3Ti>@20?KfmP80fm_K0P3alO420=oOg`80kNg]0P3Lg=`20=;BdP80k^k^
0P3Ti>@20<K6aP80n?Sh0P3?cll20<C4a080`<300P2l_;`20;2`/080U9BD0P2/[:`20>GUi@80X:2P
0P1kNg/209NGU`80b/[:0P3WinL20>k^kP80l_;b1@3inOT20?knoP80n?Sh1P3no_h20?[jnP80no_k
0P3gmoL20>;RhP80^[Zj0P2<S8`208J6QP80YJFU0P3Shn<20<;2`P80VYZJ0P2DU9@208j>SP80Xj>S
0P2e]KD20;Ng]`80/K6a0P2j^[X20=GEe@80m?Cd0P3Vi^H20?Ogm`80l_;b0P3UiND20?3`l080oooo
0`3Shn<20>;RhP80b<S80P3clo<20=oOg`80hn?S0P3Xj>P20=WIf@80bLW90P3[jn/20>g]k@80lO7a
0P3[jn/20<;2`P80kNg]0P3alO420<?3``80_;bl0P2VYZHQ0?ooo`@0no_k9`3oool002<0oooo103i
nOT20?Shn080U9BD0`2MWId2059BDP80m?Cd0P3Shn<20>OWi`80gMgM0P3UiND20?Gem@80j^[Z0P3e
mOD20?_kn`80hN7Q0P3[jn/20=7Ad@80c/k>0P3emOD20<S8b080^k^k0P3Ogml20?;blP80lO7a0P3F
e]H209:BTP80TI6A0P34a<@20?;blP80m_Kf0P3inOT;0?ooo`80m?Cd0P3oool20?Shn080m?Cd0P3e
mOD20?Shn080n_[j103inOT20?Ogm`80jNWY0P3Jf]X20;jn_P80V9RH0P1jNWX207emO@80WYjN0P3M
gMd20>k^kP80iNGU0P3]kNd20?7al@80e]KF0P3Ng]h20>o_k`80m?Cd103clo<20>7Qh@80m?Cd0P3c
lo<30=KFeP80gMgM0P3Cdm<20>CTi080jn_[0P3Bd]820=OGe`80k^k^0P2WYjL20>g]k@80k^k^0P3`
l?020>[ZjP80aLG50P3]kNd20<S8b080n?Sh0P22PX820=OGeb40oooo203kno/S0?ooo`008`3oool4
0?Win@80n?Sh0P2DU9@309fMW@80DU9B0P3dm?@20>?Sh`80inOW0P3MgMd20>GUi@80mOGe0P3Zj^X2
0?Gem@80no_k0P3QhN420>_[j`80dM7A0P3>c/h20?Gem@80b<S80P2k^k/20=oOg`80l_;b0P3alO42
0=KFeP80TY:B0P2ATI420<C4a080l_;b0P3fm_H20?Win@/0oooo0P3dm?@20?ooo`80n?Sh0P3dm?@2
0?Gem@80n?Sh0P3jn_X40?Win@80moOg0P3YjNT20=[JfP80_[jn0P2HV9P207YjNP80OGem0P2NWYh2
0=gMg@80k^k^0P3UiND20>g]k@80lO7a0P3Fe]H20=kNgP80kno_0P3dm?@40??cl`80hN7Q0P3dm?@2
0??cl`<0e]KF0P3MgMd20=?Cd`80i>CT0P3[jn/20=;BdP80emOG0P3^k^h20:NWY`80kNg]0P3^k^h2
0?3`l080j^[Z0P35aLD20>g]k@80b<S80P3hn?P208:2PP80emOG8@3oool80?_knb<0oooo000E0?oo
o`@0no_k103oool40?_kn`80oooo103kno/20?ooo`80ZZZZ0`2OWil20=CDe080l_;b0P3;bl/20=[J
fP80hN7Q0P3^k^h20?Gem@80j^[Z103gmoL20>KViP80nOWi0P33`l<20=3@d080nOWi0P3kno/20?[j
nP80f=SH0P2g]kL20:^[Z`80^;Rh0P3Ng]h20?Cdm1<0oooo0P3dm?@40?Shn080oooo0P3hn?P20?Og
m`H0o_kn0P3kno/20?Gem@80nOWi0P3fm_H20?Shn080oOgm0P3lo?`20=KFeP80/k>c0P2GUiL209nO
W`80/;2`0P36a/H20>GUi@80k>c/0P3[jn/20?Shn080k>c/0P3WinL20>WYj@@0nOWi0`3Kfm/20<k>
cP80oooo0P3Jf]X20=WIf@80iNGU0P3oool20??cl`80PH610P3Ti>@20>_[j`80]kNg0P3:b/X20=?C
d`80fm_K0P2a/K420<K6aP80RXZ:0P3bl_8U0?ooo`@0no_k8`3oool001D0oooo103kno/40?ooo`@0
no_k0P3oool40?_kn`80oooo0P2ZZZX309nOW`80e=CD0P3bl_820<_;b`80f][J0P3QhN420>k^kP80
mOGe0P3Zj^X40?Ogm`80i^KV0P3inOT20<?3``80d=3@0P3inOT20?_kn`80n_[j0P3Hf=P20;Ng]`80
Zj^[0P2h^;P20=kNgP80m?Cd4`3oool20?Cdm0@0n?Sh0P3oool20?Shn080moOg1P3no_h20?_kn`80
mOGe0P3inOT20?KfmP80n?Sh0P3moOd20?clo080e]KF0P2c/k<209NGU`80WinO0P2`/;020<K6aP80
iNGU0P3/k>`20>_[j`80n?Sh0P3/k>`20>OWi`80jNWY103inOT30=_Kf`80c/k>0P3oool20=[JfP80
fMWI0P3UiND20?ooo`80lo?c0P21PH420>CTi080jn_[0P2g]kL20<[:bP80dm?C0P3Kfm/20;6a/@80
a/K60P2:RXX20?;blRD0oooo103kno/S0?ooo`004@3oool80?_kn`80oooo0P3kno/20?ooo`80no_k
203oool20;Fe]@<0NWYj0P3Rh^820?Shn080^k^k0P3Ng]h20>CTi080oOgm0P3_knl20>k^kP80o?cl
0P3gmoL20=cLg080nOWi0P32`/820<c<c080nOWi0P3kno/20?ooo`80mOGe0P3oool20?knoP80n?Sh
0P3dm?@20?ooo`80mOGe0P3inOT40?ooo`@0nOWi1`3oool20?Gem@80nOWi2P3hn?P60?knoP80n?Sh
0P3gmoL20?[jnP80mOGe0P3oool20?gmo@@0mOGe0P3clo<40?Cdm0@0moOg0P3fm_H20?Win@80jNWY
0P3gmoL20>[ZjP80j>SX0P3jn_X20?clo0<0hn?S0P3]kNd20<o?c`80fm_K0P3/k>`20>_[j`80i>CT
0P3Zj^X206ATI080c<c<0P3QhN420:VYZ@80alO70P3hn?P20;>c/`80YZJV0P2UYJD209RHV080n?Sh
C03oool00140oooo203kno/20?ooo`80no_k0P3oool20?_kn`P0oooo0P2e]KD307YjNP80h^;R0P3h
n?P20;^k^`80g]kN0P3Ti>@20?gmo@80kno_0P3^k^h20?clo080moOg0P3Lg=`20?Win@80`/;20P3<
c<`20?Win@80no_k0P3oool20?Gem@80oooo0P3no_h20?Shn080m?Cd0P3oool20?Gem@80nOWi103o
ool40?Win@L0oooo0P3emOD20?Win@X0n?Sh1P3no_h20?Shn080moOg0P3jn_X20?Gem@80oooo0P3m
oOd40?Gem@80lo?c103dm?@40?Ogm`80m_Kf0P3inOT20>WYj@80moOg0P3Zj^X20>SXj080n_[j0P3l
o?`30>?Sh`80kNg]0P3?cll20=_Kf`80k>c/0P3[jn/20>CTi080j^[Z0P1TI6@20<c<c080hN7Q0P2Y
ZJT20<O7a`80n?Sh0P2c/k<20:JVYP80YJFU0P2HV9P20?Shn4`0oooo000A0?ooo`@0no_k1P3oool4
0?_kn`X0oooo0P2i^KT306MWI`80iNGU0P3Xj>P20=CDe080fm_K0P3alO420>_[j`80m?Cd0P3lo?`2
0?Ogm`80m?Cd0P3Fe]H20?KfmP80bl_;0P31`L420?3`l080no_k0P3oool40?Shn080o_kn0P3inOT4
0?Shn080nOWi0P3fm_H40?ooo`@0nOWi1`3oool20?Win@80mOGe103hn?P20?Cdm080oooo0P3hn?P2
0?knoP80n_[j1P3hn?P20?_kn`80mOGe0P3no_h20?gmo@80nOWi0P3oool20?Cdm080no_k0P3dm?@4
0?Ogm`80n?Sh0P3inOT20??cl`80mOGe0P3WinL20>SXj080mOGe0P3fm_H30>SXj080kNg]0P35aLD2
0?Cdm080k>c/0P3Vi^H20>CTi080j^[Z0P1NGUh20=_Kf`80g]kN0P2b/[820<o?c`80j>SX0P2][Jd2
0;Fe]@80KVi^0P3:b/X20?Shn4`0oooo000A0?ooo`@0no_k1P3oool40?_kn`X0oooo0P2i^KT306MW
I`80iNGU0P3Xj>P20=CDe080fm_K0P3alO420>_[j`80m?Cd0P3lo?`20?Ogm`80m?Cd0P3Fe]H20?Kf
mP80bl_;0P31`L420?3`l080no_k0P3oool40?Shn080o_kn0P3inOT40?Shn080nOWi0P3fm_H40?oo
o`@0nOWi1`3oool20?Win@80mOGe103hn?P20?Cdm080oooo0P3hn?P20?knoP80n_[j1P3hn?P20?_k
n`80mOGe0P3no_h20?gmo@80nOWi0P3oool20?Cdm080no_k0P3dm?@40?Ogm`80n?Sh0P3inOT20??c
l`80mOGe0P3WinL20>SXj080mOGe0P3fm_H30>SXj080kNg]0P35aLD20?Cdm080k>c/0P3Vi^H20>CT
i080j^[Z0P1NGUh20=_Kf`80g]kN0P2b/[820<o?c`80j>SX0P2][Jd20;Fe]@80KVi^0P3:b/X20?Sh
n4`0oooo000G0?ooo`@0no_k3P3oool20=[JfP<0C4a<0P3jn_X20>OWi`80gmoO0P3YjNT20?Shn080
k>c/0P3emOD20?Ogm`80n_[j0P3inOT20=;BdP80jn_[0P3Kfm/20<C4a080l?3`0P3alO420?knoP80
oOgm0P3fm_H20?ooo`80o_kn103hn?P40?Win@@0oooo0P3inOT20?KfmP80nOWi2@3oool20?Shn0@0
m?Cd0P3hn?P20?ooo`80moOg0P3inOT40?ooo`80o?cl0P3gmoL20?Shn080oooo0P3dm?@20?;blP80
m_Kf0P3oool20?Ogm`80m?Cd0P3oool20?KfmP80oOgm0P3/k>`20?7al@80k>c/0P3_knl20>[ZjP80
oooo0P3/k>`30>;RhP80fm_K0P3QhN420>g]k@80gmoO0P3Ti>@20?ooo`80i>CT0P1oOgl20?;blP80
c<c<0P36a/H20<g=c@80hn?S0P3Ng]h20>SXj080LG5a0P3kno/U0?ooo`@0no_k9@3oool001L0oooo
103kno/>0?ooo`80f][J0`1<C4`20?[jnP80inOW0P3Ogml20>WYj@80n?Sh0P3/k>`20?Gem@80moOg
0P3jn_X20?Win@80d];B0P3[jn/20=_Kf`80a<C40P3`l?020?7al@80o_kn0P3moOd20?KfmP80oooo
0P3no_h40?Shn0@0nOWi103oool20?Win@80m_Kf0P3inOT90?ooo`80n?Sh103dm?@20?Shn080oooo
0P3gmoL20?Win@@0oooo0P3lo?`20?Ogm`80n?Sh0P3oool20?Cdm080l_;b0P3fm_H20?ooo`80moOg
0P3dm?@20?ooo`80m_Kf0P3moOd20>c/k080lO7a0P3/k>`20>o_k`80j^[Z0P3oool20>c/k0<0h^;R
0P3Kfm/20>7Qh@80kNg]0P3Ogml20>CTi080oooo0P3Ti>@207moO`80l_;b0P3<c<`20<K6aP80cLg=
0P3Shn<20=kNgP80j>SX0P1aLG420?_knbD0oooo103kno/U0?ooo`005`3oool40?_kn`h0oooo0P3J
f]X304a<C080n_[j0P3WinL20=oOg`80jNWY0P3hn?P20>c/k080mOGe0P3gmoL20?[jnP80nOWi0P3B
d]820>_[j`80fm_K0P34a<@20?3`l080lO7a0P3no_h20?gmo@80m_Kf0P3oool20?knoP@0n?Sh103i
nOT40?ooo`80nOWi0P3fm_H20?Win@T0oooo0P3hn?P40?Cdm080n?Sh0P3oool20?Ogm`80nOWi103o
ool20?clo080moOg0P3hn?P20?ooo`80m?Cd0P3bl_820?KfmP80oooo0P3gmoL20?Cdm080oooo0P3f
m_H20?gmo@80k>c/0P3alO420>c/k080kno_0P3Zj^X20?ooo`80k>c/0`3Rh^820=_Kf`80hN7Q0P3]
kNd20=oOg`80i>CT0P3oool20>CTi080Ogmo0P3bl_820<c<c080a/K60P3=cLd20>?Sh`80g]kN0P3X
j>P2075aL@80no_k9@3oool40?_knbD0oooo000G0?ooo`@0no_k3P3oool20?KfmP<0;Rh^0P3jn_X2
0>c/k080lO7a0P3[jn/20?Cdm080jNWY0P3emOD20?[jnP80oooo0P3gmoL20=[JfP@0jNWY0P3De=@2
0?3`l080k>c/0P3no_h20?Shn080n_[j0P3oool20?knoP80moOg0P3hn?P20?Win@80m_Kf0P3inOT2
0?ooo`80m_Kf103inOT50?Shn0@0oooo0P3dm?@40?ooo`@0o_kn0P3emOD20?Cdm080n_[j0P3oool2
0?_kn`80nOWi103oool20>o_k`80no_k103hn?P20?[jnP80mOGe0P3moOd20?KfmP80oOgm0P3/k>`2
0?KfmP80kno_0P3inOT20?KfmP80lO7a0P3]kNd30>?Sh`80h>3P0P3kno/20>_[j`80fm_K103gmoL2
0>7Qh@80WIfM0P36a/H20=3@d080clo?0P3Rh^820>GUi@80gmoO0P24Q8@20;Bd]2L0oooo103kno/U
0?ooo`005`3oool40?_kn`h0oooo0P3fm_H302h^;P80n_[j0P3/k>`20?7al@80jn_[0P3dm?@20>WY
j@80mOGe0P3jn_X20?ooo`80moOg0P3Jf]X40>WYj@80e=CD0P3`l?020>c/k080o_kn0P3hn?P20?[j
nP80oooo0P3no_h20?Ogm`80n?Sh0P3inOT20?KfmP80nOWi0P3oool20?KfmP@0nOWi1@3hn?P40?oo
o`80m?Cd103oool40?knoP80mOGe0P3dm?@20?[jnP80oooo0P3kno/20?Win@@0oooo0P3_knl20?_k
n`@0n?Sh0P3jn_X20?Gem@80oOgm0P3fm_H20?gmo@80k>c/0P3fm_H20>o_k`80nOWi0P3fm_H20?7a
l@80kNg]0`3Shn<20>3Ph080no_k0P3[jn/20=_Kf`@0moOg0P3QhN4209fMW@80a/K60P3@d=020<o?
c`80h^;R0P3UiND20=oOg`80Q8B40P2d];@W0?ooo`@0no_k9@3oool002T0oooo0P3dm?@303@d=080
k^k^0P3clo<20>SXj080moOg0P3alO420?Cdm080kno_0P3inOT40>o_k`80j^[Z0P3Ng]h20?3`l080
gmoO0P3UiND20>o_k`80nOWi0P3jn_X20?Shn080n_[j0P3oool80?Win@80n?Sh103inOT20?knoP80
mOGe1@3no_h20?Gem@80m?Cd0P3inOT60?knoP80oooo103jn_X20?Shn080oooo0P3gmoL20?clo080
n?Sh0P3oool20?Cdm080l_;b103hn?P20?[jnP80m_Kf0P3lo?`20?Gem@80o_kn0P3/k>`20?KfmP80
kno_0P3gmoL20?ooo`80iNGU0P3alO430>WYj@80f][J0P3oool20=?Cd`80l_;b103Zj^X20;no_`80
_;bl0P3>c/h20>;RhP80c<c<0P3`l?020=_Kf`80]KFe0P1]KFd20=gMgE00oooo000Y0?ooo`80m?Cd
0`0d=3@20>k^kP80lo?c0P3Xj>P20?Ogm`80lO7a0P3dm?@20>o_k`80nOWi103_knl20>[ZjP80g]kN
0P3`l?020=oOg`80iNGU0P3_knl20?Win@80n_[j0P3hn?P20?[jnP80oooo203inOT20?Shn0@0nOWi
0P3no_h20?Gem@D0o_kn0P3emOD20?Cdm080nOWi1P3no_h20?ooo`@0n_[j0P3hn?P20?ooo`80moOg
0P3lo?`20?Shn080oooo0P3dm?@20?;blP@0n?Sh0P3jn_X20?KfmP80o?cl0P3emOD20?knoP80k>c/
0P3fm_H20>o_k`80moOg0P3oool20>GUi@80lO7a0`3YjNT20=[JfP80oooo0P3Cdm<20?;blP@0j^[Z
0P2o_kl20;bl_080c/k>0P3Rh^820<c<c080l?3`0P3Kfm/20;Fe]@80KFe]0P3MgMe@0?ooo`00:@3o
ool20?Cdm0<0=CDe0P3kno/20<c<c080l?3`0P3_knl20?;blP80o?cl0P3dm?@20>k^kP80k>c/0P3P
h>040>?Sh`80m_Kf0P3Ogml20>3Ph080lo?c0P3fm_H20?gmo@@0n_[j0P3oool40?Win@80n?Sh0P3o
ool20?Gem@@0nOWi0P3no_h40?Win@<0o_kn0P3hn?P40?knoP@0oooo103no_h60?[jnP80m_Kf0P3k
no/20?Win@80m_Kf0P3oool20?Cdm080o?cl0P3emOD20?Shn080lO7a0P3hn?P20?knoP80mOGe0P3n
o_h20>GUi@80m?Cd0P3YjNT20?Ogm`80k>c/0P3Ti>@20>g]k@<0gMgM0P3gmoL20=gMg@80fMWI0P3X
j>P20?7al@80inOW0P2CTi<20>OWi`80kNg]0P3WinL20<30`080n?Sh0P3WinL20=GEe@80Y:BTDP3o
ool002T0oooo0P3dm?@303De=@80no_k0P3<c<`20?3`l080kno_0P3bl_820?clo080m?Cd0P3^k^h2
0>c/k080h>3P103Shn<20?KfmP80gmoO0P3Ph>020??cl`80m_Kf0P3moOd40?[jnP80oooo103inOT2
0?Shn080oooo0P3emOD40?Win@80o_kn103inOT30?knoP80n?Sh103no_h40?ooo`@0o_kn1P3jn_X2
0?KfmP80no_k0P3inOT20?KfmP80oooo0P3dm?@20?clo080mOGe0P3hn?P20?7al@80n?Sh0P3no_h2
0?Gem@80o_kn0P3UiND20?Cdm080jNWY0P3gmoL20>c/k080i>CT0P3]kNd30=gMg@80moOg0P3MgMd2
0=WIf@80j>SX0P3alO420>OWi`80Ti>C0P3WinL20>g]k@80inOW0P30`<020?Shn080inOW0P3EeMD2
0:BTY580oooo000A0?ooo`P0no_k403oool20?Shn0<0I6AT0P2LW9`40=cLg080l_;b0P3]kNd20?3`
l080nOWi0P3clo<20>o_k`80hN7Q0P3Ng]h20>OWi`80l?3`0P3Rh^820>7Qh@80l_;b0P3hn?P20?Og
m`80n_[j103no_h20?KfmP80oooo103emOD40?Win@80m_Kf1P3inOT30?knoP80n?Sh2P3no_h20?oo
o`80o_kn0P3oool20?Gem@80nOWi0P3fm_H40?_kn`80oooo0P3_knl20?3`l080kNg]0P3oool20?Cd
m0@0oooo0P3hn?P20?Ogm`80j^[Z0P3clo<20=oOg`80kno_0P3YjNT20?Shn080j>SX0`3MgMd20?7a
l@80g=cL0P3Jf]X20?Gem@@0hn?S0P29RHT20?Gem@80n?Sh0P3`l?020;bl_080n?Sh0P3]kNd20::R
XP80j>SXDP3oool00140oooo203kno/@0?ooo`80n?Sh0`1TI6@209bLW0@0g=cL0P3bl_820>g]k@80
l?3`0P3inOT20??cl`80kno_0P3QhN420=kNgP80inOW0P3`l?020>;RhP80hN7Q0P3bl_820?Shn080
moOg0P3jn_X40?knoP80m_Kf0P3oool40?Gem@@0nOWi0P3fm_H60?Win@<0o_kn0P3hn?P:0?knoP80
oooo0P3no_h20?ooo`80mOGe0P3inOT20?KfmP@0no_k0P3oool20>o_k`80l?3`0P3]kNd20?ooo`80
m?Cd103oool20?Shn080moOg0P3Zj^X20??cl`80gmoO0P3_knl20>WYj@80n?Sh0P3Xj>P30=gMg@80
lO7a0P3Lg=`20=[JfP80mOGe103Shn<208V9R@80mOGe0P3hn?P20?3`l080_;bl0P3hn?P20>g]k@80
XZ:R0P3Xj>QB0?ooo`004@3oool80?_kna80oooo0`3Xj>P205MGE`80f][J0P3lo?`20?;blP80mOGe
0P3kno/20?;blP80m?Cd0P3]kNd20?KfmP80f][J0P3]kNd20>KViP80k^k^0P3UiND20?;blP80m_Kf
0P3inOT20?Gem@@0o_kn0P3inOT20?KfmP@0nOWi0P3no_h40?Win@80mOGe0P3inOT20?Ogm`<0o_kn
0P3hn?P40?knoPH0oooo103no_h20?Gem@80n_[j0P3kno/20?ooo`80m?Cd103hn?P20?Cdm080mOGe
0P3alO420?Shn080m?Cd0P3no_h40?Shn080m?Cd103emOD20>;RhP80mOGe0P3[jn/20>k^kP80j>SX
0`3?cll20=[JfP80i>CT0P3/k>`20?;blP80i^KV0P3`l?020820P080l_;b0P3gmoL20?;blP80]kNg
0P3Shn<20=?Cd`80/;2`E03oool00140oooo203kno/B0?ooo`<0j>SX0P1GEeL20=[JfP80o?cl0P3b
l_820?Gem@80no_k0P3bl_820?Cdm080kNg]0P3fm_H20=[JfP80kNg]0P3Vi^H20>k^kP80iNGU0P3b
l_820?KfmP80nOWi0P3emOD40?knoP80nOWi0P3fm_H40?Win@80o_kn103inOT20?Gem@80nOWi0P3g
moL30?knoP80n?Sh103no_h60?ooo`@0o_kn0P3emOD20?[jnP80no_k0P3oool20?Cdm0@0n?Sh0P3d
m?@20?Gem@80lO7a0P3hn?P20?Cdm080o_kn103hn?P20?Cdm0@0mOGe0P3Rh^820?Gem@80jn_[0P3^
k^h20>SXj0<0clo?0P3Jf]X20>CTi080k>c/0P3bl_820>KViP80l?3`0P20P8020?;blP80moOg0P3b
l_820;Ng]`80hn?S0P3Cdm<20;2`/5@0oooo000[0?ooo`<0n?Sh0P1VIVH20:BTY080lo?c0P3emOD2
0?KfmP80o?cl0P3dm?@20?Shn080kNg]0P3Vi^H20>;RhP80k^k^0P3Vi^H20>WYj@80j^[Z0P3clo<2
0?Cdm080no_k0P3dm?@40?knoPH0nOWi0P3emOD20?Shn0@0oooo0P3hn?P20?ooo`80moOg0`3inOT2
0?knoP80nOWi1P3no_h60?ooo`80m?Cd0P3emOD20?[jnP@0no_k0P3lo?`20?Shn080o_kn0P3oool2
0?7al@80n?Sh0P3dm?@20?knoP80n?Sh0P3oool20?Shn0@0l?3`0P3]kNd20??cl`80m?Cd0P3Vi^H2
0>WYj@<0c/k>0P3dm?@20>OWi`80n_[j0P3Ti>@20>_[j`80m_Kf0P1jNWX20>[ZjP80g=cL0P3]kNd2
0<?3``80eMGE0P32`/820=[JfP@0no_kD03oool002/0oooo0`3hn?P206IVIP80Y:BT0P3clo<20?Ge
m@80m_Kf0P3lo?`20?Cdm080n?Sh0P3]kNd20>KViP80h^;R0P3^k^h20>KViP80jNWY0P3Zj^X20??c
l`80m?Cd0P3kno/20?Cdm0@0o_kn1P3inOT20?Gem@80n?Sh103oool20?Shn080oooo0P3gmoL30?Wi
n@80o_kn0P3inOT60?knoPH0oooo0P3dm?@20?Gem@80n_[j103kno/20?clo080n?Sh0P3no_h20?oo
o`80lO7a0P3hn?P20?Cdm080o_kn0P3hn?P20?ooo`80n?Sh103`l?020>g]k@80lo?c0P3dm?@20>KV
iP80jNWY0`3>c/h20?Cdm080inOW0P3jn_X20>CTi080jn_[0P3fm_H207YjNP80j^[Z0P3Lg=`20>g]
k@80`l?30P3EeMD20<;2`P80f][J103kno]@0?ooo`003`3oool40?_kna/0oooo0P35aLD206EUI@80
hN7Q0P3`l?020?Gem@80n_[j0P3kno/20?[jnP80o?cl0P3Lg=`20>;RhP80i^KV0P3Ti>@20>[ZjP80
i^KV103gmoL40?Shn080no_k0P3no_h<0?Win@80n?Sh103inOT20?Shn0<0oooo0P3inOT20?Shn0X0
o_kn0P3oool20?Shn080n_[j0P3gmoL20?knoP80o?cl0P3jn_X40?ooo`80n?Sh0P3fm_H20?Shn080
lo?c0P3gmoL20?ooo`80mOGe0P3inOT20?Cdm080lO7a0P3emOD20>OWi`80m_Kf0P3Xj>P20>7Qh@<0
d=3@0P3hn?P20>[ZjP80oooo0P3dm?@20>WYj@80lo?c0P22PX820>CTi080clo?0P3Bd]820<o?c`80
alO70P33`l<20?ooo`@0no_kD03oool000l0oooo103kno/K0?ooo`80aLG50P1UIFD20>7Qh@80l?3`
0P3emOD20?[jnP80no_k0P3jn_X20?clo080g=cL0P3Rh^820>KViP80i>CT0P3Zj^X20>KViP@0moOg
103hn?P20?_kn`80o_kn303inOT20?Shn0@0nOWi0P3hn?P30?ooo`80nOWi0P3hn?P:0?knoP80oooo
0P3hn?P20?[jnP80moOg0P3no_h20?clo080n_[j103oool20?Shn080m_Kf0P3hn?P20??cl`80moOg
0P3oool20?Gem@80nOWi0P3dm?@20?7al@80mOGe0P3WinL20?KfmP80j>SX0P3QhN430=3@d080n?Sh
0P3Zj^X20?ooo`80m?Cd0P3YjNT20??cl`80PX:20P3Ti>@20<o?c`80d];B0P3?cll20<O7a`80`l?3
0P3oool40?_kne00oooo000?0?ooo`@0no_k6`3oool20?_kn`80E5AD0P3>c/h20>3Ph080kno_0P3c
lo<20?clo0@0n?Sh0P3Ph>020>CTi080f][J0P3Rh^820>SXj080l?3`103gmoL40?Shn080n_[j0P3o
ool40?knoP@0nOWi0P3emOD20?Shn080nOWi0P3oool70?knoP80oooo0P3no_h20?ooo`80o_kn0P3o
ool40?knoP@0n_[j0P3oool20?_kn`80o?cl0P3gmoL20?_kn`80o_kn0P3oool20??cl`80oooo0P3i
nOT20?Gem@80m_Kf0P3oool20?KfmP80moOg0P3clo<20>SXj080n_[j0P3WinL20?3`l080j>SX0P3U
iND30=gMg@80n_[j0P3/k>`20?Cdm080l_;b0P3]kNd20>?Sh`80PH610P3Ti>@20>KViP80e=CD0P3C
dm<20;bl_080f][JEP3oool000l0oooo103kno/K0?ooo`80no_k0P1DE5@20<k>cP80h>3P0P3_knl2
0??cl`80o?cl103hn?P20>3Ph080i>CT0P3Jf]X20>;RhP80j>SX0P3`l?040?Ogm`@0n?Sh0P3jn_X2
0?ooo`@0o_kn103inOT20?Gem@80n?Sh0P3inOT20?ooo`L0o_kn0P3oool20?knoP80oooo0P3no_h2
0?ooo`@0o_kn103jn_X20?ooo`80no_k0P3lo?`20?Ogm`80no_k0P3no_h20?ooo`80lo?c0P3oool2
0?Win@80mOGe0P3fm_H20?ooo`80m_Kf0P3gmoL20??cl`80j>SX0P3jn_X20>OWi`80l?3`0P3Xj>P2
0>GUi@<0gMgM0P3jn_X20>c/k080m?Cd0P3bl_820>g]k@80hn?S0P21PH420>CTi080i^KV0P3De=@2
0=?Cd`80_;bl0P3Jf]YF0?ooo`00<03oool208f=S@80J6QX0P2LW9`20=GEe@80i^KV0P3Ogml20>_[
j`80oOgm0P3Vi^H20>SXj080gmoO0P3Ng]h20>3Ph080m_Kf0P3gmoL40?Shn080nOWi0P3fm_H20?[j
nP80o_kn0P3oool20?Shn080mOGe0P3inOT20?ooo`80nOWi0P3hn?P90?knoP80oooo1P3jn_X40?Sh
n0@0n_[j0P3hn?P20?knoP80nOWi0P3jn_X40?ooo`80m?Cd0P3fm_H20?knoP80n?Sh0P3gmoL20?_k
n`80m?Cd0P3gmoL20?clo080gmoO0P3dm?@20>k^kP80lo?c103WinL20>GUi@<0lo?c0P3/k>`20?Kf
mP80k>c/0P3clo<20>3Ph080gmoO0P1lO7`20>[ZjP80moOg0P3@d=020=[JfP80ZZZZ103kno]D0?oo
o`00<03oool208f=S@80J6QX0P2LW9`20=GEe@80i^KV0P3Ogml20>_[j`80oOgm0P3Vi^H20>SXj080
gmoO0P3Ng]h20>3Ph080m_Kf0P3gmoL40?Shn080nOWi0P3fm_H20?[jnP80o_kn0P3oool20?Shn080
mOGe0P3inOT20?ooo`80nOWi0P3hn?P90?knoP80oooo1P3jn_X40?Shn0@0n_[j0P3hn?P20?knoP80
nOWi0P3jn_X40?ooo`80m?Cd0P3fm_H20?knoP80n?Sh0P3gmoL20?_kn`80m?Cd0P3gmoL20?clo080
gmoO0P3dm?@20>k^kP80lo?c103WinL20>GUi@<0lo?c0P3/k>`20?KfmP80k>c/0P3clo<20>3Ph080
gmoO0P1lO7`20>[ZjP80moOg0P3@d=020=[JfP80ZZZZ103kno]D0?ooo`003`3oool40?_kna00oooo
103kno/90?ooo`80m?Cd0P2m_Kd207inOP80RXZ:0P3jn_X20>o_k`80moOg0P3alO420?3`l080gmoO
0P3Ti>@20>_[j`80h>3P0P3Vi^H20?knoP80oooo0P3dm?@20?gmo@80n?Sh0P3jn_X40?_kn`80oooo
0P3no_h20?ooo`80o_kn103inOT20?knoP80oooo0`3no_h40?ooo`@0n_[j0P3hn?P40?ooo`80n_[j
0P3oool20?7al@@0moOg0P3no_h40?ooo`80l_;b0P3moOd20?Shn080no_k0P3gmoL20?ooo`80j>SX
0P3inOT20>g]k@80jn_[0P3gmoL20>GUi@80hn?S0P3Jf]X20?Ogm`80i>CT0`3bl_820>c/k080l_;b
0P3fm_H20>SXj080lO7a0P27QhL20;^k^`80g=cL0P3WinL20=oOg`80a/K60P2d];@40?_kne@0oooo
000?0?ooo`@0no_k403oool40?_kn`T0oooo0P3dm?@20;fm_@80OWin0P2:RXX20?[jnP80kno_0P3g
moL20?7al@80l?3`0P3Ogml20>CTi080jn_[0P3Ph>020>KViP80o_kn0P3oool20?Cdm080oOgm0P3h
n?P20?[jnP@0no_k0P3oool20?knoP80oooo0P3no_h40?Win@80o_kn0P3oool30?knoP@0oooo103j
n_X20?Shn0@0oooo0P3jn_X20?ooo`80lO7a103gmoL20?knoP@0oooo0P3bl_820?gmo@80n?Sh0P3k
no/20?Ogm`80oooo0P3Xj>P20?Win@80kNg]0P3[jn/20?Ogm`80iNGU0P3Shn<20=[JfP80moOg0P3T
i>@30?;blP80k>c/0P3bl_820?KfmP80j>SX0P3alO4208N7Q`80^k^k0P3Lg=`20>OWi`80gmoO0P36
a/H20;Bd]0@0no_kE03oool000l0oooo103kno/@0?ooo`@0no_k2@3oool20?Shn080m?Cd0P3bl_82
06YZJP80b<S80P3dm?@20?Gem@80l?3`0P3moOd20>7Qh@80g]kN0P3/k>`20>OWi`80i^KV0P3bl_82
0?Cdm0@0n?Sh0P3inOT20??cl`80nOWi103kno/20?knoP80oooo103jn_X40?ooo`D0n_[j0P3hn?P6
0?KfmP80n_[j0P3oool20?clo080m?Cd0P3`l?020?Shn0H0oooo0P3no_h20?ooo`80l_;b0P3hn?P4
0?ooo`80moOg0P3hn?P20>o_k`80oooo0P3clo<20>_[j`80inOW0P3Ogml20>WYj@80l?3`0P3inOT2
0>[ZjP<0f=SH0P3hn?P20>g]k@80lO7a0P3Rh^8208Z:RP80TI6A0P3alO420>OWi`80clo?0P3;bl/2
0:b/[080f][J0P3kno/20?Win@80no_kDP3oool000l0oooo103kno/@0?ooo`@0no_k2@3oool20?Sh
n080m?Cd0P3bl_8206YZJP80b<S80P3dm?@20?Gem@80l?3`0P3moOd20>7Qh@80g]kN0P3/k>`20>OW
i`80i^KV0P3bl_820?Cdm0@0n?Sh0P3inOT20??cl`80nOWi103kno/20?knoP80oooo103jn_X40?oo
o`D0n_[j0P3hn?P60?KfmP80n_[j0P3oool20?clo080m?Cd0P3`l?020?Shn0H0oooo0P3no_h20?oo
o`80l_;b0P3hn?P40?ooo`80moOg0P3hn?P20>o_k`80oooo0P3clo<20>_[j`80inOW0P3Ogml20>WY
j@80l?3`0P3inOT20>[ZjP<0f=SH0P3hn?P20>g]k@80lO7a0P3Rh^8208Z:RP80TI6A0P3alO420>OW
i`80clo?0P3;bl/20:b/[080f][J0P3kno/20?Win@80no_kDP3oool003@0oooo0P3dm?@209^KV`80
JVYZ0P3Jf]X20>CTi080inOW0P3Vi^H20>SXj0@0i^KV0P3WinL20>g]k@80nOWi0P3clo<20?ooo`80
moOg103kno/20?Ogm`@0n_[j0P3hn?P20?[jnP80oooo0P3jn_X40?ooo`80n_[j0`3oool20?Win@@0
n?Sh0P3inOT40?Shn080no_k0P3fm_H<0?ooo`80moOg0P3inOT20?Shn080o_kn0P3hn?P20?KfmP80
no_k0P3Ti>@20?7al@80mOGe0P3Ng]h20>c/k080k^k^0P3bl_840>g]k@80k>c/0`3MgMd20<C4a080
hn?S0P3clo<20;fm_@80ZZZZ0P3Jf]X20>g]k@80l_;b0P3;bl/20<K6aP80`<300P3alO420?Win@80
lo?c0P3fm_IB0?ooo`00=03oool20?Cdm080Vi^K0P1ZJVX20=[JfP80i>CT0P3WinL20>KViP80j>SX
103Vi^H20>OWi`80kNg]0P3inOT20??cl`80oooo0P3gmoL40?_kn`80moOg103jn_X20?Shn080n_[j
0P3oool20?[jnP@0oooo0P3jn_X30?ooo`80nOWi103hn?P20?Win@@0n?Sh0P3kno/20?KfmP`0oooo
0P3gmoL20?Win@80n?Sh0P3no_h20?Shn080m_Kf0P3kno/20>CTi080lO7a0P3emOD20=kNgP80k>c/
0P3^k^h20?;blP@0kNg]0P3/k>`30=gMg@80a<C40P3Shn<20??cl`80_Kfm0P2ZZZX20=[JfP80kNg]
0P3bl_820<_;b`80a/K60P30`<020?7al@80nOWi0P3clo<20?KfmU80oooo000d0?ooo`80m?Cd0P2]
[Jd206m_K`80gMgM0P3IfMT20>KViP80e=CD0P3oool40>KViP80inOW0P3bl_820>c/k080moOg103n
o_h20?Ogm`80m_Kf0P3alO420?Gem@80o_kn1P3jn_X60?Shn080n_[j0`3dm?@20?Win@80l_;b0P3`
l?020?Shn0@0lO7a103gmoL20?knoPH0oooo0P3no_h20?ooo`80kno_0P3fm_H60?Shn080o_kn0P3g
moL20>;RhP80lo?c0P3Vi^H20=oOg`80jn_[0P3YjNT20>OWi`80kNg]0P3^k^h20?Cdm0<0g]kN0P3G
emL20<S8b080alO70P3Fe]H20=SHf080h^;R0P3clo<20=cLg080b/[:0P3GemL20;bl_0@0lo?c0P3f
m_H20?Shn580oooo000d0?ooo`80m?Cd0P2][Jd206m_K`80gMgM0P3IfMT20>KViP80e=CD0P3oool4
0>KViP80inOW0P3bl_820>c/k080moOg103no_h20?Ogm`80m_Kf0P3alO420?Gem@80o_kn1P3jn_X6
0?Shn080n_[j0`3dm?@20?Win@80l_;b0P3`l?020?Shn0@0lO7a103gmoL20?knoPH0oooo0P3no_h2
0?ooo`80kno_0P3fm_H60?Shn080o_kn0P3gmoL20>;RhP80lo?c0P3Vi^H20=oOg`80jn_[0P3YjNT2
0>OWi`80kNg]0P3^k^h20?Cdm0<0g]kN0P3GemL20<S8b080alO70P3Fe]H20=SHf080h^;R0P3clo<2
0=cLg080b/[:0P3GemL20;bl_0@0lo?c0P3fm_H20?Shn580oooo000d0?ooo`80m?Cd0P2EUID20<[:
bP80Zj^[0P3_knl20?;blP80g=cL0P3QhN420>?Sh`@0i>CT0P3[jn/20??cl`80lO7a0P3hn?P20?Cd
m080l?3`0P3lo?`20?Cdm080moOg0P3kno/20?Gem@80m_Kf0P3kno/20?ooo`80n_[j0P3fm_H20??c
l`<0l_;b103kno/20?Cdm080kNg]103alO420?Cdm080oooo0P3inOT40??cl`80l_;b103]kNd20>WY
j@@0m_Kf0P3_knl20?Cdm080kno_0P3Ti>@20>g]k@80n?Sh0P3alO420>[ZjP80nOWi0P3YjNT20>GU
i@80l_;b0P3_knl20?3`l0<0hn?S0P3^k^h20>CTi080/[:b0P2j^[X20<o?c`80lO7a0P3;bl/20>OW
i`80bl_;0P2n_[h20<_;b`80n?Sh0P3clo<20?_kn`80oooo103hn?PQ0?ooo`@0n?Sh:@3oool003@0
oooo0P3dm?@209FEU@80b/[:0P2[Zj/20>o_k`80l_;b0P3Lg=`20>7Qh@80hn?S103Ti>@20>_[j`80
lo?c0P3alO420?Shn080m?Cd0P3`l?020?clo080m?Cd0P3gmoL20?_kn`80mOGe0P3fm_H20?_kn`80
oooo0P3jn_X20?KfmP80lo?c0`3bl_840?_kn`80m?Cd0P3]kNd40?7al@80m?Cd0P3oool20?Win@@0
lo?c0P3bl_840>g]k@80jNWY103fm_H20>o_k`80m?Cd0P3_knl20>CTi080kNg]0P3hn?P20?7al@80
j^[Z0P3inOT20>WYj@80iNGU0P3bl_820>o_k`80l?3`0`3Shn<20>k^kP80i>CT0P2b/[820;Zj^P80
clo?0P3alO420<_;b`80inOW0P3;bl/20;jn_P80bl_;0P3hn?P20??cl`80no_k0P3oool40?Shn240
oooo103hn?PY0?ooo`00=03oool20?Shn080/;2`0P2m_Kd205YJFP80g]kN0P3Ph>020?3`l080fm_K
0P3WinL20>c/k080i^KV0P3YjNT20?Ogm`@0l_;b0P3emOD20>g]k@80n_[j0P3hn?P20?KfmP80oooo
0P3jn_X20?clo080moOg0P3emOD40?7al@80nOWi0`3jn_X20?Shn080l?3`0P3[jn/20?Gem@@0n?Sh
0P3alO420>SXj080inOW103_knl20>SXj080kNg]0P3emOD20>k^kP@0m?Cd0P3gmoL20?Cdm080moOg
0P3_knl20?;blP80l?3`0P3inOT20>g]k@80n_[j0P3QhN420>[ZjP80lo?c0P3bl_820>3Ph0<0dm?C
0P3YjNT20=CDe080Z:RX0P3Ogml20>o_k`80hN7Q0P32`/820=kNgP80fm_K0P2k^k/20?_kn`80oooo
0P3kno/20??cl`H0n?Sh503oool40?_kn`T0oooo103hn?PY0?ooo`00=03oool20?Shn080/;2`0P2m
_Kd205YJFP80g]kN0P3Ph>020?3`l080fm_K0P3WinL20>c/k080i^KV0P3YjNT20?Ogm`@0l_;b0P3e
mOD20>g]k@80n_[j0P3hn?P20?KfmP80oooo0P3jn_X20?clo080moOg0P3emOD40?7al@80nOWi0`3j
n_X20?Shn080l?3`0P3[jn/20?Gem@@0n?Sh0P3alO420>SXj080inOW103_knl20>SXj080kNg]0P3e
mOD20>k^kP@0m?Cd0P3gmoL20?Cdm080moOg0P3_knl20?;blP80l?3`0P3inOT20>g]k@80n_[j0P3Q
hN420>[ZjP80lo?c0P3bl_820>3Ph0<0dm?C0P3YjNT20=CDe080Z:RX0P3Ogml20>o_k`80hN7Q0P32
`/820=kNgP80fm_K0P2k^k/20?_kn`80oooo0P3kno/20??cl`H0n?Sh503oool40?_kn`T0oooo103h
n?PY0?ooo`00=P3oool20>WYj@80_Kfm0P1hN7P20;jn_P80hN7Q0P3jn_X20?3`l080hN7Q0P3UiND2
0=?Cd`80i>CT0P3`l?020?_kn`80mOGe0P3inOT20?;blP80lO7a103moOd20?[jnP80n?Sh0P3gmoL6
0??cl`80kno_0P3Vi^H30>3Ph080i>CT103^k^h20?3`l080j^[Z0P3Shn<20=kNgP80hN7Q0P3Xj>P2
0>WYj@80inOW0P3[jn/20>KViP80f][J0P3QhN440>CTi080hN7Q0P3Ph>020>[ZjP80k>c/0P3alO42
0?Shn080i^KV0P3Jf]X20>k^kP80jn_[0P3^k^h20>o_k`80gmoO0P3inOT30?7al@80gmoO0P3MgMd2
0>CTi080i^KV0P3Ph>020?Gem@80d=3@0P3Vi^H20=GEe@80bl_;0P3kno/40?ooo`@0n?Sh603oool4
0?_kncH0oooo000f0?ooo`80jNWY0P2m_Kd207QhN080_[jn0P3QhN420?[jnP80l?3`0P3QhN420>GU
i@80dm?C0P3Ti>@20?3`l080no_k0P3emOD20?Win@80l_;b0P3alO440?gmo@80n_[j0P3hn?P20?Og
m`H0lo?c0P3_knl20>KViP<0h>3P0P3Ti>@40>k^kP80l?3`0P3Zj^X20>?Sh`80g]kN0P3QhN420>SX
j080jNWY0P3WinL20>_[j`80i^KV0P3Jf]X20>7Qh@@0i>CT0P3QhN420>3Ph080j^[Z0P3/k>`20?7a
l@80n?Sh0P3Vi^H20=[JfP80k^k^0P3[jn/20>k^kP80kno_0P3Ogml20?Win@<0lO7a0P3Ogml20=gM
g@80i>CT0P3Vi^H20>3Ph080mOGe0P3@d=020>KViP80eMGE0P3;bl/20?_kn`@0oooo103hn?PH0?oo
o`@0no_k=P3oool003P0oooo0P2f][H208b<S080[jn_0P3YjNT20>g]k@80oooo0P3WinL20>_[j`80
l_;b0P3De=@20<_;b`80h>3P0P3jn_X20?Gem@80lO7a0P3dm?@20?Ogm`@0lo?c0P3dm?@20>_[j`80
k>c/103UiND20?Ogm`80jn_[1@3emOD20?Cdm080i>CT0P3Zj^X20>CTi080jNWY0P3Zj^X20>g]k@80
hn?S0P3Ph>020=kNgP80f][J0P3Ng]h20>3Ph080iNGU0P3[jn/20>KViP80k^k^0P3hn?P20>[ZjP80
kNg]0P3fm_H20>[ZjP80jNWY0P3IfMT20>GUi@80j^[Z0P3`l?020>CTi080k^k^0P3;bl/30>o_k`80
cLg=0P3QhN440>?Sh`80gMgM0P3QhN420=7Ad@80l_;b0P2m_Kd20?Win@X0oooo103kno/Q0?ooo`@0
n?Sh:@3oool003P0oooo0P2f][H208b<S080[jn_0P3YjNT20>g]k@80oooo0P3WinL20>_[j`80l_;b
0P3De=@20<_;b`80h>3P0P3jn_X20?Gem@80lO7a0P3dm?@20?Ogm`@0lo?c0P3dm?@20>_[j`80k>c/
103UiND20?Ogm`80jn_[1@3emOD20?Cdm080i>CT0P3Zj^X20>CTi080jNWY0P3Zj^X20>g]k@80hn?S
0P3Ph>020=kNgP80f][J0P3Ng]h20>3Ph080iNGU0P3[jn/20>KViP80k^k^0P3hn?P20>[ZjP80kNg]
0P3fm_H20>[ZjP80jNWY0P3IfMT20>GUi@80j^[Z0P3`l?020>CTi080k^k^0P3;bl/30>o_k`80cLg=
0P3QhN440>?Sh`80gMgM0P3QhN420=7Ad@80l_;b0P2m_Kd20?Win@X0oooo103kno/Q0?ooo`@0n?Sh
:@3oool003X0oooo0P2j^[X207MgM`80N7Qh0P3De=@20??cl`80g=cL0P3[jn/20=cLg080e=CD0P3]
kNd20=KFeP80j^[Z0P3]kNd40?Shn080nOWi0P3fm_H20>o_k`80i^KV0P3/k>`20?KfmP80moOg0P3h
n?P20>SXj080j^[Z0`3moOd20>c/k080i^KV0P3Ti>@20>g]k@80j^[Z103_knl20=kNgP80hn?S0P3^
k^h20=[JfP80h>3P0P3/k>`20?7al@80i>CT0P3UiND20>OWi`80kNg]0P3_knl20?Cdm080h^;R0P35
aLD20=KFeP80inOW0P3YjNT20?;blP80kNg]0P3[jn/20?7al@80dm?C0P3]kNd30<o?c`80a<C40P3H
f=P20??cl`80kno_0P3;bl/20=SHf080lO7a0P2o_kl20<_;b`@0oooo103kno/40?ooo`@0no_k603o
ool40?_kn`D0oooo103hn?PY0?ooo`00>P3oool20;Zj^P80MgMg0P1hN7P20=CDe080lo?c0P3Lg=`2
0>_[j`80g=cL0P3De=@20>g]k@80e]KF0P3Zj^X20>g]k@@0n?Sh0P3inOT20?KfmP80kno_0P3Vi^H2
0>c/k080m_Kf0P3gmoL20?Shn080j>SX0P3Zj^X30?gmo@80k>c/0P3Vi^H20>CTi080kNg]0P3Zj^X4
0>o_k`80g]kN0P3Shn<20>k^kP80f][J0P3Ph>020>c/k080lO7a0P3Ti>@20>GUi@80inOW0P3]kNd2
0>o_k`80m?Cd0P3Rh^820<G5a@80e]KF0P3WinL20>WYj@80l_;b0P3]kNd20>_[j`80lO7a0P3Cdm<2
0>g]k@<0clo?0P34a<@20=SHf080lo?c0P3_knl20<_;b`80f=SH0P3alO420;no_`80bl_;103oool4
0?_kn`@0oooo103kno/H0?ooo`@0no_k1@3oool40?Shn2T0oooo000K0?ooo`P0no_k6@3oool20?;b
lP80NWYj0P3UiND20=WIf@80h^;R0P3Zj^X20<W9b@80^KVi0P3^k^h20=_Kf`80i>CT0P3Kfm/20>SX
j080lo?c0P3bl_820?7al@80lo?c0P3fm_H20?_kn`@0jNWY103emOD20>[ZjP<0jn_[0P3/k>`20?Kf
mP80l?3`0P3gmoL20>KViP80h^;R0P3Zj^X20?7al@80k>c/0P3emOD20?Cdm080g]kN0P3dm?@20?7a
l@80kno_0P3gmoL20>k^kP80o?cl0P3inOT20?7al@80dm?C0P3bl_820>o_k`80moOg0P3_knl40?Kf
mP80l?3`0P3_knl20>SXj080kNg]0`3kno/20?7al@80j^[Z0P3>c/h20<C4a080j^[Z0P3dm?@20>?S
h`80Z:RX1P3oool40?KfmR00oooo103kno/b0?ooo`006`3oool80?_knaT0oooo0P3bl_8207YjNP80
iNGU0P3IfMT20>;RhP80j^[Z0P39bLT20;Vi^@80k^k^0P3Kfm/20>CTi080fm_K0P3Xj>P20??cl`80
l_;b0P3alO420??cl`80m_Kf0P3kno/40>WYj@@0mOGe0P3Zj^X30>_[j`80k>c/0P3fm_H20?3`l080
moOg0P3Vi^H20>;RhP80j^[Z0P3alO420>c/k080mOGe0P3dm?@20=kNgP80m?Cd0P3alO420>o_k`80
moOg0P3^k^h20?clo080nOWi0P3alO420=?Cd`80l_;b0P3_knl20?Ogm`80kno_103fm_H20?3`l080
kno_0P3Xj>P20>g]k@<0no_k0P3alO420>[ZjP80c/k>0P34a<@20>[ZjP80m?Cd0P3Shn<20:RXZ0H0
oooo103fm_HP0?ooo`@0no_k<P3oool00140oooo103kno/60?ooo`P0no_k6`3oool209ZJVP80Q8B4
0P3clo<20>o_k`80j^[Z0P37alL20=CDe080h^;R0P3Kfm/20?Cdm080l_;b0P3jn_X20>k^kP80kNg]
0P3gmoL20>c/k0@0lO7a0P3Shn<20>o_k`@0inOW1@3_knl20>[ZjP80n_[j103YjNT20?Gem@80i>CT
0P3Rh^820>g]k@80l_;b0P3Vi^H20>GUi@80kNg]0P3bl_820=3@d080b<S80P3Kfm/20>WYj@80l_;b
0P3kno/20>KViP80h^;R0P3inOT20=[JfP80aLG50P3=cLd20=oOg`80fm_K0P3Fe]H20>GUi@80inOW
0P3[jn/30??cl`80clo?0P34a<@20<;2`P80inOW0P3_knl20=[JfP80X:2P0P3MgMd60?ooo`@0n?Sh
EP3oool00140oooo103kno/60?ooo`P0no_k6`3oool209ZJVP80Q8B40P3clo<20>o_k`80j^[Z0P37
alL20=CDe080h^;R0P3Kfm/20?Cdm080l_;b0P3jn_X20>k^kP80kNg]0P3gmoL20>c/k0@0lO7a0P3S
hn<20>o_k`@0inOW1@3_knl20>[ZjP80n_[j103YjNT20?Gem@80i>CT0P3Rh^820>g]k@80l_;b0P3V
i^H20>GUi@80kNg]0P3bl_820=3@d080b<S80P3Kfm/20>WYj@80l_;b0P3kno/20>KViP80h^;R0P3i
nOT20=[JfP80aLG50P3=cLd20=oOg`80fm_K0P3Fe]H20>GUi@80inOW0P3[jn/30??cl`80clo?0P34
a<@20<;2`P80inOW0P3_knl20=[JfP80X:2P0P3MgMd60?ooo`@0n?ShEP3oool00140oooo103kno/Y
0?ooo`80n?Sh0P23Ph<208R8R080hN7Q0P3]kNd20<o?c`80hN7Q0P3Shn<20=OGe`80i^KV0P3lo?`2
0?_kn`80jn_[0P3^k^h20>c/k080l?3`103gmoL20>g]k@80n?Sh0P3`l?020?7al@80n_[j0`3inOT2
0>KViP80i>CT0P3@d=020?3`l080kno_0P3IfMT20=OGe`80clo?0P3Lg=`20>OWi`80l_;b103oool2
0=SHf080emOG0P3WinL20=7Ad@80/[:b0P35aLD20>;RhP80j^[Z0P3alO420??cl`80hN7Q0P3Hf=P2
0>WYj@@0l?3`0P3^k^h20>KViP80[:b/0`2k^k/20<c<c080fm_K0P2g]kL20;^k^`80hN7Q0P3Rh^82
08Z:RP80n?Sh303oool40?_kne00oooo000A0?ooo`@0no_k:@3oool20?Shn080Ph>30P28R8P20>7Q
h@80kNg]0P3?cll20>7Qh@80hn?S0P3GemL20>KViP80o?cl0P3kno/20>_[j`80k^k^0P3/k>`20?3`
l0@0moOg0P3]kNd20?Shn080l?3`0P3alO420?[jnP<0nOWi0P3Vi^H20>CTi080d=3@0P3`l?020>o_
k`80fMWI0P3GemL20<o?c`80g=cL0P3WinL20?;blP@0oooo0P3Hf=P20=OGe`80inOW0P3AdM420;:b
/P80aLG50P3Rh^820>[ZjP80lO7a0P3clo<20>7Qh@80f=SH0P3YjNT40?3`l080k^k^0P3Vi^H20:b/
[0<0^k^k0P3<c<`20=_Kf`80]kNg0P2k^k/20>7Qh@80h^;R0P2:RXX20?Shn0`0oooo103kno]@0?oo
o`00@03oool20?Shn080QHF50P3EeMD20>?Sh`80a<C41032`/820<k>cP80l?3`0P3kno/20?clo080
hn?S0P3emOD20?Cdm080kNg]0P3dm?@20?Ogm`80kno_0P3[jn/20?;blP80n_[j0P3bl_830>k^kP80
m?Cd103Vi^H20>;RhP80h>3P0P3]kNd20;Jf]P80h^;R0P3oool20?;blP80e]KF0P3Shn<20=_Kf`80
hN7Q0P3]kNd20<S8b080f][J0P3/k>`20=oOg`80k>c/0P3hn?P20?Cdm080o_kn0P3]kNd20>3Ph080
iNGU0P3`l?020=?Cd`80aLG50P34a<@20=KFeP<0k^k^0P3Lg=`20=GEe@80^[Zj0P2o_kl20=cLg080
OWin0P3Kfm/20?Shn0@0oooo103kno/20?ooo`80no_k0P3oool20?_knaP0oooo103kno/20?ooo`D0
n?Sh;@3oool00400oooo0P3hn?P208F5Q@80eMGE0P3Shn<20<C4a0@0`/;20P3>c/h20?3`l080no_k
0P3lo?`20>?Sh`80mOGe0P3dm?@20>g]k@80m?Cd0P3gmoL20>o_k`80jn_[0P3bl_820?[jnP80l_;b
0`3^k^h20?Cdm0@0i^KV0P3Rh^820>3Ph080kNg]0P2f][H20>;RhP80oooo0P3bl_820=KFeP80hn?S
0P3Kfm/20>7Qh@80kNg]0P38b<P20=[JfP80k>c/0P3Ogml20>c/k080n?Sh0P3dm?@20?knoP80kNg]
0P3Ph>020>GUi@80l?3`0P3Cdm<20<G5a@80a<C40P3Fe]H30>k^kP80g=cL0P3EeMD20;Zj^P80_kno
0P3Lg=`207inOP80fm_K0P3hn?P40?ooo`@0no_k0P3oool20?_kn`80oooo0P3kno/H0?ooo`@0no_k
0P3oool50?Shn2d0oooo00120?ooo`80][Jf0P1eMGD20?;blP80aLG50P3AdM420>[ZjP80fMWI0P3P
h>020?Shn080m_Kf0P3_knl20=GEe@80hn?S0P3/k>`20>_[j`80oooo0P3`l?020>OWi`80k>c/0P3j
n_X50>c/k080m?Cd0P3WinL20>k^kP80d=3@0P3^k^h20=cLg080i^KV0P3Ng]h20=gMg@80jNWY0P3g
moL20>o_k`80k^k^0P3emOD20?Ogm`@0kno_0P3emOD20=oOg`80j>SX0P3kno/20?;blP80kNg]0P3f
m_H20?3`l080e=CD0P3QhN420?;blP80l?3`0P3GemL20>WYj@<0h^;R0P2VYZH20<g=c@80gMgM0P3T
i>@20;Rh^080V9RH0P3inOT20?_kn`80oooo0P3kno/20?ooo`@0no_k0P3oool20?_kn`@0n?Sh1P3o
ool40?Shn0`0oooo103kno/20?ooo`D0n?Sh;@3oool00480oooo0P2f][H207EeM@80l_;b0P35aLD2
0=7Ad@80j^[Z0P3IfMT20>3Ph080n?Sh0P3fm_H20>o_k`80eMGE0P3Shn<20>c/k080jn_[0P3oool2
0?3`l080inOW0P3/k>`20?[jnPD0k>c/0P3dm?@20>OWi`80k^k^0P3@d=020>k^kP80g=cL0P3Vi^H2
0=kNgP80gMgM0P3YjNT20?Ogm`80kno_0P3^k^h20?Gem@80moOg103_knl20?Gem@80gmoO0P3Xj>P2
0?_kn`80l_;b0P3]kNd20?KfmP80l?3`0P3De=@20>7Qh@80l_;b0P3`l?020=OGe`80jNWY0`3Rh^82
0:JVYP80cLg=0P3MgMd20>CTi080^;Rh0P2HV9P20?Win@80no_k0P3oool20?_kn`80oooo103kno/2
0?ooo`80no_k103hn?P60?ooo`@0n?Sh303oool40?_kn`80oooo1@3hn?P]0?ooo`00@P3oool20?Sh
n080J6QX0P27QhL20<K6aP80cLg=0P3Ogml20>KViP80lO7a0P3Ng]h20??cl`80kno_0P32`/820>_[
j`80l?3`0P3Vi^H20>?Sh`80i^KV0P3YjNT20>KViP80nOWi0P3Zj^X50>CTi080jn_[0P39bLT20=SH
f0@0m?Cd0P3Xj>P20<k>cP80emOG0P3Shn<20>o_k`@0moOg0P3fm_H20?Win@80l?3`0P3Ti>@20=oO
g`80l_;b0P3_knl20>KViP80kno_0P3Xj>P20>KViP80k^k^0P3IfMT20=gMg@80eMGE0P2h^;P20<30
`080o_kn0`3:b/X20>c/k080eMGE0P3Xj>P20;Ng]`80WYjN0P3Vi^H20??cl`80nOWi0P3oool40?_k
n`80oooo103kno/20?ooo`@0n?Sh1P3oool40?Shn4@0oooo00120?ooo`80n?Sh0P1XJ6P208N7Q`80
a/K60P3=cLd20=oOg`80i^KV0P3alO420=kNgP80lo?c0P3_knl20<;2`P80jn_[0P3`l?020>KViP80
hn?S0P3Vi^H20>WYj@80i^KV0P3inOT20>[ZjPD0i>CT0P3[jn/20<W9b@80f=SH103dm?@20>SXj080
c/k>0P3GemL20>?Sh`80kno_103gmoL20?KfmP80nOWi0P3`l?020>CTi080gmoO0P3bl_820>o_k`80
i^KV0P3_knl20>SXj080i^KV0P3^k^h20=WIf@80gMgM0P3EeMD20;Rh^080`<300P3no_h30<[:bP80
k>c/0P3EeMD20>SXj080]kNg0P2NWYh20>KViP80lo?c0P3inOT20?ooo`@0no_k0P3oool40?_kn`80
oooo103hn?P60?ooo`@0n?ShA03oool00480oooo103kno/208b<S080E5AD0P3Zj^X20:JVYP80dM7A
0P3^k^h20=7Ad@80nOWi0P3/k>`20;jn_P80j>SX0P3^k^h20>WYj@80k>c/0P3Zj^X20=gMg@80nOWi
0P3YjNT20>g]k@D0l_;b0P3emOD20=OGe`80g]kN0P3jn_X20?3`l080gmoO0P3De=@20;Ng]`80g=cL
0P3Fe]H20=oOg`80nOWi0P3Ti>@20?7al@80lo?c0P3_knl20?Gem@80kNg]0P3YjNT20>KViP80gMgM
0P3Lg=`20>[ZjP80_[jn0P3Hf=P20>?Sh`80jn_[0P3clo<209jNWP80[Zj^0`3UiND20>CTi080iNGU
0P3gmoL2071`L080l?3`0P3dm?@20?KfmP80no_k0P3oool40?_kn`@0n?Sh503oool40?_kna40oooo
103hn?PY0?ooo`00@P3oool40?_kn`80S8b<0P1DE5@20>[ZjP80YZJV0P3AdM420>k^kP80dM7A0P3i
nOT20>c/k080_[jn0P3Xj>P20>k^kP80jNWY0P3/k>`20>[ZjP80gMgM0P3inOT20>WYj@80kNg]1@3b
l_820?Gem@80emOG0P3Ng]h20?[jnP80l?3`0P3Ogml20=CDe080]kNg0P3Lg=`20=KFeP80gmoO0P3i
nOT20>CTi080lO7a0P3clo<20>o_k`80mOGe0P3]kNd20>WYj@80i^KV0P3MgMd20=cLg080j^[Z0P2n
_[h20=SHf080hn?S0P3[jn/20??cl`80WYjN0P2^[Zh30>GUi@80i>CT0P3UiND20?Ogm`80L71`0P3`
l?020?Cdm080m_Kf0P3kno/20?ooo`@0no_k103hn?PD0?ooo`@0no_k4@3oool40?Shn2T0oooo000G
0?ooo`@0no_k9`3oool40?_kn`80n?Sh0P26QXH207UiN@80j>SX0P3Bd]820<k>cP80eMGE0P3Ph>02
0?[jnP80^[Zj0P3Ti>@20=KFeP80n_[j0P3emOD20=GEe@80hN7Q0P3Ng]h20>GUi@80i>CT0`3/k>`2
0??cl`80inOW0P3hn?P20>o_k`80k^k^0P3bl_820>k^kP80`<300P36a/H20?Cdm080cLg=0P3Ti>@2
0?Cdm080inOW0P3Ogml20>OWi`80dM7A0P30`<020=CDe080cLg=0P2g]kL20;:b/P80b<S80P3?cll2
0>CTi080cLg=0P3@d=020=oOg`80alO70P2d];@20=3@d0<0j>SX0P3clo<20=OGe`80OGem0P2g]kL8
0?ooo`80n?Sh0P3clo<20?ooo`80lo?c0P3hn?P60?ooo`@0n?Sh2P3oool40?_kn`@0n?Sh3@3oool4
0?Shn2T0oooo000G0?ooo`@0no_k9`3oool40?_kn`80n?Sh0P26QXH207UiN@80j>SX0P3Bd]820<k>
cP80eMGE0P3Ph>020?[jnP80^[Zj0P3Ti>@20=KFeP80n_[j0P3emOD20=GEe@80hN7Q0P3Ng]h20>GU
i@80i>CT0`3/k>`20??cl`80inOW0P3hn?P20>o_k`80k^k^0P3bl_820>k^kP80`<300P36a/H20?Cd
m080cLg=0P3Ti>@20?Cdm080inOW0P3Ogml20>OWi`80dM7A0P30`<020=CDe080cLg=0P2g]kL20;:b
/P80b<S80P3?cll20>CTi080cLg=0P3@d=020=oOg`80alO70P2d];@20=3@d0<0j>SX0P3clo<20=OG
e`80OGem0P2g]kL80?ooo`80n?Sh0P3clo<20?ooo`80lo?c0P3hn?P60?ooo`@0n?Sh2P3oool40?_k
n`@0n?Sh3@3oool40?Shn2T0oooo000G0?ooo`@0no_k;@3oool20=_Kf`80MWIf0P2LW9`20>3Ph080
inOW0P2k^k/20;>c/`80aLG50P3hn?P20;6a/@80j>SX0P3Lg=`20?Gem@80jn_[0P3clo<20=kNgP80
kNg]1@3QhN420?7al@80moOg0P3^k^h20>OWi`80l_;b0P3Ng]h20?Gem@80inOW0P3^k^h20=OGe`80
cLg=0P3Ti>@20??cl`80i>CT0P3Rh^820>SXj080k>c/0P3_knl20=;BdP80a/K60P2l_;`20<o?c`80
g]kN0P37alL20>GUi@80f=SH0P35aLD20>[ZjP80^k^k0P3alO420<;2`P<0k^k^0P3_knl209ZJVP80
Xj>S0P3hn?P20?Cdm080n?Sh0P3kno/20?KfmP@0no_k0P3clo<20?ooo`80no_k103hn?P20?ooo`@0
n?Sh3P3oool40?Shn0H0oooo1@3hn?P_0?ooo`005`3oool40?_knbd0oooo0P3Kfm/207IfMP80W9bL
0P3Ph>020>OWi`80^k^k0P2c/k<20<G5a@80n?Sh0P2a/K420>SXj080g=cL0P3emOD20>_[j`80lo?c
0P3Ng]h20>g]k@D0hN7Q0P3alO420?Ogm`80k^k^0P3WinL20?;blP80g]kN0P3emOD20>OWi`80k^k^
0P3GemL20<g=c@80i>CT0P3clo<20>CTi080h^;R0P3Xj>P20>c/k080kno_0P3Bd]820<K6aP80_;bl
0P3?cll20=kNgP80alO70P3UiND20=SHf080aLG50P3Zj^X20;^k^`80lO7a0P32`/830>k^kP80kno_
0P2JVYX20:>SX`80n?Sh0P3dm?@20?Shn080no_k0P3fm_H40?_kn`80lo?c0P3oool20?_kn`@0n?Sh
0P3oool40?Shn0h0oooo103hn?P60?ooo`D0n?Sh;`3oool00480oooo103hn?P40?ooo`80c<c<0P28
R8P20<G5a@80l?3`0P3Vi^H20=cLg080m_Kf0P3@d=040<C4a080kno_0P3QhN420>k^kP80j>SX0P3T
i>@20=GEe@80no_k0`3gmoL20??cl`80moOg0P3fm_H20>3Ph080hn?S0P3`l?020>SXj080iNGU0P3Y
jNT20<K6aP80hN7Q0P3Kfm/20??cl`80fm_K0P3hn?P20>7Qh@@0d=3@0P3Kfm/20=?Cd`80gMgM0P3T
i>@20>WYj@80`/;20P2m_Kd20;^k^`80XZ:R0P2/[:`20??cl`80eMGE0P3hn?P30?3`l080RHV90P2?
Shl80?Shn080lo?c0P3fm_H40?_kn`80n?Sh103kno/40?Shn1h0oooo1@3hn?P_0?ooo`00@P3oool4
0?Shn0@0oooo0P3<c<`208R8R080aLG50P3`l?020>KViP80g=cL0P3fm_H20=3@d0@0a<C40P3_knl2
0>7Qh@80k^k^0P3Xj>P20>CTi080eMGE0P3kno/30?Ogm`80lo?c0P3gmoL20?KfmP80h>3P0P3Shn<2
0?3`l080j>SX0P3UiND20>WYj@80a/K60P3QhN420=_Kf`80lo?c0P3Kfm/20?Shn080hN7Q103@d=02
0=_Kf`80dm?C0P3MgMd20>CTi080jNWY0P32`/820;fm_@80^k^k0P2RXZ820:b/[080lo?c0P3EeMD2
0?Shn0<0l?3`0P29RHT208n?S`P0n?Sh0P3clo<20?KfmP@0no_k0P3hn?P40?_kn`@0n?Sh7P3oool5
0?Shn2l0oooo00120?ooo`@0m_Kf0P3oool40?_kn`80^[Zj0P22PX820;fm_@80kNg]0P3WinL20?3`
l080j^[Z0P3dm?@20<C4a080_kno103QhN420?Ogm`80n_[j0P3Shn<20=SHf0<0k^k^0P3WinL20=KF
eP80emOG0P3Rh^820<o?c`80mOGe0P3EeMD20>OWi`80^KVi0P2a/K420:2PX080W9bL0P2GUiL209nO
W`80];Bd0P30`<020;Vi^@80[Jf]0P2o_kl20=[JfP80g]kN0P2l_;`20=7Ad@80kno_0P3MgMd20=kN
gP80jn_[0P2m_Kd20<;2`P80l?3`0P3jn_X30861P@80YZJV203hn?P20?Cdm080n?Sh0P3oool40?Sh
n0@0no_k0P3oool20?Shn080m?Cd0P3hn?Q@0?ooo`00@P3oool40?KfmP80oooo103kno/20;Zj^P80
PX:20P2m_Kd20>g]k@80inOW0P3`l?020>[ZjP80m?Cd0P34a<@20;no_`@0hN7Q0P3gmoL20?[jnP80
hn?S0P3Hf=P30>k^kP80inOW0P3Fe]H20=OGe`80h^;R0P3?cll20?Gem@80eMGE0P3WinL20;Vi^@80
/K6a0P2PX:0209bLW080UiNG0P2OWil20;Bd]080`<300P2i^KT20:f][@80_kno0P3Jf]X20=kNgP80
_;bl0P3AdM420>o_k`80gMgM0P3Ng]h20>_[j`80_Kfm0P32`/820?3`l080n_[j0`21PH420:JVYPP0
n?Sh0P3dm?@20?Shn080oooo103hn?P40?_kn`80oooo0P3hn?P20?Cdm080n?ShD03oool00480oooo
103kno/20?ooo`80no_k0P3clo<20?Shn080aLG50P1[Jf/208N7Q`80nOWi0P3:b/X20<71`@80fm_K
0P3`l?020;no_`80dm?C0P3Ng]h20=oOg`80kNg]0P3^k^h20>;RhP<0Zj^[0P2WYjL20=3@d080gMgM
0P3Xj>P20=KFeP80h^;R0P3>c/h20>OWi`80f=SH0P33`l<20?Cdm080hN7Q0P3IfMT20=KFeP80b/[:
0P3Hf=P20?3`l080`<300P35aLD20<W9b@80`<300P3WinL20?Ogm`80emOG0P3WinL20>WYj@80g=cL
0P3=cLd20?Gem@80oooo0P2<S8`308j>SP80n?Sh0P3kno/20??cl`80n?Sh0P3kno/20?Win@80no_k
103oool20?_kn`80oooo0P3kno/20?ooo`80n?Sh0P3dm?@20?Shn0@0no_kC03oool00480oooo103k
no/20?ooo`80no_k0P3clo<20?Shn080aLG50P1[Jf/208N7Q`80nOWi0P3:b/X20<71`@80fm_K0P3`
l?020;no_`80dm?C0P3Ng]h20=oOg`80kNg]0P3^k^h20>;RhP<0Zj^[0P2WYjL20=3@d080gMgM0P3X
j>P20=KFeP80h^;R0P3>c/h20>OWi`80f=SH0P33`l<20?Cdm080hN7Q0P3IfMT20=KFeP80b/[:0P3H
f=P20?3`l080`<300P35aLD20<W9b@80`<300P3WinL20?Ogm`80emOG0P3WinL20>WYj@80g=cL0P3=
cLd20?Gem@80oooo0P2<S8`308j>SP80n?Sh0P3kno/20??cl`80n?Sh0P3kno/20?Win@80no_k103o
ool20?_kn`80oooo0P3kno/20?ooo`80n?Sh0P3dm?@20?Shn0@0no_kC03oool004X0oooo103dm?@2
0?ooo`80n?Sh0P2BTY8207alO080g]kN0P3<c<`20<k>cP80e]KF0P3]kNd20;jn_P80clo?0P34a<@2
0<71`@80/k>c0P2_[jl30>CTi080aLG50P1[Jf/204Y:BP80@T920P1HF5P2096AT@80^k^k0P3;bl/2
0;fm_@80a<C4103dm?@20>o_k`80k^k^0P2c/k<20<30`080cLg=0P3Jf]X20=gMg@80i^KV0P3Ogml2
0>o_k`80iNGU0P3^k^h20;fm_@80cLg=0P3/k>`20>g]k@80WYjN0P1XJ6P20:BTY0<0n?Sh0P3fm_H2
0?ooo`80no_k0P3oool40?_kn`80nOWi103oool20?_kn`80oooo0P3kno/20?ooo`@0n?Sh0P3oool4
0?Win@80oooo103kno/40?Shn480oooo001:0?ooo`@0m?Cd0P3oool20?Shn080TY:B0P1lO7`20=kN
gP80c<c<0P3>c/h20=KFeP80kNg]0P2n_[h20<o?c`80a<C40P31`L420;>c/`80[jn_0`3Ti>@20<G5
a@80Jf][0P1:BTX20492@P80F5QH0P2ATI420;^k^`80bl_;0P2m_Kd20<C4a0@0m?Cd0P3_knl20>k^
kP80/k>c0P30`<020<g=c@80f][J0P3MgMd20>KViP80gmoO0P3_knl20>GUi@80k^k^0P2m_Kd20<g=
c@80k>c/0P3]kNd209jNWP80J6QX0P2TY:@30?Shn080m_Kf0P3oool20?_kn`80oooo103kno/20?Wi
n@@0oooo0P3kno/20?ooo`80no_k0P3oool40?Shn080oooo103inOT20?ooo`@0no_k103hn?Q20?oo
o`00=P3oool40?Shn100oooo103dm?@40?ooo`80n?Sh0P2<S8`205MGE`80Z:RX0P3Fe]H20<G5a@80
cLg=0P3clo<20=gMg@80e]KF0P3EeMD20>3Ph080l_;b0`3Jf]X20=?Cd`80m_Kf103Hf=P20>CTi080
nOWi0P3`l?020>3Ph080kno_0P3inOT20>g]k@80e]KF0P3@d=020<o?c`80h>3P0P3Xj>P20<O7a`80
kno_0P3Zj^X20>?Sh`80n_[j0P3Lg=`20;fm_@80/k>c0P3UiND20?Cdm080gMgM0P2<S8`208f=S@80
lo?c0P3kno/30?KfmP80n?Sh0P3kno/60?ooo`P0no_k0P3oool40?_kn`80oooo103hn?P20?ooo`@0
no_k0P3oool40?_kn`@0n?Sh3P3oool50?Shn080oooo103hn?P40?_knbD0oooo000f0?ooo`@0n?Sh
403oool40?Cdm0@0oooo0P3hn?P208b<S080EeMG0P2XZ:P20=KFeP80aLG50P3=cLd20??cl`80gMgM
0P3Fe]H20=GEe@80h>3P0P3bl_830=[JfP80dm?C0P3fm_H40=SHf080i>CT0P3inOT20?3`l080h>3P
0P3_knl20?Win@80kNg]0P3Fe]H20=3@d080clo?0P3Ph>020>SXj080alO70P3_knl20>[ZjP80hn?S
0P3jn_X20=cLg080_Kfm0P2c/k<20>GUi@80m?Cd0P3MgMd208b<S080SHf=0P3clo<20?_kn`<0m_Kf
0P3hn?P20?_kn`H0oooo203kno/20?ooo`@0no_k0P3oool40?Shn080oooo103kno/20?ooo`@0no_k
103hn?P>0?ooo`D0n?Sh0P3oool40?Shn0@0no_k9@3oool003H0oooo103hn?P@0?ooo`@0m?Cd103o
ool20?Shn080S8b<0P1GEeL20:RXZ080e]KF0P35aLD20<g=c@80lo?c0P3MgMd20=KFeP80eMGE0P3P
h>020?;blP<0f][J0P3Cdm<20?KfmP@0f=SH0P3Ti>@20?Win@80l?3`0P3Ph>020>o_k`80nOWi0P3]
kNd20=KFeP80d=3@0P3?cll20>3Ph080j>SX0P37alL20>o_k`80j^[Z0P3Shn<20?[jnP80g=cL0P2m
_Kd20;>c/`80iNGU0P3dm?@20=gMg@80S8b<0P2=SHd20??cl`80no_k0`3fm_H20?Shn080no_k1P3o
ool80?_kn`80oooo103kno/20?ooo`@0n?Sh0P3oool40?_kn`80oooo103kno/40?Shn0h0oooo1@3h
n?P20?ooo`@0n?Sh103kno/U0?ooo`00=P3oool40?Shn0`0oooo103hn?P20?Cdm0P0n?Sh0P3oool2
0>SXj080K6a/0P2:RXX20>WYj@80gMgM0P3<c<`20>SXj080gMgM0P3YjNT20?Ogm`80m_Kf0`3bl_82
0?KfmP80lO7a0P3Ph>020>CTi080k>c/0P3clo<20?KfmP80lO7a0P3fm_H20?;blP80l?3`0P3EeMD2
0=[JfP80gMgM0P3Ng]h20=7Ad@80dm?C0P3UiND20=CDe080f][J0P3<c<`20=GEe@80j^[Z0P3]kNd2
0?clo080/;2`0P29RHT20;Ng]`80oooo103inOT50?_kn`P0n?Sh0P3oool20?_kn`80oooo0P3kno/>
0?ooo`@0n?Sh303oool40?Shn0H0oooo0P3hn?P20?ooo`<0n?Sh0P3oool20?Shn080oooo0P3clo<2
0?_knbD0oooo000f0?ooo`@0n?Sh303oool40?Shn080m?Cd203hn?P20?ooo`80j>SX0P1/K6`208Z:
RP80jNWY0P3MgMd20<c<c080j>SX0P3MgMd20>WYj@80moOg0P3fm_H30?;blP80m_Kf0P3alO420>3P
h080i>CT0P3/k>`20??cl`80m_Kf0P3alO420?KfmP80l_;b0P3`l?020=GEe@80f][J0P3MgMd20=kN
gP80dM7A0P3Cdm<20>GUi@80e=CD0P3Jf]X20<c<c080eMGE0P3Zj^X20>g]k@80o?cl0P2`/;0208V9
R@80]kNg0P3oool40?Win@D0no_k203hn?P20?ooo`80no_k0P3oool20?_kn`h0oooo103hn?P<0?oo
o`@0n?Sh1P3oool20?Shn080oooo0`3hn?P20?ooo`80n?Sh0P3oool20??cl`80no_k9@3oool004H0
oooo1P3hn?P20?Cdm0H0n?Sh0P3kno/20??cl`80l_;b0P2<S8`206MWI`80VIVI0P3Ng]h20;Ng]`80
b<S80P3`l?020>k^kP80m_Kf0`3oool20?[jnP80lO7a0P3Ti>@20>WYj@80jn_[0P3UiND20<k>cP80
^[Zj0P2g]kL20<[:bP80h>3P0P3Fe]H20>WYj@80f=SH0P3Kfm/20>3Ph080eMGE0P37alL20;2`/080
ZJVY0P3Hf=P20>[ZjP80k>c/0P2YZJT20861P@80[:b/0P3YjNT40?ooo`80no_k0P3clo<30?Shn080
oooo103hn?P40?KfmP80oooo103fm_H40?Shn0@0oooo103kno/80?Shn0@0oooo103hn?P40?ooo`@0
n?Sh1P3oool40?Shn0<0oooo0P3hn?P20?Cdm080n?Sh0P3alO420?_kn`X0oooo103hn?PG0?ooo`00
AP3oool60?Shn080m?Cd1P3hn?P20?_kn`80lo?c0P3bl_8208b<S080IfMW0P2IVIT20=kNgP80]kNg
0P38b<P20?3`l080k^k^0P3fm_H30?ooo`80n_[j0P3alO420>CTi080jNWY0P3[jn/20>GUi@80c/k>
0P2j^[X20;Ng]`80b/[:0P3Ph>020=KFeP80jNWY0P3Hf=P20=_Kf`80h>3P0P3EeMD20<O7a`80/;2`
0P2YZJT20=SHf080j^[Z0P3/k>`20:VYZ@80PH610P2/[:`20>WYj@@0oooo0P3kno/20??cl`<0n?Sh
0P3oool40?Shn0@0m_Kf0P3oool40?KfmP@0n?Sh103oool40?_kn`P0n?Sh103oool40?Shn0@0oooo
103hn?P60?ooo`@0n?Sh0`3oool20?Shn080m?Cd0P3hn?P20?7al@80no_k2P3oool40?Shn1L0oooo
000d0?ooo`@0n?Sh603oool20?_kn`80m_Kf0P3clo<20?_kn`@0m?Cd0P3oool20:JVYP80KFe]0P1R
HV820<30`080cLg=0P30`<020=CDe0<0fm_K0P3^k^h20?3`l080lo?c0P3gmoL20>o_k`80iNGU0P3H
f=P20=cLg080e]KF0P3_knl20>k^kP80m_Kf0P31`L4209fMW@80YZJV0P2a/K420;^k^`80i^KV0P3T
i>@20=cLg080c/k>0P2<S8`207]kN`80/[:b0P3fm_H40?ooo`@0n?Sh0P3oool50?Shn080oooo103h
n?P40?_kn`80oooo103hn?P40?KfmP@0oooo103kno/:0?Shn080m?Cd103hn?P20?Cdm080n?Sh203o
ool40?Shn0D0oooo0P3dm?@20?ooo`80n?Sh0P3kno/20?KfmPX0oooo103hn?PG0?ooo`00=03oool4
0?Shn1P0oooo0P3kno/20?KfmP80lo?c0P3kno/40?Cdm080oooo0P2VYZH206e]K@80HV9R0P30`<02
0<g=c@80`<300P3De=@30=_Kf`80k^k^0P3`l?020??cl`80moOg0P3_knl20>GUi@80f=SH0P3Lg=`2
0=KFeP80kno_0P3^k^h20?KfmP80`L710P2MWId20:JVYP80/K6a0P2k^k/20>KViP80i>CT0P3Lg=`2
0<k>cP80S8b<0P1kNg/20;:b/P80m_Kf103oool40?Shn080oooo1@3hn?P20?ooo`@0n?Sh103kno/2
0?ooo`@0n?Sh103fm_H40?ooo`@0no_k2P3hn?P20?Cdm0@0n?Sh0P3dm?@20?Shn0P0oooo103hn?P5
0?ooo`80m?Cd0P3oool20?Shn080no_k0P3fm_H:0?ooo`@0n?Sh5`3oool00380oooo0P3kno/20??c
l`80n?Sh603oool20?_kn`80m_Kf0P3hn?P20?ooo`@0n?Sh0P3oool60?Shn080YZJV0P26QXH20;no
_`80kNg]0`3Vi^H20>3Ph080c<c<0P3Vi^H20??cl`80mOGe0P3jn_X20>CTi080a/K6102d];@20;Rh
^080_kno0P3WinL20=?Cd`80l?3`0P3Cdm<20=_Kf`80i^KV0P2YZJT209bLW080b/[:0P3YjNT20?oo
o`80lo?c0P3fm_H40?ooo`@0n?Sh103oool50?_kn`80n?Sh0P3clo<20?_kn`@0oooo203kno/80?oo
o`@0no_k1P3hn?P60?Cdm080lO7a0P3fm_H20?Shn080m_Kf0P3kno/20?ooo`@0n?Sh0P3oool30?_k
n`80lo?c0P3dm?@40?Shn080lo?c0P3kno/S0?ooo`00<P3oool20?_kn`80lo?c0P3hn?PH0?ooo`80
no_k0P3fm_H20?Shn080oooo103hn?P20?ooo`H0n?Sh0P2VYZH208J6QP80_kno0P3]kNd30>KViP80
h>3P0P3<c<`20>KViP80lo?c0P3emOD20?[jnP80i>CT0P36a/H40;Bd]080^;Rh0P2o_kl20>OWi`80
dm?C0P3`l?020=?Cd`80fm_K0P3Vi^H20:VYZ@80W9bL0P3:b/X20>WYj@80oooo0P3clo<20?KfmP@0
oooo103hn?P40?ooo`D0no_k0P3hn?P20??cl`80no_k103oool80?_kn`P0oooo103kno/60?Shn0H0
m?Cd0P3alO420?KfmP80n?Sh0P3fm_H20?_kn`80oooo103hn?P20?ooo`<0no_k0P3clo<20?Cdm0@0
n?Sh0P3clo<20?_knb<0oooo000b0?ooo`80no_k0P3clo<20?Shn200oooo103kno/20?ooo`80m?Cd
0P3alO420?;blP80m_Kf0P3oool20;Zj^P80W9bL0`2[Zj/20:f][@80];Bd0P3Bd]820>CTi080hN7Q
0P3Xj>P20?Gem@80clo?0P36a/H20=oOg`80moOg0P3fm_H20?;blP80o?cl0P3Cdm<209jNWP80W9bL
0P2h^;P20=OGe`80l_;b0P3oool20?Cdm080oooo0P3alO420??cl`@0m?Cd0P3hn?P60?ooo`<0no_k
0P3oool20?Win@80oooo0P3kno/40?ooo`P0no_k0P3hn?P20?KfmP80no_k0P3oool20?_kn`80lo?c
0P3hn?P:0?ooo`@0no_k0P3hn?P20?_kn`80m_Kf103hn?P40?ooo`D0no_k1P3oool40?KfmP`0oooo
103hn?PC0?ooo`00<P3oool20?_kn`80lo?c0P3hn?PP0?ooo`@0no_k0P3oool20?Cdm080lO7a0P3b
l_820?KfmP80oooo0P2j^[X209bLW0<0Zj^[0P2][Jd20;Bd]080d];B0P3Ti>@20>7Qh@80j>SX0P3e
mOD20<o?c`80a/K60P3Ogml20?Ogm`80m_Kf0P3bl_820?clo080dm?C0P2NWYh209bLW080^;Rh0P3G
emL20?;blP80oooo0P3dm?@20?ooo`80lO7a0P3clo<40?Cdm080n?Sh1P3oool30?_kn`80oooo0P3i
nOT20?ooo`80no_k103oool80?_kn`80n?Sh0P3fm_H20?_kn`80oooo0P3kno/20??cl`80n?Sh2P3o
ool40?_kn`80n?Sh0P3kno/20?KfmP@0n?Sh103oool50?_kn`H0oooo103fm_H<0?ooo`@0n?Sh4`3o
ool003@0oooo0P3hn?P20??cl`80no_k503oool20?Shn080m_Kf0P3kno/40?ooo`80no_k0P3oool2
0?_kn`80n?Sh0P3fm_H20?Win@80no_k103oool20?_kn`<0nOWi0P3bl_820>WYj@80k>c/0P3UiND2
0>SXj080l?3`0P3Hf=P20<K6aP80_[jn0P36a/H20<O7a`80`/;20P35aLD20<S8b080fMWI0P3alO42
0?_kn`80n?Sh0P3dm?@20?Shn080oooo103hn?P20?Cdm080n?Sh103dm?@20??cl`80no_k103hn?P3
0?ooo`80m_Kf0P3bl_820?_kn`80oooo203hn?P60?KfmP80n?Sh1P3kno/40?Shn100oooo103fm_H2
0?Shn080oooo0P3hn?P70?ooo`@0n?Sh0P3oool40?Shn0`0oooo103hn?PC0?ooo`00=03oool20?Sh
n080lo?c0P3kno/D0?ooo`80n?Sh0P3fm_H20?_kn`@0oooo0P3kno/20?ooo`80no_k0P3hn?P20?Kf
mP80nOWi0P3kno/40?ooo`80no_k0`3inOT20?;blP80jNWY0P3/k>`20>GUi@80j>SX0P3`l?020=SH
f080a/K60P2n_[h20<K6aP80alO70P32`/820<G5a@80b<S80P3IfMT20?7al@80no_k0P3hn?P20?Cd
m080n?Sh0P3oool40?Shn080m?Cd0P3hn?P40?Cdm080lo?c0P3kno/40?Shn0<0oooo0P3fm_H20?;b
lP80no_k0P3oool80?Shn0H0m_Kf0P3hn?P60?_kn`@0n?Sh403oool40?KfmP80n?Sh0P3oool20?Sh
n0L0oooo103hn?P20?ooo`@0n?Sh303oool40?Shn1<0oooo000f0?ooo`@0no_k503oool20?Shn080
m_Kf0P3kno/40?ooo`80no_k0P3oool40?_kn`80m_Kf0P3hn?P40?ooo`L0no_k0P3clo<40?Shn080
m_Kf0P3kno/20?ooo`80no_k1P3inOT20?7al@80m?Cd0P3oool40?_kn`@0oooo0P3hn?P20?Cdm0H0
n?Sh103dm?@40?ooo`80no_k0P3hn?P20?KfmP80m?Cd2@3hn?P40?ooo`P0n?Sh0P3dm?@20?7al@80
no_k0P3inOT20?_kn`80oooo0P3kno/<0?ooo`@0n?Sh103oool40?_kn`80oooo103dm?@50?ooo`80
no_k0P3clo<20?ooo`80m?Cd0P3hn?P>0?ooo`@0n?Sh103kno/?0?ooo`00=P3oool40?_kna@0oooo
0P3hn?P20?KfmP80no_k103oool20?_kn`80oooo103kno/20?KfmP80n?Sh103oool70?_kn`80lo?c
103hn?P20?KfmP80no_k0P3oool20?_kn`H0nOWi0P3alO420?Cdm080oooo103kno/40?ooo`80n?Sh
0P3dm?@60?Shn0@0m?Cd103oool20?_kn`80n?Sh0P3fm_H20?Cdm0T0n?Sh103oool80?Shn080m?Cd
0P3alO420?_kn`80nOWi0P3kno/20?ooo`80no_k303oool40?Shn0@0oooo103kno/20?ooo`@0m?Cd
1@3oool20?_kn`80lo?c0P3oool20?Cdm080n?Sh3P3oool40?Shn0@0no_k3`3oool003P0oooo103h
n?PL0?ooo`@0no_k0P3hn?P20?7al@80no_k0P3hn?P20?ooo`80no_k0P3oool20?_kn`D0m_Kf0P3o
ool20?Shn080no_k0P3fm_H20?ooo`@0n?Sh103oool40?KfmP80oooo103kno/40?ooo`@0no_k0P3h
n?P20?ooo`80n?Sh0P3dm?@40?Shn080oooo0P3kno/20?Shn080m_Kf0P3hn?P20?7al@<0m_Kf103h
n?P60?ooo`@0n?Sh0P3oool20?Shn080m_Kf0P3inOT60?_kn`80oooo0P3hn?P20?KfmP80no_k1P3o
ool40?Cdm080oooo103hn?P20?ooo`80no_k0P3clo<20?Shn0D0oooo103kno/20?KfmP80lo?c0P3d
m?@>0?ooo`@0n?Sh103fm_H?0?ooo`00>03oool40?Shn1`0oooo103kno/20?Shn080lO7a0P3kno/2
0?Shn080oooo0P3kno/20?ooo`80no_k1@3fm_H20?ooo`80n?Sh0P3kno/20?KfmP80oooo103hn?P4
0?ooo`@0m_Kf0P3oool40?_kn`@0oooo103kno/20?Shn080oooo0P3hn?P20?Cdm0@0n?Sh0P3oool2
0?_kn`80n?Sh0P3fm_H20?Shn080lO7a0`3fm_H40?Shn0H0oooo103hn?P20?ooo`80n?Sh0P3fm_H2
0?Win@H0no_k0P3oool20?Shn080m_Kf0P3kno/60?ooo`@0m?Cd0P3oool40?Shn080oooo0P3kno/2
0??cl`80n?Sh1@3oool40?_kn`80m_Kf0P3clo<20?Cdm0h0oooo103hn?P40?KfmPl0oooo000`0?oo
o`@0n?Sh0P3oool20?_kn`80lo?c0P3hn?P40?_kna@0oooo0P3kno/20?KfmP80n?Sh0P3oool20?Sh
n080lO7a0P3fm_H40?ooo`80no_k0P3oool20?KfmP<0no_k0P3fm_H40?ooo`@0m?Cd0P3oool20?Sh
n080oooo0P3hn?P20?_kn`80oooo1P3kno/60?ooo`@0no_k103hn?P20?ooo`@0n?Sh0P3dm?@20?oo
o`80no_k0P3oool20??cl`80n?Sh1@3kno/20?KfmP80no_k0P3dm?@20?Shn080oooo0P3fm_H20?_k
n`80n?Sh1P3oool40?Shn0@0oooo0P3dm?@20?7al@80no_k0P3oool60?Shn080oooo103hn?P20?oo
o`80m?Cd0P3clo<20?_kn`@0n?Sh1@3oool20?_kn`80oooo0P3fm_H20?Shn0X0oooo103hn?P40?oo
o`@0n?Sh3`3oool00300oooo103hn?P20?ooo`80no_k0P3clo<20?Shn0@0no_k503oool20?_kn`80
m_Kf0P3hn?P20?ooo`80n?Sh0P3alO420?KfmP@0oooo0P3kno/20?ooo`80m_Kf0`3kno/20?KfmP@0
oooo103dm?@20?ooo`80n?Sh0P3oool20?Shn080no_k0P3oool60?_kn`H0oooo103kno/40?Shn080
oooo103hn?P20?Cdm080oooo0P3kno/20?ooo`80lo?c0P3hn?P50?_kn`80m_Kf0P3kno/20?Cdm080
n?Sh0P3oool20?KfmP80no_k0P3hn?P60?ooo`@0n?Sh103oool20?Cdm080lO7a0P3kno/20?ooo`H0
n?Sh0P3oool40?Shn080oooo0P3dm?@20??cl`80no_k103hn?P50?ooo`80no_k0P3oool20?KfmP80
n?Sh2P3oool40?Shn0@0oooo103hn?P?0?ooo`00<03oool40?Shn080oooo103kno/20?Shn080lo?c
0P3kno/D0?ooo`80no_k0P3fm_H20?Shn0@0oooo103kno/60?ooo`80nOWi0P3bl_830?KfmP80no_k
0P3hn?P20?KfmP80lo?c0P3oool20?Shn080oooo103hn?P40?KfmP80n?Sh0P3clo<20?_kn`P0oooo
103kno/40?Shn080oooo103hn?P20?ooo`@0no_k103hn?P50?ooo`80no_k0P3fm_H20?7al@80m_Kf
0P3oool20?_kn`80m_Kf0P3hn?P20?ooo`80no_k0P3fm_H40?_kn`80n?Sh0P3oool40?Cdm080oooo
0P3kno/20??cl`80n?Sh0P3oool40?Shn080oooo0P3hn?P20?Cdm080n?Sh0P3oool40?Shn0T0no_k
303oool20?_kn`80lO7a0P3dm?@G0?ooo`00<03oool40?Shn080oooo103kno/20?Shn080lo?c0P3k
no/D0?ooo`80no_k0P3fm_H20?Shn0@0oooo103kno/60?ooo`80nOWi0P3bl_830?KfmP80no_k0P3h
n?P20?KfmP80lo?c0P3oool20?Shn080oooo103hn?P40?KfmP80n?Sh0P3clo<20?_kn`P0oooo103k
no/40?Shn080oooo103hn?P20?ooo`@0no_k103hn?P50?ooo`80no_k0P3fm_H20?7al@80m_Kf0P3o
ool20?_kn`80m_Kf0P3hn?P20?ooo`80no_k0P3fm_H40?_kn`80n?Sh0P3oool40?Cdm080oooo0P3k
no/20??cl`80n?Sh0P3oool40?Shn080oooo0P3hn?P20?Cdm080n?Sh0P3oool40?Shn0T0no_k303o
ool20?_kn`80lO7a0P3dm?@G0?ooo`00=P3oool80?Shn1@0oooo103kno/B0?ooo`80nOWi1@3kno/2
0?ooo`80n?Sh0P3fm_H20?ooo`80lO7a103hn?P20?ooo`80n?Sh0P3kno/20?KfmP@0n?Sh103oool4
0?Shn0@0no_k0P3inOT20?Shn080oooo0P3fm_H20?_kn`P0n?Sh0P3oool90?Shn080oooo103kno/2
0?ooo`@0n?Sh103oool20?_kn`80m_Kf103bl_820?ooo`P0n?Sh0P3clo<20?_kn`80oooo203hn?P2
0?ooo`80n?Sh0P3fm_H20?_kn`@0oooo1@3kno/40?Shn080oooo103hn?P60?ooo`80no_k0P3fm_H2
0?Shn0@0oooo0P3kno/20?Win@l0oooo000f0?ooo`P0n?Sh503oool40?_kna80oooo0P3inOT50?_k
n`80oooo0P3hn?P20?KfmP80oooo0P3alO440?Shn080oooo0P3hn?P20?_kn`80m_Kf103hn?P40?oo
o`@0n?Sh103kno/20?Win@80n?Sh0P3oool20?KfmP80no_k203hn?P20?ooo`T0n?Sh0P3oool40?_k
n`80oooo103hn?P40?ooo`80no_k0P3fm_H40?;blP80oooo203hn?P20??cl`80no_k0P3oool80?Sh
n080oooo0P3hn?P20?KfmP80no_k103oool50?_kn`@0n?Sh0P3oool40?Shn0H0oooo0P3kno/20?Kf
mP80n?Sh103oool20?_kn`80nOWi3`3oool003H0oooo203hn?PD0?ooo`80no_k0P3clo<20?Shn080
oooo203kno/60?ooo`80no_k0P3inOT30??cl`80n?Sh103oool20?_kn`80m_Kf0P3dm?@20?Shn080
no_k103alO420?_kn`P0oooo103hn?P20?_kn`80nOWi103kno/20??cl`80no_k0P3fm_H40?Cdm0@0
n?Sh0P3kno/70?7al@80m?Cd103oool40?_kn`@0n?Sh203oool20?_kn`80lo?c0P3kno/20?;blP80
no_k0P3oool20?Shn080lo?c0P3kno/20?ooo`@0n?Sh103dm?@20?ooo`80n?Sh0P3fm_H20?_kn`@0
oooo2@3hn?P20?ooo`@0n?Sh303oool40?_kn`80m_Kf0P3bl_8?0?ooo`00=P3oool80?Shn1@0oooo
0P3kno/20??cl`80n?Sh0P3oool80?_kn`H0oooo0P3kno/20?Win@<0lo?c0P3hn?P40?ooo`80no_k
0P3fm_H20?Cdm080n?Sh0P3kno/40?7al@80no_k203oool40?Shn080no_k0P3inOT40?_kn`80lo?c
0P3kno/20?KfmP@0m?Cd103hn?P20?_kn`L0lO7a0P3dm?@40?ooo`@0no_k103hn?P80?ooo`80no_k
0P3clo<20?_kn`80l_;b0P3kno/20?ooo`80n?Sh0P3clo<20?_kn`80oooo103hn?P40?Cdm080oooo
0P3hn?P20?KfmP80no_k103oool90?Shn080oooo103hn?P<0?ooo`@0no_k0P3fm_H20?;blPl0oooo
000j0?ooo`80n?Sh0P3clo<20?_kn`h0oooo0P3kno/20?KfmP@0n?Sh0P3clo<40?_kn`80oooo0P3k
no/20?Win@@0oooo0P3hn?P20?Cdm0L0n?Sh103kno/60?ooo`80no_k0P3oool20?KfmP80oooo0P3h
n?P20?_kn`80m_Kf0P3hn?P80?ooo`@0n?Sh1P3fm_H20?_kn`80oooo0P3clo<40?_kn`80oooo0P3f
m_H50?_kn`80n?Sh1P3kno/20??cl`@0m_Kf0P3hn?P60?_kn`80m_Kf0P3oool20?_kn`80l_;b0P3k
no/20?ooo`80no_k0P3oool20?_kn`H0oooo103hn?P<0?ooo`D0n?Sh103kno/B0?ooo`@0no_k103h
n?P?0?ooo`00>P3oool20?Shn080lo?c0P3kno/>0?ooo`80no_k0P3fm_H40?Shn080lo?c103kno/2
0?ooo`80no_k0P3inOT40?ooo`80n?Sh0P3dm?@70?Shn0@0no_k1P3oool20?_kn`80oooo0P3fm_H2
0?ooo`80n?Sh0P3kno/20?KfmP80n?Sh203oool40?Shn0H0m_Kf0P3kno/20?ooo`80lo?c103kno/2
0?ooo`80m_Kf1@3kno/20?Shn0H0no_k0P3clo<40?KfmP80n?Sh1P3kno/20?KfmP80oooo0P3kno/2
0?;blP80no_k0P3oool20?_kn`80oooo0P3kno/60?ooo`@0n?Sh303oool50?Shn0@0no_k4P3oool4
0?_kn`@0n?Sh3`3oool003`0oooo103kno/>0?ooo`80no_k0P3fm_H20?Shn080oooo103fm_H20?Sh
n080lo?c0P3kno/20?;blP80m?Cd0P3hn?P20?KfmP80lo?c0P3dm?@50?ooo`@0no_k1P3oool20?Kf
mP80lO7a1P3hn?P20?_kn`80lO7a0P3dm?@80?ooo`80n?Sh103oool20?Shn080no_k0P3fm_H20?Sh
n080m_Kf1P3alO470?Shn080oooo103inOT20?Shn080oooo103fm_H20?ooo`H0lO7a0P3kno/60?Sh
n0@0oooo0P3fm_H20?7al@80n?Sh1P3oool40?_kn`X0oooo1@3hn?P20?ooo`@0no_k103hn?P60?oo
o`P0n?Sh0P3oool40?Shn140oooo000l0?ooo`@0no_k3P3oool20?_kn`80m_Kf0P3hn?P20?ooo`@0
m_Kf0P3hn?P20??cl`80no_k0P3bl_820?Cdm080n?Sh0P3fm_H20??cl`80m?Cd1@3oool40?_kn`H0
oooo0P3fm_H20?7al@H0n?Sh0P3kno/20?7al@80m?Cd203oool20?Shn0@0oooo0P3hn?P20?_kn`80
m_Kf0P3hn?P20?KfmPH0lO7a1`3hn?P20?ooo`@0nOWi0P3hn?P20?ooo`@0m_Kf0P3oool60?7al@80
no_k1P3hn?P40?ooo`80m_Kf0P3alO420?Shn0H0oooo103kno/:0?ooo`D0n?Sh0P3oool40?_kn`@0
n?Sh1P3oool80?Shn080oooo103hn?PA0?ooo`00<P3oool80?Shn080oooo203kno/80?ooo`@0n?Sh
1P3oool40?Shn0@0m_Kf0P3inOT20?;blP80lO7a0P3fm_H20?_kn`80m_Kf0P3hn?P70?ooo`@0no_k
103oool20?Shn080m?Cd1P3hn?P20?ooo`H0n?Sh0P3fm_H20?_kn`80n?Sh0P3dm?@20?ooo`80n?Sh
203oool20?Shn0H0m?Cd1`3hn?P20?ooo`@0no_k0P3hn?P20??cl`80no_k0P3oool20?Shn0H0m?Cd
0P3oool60?Shn080oooo0P3kno/20??cl`80n?Sh0P3dm?@40?ooo`80n?Sh0P3clo<20?_kn`X0oooo
0P3hn?P30??cl`H0no_k103hn?P60?ooo`P0n?Sh0P3oool40?Shn140oooo000b0?ooo`P0n?Sh0P3o
ool80?_kn`P0oooo103hn?P60?ooo`@0n?Sh103fm_H20?Win@80l_;b0P3alO420?KfmP80no_k0P3f
m_H20?Shn0L0oooo103kno/40?ooo`80n?Sh0P3dm?@60?Shn080oooo1P3hn?P20?KfmP80no_k0P3h
n?P20?Cdm080oooo0P3hn?P80?ooo`80n?Sh1P3dm?@70?Shn080oooo103kno/20?Shn080lo?c0P3k
no/20?ooo`80n?Sh1P3dm?@20?ooo`H0n?Sh0P3oool20?_kn`80lo?c0P3hn?P20?Cdm0@0oooo0P3h
n?P20??cl`80no_k2P3oool20?Shn0<0lo?c1P3kno/40?Shn0H0oooo203hn?P20?ooo`@0n?Sh4@3o
ool00380oooo103dm?@20?Shn080oooo0P3hn?P80?_kn`P0oooo103hn?P60?ooo`h0no_k0P3clo<6
0?Shn0L0oooo103kno/80?ooo`@0n?Sh0P3dm?@40?ooo`80no_k0P3clo<20?KfmP80lo?c1P3hn?PB
0?ooo`T0n?Sh1P3oool40?_kn`X0oooo0P3dm?@40?Shn080m?Cd0P3oool40?_kn`@0n?Sh103oool4
0?Shn0X0oooo103hn?P90?Win@80oooo103hn?P20?ooo`80n?Sh0P3fm_H20?_kna/0oooo000b0?oo
o`@0m?Cd0P3hn?P20?ooo`80n?Sh203kno/80?ooo`@0n?Sh1P3oool>0?_kn`80lo?c1P3hn?P70?oo
o`@0no_k203oool40?Shn080m?Cd103oool20?_kn`80lo?c0P3fm_H20??cl`H0n?Sh4P3oool90?Sh
n0H0oooo103kno/:0?ooo`80m?Cd103hn?P20?Cdm080oooo103kno/40?Shn0@0oooo103hn?P:0?oo
o`@0n?Sh2@3inOT20?ooo`@0n?Sh0P3oool20?Shn080m_Kf0P3kno/K0?ooo`00o`3ooolQ0?ooo`00
o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00
o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00
M03oool2@0000:X0oooo001f0?ooo`03@000003oool0oooo0:L0oooo001X0?ooo`=000000`3oool3
@00000<0oooo0d0000050?ooo`03@000003oool0oooo0080oooo0d0000040?ooo`03@000003oool0
oooo00P0oooo0d000000103ooom00000@000003oool2@0000080oooo0T0000030?ooo`9000000P3o
ool3@00000060?oood0000100000@000003ooom00000L03oool006T0oooo00=000000?ooo`3oool0
0`3oool01D000000oooo0?ooo`3ooom000000080oooo00=000000?ooo`3oool02@3oool00d000000
oooo0?ooo`0>0?ooo`03@000003ooom000000080oooo00=000000?oood0000000P3oool00d000000
oooo0?ooo`020?ooo`06@000003oool0oooo@000003ooom00000103oool014000000oooo0?oood00
001`0?ooo`00J@3oool00d000000oooo0?ooo`030?ooo`05@000003oool0oooo0?oood0000000P3o
ool00d000000oooo0?ooo`070?ooo`A000004@3oool00d000000oooo0?ooo`03@0000080oooo0d00
00020?ooo`03@000003oool0oooo0080oooo00=000000?ooo`3oool00P3oool014000000oooo0?oo
od00001`0?ooo`00J@3oool2@00000<0oooo0T0000040?ooo`=000002@3oool00d000000oooo@000
000A0?ooo`06@000003oool0oooo0?oood000000oooo0T0000001@3ooom00000@00004000000oooo
00A000000P3oool3@0000080oooo0d00001a0?ooo`00J@3oool014000000oooo0?oood00000D0?oo
o`900000403oool00d000000oooo@00000020?ooo`03@000003oool0oooo00L0oooo00=000000?oo
o`3oool01`3oool00d000000oooo0?ooo`1a0?ooo`00J03oool5@0000080oooo00=000000?ooo`3o
ool0403oool00d000000oooo0?ooo`0>0?ooo`=0000000<0oooo@000040000004P3oool2@00007<0
oooo003o0?ooob40oooo003o0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-6.47761, -2.56068, 0.491133, 
  0.491133}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["2.6 Three-dimensional image generation",
  FontFamily->"Times New Roman",
  FontWeight->"Bold"]], "Section"],

Cell[TextData[{
  StyleBox["\t",
    FontFamily->"Times New Roman",
    FontSize->10.5],
  StyleBox[
  "As shown in Fig.4, the sketch captures the characteristics of the sample \
monochrome image. Thereby, it may be possible to work out the filters \
extracting the various characters from the vectors distribution in Fig.3. ",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Mathematica",
    FontFamily->"Century",
    FontSize->10.5,
    FontSlant->"Italic"],
  StyleBox[" function imageNormalize",
    FontFamily->"Century",
    FontSize->10.5]
}], "Subsubsection"],

Cell[TextData[{
  "\t",
  StyleBox["Before to continue the discussions, we define a ",
    FontFamily->"Times New Roman"],
  StyleBox["Mathematica",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox[
  " function \[OpenCurlyDoubleQuote]imageNormalize\[CloseCurlyDoubleQuote], \
which converts the 2-dimensional image data between the values 0 and 1. ",
    FontFamily->"Times New Roman"]
}], "Text"],

Cell[BoxData[
    \(\(imageNormalize = 
      Compile[{{data2D, _Real, 2}}, \n\t\t
        Module[{minimum = Min[data2D]}, \n\t\t\t
          \((data2D - minimum)\)/Max[data2D - minimum]]]; \)\)], "Input",
  CellLabel->"In[28]:="],

Cell[TextData[{
  StyleBox["\t",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"],
  StyleBox[
  "In this textbook, we work out the different angled lighting images based \
on the nature of vector fields. Let us consider the six different directed \
unit vectors \[OpenCurlyDoubleQuote]viewV\[CloseCurlyDoubleQuote] given by",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell["\<\
rotation=6;
viewV=Table[{Cos[2.Pi i/rotation],Sin[2.Pi i/rotation]},
\t{i,0,rotation-1}];\
\>", "Input",
  CellLabel->"In[29]:="],

Cell[TextData[StyleBox[
"then after computing the inner product \[OpenCurlyDoubleQuote]angle\
\[CloseCurlyDoubleQuote] between the vectors in Fig.3 and in the list \
\[OpenCurlyDoubleQuote]viewV\[CloseCurlyDoubleQuote], we normalize the inner \
products to the values between 0 and 1 by the function \
\[OpenCurlyDoubleQuote]imageNormalize\[CloseCurlyDoubleQuote].",
  TextAlignment->Left,
  TextJustification->1,
  FontFamily->"Times New Roman"]], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell["\<\
angle=Table[chractV[[i,j]].viewV[[k]],
\t{k,rotation},{i,dim[[1]],1,-1},{j,dim[[2]]}];\
\>", "Input",
  CellLabel->"In[31]:="],

Cell[TextData[{
  StyleBox["\t",
    FontFamily->"Century",
    FontSize->10.5],
  StyleBox[
  "Consequently obtained results are shown in Fig. 5, where the first image \
is represented in terms of the red, green and blue colors which are \
corresponding to the lighting angles 0, 120 and 240 degrees, respectively. \
The remaining images in Fig.5 are the shadowed three-dimensional relief \
images at each of the lighting angles. ",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell["\<\
angleN=Table[imageNormalize[angle[[i]]],{i,rotation}];
angleNG=Table[Table[ListDensityPlot[angleN[[i]],
\tPlotRange->All,Mesh->False,Frame->False,
\tPlotLabel->StringForm[\"`1`deg.\",(i-1)360/rotation],
\tDisplayFunction->Identity]],
\t{i,rotation}];\
\>", "Input",
  CellLabel->"In[32]:=",
  FormatType->InputForm],

Cell[CellGroupData[{

Cell["\<\
Show[convertRGB[Table[angleN[[i]],{i,1,rotation,rotation/3}]],
\tAspectRatio->1,PlotLabel->\"Fig.5.Lighting effect\"];
Show[GraphicsArray[
\tTable[Table[angleNG[[i+j]],{j,0,2}],{i,1,rotation,3}]],
\tImageSize->{450,300},PlotLabel->\"Angle\"];\
\>", "Input",
  CellLabel->"In[34]:="],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00744048 0.0238095 0.00744048 [
[.5 1.0125 -65 0 ]
[.5 1.0125 65 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -126 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Fig) show
81.000000 12.812500 moveto
(.5) show
93.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(.) show
99.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Lighting) show
153.000000 12.812500 moveto
(effect) show
189.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
384 string
128 128 8 [128 0 0 128 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
788C89778C89738A8D788C897D8E83778C89798D87788C89718A8F7E8F82768C8A8C9474788C89\
788C89778C89738B8D7C8E84788C89788C89788C89788C8964859C7C8E84B6A548
4F7CB3718A8F7E8F82788C897C8E84728A8E788C897E8F82718A8F778C89788C88778C897E8F82\
788C89728A8E788C89748B8D788C897B8E85788C89788C88788C89788C89778C89
8090806F8991788C89788C89728A8F788C89788C89788C89788C89788C89788C897A8D86758B8B\
7D8F83788C89758B8B748B8C7D8F83788C89788C89788C89788C89788C88788C89
788C89788C89778C89788C89798D87768C8A788C89788C88778C89788C89788C886886986E8992\
81907FA99F565C81A5788C89728A8E788C897D8E83788C89788C89738A8D788C89
788C89788C89788C89788C89728A8F788C887A8D86758B8B718A8F7C8E84748B8D788C89788C89\
7D8E83728A8E7D8F837D8E83788C887F8F81788C89758B8C788C89788D887A8D86
6184A0788C8895986A63849D688699718A8F748B8C7D8E83
788C89778B8A748D8B74948676918678878C7E84897E8887728E8B798C887C88888C83808A8282\
788B89788C89738E8A789086788C89788C89788D88778D8864979068998CB69255
6370AC73898E7D8F83788C887C8A87778D89729487789185728E8C728F8B788C89788C897D8986\
7E848A788B89738E8B748A8D788F86788F86788D88788D88789483709589728F8B
808985778A8A71908A778D8972908A719587729289759187749386729587728F8B7A9084729388\
788C897D8986758E89729289789285788C89788A8A7A8B88788C89788C88788C89
788C89788B89788C89788C89798B88788C89769385728F8B788C89788D88788C8969948E5F9992\
788C89B28D5C6A968C59979878878C788C897D8E83788C89788C89738F8A739387
738E8B798A89798A89798A89748A8D789086778C89788C886E918D76938572908A729487729487\
788C89788C897891857D8F83788C898088857F818B7C8789788C8978888B7F7196
7D6F997E9B798299786D88945E8B9C718A8F749089789185
768E88758F89759188788D88788B89728F8A729487789185788C88728F8A778C897E8489907D81\
8C8181788D88778D88778D88778F87758E89788D88788F86748E8A688A969D787A
8C9A7042AA9B7790877A8B88789085789483738E8A78878C7C858A78888C778C89788C88778C89\
788C887C8F837193896B90907B8B877B8A87788C887890867B8F84788B8A71918A
7199857397846E958A6D9689738F8A778C89748E8A758E897B8D86788C89728F8B789285788D88\
71908B78928578888B7C858B7D848A7D868979898A7A888A7D8986788C88788B89
788C89788C89788C89788C89788C89798C877D888878868D788C89788C88788C89788C8869948E\
5FA38B907F7FB54C88878A7E4DA89572948778918578878C7D85897C8A87788C89
728A8E77928571958771908B748A8D7C8A8777898B7C8B8777898B788C89778C8978888B7C858A\
78888B7C8F84788E877C8D84798B88788B89798B887C8A877C818D7C7D906D8A92
6C928D918A77868483778B8A5E899E6A9090768A8B7C8987
798A89798A8979898A79868C7D8A8678878C7D858A7C8B8676898C7D858A788C89739487769286\
8B857F8A728D8A7D857D8C84768D89788E87749287779086748F8A68988C649393
BD726782689A67958F778E887D898781878578888B728F8B72948772948771908B788C89788C89\
788C887D8E837A8B886E8A91749288788F86788C887D8E8478888C7E8A85788F86
788C897B87897B8A8772908A6D938C71908B778D88748E8A788F86788D88778D89788D88788D88\
778D8977898B77838F7C8888788C897A8B887B848B7C87897D89867D86897B858B
7D848A7D8986788C89788C89788B89798B88788B89788C89788B89788C88788C89788C89788C88\
738E8B5F99926E928CBB686F8D7B855997987E838A78868C798B887E87877E808D
7C848B7E88877E838B78868C748B8C789086748E8A788F86748D8A788C8978878C79888B778D89\
789185788C897E8D84788E877A8D8677878D7D8A86787996887B8978888B78838F
78997F699A8A8B8A7C7C8A87657FA074888E6E958A729387
778D88788B89788C89728F8A798B88788B8A7491887B8F8472898F788C897C8A877D858A7C8987\
79878B7E88878583858F80807D86897C88887D898678898B7B8A8778878C6A819B
8386849B906B69859879898A79888B818C82788C89788C8978878C7D8986728F8B71908B778D88\
788C897E89867D848A78868D788C89779185729487789185738A8D7E8986818189
7E808D7E838A8185867D8986738B8D71908B728F8B7794846F99867099866F918C788C89788B89\
788B89748D8A6E958A7293887892857295876E8E8F7C8A877C8F84758E8A788D88
748E8A7D8C847A8B8877898B7B87897B8A87788C8878888B7B87897C87897C8A8778888B7C8A87\
788C89738F8A5F99926E928CB5895D66809E6A948E78898B7B87897B8789788C89
788F86788C8977898B7B878978898B7B8A8878878C7D898778898B778B8A748A8D798D87788C89\
7C8A87788C897C8E847C868A7D8B857286918276917B7894838784837D8B787E92
958B746F7C9A8995767891855E82A378838F82828878898B
788C89768C8A798E86758C8B749089769286768D8979888A788D88719389749188749486768D89\
78888C7D8D8479878B8B81828D7E837F88867C8A877A878A7C898776898C68968E
68948E9B7B7A8A748C77898B79888A828A827D858A7C8A87728F8B788C897D858977878D788B89\
789185729587728F8B779285729984729387788C89788E87718B8E788C89788C89
788C89788C887C89878282887F87877591876E958A7691867B8C8676868E788A8A71908B778D89\
788C89788C89788C89728F8B788F867A868B74898E749884779185778A8B798D87
768C8A798B887D888778878C798B887B8A887C8789788C89748E8A788F86788F86748D8A789086\
78898B7B8A87738F8A5F99928E81809E6E8171908B66958F748D8A788B897C8A87
7B8A8878898B78898B778A8A7A8989798989788B8A798D87788B8A788C8972908A738F89788C89\
788C897C8E84789285729786769882688C94698B94778B8A7E9C7964A08969A681
739F7F6D8397929271787E926D74A274888E798F867B8C86
788C8976888D7E86887B848B7D8C8576888D7B8C8671908B7B8E8578868D7B8D8578898B78868D\
789185768D8978898B7B8A878781859075868A7E857C87897C848B7D85897C858B
6E8D906F8D8E9088797C8987748D8A7D89877E85898187857D858A778D89739487719487719687\
7792857891856D9B866D9B8677918672908A72918A7892856D8C91788C8978888B
7B878A7C87897B878A7B858B86858381808A818785728A8E7D8B85718B8E7995826E928C719588\
7198856F918B778D88778D89758E89728E8B759386789285738F8A749387749287
749288729388749486728F8B788E87779087749287788F86748F89779086778D88778D88788D88\
749089769087788C897390895E96958784839E658886798B728F8B749287749287
779086748C8C788D88748C8B788C89788E87768D89798D8776888D7D8A8678888B78888B788C89\
78958272998477A07B6BA4816B968B6A7C9F78888B6B8F9090976F6F8D8F7C8D84
77888C68968D81A074687D9F717F96788D88768A8B7E8A85
788C89728F8B7392887491887B8E8574888E7E8C8478868D7B8C86729189799284718F8C729487\
788C89788B8A748E8A788C89788C897C8D85888482867E877D848A7D85897C848B
7C87896D8F8F7C8A878F7F807CAC6F4EA298798F85798E86799085789086788C89788C88788C88\
779583729984788C8978878C788C89788C89748E8A7890866D8D9071908B748E8A
748E8A788C89788C89758B8B7E8E82788B89828E7F748E8A749386729388779185748A8D788F86\
7692866D948B6D9B866D97897195876E9788719388779285719587719487729586
71918B77938471908A739089729984719587758F89768E88779384719587719587719587719587\
73948671948871908A79918468988B599D947193888D8F76778D89768E89778D89
788C88748D8A759187728E8C768D89798D87768D8978888B78878C7D8E83738E8A739287739883\
779B7F73A7796CA3817890866A839A638A9974A17D5FB47F68AF7C6E918C739983
6D8E8F7C8D847E92805E82A3708A8F798E8671908B789185
788C8977888C7B8B87768A8B7B878978898B7B8F8472908A788F86798A897B868B7D8789798B88\
72908A758E8A788C89748E8A788C897B8F8478898B858583817B8E867B8A827D8B
84798D87758D7C7E8F888283B65D7B8B69936E9888768E897E8B857C8A87788C89788C89789086\
7E89868184877585907C868A7C858B7D7F8D827D8B828188798C886D918D728F8B
748B8C788C89788C89758E897B8A877D868984868481888479878B7D7F8D81858675898D7D8987\
7D85897C858A7C8A87738F8A7399836D9B86689F876DA57F699E886C9C866D9D85
679F886DA57F63A18968A4846DA083699E8768A28568A3846DA0826D9B866D9B866D928C779086\
738F8A778D8871908A77968273938764978F5DB28268A3847D858A7C9A7C65B878
53AF8C679B8B7195876D928C729388749486748E8A728F8B729487788D887C8A8778928578B06F\
5BB4827797827A80907C87886892905F999278958287888078838F71918B788090
7C808E7C987D78838F6E7A9D708B8F798C88798C88768F88
7D858A788B8A798B88788C89738F8A788C897D89877C8888788B89788F8771918A769286788E87\
798B8873898F7B8F8472928971908B7D8E83728A8E7D8D8474898D7B8E85788E87
728C8D788F86788F86788D8878898B9E787A917D8171A87A5E93978589817895826E918C7C8A87\
78898B7E8F8271908B7198856C968A6D938B7194887890867D8F83728C8D718B8E
748E8A748C8C7A8B88788A8A788C89789285788F86818C8278888B738F8A7B8F8478858E7C8A87\
79878B7D848A828188828188847C8B88798A847C8B887A89817D8C7E808C828189
7E828A8280897E7C8F8281897E838B7E7F8E837D8B817D8C837D8B827D8B82788F7E7A90818A83\
7485907E838A7E838A8186857C818D7E84898286856E87946F948A8B8281A06288
8C659578C46131B5A06D9B86689A8A71918A72918A71948872A57B5CC87347DC7547D87769B775\
6D82987879967F7E8D83888378838F71869272948778888C8282877D92805B8D9E
7E8D838697765E879F728C8D6C8D91768B8A7B878A7E8887
719687759386728C8D7C8F83728E8B749486719488769087788C897B878A7C8A87768C8A79878B\
7C858A788B89798E867B898974888E7D8D8474898D7B8E85748B8C7B8F84788C89
748C8B789185768A8B7C8B86728E8B798E869897688C957354959D6DAB7B7397846E8992778D88\
788D887E89867E828B82878575888D748B8D768C8A788C897D8F83748B8C718A8F
788C89728F8B749486728F8B788E877B8A877B87898088857C8A87788C8978888C78888C7C8A87\
78888C788C89788C897C8A87788C89789483748A8D7E85898181897E808D818685
7C87897B868B79878B7D848B817E8B7C858A798B88788B8A798D8778878C78878C788C89818785\
78838F789086738F8A7D8D8373898E7D89867D838B7D848A768E886E928C749288
7D8A86C75B6F8338BC90877A6BA68055BB8255B28862BD7761C57272A17D828B8178878C727C98\
6D8894638E967695837898806C72A4917F7F768E896D8F8F76A47973898F73739E
7D987C828288777E936B8B9476878E71918A719289768D89
7E838A7D8887728F8B788C887B8A8779888A7D838B7B8C86758F89739089798B887B8889748B8C\
789185768D897B8C86768D89748E8A788C89788E87768D8978898B7D89877B868B
7B8C86788E8772908A769385758C8B788F8795956C937982868A7F69978C748E8A6BA4815C9B93\
788C89788F86738E8A7E928073898E77898B769187728F8B7D8B8578898B718A90
778D89788D88778C89748E8A748E8A789086748E8A7C8E847C8A877C8A87738F8A738F8A788C89\
788C89788C89788C89788C897C8A87808489788C89709589739387738F8A7D8986
7E848A7C8A87768D8973908A72978574928778888C7C868A7D8C84708B8F788C89788C89788C89\
789086789086738A8D7C8F83728B8E78928471908B788D887D898677878C789284
6E968870998569928F8E857DA06288A05E8B85A16F5EBF786A968C728F8A789185787F92718791\
7195875DA08E65A187778A8B5880A98BAD6363A18A698F928C93755D87A069928F
869876647CA38F7A847379997B8A8778888C798A8972898F
729487788C897C858A788D88789185728A8E789185798B887C848B7C858A788D88768D8978898B\
7D8D84748E8A788C887B868B7B878978898B7D8E83738D8B748E8A788C89788F86
799084788C89798A897B8988768C8A798D879090737D8986998A71788C8868948E86A06F4DBE86\
3FB39872908A788C897D8D8475868F788F87788C88768C8A769385748D8A71898F
788C89788C89778D89778D88748B8C7C8E84748E8A789086788C897C8A877C868A78888C788C89\
788C89788C89788C88788C89788C89788C89808C8378898B788C89738A8D789086
739387798B887C8A87779087788B8978898B738F8A739586799184728890788C89788C88788C89\
7C9182748A8D78888C7D8D83738E8B79908573898E788C89789185729487789185
788D8877968264A6855DB77F58CE7250DD6E7EAE6C85758F72859275938672829478878C738E8A\
778C89787D937A7B93738C8C5B919B929D69738591688B95869379677AA2788D88
7E8D84647FA1788C8978868D7B8E8572898F7D858A788B8A
7D858A788B8A749386788F86798B88738A8E7C8F83728B8E78928471908B7D8E83728A8E789185\
768D897C8B86728B8E788C89788C8978918577908678888C78898B789185768D89
7D8B86788D88758E8A78898B7D8987788C888C8B7A86778D9D7180A2886C64979087A06F85907C\
4AB58E2EAEA8789483728C8D7892857298856F918C778D897C888877898B718A8F
788C89788C89788C89788C89748E8A789086788C89788C89788C89788C89789086739387739387\
739387728F8B789185738F8A788C89788C897C8E84788C89788C89738F8A789086
788E8771918A789284798A8978898B788C89788C89798D87778B8A738E8B728F8B789384719488\
7B8F84738790788C897C8E84788E87768D89738F8A739387799581738F8A779682
6E9B8577A07B739F7E70AF7570AE76788C89787897837D8B84788D867E886E918C6D928D78888B\
778191737F95788C88778390728F8B7CA2756D8E8F6D928C78878C6F8296789483
7387906D7D9B7B878A758C8B7E8A8573888F749188789284
72948776908779888A7B8988798E86718B8E7D898778878C7E8D8373898F7D8D84748E8A778C89\
788D88788C8978878C789185739487788F86788C89728C8D789284768D89788B8A
79908579878B7D8789748C8B799284768D8983957A6D88948996759DA35D739883789A7E83947A\
87967631C29725C2A069958D77958377848F7B858B748B8C789086748E8A718F8C
728F8B788C89788C89788C89779186738F8A788C89788C89788C89788C897C8A877C868A7C8A87\
78888C788C89789086738F8A738F8A788C897C8A877C868A7C8E84749287748E8A
798B88798A89798A89788E87748E8A788E87769187759088758E89769087708C8F7E8D8378868D\
7C8A8773908971908B7C8A877E8986788B8A788E87769385789285749486779782
7797817797827E9D787FA2737582927D7695788C896D928C7583918886808386846E8793738392\
788C89669391769782629A8F759C807E808C827492827D8B72739F86937968948F
6F7A9B758094788C89798E86738F8A768F88758B8C7E8986
788C89768D89729189769286798D8772898F789284719488789284718B8E7B8A877D8689788C89\
788C88788C89739387788C897D8A8676888D7D8987748E8A798C88788B89769286
78898B788C89768D897B8A877B8C87788C89868F7C6D89938C99719D7F75A0817278878C8D8B79\
8B90778993762BB5A526B3AA788C896E8C907795836E8E8E7C8B87788C8973888F
78878C788C89788C89788C897C8A87788C89739387738F8A788C89789086739387739387789086\
739288749486768D8978888C78888C788C897890867393877C8E847C8889768D89
749189759386728F8B7B8A8778898B798F85788C897891846F908C798C87718D8D789086738F8A\
789086798B88738D8B739586759D7E6B9E856DA1826DA67F66A5846DA2826D9C85
78A47768BB7363C86E66968F726FA1827E8B869A74608F986C8E907C828C90708A887090788C89\
739D7F6497907198856F86937C8B85698797788C897874997D898782947B77759A
6A819B749287709389778E8878888B798B8872898F7B8E85
768F8876898C7D8888798C8878888C788C89799085778A8B7B868A78898B749188748E8A7C8D85\
748A8D7C8D8579878B78888C7D8D8474898D7B8E85798C87738E8B788C887C8888
748F8A779284718F8C789185788C897B8C868186867E8A86858B808D9275969C66788C89849B75\
859777898B7C80888526BEA31FBCA9728A8F7E91806B8B93789086788C89718B8F
738F8A789086739387739387739387788C897C8A87738F8A738F8A7C8E84788C8978888C7C8A87\
7C8A87798B88748F8A71908B739387739586768D897C8A87789086759386768F88
768F88788F86728F8B7295877292897991847490897C92826F918C7098866E938B748E8A789582\
6E928C7898806B958C7892857E90817A8F857890867E8F82789285729E8068AF7C
6BC36B6DAB7B8184876674A768879878928493827B776D9F7D7F8D6F8693789483729487828785\
888482738B8D71849373898E788D886D8496788B895F9992789F7C787F92767B96
77838F789284718F8C72898F798A89798C88728A8E7B8A87
798A89738F8A758E8A7D868978878C7D8F8276888C7B868B78898B7B8F84768F88728C8D7B8F84\
738F8A78928471908B749386769286728C8D7B8A877C87897C8988748D8B788C89
7D8B85798C88768C8A788C89788C897991847293887E9C786F908D98AA5B7DA0777D8F83899774\
81947C818785898382878B7E1FCD9D05CEB07593866F8D8E729288748E8A728E8C
72918A769186788C89788C89788C89738A8D7C8E8478888C788C89789086788C89738F8A789284\
768D897C8A877A8B887490897491897790866F8F8D7890867C8C867C8888798A89
798D87788B8A798F857495866D958A749089798F8578908678878C7D8986728890758F887C9381\
6E948B789285748D8A7298857693857C9083789185789B7E74A8786BAD7A71A57C
85927B787B947C6F9A7A6D9D78878C739387788C897185937892846BA18368A881689B8A6B9D86\
788C8984768F788091788D88738294788290788B8978888B78759983749178878C
728F8B7F838A7E7E8E76848F7B87897D868978878C788C89
768F8878888C78898B748E8A788C897E8986788B8A739288748E8A7C8A877D8887748E8A779284\
758D8B7B878A7B848B7D86897D858A788B8A749386729288788F86788C89748B8C
7D8D84798A89798A89788D88778E887D88877F8886888E7B728791AB9D56818C827D8E838D9175\
858E7D788C8981907F879875858A801FBBAA0BC0B6788D887286917C8987738B8D
788D88768C8A788C89788C89788C89738F8A788C8978888C7C8E84788C89788C89788C89798B88\
788B8A788C897C8C85798A8978888B7C8C86748C8C769187759187779186769087
788E87768D897C8F837A8B88788A8A728F8B7894837594856B958C75938670938A718F8B80927E\
739089728F8B7793847796826E958A78958177A6776DBA7069AB7E78AD725F9992
807E8D7D769470779D778A8B78928578898B778D896C8795848684887E8788758D7E759488788A\
787D9478888C7C88897B7D91787E93778B8A788C897384916A8A956E9689788C89
77848F75898D78898B788B89748E8A788F86749386728F8A
7E838A78868D7B9083718D8D788F86748E8A7C8A877B868A788C89749188789284768D897B868B\
7B8988729289719389749188748E8A7B8A877D8B86768B8A78898B7B8C86729189
76908778898B7B8A87798D87778C89768F887B9183838D80788F869EA35C81907F7D997C7E997A\
85888182878581987A8499767893847E848A1F58F0788C896E8C90778D8978898B
788C89778D8976898C7C8A8778888C7C8A87738F8A739387789086788C89789086748E8A788C89\
788E87758E897A8F85768D8A768F8878928574908976958471918A788E87788C89
788C89789086789086788F87759386729686739586789086738B8D7584918289836D9B8672A37D\
6D97896E9A866F9986799E7B679F886EAC7A77A07B8DA2696198918C887C70769E
719786639195698A957895827393876F918C78858D72849278898B807D8C838684728A8E787E92\
86828576898C79828E788190778B8A788C89778290787E9278888B7480947E7F8E
79818F7C848B788B89788F86748B8C7B8F8478898B78878C
788C89788F867B8F84738D8B769087749089728F8A789185768D897B8C86798D8776878D78898B\
7D8D847B868B7B8988768A8B788C89749188798F8678888C788E8778918578878C
7B868B788C89788C897D8B86788B8A7B8C867C8C8580927E7BA77387A86A81907F888F7A82907E\
77878D8B8C7B89887F91857B8580877876992AA7B02FB2A473879077898B78868D
7D8986788D88718A8F7C8E84738F8A789086788C89788C89788C89788E877A8B88788A8A769385\
749188748C8B7C8C85778D89788E87798A897B8E8578898B7B8D8671908B78898B
7B8A877C8E84788C897A9084788F867898806B9889718B8E787E92788C8978A9746DA18272908A\
77928570918B7694847C9F786D9D8578A57768A5838A83828D6C8F807494857291
8D6E8E7F689D7C7C918288847C858A79888B6C8895789682649C8C679D8978968172898F69998A\
6FA47E6D879478838F788C89768C8978848F767F94788091817F8B72809679878B
788D88729586758E8A7B8789788C89798E8674898D788F86
788C897B8A877C8B8677888C7B8B87788C89748C8B798C8878888C7C8E8478888B78878C788C89\
7B8A87788E87779086748A8D7B8F84768D89788F8771918A788C897D8987728D8C
748E8A7B8F84738F8A799085768F887893847690878397788C9A6F879B73789582849579828785\
7C828C8999727891858B8D797F7C8F7A7D92779C7D187CDC6F8992788B8972898F
7E8F82788C89718E8C789483749189758E89789086749189758E89798B88788D88779086798C87\
798A89748F8A768D897C8D85768F887490897C8A87788F87788E87798B886D958A
749784769385759386789682739B8278938478878C6D7F9A77838F82A470789C7E78838F78878C\
7D92806EA28166B27B6EB375639890878E7B7D8B85669292778D88778191789781
6591936E8B91778D897D8E83789086739F7F5B88A08B887D777B95808885727C98868583788C89\
7E7694787996788C89788C8977878D73898E6E849678838F788B89718990748B8C
7D8F8278878C78868D788C897B8F84768A8B78898B7B8A87
788C89789185788C89788C89788C887B868B7B878978898B788C897C8D85748A8D788C89788C89\
788C897D8D84788C89738C8D7D89877B89887B8B87798B88718B8E7D8D8478878C
788E8777918576898C7C87897E89867E8D84778D8989A46B7B9E7A90966F7898807C9B7B729884\
709D82879D71748E8A848187837690818D8184A56D0C66F578878C738E8B72908A
789086798B88768C8A7C8E84768D89748C8C7C8E84768D89749089749287769187788E87768C8A\
798B88798B88749089788E877B8A87788C897494857896826F918C789285788C89
778E87788C887C91827893847D947E6E958A6E88936D87946EAD7878AE716E9689689A8A6CA083\
72A57B789E7C79A3787193896B809A83917D7D898679868C6C908E6C9E85769882
6786996E8992788C897C90827A8E86867C89687AA17F967C698E927D977D5D9A92729D8177878C\
69948E69938E788B89788B89737F95826F967E7793778C8978898B75859078898B
7E8C8474888E788C89789185788F86748E8A728F8A788C89
788C897D898778878C7C8F83728B8E788C89788F86748E8A788F86788C89788C89748E8A788C89\
788C897B8A877C8A87748D8B749188788F86788C897B878A78868D7B8E85748B8C
7D8E8378878C78878C788C897C8F837D8F8378968290A267789781889874868C7E828A82818785\
80967B7C9E7972879178848F7C8F848498778F867B1554FA7C8D847385917E8986
779186748E8A788C897A8D877A878A788C89788F86788A89798B88789285728F8B788C89769385\
709786729686749486708F8D7995817194887A9084788C88788A8A789086739486
749287739884769782789C7E73988478898B678C956CA2827CA475779185788D88738F8A779781\
78A5776BA084838D7F7581936B7E9D8E8081847B8B838684778E88777B958A768A
7280956E8F8D7094897B8C867E749587788C77878D7D918170908B789285788C896C8D91728194\
86768E7878967E8887787E93787A956D8A93788E877B8A87738B8C718E8C739586
758E8A78898B788F86798B887B868B7D868978878C788C89
788C89788F86748E8A7D898778878C788F86788F86748B8C7B8A87788C89788C8978898B788C89\
788C89788F86788C897B8A87788C8978898B7B8789788C89748E8A7B8E85748E8A
798E86748C8B7491887492877891857D8E8382917D92976D81957C7F977B7F967C7C9480788F87\
8E8D77877F8678729B8585837DA47473A07D7895820F69F07C8E846E8E8E779B7E
72908A76888D798B887993836E9987729388778E887494867296867892857292896F9688789285\
788F87759088758E8A729587749386788F86749486749287729389789284778D89
78938477928578928480917E778D886F879378918572A57B70A77B68998B729B826B9A8878A577\
779186817F8B7C888978898B608C9A788C8983828889897E7E7E8E708693759485
72888F789880669490748C8C67869980888580808B888A7E778B8A787F92868583718A8F63849E\
768C89718B8E7C818D7876987D7B907E848A738B8D7C8E8473898E788B8A79878B
78868D788C897B8E85749089729288749386729288748E8A
788C897B8A8778898B788F86748E8A7B8A877B8A87748B8C788C897B8A87788C89748E8A788C89\
788C897B8A8778898B7B8A877B878978898B788C897B8E85748B8C7B8E85788C89
78898B7B8C86768F8877898B7D858A828C81839D7484A66D7D9280888B7D86907B7D8F83788C88\
869A7472898F70908B78A77685A170728C8D828C810F64F47B8B8778898B818785
78838F769187728F8B8289837F8886728A8F799184789284758E8A788F87789285728F8B759386\
749088788F86729389789285728C8D7C8C857B8B8777918673958672908A789185
789185788C887D8F837C938077888C718B8E79A278789E7C789185709389729B826DA47F729C82\
6F8C9074A57A669E89708E8D6C7D9C78838F7D8987897A88877E887A8B88789185
699B89788C89767A977890865F8D9A748E8A7894837F977B767F93787D94898B7C787D946D7F9A\
778D89728195787D93748690729587719587738B8D7C878979858D798A89748A8D
788F86748E8A7B8A877D86897B8988798B8878878C788C89
788C89788C89788C897B8A87788C89749188788C89788C89749386728F8A7B8A8778898B788C89\
788F86748E8A788C89788C89788C89788C89788F86788C8978898B7B8E85788F87
71908B79928476898C788B8A7492877E8D83969F64809C777897817A9A7D84A071709986759B80\
8199786C849782917D82937C898C7C787C9489877F1560F27894826F918C789086
748E8A7C8E8472938870928A7F8F81728F8B7892857A8D86759187749486788F86749386729685\
70918B779484739387738F8A748F8A739387789682759286798E8771908A779285
778D887896827498847E92806E88937C93807F997A7A94817295877497847496847D89877B808F\
7896817C94807186926E8992618E986D928D7891856E928C82907E7D838B868B7E
788C8969988B5F9B9078858D728095709588778C89897B88787D93759B80729A846D88936D8893\
78868D6E7F9A768A8B718C8D7E838A7E7F8D788C89708D8D78898B7B8A87748B8C
7B8A8778898B788C89788C897B8E8578898B78898B7B8E85
788C89788F86749188748E8A7B8E85788C89748B8C7B8A877D8689788B8A749386728F8A788C89\
7B8E85748B8C788C89788F86749188749287769286728C8D788F86788F867B878A
7B848B7E898674888E7B9083768E88789C7E93A562818F8083957A7897818A93767B7E908C9077\
79868C788290838C80899C7170A08066998C7893841964EC81917F6E8C90789582
6E918C7890867C8E8470908B789384789285729289789284779484738F8A779186789085788C89\
7396856F9C846F98866B958C7196867193887A9184768D89789384729587729587
729984789582789185788F86709C836BAD7B72A17E77998073928878898B818487788B89739685\
7E8D837E808C7B7D9178838F6D87946D88947D7A9188758D887090907C82889775
719687758E896B809B6C928D67958F78858E77858E778D88789B7E779B7F71908B67829C777E93\
77878D69889678878C788B896D8E8F78928578868D7B848C748B8C7B8A8778898B
788C89788F86748E8A788C897B8A87788E87728F8A7B8E85
749188788C897B8789788C89788F86788D88739089729487729288788C897D868978878C789185\
768D89788C89748E8A7B8E8578898B7C8B8678888B78878C7B8A877B878978898B
788F86789185728F8A7B8F84788B8A899F6E849E7280977A80947D81927D7D9A7A6A968C879776\
717F967F977C6EA57E88A66A7593866F8C90738E8A156AEB81907F728A8E7D8987
78878C789086789086789285729686779384738F8A7890867C8E84739089769385758E89788E87\
7D8B857D8986788C89728F8B7295876F918C788E87789285789285788C89789582
7298847294877799806E928C84977879987F709D82718F8B7B8A87708D8E788C8980A57160AE82\
60A787659293747F95827C8C78828F6D8D906294937195876D97897D8B85A37777
8D7B85787B9573839278878C728F8B5F9198788B8978997F789A7E788C89788C885C82A4728A8F\
777A967E7D8F718A8F7D898773898E788B897285917B908371918A738F8A788C89
788F86788C8978898B788C89788F86798B8878878C7B8A87
7B878978898B788C897B8A877B8A8779888A7D858A7D858A7B868B78898B788C89788C897D8987\
788C89769087748B8C7B8F84738C8D7C8D85748A8D788F86748E8A788F86749287
76908779888A7B8C86768D897997808AA5697E957E889874789B7E7C9D79809080789284789681\
6A8E928799747D957E88907A817B8E7C7E907C848C1C6BE578958272908A719587
729488789285769385788E877C8A87788B89789185729388789086799383729587709688729E80\
699D887498847496846F918C788C8972978569998A789285788C89789582789582
778D89788D887F947E6B87968D9175809F756E8D8F7584917C918270968769AF7B7AA873789C7D\
5E81A3766CA1788C8968948E78968267948F698B94718593838685708296909471
8685837A7796818586708792828984677F9F779B7F789A7F7895826E958A737F956D73A2787D93\
6E8496799085728F8A718C8E7B858B78878C738A8E7E8C8479898A748A8D788C89
7B8A87788E87728F8A788F86788C89788C89748E8A788C89
788C89788C89788F86748E8A7B8E85748E8A749386729288749188748E8A788F86748E8A788C89\
7C8A877B868A78898B7C8F83728F8A769087749089768D8978898B7B8E8579888A
7B868A788E87798F86788C89829F7384A270789C7D83A46F78958282937C788F86828B817E8986\
71908B81A471759C807C9082738B8D788C89758E8A236EDE788D88788C8978828F
8185877A8A887E898577868D7E89857B88898183888181897D858A8486837E8D83749884769186\
7891856E97887692856E938B6E9B86769186748A8D7498846E9B86779682789483
6F9887709F81759982668A978A9F6D879D715F8B9C738C8C809B786EA77D76A17B738D8C8D7589\
6A6FA863889C87848378848E7C8A87778F875B8E9D6B8D91778A8B7693857F997A
7E8B856E8F8D7A9084728F8B728294787D9386927977878D8884827C7397767B966688996C7B9E\
838684748F8978848F78868D72898F7C858A78888C7B8A877B8A87748B8C788C89
788C897D898778878C7B8A8778898B7B8E85748B8C788F86
749188748E8A7B8A87788F87759485758B8C7D898778878C7B8789788C89788F86748B8C788C89\
789185728F8A788F86798B887C8987768C8A798C87738A8E788C897B8E85748E8A
749386789185768D897992838B997187957782967988977578918581917E7B8F8478848F8C8C7A\
728F8A90A66466909382878578888B789086737E963562D9787E9286758E7E7A91
867F8786788C89768B867C89818289817F8B8084887F86877E828A8582868D7B858F7687828A82\
789582748F897293887492877495856A9A896AA085709688789086749585789185
7A8F857A9481729289658F948DA8667B987D69829B70978781A3727A9D7B7197866C76A1858782\
638E9763839E788C887E8F827196877892846282A06D8B917087928881848A758B
907F7F7C828C7C957F6EA47F4F8DA7788C8987937870908C78848E787E927881917468A5767A97\
818D817E808C7385917B898873898F748E8A788F86748E8A7B8A8778898B788C89
788F86748E8A788C89788C89788C897B8A87788C89789185
7B8789788C897491887B8B877E838A78868D7B8E85748B8C788C897B8A877B878978898B788C89\
7D8D8474898D7B8A87788C89798C887B868A7C8D85718B8E788F86788C897B8C86
788E87788B8A798A897F9B787EA6727EA0767F9B7883957A7C8F837C9C7A7197866A998A7D967E\
7E9280929E68677E9F7F88867E89867C8E846262B75950CA797B93788190828586
7A89897B8B87788B89808587837E8A80808B8685837D848A7D85897E89867E8986828785927C80\
8E74898785827694846F9489788D887A89897A888A7495856C9988788D88788C89
7C90827D8F8378948362939595966C80798F78729B8C957378A07B7F957D7381946074AB96916E\
64839E638E976D928D7F937E799184718A8F668A9767958F628E97778C897A8D86
888C7D7F88868897757C818D617AA66F99867F90807D828B6F789D848E7E628C995A81A77C9381\
7299836D908E758D8A72898F7B8988748B8C7B8F84728F8A749386729288749188
788C8978898B788F86748E8A788C89788C897B8A877D8689
749188788C897B8C86738C8D788F86749287768D89788E87728F8A788C89788C89788C89788F86\
789185738C8D788F86788F86748B8C788F867B8E8574888E7B8E85749089779185
788C89768B8A788C898E9572889973809D777C977E81977978968286898080828A7E8F82718A8F\
8DA666789582707C997D90827892847C54AD7C28CC785BAB7D808D78878C7B8A87
7F88867A848D82858678878C7D89867A8B8880888580808B8287857D88878088857E8787828785\
848286937882946F888983827094887097876F97877A8C877A888970908B789384
78997F7496847D9C795DAD8568948E858583647FA1A7995B789980789F7C5CA08F468DAD937D7F\
817F8B648E966C7E9B8E8D77787A95867E876B87957280956D7E9A77838F847C8B
8E808189A16D749486787F926A8C93729A836C928D78848F6C8A9280957C6969AD747C97789C7D\
75898D767E947D848A7485907B8A87788D88788C887B868B7D86897B868B7B8A87
748E8A748E8A7B8A8778898B788C89788F86748E8A788C89
7B8789788C89798C8878888C7B8A877C878978888C7D8E83728D8C749287738F8A788C897B8A87\
7C8B86738E8B788C897B8A87748E8A788F86788C89748B8C7B8A877D86897D858A
7C8A8776928671A07F7CA3758AA16C7D987C7E987C7D9F77759F7D699B897894837E8F82719A84\
8FA5656E7E9A78829083917D7830CAA114BF7D5FA475898D748B8D7C8A8778898B
7E898678868D7E9081748E8A788F867A888A7E8986788C8980898580818B868384808A847C8C85\
7C848B858584848584957D7E8E837E7593867295876B938D7898806D948B759783
7B9381779186849E737896825274B5989B654882B3B484619B7C7A89768C8C81814098AA59909D\
97976A5A89A1628D98859A7564859C848882788191688C9567958F638D97778B8A
84927BA18A6B7A838E6E918C708B8F7C8C86707D9977848F788C887A808F5D7BA97797827B8C87\
717F9676898C75898D788D88738F8A7C8D85748A8D788C89788F86749188788C89
7B8A87748E8A748E8A788C89788C897B8A8778898B788C89
788C897B8A8778898B788C89789185728F8A788C897D89877B868B7C878978888C788C89789185\
779086788C89738C8D7B8A877B8A8778898B7B878978898B788C89788C89788F86
7991847B8F848396787A9A7D8DA16A77978181967B858F7D868A7F77878D789284789284839D74\
82977968859A7499837868A24745DF76878E7A9084728D8C748E8A748E8A798C88
788B89798C887F88867E828B7F8886748E8A7A9084788C88788B897891857895827E8986828288\
7C88887E8A858386848485849783778B6B9294807C6E948A749386759188759485
789483779B7F82967A7E8C84457EB8A282706472AA8A9376A4956169A483788F877661A96370AC\
A0727D885E9D788290848187788D886592927C8888708891708A906290966A938E
84878398906E81967A698B947296866A938E67809D7D7E8E84828670908C5997986E8C907E7A91\
79809079898A74888E7C8D85748A8D7B8E85748B8C788F86788F8678898B78898B
7B8A877B8789788C89748E8A788C89788C89788F86748E8A
729487728F8A788F86748E8A7D898778878C789185738F8A788F86749188748E8A788F86798E86\
788B8A798D87738A8D788F86788F86748F89738F8A788C8978928471908B7B8F84
798E867B9480839779829A77889D717D8E8381947B7D967D7D9C796B988A789B7E6E918C90A267\
6F918C7087927E79915D3DD47460AB728D8C7D898678878C788C89748B8D789384
70908B789384719786708F8C7F8F81788C897A8D86788D88778D897E89868281887E8986788F86\
7C8A877D8B867C8A868287858D81807E818C9783778F847D70908C779086789582
74928783957A7794847DA0773A92B3707C9A90996D5A8C9FBF7464A74C939770855586A766A386\
4F9B9D7F9E7766968F728F8B858385767F93728B8D789582608A9C7892845C8F9C
79818FA6936186927A6987977F8787747D96678E94639D8C73998378858D72739F717D98728F8B\
728F8A768F8871908B788C89788C89788C8978898B7B8E85788C89748B8C788F86
749188748E8A7B8E85748E8A748E8A788F86788C8978898B
798A8974898D7B8E85748B8C788C89788C897C8D85748D8B788C897B878978898B7B8A877B8A87\
788C8979888A788B89788C897B87897C878978888C788C897E898678898B799481
7492877F9A797A95818D9E6C7E9B797A9F7A779A7F81957C83907D78868D818E81719E8185A071\
73769B7F74947635C77845BA77898B75898D788C89788C89788F8670928A799582
6E948B7597837590886E948B7597837598826F9B8570968771908B7793847194887D9380788C89\
7892847790867A8B887C8A878287858486838685839C757E937E7E739D80719488
7895827A997D7B977E82917D5485A84094ADA48B6866839C7D8689988C70877A8A876A95808686\
6082A27E908178888B6A938E7089907DA474559A99818D816183A07E9180628A9A
5FA38B908A78A972767890866397906C8A93759286678D9477829178749A74739E7C8A87718C8E\
76888D798D8775888E788C89788F86748B8C788F86788C897B8789788C89788C89
7B8A87748B8C7B8A877B8789788C89788C8978898B788C89
7B878978898B7B8E85748B8C788C89788C897B8E8578898B788C89749188749188749188788C89\
7B8789788C89788C89788C89749287739487729288749188748E8A7B8A87828D81
7896817C987C7A9C7C87A76A7B9E797D997B779980789F7B789185788C897FA67170A0807C8E84\
66968F5D49CC7843BC78878C7A888A759187729587729388789285749585729C81
6D9F8369A18569A48366A58467A5846FA47E6B9B886D9A87679F886DA1826C968A779285778D88\
7E89867C848B7D8B85788D887C8E847F8D83808786828188A27679A36B7F838288
80947D7A8D87868D7D7E8986658C96479BA2648F959773836C89939A787D8F5A9A937E7E869379\
599A966A84988B8381778092709D827F917F6E80986E849678868C70908B6F8991
758192797D92A096638A7D857E6B9C7A858B78958263889B6B87956977A379888B78898B7B818E\
768C8A798D87718A8F7B8A877B8A87748B8C7B8F84728F8A748E8A7B8E85748E8A
788C8978898B788C89788C897B8A8778898B788C89788F86
788C89788F86788C8978898B788C89788F86788C8978898B7B8A877B87897B8A8778898B78898B\
788C897B8A8778898B7B8E85798C88798A8978878C7B8789788C897491887E9280
83917D7C9083889874899674889676799085868C7E82937B6F918C789384909A6D73888F7C7E90\
8923C67628D07B878976888D7A8D867B8E85788C89758E89779583779A7F749884
779782719A846FA0816AA0856AA0856E9E836A9C876A978B7496846F95896D928C7299846D928C\
778D89788C897E8E82788C887C8E847C8B867C8B867892847C8F8391847C998B71
7E967D7494867D967D789E7C6099915A8BA0517EAF7F9E7675AD734788B09292717A7E91B16E73\
8372925D99936B8E91828685858C7F737B988187855F83A17F9080708196788C89
629891659292A0886D88778B77888C7D8C8581808A6F7D996C86965985A47E8E82708593798E86\
768A8B7B868A78898B748E8A7B8A87788E87788C897B868B78898B7B8E8578898B
78898B788F86748E8A788C89788C89788C89788C897B8A87
788C897B8E85748B8C788C89788F86788C8978898B788C89788C89788C897B8E85748B8C788C89\
788C89788C89788C897B8A877B8A87788D88739089738F8A7B8E85788F877B9B7C
789B7E7A90848C9E6C7DA8717C9E79779A807397848B927671928974A57A7C9A7C78868D6D8794\
1F6AE3748C8B749287729388749386788F86788D8878948375B76C59C87652B985
63AF7F68A384729A8472958772958772958772A47C58B2865CB87E58B68354A59271908B728C8D\
728F8B778D897D8A867E89867C8A877D89867E8D837E89867E8986818F7F9A7B7B
A77F6F789582789B7E81977A668D95578DA14799A478868DA9697D5F7AA87E868887778C897D86\
A26783926B8C6D8C90709588847F897892846CA0835B929A728F8B6F96886A928F
79838E668A97848A818E8B7978848E828C81708E8D6E7E99767B966688986D918D728B8D789185\
71908B71918A768D89788E87729288798B88788B8A748E8A788C897B8A87788C89
748E8A7B8A87788C89748E8A788C89788F86748E8A788C89
788C897B8E85748B8C788F86788C89788C89748E8A788C89788C89788C897B8E85748B8C788C89\
788F86749287738F8A788C897B8E8579888A7C858A788C89768D897E8F8283907E
8188857D9E7883A96C889B727A987F7C957E7394867E9F77768D898A897D7E8986758391782DCC\
7C37C2788D88788D88788D8877898B7B8A8778A87462B97980A273887C887C58AA
A2588E9473857E838A7E78938B6894947D7E88848288798A837C8B828387629891549F966D928C\
728F8B728F8B788C897E8E83788C887C8A878288837C8A877E8F82808A837F8985
A67B72A9737586917B7C92816F918C548AA45EB77E219AC09076869194704591AB87A16E608D9A\
867D899582798680867878977F9E77749089847B8B6E84966A8E927E8E82678898
6F928B6C879578868D95996A67A5846CA1827089906390966380A1827790777F9278898B7B8E85\
7385917C848B788D88788F86788B8A748B8C7B8E85748B8C788F86749188788C89
78898B788F86788C8978898B788F86788F86748B8C788F86
749188788C89788C89788C89788C89788C89788C89748E8A788F86749188788C89788C89749188\
788F86798C88748D8B749188789185738C8D788C897C8F83728B8E829A78749F7E
71AD7677B46D78A676809A7982A0736B9D86789A7F7C8A877E9D7867A6837892846C63AE4153DA\
7B8B877C87897C8A87788C88748E8A77908696A262739486788C897890864EAB93
53CA7869B676699A8A65AB814BC48267C76B5DAF8465AB81678B968A887E7C8A8762A18A49A09D\
728D8C74898D778D897D8A867E848A7E89867D8F837C8E847E8986818785818587
898481A67973B0786D85798C898F794B98A2818289426BC85AA88B9A9A655784A78188847A848D\
5F9594906A8EA77377709B83828F7E7877987F997A639790688E93778D896F8B8F
6E928C628C99728F8A96976A888383787D93758E89678D94517DB0788C8974898E798E86788F86\
6E8893788C897D89877B868B7B878978898B7B8A87788C89788C897B878978898B
788C897B8A8778898B788C897B8A877B878978898B7B8A87
7B878978898B7B8A8778898B7B8E85748E8A788C89788C89788F86788C89748B8C7B8E85788C89\
788C8978898B7B87897B8A87798C88748A8D788F86798E86748C8B8997747E957D
879F707F977B839A7675A47A83A2716F8B9080927E6DA5807D997B7F838A73789A5D39D77859AC\
788C88789086789086788C8878A87559BE7C7CBE6263BC764BCA7F53BE815FA887
6BA97D5FAF8257AE896DB27665B17D65BB7556B3875DAB8648C88247D57A57BF7D61BF7633BB9B\
3BBA965E9794788C89788C897892857892857D8986828B82788C897E89867D838B
888C7C868C7EA984699095707BA3766180A25F8C9B4CA5984D9E9C817B8D8B99713F99AA8D9F6C\
568FA059939B9B7A7BB4657782729382977A798C887F7E8D678C957294876CA183
6091976A809B768D8990827D927C807A7C928983826D7C9B5880A9718C8E768E89778E887B848B\
748B8C71908B788C89788F86748E8A788F86748E8A7B8A8778898B788C89788C89
788C89788C89788C89788F86748E8A788F86748E8A788C89
749188749188749188748E8A7B8A877B8A87748E8A788C897B8A8778898B788C89788C897B8A87\
78898B788C89749188788F86788C89748E8A789185768D89789284839779849579
8B9F6D77A27A7DAA6F78A677789185778D8879977F8786817C7C91878184692FD67841BD789086\
748F897C88887D8986788C88968478946192B16877AB697B95639088738E767E94
888581827890826D979678808E75889A668A925F958A6A939D67868D41ADB13899BC2E98AC2CA5\
8B4CA772789C788C897890867A8F857A8B88788A8A8489817E8986788C88788C89
878A7F898382998376B7845F8F837E5D9A9353A3945E8F9A5390A25193A0A97E6E6B89956A988A\
778D894B91A76D928C937D7F9E8E6B7B9481787C947F8F816E8893768D8981927D
5780AA6C938D6A928E7B868A92976D678D94828E7F6972A773719F74888E789086738E8A708D8D\
7B8B87748B8C749188788C8978898B7B8A8778898B788F86748E8A788C89788F86
748E8A788C89788F86788C8978898B7B8E85748B8C788C89
7B87897B8A87788C89748B8C788F86788C897B878978898B7B8E85748B8C7B8E85748B8C7B8A87\
78898B7B8A877B87897B8C86768A8B7B8A87798E86758E8A7D9082829779839F73
89A6697CA4747D967D8B877D788D887896827A9382728F8A788E8777878D1F64E8779186778D88\
788A8A759187788E877C8B878084887C7D909C737FAF4A8EB73597BC3692AD399B
B3329BB73498A1469BB34191B9299DBD3096B43599B33B95AD43958952A588738E847B8C7E7F8E\
7E838B78868C788C897C8A877C89877A8D86768D897C90837E89867E8986788C88
7D8F83818785938579AC8566A47D72868B7E5970B47880915A9C9445A79C5EA7898F9F694E8FA6\
7FA86F40A3A252A0976D928DAA8F60886E9282858681927D69988B69948E81808A
697E9D6F9E825C8F9C738A8D9A94696D8D9075A07C4880B4718692778D88788C89788C88708692\
7B87897B87897B8A87748B8C788C89788C89788C897B8A8778898B788F86788C89
788C89748E8A7B8A8778898B788F86788C8978898B788C89
749188788C897B878978898B7B8A8778898B788F86748E8A7B8A8778898B7B8E85748B8C788F86\
749188748E8A788C897C8D85748E8A7690877B8B87798F8678A57773A67A84A46F
88A7697F9E7672A07F71A07F7A9481789E7C6D948B78878C7A8F856D4ABF6645C87C8A8778888B\
788D877A89897A8B88788A8A7A8A88728D8C788C89748B8D798F857D8987828288
74859182917E788C89728F8B6E9788779F7C6D9C85739883789086738B8C7B8E8578898B7C808E\
818685788C8877898B7C8A877C8D857A8B887A8B887C8E84788C897E8F82789482
759386788C8989937697916D9D9864898B7D4D7AB67891857369A5837690647AA4A091675DA08E\
6990917C77945585A86E918C8D7B859972828E8A7A84888284768F7A8B8861A18B
60A986669B8B5C81A5738A8D94956D7A818F8D867D4870C078868D78928471908B78878C738591\
788C89788C897B8E85748B8C788C89788F86749188749188748E8A7B8A8778898B
7B8A8778898B788C89788C897B8A8778898B788C89788F86
788C89748B8C788F86749188749188749188788C89788D88738F8A788C897B8A8778898B7B8E85\
78898B788C89748E8A7B8E85798C88788C89768D897E8986948D7380A17378B56B
7DAE6C7993838A9277749288789C7D7C8C85787E93788C897C8A872B5BE5787C94788F86748E8A\
798A89788C897A8E8574898E7D8B8576888D788C89748E8A789086748E8A789086
7490897C9380788C89778D88778D8881917E78898B7B868B7D8987748A8D7C8D85748590788F86\
788C89828785748D8A78938478908678898B7E8B857C8E84789086798B88878582
7D8788788C89898B7C978874AC82689271886A99894B9F9C549F9662AB834FAA9278A5778B8281\
5986A46EA082519A9C5C929971918B84A56E828F7F888483738C8C869478738194
818B826183A0628B9A66968F8E91747794847894834A7CB66D928D7E8A86789185678B96788B89\
748E8A788C897B8E85748B8C788F86788C897B87897B878978898B788F86748E8A
788C89788C89788F86749188748E8A788C89788C897B8A87
7B8789788C89788C897B8A87788C8978898B78898B7C8A87788B89748E8A788C89788C897B8A87\
78898B7B8A8778898B7B8A877B8A87798C88788C8976A37A78A87591A266879C72
85927A789C7D78978182937C788F8778908668958E788A8A7A96800E6EED788F86788F86748B8C\
768C8A7B8A877B8789788C89768D89788B8A788C89788C89788E87768D89788C89
7991847791867896826E918C789582789A7F6F918B728F8B7B8F84738D8B798A89738691818E80\
708F8D798B88827E8B8685837C868A788C887A8F857E8D847C8A87788E87789284
7D91817596847894828E8D789E8F6A859B7481907E5B79AB708494777E947B818E7479998F877B\
6A9A8962AA84528FA35BA19057AB8B838089937088909372708C8E88997360869F
8C81816A79A070918C628C9985927A8798746974A56F71A36D8894788B898385856E8198788C89\
78898B788C897B8A8778898B7B8A87788C89748E8A788C89788C897B8E85748B8C
788F86748E8A7B8A877B878978898B788C89788C89788C89
788C897B8A8778898B7B8A877B878978898B788C89788C897B8A87788C89748E8A788C89788C89\
788C89788F86749188749188788C897B87897C9083899C7079A47683A3708C9C6E
78998089887E7D8C8482937D788290878582777E937698827867A3444BDD769087788C8974898D\
788B8A788C89788C897B878A7C8789788E87768D89788C89798B88789086729587
789B7E6EA18171A37E639B8E749D807697826D938B6D958A749287758E89728C8D73908A7A8B88\
80808B78848E789483799383798B887C8E84788E877C9083788C897E8F82788C88
818785868285818C8280967B978E6FA183708277906D84965D8F9A6B9C86629394699D87729885\
8C92756B8D9156A98E4D93A47B6C9C7195886FA57E939071788091958B73648A99
6E9788698995758E8962849F858C7F948C74556DB97C8E835E899E7E898678838F7B818E78898B\
788C89788C89788C89788F86748E8A7B8A8778898B788C89788C897B8A87788C89
788F86748B8C788C89788F86748E8A788C89788C89788C89
749188748E8A788C89788C89788C89788C89788F86748E8A788F86788F86748B8C788C89788F86\
748E8A7B8A877B87897B8C86738C8D788F867E8C8494956D8AA16C78AA737FA86F
779F7C6AA1847D9A7A7895826C9D856D928C788B8983957A3D4FDF7860A8788B8A788B8A74898D\
788C89788C89788C89748E8A789086798E86758C8B788C89788C897D8F83789483
79987F7B8B87828F7F6C928D7395867896816D938B6F918C72928971908B728F8B738E8A739189\
6F918C778D8880898580888679848D8684847F88867E89867C8A877E8F82788C89
788C887D967D7D9281888780918D7595966C75AB7553AE8C51999C70958861889C7D9D785D8D9C\
938B75788091849777317BCA68AC7E68A8817172A0A3826F788C89878880838386
6E89926C958C689A8B5B88A17E8B85927A816276A97F8C836689986DA67F5E9098788C89788C89\
788C89788C89788C897B8E85748B8C788C89788C89788C89788C89788C897B8A87
7B878978898B788C897B8E85748B8C788C89788C89788C89
7B878978898B788C89788C89788C89788C897B8A87788C89788C897B878978898B788F86788C89\
78898B788C89788C897C8A8778888C7B8A877B908392A76289A86882A76E78A478
79987F789B7E6C968A838B817E7E8E78838F769B7F789D7C0C64F6788D88758E89758E89728C8D\
788F86748A8D7C868A7C8A87788C897A8B88788D88748B8C7BA8735EC674579E95
867D8983828889897E7BAE6E4DCA7D53B3886495916FAB7955A98E66958F718F8B728691808489\
78848E788B89788B89808885788C897895827C8F847A8B877E8D847E89867E8986
788C88868A7F81888580967B8891799E8A6DA08C6A6D81985D92985F99925E999278988061889C\
7C92817C967E7E85894D97A157AF896A7B9F6298917F9C788E887B73908981A371
5C9B93709985688699627EA3798E8678729B8A8D7B5C8B9F839A7766829D787599788C89788C89\
788C89788C89788C897B8A8778898B788C89788C89788C89788C89788C89788C89
788C89788C89788C897B8A8778898B788C89788F86748E8A
749188749188748E8A788F86749188748E8A788C897B8A8778898B788F86749188788C89788C89\
748E8A788C89788C89788C89788C89788F867E987B97AE5983AA6B859B74848585
878A7F838A81788C89719388748A8D7996817C9A7C7878972454EF7A8C8778878C7C858B78838F\
7F8886748E8A70908B7C9182748E8A788E87798C8875878F9B7E78A55C897864A5
7A89898386848A8580AD6F75A7489692519E826999A0727C7F7C8F639791668F936E8893788B89\
788C89788C89788C89789483788C8981808A8684847D8A867E8B857C8A877E8F82
78928478928581907F888880898581998575AA975B65968F6497905D9298679092708B8F6C968A\
6692928E9174668F9478B9692F7EC9768A8C6EA18167829D9D98646E8F8E94936F
6A88967286916A85985B94996D8E9062929589A868509B9C78838F7865A4788F86748E8A788C89\
788C89788C89788C89788F86748E8A788C89788C89788C89788F86748E8A788C89
788C89788C89788C89788F86749188748E8A7B8A8778898B
7B87897B878978898B7B8A877B878978898B788F86748E8A788C897B8E85788C89748B8C7B8A87\
78898B788C89789185738F8A788C897B8A87889477A3A75587A56C789C7D73AA77
6CA580778A8B868A8077829078868D8699757597835B6AB6405FD2768C8A768B8B749089708D8D\
7B8B877F848878858D7F89857B878A7A8B88788D88708C8E7D928078888C7E818B
7E838A8187858586838883827D868979898A758F897C8F838D81817E79916D81996F8793788C89\
788A8A7A8B88788C89808885788C887098867893837E8A857E89867E8986828B82
80907F7590887E91807C918181947C868E7DB8A04B708395738E8A5B83A4738095728294839779\
568EA08A9773718A909D95661F73DD7AA079707F976B799FA49E5B6E88938F8E76
7880916E88936C8D9067859A68859A788C898A887E7C76955C74AF788C897B8E85748B8C788C89\
788C89788C89788C897B8A8778898B788F86748E8A788C897B8A8778898B788C89
788C89788C89788C897B8A877B8A87748B8C788C89788C89
788C89788C89788C89788F86748E8A788F86788C8978898B788F86788C897B8A87748B8C788C89\
789185738F8A7C8D85748D8B748E8A788F86899A72A5B04D85A56D76928690877A
7F7E8D758D8A7D8A867A828E798F85899C7075878E4641E37859AC76868E7B87897B838C79858D\
788B89788D88778D89798D877B8A887C8D857892856E8B9181878579848E78868D
7E89867E8F827B8D86838C817F8B83779086768F87788C887C8E8478868D7284936F8991788C89\
758A8C7B8D86788A8A7A8B8880888580818B8088867A8B887E8C847A8B88828A82
878483838486818D81818F8082907E81957CB295577F8F8169948E597EA96CA87E4D97A1908A77\
667BA28A9D6F66958F907F7F4F73B968988C63859D69968D9590708585837D8986
8187856D928C68998B578EA067859A79958174888F7A6B9E74749C788C897B8A8778898B788C89\
788C89788C89788F86749188748E8A7B8A8778898B788C89788C89788C89788C89
788C89788C89788C89788C897B8A8778898B788C89788C89
788C89788C89788C897B8A8778898B7B8A8778898B788F86788F86748B8C7B8E85748E8A748E8A\
7C8A87788B89788C897B878978898B7B8F848CBA598DC6507D967E7DA07766A683
729983728F8A768B8B768F887CAB7071A080719687006CF977898B748A8D779087708C8E788C89\
788D88788C89788B89798C88788B897F888682848774898E74958571918A71908B
7892847E8C847D8B857E967D789B7E739586738E8B789285778C8976839076809378848F788B89\
758A8C7C88897B8A87788E87788C88788C898088858088867D8F83788C887E8B85
808885848882868C7D81907F828C818B857FA8806DAB8666688798578EA0827A8E6D75A1789284\
6C87958E9770728691719686578F9F628B996193956B8E9083788FA58E6569948E
7D9B7A6E8C90787E93686BAC727E9683A07155919F5F82A2788C89748E8A788F86749188749188\
748E8A788C897B8A877B8A87748B8C788C89788C89788C89788C89788C89788C89
788C89788C89788F86748E8A788C89788C89788C89788C89
749188749188748E8A788C89788C89788F86748E8A7B8A877B878978898B7B8A877B8789788C89\
748E8A7B8E85748B8C788C89788C897C8F83B3AE4490A068789B7E85A170717F97
847F897A848D788C8978B26E71A67B758B8C7A848C0F54FF75888D79858D7F848877878D778E88\
788D88778D89778E88778E88778E88778D897C8A877C8D85788D88738E8A718F8C
79928474968478997F7D9380848D7F77888C78888C7D8987788190787D9378838F778D89778D89\
748C8B748C8B7D8E83788A8A7B8B87788C89788C89808F807D89867E89867A8B88
7E8E827D89878D867D898381868A7F808F80919172AB9A58707A9B6F849556959B6C9C866A948D\
6B99897E88878580887F88866177A86C809970889266869A6D7F9AB49654788C89
7C967E6A8E926492934F93A2659292937B807859AD74749C7B8A8778898B7B8A877B87897B8789\
78898B788C89788C897B8A8778898B788C89788C89788C89788F86748E8A788C89
788C89788C897B8E85748E8A748E8A788C89788C89788C89
7B87897B878978898B788C89788F86788C8978898B788C89788C89788C89788C89788F86788C89\
788C89788C89788C89749188749188798E86C0A740909B6C839778838883717F97
7C9182749188788C89A08D6978868D758E8A6E37CC6433D776898C728C8D798D87788C89788C89\
788C8978878C7D848A7D848A7D8986778C8A788C897F88867D86897B8E856E8A91
7F8886818A8380907F7993837D8F8278878C77878D7D848A78838F71869278888B7C8987788A8A\
788B8A74878F8188847A89897A8D86798C88788C89809080788E877C8C867C8C85
7E8E827890867E8F82878D7D8693797E90818B877DB88B596F928B6194946A938E608E99787F91\
7E8E826490947F89868585845B87A26480A07C7D906D839862859EAFA74C778291
91927262879D788E87527CB07379997A878A5F80A478898B788C89788C89788C89788C89788C89\
788C89788C89788C89788C89788C89788C89788C89788C897B8A8778898B788C89
788C89788C897B8A877B878978898B788C89788F86748E8A
749188749188749188748E8A7B8A8778898B788C89788C89788C89788C89788F86788F86748E8A\
788C8978898B7B8E85788C8978898B7BA376A4C43F87A06F84967872898E77878D
7F8C837A8A8875A47A78AC727899806A2CD78319D278779776888D78828F7D8A86788C8978878C\
7D8986728F8B729587729587789285778D89778E88778E887B8B87818785748690
788C89828E808386848885817E898678878C78878C778C89738B8D71898F748D8A78888C7E808C\
7F8886708A907C918278878C8185877C86897C89878187858280898086867F8985
8287848288837D8987878483978377858B7F7D8E83AB8766A26D7F756DA185758F707B9B6A8995\
8A897D717E98788D887E977C6085A05979AD7D87886D8A92618E99AB9B58768C8A
8CA965538CA47A8F854B7EB363899A7E779371769D788C89788C89788C89788C89788C89788C89\
788C89788C89788F86748E8A788C89788F86749188748E8A788C89788F86748E8A
788F86748E8A788C89788C89788C89788C897B8A8778898B
788C8978898B7B8A87748B8C788C89788C89788C89788C89788C89788F86788C897B87897B8A87\
748B8C788C897B8A877B878978898B96CF4278D15878A07A83A3705F8C9B7A9183
749585778D8993946E7F7C8E926E8A1849FF73869076898C77868E73908A78928578878C78878C\
7D8F83788C89788B8979868C7D8986788C89788C89788C89778C8A7C8F84728B8D
788C897F8886828785848F7D7E8F82728A8F78888B7B868A78888B718C8E758A8C738690789086\
7A8B8879868C7E8887788C89759286788C897C8A877C8A877A8B88808C827C8B86
7E8E827E8986828B82788C888F9273898A7D838F7E8B95748C877D78838F6D928C6D8B926C8C92\
788B897881907D8F82807B8F7769A2607AA77891856F918C6298918E9F6A889775
8C9E6D5783A7747D966478A55E7FA56D7E9B78868D788C89788C89788C89788C89788C89788C89\
788C89788C897B8A8778898B788C897B8A877B878978898B788C897B8A87788C89
788C8978898B788C89788F86748E8A788C89788C89788C89
788C89748B8C7B8A8778898B788C89788C89788C89788C89788C897B8A8778898B788C897B8E85\
748B8C788C89788C89788F86748E8AD2AC2E8B8A7C85927A899377637AA5858782
7F87867591878B8F78788C896E62AE4644E079878B73878F778D89788D8878878C78878C789285\
789185798C88778C8A738F8A79918478878C7D848A7D8986778D897C8A8778878C
788D8877948478938484917B7E8F82728F8B6E8E8E778C8978868D79868C74888E728E8B789185\
728B8D788D8877938578938475878E7D8887798C887B8E85788C887E8986828785
828C81788C88828C817D8A868B9077888E7B889278878D7C88947770978770908B658C96709489\
678A97788C897E89866F918C5A7DAA777C95788D88788C896F8C8F898382A38A6A
917E8071749F6390965B8A9F5A76AF718096788C89788C89788C89788C89788C89788C89788C89\
788C89788C89788C89788C89788C89788F86748E8A788F86748E8A788C897B8A87
78898B788C89788C897B8A8778898B788C89788C89788C89
7B878978898B788F86748E8A788F86748E8A788C89788C89788F86748E8A788C89788C897B8A87\
78898B788C89788C897B8A87788C89CBB32F818B839588758A83826A8E926C9889
7E8C837F997970908B8B718D5634E0765AAD79898A738B8D788C89788C89728F8B729587789285\
778D89788C89788C89779286738F89728F8B729587789285788B89788B89789582
6F928B7E89867E828B8C897B828B827A8B886E8C90738E8B71908B71918A718F8B748E8A788C89\
738E8A738E8A7E8D837A848D788A8A779583749386789086788C89788E877C9083
8287858386847E8E827D8E8487897F91877A8F857C8B897C91887985828573888F6D928C6A8D93\
6C899471918A779881719F803C77C481878578938470908C7391896D8D90A5A952
698F9178888C6D8B915784A74E7CB473898F788C89788C89788C89788C89788C89788C89788C89\
788C89788C89788C89788C89788C897B8A8778898B7B8A8778898B788F86748E8A
788C89788C89788C89788C89788C89788C89788C89788C89
749188748E8A7B8A8778898B7B8E85748B8C788F86748E8A7B8E85748B8C788C89788C89788C89\
788C89788C89788F86748E8A7BB9669FD537689F87829B767F838A897C8777848F
799C7C7F987B6E85956C3DCA7538C67C8A87748B8D79888B788C89788C89788C8978878C7D8986\
788C89778C8A7990857894836F94896F9489739287738E8B788B89789384798F85
75868F788C89778C8A888D7C868C7E7A8E8671908B6D97896E928C72988467948F728D8C769187\
748B8D788C89789086728F8A789582789285768D89788C88778D89798C877E8D83
788C8982907E7F8985828785838F7E878D7D8E8D77898D7B8A8A7D8696766B8F90788C89658C96\
6984997F89867E8D838281883E76C4759D7E788C8977868E7AAE6F4791AABDAC3E
56949D7082968074946779A24B77B978888C788C89788C89788C89788C89788C89788C89788C89\
788C89788C89788C89788C89788C89788C89788C89788F86748E8A7B8A8778898B
788C89788C89788C89788C89788C89788C89788C89788C89
7B878978898B788C89788F86788C8978898B7B8E85748B8C7B8A8778898B788C89788C89788C89\
788C89788C897B8E85748B8CAABE408E93739672848A93766A83998A8F79729189
8899747485917C7D902065E66C8F907996806C8B92788D8878878C7D8986788C89728E8B799184\
789086729388789D7C6E9788758E89738F8A7393886E918C728F8A7F8E82768A8B
758A8C798C88778C8A82907E869577778F8777918571908B6E928C778C89728194748D8B788B8A\
739189719A84719A846D9888759385778F87758E89768E89788C89788E877C8B86
7C90827A8C878288847D8F83858A80878A7F8E8E778B8C7A868E7C93936F6B978B66958F6D8893\
5E8D9B7891857E8986788C89497AB87D8D84728E8C728F8B9DAF54288BC5C2A341
6E8496558DA26D8099756EA0596FB4788C89788C89788F86748E8A788C89788C89788C89788C89\
788C89788C89788C89788C89788C89788C89788C897B8E85748B8C788C89788C89
788C89788C89788C89788C89788C89788C89788C89788C89
788C89788C89788C897B8E85748B8C788C897B8A87788C89748E8A788C89788C89788F86749188\
749188749188788C8978898BCACA1F4C95A3939E6885868377829184907D808885
899E6F6076AA8B3CB26A41C87599816B958C6F8693798C88728F8B789285788C89779186739586\
769584749287818C8279928368A285679B8B71928A71908B6E918C789781709389
6E8E8E788D88778C8A82987981977A789383749089758E897293886A91906B8F90758E89729686\
739983739983709B836B9D8668A38468A78163A48768A285679B8B739586739387
7F8D8278868D82907F7E8E827D947F81957C869379898A7D8D877C9783788F8C775D9497639790\
5F8C9B71908B78888C838C804383B7758B8B7E997B60A08CA5AB513268D6BB9450
838F7E517BB26B7A9F667AA3627CA5788C89788C897B8A8778898B788C89788C89788C89788F86\
748E8A788C89788C89788C89788C89788C89788C897B8A8778898B788C89788C89
788F86748E8A788C89788C89788C89788C89788C89788C89
788C89788C89788C897B8A8778898B788C89788C897B8A8778898B788F86748E8A7B8E8578898B\
7B87897B878978898B78878CF0A31E5C7EA78EA96367958F799A7D728C8D87AA68
74888F6A7A9F306FD37A9C7B64AA8262879D728791798D87788C89788C8978908678958274A17D\
67B97552C87A4DB88971A57C71A37E599C94699D88678F9378888B7E8D83788A8A
6F8892798B89788B898A8B7B888B7D81917E6F95897099867082957E8589698896789781709E82\
6EA2806CAA7C66B47A5AB6815EA689709D83699B89699B89668D95778D89789582
6F9A866F99867895827D8F82838D80848E7E888C7C8594797F987A848D7F9D7E77827591708D8D\
588CA072958666929282917D4F80AF659B8C819D756E918C9B99653367D6B1AD46
809A784674BF6D8B925486A8637EA27D8986788C89788C89788C89788C89788C89788C897B8A87\
78898B788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89
7B8A8778898B788C89788C89788C89788C89788C89788C89
749188748E8A788C89788C89788C89788F86748E8A788F86748E8A7B8A8778898B7B8A8778898B\
788C89788C89788C8972C7649ACD4177898B8DA2696A948E789980688D93A39463
5F73AD8242B56C4AC0919D696E86945D83A3728F8B738F89788C8978948374A37B6BC36C58C27A\
728F8B92708878A87547D17D58B58456989969A7804EB68B4EA696789086788E87
6C8A93788C89788C8982917E888D7C898D7B7A878A7C8F835A989770D55B27E38846CD805DA28D\
7A7E91969A686DC06C50A89360A4895FB0815FB08259AC8A50A098689E88779682
778D89788C8979928478918580927E80937D81977A88907A898581858C7E82808A918B76729587\
5886A5788C886D8C9178868D657BA3728691879279738F8A909A6C2F73D1BDA146
87768D5960BF807E8C5C6FB268819C789285788C89788C89788C89788C89788C89788C89788C89\
788C89788C89788C89788C89788C89788C89788F86748E8A788C89788C89788C89
788C89788C89788C89788C89788C89788C89788C89788C89
7B878978898B788C89788C89788C897B8A8778898B7B8A8778898B788C89788C89788F86748E8A\
788C89788C89788C89B4B24180888595827995877682977966968F708296999669
5BA18F0F7BE3838C81878D7D7C7D90637EA278878C798C8873988375A37B78B86A78A6767769A2\
7F5BA695AB5D7EB765749A8254989B5AA09167958F7E8986528BA569A48369958D
6D8794788C897892857C938082907E898D7B79948278A279609E8D9F7E75997A7C5168BF8C48A9\
8CA76671C8638B8F786677A57E9F766183A08F857C69A1854AA59A5A9D93719687
70908B778E887D8F827891857E8E8286907B84937A7F8E828397787F957D70A1807EB964639E8C\
5184AB78878C7897815A919B65859C6E928C81A2726A928E918C763D71C8ADBA40
5D7BA8676EAB788B895274B678838F788C89788C89788C89788C89788C89788C89788C89788C89\
788C89788C89788C89788F86748E8A788C897B8A87788C89748E8A788C89788C89
788C89788C89788C89788C89788C89788C89788C89788C89
788C89788C89788C89788C89788C89788C89788C89788C89788F86748E8A788C897B8A8778898B\
788C89788C8978878CC96468B1717183B6636DAC7A8AA36A5E82A370908B8E877B
9760902A4AF2899973749C8069928F62899B6D938C779682799E7A76AD7382B46564CC6A18BAB0\
4BAA95AAAE4B8659A2BAA04930A0B16DB27637B69B5EA988579E956494926E7F99
718692788C897D8D847D8D84828D80868583918D75828C81789A7F599C949F7D765590A023BDA5\
B1CD30616AB1B1AE4624B6AA82A86D427DBB96C7484BBB895094A058999764A387
6497907295877892857C977E6F988682957B868F7C7F987A80987A7F8B838D9D6D869777718394\
519A9B52A09784937B5E77AA6D8E8F699C88828E7F788091868E7C477CB9BCA941
457DB96190976F82965871B4788C89788C89788C89788C89788C89788C89788C89788C89788C89\
788C89788C89788C897B8A8778898B788C89788C897B8A8778898B788C89788C89
788C89788C89788C89788C89788C89788C89788C89788C89
788C89788C89788C89788C89788C89788C89788C89788C897B8A8778898B788C89788C89788C89\
788C89788C8972CD5F38D188A6B5499D8472937E7E90807F70799C788C8978858E
786D9F446AC784A46E7892846D869668859A74898D7C977E7D9F77859E728BB45E858F7C5383AA\
3EE4764EFF5615EB8F94B854655BB99286796D6DA770799C786F9D74729E6F8296
748C8C748E8A7C8E847D8F837F8D827D8C849288788D8181907F7F77898B63AA837B9282518EA5\
A0D13A1DD7978AD6475485A864AB813CB99686B4627C709A5A7FA86B8C926D968A
6096936C978A73948781947C779682759D7F7DA672789E7C7E8B85828E80968974927E7F787798\
827492658A986D99875787A5748E8A7591876D9F83659392868A7F5276B5BC984D
5A72B16987975E6FB06D74A1788C89788C89788C89788C89788C89788C89788C89788C89788C89\
788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89
788F86748E8A788C89788C89788C89788C89788C89788C89
788C89788C89788C89788C89788F86748E8A788C89788C89788F86748E8A788C89788C89788C89\
788C89788C89BBB83741A2A286A06F9599697FA273788190827F8A78938368978D
5382AB5582AA84977778898B6D889366859B749089818D818D7D839C727FC25F719D5C8F868484\
928878996D868C639676799769819B836F958357A5855CA07C689F7D7C90728592
78888B78888B7C8E847D8F837D89878282888C8280917F7F8D79869677819274867698825AA58D\
A97673B83D90A84D9196728475898D788C896F6EA48E5B9A845F9F7C7F8E7B7E90
787B9578868D789483789284848B8081937D889973798D877892857F8E828A867F928A766E8297\
7592877097876690935A81A7748293858881818C8265859C7D808D6175AAAB9B57
607EA46A829A4E74B9718692788C89788C89788C89788C89788C89788C89788C89788C89788C89\
788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89
7B8A8778898B788C89788C89788C89788C89788C89788C89
788C89788C89788C89788C897B8A8778898B788C89788C897B8A8778898B788C89788C89788F86\
748E8A788C89CE6861A9677E6CB37682BB5F789D7D61989170A180789D7D687D9F
6271AC5E9198719B83759684649293618A9C78898B7D848A827C8C927486A16784B34A8AC13590\
C62A94C1249BBE239EC01EA0B02CA3985B93737B986D8A92698B9477838F7C858B
748C8C778E887B8B878287857D86897C8A8783907E82977A779186828F7F827A8EAB5B85984C9E\
926E8A8B768A9D6787B04A8DB92E9BB725A29E3AA68B599E91669093668F89708F
7D7F8E7C8A87818D81789284779484898C7C8F8E7579898A828C81789D7D71A07F8597776E8893\
7C7E9089778B78868D5086AB6A829A8B8F787C9281657EA0757F93677E9FA9995B
647CA36A61B16E5CB27D838B788C89788C89788C89788C89788C89788C89788C89788C89788C89\
788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89
788C89788C89788C89788C89788C89788C89788F86748E8A
788C89788C89788F86748E8A788C89788F86748E8A788C89788C89788C89788C89788F86788C89\
78898B78878C887E86C8CA215BB87F85AB686A9D876D98886D8099958D724D91A5
519B9B5E949671908B7A9680648A996280A27891856D908E74898E7D8987828388807F8C887B88\
8C738B8E877B70AB7953C87A4BD67556CB755291A27C779478769878828F7C8A87
79838E7D8986778C8A7C8B867D89867D838B8D867D8F837E83947B71B4714DBA8851C28053B289\
728096965C949A58939A5A9292659188709088788A7E7D8E7C848B7E8A857D8F82
7899806FA77C6B9989808F80789583789B7E898F797F8A857E937F8983828A8C7B7B977F6E928C\
6099916EAB7A6692925E83A255989B7F9E767C8F835C7FA674868F647BA3AE935B
657AA44C70BD688699789285788C89788C89788C89788C89788C89788C89788C89788C89788C89\
788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89
788C89788C89788C89788C89788C89788C897B8A8778898B
788C89788C897B8A8778898B788C897B8A8778898B788C89788C89788C89788C897B8A8778898B\
788C8972998468958EF9C4005F94958A9F6D70899078838F64869C9191726F6EA5
6D82985C9498669A8C789483648C985589A47E90826F928B679A8C6E918C798D87778D89779484\
71C4665BD66A6CBB7070A0817A6E9C9C41A2814BAF7E7A9174859178888C7C8A87
738A8D7D8F83778C8A798C887C8988788C89838A828C7D84A27679AB70768B8B7B68A8804FB08D\
33C0973EB99462A3896B948C7C88887E838A82898379878B7C9083789682799E7B
77AA74708F8D78888C7798817D987C78998078938383917D7E9F7665A68482A470788A8A7E8986\
6E958A787B947C65A07677996F7D9A828A8282917E5385A972918A558FA19C9468
71799B4670C278838F788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89\
788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89
788C89788C89788C89788C89788C89788C89788C89788C89
788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788F86748E8A\
78878C87B2623F9CA8FFB1097E838A8586838277907893845E93977F8E81648999
6B978A60A38A56A0936C978A6889975981A77A878B83A56E52B6874FB78858C07C53CA7850E06B\
6BCA66757C969A42A3B9279F993BA982649D81798F817F8B7C818D78888C7C8A87
788D88789285778D89778E88778D897C8B867B8B877E89868C7B85A76282C6457FC0368FAC4B8F\
89788A4EB28D39D3863CDC7D36DF8042D08156C67953C37D59C97556C27C65AD7F
808885757C967D8C85818785878E7B7F8F81788C898396798A78899B8C6E718A8F8573908B7B86\
8983825B9A9451969F7084946D89927B9481838F7E5A7CAA7880916E95896EBA70
587BAD5C64BA788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89\
788C89788C89788C89788C89788C89788F86748E8A788C89788C89788C89788C89
788C89788C89788C89788C89788C89788C89788C89788C89
788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C897B8E85748B8C\
728F8BAAA94E3CD1858EF42F7C9182787996887C87917F7F708097779484698E92
70908B768A8B66899869958E5F84A1627DA4728B8EA077799A58938F79857C92817D92818E6D8E\
A137A59C36AA8160A17C818D7C858A78888C788C89788C89788C89788C89788C89
7E8E82788C8978878C7D848A7C848B7D89867C89887C87897B878A7E8986888582917586A26088\
B6448DC52B93B327A3B84E858E76876B978A699F86709B8478828F8A6C9188728F
7881917A838D8085877F8D828792787F8C837C838C918F7466A6838C99717C7894719C8270AE76\
6AAC7C6D9888497CB77185937399836C908E8884826078A970869388A66A758A8D
4D58CE6E789E788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89\
788C89788C89788C89788C89788C897B8A8778898B788F86748E8A788C89788C89
788C89788C89788C89788C89788C89788C89788C89788C89
788C89788C89788C89788C89788F86748E8A788C89788C89788F86748E8A788C897B8A8778898B\
788C89AE8D5FB292599191728287856775A59379828E7E8282808A7F8886708494
77878D738B8D6D8496758A8C5585A85D85A1748D8B748E8A7C8A87937585A1588EA64E9190559D\
787599728A8F788C89788C89788C89788C89788C89788C89788C89788C88778D89
7D8F8278878C78878C788C89789285779285778E88788D88778D897B8B877F8A857C88887C858B\
7D8986798B88798A8996807AA85889B03E96AC4593A452918C5F9985788D868285
7E7C8F7D8C85759B80779D7D7D987C7B88897A888A91867A9B8176788C8978A6776EAA7B789E7C\
788C89718A8F475ECE8C82817C977D626BB09D82745A8F9D62899BA694616078A8
4665C978838F788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89\
788C89788C89788C89788C89788C89788C89788C897B8A8778898B788C89788C89
788C89788C89788C89788C89788C89788C89788C89788C89
788C89788C89788F86748E8A7B8A8778898B788C89788F86788C8978898B788C89788C89788C89\
788C8998A460AABF3F71A37E7C8888616FAE8E8A7986927A788A8A848485748392
768F8871908B64879B7A8E855683A95C83A4758A8C78898B788C89728A8E788C89798D8778878C\
7D848A788C89729488738F8A788C89788C89789185738F8A778D89788D88788C89
7D8E83738F8A728F8B78928578928578878C7D8986788B89798B89788B897D89867D8B85748C8B\
7D8E83788C88788E877C908373898E7993827894837E8F827892847792857C8F83
738F8A81947C7D8887888383878B7E748E8A788E877F9A798585839B7D788F8C77858186857F88\
7E7793857D8A2C67DC9B85738D857D4781B595986B728F8B4A86AFA69E59556BBA
5165C17D8986788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89\
788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89
788C89788C89788C89788C89788C89788C89788C89788C89
788C89788C897B8A8778898B788C89788C89788C897B8A8778898B788C89788C89788C89788C89\
788C89A48E66D19B3B7B7994827A8D5D8A9E7DA275828883827D8B808885788E87
7393877194885B919B749486568DA14F8FA56D908E748E8A778D89728F8B728F8A798C88738F8A\
728F8B7D89867C8987738A8D788C89788C897C8A8778888C788C89788C89788C89
7C8A877D858978878C7D89867D848A788C89789285778D897791867492877492877B8E8578898B\
7D8F83788D88798D877C8888788C897C90827B8B877D8F837E89867D89877D8987
7C8A878188857F86877F977B7F977C78858D7D8D84878B7E7899807CB16B7E8F8285808785927B\
649D8C6E9D84236DDE8B92768E8A7A5B6FB3958F7181957C428EAF95A85F4056D9
6E6EA5789285788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89\
788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89
788C89788C89788C89788C89788C89788C89788C89788C89
788C89788C89788C89788C89788C89788F86748E8A788C89788C89788C89788C89788C89788C89\
788C8993817CE49730748E8A6D9F8362A18A6D9E84728F8B789A7F7394867C8E84
78888B7C8987667CA17E7C8F6F7A9C5B7EA86D918D6D8F8E778C89788B8A748A8D788C89798D87\
728F8B728F8B7C8A8778888C788C89788C89789185739387738F8A788C89788C89
788C89788C89789285729587729587789285788C89789284749188788C89788C89788E87759386\
789285788C887993836F9589789384788C897C8D847E8F82788C897D8D84798C87
7C967E6F9787789A7F818F80878483788C897B977E78A07B7F9F75898F797581928598767E9B79\
788C89717E982F7CCB7189909D727F6573A895936E8C867E5F98937280954A4ED7
78898B788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89\
788C89788C89788C89788C89788C89788C89788F86748E8A788C89788C89788C89
788C89788C89788C89788C89788C89788C89788C89788C89
788C89788C89788C89788C89788C897B8A8778898B788C89788C89788C89788C89788C89788C89\
788C897B858BE3B81976898C86858378838F797E917C838C8884827E85897C8A87
788C8978868D66829D6E85957281955D899F6D8E8F6E8893778B8A77888C78888B788C89798C88\
79868C78878C789185739387738F8A788C897C8E8478888C78888C789285728F8B
788C89788C897D8F83788C89788C89788B89798B897F87867C838C7C8A87788C897A8D867B8E85\
788C89788C89809080758F887492877392887890867E8C837A8B887C8F83788E87
8589807E8788808F807791867C8F83828983838E7F898E7B8596787B8B877C977E7AA3767E8986\
7E8986648D974080BB5588A682A56F56949D8891798B80828D8A7A4462CD5E6DB2
788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89\
788C89788C89788C89788C89788C89788C897B8A8778898B788C89788C89788C89
788C89788C89788C89788C89788C89788C89788C89788C89
788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89\
788C89728A8FEFA02184878375968473809579868C7896827195877E937F739089
7A80907D7F8D6D88946489996E8C90658999688B966D8C91738D8B748D8B749287748E8A788C89\
738F8A738F8A7C8A877C8B86728F8B738F8A7C8A87788D88729488798C88788B89
739487729587789185798C88788B89788B89788C89789086748E8A7C8E84788C897A9084788A8A\
7D8986788D888089858185867C87897B878A7C8B877B9083788E877D8E83788C88
7C967E7594858090807C8E84788C897F997A78968183917D908C77788C89899C707A9381719D82\
709D82656EAC626FAE54999B7E9C79627BA5838684867092AC637E5045D9787599
788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89\
788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89
788C89788C89788C89788C89788C89788C89788C89788C89
788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89\
788C89728A8FD2C81A7B89888E64948386846D97897E9081768C8A7E8F827A8090
749B81619E8D6D8298707F98728C8D648B98678799718A8F728C8D768D8978888B78888B788C89\
78888C78888C789285788C897C848B78888C789185798C887C898773908A778D89
7D8986798C88778D89788C89788C89778E88778D897C8A8778888B7C8A877C8F83788F86748B8C\
7B9083788C88789383758E897E8D83739288789582789185788C887D8E83788C88
85927B75868F868C7E7C8D8478997F7C9C7A77998076A4797892858A9376829F73789C7D78828F\
8A8382446FC4767D956C8C91709F814F8EA67891856790927D6D9B675AB9788C89
788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89\
788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89
788C89788C89788C89788C89788C89788C89788C89788C89
788C89788C89788F86748E8A788F86748E8A788C89788C89788C89788C89788C89788C89788C89\
788C89728F8BE76550BB4E8278A47774A6796F96886F9A857298857390896F9589
84888378789766869A6A8895788290707E98688699718A90748B8D76888D78888B788D88778D89\
738A8D788C897D8E8373898E789185738F8A7C8E8473908A77918679878B788B89
789285788D88788B89788B89798C88798B89788C89778D89788C897893847A8F857B858B7A8D86\
788F86788C8980908070899181907E788C897E8F82788D88788D887D89877D8A86
858C7F75858F8695777897817E967C7D898789828391817E7A95817FA0758B94757F88866D8198\
8A8C7B4269C978858D77888C828B82557EAD78878C7880915568BC787D94788C89
788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89\
788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89
788C89788C89788C89788C89788C89788C89788C89788C89
788C89788C897B8A8778898B7B8A8778898B788C89788C89788C89788C89788C89788C89788C89\
788C89788C89887E86D1AB3080A074788E8778958270918B788F8770978770928A
6F879278868D6D7A9D7383936C85977284926C8497718A9074898E74908970908B798D87778C8A\
738F8A73938778918573908A778D8978888C7C8A877D85897C8A8772908A778D89
7D8986798B89788B89788C89788C89788C89798C88788B8978938478908678898B788C897D8F83\
78878C7D898680888578858E818B827D89877E8F82788C88789185728F8A7D8F83
7F88867C8F838298798088868684837E937F719E817BAB7078A677789F7B7E957E7E9081659292\
7C94803A6BCE828785729288789582547AB07879967F6B9B5C6BB4788C89788C89
788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89\
788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89
788C89788C89788C89788C89788C89788C89788C89788C89
788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89\
788C89788C89728F8BDD8343BA6A6E808A847F888678858D7A8A887F858875898D
6A958C668F94658C976B8E906989966C88956F859471898F728A8F7B8A8774878F798D87778D89\
77888C7C8B8677888C7D858978878C788C89788C89789285788C897D8887738F8A
778D897C8B86778D89788D88778D89788C89788C89788C897F8C8378858D7C8A87788F867A8D86\
758E89789285788C88788C897C93807891857E8E83798C887D8987788D88789185
7896817A9580848B807C918278948389897E87888090986E7C918285917B78888B8A8A7D728294\
7E8787376BD0847D8B8F89797284935C7AAA6382A06F68A978739A788F86748E8A
788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89\
788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89
788C89788C89788C89788C89788C89788C89788C89788C89
788C89788F86748E8A788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89\
788C89788C89788C89A27976DB8940869478709886709389759088758E8A7B8989
7A8B8863889B6C8299737E96717E977083946D849677878D728F8B729189728F8B758E8A798B89\
738E8B799085738E8B738F8A789185738F8A789285789185738E8B789285788C89
738F8A789285778C8A798C88788B89788D88778D89788C897C8E84748E8A789284798C887A8B88\
7A8E85788C89788C887891857C8F837C87898188857E8A85788C897D8E83789086
7E8E837E908177948484917C789284789C7D7C9E798D9A6F7C8E84858D7E788C897F86877F7B8F\
7F8F822E80C8658F94958E717072A16F71A26872A75D79AA788C897B8A8778898B
788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89\
788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89
788C89788C89788C89788C89788C89788C89788C89788C89
788C897B8A8778898B788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89\
788C89788C89788C897B8A87D9A2309C797B8E7C837881907F84897A8B88728D8C
7D88886B819A6492935F8F996B8399757E94728691718F8B77878D79878B78878C78888B788C89\
788D88778E8877888C78888C7C8F83728F8B799085788C89778E88788D88778D89
788C89798B89788C89778D89788C89798C88788B89789086789086788C897A8D86758E89799184\
788F87778D88778D897E8F82788D887891857893847A9084788C897D8D847E8887
7E8F8280957C77908680967B7B94807F977C7E9A7A8599767C8A87848B807F8C83718A90789980\
78A07B3279CB6493927C9B7B6282A0657DA1646DAD71779C788C89788C89788C89
788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89\
788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89
788C89788C89788C89788C89788C89788C89788C89788C89
788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89\
788C89788C89788C89788C89CB5B6DDF307CC05976906E8C867A8B8B758A868087
768D896A899672809569829A60919762909673898E77878D728F8B728F8B749089729388748F89\
788D88788C89728F8B729488799085788C8977888C7D8986798C88788B89798B89
788B89788C89798F85748D8B78908674928774928778908678888B7C8D85778D897A8F85779086\
788D88788C89779484759385788D887C8E847B8F8478898B7E8E82769385768F88
839A777894837C957F7B938282947B7C9A7B7F997A8187858589817E8D84858C7F71968778A17A\
767898524FD08680867C868A6977A267819D4D78B678898B748E8A788C89788C89
788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89\
788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89
788C89788C89788C89788C89788C89788C89788C89788C89
788C89788F86748E8A788C89788C89788C89788C89788C89788C89788C89788C89788F86748E8A\
788C89788C89788C89788C89728A8FA87276D13F7CCD66637C8A877897817A9184
80828A7089916190976888976F8694648D97688C95778C89788C89728A8F798B8878878C79888B\
798F86758E8A788C89778C8A788C89798C88738E8B789185798C88788C89778D89
788C89788C897C8A8778888B7C8E84788C89788C8978888B788C897B9481729289789184788B89\
788C88788C89808C82798D87749287788F867E8986788D887D987C738E8B78987F
7D967E7D898784947A75A07C75A778789284888F7B7497847C967E7C92817C8F83858F7C7C9281\
5752CA6F63AC7E9F76698B9466869A6475A85E6DB27B8A8778898B788C89788C89
788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89\
788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89
788C89788C89788C89788C89788C89788C89788C89788C89
788C897B8A8778898B788C89788C89788C89788C89788C89788C89788C89788C897B8A8778898B\
788C89788C89788C89788C89728F8B729587828785D987439B8C6E739585769485
6C928D788B8A69849965889A6C8A936D8596688B957197866F918C728F8B728F8B749189719687\
759187758E8A758D8A788B89788C89789086748E8A788C89788C89798F85748D8B
789285729388749387729388789086788C89788E87719587729984789285788C89788D88778D89\
788C88778D897C9281799084788C89788C89789184789185838B81788C89818885
858A80779D7D7BA07881947C83888379878B888482918B7674928780917F7896827C9D79793CC0\
803DBA7697837D997B647CA3766AA2675FB56E7A9D788F86749188748E8A788C89
788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89\
788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89
788C89788C89788C89788C89788C89788C89788C89788C89
788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89\
788C89788C89788C89788C89788C89788C89728A8FB9885ACCA03B5D97957F7792
897E856F8197787C946A8796698995698A956D8A9279878B76858F788D8871908B748E8A7A8989\
78868D7C8A87748F89728F8A789086788C8978888B788C89788C897C8A87788C89
798F8578878C7D8987789185728F8B789285748E8A7D8C84788C89788D88778D89788C88788C89\
788D887892847990857D8C85778D887792857892847790867A9D7B6F9688739586
809D7680937E838D80828785838D7F7899806C99888E7588A1827071A27F789483845BA3556EB7\
5DA28D828F7F7D828B6874A56177A85E76AB7485907B8E8578848F7D8689788C89
788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89\
788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89
788C89788C89788C89788C89788C89788C89788C89788C89
788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89\
788C89788C89788C89788C89788C89788C89728A8F99A85BCE984089728E5C9F90
759F7D657EA1788C886A87966C85966D85966E918D69938E718E8C788C88778C89728D8C749386\
6E8E8F7C9083768D89748D8B789086748E8A749287749287749287748E8A7C9182
7491887096887299847892857297856F968872908A779385778D88788D88778D89778D89788C88\
788C897E927F729388789185789185779285788D877A90848594796F918C759F7D
78A279759C80789C7E729F7F789880848A817B838D67A6838999729D69868B60996E779F6C7B9E\
7878967C838C827194726CA46B7B9F557EAC78848F818785728C8D789285788C89
788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89\
788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89
788C89788C89788C89788C89788C89788C89788C89788C89
788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89\
788C89788C89788C89788C89788C89788C89728A8FAAA94F9C8771AC8F5F6C938D
6E8F8D5D9D91629E8C648F9564929364998E699190708B8F6D928C72908A7794846D908E7A8B88\
708C8E789184769087729487729388748E8A788C8978888B7C8F846E938B799481
759088788F877795836F9A857697826D928C6F918B788C897890867396857095897297856F9A85\
6E9A86789B7E72938974938778978172958772998373A17E7899807892857C9381
83917D7B888988878085937A7097877599827098868594796F889281977A6664B2A45E876C74A3\
7896816577A5867A8A6775A67A5FA77869A1728F8B789582748E8A788C8978878C
7D8986788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89\
788C89788C89788C89788C8978878C7D8986788C89788C89788C89788C89788C89
788C89788C89788C89788C89788C89788C89788C89788C89
788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89\
788C89788C89788C89788C89788C89788C89728F8BAE8466A36088D5A2335F9992
69839A83888362899B6989956A8F916C86966F84957292896E918C6E948B7894836D8B92759088\
749287729388778D897C8B87758E897292897294876E9788779682738F8A789086
789185739883769B8073948774928772908A6D928C6F9E826E9F837199856E9888729E806D9988\
7194887A967F6F918C779483779385779484759386809080789582749883779186
828F7F7890867C9E7981947D7F84898287857C7595967384867D89896B93655DB88C8D79778291\
837591696DAA84729178749A5183AC748E8A788C897B8A8778848F7D8986728F8B
789285788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788F86748E8A\
788C89788C89788C89788C89728F8B789285788C89788C89788C89788C89788C89
788C89788C89788C89788C89788C89788C89788C89788C89
788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89\
788C89788C89788C89788C89788C89788C89788C89888482969F64CB92469F5E8C
6886997C8B86728591619891659A8D5798986497907187917B8A877093897390896E938B6D918D\
798B88788B8A748E8A7892857693857195877196877196867299846DA08368A583
6CA282729A837699816F98876F9D8367A18665A5856BA4816B9D876D9D846B9F85719C836DA083\
62A8866DA480679F886DA2826DA4806BA58169998A78997F7C938178918573A07E
6DA97C6D9988868980848A817782918B758A7990856E958A8A748C7A7398659094799D7C6D7F9A\
78858D5F82A26E83977A6E9C766AA278898B788C89788C89728F8B789285788C89
788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C897B8A8778898B\
788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89
788C89788C89788C89788C89788C89788C89788C89788C89
788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89\
788C89788C89788C89788C89788C89788C89788C89788C89AE6F74CC5C6BB3736E
8882846B8D91788C89727F96777F926E918D58A29154AC8D63A08A758C8B75878E7C818D77858E\
769385719587719587739586779A7F6D9B866DA181679F8872908A81927D729487
739487719587789E7B6A9A8975A07D689A8A719D826A948E76A07C629F8B72A67B60A68872A57B\
66A485669D8A709C836B9F85739A827492886E9D846B98897C858B878781877F87
9275857F7891848F7E818D81727E977C7F8F9C847371998454A98F6689988176918A7A886E7C9C\
7D7595746FA0718990567DAC78888C788C89788C89788C89788C89788C89788F86
748E8A788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89\
788C89788C89788C89788C8978878C7D8986788C89788C89788C89788C89788C89
788C89788C89788C89788C89788C89788C89788C89788C89
788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89\
788C89788C89788C89788C89788C89788C89788C89788C89788C89AA7176D33681
D9496F936F897C92825E959569948E76A5785A929B7284936A7B9F7C7C917D7E8F77888C789185\
7890867893847099856FA081719C82749386789184728F8B689A8B789B7E768E89
789A7F6A9F85789E7B6C9889789B7E6B928D77988165A5856FA27F6B918E7CA37565A3876A978B\
7D9280649293789E7C699D876D99887099867794846BA38154B68667AD7E679C8A
759D7F709688838E7F827D8C7995815BAA89789980986F85895E9C6E789E7094897484917E669F\
7E6F997896826370AC7869A1788C89788C89788F86748E8A788C89788C897B8A87
78898B788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89\
788F86748E8A788C89788C89728F8B789285788C89788C89788C89788C89788C89
788C89788C89788C89788C89788C89788C89788C89788C89
788C89788C89788C89788C89788C89788C89788C89788F86748E8A788F86748E8A788C89788C89\
788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89828785
C2A043898B7C9277847E76937381949263928956A27F7F8D618B9A69A18561A687699C89759584\
759783759783779583789284758D8A789B7E699B8970918B779384709D836B9A89
7D967E779384779781739388789E7C658D9682927D7B818E827D8C7894837E84898F7A846F918C\
7485918281897E8887838089788A8A78888B7C818D929072708B8F7484917A868C
7E937F71908B78868D7E9180838A82857B8B758292788F876E8E8F72829480679D885F9C767F94\
71958783768F5E63B9788C89788C89788C897B858B7D8689788C89788C89788C89
788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89\
7B8A8778898B788C89788C89788C89788C89788C89788C89788C89788C89788C89
788C89788C89788C89788C89788C89788C89788C89788C89
788C89788C89788F86748E8A788C89788C89788C897B8A8778898B7B8A8778898B788C89788C89\
788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89
C25F70D06D5C708C8E828C816A9A8A4EA6955DAA876DA3805D9A936F918C78838F748F8A709A84\
739A827292897B977E7098867097877E9B796C938D6A9E866C9F847798816C938D
789B7E748E8A82927C6F9E83789384669F8967A2866A948D70968884937B649790789880828685\
667BA38BA36A5EA08E719E817288907B8A876EA0817F9B7878908660A6885FBA7B
61B37E609C8F66A9826CAC7A669E896E9F8268948E78848E7C699E83609F7862A685907C6C968B\
78A577457BBB787599788C89788C89788C89728F8B789285788C89788C89788C89
788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89\
788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89
788C89788C89788C89788C89788C89788C89788C89788C89
788C89788C897B8A8778898B788C89788C89788C89788C89788C89788C89788C89788C89788C89\
788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89
728F8BD35C66CC49798D857D848187736EA183749184768F7E6E997A7A94788A8A7B8B877E967D\
709A856C9A8878978178928571908B848C8078878C7D92806E958A748E8A789185
779E7D659E8A78AC726E8D907C808E8D927561AA8454A3936BA87E669A8C7F838A788C89788C89\
65AB8173AA77747F957EA87047C18854B58674A27C6D9D857896827B828D8C7987
866D937F7B8F83858583868475829282798F7D51AE9C5991776AA178739A70C1694FBD846BA481\
757A975D4FC87D8986788C89788C89788C89788C89788C89788C89788F86748E8A
788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89\
788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89
788C89788C89788C89788C89788C89788C89788C89788C89
788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89\
788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89
788C89728F8BBB9F499587767D9C794DA8955ABC7D4FB48B539F976C948C768F88758E89898E7A\
7D8F83719587719B8372958771908B789781729C8274978478888B729786709A84
8088857F987B777C9586768E72A47C788091AE6F74668B97788C89708A8F66AD7F66A0886CA97D\
76A27B6C98895BB68078A6777F7D8D6B809B7E947E73928874878F778D89729B82
66A485689F877286918D6B908F5F978A5E9C6D779F78809184719374AB768EAB626073AC8A9376\
435FD072779C789285788C89788C89788F86748E8A788C89788F86788C8978898B
788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788F86\
748E8A788C8978878C7D8986788C89788C89788C89788C89788C89788C89788C89
788C89788C89788C89788C89788C89788C89788C89788C89
788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89\
788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89
788C89788C89AD6A78CC94447096877C63A39975807480945E8F9A619593728F8B7693857A9680\
83A171669F89749B816A8E91788C897D92807B9B7C6A90907490897F937E708593
7C91828983826C988960B081838D805E9A92789D7C8F867C5F9396789C7E7991846B948C7C957F\
76948575938684858478819078938363A2886C9E85758B8B6E938B729B83779385
7B818E7C6D9B7E7594708B907098865F8A9D7E7B906FA37F4DD17871B1737D73977E78928556A4\
6E4CBD749188748E8A788C89788F86788C8978898B788F86788C8978898B78878C
7D8986788C89788C89788C8978878C7D8986788C89788C89788C89788C89788C89788C897B8A87\
78898B788C89728F8B789285788C89788C89788C89788C89788C89788C89788C89
788C89788C89788C89788C89788C89788C89788C89788C89
788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89\
788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89
788C89788C89728F8BE6575BCC477A5FB97B53A6928373917C79936D928D619196818686838585\
9996686F86947F9080669A8C66A088779E7D7C987C688C957591877C987D649790
789F7B68948E909C6B66809E7F8C837F8C836C9F8470B17465809F88907A70998571908B789284\
7D8E8377918670988670A1806DA57F6E95896C938D699F866C958B787C948A7E85
71859266819E7D7397916E8B8A55A1905B9A788D88909B6B82907E677DA0729E805A74B1784BB7\
81798F818785748B8C788C897B8A8778898B788C897B8A8778898B788C89728F8B
789285788C89788C89788C89728F8B789285788C89788C89788C89788C89788C89788C89788C89\
788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89
788C89788C89788C89788C89788C89788C89788C89788C89
788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89\
788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89
788C89788C89788F86748E8ACC5A6DF5485B68988C3AC2905AAB896D98885F84A176898C838D7F\
9A9A666B9D866C8F90888482708593847D899078857A8E8567958F848A80779682
6E928C78858E90907466859A7C8A878383868F817F8E957243A89C73A67A78709C8F827E759187\
789F7B6D918D7F8C837E927F7B91836A938E6E9E836AA0855F96955E9496797D92
8E5A9C856D94688897787E926F938B61D7654DCA7D6CA1838B867F64969179868C4C4CD7728691\
7295877B908378898B788C89788F86748E8A78878C7D8986788C89788C89788C89
788C89788C89788C89788C89788C89788C89788C89788F86748E8A788C89788C89788C89788C89\
788C89788C89788C89788C8978878C7D8986788C89788C89788C89788C89788C89
788C89788C89788C89788C89788C89788C89788C89788C89
788C89788C89788C89788C89788C89788F86748E8A788C89788C89788C89788C89788C89788C89\
788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89
788C89788C897B8A8778898B728F8BCA7E54D969596E849558A88C549C98599798619E8D789086\
A19166888E7B5B919A7790867894835FAC8568A384849976659B8C669F88848C7F
708D8E6A9F867D89867E7F8C709A846E928C858484A773778E5F9780888554A88F70A27F808885\
8A8382787698898381896895A265848C6A919066919754989150A08B6199736EA1
727D978865989973816194947EAE6C8AB36057939D688D9378848E9373866A3DCB785BAB788C89\
788C89788C89788C8978878C818785788C896E918C789285788C89788C89788C89
78878C7D8986788C89788C89788C89788C89788C897B8A8778898B78878C7D8986788C89788C89\
788C89788C89788C89788C89728F8B789285788C89788C89788C89788C89788C89
788C89788C89788C89788C89788C89788C89788C89788C89
788C89788C89788C89788C89788C897B8A8778898B788C89788C89788C89788C89788C89788C89\
788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89
788C89788C89788C89788C89788C89927E7FDC615CC0597688748D6595904EBC8643B99154B587\
7D8986AD856666978E5E9B917E8D8387848370948979A278719B83639F8B65A187
749884728E8C6C8F90789D7D78958266869A7E848A8A838283818894857982669C8B7B87789582\
777A9686768E897F857185938486848A69948D5F988A58A093698D8472927D64A1
897A895B9E917CB16B699B8982B465828B827A62A57C7F8F6C968A6851BE7D4BB278878C7D848A\
7D8986788F8674898E788F86748E8A818785788C89748E8A78878C7D8986788C89
728F8B789285788C89788C89788C89788C89788C89788C89788C89728F8B789285788C89788C89\
788C8978878C7D8986788C89788C89788C89788C89788C89788C89788C89788C89
788C89788C89788C89788C89788C89788C89788C89788C89
788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89\
788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89
788C89788C8978878C7D8986788C89788C899D787ACE6A60A27A7583848684798D6D7C9C728B8D\
58909EA28171A3727B6C938D62919584888288878084778F96807A758C8B718E8C
71898F79868C748A8D8399776D819979818F6C86958B867E807A8F9A648B89768B8898747E838A\
69809C7D88878374919068908A67958570937D6C9C7F72958B7D8583917C4FB48B
5FC07661C27459D56C47C8837595847D6D9A748B8C7187918935B97840BE789285728F8B728F8B\
7D8986818785728C8D7B8A8778898B7892857B8A8778898B728F8B789285788C89
788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89\
788C89728F8B789285788C89788C89788C89788C89788C89788C89788C89788C89
788C89788C89788C89788C89788C89788C89788C89788C89
788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89\
788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89
788C89788C89729388749386788C89788F86748E8AAA7176D3546BA77D6F6A938E6C8696778290\
708494718B8EA3727BA76E7B6B829978A17A728F8B78888B8C867E90708A848A81
669B8C66AD7F5AA1908298785D85A1799283657FA08A83827C5BA99B5099B95380B74988A63B9F\
A5429B9F5493905B9990559DA04D97A05F8A7E70977F9D7763C1736AB079779881
6DA77E76A479868186825BA47F5FA38386847A8F856641CA7850B378928578878C7D8986728F8B\
729587789285788C89728F8B789285788F86748E8A788C8978878C7D848A7D8986
788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89\
788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89
788C89788C89788C89788C89788C89788C89788C89788C89
788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89\
788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89
788C89788C897B8A8778898B788C897B8A8778848F7D8986A27578DE337BCD4A77738F8A60B67D\
4AAB9563889B7E808DA772789670868F79857F7395858286817F8B84758FA64E92
B354849A7A7B6C7E9C84907C5F889D777997766CA1897F855B9E914BAA957C91828D7D837E7098\
8B6D9095658E9272877098865BBD7C62BA7961B77C74B96C7E987B728E8C78A775
709F81757E948271956E70A3799283788C898737B97243C1789285788F866E918C789285788F86\
749188748E8A788C89788C89788F86788C8978898B788C89728F8B729587789285
788F86748E8A788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89\
788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89
788C89788C89788C89788C89788C89788C89788C89788C89
788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89\
788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89
788C89788C89788C89788C89788C89788C89728A8F7D8F83788C897D8987C75872D85E618D8C79\
5C83A4539F975AA290778092A774768D6793945E949C5F8D98519B9D4F9888788A
976190D02292C500B2E40398C80CA7A736A29557999A6B869C5B908260A07D838B7E848A788191\
739A8265C76D53BA837DAB6F70A87A65A68471A0807D9E776E9888769F7D7C7F8F
9458988865987E7D8E6A928F784BB7C119A3784EB478878C7D8C84788C8978898B788C897B8A87\
7B8A87748B8C788C89788C897B8A87788C89748E8A788C8978878C7D8986788C89
7B8E85748B8C788C89788F86748E8A78878C7D8986788C89788C89788C89788C89788C89788C89\
788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89
788C89788C89788C89788C89788C89788C89788C89788C89
788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89\
788C89788C89788C89788C89788C89788C89788C8978878C7D8986788C89788C89
788C89788C89788C89788C89788C89788C89728A8F7D8F83788C89788C89728F8BCC6565DE178F\
B86A715BA68B4D9C9D53A593729686847192816C98957384787797818785917685
75709F7793855CA48C64AA8272A17E738F8A7E818C8E7C837E7F8D7C88897E947E6BAC7B56A491\
7DA9708696776F839586A86A709985789B7E67A0877C8A878470939859948E51A1
87798B7F8C837875999634B17243C1789582748E8A72938878928578898B788C89788C89788C89\
7B8A8778898B788F86748E8A788C897B8A8778898B788C89728F8B789285788C89
7B8A8778898B788C897B8A8778898B728F8B789285788C89788C89788C89788C89788C89788C89\
788C8978878C7D8986788C8978878C7D8986788F86748E8A788C89788C89788C89
788C89788C89788C89788C89788C89788C89788C89788C89
788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89\
788C89788C89788C89788C89788C89788C89788C89728F8B789285788C89788C89
788C89788C89788C89788C8978878C7D8986728A8F7D89867D898678878C7D8986788C89887E86\
E44D64CA4A796D87955F9F8E54959D679B8A61A18B6D9D8472908A78868D7E828A
78868D83868481749387788B85808777848F728B8D7D92817A91837597837E92809190735FA589\
6BA77F7AA2785EAE8480A571707F97928F7372769C82659C896B92797D92759A81
758E8A8B4FA59D30AE785BAB788C897B8E85748B8C7B8A8778898B78878C7D898678878C7D8986\
788C89788F86788C8978898B788C89788C89788C89788C89788C89788C89788C89
78878C7D8986788C89788C89788C89788C89788C89788C8978878C7D8986788C89788C89788C89\
78878C788C89789285788C89728F8B788C8981878578898B788C89788C89788C89
788C89788C89788C89788C89788C89788C89788C89788C89
788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89\
788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89
788C89788C89788C89788C89728F8B789285728F8B729587789285728F8B789285788F866E918C\
828785CC566FC81A9DC1587662A2894FC1824FA1996F8B9175829278868D788D88
779086749784649690749D7F719C826EA18162B27E5FC37557C4795AB48364A288849F7283917D\
69AB7D6AA87F7A76979573857866A3AC5A85904AA5886D9281937D6D8A939049A6
AF2AA4884DA9787D93788C89788C897B8A8778848F7D8986788C89728F8B789285729388749386\
788C897B858B7D868978878C7D8986788C89788C89788F86748E8A78878C7D8986
728F8B789285788C89788C8978878C7D8986788C89788C89728F8B789285788C89788C89788C89\
728F8B789285788C8978878C7D848A78878C7D9280748E8A788C89788C89788C89
788C89788C8978878C7D8986788C89788C89788C89788C89
788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89\
788C89788C89788C89788C89788C89788C8978878C7D8986788C89788C89788C89
788C89788C89788C89788C89788C89788C89788C89788C89788C89788F8674898E81878578898B\
728A8F7D8F83788C89B96970CC2394C615A2A265845AB1854BB19060AD8363A786
6B928E82828878838F7E8986828189897A88957D7E8F7588957682788190729A8374898E965C94\
BF59778E48A8904FA1A35E8884798D6EA181618E9983679AB73795B026A78154A9
7D8689788C89788C8978878C7D8986788C89728F8B789285788C8978878C7D89867B8A8778898B\
788C89728F8B789285729388749386788C89788C897B8A8778898B728F8B789285
78878C7D898678878C7D848A78878C7D89867D848A7D8986788C89788C89788C89788C8978878C\
7D8986788C89788C89728A8F788C897892857B8A877D8689788C89788C89788C89
788C89788C89728F8B789285788C89788C89788C89788C89
788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89\
788C89788C89788C89788C89788C89788F866E918C789285788C89788C89788C89
788C89788C89788C89788C89788C89788C89788C89788C89788C897B8A87728C8D789285788C89\
728F8B789285788C8978878C7D898678878CB96970B93297A46782709A84669193
66A48557AE89669C8B719587718D8D7C8A87897A89936094A85A88A4578DA45B8A885AA07E7991\
987B7C81818961AE8261A588887B899F499A943FAA82649E728195788C89789582
749386788C89788C89728F8B789285788C89788C89788F86748E8A728F8B789582748E8A788C89\
788C89788F86748E8A7B8A8778898B788C89788C89788C89788C89788F86748E8A
728F8B789285728F8B72958772958772958772988574938678878C7D8C84748E8A788C89728F8B\
789285788C89788F866E918C729587789285728F8B789582748E8A788C89788C89
788C89788C89788C89788C89788C89788C89788C89788C89
788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89\
788C89788C89788C89788C89788C897B8A8778848F7D8986788C89788C89788C89
788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89\
788F86748E8A788C89728A8F7D92806E948A749386788C89AA7176AF43929A4A9E
AA528C9A5298896994897989787797877E8778938461B1805DB97D67A584789285729289749784\
758D8A936D8AAA4396A03FA193559B826D9778838F788C89728A8F788C89818D81
78848F7D848A7D848A7D8986788C89788C89788C897B8A87788C89749188788C8978898B788C89\
788C897B8A8778898B788F86748E8A78878C7D8C84748E8A788C897B8A8778848F
7D8986788C89788C89788C89788C89788C897B8A8778898B728F8B7B8A877D868978878C7D8986\
788C89788C897B8A8778898B788C89788C89788C897B858B7D8689788C89788C89
788C89788C89788C89788C8978878C7D8986788C89788C89
788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89\
788C89788C89788C89788C89788C89788C89728F8B789582748E8A788C89788C89
788C89788C89788C89788C89788C89788C89788C89788C8978878C7D8C84748E8A788C89788C89\
7B8A87788C89748E8A728F8B7B90837B878978898B788C89788C897B8A877B8789
7B828D878185827E8B887A897C7B918282889377839A648C9A5B929060968F61969C608D966091\
926292826F967B818E78898B78878C7D848A7D8986788C89728F8B728F8B7D8F83
728F8B729587729587789582748E8A78878C7D8986788C897B858B81848778898B788C8978878C\
7D898678878C7D89867B858B7D868972938878928578898B788F86748E8A728F8B
789285788C89788C89788C89788C89788C89788C89788C89788C89729388749386728F8B788C89\
7D8986788C89788C89788C8978878C7D8986788C89728F8B789285788C89788C89
788C89788C89788C89788C89728F8B789285788C89788C89
788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89\
788C89788C89788C89788C89788C89788C89788C897B8A8778898B788C89788C89
788C89788C89788C89788C89788C89788C89788C89788C89728F8B7B908378898B788C89788C89\
788F86788C8978898B788F8674898E7D8986788C89788C89788F86748E8A788F86
6E918C78928578878C7D8C84748E8A788C897B8A877B87897B87897B87897287917D8F83788C89\
788F86748E8A788C89788C89728F8B72958778928578878C7D8986728A8F7D8F83
788C89788C89788F8678878C7D8689728A8F7D89867D8986728F8B789285788C89788C89728F8B\
789285728F8B789285728A8F7D9280788F86748B8C788F86788C8978898B788C89
788C89788C89788C89788C89788C8978878C7D8986788C89788C897B8A8778898B788C89728A8F\
7D8F83788C89788C89788F866E918C788C897D848A7D8986788C89788C89788C89
788C89788C89788C89788C8978878C7D8986788F86748E8A
788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89\
788C89788C89788C89788C89788C89788C89788C89788C8978878C7D8986788C89
788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89\
7B8A8778898B78878C81828978898B789285788C89788F86788C8978898B7B858B
7D8689788C89728F8B7B8A877D8689788C8978878C7D8986788C89788C89729388749386788C89\
7B8A8778898B788C89788C89788F86748E8A78878C788C89789285728A8F7D8986
7D8986788C897B8A87728F8B749386728F8B72988574938678878C7D8986788C89788C89788C89\
78878C7D8986788C89728F8B7B90837B878978898B7B8A8778898B788C8978878C
7D8C84748E8A788C89788C89788C89728A8F7D8F83788C8978878C7D8986788C89788F866E918C\
789285788C89788C897B8A8778898B7293886E918C7D8F83788C89788C89788C89
788C89788C89788C89788C89728F8B7892857B858B7D8689
788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89\
788C89788C89788C89788C8978878C7D8986788C89788F866E918C789285788F86
748E8A788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788F8674898E\
7D8986788C89728F8B729885749386788C89788C897B8A87788C8974898E788F86
749386788C89788C89728A8F7D8F83788C89728F8B788C897D8986788F86788C8978898B788F86\
748E8A788C89788C89788C897B8A8778898B728F8B789285788C89728F8B728F8B
7D8F83788C89788F86788C8978848F7D89867B8A8778898B729388748E8A7D848A7D8986788C89\
729388748E8A7D8986788C89788C89788C8978878C7D8986788C89788C89728A8F
818D8178898B788C8978878C7D8986728F8B788C897D8986728F8B788C897D848A81878578898B\
78878C7D8986788C89788C89788F86788C89728C8D789285788C89788C89788C89
788C89788C8978878C7D8986788C89788C89728F8B789285
788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89\
788C89788C89788C89788C89728F8B789285788C897B8A8778898B78878C818785
78898B788C89788C89788C89788C89788C89788C89788C89788C89788C89788C897B8A87728C8D\
789285788C89788C897B8A8778898B788C89788C89788C897B8E856E8E8E7B9083
78898B78878C7D8C846E918C788C897D8986788C89728F8B7892857B858B7D868978878C818785\
78898B788C89788C89788C89788C89788F86748E8A78878C7D8986788C89728F8B
789285788C897B8A8778898B728F8B789285788C89788C897B8A87728C8D729885749386788C89\
7B8A87728C8D789285788C89788F8674898E788F86748E8A7D8986788C89728A8F
7D8F83788C89788F866E918C789285788C89728F8B789285788C89728F8B729587789285788C89\
728F8B789285788F86748E8A7B8A8778898B788C89788C89788C89788C89788C89
788C89788F866E8C907D8F83788C89788C89788C89788C89
788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89\
788C89788C89788C89788C89788C89788C89788C8978878C7D8986728F8B789285
788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788F86748E8A788C89\
788C89788C89788C89788C89788C89788C89788C89788C897B8E85748E8A748E8A
788C89728F8B7B9083788C896E8C907D89867D8986788C8978878C788F86749386728F8B789285\
788C89788C8978878C7D8986788F86788F86748B8C728F8B788C897D8C84748E8A
78878C7D898678878C7D8986788C8978878C7D898678878C7D8986788C897B8A8778898B788C89\
78878C7D8986788C89788C897B8A87728C8D7B93816E8E8E788C897D8986728F8B
78928578878C81878578898B788C8978878C7D898678878C7D8986788C8978878C7D8C84748E8A\
788C89788C897B8A8778898B78878C7D8986788C8978878C7D8986788C89788C89
788C897B8A87728C8D789285788C89788C89788F86749188
788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89\
788C89788C89788C89788C89788C89788C89788C89728F8B78928578878C7D8986
788C89788C89788C89788C89788C89788C89788C89788C89788C89788C897B8A8778848F7D8986\
788C89788F86748E8A788F86748E8A788C89788C89788C897B8A877B878978848F
7D8986788C89788C897B8A87728C8D729587789285788F866E8C90818D8178898B788C89788C89\
788C89788C89728F8B7892857B8A877B878978898B788F866E918C7B8A877D8689
728A8F7D8F83728F8B789285788F866E8C907D92806E8C907D8F83788C89788C89788F86748E8A\
728F8B789285788C89788C89788C89788C897B8A8778848F788F86749784748E8A
788C89728F8B789582748E8A788C89728F8B789285728A8F7D8F83788C89728F8B7B908378898B\
788C89788C8978878C7D8986728F8B789285788C89728F8B789285788C89788C89
788C89788C89788C89788C89788F86748E8A7B858B818487
788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89\
788C89788C89788C89788C89788C89788C89788C89788C89788C89728F8B789582
748E8A788C89788C89788C89788C89788C89788C89788C89788F8674898E7D8986728F8B789582\
748E8A7B8A87788C89788F86748B8C788C89788C8978878C7D848A7D8986728F8B
789285788F86748E8A788C89788C89788C89788F86788C89728C8D788C897D8986788F8674898E\
7D8986788C89788C89788C89788C8978878C7D89867B858B7D8689729388748E8A
788C89789582748E8A788F86788C89728C8D7B8A8778898B789285788F86748E8A7B8A8778848F\
7D8C8474898E7D8986788F86748E8A788F8674898E788C897B8A8781848778898B
788C89788F86788C8978898B788C89788C89788C89728F8B789285788C89788C89788C89788C89\
788C89788C89728F8B789285788F86748E8A788C89788C89788C89788C89788C89
788C89788C89788C89788C897B8A8778898B728F8B789285
788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89\
788C89788C89788C89788C89788C89788C89788C89788C89788C89788C897B8A87
78898B788C89788C89788C89788C89788C89788C89788C897B8A87728C8D789285788C897B858B\
7D868978878C8187857B8A877486907D848A7D89867293886E918C7D8F83788C89
788C897B8A8778898B788C89788C89788C897B858B7D818C7D8986728F8B7892857B8A87728791\
7D8F83788C89788C89788C89788C89728F8B788C89788C897892857B8A87728C8D
7892857B858B7D818C8182897D818C7D8986728F8B789285788C897B8E85748B8C78878C788C89\
7B9083728C8D788C898182897D818C81828978898B789285728F8B789285788C89
788C897B858B7D818C7D8986788C89788C89788C89788F86748E8A788C89788C89788C89788C89\
788C8978878C7D8986788C897B8A8778898B78878C7D8986788C89788C89788C89
78878C7D898678878C7D8986788C8978878C7D8986788C89
788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89\
788C89788C89788C89788C89788C8978878C7D898678878C7D8986788C89788F86
748E8A788F86748E8A788C89788C89788C89788C8978878C7D8986788C89788C89788C89728F8B\
7892857293887493867B8E856E8E8E7298857493867B8A87728C8D789285788C89
788C89788C89788F86748E8A788C89788C89728F8B72958778928578878C7D8986788C89728F8B\
78928578878C7D8C84748E8A78878C7D848A788C89789285788C89788C89788C89
788C89728F8B72958772958772958778928578878C7D8986788C897B8A8778898B728F8B789582\
748E8A788C89728F8B729587729587729587788C897D898678878C7D8986788C89
788F866E918C728F8B7D8F83788C89788C8978878C81878578898B788C89788C89788C89788C89\
788C89728F8B789582748E8A788F86748E8A728F8B789285788C89788C89788C89
728F8B789285728F8B789285788C89728F8B789285788C89
788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89788C89\
788C89788C89788C89788C89788C89728A8F7D8F83728F8B788C897D89867B8A87
78898B7B8A8778898B788C89788C89788C89788C89728F8B789285788C89788C89788C89788F86\
748E8A7B8A8778898B7B8A8778898B7B8A8778848F7D898678878C7D8986788C89
788C89788C897B8A8778898B788C89788C89788C89788C8978878C78878C7D8F83788C89788C89\
788F866E918C7B908378848F78878C789285789285788C89788C89788C89788C89
788C89788C89788C89788C89788C8978878C78878C7D89867D8986788C89788C89788C897B8A87\
78898B788C89788C89788C89788C89788C89728A8F7D898678878C7D8F83788C89
7B8A8778898B728F8B789285788C89788C89728F8B789285788C89788C89788C89788C89788C89\
78878C7D89867B8E85748B8C7B8E85748B8C788C8978878C7D8986788C8978878C
7D8C84748E8A788C89788C89788C89788C89788C89788C89
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[34]:=",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`003P3oool207R<R@80Mhb90P1cRXd207R<R@80OHj3
0P1gS8T207V=Q`80N8b90P1aRXl207j?PP80MXb:0P2<U7@407R<R@80Mhb90P1cRhd207b>Q0P0N8b9
0P1TQI`207b>Q080]ZE80P1?O;<2076:S`80OXn20P1hS8T207b>Q080LXZ>0P1hS8T307j?PP80LHZ?
0P1gS8T207R<R080Mhb90P1nSh8207R<R@80LXZ>0P1hS8T207B;S@80N8b90P1kSXD207R<R@80N8b8
101hS8T207N<R@80P9200P1_RI4407R<R@80LXZ?301hS8T207Z=QP80MH^;0P1mSh<207R<R@80MH^;
0P1dRh`207f?P`P0N8b90P1hS8P607R<R@80Mhb90P1hS8T207V=Q`80MXb:0P1hS8T207R<R080Mhb9
0P1hS8T207R<R080J8JH0P1^RI82086@O`80ZImF0P1LPJD207R<R@80LXZ>0P1hS8T207f>P`@0N8b9
0P1cRXd;07R<R@80LXZ?0P1hS8P207Z=QP80MH^;0P1aRXl207b>Q080M8^=101hS8T207f>P`80LXZ>
0P1mSh<207f>P`80N8b80P1oSh4207R<R@80MH^<0P1hS8T207R=R080NXf60P1QQ:0207R<R080UIQZ
0P1SQ9d206R6V@80LHZ?0P1dRh`207f>Pa00oooo000>0?ooo`80N8b90P1gS8T207>:S@80N8b90P1m
SX<207N<R@80NHf70P1hS8T2076:S`80OXn20P1fS8X208bDM0@0N8b90P1gS8T207>;S@80O8j4201h
S8T206B5W080O8j40P2fYDP204ml/`80LHZ?0P1nSh8207R<R@80O8j40P1bRXh207R<R@<0OXn20P1a
RXl207N<R@80N8b80P1gS8T207j?PP80N8b90P1bRXh207R<R@80M8^=0P1hS8T207^>Q@80N8b90P1h
S8P407R<R@80Mhb90P20T80206n9T@@0N8b90P1bRXl<07R<R@80NXf60P1eRh/207f?P`80N8b90P1e
Rh/207B;S080OHn3201hS8T207R<R0H0N8b90P1gS8T207R<R@80NHf70P1fS8X207R<R@80N8b80P1g
S8T207R<R@80N8b80P1XQYP206j9TP80PI1o0P2YWeH205b1Y@80N8b90P1bRXh207R<R@80OHj3101h
S8T207>:S@/0N8b90P1bRXl207R<R080NXf60P1eRh/2076:S`80O8j40P1dRhd407R<R@80OHj30P1b
RXh207f?P`80OHj30P1hS8P207n?P@80N8b90P1eRh`207R<R@80N8f80P1jSHH20664X080N8b80P2E
V6X206>4W@80J8JI0P1aRXl207B;S080OHj3403oool000h0oooo0P1hS8T207N;RP80M8f;0P1dU8H2
07JAQP80N8N<0P1nQ8T207j8Q`80LXj;0P1iS8P207b8R080S8>00P2:PX8207R;R@80N8b90P1cSXX2
07R@QP@0N8b90P1hSHP207N=R080I9N@0P1XVH`20;JBE@80Hg2/0P1cRHh207f?P`80N8b80P1lRXL2
07N=R@80LYB70`1hTHD207:>S080LXn;101hS8T207f9QP80OXB:0P1hRhT207>>R`80M8Z=101hShH4
07R=R080N9B30P1`UHT207:?R`80P8V50P1gRXX2076@RP80Mhf90P1bT8X2076EQ`80LY:90P1eTHL2
07BCQP80LYF70P1bSh/207Z@Q080LY>80P1hS8T207f9QP80MHj90P1bTXT207RBQ@80N8b90P1hRXX2
07Z;R080N8b90P1hS8P407R<R@80N8^9101hS8T207V;R080N8b90P1fThD207:?R`80N8b90P1hSHP2
07R<R@80JIB>0P1OVI8207R<R@80/XeL0P1ZUX`205VGV080N8N<0P1hS8T207f>P`@0N8b90P1cShX3
07>CQ`80Lhj;1P1iRXT207B:S@80N9260P1gS8T207R<R080KY6=0P1fThD207:@RP@0LYB7101hS8T2
07RAQ@80OHn30P1hS8T20828Q@80Oh6;0P1lQhT207R<R@80N8R;0P1oLIH207e_V@80OY]i0P22VGP2
06f8U080GX^L0P1aRXl207B@R@80N965403oool000h0oooo0P1hS8T207N;RP80M8f;0P1dU8H207JA
QP80N8N<0P1nQ8T207j8Q`80LXj;0P1iS8P207b8R080S8>00P2:PX8207R;R@80N8b90P1cSXX207R@
QP@0N8b90P1hSHP207N=R080I9N@0P1XVH`20;JBE@80Hg2/0P1cRHh207f?P`80N8b80P1lRXL207N=
R@80LYB70`1hTHD207:>S080LXn;101hS8T207f9QP80OXB:0P1hRhT207>>R`80M8Z=101hShH407R=
R080N9B30P1`UHT207:?R`80P8V50P1gRXX2076@RP80Mhf90P1bT8X2076EQ`80LY:90P1eTHL207BC
QP80LYF70P1bSh/207Z@Q080LY>80P1hS8T207f9QP80MHj90P1bTXT207RBQ@80N8b90P1hRXX207Z;
R080N8b90P1hS8P407R<R@80N8^9101hS8T207V;R080N8b90P1fThD207:?R`80N8b90P1hSHP207R<
R@80JIB>0P1OVI8207R<R@80/XeL0P1ZUX`205VGV080N8N<0P1hS8T207f>P`@0N8b90P1cShX307>C
Q`80Lhj;1P1iRXT207B:S@80N9260P1gS8T207R<R080KY6=0P1fThD207:@RP@0LYB7101hS8T207RA
Q@80OHn30P1hS8T20828Q@80Oh6;0P1lQhT207R<R@80N8R;0P1oLIH207e_V@80OY]i0P22VGP206f8
U080GX^L0P1aRXl207B@R@80N965403oool000h0oooo0P1fSXP207F?R@80MI680P1hSHP207R;R@80
LXn:0P1bU8L207RAQ@80N8b80P1bShX207N<R@80OXB90P2@OH4208b1P@80N8f8101gSHP207N?Q`80
MHj90P1hSHP207R?QP80M8j:0P1XRYH209ehNP80S9Y`0P12ZY/207N@Q`80NX^80P1hT8D207RDP`80
Lhj:0`1hQh`207b5RP80N8R<0P1gS8T207R<R080Mhb90P1hS8P207b?P`80LI>90P1[T90207^;Q`80
NhZ70P1hS8P207R@QP80Nhn40P1hRhX2076ARP80LIV50P1cUh@206jERP80KIJ90P1cShX207N<R@80
M8j:0P1eSXT207^=QP80N8b90P1bSh/207RBQ@80N8f80P1aT8/207RBQ@80N8R;0P1lQH/207f4RP80
OHJ90P1iRHX207Z8RP80OHV60P1hS8P207R;R@X0N8b90P1iS8L207f8R080N8J=0P1hS8T207R<R080
N8b90P1hS8P206VDSP80Gj>;0P2@Ogl20;E<R080QhYn0P1=Z9D207:DQ`80N9650P1hQh`207f5R@80
O8Z70`1hS8T207::SP80Mi:50P1aUHL2076@R`80M8Z=0P1lRXL207N9R`80O8^70P1gRH/207R<R@80
Mhb90P1hR8/207b5RP80N8R;0P1lSh@207R>Q`80O8f40P1iRhP207R;R@80NH^80P1lRXL207b1S@80
O7f@0P1]RY8206bBS@80THYg0P26Q8<207N;RP80GXVN0P1ZT90207J:R`80O8V7403oool000h0oooo
0P1fSXP207F?R@80MI680P1hSHP207R;R@80LXn:0P1bU8L207RAQ@80N8b80P1bShX207N<R@80OXB9
0P2@OH4208b1P@80N8f8101gSHP207N?Q`80MHj90P1hSHP207R?QP80M8j:0P1XRYH209ehNP80S9Y`
0P12ZY/207N@Q`80NX^80P1hT8D207RDP`80Lhj:0`1hQh`207b5RP80N8R<0P1gS8T207R<R080Mhb9
0P1hS8P207b?P`80LI>90P1[T90207^;Q`80NhZ70P1hS8P207R@QP80Nhn40P1hRhX2076ARP80LIV5
0P1cUh@206jERP80KIJ90P1cShX207N<R@80M8j:0P1eSXT207^=QP80N8b90P1bSh/207RBQ@80N8f8
0P1aT8/207RBQ@80N8R;0P1lQH/207f4RP80OHJ90P1iRHX207Z8RP80OHV60P1hS8P207R;R@X0N8b9
0P1iS8L207f8R080N8J=0P1hS8T207R<R080N8b90P1hS8P206VDSP80Gj>;0P2@Ogl20;E<R080QhYn
0P1=Z9D207:DQ`80N9650P1hQh`207f5R@80O8Z70`1hS8T207::SP80Mi:50P1aUHL2076@R`80M8Z=
0P1lRXL207N9R`80O8^70P1gRH/207R<R@80Mhb90P1hR8/207b5RP80N8R;0P1lSh@207R>Q`80O8f4
0P1iRhP207R;R@80NH^80P1lRXL207b1S@80O7f@0P1]RY8206bBS@80THYg0P26Q8<207N;RP80GXVN
0P1ZT90207J:R`80O8V7403oool000h0oooo101iRXT207V9RP80NHJ<0P1mRXH207R7S080OHF:0P1l
RhH207J9S080OHF:0P1hS8T207>DQ`80MY:60P2;QGl208YbS@80RWf50P1mS8@207J=R@80N8j70P1d
TXL207N@QP80M8n:0P1XV8`206BCT`80_G9W0P22J9X206NES`80Mhj80P1mRHL20867Q@80N8R;0`1b
Sh/407:DQ`80LI2;101hS8T207R<R080OHj30P1jRhP206j:T@80M9:80P1hShH207R<R080OHj40P1h
R8`207j:Q@80N8n60P1hS8T207^7R@80NhZ70P1bT8X206fCS080LI2;0P1gSHP207B>RP80N8n60P1h
SHP207N=R@@0N8f80P1gSHT207N9R`80Mh>?0P1lR8P207R<R@80NX^80P1kQ8/207b7R@80OHV60P1m
QXT207^5R`80OHB:0P1mRHH407R<R@80N8^90P1iRhP207R;R@80N8b90P1hRhT207R<R0@0N8b90P1h
S8P207>>R`80GiVB0P1^TX`20;]XK`80SG^50P1IUiP207j3RP80N8J<0P1iRhP207j7Q`<0OX2=0P1l
Q8/207j8Q`80OX>;0P1hQX`207B;S080N9260P1dSXX207R?QP80M8f:0P1hS8T207R7S080NHR;0P1g
SHT207RAQ@80N8b90P1nSH@207R>Q`80NXf60P1gQhd207f:QP80N7VF0P28NhT207R8R`80N8>?0P1h
VGl206VJRP80RhYl0P1lRXL206EoX080M8R>0P1^UHX207:CQa00oooo000>0?ooo`@0NHZ90P1iRHX2
07V6S080OHZ60P1hQh`207f5RP80O8^60P1fRH`207f5RP80N8b90P1cU8L207JBQP80RhEo0P2:LXd2
08YmQ@80OHb40P1fSHT207R>Q`80M9:70P1gT8H207B?RP80J9R<0P1TTi<20;ebI`80PVRJ0P1WUHl2
07N>R080OHV70P21QhD207R8R`<0LXn;101bU8L2076@R`@0N8b90P1hS8P207f>P`80NX^80P1^RY42
07BBR080N8n60P1hS8P207f>Q080N8R<0P1nRXD207R?QP80N8b90P1kQhT207^:Q`80LY2:0P1]Th`2
076@R`80Mhf80P1dSXX207R?QP80N8f80P1gSHT407R=R080Mhf90P1gRH/207N3S`80O8R80P1hS8T2
07Z;R080NhB;0P1lQhT207f9QP80OHJ90P1kQH/207f4RP80OHV6101hS8T207R;R@80NH^80P1hRhT2
07R<R@80N8^90P1hS8P407R<R@80N8b80P1cSX/205nITP80KY:<0P2kJ6l208ekQ@80FINH0P1nPhX2
07R6S080NH^80P1nQhL307j0S@80O8B;0P1nR8L207j3R`80N8J<0P1dRh`207R@QP80M8j:0P1hShH2
07B=RP80N8b90P1hQh`207V8R`80Mhf90P1hTHD207R<R@80OXf40P1hSXL207Z=QP80MhN=0P1mRXH2
07QiUP80R7^90P1hR8/207R3S`80N9Uo0P1YVXX208^:O080O8Z70P1UOj0207B8SP80KYF:0P1bThL@
0?ooo`003P3oool207N=R080N8^90P1hS8T207:?RP80NH^80P1hRhX207BAR080Nhn40P1bRHl207R<
R@80O8Z70P1mQHX207b9Q`80NHN;0P1nR8L208F3Q@80Sh200P1mQXT207b8R080OHV60P1hRH/207^:
Q`80N8N<0P1ZPI/208>6Q080Vi1[0P1YQIP207V9RP80NHR;0P21S88507R<R@80N8N<0P1mRHH207:?
R`80LI2;0P1gSHP207R<R@80OXV60P1mQ8X207R6S@80N8b90P1gTHD207:DQ`80N9650P1cRXd207j9
QP80PH690P1nP8d207j3RP80PHF60P1mRHH207>;S@80LI2;0P1bSh/207NDQ080KiV60P1`VHH206nA
S080N8b9101hRhT207B=RP80KYF:0P1bThP207RBQ@80LYF70P1^SXl207b:Q`80O8n40P1eSXX207R=
R080M8j:0P1mS8@207Z;R080MhV;0P1kQhT207^:Q`80N8b80P1hR8/207^7R@80O8N90P1lRXL207R8
R`80O8Z70P1hS8T207>?RP80GiVB0P1^TX`20;F9G@80IX2N0P1ZU8h207R9R`@0NhN90`1hS8T207R?
QP80N8b90P1gRH/207^7R@80N8V;0P1kRXP207R7S080OHV70P1hRH/207N;RP80M8Z=0P1iSHL207R<
R@80O8Z70P1hS8T207b>Q080O8J:0P1mRhD207:6T@80PWJA0P1kN9@208>7Q080Pgf;0P1hOY8209F;
M080KgbJ0P29UGH207RAQ@80GX:S0P1hPhl208:2R080N8V;403oool000h0oooo0P1gSHP207R;R@80
N8b90P1bShX207V;R080N8^:0P1dTHP207^?Q080LXV?0P1hS8T207b:Q`80OHF:0P1lRHL207V7R`80
OXR70P25PhD208n0P080OHJ90P1lR8P207f9QP80N8V;0P1kRXL207R7S080JX6K0P23QX@209^@J`80
JHFH0P1iRHX207V8R`80PHb21@1hS8T207R7S080OHV60P1bSh/2076@R`80Mhf80P1hS8T207j9QP80
OHB:0P1hQXd207R<R@80Mi650P1bU8L207RAQ@80LhZ=0P1nRHH20861R@80OX2=0P1nPhX20865QP80
OHV60P1cRhd2076@R`80LXn;0P1gU8@206nIQP80L9V60P1_TH`207R<R@@0N8^90P1dSHX206jERP80
LY>80P1hTXD207:EQ`80KXj?0P1lRXL207b?Q080MHj:0P1hSHP207B>RP80OHb40P1jRhP207N9R`80
NhN90P1kRXL207R<R080N8R;0P1kQhT207b7R@80O8Z70P1hR8/207b:Q`80N8b90P1cShX205nITP80
KY:<0P2eREd206J0WP80JYB>0P1hRH/407^7R@<0N8b90P1hShH207R<R@80MhV;0P1kQhT207R9R`80
NhZ80P1hQh`207f9Q`80N8V;0P1gRhX207B:S@80NHf70P1hS8T207b:Q`80N8b90P1lSX@207b6RP80
OH^50P1bQY42089fT@80NgRD0P23Qh@208=mR`80N7jB0P2ERg@206mlVP80RIEf0P1hTHD205j2X`80
N8>?0P22PXP207R9Ra00oooo000>0?ooo`80N8b90P1fS8X207V>QP80MHb;0P1dT8T207JBQP80MXf9
0P1iR8X207R=R080LI>90P1dTHP207BDQP80MXf90P1hR8`207f=Q080NHN;0P2;PH8208enP`80OhR6
0P1lRXL207Z7RP80O8V70P1fRH`206RFSP80J9B>0P2KNgX208YdS080MhV;0P1iR8X208::PP80OHF:
0`1lRXL207:?R`80N8b90P1mQHT207N7S@80N8^90P1hTHD207:EQ`80LXn;0P1gTXD207:IQ080LY>7
0P1hS8T207R>Q`80LH^>1P1hS8T207R<R080O8V70P22PXP207n7Q`80MI670P1^UHX207JAQP80Nhb6
0P1fQXh207R:RP80LI2;0P1gSHT607R<R@80LXn;0P1hShH207Z6R`80M8V>0P1dV8@207NAQ@80MhZ;
0P1iSHL207J<RP80NH^80P1mR8L207R7S080NH^80P1kRXP207b7R@80N8b90P1dSXX407R?QP80M8f:
0P1hT8H207R9R`80NhZ70P1cShX205nITP80SX600P2NKX42076@R`80IYF?0P1dSHX207R;R@<0O8Z7
0P1kRXP407R9R`80MhZ:0P1jRHT207V9R@80N8^:0P1iSHL207R;RP80N8b90P1bT8X207>?R@@0N8b9
0P1lSX@207RBQ@80LYN60P1fV88206R<U080JH^D0P1gRhX207jLN@80I:290P1YYX4207>OO`80KH>G
0P2BTW4207QnTP80KGBR0P1dR8h207V?QP80Nhb6403oool000h0oooo0P1hS8T207J<RP80NHj60P1e
S8/207B@R@80MY:60P1fSHT207V8RP80N8f80P1aThT207BAR080M9B60P1fSHT207R8S080OHf40P1i
Qh/208^1PP80SGj30P1oR8H207b:Q`80NXN:0P1lRHL207J9S080J9J>0P1XU8h209]kNP80RWB<0P1g
RH/207V8RP80PXZ20P1mQHX307b:Q`80LXn;0P1hS8T207f5R@80MhN=0P1hRhT207RAQ@80LYF70P1b
Sh/207NBQ@80LYV40P1bThL207R<R@80N8j70P1aRhh607R<R@80N8b80P1lRHL208:2R080OhN70P1e
THL206jERP80MY660P1kS8H207J6SP80N8Z:0P1aT8/207N=R@H0N8b90P1bSh/207R?QP80NXJ;0P1d
RHh207BHQ080Mi650P1gRX/207V=Q`80MXb:0P1iRhP207f8Q`80N8N<0P1iRhP207^:R080O8N90P1h
S8T207B>RP@0N8n60P1dSHX207R@QP80N8V;0P1kRXL207>?RP80GiVB0P2>PH0209i^P@80LI2;0P1V
UHl207B=RP80N8^90`1lRXL207^:R0@0N8V;0P1gRXX207Z9R@80NHV90P1hRhX207V=Q`80N8^:0P1h
S8T207:@RP80Lhn9101hS8T207b>Q080N9:50P1bUhH207JHPP80J8bD0P1YRi@207N;RP80OYai0P1T
X8T206VVP@80Limo0P1]PiL209:BL@80N7jB0P1]M:8207B8SP80NHn60P1kS8H@0?ooo`003P3oool2
07R<R@80MXR=0P1nQXP207^4R`80OHb50P1fR8d207^<QP80LI2;0P1kSXD207R6S@80Nhf50P1hRH/2
07R6S@80N9650P1fSHT207R9R`80NhZ70P27PHD2091eQP80RWj50P1lQhT207b4R`80OHF90P1lQH/2
06j=T080Khf>0P2@R7T207b9Q`80M8f:0P1mRHL207j5R@<0PHN50P1mQHX207N=R@80LiB70P1aU8L2
076FQ`80Mi:50P1hTHD406fKQP80Mi660P1bT8X207:ARP80N9:50P1]S94207R<R@80N8R;0P1kQhX2
07b7R@80NhN:0P1kQH/208J5P`80PH2:0P21QhD207::SP80OH^50P1aRhh207VEPP80KY:<0P1aUHP2
076HQ@80Ki6;0P1gSHP207N=R@80MHj90P1bSX/207FCQP80N9:50P1cShX207BCQ`80M9:70P1dTXP2
07:CR080M9B60P1bSh/207R>Q`80Mi270P1dTXL207R?QP80M8n90P1gT8H407N=R080N8f80P1dT8T2
07J@Q`80N8b90P1cT8T205jFU@80QhB30P2NIHP208IiR`80LXn;1@1dTXL207N@QP80M8b<0P1hSHP2
07B<R`80N8b90P1hSXL207J=R@80NHf70P1fR8d207f:QP@0N8R;0P1hS8T207REPP80LYV40P1gX7/2
06^TP@80JiJ;0P1ZO9l207R8R`80Jhn@0P2@Ufl206n=S`80O8f40P1gR8`206RFS@80PJ1d0P1XOIl2
075oUP80N8f80P1fRX/207j:QA00oooo000>0?ooo`80N8b90P1fR8d207j6R080NhB;0P1mS8D207J8
S@80Nhb60P1aT8/207^>Q@80N8J=0P1kSHD207R9R`80N8J=0P1hTHD207J=R@80N8V;0P1kRXL208N1
Q@80T7F60P2:OXD207b7R@80O8B;0P1mQHT207b5R`80KXf@0P1_SHh20928N@80O8V70P1dSHX207f9
Q`80OXF90`21QhD207f5RP80Mhf90P1cU8L2076DQ`80LIJ70P1gTXD207RAQ@@0KI^60P1gTHH207:@
RP80LY6:0P1hTXD206f<T@80N8b90P1hR8/207^7RP80O8N90P1kQhX207^5R`80QXF30P21P8X20867
Q@80LXZ>0P1mRhD2076;SP80NIF20P1^TX`2076ER080LIR50P1_TH/207N=R080Mhf90P1eSXT207:>
R`80MI>60P1hTXD207>?RP80M9>70P1dTXL207BBR080LY>80P1dU8H207:?R`80N8j70P1gT8L207BB
Q`80N8n60P1dShT207N@QP@0Mhf80P1hSHP207B@R@80MY270P1hS8T207>@R@80GYJE0P27Q8<209iU
R080QWV;0P1bSh/507BBQ`80Mi260P1dS8`207R=R080M8b;0P1hS8T207R>Q`80MXf90P1iSHL207J8
S@80OHZ6101hR8/207R<R@80N9F20P1bVH@207NPN`80JjB10P1[UX/206YlW`80N8R;0P1[Si02092G
K`80Khf?0P1lSH@207N8S080J9J=0P21X7@206QmW`80LGnF0P1hSHP207J:R`80OXZ5403oool000h0
oooo0P1hS8T207:?R`80Li:80P1dTHP207^>Q@80M8R>0P1nS8@207R6S@80Nhb60P1bTHT207VBQ080
LHn<0P1bU8L207R<R@80N8^:0P1dSXX407R<R@80O8f50P28Q88208InQ`80OHB:0P1mQHT207b4R`80
O8N90P1]Shl207b:Q`80Sgn00P1l[6l204jRV080NHn50`1iSXH207V@Q@80N9260P1hS8T407R<R080
MiF30P1bVH@207R<R@80N8N<101hS8T207B>RP80N9260P1]SI02076@R`@0M8j:101hS8T207F;R`80
OXj20P1hRhT208:>O`80M8j:0P1dThH207:CR080Mi650P1dRXd207R?QP80MY:60P1]U8/206fKQP80
KIN90P1aUHL206jGR080LI>80P1gTXD2076EQ`80LIB70P1bUHH2076AR`80Mi>40P1aT8X207>@R@80
LYV40P1aUHL207F?R@80MXj80P1gTh@8076EQ`80LiB60P1aU8P2076@RP80NI640P1XV8/205VMU080
LI>80P2=SgH207N=R@80MXj90`1gSHT207R<R080M8f:0P1eTHL207:>S080MXf90P1iSHL207J=R@80
N8R;0P1hQh`207f>P`80Lhj:0P1cTXL207>HP`80Mi]o0P1cYgT206bSP@80N9260P1ZPiX206>:V@80
M:5m0P1O]7l206R_O080KY6<0P1cVH<206f>S`80O8f40P1nTX0205j2X`80L8Z?0P1iSXH2076@R`80
N965403oool000h0oooo0P1hS8T207:?R`80Li:80P1dTHP207^>Q@80M8R>0P1nS8@207R6S@80Nhb6
0P1bTHT207VBQ080LHn<0P1bU8L207R<R@80N8^:0P1dSXX407R<R@80O8f50P28Q88208InQ`80OHB:
0P1mQHT207b4R`80O8N90P1]Shl207b:Q`80Sgn00P1l[6l204jRV080NHn50`1iSXH207V@Q@80N926
0P1hS8T407R<R080MiF30P1bVH@207R<R@80N8N<101hS8T207B>RP80N9260P1]SI02076@R`@0M8j:
101hS8T207F;R`80OXj20P1hRhT208:>O`80M8j:0P1dThH207:CR080Mi650P1dRXd207R?QP80MY:6
0P1]U8/206fKQP80KIN90P1aUHL206jGR080LI>80P1gTXD2076EQ`80LIB70P1bUHH2076AR`80Mi>4
0P1aT8X207>@R@80LYV40P1aUHL207F?R@80MXj80P1gTh@8076EQ`80LiB60P1aU8P2076@RP80NI64
0P1XV8/205VMU080LI>80P2=SgH207N=R@80MXj90`1gSHT207R<R080M8f:0P1eTHL207:>S080MXf9
0P1iSHL207J=R@80N8R;0P1hQh`207f>P`80Lhj:0P1cTXL207>HP`80Mi]o0P1cYgT206bSP@80N926
0P1ZPiX206>:V@80M:5m0P1O]7l206R_O080KY6<0P1cVH<206f>S`80O8f40P1nTX0205j2X`80L8Z?
0P1iSXH2076@R`80N965403oool000h0oooo0P1hS8T207N8S080Nh^70P1fRX/207^7R@80N8V;0P1k
Sh@207:@RP80N8n60P1iRXT207^6R`80OHN90P1iRhP207:@RP80MHj:0P1hS8T207B>RP80N8b90P1k
Sh@207R9R`80QHF30P21Nhh208IkRP80PWf;0P24NHd208MeS@80O7j?0P28PX<20;IMN`80RfVC0P1^
V8P307J>R@80OX^50P1lRXL407R<R@80N9260P1nRHH20864Q`80MHF@0P1lQXX207b5R`80OGn=0P22
OH/208:1R080NHb80P1]THd207:?R`80M8^<101hS8T207F>R@80NhZ70P1mQXT208B6Q080PHR40P1i
Qh/207eoS@80PHF60P1eRHd207f9Q`80OHF90P1lQHX207b:Q`80Lhn:0P1cVH<206fKQP80J9n70P1]
YGl206VNR080K9b60P1]WHD206NOR080KJEo0P1SXHT206RTQ080KJ230P1YWXL206RRQ@80J:>40P1]
X88406fKQP80KI:<0P1gT8H207>?RP80Mhf80P1aT8X207NFPP80Li>70P1TUhl205fbPP80J:>40P1m
QHX207bJO0<0IKQh0P1C[h`206NKR`80LIF70P1]TX`207:CR080M9B60P1dSXX207:?R`80LYB70P1h
SHP207b:Q`80N9:50P1h/6l205^dPP80MiN20P1jP90207b7R080J9:@0P1OVI8207REPP80QhR00P1h
Phl2076AR`80N82@0P1lP8h207bHO@80N8>?0P1^NYd2072;S`@0NHb80P1fShP@0?ooo`003P3oool2
07R<R@80MhR<0P1kRhL207J:R`80NhN90P1hRH/207^?Q080LY2:0P1hShH207V:R@80NhJ;0P1mQhT2
07V;R080LY2:0P1eSXX207R<R@80M8j:0P1hS8T207^?Q080N8V;0P25QH<2085kSP80QW^:0P22OH/2
08AiS@80QgF=0P1lOXl208R2P`80]Uek0P2;JI<206jHR0<0MXj90P1nRhD207b:Q`@0N8b90P1hT8H2
07j9QP80PHB70P1eQI0207b6RP80O8F;0P1mOhd2089mR`80PX680P1iS8P206fAS@80LXn;0P1dRh`4
07R<R@80MHj90P1kRXL207f6R@80Q8J40P21R8@207V7R`80OGn=0P21QHH207F9S@80OHV70P1mQHT2
07b5RP80O8Z70P1cShX207>IP`80KI^60P1XWhL206fUO`80JIj80P1/W8H206fMQ@80Iin80P1]YGl2
06>QR@80J:B40P1]X8<206VNQ`80J::50P1XXh@206fPPP@0KI^60P1]TX`207N@QP80Lhn:0P1gSHP2
076@RP80MiJ20P1cThL206BGS`80GK:20P1XXh@207f5RP80O9Yl0`1U^7P205>_S080Ii^;0P1aUHL2
06fBS080LY>80P1dU8H207B>RP80LXn;0P1bU8L207R=R080O8Z70P1hTXD207R`K`80FkB20P1gUh82
07Z0T080O8N80P1XTY0205nITP80N9F20P27R80207R3S`80LI6;0P1hP90207b0SP80O9Qm0P1hPhl2
06ijW@80L8^?101iS8P207J?R100oooo000>0?ooo`80OHF:0P1hRhX207V;R080N8b90P1cShX207R<
R@80OHV70P1lR8P207R;R@80N8n70P1aTHX207JBQP80N8j70P1iRhP207>9S`80Nhn40P1bTXT2076@
R`80OHj30P1bRXh207f=Q080M8V=0P1kSXD207R>Q`80LXb=101hShH207R=R080N8V;0P2NN7X2095m
P@<0LJQj0P1NTiL208F9P@80N9F20P1^TH`207b:Q`80N8V;0P1nSh82076@R`80LIR50P1/UXX206fC
R`80LIB80P1hT8H207f?P`80LXb=0P1aRhh207B>RP80M8b<0P1jRhP207R:RP80N8b90P1hTXD207R?
QP80PHb20P1hR8/207>?RP80Nhn40P1hQHh207b:Q`80NHN;0P1mQ8X408:1R080Q7b;0P28NHX208Al
R`80R7Z90P21OH`207j0S080PX690P1nPXX208:0R@80OWb?0P22PHT207j3R`80OWn>0P23OH/2085m
S080Pgf;0P22OH/2089hS`80OWZ@0P21RX<207B5T0@0OX>:0P21QXD207b1S@80OXB90P22QXD206j7
U080KiB:0P2;PX430:1RR080S6FE0P1ha642036eX080KI^60P1XVXX2076ARP80LY6:0P1aU8P207:U
N`80G<Qc0P17g7D204OHM`80JKMe0P1]PYP207QiUP80Ogj=0P23R8<207R3S`80LHJB0P1bU8L207R8
S080PX:70P1mTX0205^=WP80OXf30P26UgH205j7W`80LXb=0P1/SI4207J;RP80NhN:0P1nR8L@0?oo
o`003P3oool207f5RP80N8^:0P1iRhP207R<R@80Lhn:0P1hS8T207f9Q`80O8R80P1hRhT207R?Q`80
LI6:0P1fTXH207R>Q`80NH^80P1cRHl207^?Q080LY:90P1aT8/207f>P`80LXZ>0P1mSH@207B9S@80
Nhj50P1hSXL207:<S@@0N8n60P1hSHP207R9R`80WWQj0P2AOH43076XNP80GY>G0P25RH4207REPP80
KY6<0P1lRXL207R9R`80OXn20P1aT8/2076HQ@80K9J:0P1]Th/2076DR080N9260P1mSh<207:<S@80
LH^>0P1dSXX207B<S080NX^80P1hRXX207R<R@80N9:50P1hShH2086<PP80N8R;0P1cShX207^?Q080
N8F>0P1lRXL207V7R`80OHB:1022PHP208AlR`80R7V:0P24O8/208QjR@80PGf<0P1nP8`208:1R@80
OX::0P22P8T207ilS`80PX690P1nPh/207ioSP80Pgf;0P21OH`208=mR`80PWf;0P22N8l207ijT080
PHZ30P1dQI0407j3RP80PHJ50P1lPHd207j4R@80PXJ50P1^Qi@206nDRP80Rh:10`2PHXP208aUU@80
N<AQ0P0a]J0206fKQP80J9Z:0P1aTHX207:ARP80LIB80P1bYG/205c8L`80Amae0P17f7L206VgM@80
KH:H0P1hNIH207mnS@80PhR30P1hPhl20766TP80LYB70P1hR8`208:2Q`80OI:00P1KSIh207j=P`80
QYMf0P1NQil207:<S@80K8fA0P1fRhX207^7RP80OXR7403oool000h0oooo0P1aUXL207FCQP80LXb=
0P1lSh<207:>R`80M9B60P1aU8P207J@Q`80N8b90P1kQhX207b:Q`80MXb:0P1iQh/207b5RP80N8^9
0P1iSXH207^9R@80M8R>0P1mSH@207B9S@80Nhj50P1dRh`207^?Q080N8b90P1dS8/207RAQ@80MXZ;
0P1lRhH207:>R`80NHj60P2HUfP308bEL`80E9FM0P1]Zg/207>GQ080KXVB0P1gSHP207R=R080OXV6
0P1nPX/208:7Q@80MHR=0P1dRhd207J<RP80N8b90P1mSh<207B;S080LHZ?0P1hS8T207:?R`80M9B6
0P1bSh/207R>Q`80NhZ70P1kQhT20828Q@80O8Z70P1hS8T407R8S080O8Z70P1hR8`407R<R@80O8Z7
0P1hS8T207RDP`80M8Z=0P1nQHT20861R@80OX2=0P21QXD207b7R@80NhJ;0P1iQh/207f4R`80PGj;
0P1lQHX207V;R080N8^:0P1iSHL407R7S080N8b90P21QhD207R3S`80N9260P1cShX207f=P`80LhV>
0P1mRHH207f3R`80OHB:0P1fSXP206jBS0<0M9:80P1mRXH20<MKK`80PcRl0P2@QgX206^VP080EK^2
0P1E/XP206:mM`80HLEb0P1bXGd208:;P@80N8N<0P1bO9P206f8U080HhjF0P1fUH<207RHP080K7:T
0P2AOgl207J>R@80KHn?0P1fY7T207>9S`80Lg>N0P1mV7`208:2R080MgjC0P1[Ri@207J7SP80LI6:
0P1aTXT207J=RA00oooo000>0?ooo`80LIJ70P1eThH207:<S@80O8n30P1bSX/207BDQP80LIB80P1f
T8L207R<R@80NhN:0P1lRXL207J<RP80NHN;0P1lQHX207R;R@80NHj60P1kRHT207B8SP80OHf40P1d
RHd207^>Q@80M8^<0P1kSh@207R<R@80M8b;0P1hTHD207J:R`80O8^60P1bSX/207V>QP80V9MX0`2<
UG<205BEW@80KJ]k0P1cUh@206j9TP80Mhf80P1hSHP207j9QP80OX:;0P22QhD207F8S@80M8^=0P1f
S8X207R<R@80OHn30P1dRh`2076:S`80N8b90P1bSh/207BDQP80LXn;0P1hSXL207^:Q`80NhN90P20
R8D207b:Q`80N8b9101hR8`207b:Q`80N8R<101hS8T207b:Q`80N8b90P1hU8<207B:S@80OXF90P21
PHT207j0S@80PHJ50P1lQhT207^6R`80NHN;0P1mQ8/2085nR`80O8F:0P1iRhP207R;RP80NHf7101h
Qh`207R<R@80PHN50P1hPhl207R@QP80Lhn:0P1mSH<207>9SP80OHV60P1mPh/207f4RP80MXj80P1^
TX`307BBR080OHZ60P37Ffl208<h_080T8Mj0P1[YX0205FkPP80EK:80P1R_GL20675LP80LZ5m0P22
Rh4207R7S080LWbH0P1]R9@206>>UP80MYF30P1hV80206abY080TGmo0P1fSXT206f?S`80MZAi0P1c
RHl207=cWP80OIQl0P22PXP207MnT`80Jh^D0P1fQhh2076ARP80LI:90P1fSHT@0?ooo`003P3oool2
07j3RP80OHR70P1bSh/207R<R080NhZ70P1iR8X207f3R`80Nhb60P1eShT207>@R@80NH^80P1kR8T2
07B;S080N9650P1fSHT207^<QP80MXf90P1dSXX207R<R@80N8j70P1fSHT207R9R`80OHV70P1kQX/2
07^<QP80N8j70P1bT8X207JCQ@80MHb;0P1hShL209FEK0<0TgV20P26RWl206VGS080M8j:0P1[Y842
05bKT`80N8b90P1hShH207>>RP80OY:00P1cRHh207N9R`80MY670P1bSh/207f;Q@80N8V;0P1aRY02
07N=R@80N8f80P1gS8T407B>RP80N9260P1dSXX207b>Q0@0O8Z7101cShX:07R<R@80O8Z70P20Q8T2
07R<R@80L9F90P1cThL207>?RP80OHV60P1nQ8X207b:Q`80MXf90P1cT8X207:GQ@80M9:70P1hR8`2
07b6RP80OHb40P1`Rhl607R<R@@0N9260P1cRXd207b?P`80LX^>0P1hTX@2076@R`80N8f80P1mRHH2
07N7S0<0N9:40P1^UXP2072IQ@80JI:?0P2>QGd20:1RR080X5j;0P25XFl205joN080JYJ<0P1bShX2
07RAQ@80N7nB0P1aQi42076EQ`80GJ2>0P1UXHL207N:R`80F82Y0P2;[F<206>QRP80JHnB0P2<TgD2
05f7X080JI:?0P26V7H206AlX`80SgZ40P1cNIT207^:Q`80N8R<0P1iRXT207:9Sa00oooo000>0?oo
o`80OX>:0P1mR8L207:?R`80N8b80P1kRXL207V8RP80OH>;0P1kS8H207F?R@80Li290P1iRhP207^8
R@80M8^<0P1hTHD207J=R@80Nhb60P1fSHT207B>RP80N8b90P1hSXL207J=R@80N8V;0P1mRHL207^6
R`80Nhb60P1hSXL207:@RP80MY>50P1eS8/207R?Q`80UIE/0`2CNH8208J:O`80JIN<0P1dSXX206^T
P@80G9^C0P1hS8T207R?QP80Lhj:0P1nTX0207>9SP80MhV;0P1fTHL207:?R`80OH^50P1hRH/2076:
T080Mhf90P1hSHP207N<R@@0M8j:0P1hT8H207B>RP80O8j4101lRXL407>?RPX0N8b90P1lRXL20824
R@80N8b90P1`UHT207>CQ`80Lhn:0P1mRHH207j4RP80O8Z70P1fSHT207>@RP80LYN50P1dTXL207R8
S080O8J:0P1mS8@2072;S`H0N8b9101hT8H207>:S@80O8n30P1bRhh207RBQ080LI2;0P1hSHP207f9
QP80MhN<0`1hTX@206jFR080L9V50P1YTXl208j5O@80X6:80P2PGX/208FQK`80G[mh0P1ZUX`207:?
RP80N9650P1hOi820767T@80LIF70P1MX8h206FQQ`80MhZ;0P1HP:T208^]H`80Hj6:0P1YSi8208bC
M@80GHNP0P1YTXl208JHMP80I7bS0P2?NX@207=iV@80NhZ70P1hR8`207V:R@80LXV?403oool000h0
oooo0P1bU8L207R<R@80O8F:0P1hSHP207RAQ@80LXZ>0P1hTHD207V;R080O8B;0P1lQHX207R=R080
MXf90P1hRH/207f=Q080M8j:0P1hS8P207^6R`80NhN90P1hRH/207f>P`80Lhf;0P1dSXX207R<R@80
N8n60P1iT8@207R<R@80NHZ90P1kRHP207J<RP80NHf70P2@T7<307f9QP80VHYa0P1hS8P206RDSP80
QZ1_0P1=_XH203ncV080LY2:0P1hS8T207f=Q080MHJ?0P1hShL207R<R080MXb:0P1fThD207B=RP80
LHV?101hS8T207N=R@80Mhf80P1dRh`207b>Q080M8j:0P1hT8H207R<R@80O8Z70P1lQXX207R8S0H0
N8b90P1hS8P607R<R@80P8b30P1hRH/207R<R@80LhZ=0P1hT8H207>CQ`80NH^80P1lRXL207N@Q`80
N8^90P1hRH/207>?RP80LiF60P1iTH@207:8T080N8b90P1hS8P207R<R@80O9620P1dRXd207R8S080
OHf30P1cSX/207V@Q@80LhV>0P1hS8T207RAQ@80LYB70`1hTHD207R=R080MiJ20P1TYXD205fgO`80
F<ib0P1@gFh207j^K080QGF?0P1bQI8207FCQP80LX:D0P1hQh`207>>RP80Mhb90P1hOI<207YkT`80
Lhb<0P1KTI/209:MJ@80LhFA0P1XRiD208JCN@80IgZR0P1hSHP207j=Q080I7nQ0P1hS8T207R6S@80
Nhj50P1bRHl207f5RP80N8^:403oool000h0oooo0P1bU8L207R<R@80O8F:0P1hSHP207RAQ@80LXZ>
0P1hTHD207V;R080O8B;0P1lQHX207R=R080MXf90P1hRH/207f=Q080M8j:0P1hS8P207^6R`80NhN9
0P1hRH/207f>P`80Lhf;0P1dSXX207R<R@80N8n60P1iT8@207R<R@80NHZ90P1kRHP207J<RP80NHf7
0P2@T7<307f9QP80VHYa0P1hS8P206RDSP80QZ1_0P1=_XH203ncV080LY2:0P1hS8T207f=Q080MHJ?
0P1hShL207R<R080MXb:0P1fThD207B=RP80LHV?101hS8T207N=R@80Mhf80P1dRh`207b>Q080M8j:
0P1hT8H207R<R@80O8Z70P1lQXX207R8S0H0N8b90P1hS8P607R<R@80P8b30P1hRH/207R<R@80LhZ=
0P1hT8H207>CQ`80NH^80P1lRXL207N@Q`80N8^90P1hRH/207>?RP80LiF60P1iTH@207:8T080N8b9
0P1hS8P207R<R@80O9620P1dRXd207R8S080OHf30P1cSX/207V@Q@80LhV>0P1hS8T207RAQ@80LYB7
0`1hTHD207R=R080MiJ20P1TYXD205fgO`80F<ib0P1@gFh207j^K080QGF?0P1bQI8207FCQP80LX:D
0P1hQh`207>>RP80Mhb90P1hOI<207YkT`80Lhb<0P1KTI/209:MJ@80LhFA0P1XRiD208JCN@80IgZR
0P1hSHP207j=Q080I7nQ0P1hS8T207R6S@80Nhj50P1bRHl207f5RP80N8^:403oool000h0oooo0P1m
QHX207R;RP80M9>60P1hShH207V;R080LhZ>0P1lSh<207:;SP80N9:40P1aT8/207f>P`80LXZ>0P1h
THD207J=R@80O8^60P1bRhh407R<R@80N9650P1gT8H207R8S080N8V;0P1hTHD207J=R@80OH^60P1h
SHP207F>RP80N8V;0P1mRHL207R<R080S8]j0`26Mhd209eaP080XXQ/0P1TUi0208NPK`80QI1l0P1:
]Hh202j^Z080N9B30P1bS8d207RBQ@80LYR50P1_TH`207N=R@80O8R80P1gRH/2076:S`P0N8b90P1d
SXX207R@QPP0N8b90P1hT8H607>CQ`80LXn;0P1hTHD207>?RP@0N8b90P1lSX@407R<R@80Lhn:0P1h
T8H207R>Q`80LI6:0P1hTX@207V:R@80N8V;101hS8T207V=Q`80Mh^:0P1cSX/207:?R`80N9>40P1a
U8P207^?Q080LhN@0P1hS8T207b>Q080N8j70P1fSHT207>?RP80Li>70P1iUH4207>?RP<0MiJ20P1^
VhD207NPN`80Limn0P1`[gD2072^MP80N8b90P1hN9L208=mR`80Q7R=0P26OXP206jAS080KI:=0P1h
R8/207N1T@80LgnE0P1hS8P207N3T080LXn;0P1lXWD206f>S`80KI:<0P1hQh`206n2UP80N9B30P1c
Qi0206emV`80NhN:0P1eS8/207j:Q@80LhR?0P1dTHP207RBQ100oooo000>0?ooo`80OHF:0P1hRhX2
07BCQP80N8n60P1iRhP207>:SP80O8n30P1bRhh207RBQ080LI2;0P1mSX<207::SP80N9650P1fSHT2
07b;QP80LX^>101hS8T207RAQ@80Mi260P1hR8`207R9R`80N9650P1fSHT207f;QP80N8f80P1eSXX2
07R9R`80OHV70P1hS8P208b;NP<0QWN=0P2MLH020::8K080I9N@0P27X6l208F@O080B[F>0P0^[ZP2
07RDP`80LXb=0P1hTXD207:HQ@80Ki6<0P1gSHT207b8R080MhV;0P1aRXl807R<R@80M8j:0P1hT8H8
07R<R@80N9261P1cThL207:?R`80N9650P1cShX407R<R@80O8j4101hS8T207>?RP80N9260P1hSXL2
076ARP80N9:40P1iRXT207R9R`@0N8b90P1iSHL207N;RP80Lhj;0P1bSh/207RCQ080LIB80P1kSh@2
07>7T080N8b90P1lSX@207R>Q`80MXf90P1cShX207>CQ`80NIF10P1cShX307NFPP80KY^50P1gX7/2
07>OOP80L:me0P1`[WH207R<R@80N7RG0P23OH/208AhS@80QWj80P1^TH`206fBS@80N8R;0P1gPI42
07=oU@80N8b80P1gPi0207:?R`80O:9e0P1]SXl206fBS080N8N<0P1_PYH207RDP`80LhN@0P1]OI/2
07^7RP80MHb;0P1nRXD207>8S`80M9680P1hTX@@0?ooo`003P3oool207:DQ`80MY270P1iR8X207^9
R080NHj60P1aRhh207f9Q`80N8N<0P1nSH<207>9S`80OHf40P1dSXX207N<R@80N8f80P1hS8T207R7
S080N9650P1cU8L207R?QP80N8b90P1bS8d207RBQ080MXf90P1hRhX207V@Q@80NHN;0P1mQhT207B<
R`80NI:40P1fSHT208>ENP<0KHRD0P29UWD209fSG@80LiR30P1hVWh208>DNP80QiIf0P0a`YL202G2
X080JIF=0P1gUH<207N4S`80NhF;0P1dRh`207R@QP80M8j:0P1aSh`207:?R`H0N8b90P1gTHH207>?
RPP0N8b90P1lRXL207b6RP80O8Z70P1hR8`207R<R@80N926101cShX207R<R@80O8Z70P1lQXX207b>
Q080M9:70P1dSXX207V;R0@0NHZ90P1hSXL207B>RP80N8j70P1fTHL207F@R080MHj90P1fT8L2072<
S`80OXf30P1hQXd207b:Q`80Li290P1aT8/207b:Q`80OXV60P1hRhX207R>Q`80MY>50P1hTXD207BD
QP<0MiN20P1gUh4207NGPP80OYeh0P1oXW<207F2TP80OGJE0P1hS8T206fBS080MH>A0P28QX0208>6
Q080KXNC0P1cPi8207R<R@80IY>A0P1fUh8206:JS`80MIb00P1nP8`2089dTP80PWf;0P1bLil208JC
N@80J9B?0P1_NY/207F0U080N8b90P1iSXH207>?RP80MXn80P1eRh`207j9QQ00oooo000>0?ooo`80
LYB70P1fT8L207V8RP80NhV80P1iSXH2076;SP80OHV70P1hQh`207j=P`80LhV?0P1mSH@207B>RP80
Mhb90P1hSHP207R<R@80N8N<0P1hTHD207>DQ`80N8n60P1hS8T207:<S@80N9:40P1fSHT207R;RP80
NI250P1iQh/207f7R@80M8b;0P1iTX@207J=R@80PiEj0`1]R9@208VFM@80WJ=M0P1cV8<207RJOP80
PiAj0P27UWH20372U`809L:P0P1YUHd207NEP`80MhB?0P1kQH/207B;S080N9260P1dSXX2076?S080
LXn;1P1hS8T207NAQP80Lhn:201hS8T207b:Q`80O8J:0P1lRXL207R8S080N8b90P1hT8H407>?RP80
N8b90P1lRXL207b6RP80O8j40P1dTXL207B>RP80NH^8101iRXT207R>Q`80M8j:0P1hSXL207JAQ`80
MI280P1eSXT207J@Q`80L8b?0P1nSH<207R6S@80O8Z70P1cT8T2076@R`80O8Z70P1nRHH207R;RP80
N8j70P1fThD207RBQ@80M9B60`1gUh8207NGP@80MiN20P1nWGP207nRL`80MH:B0P1mMYD207R<R@80
KI:<0P1ePi4208R6P080PhJ40P1^Qi<207>3TP80N8b90P1VTi4207JGPP80HYZ?0P1eW80207j0S080
PWBB0P22OH/2079cW`80QY=i0P1XU8l206mjV`80MH2D0P1hS8T207V>QP80Lhn:0P1fShP207F;S080
OXV6403oool000h0oooo0P1hS8T207J=R@80LY690P1fTXH207V=Q`80LXV?0P1hTX@2076DR080N9:4
0P1aRhh207^:Q`80OHJ90P1hS8T207R<R080N8b90P1cThL207R<R@80OHZ60P1fR8d207f9Q`80M8j:
0P1iS8P207R;R@80MY:60P1hRH/207R<R@80MXf90P1kRXL207^<Q`80N8b90P26Sg`306f9T`80S9Ua
0P2MOgD20:21LP80N8N<0P2=RgT208^@M`80RI=f0P0[]JD202JcZP80N8b90P1^S90207NEP`80KXj>
0P1lRhL207R<R@80LhR?0P1hQh`607R<R@80O8Z70P1hS8T207>CQ`80Lhn:0P1hS8T207R@QP@0Li>7
0P1hT8H207>BR080M9B60P1fSHT407R8S080N8b90P1hT8H207>CQ`80O8j40P1lR8T207J=R@80M969
0P1eThH207:?R`80NhZ70P1hRH/207V?Q@80N8b90P1hTH@206n@S080NHb70P1aSHd207R@QP80Lhn:
0P1hT8H207V;R080Lhf;0P1cUHH207FMOP80Jij50P1]XH8206fVO`80IZF40P1]XX8306fLQ@80N:Ag
0P1X^g<206?8KP80IYJ?0P1bKj42089nR`80QYYd0P1PSiP206b>T080O8:<0P2@L8X208Q`T080N8b9
0P1cWGl206BGT080LIR50P1_QY<207b;Q@80JHNG0P1hS8T207QdV@80OHV70P22U7/207MeVP80JX6K
0P1dTXL2072CR@80Mhj80P1hR8/207V;R080LXV?0P1kSXD@0?ooo`003P3oool207R<R@80MXf90P1b
THT207JBQP80NHf70P1bRHl207RBQ080LIB80P1hTX@2076;SP80NhZ70P1mQXT207R<R@80N8b80P1h
S8T207>CQ`80N8b90P1mRXH207J8S@80OHV70P1dSXX207V<R080N8^90P1fTXH207R9R`80N8b90P1f
SHT207^:Q`80Nhb70P1hS8T208J?O0<0KHVC0P2<VG4209eoM@80X85b0P1hQh`208f;N@80Ri1g0P29
TgH202^eY@809[>Z0P1hS8T206j<T080MiF30P1^SXh207b;Q`80N8b90P1cR8l207R7S0H0N8b90P1l
RXL207R<R@80Li>70P1cShX207R<R@80N926101cThL207R@QP80Li:80P1dU8H207J=R@@0N8R<0P1h
S8T207R@QP80Li>70P1lSX@207b8R@80MXf90P1dTHT207FCQP80LXn;0P1kRXL207R9R`80NHn50P1h
S8T207RAQ080Ki2<0P1iS8L2076=S@80N9260P1cShX207R@QP80NH^80P1cSH/207>EQP80MIen0P1[
WXD206fQPP80KJIo0P1VYH@206fRPP<0KIb50P1hY7L206RkL`80HlQ^0P1VUXl2079_X@80PWj;0P26
VW@2062?V080K8j@0P1lPX`2091`RP80R72@0P1hS8T207>MO`80I9N@0P1aV8D206n6T`80O8^50P1Y
QiL207R<R@80N7BI0P1mRHL208:DN`80MgFJ0P1ZPI/207BBQ`80L9>90P1gSXP207R8R`80NH^80P1b
RHl207^>QA00oooo000>0?ooo`80MXn80P1fRH`207f8R080NHb80P1hR8`207R<R@80NI250P1gRX/2
07^6RP80N8V;0P1dTHP207B>RP80O8f50P1dRXd207b=Q@80NHN;0P1hR8`207f=Q080M8V=0P1kSXD2
07V<Q`80Lhj;0P1hS8P207b8R080M8n:0P1gTX@2076?S080N9650P1hS8T207^<QP80PHJ60`1nRXH2
08F;P080SI9e0P2FW6H207R<R@80Q9]e0P25UgL208V;O080P8R50P0V_Z<201nlZ@80LXZ?0P1nTH02
06^;T`80N9260P1hS8T2076;S`80Lhn:0P1hT8H607>CQ`80N8b90P1lRXL407>?RP80O8j40P1hS8T2
07R8S0@0O8Z70P1iRhP207B?RP80LI2;0P1cThL207>EQP80MXf90P1lRXL207R@QP80MI>6101fShP2
07R?QP80LXn;0P1bUHL207:BR@80NI640P1dT8T207bBPP80Ki6<0P1`V8H206jCR`80M8j:0P1hUH82
06jBS080N9R00P1[UH`207RBQ@80OY210P1jShD207R@QP80OXn20P1hTXD207:NP0<0J:ml0P1[`f/2
06f[N`80PHB70P1VM:L206R7V080N9:40P2CPW/207M]W`80OGn=0P1_QY<207RDP`80LYB70P22QhD2
08R4PP80Lh^=0P1aQ9<207>9SP80N8f80P1]Q9H207R;R@80GiVB0P1hWg`207QoTP80MW^F0P1gPhl2
07RBQ080LHn<0P1bRHl207V:R@80NHb80P1bRXh207^:Qa00oooo000>0?ooo`80MXn80P1fRH`207f8
R080NHb80P1hR8`207R<R@80NI250P1gRX/207^6RP80N8V;0P1dTHP207B>RP80O8f50P1dRXd207b=
Q@80NHN;0P1hR8`207f=Q080M8V=0P1kSXD207V<Q`80Lhj;0P1hS8P207b8R080M8n:0P1gTX@2076?
S080N9650P1hS8T207^<QP80PHJ60`1nRXH208F;P080SI9e0P2FW6H207R<R@80Q9]e0P25UgL208V;
O080P8R50P0V_Z<201nlZ@80LXZ?0P1nTH0206^;T`80N9260P1hS8T2076;S`80Lhn:0P1hT8H607>C
Q`80N8b90P1lRXL407>?RP80O8j40P1hS8T207R8S0@0O8Z70P1iRhP207B?RP80LI2;0P1cThL207>E
QP80MXf90P1lRXL207R@QP80MI>6101fShP207R?QP80LXn;0P1bUHL207:BR@80NI640P1dT8T207bB
PP80Ki6<0P1`V8H206jCR`80M8j:0P1hUH8206jBS080N9R00P1[UH`207RBQ@80OY210P1jShD207R@
QP80OXn20P1hTXD207:NP0<0J:ml0P1[`f/206f[N`80PHB70P1VM:L206R7V080N9:40P2CPW/207M]
W`80OGn=0P1_QY<207RDP`80LYB70P22QhD208R4PP80Lh^=0P1aQ9<207>9SP80N8f80P1]Q9H207R;
R@80GiVB0P1hWg`207QoTP80MW^F0P1gPhl207RBQ080LHn<0P1bRHl207V:R@80NHb80P1bRXh207^:
Qa00oooo000>0?ooo`80NHZ90P1cShX207F>RP80OHJ90P1hQh`207f?PP80MXR<0P1kQX/207R9R`80
Nhn40P1fShP207:<S@80Nhn40P1cShX207RBQ080LI2;0P1dThH207JBQP80LXb=0P1kRXL207b7R@80
O8V80P1dSH/207R<R@80OH^50P1iS8P207J<RP@0N8b90P1iTH@207:CR0<0OYah0P1_T8d209RZF`80
OJ1g0P1mSh<208VGM080PIAl0P21QhD208V3PP80Qh]n0P0OcId200G>/080MI>60P1_SHh207:BR080
M8j:0P1bSX`207:ARP80MY661P1hS8T207>:S@80O8j40P1hR8`207R<R@80N9260P1hS8T207>?RP80
N9:40P1fSHT207b:Q`80NX^80P1dT8T207BAR@80Mi260P1_Shd207R@QP80O8b60P1lR8P207V:R@80
NHf70P1hRhX207V?Q@80M9F60P1]UHX207B@R@80NHn50P1hT8H207R7S080OHV60P1bR90207F?R080
O9>10P1^U8/207RBQ@80M8f:0P1bV8D207JCQ@80O9230P1hTHD207RKOP80M:Qh0P1[[GX3076UO080
QI9k0P1hNi@207a_VP80NVfM0P1hQh`207>CQ`80N8b90P1aQI<207RBQ080Jj630P1XZ84206RKRP80
Jif60P1hS8T208AfS`80N82A0P1hSHP207>2U080N8:@0P1hRhT207R8R`80N7FI0P23M94207R7S080
LXn;0P1oPhX207inSP80MXB?0P1kQhT207f6R@80N8N<0P1hS8T@0?ooo`003P3oool207V:R@80Lhn:
0P1eSXX207f6R@80N8N<0P1mSh8207J8S080NhJ;0P1hRH/207^?Q080MXn80P1bS8d207^?Q080Lhn:
0P1hTX@2076@R`80M9>60P1fTXH207:<S@80NhZ70P1lQhT207b9R080M8f;0P1hS8T207f;Q@80NHb8
0P1fS8X407R<R@80NI640P1bThP307jLN080Ki2=0P2HZU/207fPM`80OHn30P29Ug@2086DO080PHN5
0P29Ph8208N;OP807lfM0P05c[0207FCQP80Khf>0P1bTXP207B>RP80LXj<0P1bTHX207JAQPH0N8b9
0P1cRXd207b>Q080N8R<0P1hS8T207R@QP80N8b90P1cShX207RBQ080MXf90P1lRXL207Z;R080M929
0P1dTHT207N@QP80Khn=0P1hT8H207b<QP80O8R80P1iRXT207V=Q`80N8^:0P1iShD207BEQP80KIF:
0P1dT8T207V?Q@80N9260P1hQh`207f9QP80LXR@0P1eShP207bCP@80KYB;0P1hTXD207B=RP80LYR5
0P1fThD207b@P`80N9650P1hVgh207BXN080Jjej0`1aYG`208FBN`80N7^D0P1lKiX207Y]W@80N8N<
0P1cThL207R<R@80LHFC0P1hTX@206^QP`80J:R10P1XVhX206^MQP80N8b90P24MXl207R0T@80N8f8
0P1cPY@207R2T080N8^90P1hR8/207QeV@80PgBA0P1hQh`207:?R`80Oh>:0P1nOXh207J4S`80NhN9
0P1mQXT207R7S080N8b9403oool000h0oooo0P1fShP207R8S080N8V;0P1dSXX207R<R@80OXV60P1h
RhX207>BR080M8j:0P1lRXL207f8Q`80M8j:0P1gTX@207F=R`80NhN:0P1kQ8/207f6R@80OHF:0P1h
RhX207BCQP80LY:80P1hShH207R<R@80M8^<0P1mSH@407V:R@80N8f80P1gSXP207f8Q`80OhR60`28
SW/207:7T@80ZieF0P21S88207f>P`80SI5e0P25SWd207R<R@80PI1o0P27V7D208F:P0807k^Z0P0;
`;H207R=R080LXJA0P1lRHL207>;S@80N8f80P1fS8X607R<R@80Lhn:0P1hS8T207R8S080O8j41P1h
S8T207V;R080N8^:0P1hS8T207b<Q@80NHZ90P1hR8/207b<QP80M8b<0P1fTHL207FAQ`80Mi660P1f
T8L207R>Q`80MXf90P1lSh<207Z;R080N8Z:0P1bSh/207RDP`80MIB50P1[UH`207FCQP80L9>:0P1a
Sh/2082BOP80Li290P1bSh/207NCQ080MiJ20P1^UHX207REP@80MjIg0P1]^W0206V[OP80N:eb0`1O
VI82081nS@80OGJD0P1`Mid207N:R`80N9:50P1hRH/207N=R@80K8NE0P24QX@208QnQ`80R7F=0P1n
MI@208QhRP80N7fD0P1hR8`207b8R@80NgfA0P1hOY<207N;RP80N8b90P1cQ94206Z:U@80KYJ90P1h
S8T207N4S`80MHV=0P1hRH/207R;R@80M8j:0P1hShH207BCQP80LXn:403oool000h0oooo0P1fShP2
07R8S080N8V;0P1dSXX207R<R@80OXV60P1hRhX207>BR080M8j:0P1lRXL207f8Q`80M8j:0P1gTX@2
07F=R`80NhN:0P1kQ8/207f6R@80OHF:0P1hRhX207BCQP80LY:80P1hShH207R<R@80M8^<0P1mSH@4
07V:R@80N8f80P1gSXP207f8Q`80OhR60`28SW/207:7T@80ZieF0P21S88207f>P`80SI5e0P25SWd2
07R<R@80PI1o0P27V7D208F:P0807k^Z0P0;`;H207R=R080LXJA0P1lRHL207>;S@80N8f80P1fS8X6
07R<R@80Lhn:0P1hS8T207R8S080O8j41P1hS8T207V;R080N8^:0P1hS8T207b<Q@80NHZ90P1hR8/2
07b<QP80M8b<0P1fTHL207FAQ`80Mi660P1fT8L207R>Q`80MXf90P1lSh<207Z;R080N8Z:0P1bSh/2
07RDP`80MIB50P1[UH`207FCQP80L9>:0P1aSh/2082BOP80Li290P1bSh/207NCQ080MiJ20P1^UHX2
07REP@80MjIg0P1]^W0206V[OP80N:eb0`1OVI82081nS@80OGJD0P1`Mid207N:R`80N9:50P1hRH/2
07N=R@80K8NE0P24QX@208QnQ`80R7F=0P1nMI@208QhRP80N7fD0P1hR8`207b8R@80NgfA0P1hOY<2
07N;RP80N8b90P1cQ94206Z:U@80KYJ90P1hS8T207N4S`80MHV=0P1hRH/207R;R@80M8j:0P1hShH2
07BCQP80LXn:403oool000h0oooo0P1nPhX207R6S@80Ni230P1aSHd207R?QP80M8j:0P1lRXL207^6
RP80N8b90P1dTHP207RBQ080MXf90P1kQX/207^9R080LY:90P1aThT207BAR080M8j:0P1kRXL207f;
QP80MX^:0P1hRH/207^<QP80LY690P1fT8L207R9R`80NhZ70P1iSHL207N<R@80MXn80P1kTH<308>=
P080N8n60P2NXe`2086@O`80OIUl0P1nVGX208F8P@80PXN50P21V7X208BIMP80N9>40P1nQ8X201mH
l080N8b90P1^S90207N=R@80N8V;0P1hS8T207N=R@80MXV<0P1lRXL207R8S080O8Z70P1cShX207>C
Q`80N9260P1hS8T207R@QP80M8j:0P1hS8T207R>Q`80MHj90P1jShD207J=RP80MXn80P1hTXD207B@
R@80MYF40P1aTHX207R>Q`@0N8b9101hT8H207R?Q`80MI>60P1bUXH207>EQP80N9260P1cRhd207F4
T@80PXV30P1]VhH207:SO@80KIN90P1^VXH206nIQP80NIik0P1WWhP206j/NP80Mj1k0P2=XVT2066H
T@80S8Ql0`1`MYh2076GQP80Hi6E0P1YRYD207REPP80Li>70P1_TH`207R5S@80LXBB0P1hRH/2081m
S080PhJ40P1bRXh207QnTP80QX:50P1fRH`207V2SP80N86@0P1gRhX207R<R@80Mh:@0P1hOY8207R8
R`80M82D0P1nOhh207V1S`80O8B;0P1hRhT207R?QP80M8^<0P1kSh@207R9R`80N8N<403oool000h0
oooo0P1nPhX207R6S@80Ni230P1aSHd207R?QP80M8j:0P1lRXL207^6RP80N8b90P1dTHP207RBQ080
MXf90P1kQX/207^9R080LY:90P1aThT207BAR080M8j:0P1kRXL207f;QP80MX^:0P1hRH/207^<QP80
LY690P1fT8L207R9R`80NhZ70P1iSHL207N<R@80MXn80P1kTH<308>=P080N8n60P2NXe`2086@O`80
OIUl0P1nVGX208F8P@80PXN50P21V7X208BIMP80N9>40P1nQ8X201mHl080N8b90P1^S90207N=R@80
N8V;0P1hS8T207N=R@80MXV<0P1lRXL207R8S080O8Z70P1cShX207>CQ`80N9260P1hS8T207R@QP80
M8j:0P1hS8T207R>Q`80MHj90P1jShD207J=RP80MXn80P1hTXD207B@R@80MYF40P1aTHX207R>Q`@0
N8b9101hT8H207R?Q`80MI>60P1bUXH207>EQP80N9260P1cRhd207F4T@80PXV30P1]VhH207:SO@80
KIN90P1^VXH206nIQP80NIik0P1WWhP206j/NP80Mj1k0P2=XVT2066HT@80S8Ql0`1`MYh2076GQP80
Hi6E0P1YRYD207REPP80Li>70P1_TH`207R5S@80LXBB0P1hRH/2081mS080PhJ40P1bRXh207QnTP80
QX:50P1fRH`207V2SP80N86@0P1gRhX207R<R@80Mh:@0P1hOY8207R8R`80M82D0P1nOhh207V1S`80
O8B;0P1hRhT207R?QP80M8^<0P1kSh@207R9R`80N8N<403oool000h0oooo0P1hS8T207R?QP80Nhn4
0P1cSH/207J@Q`80M9290P1bShX207RAQ@80MXf90P1kS8H207V=Q`80MXN=0P1hRH/207f=Q080NhJ;
0P1kRHP207J:R`80N8b90P1dTHP207V?QP80N8R<0P1hSXL207RAQ@80N8N<0P1kQX/407R<R@80OH^6
0P1hRhX207^<QP80O8b50`20TWh207^WL`80QjQZ0P21T7l208R?NP80PY1n0P1gQhd208^<N`80RHQo
0P2AQG/208F0Q`80N7JI0P0ZYk0202nbY080LhN@0P1gRH/207R6S@80OHV60P1hSHP2076:S`80O8j4
0P1cShX207R@QPH0N8b90P1hSXL207Z;R080N8Z:0P1fThD207BAR080M8b;0P1lS8D207N=R@80N8j7
0P1iRXT207^>Q@80N8V;0P1kSHH2076@R`80N8V;0P1kRXL207b>Q080N8b90P1jT8@207R?QP80N9R0
0P1[V8T2076;SP80N7jB0P1hS8T207RYM080KJ620P1bT8X207NBQ@80L96;0P1fU8@207bON080KIf5
0P1hYGL206RUP`80RX>20P2=K8l2081dU0<0QG:A0P2=KXh207mXW@80O7bA0P22R8@207b5RP80NHR;
0P1/R9D207RFPP80I9b<0P1WWHT207RFP@80LXV?0P1YVHX206nTOP80KHND0P1hPhl207R<R@80MXb9
0P1hQ8l207IoU080N82A0P21Oh/207:0UP80NHN;0P1hSHP207:EQP80MHj:0P1kQhT207R<R@80NHj6
0P1dRHd207R?QQ00oooo000>0?ooo`80N8b90P1hShH207^?Q080Lhf;0P1fT8L207B@R@80LXn:0P1h
THD207J=R@80Nhb60P1iSHL207J7S@80N8V;0P1mSH@207^6R`80NhV80P1fRX/207R<R@80M9680P1i
ShH207R8S080N8j70P1hTHD207R7S080NhJ;101hS8T207f;QP80N8^:0P1kS8H207b<Q@<0P99n0P1k
Yg<208NXJP80PI1o0P28SgX208:@OP80MhN=0P2;S7/208V8O`80THEk0P25P8L207QfV@80:ZN`0P0_
/Z@207>7T080MhV;0P1hQXd207f9QP80N8f80P1aRXl207b>Q080Lhn:0P1hT8H607R<R@80N8j70P1j
RhP207R:RP80MY>50P1dTHP207B<R`80O8b50P1gSHT207R>Q`80NHZ90P1kSXD207R9R`80Nhf60P1a
T8/207R9R`80NhZ70P1lSX@207R<R@80NY240P1hShH207RHP080JiR90P1aRhh207QnTP80N8b90P1h
ZG@206fQPP80LY2:0P1gTXD2072AR`80MYB40P1lWgP206fMQ@80N:Eg0P1XYH<208Z3PP80SFb?0P20
M9@308EbT@80SFj>0P1oJ9d207alT@80PXR40P1lQHX207V8R`80K8RE0P1hUX8206BLS080Iif90P1h
UX4207:9S`80JIV:0P1_Y7h206f7U080N8>?0P1hS8T207J<R@80N8B?0P1fOi@207R0T@80PGn;0P1b
P9H207V7R`80N8f80P1bUHH207F>RP80NhN90P1hS8T207V>QP80M8V=0P1hShH@0?ooo`003P3oool2
07R<R@80NhZ70P1lRhH207N8S080Nh^70P1hS8T207B<R`80NHb80P1hR8`207b>Q080N8R;0P1hQh`2
07R<R@80NhZ70P1hSXL207N@QP80M8Z=0P1kSh@207J=R@80N8n70P1aTHX207R<R@80OHV70P1bSH`2
07B>RP80Nhn40P1cShX207V@Q@80MXn80P1hTh@207J@Q`<0PiMh0P2<VVl208NKL`80N9F20P24UGT2
08:7Q@80O8:<0P29VG8207RAQ@80Rhei0P1oO8l207YmTP80Miam0P0HO=`206n9TP80N8^90P1bRHl2
07j?PP80N8b90P1aSX`207RDP`80M9690P1eSXT207R@QP80M9690P1eSXT207V;R080N8f80P1gT8H2
07V<Q`80NHZ90P1dShX207J=R@80O8f50P1fShP207B@R@80O8Z70P1hShL207R>Q`80NH^80P1]UHX2
07BGQ080MY>50P1eThH207RFPP80Li^20P1hTh@207R7S080KGnJ0P1gPhl208:TL080N9an0P1hPhl2
07R7S080OI:00P1^XX4206JbN`80K[=e0P1SV90208N>N`80OH^50P1VTY8207N=R080Mh6A0`1hUh42
06FAT`80KX^A0P1gSHT207f>P`80N9260P1cWgl205^8X080RhQm0P1gNiD20828Q@80LWbH0P26QH<2
07R<R@80OWJD0P1hNIH407R<R@80MhN=0P1cRHh206j4UP80N8>?0P1hRhT20769T080M8^<0P1mSh82
07R7S080N8J=0P1hS8T207^?Q080MXZ;0P1hRH/207^:Qa00oooo000>0?ooo`80N8b90P1kRXL207b;
QP80MhR<0P1kRhL207R<R@80M8b;0P1iS8P207R8S080O8j40P1hR8/207R7S080N8b90P1kRXL207R>
Q`80Mi260P1dRXd207^?Q080MXf90P1hShL2076ARP80N8b90P1mRHL207:=S080M8j:0P1kSh@207>?
RP80NI250P1fShP207RCQ080MY270`23UgP208bJK`80Qi]c0P1hUH8208BEN@80PXN50P1lPX`208VI
LP80N9650P2;SGT207mlS`80NWfB0P1gW7d201Qlg080KhVB0P1hRhT207:9S`80OXn20P1hS8T2076>
S080N9B30P1dTHT207F>R@80N9260P1dTHT207F>R@80NH^80P1hSHP207N@QP80NHb70P1iRXT207B?
RP80MXf90P1lSHD207J?R080M9290P1lRXL207R?Q`80N8j70P1iRhP206fERP80M9N40P1fThD207FC
QP80N9J20P1cVh8207RCQ080N8N<0P1]OiX207N3S`80PZA`0P1hW7h207R3S`80N8N<0P1mTX0206jR
P@80I[9k0P1^/gD206>HT080Qhik0P1mRhD206JBTP80Mhf80P1gPI4307RGP@80II6C0P1^Ri4207N=
R@80OHj30P1hT8H207>OO`80FhRP0P2;R7d207MkU@80P8R50P1bO9P208J5P`80N8b90P1nMY@207Qi
UP@0N8b90P1gQhd207>9SP80KXBF0P1hPhl207R;R@80LHV@0P1dRh`207f?PP80N8N<0P1hQXd207R<
R@80Nhn40P1fRX/207R9R`80NhZ7403oool000h0oooo0P1hS8T207RAQ@@0N8b90P1hS8P207^6R`80
NhN90P1hRH/207R<R@80O8f50P1dRXd607R<R@80OHf40P1hS8T207><S@80OHV70P1kRHP207^;Q`80
NH^80P1aRhh207f=Q080N8N<0P1hSXL207NAQ@80MXV<0P1lQhT207j9QP80OXf40P1gSHT308VTJ`80
Niij0P2@UVl207RHP080O9]k0P1bV8@2072MPP80Qiea0P1dSXX208B1Q`80PgJ@0P21SH4208BUK@80
36Ke0P1hQh`207>>R`80LY2:0P1hT8H207V;R080MXb:0P1lSX@207J=R@80M8b<0P1lSX@207J=R@80
M9290P1dTXL207JAQ`80N8j70P1fS8X407V;R080M9290P1hSXL207^:Q`80N8b90P1dU8D207RFPP80
Ki6<0P1hTXD207R<R@80Mhj70P1hS8P207bAPP80N9>40P1mU7h206jERP80KXRC0P1]Qi@206j]N080
N:ia0P1^UXT206RJRP80K:230P1bYG/207RNO080NJ=h0P1aThT206^0VP80Pi5m0P1mRHH207V6S080
K92>0P1/WXD307JHPP80IhJI0P1^RI8207R<R@80O9220P1jSXH208IlR@80J7ZQ0P1oUW`206V>TP80
OIMm0P1MVY8207:MP@80MhN<0P1YU8h206VCSP@0N8^90P1cOiD2089_UP80OWNC0P1gS8T207R9R`80
MHF@0P1hRH/207j<Q080M8R>0P1hS8T207RAQ@80N8n60P1dSXX207:?RP80N8b9403oool000h0oooo
0P1hS8T207RAQ@@0N8b90P1hS8P207^6R`80NhN90P1hRH/207R<R@80O8f50P1dRXd607R<R@80OHf4
0P1hS8T207><S@80OHV70P1kRHP207^;Q`80NH^80P1aRhh207f=Q080N8N<0P1hSXL207NAQ@80MXV<
0P1lQhT207j9QP80OXf40P1gSHT308VTJ`80Niij0P2@UVl207RHP080O9]k0P1bV8@2072MPP80Qiea
0P1dSXX208B1Q`80PgJ@0P21SH4208BUK@8036Ke0P1hQh`207>>R`80LY2:0P1hT8H207V;R080MXb:
0P1lSX@207J=R@80M8b<0P1lSX@207J=R@80M9290P1dTXL207JAQ`80N8j70P1fS8X407V;R080M929
0P1hSXL207^:Q`80N8b90P1dU8D207RFPP80Ki6<0P1hTXD207R<R@80Mhj70P1hS8P207bAPP80N9>4
0P1mU7h206jERP80KXRC0P1]Qi@206j]N080N:ia0P1^UXT206RJRP80K:230P1bYG/207RNO080NJ=h
0P1aThT206^0VP80Pi5m0P1mRHH207V6S080K92>0P1/WXD307JHPP80IhJI0P1^RI8207R<R@80O922
0P1jSXH208IlR@80J7ZQ0P1oUW`206V>TP80OIMm0P1MVY8207:MP@80MhN<0P1YU8h206VCSP@0N8^9
0P1cOiD2089_UP80OWNC0P1gS8T207R9R`80MHF@0P1hRH/207j<Q080M8R>0P1hS8T207RAQ@80N8n6
0P1dSXX207:?RP80N8b9403oool000h0oooo0P1hS8T207f9Q`80N8N<0P1lSh<207:;SP80N8b90P1h
ShH207B>RP80N8n6101hS8T207B>RP@0N8b90P1kRXL207b:Q`80M8f;0P1dTHP207R?QP80N8b90P1k
QhX207R6S@80Nhj50P1dRh`207f>P`@0N8N<0P1hS8T207b?P`80OHn30P1hUX83092RI`80N9N10P28
V7@208J<OP80PXZ20P21QhD2082FN`80O9ii0P1bQi4207R4S`80O8n40P24V7L208n6N`805ECj0P1l
SH@207>5T@80OXV60P1gTHH207B>RP80N8b90P1jSHL207Z7RP80N8b90P1hShH207R:R@80NH^80P1h
TXD207:?R`80N8b90P1fThD2072GQP80LYJ60P1dU8H2072?S@80NIF10P1aU8P207Z@Q080N8b80P1h
RXX207R@QP80LiB60P1dTXL207>HQ080MYN20P1hW7h207>HQ080N8V;0P1WS9D206bRPP80O:Ae0P1g
THD207R=R080Lhn:0P1gUh4207RUM`80Jj240P23SGl207F1T`80JgjM0P2>P84208AkR`80PhJ40P1g
SXP207MkU@<0RWJ:0P1bP9D206j?S@80L9B90P1kS8H207idU@80QgR<0P1gQhd207fAP@80L92;0P1h
TXD207R<R@80K8fA0P1bPI@208IfSP80N7RF0P1nR8L207QnT`80N7ZE0P1]RY<207R>Q`80NhZ70P1c
Rh`2076>S080LiF60P1eSXX207R9R`80N8n60P1iRhP207^6R`80OHJ90P1hQh`207R<RA00oooo000>
0?ooo`80N8b90P1mRHL207R7S080O8n30P1bRhh207R<R@80N8n60P1dSXX207R?QP@0N8b90P1dSXX4
07R<R@80NhZ70P1lRXL207B=R`80M9680P1hShH207R<R@80NhN:0P1hQXd207^>Q@80M8^<0P1mSX<4
07R7S080N8b90P1lSh<207f?P`80N9J20`2@XVL207RGP@80R9Qd0P26S7h208::PP80PHN50P20UW/2
07bNN@80LXNA0P1hQ8l207b?Q080Q9Qg0P2?QW/201EDnP80O8f40P1cQI4207j9QP80Mi660P1dSXX2
07R<R@80NXf70P1jQhX207R<R@80N8n60P1hRXT207V;R080N9:50P1bSh/207R<R@80MY>50P1`UhH2
07:FQP80M9B60P1`Shd207VEP@80LIB80P1jT8@207R<R080N8Z:0P1hT8H207>DQP80M9:70P1cV8@2
07JGPP80N9an0P1cV8@207R9R`80IhbE0P1/XX8207bTM@80Mi650P1hSHP207>?RP80MiN10P1hYGL2
06^PQ080Pheo0P1ePI<206]nW@80SX210P24Nh/208>6Q080Mhj80P1gNiD308YfRP80LX2E0P1^Shd2
072DR@80Nhb60P1nM9D208MhS080MhN=0P1mTH42072@R`80N9:50P1hS8T206b=T@80LX6D0P26MXh2
07QhUP80OXR70P1hOY<207QjU@80KHZC0P1hSXL207^:Q`80Lh^<0P1aSX`207>EQP80MHj:0P1hRH/2
07R?QP80NH^80P1kQX/207f6R@80N8N<0P1hS8T@0?ooo`003P3oool207R<R@80N8n60P1dSXX207f9
Q`80N8N<101hShH207B;S080NhZ7101hS8T207R9R`@0N8b90P1hShH207R<R@80NhZ70P1hS8T207R9
R`80NhN90P1hS8T207B>RP80Nhj50P1dSXX207V>QP80M8b;0P1dTHP207BBQ`80N9650P1mSX<208:A
O@<0TYM]0P21UG`207nGN`80OiIl0P1lU80207R?Q`80SXeg0P27OhH207QbV`80QHF30P1mY7@207>P
O@80N9F20P0?JO0207b>Q080KXj>0P1gVgh207:@RP80MXR=0P1iRhP207VCP`80KYV70P1bThP207N>
R080M9B60P1bUXH207RBQ@80LY:90P1_UXP207RBQ@80N8n70P1eT8P207F>RP80LYF70P1dThH207R?
QP80M9B60P1dTXL207:CR@80N9:40P1gSHT207RCQ080Mi:50P1hTX@2082AOP80Mhf80P1_Qi<207RA
Q@80LZEk0P1`Yg/206RIR`80LY^20P1[VXP207RUM`80Mi660P21Oh/207b8R@80N8V;0P1PS9X207R<
R@80Ph:80P29RGh207inSP80L8JC0`1eU8D207:8S`80N9R00P1VU90207B<S080IhJI0P20R8D20820
R`80R8Yn0P1gRhX207QoTP80QXF30P1aRXl206>4WP80MXb90P1aRhh207b1S@80N7JH0P1mNi0207j4
RP80Lh^=0P1lSX@207>9SP80N8^:0P1iQh/207R6S@80N8b90P1kSXD207B@R@80LY:80P1dThH207:B
R080M8j:403oool000h0oooo0P1hS8T207R?QP80M8j:0P1mRHL207R7S0@0N8n60P1dRh`207^:Q`@0
N8b90P1hRH/407R<R@80N8n60P1hS8T207^:Q`80N8b90P1hRH/207^7R@80N8b90P1dSXX207^>Q@80
M8j:0P1iSXH207B<R`80M9680P1dTXL207RAQ@80OHj30P22TGd309:GK@80PIEl0P1oUg/207nFO080
O9B00P1hShL208j=M`80Qgn60P1hLY/208F5P`80OJAd0P1cX7d207REPP803fW`0P1lSX@206j>SP80
Mi]n0P1bT8X207J8S@80NH^80P1iTh<206jIQ`80LY>80P1gSXP207BDQP80LYJ60P1hTXD207:BR@80
KiJ80P1hTXD207R?Q`80MI280P1eSXX207:EQ`80M9>60P1hShH207BDQP80M9:70P1bThT207RBQ080
Mhf90P1hTh@207NBQ@80N9:40P20TGh207N=R080KhNC0P1hTHD207:UN`80L:Mk0P1XVH/207:KPP80
JiZ80P1hYGL207NAQP80PGn;0P1lR8T207R9R`80H8bJ0P1hS8T208>2R080RHUn0P1nOXh20726T`<0
MIB50P1bR8l207RHP080IYB@0P1dS8`206N6V@80P8R50P20P8/208R:OP80Mh^:0P1hOi8208J5P`80
LHZ?0P1SQ9h207J<R@80LH^>0P1lPHd207QfV080OG^@0P1nQ8X207>;S@80O8j40P1cRHh207R;RP80
NHN;0P1hQXd207R<R@80Nhj50P1dT8T207:BR080M9>60P1bTXP207B>RQ00oooo000>0?ooo`80N8b9
0P1kRXL207R9R`80N8n60P1dSXX407^:Q`80M8^<0P1hS8T207^:Q`80N8b90P1dSXX407R<R@80NhZ7
0P1hRH/207^:Q`80NhN90P1hRH/207R<R@80Nhj50P1dRh`207^>Q@80N8b90P1hRH/207^<QP80MXn8
0P1gRH/207f5RP80PXb10P23WG@308BVK@80OI:00P28Rgd208J@N`80OHn30P1hS8P208JJM080LXV?
0P1`T8/207RWMP80QJ5`0P1bS8d208:<P@803fCd0P1kRhL207R9R`80PHN50P1hPhl207JAQ`80LXn;
0P22RH<207n8QP80LXZ?0P1iTH@207RBQ080MHj:0P1hShL207RBQ@80LXn;0P1eThH207B@R080N8n6
0P1bThT207RBQ@80LXb=0P1lS8D207^;Q`80Mi660P1cUHH207:@RP@0N9650P1hS8P207f?P`80O9>0
0P1gR8`2076;SP80NJ9h0P1hWW`207RAQ@80L9>90P1bVh8206fTO`80LYb20P1_S90207BUNP80IYj9
0P1`SXd206amW080N8>?0P1mRHL208UjR080Qgj80P1jRhP307RAQ@80JI^90P1hS8T207IjU`80N926
0P1OSIX207B>RP80N9B30P1oUg/207IoT`80N7fD0P29Rg`207QmU080KGnJ0P1gSHT207:1U@80N7fC
0P1dQY0207:EQ`80LIF70P1cRhd207b7R@80NHF=0P1iRXT207B:S@80N8n60P1dSXX207^:Q`80OHJ9
0P1kRHP207V;R080N8N<0P1hS8T@0?ooo`003P3oool207R<R@80NhZ70P1hRH/207R?QP80M8j:101k
RXL207B;S080N8b90P1kRXL207R<R@80M8j:101hS8T207^:Q`80N8V;0P1kRXL207^7R@80N8V;0P1h
S8T207^>Q@80M8^<0P1kSXD207R<R@80N8V;0P1kS8H207J?R080MhV;0P1mQHX208:<P@80Pied0`24
YVd207fBP080R8]m0P26T7/207f?P`80N8b80P26VW@207:9S`80L92;0P1hYgH208FQL080LXb=0P22
S84200mTm080Nh^70P1hRH/20867Q@80N8>?0P1fTHL207:?R`80PXV30P1oR8H207::S`80NI640P1h
TX@207F>RP80N8n70P1hTXD207:?R`80MI>60P1dT8P207R?QP80LY>90P1hTXD207:<S@80O8b50P1k
RhL207NAQP80LiF60P1bT8X407RAQ@80N8b80P1mSh<207bCP080MhR<0P1aRhh207VRN080N9il0P1h
THD2072CR@80LY^20P1]Y7l207:LPP80Khb@0P1dYGX206JNR@80L8j=0P1/OI`207R3S`80OHV70P29
NXP208MnR080NX^80`1hTHD206VKR@80N8b90P1fNYL207R@QP80GhfJ0P1dSXX207RDP`80OiMk0P1f
Oi<207QmU080RH]l0P1hOI@206eoVP80Mhf90P1bPID207QmT`80M8J@0P1bUHL2076EQ`80Lh^=0P1l
QhT207V5S@80NHZ90P1dRXd207R?QP80M8j:0P1kRXL207f6R@80NhV80P1iRhP207R7S080N8b9403o
ool000h0oooo1P1hS8T207^:Q`80N8b90P1dTHP407R<R@80M9>60P1bShX207^:Q`80N8V;0P1hS8T2
07R?QP80M8j:201hS8T207R?QP80N8b90P1hRH/207^>Q@80N8n70P1aT8/207VBQ080MXV<0P1hRhX2
07BBQ`80OXf30P2FWf@3082LM`80N9N10P1jVWd208BPL@80L9V60P1eVh02086IN080K8BG0P22TGd2
08:CO080RHal0P1hO9@208V7O`805F3b0P1hU88206nAS080N9260P1dSXX207b>Q080LY>80P1`TXX2
07n?P@80LXn;0P1hTXD207Z=QP80MI670P1dU8H207R?QP80M9>60P1bUXD2072AR`80MiB40P1cThL2
07>?RP80M8n:0P1cThL207RFPP80MI:60P1iSXL2076@RP80Mi:50P1gSHP207RFPP80M9R40P1nTX02
06j8T`80O9>00P1oVGX207ZDP@80LYF70P1dUh@207BFQ080OHV70P1kP8l207RFP@80O9B00P1aQY82
06j9TP80HHjH0P1]TXd207RAQ@80KY:<0P22T7h207f3R`<0QX]n0P1hS8T206VHR`80Gi^@0P1hQHd2
07:0U@80L9F80P1gS8T208UkR080N7fC0P1eVh0207:JQ0@0KHRC0P1hQXd206ioVP80MXZ;0P1aS8d2
07j3RP80OWn=0P1hS8T2072=S@80N8V;0P1kRXL207B;S080NhZ70P1hRH/407R<R@80Nhj5101hRH/2
07^>QA00oooo000>0?ooo`H0N8b90P1kRXL207R<R@80M968101hS8T207BCQP80LXn:0P1kRXL207R9
R`80N8b90P1hShH207B>RPP0N8b90P1hShH207R<R@80N8V;0P1kSXD207R?Q`80LI2;0P1iTX@207J9
S080N8^:0P1dTXL207j=P`80UYmT0`20W7L207RGP@80NYYm0P24X742072IQP80MI^00P21VGP206b4
U`80PY5m0P22Tg`208V<O080N7bD0P29Qgl201EPlP80N9B20P1_TH`207R@QP80M8j:0P1lSX@207:C
R080L9::0P1oSh4207:?R`80N9:50P1jSHH207FAQ`80M9B60P1hShH207BCQP80LYJ50P1`TH/207ND
Q080Li>70P1cShX207B?RP80Li>70P1hUX8207FBQP80NHj70P1aT8X207NBQ@80Mhf80P1hUX8207BH
Q080OY:00P1^R9<207bCP080OiUj0P1jU84207:EQ`80M9N40P1dUX@207f9Q`80Nh2?0P1hUX4207bD
P080LHJB0P1^RI82066>V080KI:=0P1hTHD206jBS080PY1n0P1mPh/308J;OP80N8b90P1YV8/205nK
T080N8F=0P1bP9D2072ER080Mhb90P29NhP207QmT`80MI^00P1bVX@406f8T`80N8J=0P1^OiX207J:
R`80LHb=0P1nPhX207ioS@80N8b90P1`SHd207R9R`80NhZ70P1dRh`207^:Q`80N8V;101hS8T207^>
Q@@0N8V;0P1kSXD@0?ooo`003P3oool207R<R@80N8n60P1dTHP207B>RP80Nhj50P1hS8T207B;S080
NhZ70P1mQXT207R;RP80M9>60P1bShX207R<R@80Nhj50P1dRh`207R<R@80N8n60P1dTHP207BBQ`80
MY:60P1bS8d407R?QP80NhN:0P1kQ8/207j9QP80M8R>0P1kT8<207J>R080N9an0P2CYF83086?P080
PiEj0P1hUh4208ZCMP80Ngj@0P2<T7L207V6S080N8:@0P23S80208VLL@80L:200P1VVH`207RCQ080
6FC/0P21TGl206j<T080N9F20P1^TH`207R@QP80O8j40P1`T8/207RCQ080N9:50P1bTXT207RBQ080
MiB40P1cShX207NAQP80N9250P1hS8T207>FQ@80Kib40P1_V8H206^ES080LIJ60P1aThP207ZAQ080
MXf90P1hTh@407:EQ`80LYV40P1hUH8207RAQ@80N8n60P1`W8<206^]N`80LZ5n0P1gVH0207>BR080
N8V;0P21Q8L207R;R@80LiJ50P1nSH<207j0S080NgfA0P1hPhl206f7U080KHRD0P1mNY4208QeS@80
R72@0P2@O88308RGM@80LIJ70P1eSXT206^0V`80K9:=0P1WUHl207R5SP80MhF>0P1gSHP207RKOP80
Mi]o0P1aT8/206N2W080MgjC0P1gQhd206V8UP80N8N<0P1hRhT206f>S`80N9:50P1hQXd207^4S080
M8^<0P1kRXL207R9R`80N8b90P1hShH207B>RP80N8b90P1kRXL207R>Q`80LXn:0P1kSXD@0?ooo`00
3P3oool207R<R@80N8n60P1dTHP207B>RP80Nhj50P1hS8T207B;S080NhZ70P1mQXT207R;RP80M9>6
0P1bShX207R<R@80Nhj50P1dRh`207R<R@80N8n60P1dTHP207BBQ`80MY:60P1bS8d407R?QP80NhN:
0P1kQ8/207j9QP80M8R>0P1kT8<207J>R080N9an0P2CYF83086?P080PiEj0P1hUh4208ZCMP80Ngj@
0P2<T7L207V6S080N8:@0P23S80208VLL@80L:200P1VVH`207RCQ0806FC/0P21TGl206j<T080N9F2
0P1^TH`207R@QP80O8j40P1`T8/207RCQ080N9:50P1bTXT207RBQ080MiB40P1cShX207NAQP80N925
0P1hS8T207>FQ@80Kib40P1_V8H206^ES080LIJ60P1aThP207ZAQ080MXf90P1hTh@407:EQ`80LYV4
0P1hUH8207RAQ@80N8n60P1`W8<206^]N`80LZ5n0P1gVH0207>BR080N8V;0P21Q8L207R;R@80LiJ5
0P1nSH<207j0S080NgfA0P1hPhl206f7U080KHRD0P1mNY4208QeS@80R72@0P2@O88308RGM@80LIJ7
0P1eSXT206^0V`80K9:=0P1WUHl207R5SP80MhF>0P1gSHP207RKOP80Mi]o0P1aT8/206N2W080MgjC
0P1gQhd206V8UP80N8N<0P1hRhT206f>S`80N9:50P1hQXd207^4S080M8^<0P1kRXL207R9R`80N8b9
0P1hShH207B>RP80N8b90P1kRXL207R>Q`80LXn:0P1kSXD@0?ooo`003P3oool207BAR080N8b90P1k
QhT207R<R@80N8n60P1hSHP207>@R@80LYB70P1bTXP207R<R@80OHJ90P1hQh`207RAQ@80MXf90P1h
S8T207B>RP80Nhj50P1hRH/207b;QP80N8R;0P1hQh`207^:Q`80NhN90P1hRH/207R?QP80N9650P1b
ShX207^?Q080N8^:0P29Wfh208BNLP<0P9Mj0P20U7d2086BO@80OIYj0P1ZUX`208NGMP80LGnF0P1o
Ug`206jUOP80R:IZ0P1eThH206n<T080Lhj:0P0EJ^/2086@O`80LXZ>0P1mRHL207R7S0@0N9260P1h
TXD207:FQP80Mi>40P1cShX207R@QP80O8j40P1cT8T207JCQ@80MHj90P1hSXL207f;Q@80OHV60P1h
S8T207:?R`80LYF70P1_TH`207R>Q`@0N9:50P1hS8T207REPP80LYR40P1bU8L207NIP080KY:<0P24
UgP207VHO`80L9f20P1aSh/207^:Q`80L8f>0P1hS8T2082UL@80H:j20P1PYhL206FBT`80M7nE0P22
O8`207R2S`80KHf@0P1RU9<2076EQ`80KIN90P1mRhD30:=gM`80SG^50P1hNiD207>3TP80N8N<0P1b
Sh/205nAV080N8^90P1hVGl207RJOP80N8b90P1hS8P205b2Y080LXZ?0P1gNYH207imS`80LHZ?0P1m
RHL207>9SP80N8^90P1bQI4207^@P`80LI6:0P1cShX207R<R@80N8n60P1hS8T207R9R`80N8b90P1h
ShH207V;R080N8N<0P1kRXL@0?ooo`003P3oool207BAR080N8b90P1kQhT207R<R@80N8n60P1hSHP2
07>@R@80LYB70P1bTXP207R<R@80OHJ90P1hQh`207RAQ@80MXf90P1hS8T207B>RP80Nhj50P1hRH/2
07b;QP80N8R;0P1hQh`207^:Q`80NhN90P1hRH/207R?QP80N9650P1bShX207^?Q080N8^:0P29Wfh2
08BNLP<0P9Mj0P20U7d2086BO@80OIYj0P1ZUX`208NGMP80LGnF0P1oUg`206jUOP80R:IZ0P1eThH2
06n<T080Lhj:0P0EJ^/2086@O`80LXZ>0P1mRHL207R7S0@0N9260P1hTXD207:FQP80Mi>40P1cShX2
07R@QP80O8j40P1cT8T207JCQ@80MHj90P1hSXL207f;Q@80OHV60P1hS8T207:?R`80LYF70P1_TH`2
07R>Q`@0N9:50P1hS8T207REPP80LYR40P1bU8L207NIP080KY:<0P24UgP207VHO`80L9f20P1aSh/2
07^:Q`80L8f>0P1hS8T2082UL@80H:j20P1PYhL206FBT`80M7nE0P22O8`207R2S`80KHf@0P1RU9<2
076EQ`80KIN90P1mRhD30:=gM`80SG^50P1hNiD207>3TP80N8N<0P1bSh/205nAV080N8^90P1hVGl2
07RJOP80N8b90P1hS8P205b2Y080LXZ?0P1gNYH207imS`80LHZ?0P1mRHL207>9SP80N8^90P1bQI42
07^@P`80LI6:0P1cShX207R<R@80N8n60P1hS8T207R9R`80N8b90P1hShH207V;R080N8N<0P1kRXL@
0?ooo`003P3oool207^7R@80N8V;0P1hS8T407^:Q`80NHR:101mQHX207^6R`80N8V;101hS8T207f9
Q`80N8b90P1fT8L207B;S080Nhn40P1cS8d207b=Q@80M8Z=0P1hShH207B>RP80N8n60P1dTXL207J@
Q`80NHR:0P1kS8H207J=R@80NIN00P2:YFT207jEOP<0R9Qd0P1hVgh207bMN@80P9200P1hTX@207RF
P@80JXjB0P27VG@207fEOP80R91j0P21Nhh207anT080O8B<0P0LJnD207REPP80LY2:0P1aUHL207:D
R080N9:50P1fThD207R>Q`80O8Z70P1hRhT207RAQ@80LY>80P1hT8H207VCP`80LYF70P1`UXP207:N
P080JIf80P1dV8@207BFQ080Ki6<0P1hS8T207:GQ@80JIV:0P1hTXD207R<R@@0N9F20P1gSHT207R=
R080OiAn0P1[QiH208fAM@80P9me0P1^SHl207F4T@80O9620P1`UXL206V_N`80NZQc0P1hW7d205j1
X`80MVbQ0P1hS8T206RDSP80N9J20P1WU8l206V;U080LHFC0P23QXD20722UP<0T9Aa0P26QH<207Yg
UP80PHF60P1`Qi8208:9Q080IgnO0P1gVgl207RJO`80N9F20P1^UHX207=oU@80KG>R0P1hOI<206j4
UP80NI250P1bShX2076<SP80NhF;0P1hQh`207>:SP80OXb40P1iRHX207B:S@80N8b90P1kRXL207R>
Q`80LXn:0P1hShH407R<R@80M8j:0P1hS8T@0?ooo`003P3oool207^7R@80N8V;0P1hS8T407^:Q`80
NHR:101mQHX207^6R`80N8V;101hS8T207f9Q`80N8b90P1fT8L207B;S080Nhn40P1cS8d207b=Q@80
M8Z=0P1hShH207B>RP80N8n60P1dTXL207J@Q`80NHR:0P1kS8H207J=R@80NIN00P2:YFT207jEOP<0
R9Qd0P1hVgh207bMN@80P9200P1hTX@207RFP@80JXjB0P27VG@207fEOP80R91j0P21Nhh207anT080
O8B<0P0LJnD207REPP80LY2:0P1aUHL207:DR080N9:50P1fThD207R>Q`80O8Z70P1hRhT207RAQ@80
LY>80P1hT8H207VCP`80LYF70P1`UXP207:NP080JIf80P1dV8@207BFQ080Ki6<0P1hS8T207:GQ@80
JIV:0P1hTXD207R<R@@0N9F20P1gSHT207R=R080OiAn0P1[QiH208fAM@80P9me0P1^SHl207F4T@80
O9620P1`UXL206V_N`80NZQc0P1hW7d205j1X`80MVbQ0P1hS8T206RDSP80N9J20P1WU8l206V;U080
LHFC0P23QXD20722UP<0T9Aa0P26QH<207YgUP80PHF60P1`Qi8208:9Q080IgnO0P1gVgl207RJO`80
N9F20P1^UHX207=oU@80KG>R0P1hOI<206j4UP80NI250P1bShX2076<SP80NhF;0P1hQh`207>:SP80
OXb40P1iRHX207B:S@80N8b90P1kRXL207R>Q`80LXn:0P1hShH407R<R@80M8j:0P1hS8T@0?ooo`00
3P3oool407R<R@80N8n60P1dSXX207^>Q@80M8j:0P1dThH207:BR080M9680P1dSXX207R?QP80M8j:
0P1hS8T207b:Q`80NhJ:0P1hRH/207b?P`80LXn:0P1fT8L207B@R@80MXf90P1hRH/207^>Q@80NHR:
0P1kQXX207R>Q`80NHn60P1hS8T208:OL`80Q:9`0P1hW7d308>TK`80N9F20P22Tg`207R?QP80PX^1
0P1nRHH2076@R`80PJAa0P1eW80207b@PP80Lh^=0P1hS8T207F>RP808fkN0P1hSHP207R<R@80N8:?
0P21QHL207Z:R080OXV50P1gQXd207j9Q@80NhR90P21PhP20861R@80OHF:0P24QX<207j=P`80M9R4
0P1fTHH207RAQ@80KYN80P1fTXD206jCR`80KY^60P1fTHH207B:S@80M9R40P1^VhH207NFPP80N9B3
0P1_V8L2072OP@80MIV20P1VRYL208ZOK@80Qiea0P1ORi`207><S080P9]h0P1^Ygd207JQN`80Lhf<
0P2=MHT206Y_Z080HhRL0P27Q8<207R4SP80O8Z70P1gShL205^>W@80JhfA0P1gRX/207JCQ@<0OiUj
0P1nRhD206j?S@80NY240P1bSh/207:2U080N7fC0P26TWT207N7S@80R8B20P1lLiL207IkUP80IXRI
0P1/Nih208>6Q080M8n90P1hQ8l207R6S@80LXV?0P1lQHX207R8S0@0NhZ70P1dRh`407R<R@80OHV7
0P1hQh`207^:Q`80N8V;0P1kSXD207B;S080N8n6403oool000h0oooo101hS8T207R?QP80M8j:0P1k
SXD207B>RP80M9>60P1bTXP207BAR080M8j:0P1hShH207B>RP80N8b90P1lRXL207^6RP80N8V;0P1l
Sh<207:?RP80MY270P1dT8T207J=R@80N8V;0P1kSXD207V8RP80NhJ:0P1hSXL207V?QP80N8b90P22
Wg<208BRL080N9am0`23Y6l207REPP80PY=l0P1hShH208:;P@80OXV60P1aT8/2086TL@80MIb00P1l
T88207>;S@80N8b90P1eSXX202=^gP80N8f80P1hS8T207R2S`80PHF70P1jRXP207j9Q@80MhJ=0P1n
RHD207^8R@80PH>80P21PHT207f5RP80Q8J30P1nSH<207BHQ080MY660P1hTHD206jGR080MY:50P1^
Th/206jKQP80MY660P1dRXd207BHQ080KY^60P1gUX8207RDP`80KiR70P1`Wh4207FIPP80IXZG0P2:
Wfd208NML@80Gh^L0P1cS8`2082KN080KZMm0P1fXG/207>=S080SGF90P1ZKjP206>8W080QhB30P1h
Q8h207b:Q`80Mhn70P1KSYd206^=T@80MhZ;0P1fThD307nINP80OX^50P1^Shd207Z@Q080LXn;0P1b
PY@207QmT`80QY9i0P1gQhd208R4PP80O7>G0P1fNiH206J8V@80K7^N0P23QX@207B?R@80N8B?0P1h
QXd207:9S`80O8F:0P1hR8`407^:Q`80M8^<101hS8T207f9Q`80N8N<0P1kRXL207R9R`80Nhj50P1d
Rh`207R?QQ00oooo000>0?ooo`80M9680P1dSXX207^:Q`80N8n70P1eU8D207F;S080OHV70P1hQh`2
07^7R@80N8b90P1hShH207B;S080N8b90P1hTHD207:?RP80N8n60P1iRhP207b9Q`80MXb:0P1iS8L2
07>:SP80N8b90P1kSXD207B>RP80M9>60P1hTHD207J=R@80NI:30P2;VG4208NEM`80PYIi0`28UgD2
07RAQ@80PI5n0P1kSh@207R4S`80S8aj0P1bShX2092VI080IY2C0P22QhD207R8R`80N9260P1cOYH2
03ERf@80N7jB0P26MHh207ijT@80QWn70P26N8`208UfR`80QWb90P21PXT2085oR`80P8B80P1oQXL2
07j2RP80QH:60P2=NhD208mfQ`80PXZ20P1hUH8207B?R@80LY>80P1dTXL207BEQ@80JYZ90P1ZX8D2
072FR080N9260P1dUHD207RAQ@80NXn50P1jU84207:BR@80IHnD0P2=Z6H207^HO@80JH:K0P1`UhL2
086SLP80NYek0P1aUhH206afX@80QHN20P1SSYL206>3WP80N8b80P1nSh82076FQ`80N9:40P1RPZ02
06f;T@80L8NB0P28PH@308YeR`80T7mo0P1lPX`207bEO`80KZAo0P1?SJL207R<R@80Qi=h0P1`T8`2
07R4SP80N7jB0P1hPI4207AXY@80MWZG0P21SH4207j0S080LhFA0P1kRHP207>9S`80M8j:0P1hShH2
07B>RP80NhZ70P1hRH/207R<R@80N8n60P1dSXX607R<R@80NhZ70P1hS8T207RAQA00oooo000>0?oo
o`80M9680P1dSXX207^:Q`80N8n70P1eU8D207F;S080OHV70P1hQh`207^7R@80N8b90P1hShH207B;
S080N8b90P1hTHD207:?RP80N8n60P1iRhP207b9Q`80MXb:0P1iS8L207>:SP80N8b90P1kSXD207B>
RP80M9>60P1hTHD207J=R@80NI:30P2;VG4208NEM`80PYIi0`28UgD207RAQ@80PI5n0P1kSh@207R4
S`80S8aj0P1bShX2092VI080IY2C0P22QhD207R8R`80N9260P1cOYH203ERf@80N7jB0P26MHh207ij
T@80QWn70P26N8`208UfR`80QWb90P21PXT2085oR`80P8B80P1oQXL207j2RP80QH:60P2=NhD208mf
Q`80PXZ20P1hUH8207B?R@80LY>80P1dTXL207BEQ@80JYZ90P1ZX8D2072FR080N9260P1dUHD207RA
Q@80NXn50P1jU84207:BR@80IHnD0P2=Z6H207^HO@80JH:K0P1`UhL2086SLP80NYek0P1aUhH206af
X@80QHN20P1SSYL206>3WP80N8b80P1nSh82076FQ`80N9:40P1RPZ0206f;T@80L8NB0P28PH@308Ye
R`80T7mo0P1lPX`207bEO`80KZAo0P1?SJL207R<R@80Qi=h0P1`T8`207R4SP80N7jB0P1hPI4207AX
Y@80MWZG0P21SH4207j0S080LhFA0P1kRHP207>9S`80M8j:0P1hShH207B>RP80NhZ70P1hRH/207R<
R@80N8n60P1dSXX607R<R@80NhZ70P1hS8T207RAQA00oooo000>0?ooo`80M9680P1dSXX207^:Q`80
N8n70P1eU8D207F;S080OHV70P1hQh`207^7R@80N8b90P1hShH207B;S080N8b90P1hTHD207:?RP80
N8n60P1iRhP207b9Q`80MXb:0P1iS8L207>:SP80N8b90P1kSXD207B>RP80M9>60P1hTHD207J=R@80
NI:30P2;VG4208NEM`80PYIi0`28UgD207RAQ@80PI5n0P1kSh@207R4S`80S8aj0P1bShX2092VI080
IY2C0P22QhD207R8R`80N9260P1cOYH203ERf@80N7jB0P26MHh207ijT@80QWn70P26N8`208UfR`80
QWb90P21PXT2085oR`80P8B80P1oQXL207j2RP80QH:60P2=NhD208mfQ`80PXZ20P1hUH8207B?R@80
LY>80P1dTXL207BEQ@80JYZ90P1ZX8D2072FR080N9260P1dUHD207RAQ@80NXn50P1jU84207:BR@80
IHnD0P2=Z6H207^HO@80JH:K0P1`UhL2086SLP80NYek0P1aUhH206afX@80QHN20P1SSYL206>3WP80
N8b80P1nSh82076FQ`80N9:40P1RPZ0206f;T@80L8NB0P28PH@308YeR`80T7mo0P1lPX`207bEO`80
KZAo0P1?SJL207R<R@80Qi=h0P1`T8`207R4SP80N7jB0P1hPI4207AXY@80MWZG0P21SH4207j0S080
LhFA0P1kRHP207>9S`80M8j:0P1hShH207B>RP80NhZ70P1hRH/207R<R@80N8n60P1dSXX607R<R@80
NhZ70P1hS8T207RAQA00oooo000>0?ooo`80NhN90P1hS8T207BAR080Nh^70P1nPhX207R6S@80Nhj5
0P1dRh`207R<R@80NhZ70P1kQhT207R9R`80N8b90P1mSH@207B9S@80NhZ70P1hS8T207V<R080NhJ:
0P1lSHD2076;SP80N8n60P1hS8T207^<QP80N8j70P1hRhX207V:R@80Oi]h0P1nYW8207jPMP80Oi]h
0`23UGX207b?P`80O9aj0P1aUhH206ZIRP80OIIn0P1nTX0209:NJ080IgjO0P1oR8H207j9QP80O8j4
0P1RH[L205U@bP80NG^C0P1hPI0208:5QP80NXV90P1kRhL207R;R@80P8F70P23OXX20820R`80QXF3
0P1mQ8X207f5R@@0OXV60P22QhD2099lP080SWB90P27QH8207JDQ080KiB90P1hSHP207Z9R@80NXR:
0P1dUHD206bIR080N8f80P1hS8T207b@PP80OHn30P1hU8<206:CU@80UII/0P20NHl207QbV`80S9Ec
0P1hX7/207nEO@80Lh6D0P1PM:/209JAKP80I8>N0P1SSYL206fBS@80Oi=n0P1iTH@2076:S`80IXZG
0P1WUHl206:>U`80Mhb90`1jSHH208R<O@80OhR60P28UgD207b1S@80HGZV0P1_VHH207n@P080OH:;
0P1_N9d208B>OP80HXbI0P1JPJL207bCP@80LYV30P1]T8h207F=RP80LXV?0P1kRHP207B;S080Nhn4
0P1bShX207BCQP80LY:80P1dTHP207R<R@80N8V;0P1hShH207B>RP@0N8b90P1kRXL207f6RA00oooo
000>0?ooo`80NhN90P1hS8T207BAR080Nh^70P1nPhX207R6S@80Nhj50P1dRh`207R<R@80NhZ70P1k
QhT207R9R`80N8b90P1mSH@207B9S@80NhZ70P1hS8T207V<R080NhJ:0P1lSHD2076;SP80N8n60P1h
S8T207^<QP80N8j70P1hRhX207V:R@80Oi]h0P1nYW8207jPMP80Oi]h0`23UGX207b?P`80O9aj0P1a
UhH206ZIRP80OIIn0P1nTX0209:NJ080IgjO0P1oR8H207j9QP80O8j40P1RH[L205U@bP80NG^C0P1h
PI0208:5QP80NXV90P1kRhL207R;R@80P8F70P23OXX20820R`80QXF30P1mQ8X207f5R@@0OXV60P22
QhD2099lP080SWB90P27QH8207JDQ080KiB90P1hSHP207Z9R@80NXR:0P1dUHD206bIR080N8f80P1h
S8T207b@PP80OHn30P1hU8<206:CU@80UII/0P20NHl207QbV`80S9Ec0P1hX7/207nEO@80Lh6D0P1P
M:/209JAKP80I8>N0P1SSYL206fBS@80Oi=n0P1iTH@2076:S`80IXZG0P1WUHl206:>U`80Mhb90`1j
SHH208R<O@80OhR60P28UgD207b1S@80HGZV0P1_VHH207n@P080OH:;0P1_N9d208B>OP80HXbI0P1J
PJL207bCP@80LYV30P1]T8h207F=RP80LXV?0P1kRHP207B;S080Nhn40P1bShX207BCQP80LY:80P1d
THP207R<R@80N8V;0P1hShH207B>RP@0N8b90P1kRXL207f6RA00oooo000>0?ooo`80M9680P1hS8T2
07^<QP80Lhb=0P1hShH207BBQ`80MXf90P1hSXL207:?RPH0N8b90P1hShH207RAQ@80Lhb=101hShH2
07B;S080N8n60P1kSXD207B8SP80Nhj50P1dT8T207NAQ@80N8b90P1fRhX207R<R@80SYEb0P28VG<2
082MM`80O9Mn0`21UgT207RFPP80QXV00P20PXX207j?PP80LHZ?0P2=YVH207REPP80L7bI0P1mT882
07RBQ080O5B]0P1l:<`207QKZ`80OH2=0P1hQh`207^:Q`80OhR60P1jQ8d208:5QP80N8N<0P1mRHH2
07Z;R080P8R50P20P8/208:7Q@80OHR70P20R8D207j7Q`80PXN50P24PXH209=hPP80U6n80P29Ph82
072DR080L9N70P1_UhL207Z<Q`80NXR90P1`T8/207RCQ080N9Uo0P1dUX@207fLN@80GJf50P1XU8h2
08F5P`80I7nQ0P2WVE/207RIP080N9ml0P1LX8l204J=[@80Tgeo0P21Oh/206B>UP80K7jK0P2>SGL2
07QjU@80QWj70P1[QiD207:0U@80KGjJ0P1gPhl308AlR`80SX210P29XFd207BDQP80N7nB0P1ZS9<2
07:JP`80K9:=0P1hQ8l206b:TP80P9El0P1YJJd207AlU`80N9am0P1eRHd207InU080OHB:0P1dQI02
07^:Q`80N8f80P1hS8P207^6R`80OHJ90P1kQX/207^:Q`@0M8j:0P1kRXL207R9R`80N8b90P1hShH2
07B>RP80N8b9403oool000h0oooo0P1dTHP207R<R@80Nhb60P1cS8d207R?QP80M9:70P1fSHT207R>
Q`80LXn:1P1hS8T207R?QP80N9650P1cS8d407R?QP80M8^<0P1hShH207^>Q@80M8R>0P1kSXD207B@
R@80Mi650P1hS8T207J;RP80N8b90P2>UG8208RIL`80P9eg0P1lUgh3086GN@80N9J20P26RH020822
RP80OXn20P1aRXl208fVIP80N9F20P1`O9T207f@PP80N9:40P1lE:d207`Xc080N5^[0P1mP8d207R7
S080NhZ70P1oR8H207Z4S@80PXF60P1hQh`207f9QP80NX^80P20R8D20820R`80PXN50P1mR8L20828
Q@80OXN70P22QhD208B2QP80TgR20P2DKhP208V3PP80L9B80P1`UhL206nGQ`80NXb70P1jR8T2072@
R`80N9>40P1hVGl207BFQ080OIai0P1M[HD206RDSP80QHF30P1TOj420:NIF`80N9V00P1hWg`205bP
S`80AXf]0P2COGl2085oR`80I8jF0P1/OY/208j=M`80N7ZE0P26OXL206^7U@80LX2E0P1]OYX207N3
S`<0Q7b;0P2>P84208VQK@80M9B60P1hOi8206Z<T`80LYZ30P1/TXd207R4S`80K8ZB0P20UG`206UY
[@80M7bG0P1hW7d207F9S@80MWjD0P1mQ8X207B5T080NhZ70P1hSHP207R<R080NhJ;0P1mQXT207^6
R`80NhZ7101dSXX207^:Q`80N8V;0P1hS8T207R?QP80M8j:0P1hS8T@0?ooo`003P3oool207^7R@80
N8b90P1iS8P207R8S080NhZ70P1lQhT207R8S080OHj30P1bSH`207BBQ`80Lhn:0P1hS8T207^:Q`80
O8^60P1cSX/207R<R@80NhZ70P1dSXX207R?QP80N8b90P1dRh`207^:Q`80OHJ90P1mQHX207b:Q`80
MY:60P1aX7l207bSM@80RZ5/0P1mV7`207jHO0<0OImg0P1eWgd206VKR@80N9B30P1nSh82076JQ080
SjEU0P1^OYX207R2T080Pi5m0P1h<<X20:4D_`80OEnT0P1eRHd207B;S@80O8Z70P1hRH/207j9QP80
N8J=0P1nT84207B>RP80N8n60P1jR8X207j9QP80N8b90P20RHD20821R`80QX>40P20RX@207b<Q@80
O8B;0P25QH@208B5Q080UGen0P2>Pgh207FCQP80LYF70P1[Thd207RHP080KIB;0P1eUh<207^CP@80
Mi660P24WW<207RFPP80DWBe0P2HVfD204R2/`80]8AQ0P2KO7X208UfS080S8610P10V:X205V@W@80
UiMZ0P1JRJ4206:=V080QIYe0P1TQI`208B8PP80N86A0P1XS9D206NES`80HhfG0`1gRhX208BBN`80
XHY[0P1jPhh206jAS080L8^?0P1lS8H2071mV@80MhB?0P1hS8P207Z0S`80GG^Y0P1gUh8207^<Q`80
LGnF0P1fRH`207F9S@80N8f80P1cShX207b=Q@80M8Z=0P1hS8T207R?QP80M9680P1hS8T207^:Q`@0
M8j:101hS8T207^:Q`80N8V;0P1hS8T@0?ooo`003P3oool207^7R@80N8b90P1iS8P207R8S080NhZ7
0P1lQhT207R8S080OHj30P1bSH`207BBQ`80Lhn:0P1hS8T207^:Q`80O8^60P1cSX/207R<R@80NhZ7
0P1dSXX207R?QP80N8b90P1dRh`207^:Q`80OHJ90P1mQHX207b:Q`80MY:60P1aX7l207bSM@80RZ5/
0P1mV7`207jHO0<0OImg0P1eWgd206VKR@80N9B30P1nSh82076JQ080SjEU0P1^OYX207R2T080Pi5m
0P1h<<X20:4D_`80OEnT0P1eRHd207B;S@80O8Z70P1hRH/207j9QP80N8J=0P1nT84207B>RP80N8n6
0P1jR8X207j9QP80N8b90P20RHD20821R`80QX>40P20RX@207b<Q@80O8B;0P25QH@208B5Q080UGen
0P2>Pgh207FCQP80LYF70P1[Thd207RHP080KIB;0P1eUh<207^CP@80Mi660P24WW<207RFPP80DWBe
0P2HVfD204R2/`80]8AQ0P2KO7X208UfS080S8610P10V:X205V@W@80UiMZ0P1JRJ4206:=V080QIYe
0P1TQI`208B8PP80N86A0P1XS9D206NES`80HhfG0`1gRhX208BBN`80XHY[0P1jPhh206jAS080L8^?
0P1lS8H2071mV@80MhB?0P1hS8P207Z0S`80GG^Y0P1gUh8207^<Q`80LGnF0P1fRH`207F9S@80N8f8
0P1cShX207b=Q@80M8Z=0P1hS8T207R?QP80M9680P1hS8T207^:Q`@0M8j:101hS8T207^:Q`80N8V;
0P1hS8T@0?ooo`003P3oool207R<R@80NhZ70P1hRH/207R<R@80N9650P1bShX207R<R@80OHV70P1k
QX/207b7R@80N8R<0P1hS8T207RAQ@80Mi260P1hS8T207><S@@0NhZ70P1hRH/207^7R@80N8V;101h
S8T207R?QP80NI640P1kSh@208>FN080NYYm0P2=XFX207NGP@80PIIk0`25Sgd208J:O`80MhN=101h
TX@208>MM080PYMi0P1XQIX207BIP`80N6RR0P17AMl207J7SP80NY240P1bSH`407B>RP80NHb80P1h
RhT207V<R080OhR60P1nPX/207n8QP80M8j:0P1jT8@207R<R080N8^90P1hTHD207REPP80OXV60P22
PXP207b8R080OXZ50P23QX@208B5Q080Uh=g0P2;Ji8209B0O080KYB:0P1dThH207FAR080MIB50P1h
U8<207NKO`80PYIj0P1nS8@204En^080XX9`0P1TLZX208ZCMP80Y9EQ0P1YY8<207R?Q`80MV6Y0P1S
L:`20:1bO@80R5jM0P1hPY0208B1Q`80N8f80P1UTY8207b8R080L8RA0P1`RY0206:@UP<0JY>>0P24
Qh<209R@KP80PIIj0P1YRi@207:FQP80JY>>0P1WP9d207enSP80Q8:60P1`T8`205VGV080KXb@0P1n
NY4207V0T080NHV:0P1dR8h207b=Q@80M8Z=0P1kSXD207B;S0@0N8n6101hRH/207^:Q`80NhN90P1h
S8T207B>RP@0N8b90P1hShH207B>RQ00oooo000>0?ooo`80N8b90P1kRXL207R9R`80N8b90P1hTHD2
07:?RP80N8b90P1mRHL207^6R`80O8N90P1hR8`207R<R@80N9650P1gT8H207R<R@80Lhb=101kRXL2
07R9R`80NhN90P1hRH/407R<R@80N8n60P1iTH@207^?Q080PiIh0P1jVWd208fQJP80MiN10P21UW/3
08F?O@80QXYo0P1gQhd407RBQ080Pied0P22UgT206R5VP80M9V30P1hJ:8204M5g`80MXN>0P1jT8@2
07:=S0@0M8j:0P1iS8P207R;R@80NHb80P1oR8H207j2R`80OhR60P1dSXX207Z@Q080N8b80P1hRhT2
07RAQ@80N9F20P1nRHH208:2R080O8R80P1nRXD208>6Q080Q8F40P2GPgL208][TP80U81l0P1^U8X2
07BCQP80MI680P1eU8D207RDP`80Mi]o0P22UWX207j<Q080AGjh0P2RPW0206AbZP80RY=f0P2TUF42
06VTP`80N8n70P1fHJT206=`[080X79m0P28GYd207R2T080Q8670P1hSHP206FBTP80O8R80P1`R942
072:T080HY2F0`1ZThh208B7P`80V91^0P21UWX206V;U080LYJ60P1ZThh206N0W@80OGj>0P24PXH2
072@S080FINH0P1^S90207ijT@80NH2@0P1iRHX207B8SP80O8f50P1dRXd207^>Q@80M8^<101hShH4
07R9R`80NhZ70P1kQhT207R<R@80M8j:101hS8T207R?QP80M8j:403oool000h0oooo0P1bU8L207:?
RP80N8n60P1dSXX207f9Q`80N8N<0P1hTHD207>?RP80N8n60P1dTHP207B>RP80N8n60P1iSXH207R;
RP80NHf70P1cRXd407R?QP80M8n90P1cShX207R<R@80N9:40P1aT8/207^?Q080NHj60P1kU80208>G
N@80PYYg0P28WG4207f>P`80PIAk0`1mUWd207fLN@80JiR:0P1hVgh206jAS080T:9W0P1_TH`20727
TP80OWVA0P1M?M@207APZ`80LXf<0P1mRHH207R7S080N8b90P1dRhd207RCQ080L92;0P1hTh@2076G
QP80L8n<0P1oSh4207R<R@80NXf60P1hSHP207N=R@80OXV60P22PHP207j9QP80N8n60P1lRXL207f;
QP80O8Z60P22QhD208f1P080OX6<0P2GPgL208n4O@80L92<0P1gT8H207REPP80M9:70P23UGX207ND
Q080OJ1g0P0jT[<2071lVP80T9U]0P1JS9l20;mdI080YdbC0P2GL8D205F6Y`80IZ>60P1?Vid207nN
M`80IYJ?0P1bSh/208F3Q@80MWnC0P1bRhd207REPP80H8ZL0P1hTX@305b?W080NH6?0P2VTf4208JB
NP80JHNG0P1oQhL207AmUP80IhjD0P1SWH`207>IP`80N8F=0P1bLil2075mV080LXn;0P1bShX207J?
R080LI2;1P1hS8T207R9R`80Nhj50P1hS8T207B;S080N8n60P1dTHP207B>RP80Nhj5101dSXX207R?
QP80N8b90P1hRH/@0?ooo`003P3oool207:DQ`80LXn:0P1hShH207B>RP80OHV70P1hQh`207RAQ@80
Lhn:0P1hShH207BAR080M8j:0P1hShH207V>QP80N8^:0P1iSHL207>:S@@0N8n60P1dShT207>?RP80
N8b90P1hTX@2076@R`80Nhn40P1iSXH207^DP080PiMi0P22VWL208RML@80OHj30P21U7/307fFO@80
OIai0P1[V8X207RKOP80KY6<0P2@XVL206nAS080L8NB0P1nNI4205dme080M62[0P1bSH`207f9QP80
N8N<0P1hS8T207B;S@80N9>40P1`T8/207RCQ080LIN60P1`Sh`207n?P@80N8b90P1jSHH207R=R080
Mhf90P1nRHH208:1R080OXV60P1hShH207b:Q`80OH^60P1lRXH208:7Q@80SH600P1nPH`209N3M`80
ShAm0P1`T8`207N@QP80N9F20P1dTXL208>ENP80MiB40P1mX7L203ZB/`80L7bJ0P2@VFd205Z<W`80
_gAT0P2WC9<209M`Q@80EHJW0P1VXhH204nKW@80Oiig0P1VUXl207:?R`80QH>50P1fOi<207:;S@80
N9F20P1PRY`207RBQ0<0G8nL0P1iPHl20:JCH@80QY9j0P1YQiL207n7Q`80M7fF0P1WSY@206>MS080
LiV30P1hQHd2079cW`80LGfH0P1bSh/207:?RP80MXn80P1aT8/607R<R@80N8V;0P1kSXD207R<R@80
M8^<0P1hShH207BAR080M8j:0P1kSXD407B>RP80N8n60P1hS8T207R9Ra00oooo000>0?ooo`80NHZ9
0P1dRHd207^>Q@80M8^<101hS8T207b=Q@80M8f;0P1hS8T207^7R@80N8V;101kRXL207R<R@80NHR:
0P1hRhT207R<R@80NhN90P1lQhT207R8S080N8b90P1nRHH207R9R`80NIB10P1dTXL207nJN@80NYF1
0P2=WV`207jKN@80NYmj0P1gVWl3086EO080Pi1m0P1hQXd2086>P@80LIj10P25X74207=fV`80OgBD
0P1f=LL207Q5^P80MhV;0P1eRHd407R<R@80N8n60P1`TXX207VEPP80KYB;0P1eUh<207F@R080KYB;
0P1eUh<207FHPP80Ki^50P1`UXL2076@R`80Mi>40P1aU8P207fCP080N8b90P1hTX@207N@QP80NX^8
0P1lRXL208:7Q@80Q8J30P26QH<209aeOP80Tgin0P1cWH02076DR080N9F20P1jVGd207^GOP80PY5m
0P1DQJP2042D[@80Y8]X0P1VPi`207f6R@80V8a`0P27NXX208MZU@80P8J60P1PPZ8207j@P@80N8R;
0P1ZThh20729T080OJAd0P1EVYT2086=P@80HH>P0P1nTH0306::VP80Gj>;0P2@RWP20:UbMP80N926
0P1SUi0206b:T`80MI:60P1WSI@207N2T@80N7BJ0P1dLih207b:Q`80LHb>0P1fR8d207V=Q`80MHR>
0P1hS8T207R?QP80M8^<0P1hShH207R<R@80NhN9101hS8T207^:Q`80M8^<0P1kRXL207^7R@@0N8b9
0P1hRH/207R<RA00oooo000>0?ooo`80NHZ90P1dRHd207^>Q@80M8^<101hS8T207b=Q@80M8f;0P1h
S8T207^7R@80N8V;101kRXL207R<R@80NHR:0P1hRhT207R<R@80NhN90P1lQhT207R8S080N8b90P1n
RHH207R9R`80NIB10P1dTXL207nJN@80NYF10P2=WV`207jKN@80NYmj0P1gVWl3086EO080Pi1m0P1h
QXd2086>P@80LIj10P25X74207=fV`80OgBD0P1f=LL207Q5^P80MhV;0P1eRHd407R<R@80N8n60P1`
TXX207VEPP80KYB;0P1eUh<207F@R080KYB;0P1eUh<207FHPP80Ki^50P1`UXL2076@R`80Mi>40P1a
U8P207fCP080N8b90P1hTX@207N@QP80NX^80P1lRXL208:7Q@80Q8J30P26QH<209aeOP80Tgin0P1c
WH02076DR080N9F20P1jVGd207^GOP80PY5m0P1DQJP2042D[@80Y8]X0P1VPi`207f6R@80V8a`0P27
NXX208MZU@80P8J60P1PPZ8207j@P@80N8R;0P1ZThh20729T080OJAd0P1EVYT2086=P@80HH>P0P1n
TH0306::VP80Gj>;0P2@RWP20:UbMP80N9260P1SUi0206b:T`80MI:60P1WSI@207N2T@80N7BJ0P1d
Lih207b:Q`80LHb>0P1fR8d207V=Q`80MHR>0P1hS8T207R?QP80M8^<0P1hShH207R<R@80NhN9101h
S8T207^:Q`80M8^<0P1kRXL207^7R@@0N8b90P1hRH/207R<RA00oooo000>0?ooo`80NhN90P1hRH/2
07^>Q@80M8^<101hS8T207^>Q@80N8V;0P1hS8T607BAR080N8b90P1kQhT607R<R@80M9:70P1cU8L2
07:BR080M9680P1dSXX207^:Q`80PXf10P1hUX4207bHO080NYal0P27YfX207^NN@80OIUk0P1gVH03
07RON`80N9650P1hS8T207nVL@80L:200P1lSX@206JFS`80GDW<0P1h@k`207R7S080NXR:0P1eTHL2
07:EQ`80LY>80P1hTXD207BEQ@80LYb10P1]Wh<206VQQ@80JJB30P1VYH@206NUQ080KjAn0P1[VhP2
06fJQ`80Iin80P1]XH8206bFRP80Mi:50P1gSHP207j9QP80O8B;0P1mRhD207R=R080O8j40P1oSH<2
0827QP80PX680P2RMWT20:=[O`80Ph:80P20U7d207Z=Q`80QXem0P1nRHH206F<UP80Ai^R0P1TSiD2
09McP`80K8VC0P2JN7d208mJVP80Tgin0P26TgT205VJUP80JXBH0P2;Ph4207N0TP80L9f20P1oTGl2
06j0V080KXBF0P1hQX`2072@R`<0KhVA0P1ePI8207UmTP80X9IS0P2:OHD207i[W080NXF;0P1hUH82
06>8V`80JhNE0P1YMj<207V8R`80N8V;0P1kPHh207J<RP80NHf70P1aRXl407^:Q`80M8^<0P1kSh@2
07:?RP80M8j:0P1kSXD207B>RP80N8b90P1hRH/407R<R@80NhZ70P1hRH/207R<R@80N8n6403oool0
00h0oooo0P1kQhT207R9R`80Nhj50P1dRh`407R<R@80Nhj50P1hRH/207R<R@H0M9680P1hS8T207^7
R@H0N8b90P1dTXL207>DQ`80LY:80P1dTHP207B>RP80NhZ70P22SH4207RFP@80O9Ql0P1jW7`208NW
JP80Niii0P1mVG/207NIP0<0N9mk0P1hTHD207R<R@80OjIa0P1`X80207b>Q080IYJ?0P1MBL`207Q3
_080N8N<0P1jR8X207FAQ`80LYF70P1bThP207RBQ@80M9F50P1bW84206fOP`80JJ650P1YY8<206JU
Q080IjF40P1_Y7h206^KR080KIZ70P1WWhP206fQPP80K9J:0P1gTXD207N=R080OXV60P1lQ8/207f;
Q@80N8f80P1lSX@207n=P`80P8N60P22PHP20:9fN@80Xf]o0P23PXP2082DO@80NXf70P26SGd207j9
QP80IHbF0P17Vj8206B?U@80Ug>30P1/RI<209YhO@80SeZJ0P2COWh208JCN@80FIZF0P1ZQ9P208^3
P@80Mh2B0P1`WH8207nAO`80KX2H0P1^Q9H207R6S080L92;0`1_RI4207F1TP80NGfB0P2PUV<208Ym
Q@80OV^L0P1jQH/207REPP80HhRK0P1[QiD206UgX`80NHR;0P1hRH/207^1SP80MXb:0P1iSHL2076:
S`@0NhZ70P1dRh`207^?Q080LXn:0P1dSXX207^>Q@80M8j:0P1hS8T207R9R`@0N8b90P1kRXL207R9
R`80N8b90P1hShH@0?ooo`003P3oool207R<R@80N8n60P1hS8T207R9R`80N8b90P1hShH207R<R@80
N8V;0P1kRXL207^7R@80NhZ7101hRH/207R<R@80NhZ70P1hRH/207^>Q@80NHb80P1iRXT207R7S080
NhN90P1hS8T207BAR080OY:00P23TGd207b@P`80R9Qd0P29UW@208RFMP80NI250P26S7h308:CN`80
Ki6<0P1hTh@2092JK@80LhR?0P1lOY0208TSaP80MRS@0P1kQhT207J8S@80NXf60P1kSXD207R<R@80
MHj90P1gUH<207NJO`80M9R40P1gUh82076JQ080Kj21101ZX8D206jNP`80JYb70P1ZUh/207BFQ080
KiF90P1]TX`207:IQ080KI:<0P1gSHT207R<R@80OXj20P1hS8P207b>Q0@0O8^60P1hTX@207b?P`80
THAl0P2IRg4207jFO@80M9B60P1mUWd207RNO080H9VA0P1JRj02055n[`80Oiif0P1e[G<204N8/080
TY9a0P1jOY420;5^L`80Pg:B0P1MVI<206^>T@80PXJ50P25S7l207=kV080PHN50P1OPj4207n@P080
L86F0`1hS8T206:HT@80II:B0P2PR6d208QgR`80MhR<0P1mS8D20860RP80KgfI0P1/QYH205V5Y080
OXj20P1`QI<207V>QP80MXZ;0P1kQXX207R9R`80M8j:0P1kRXL207R>Q`80N8b90P1kQX/207R9R`80
Nhj5101hRH/207R?QP80M8j:201hS8T207^:Qa00oooo000>0?ooo`80N8b90P1hShH207R<R@80N8V;
0P1hS8T207R?QP80N8b90P1hRH/207^:Q`80NhN90P1kRXL407R9R`80N8b90P1kRXL207R9R`80Nhj5
0P1iS8P207V:R@80N8N<0P1kQhT207R<R@80M9680P1nTX0208>AO@80O9230P28V7@208VFM080R9If
0P1iT8D208J<OP<0PY=k0P1_TH`207RCQ080T9Y]0P1cR8l207anT080RB?60P1f:=0207^7R@80MXR=
0P1jSHH207^>Q@80N8b90P1eSXT207NEP`80MiYo0P1dV8@207NGPP80LIZ40P1_X84406ZPQ@80KYj3
0P1ZW8L206ZGR`80M9J40P1_UHT206fBS080LYV40P1]TX`207N=R@80N8b90P1nSX8207R<R080O8j4
101lRhH207RBQ080O8n30P2AQ7`209V;L@80OYIm0P1dU8H207fFO@80N9il0P1PVI4205Z;X080DGj_
0P1oWWH207F]L`80AhR`0P2BTW4207YnT@80/Fic0P23LY8205fIT`80JhjA0P22QXD208F<O`80Lg^H
0P21QhD205n3X@80Oi200P1`PIH307R<R@80HYRA0P1UTY820:28K@80R7N;0P1gR8`207f<Q@80PH2:
0P1_OIT206b6UP80FHFT0P1nSX820725T`80NHj60P1fRX/207^6RP80N8V;0P1dSXX207^:Q`80N8j7
0P1hS8T207^6R`80N8V;0P1kSXD407R9R`80N8n60P1dSXX807R<R@80NhZ7403oool000h0oooo0P1h
S8T207^>Q@80M8^<0P1hS8T207R?QP80N8b90P1hRH/607R<R@80Nhj50P1dRh`807R<R@@0NhZ70P1h
SHP207>@R@80Lhn:0P1kSXD207R?Q`80Ni]l0P1hVgh207Z@Q080S9i/0P1mZ74207bNN@80MiZ00P1c
Uh@308^BMP80LI:90P1dYGX207bJO080N8J=0P1]Qi@201mZh`80M8b;0P1dTXL207:CR080M9>60P1h
ShH207R=R080N9B30P1e]f`205W8MP80D[V50P1S[gl206RSQ080LYZ41P1bUHL207:TO080F;:60P1L
^7h205RfP`80E:FB0P1aT8/207:<S@80LXn;0P1gSHT207f:QP80OXV60P1lRXL207f9QP80OXf3101n
RHH2086?O`80VW]k0P2WOfl207REPP80N9]n0P21UgX206J=U@80EhfQ0P17VJ@207R6S@80ZFUm0P1O
NZP207j6R080QgN<0P29OHH20:9WP`80TV^<0P1]S902072ER080Q7n90P1hTX@206bPP`80Fi:J0P1b
Sh/206nFR0<0JY:?0P1iPhh206J:U`80Q8Z10P2>RgT207R4SP80PXb10P1`SXd206inV@80MW^F0P1V
R9P206fAS@80LX^=0P1hTHD2076@R`80LI6:0P1fSHT207R>Q`80LY:80P1iRhP207R;RP80M8j:0P1h
S8T207^:Q`80N8b90P1dSXX207^:Q`80N8b90P1dSXX207R<R@80N8n60P1dSXX207R<RA00oooo000>
0?ooo`80N8b90P1kSXD207B;S080N8b90P1hShH207R<R@80N8V;1P1hS8T207^>Q@80M8^<201hS8T4
07^:Q`80N8f80P1cT8T207>?RP80Nhj50P1hShL207^KO080N9]n0P1jT8@208bNK080OJQa0P1lWWT2
07NJP080LiN40`2;TWH2076BR@80M:Ej0P1lVW`207R6S@80KHND0P0OJ^<207B<R`80M9:70P1bThP2
07BCQP80N8n60P1hSHP207RDP`80MKM/0P1Ib7H205:iQ@80Hjmo0P1XXh@207:JQ0H0LYF70P1bY7`2
05RbQP80G;Qn0P1H]X<205BUTP80LI2;0P1bS8d207:?R`80Mhf90P1mRXH207j9QP80O8Z70P1mRHH2
07j=P`@0OXV60P21Sgl209YkN`80Ygm_0P1hUH8207RKOP80PIMj0P1VSID205N=X@80AiVT0P1hQXd2
0:UYO@80GgZX0P1nQXP208MgS080RGf60P2RIh<2099[S080KHb@0P1`UHP208AoR@80N9:40P1/X8<2
05^BVP80LXn;0P1_UXP306ZBS`80NH>>0P1VRYL208B:P@80SX]i0P1hQ8h208:<P@80L8j=0P1^OYT2
07IkUP80IXRH0P1]THd207:;S@80N9650P1aT8/2076ARP80MXf90P1hSXL207:BR080NH^80P1hRhX2
07B>RP80N8b90P1kRXL207R<R@80M8j:0P1kRXL207R<R@80M8j:0P1hS8T207R?QP80M8j:0P1hS8T@
0?ooo`003P3oool207R<R@80Nhj50P1dRh`207R?QP@0N8b90P1dSXX607R<R@80Nhj50P1dRh`207R<
R@80N8n60P1dTXL207>?RP80N8b90P1kSXD207V8RP80O8F:0P1hS8T207J=R@80OXn20P23T7h20868
Q@80OIih0P23ZF`208RKLP80NYQo0P1lUGh207>DQP<0OYmg0P1fSHT208Z9O@80OXV60P1ePi4207P]
c080O3O21P1hSHP207N9R`80NhZ70P1hZ7@206:iN@80P:9c0P28O8P207aHZP80XUR>0P2DLhD207j3
RP80OWRC0P2;J9@209AmOP80R8B20P28NHX208=lR`80PX>70P1RV94205BOUP80KI:<101bSh/207R<
R@80OXj30P1hS8P207b:Q`80PXR30P1lRXL207j?PP80P8Z30P1oRHD20:IkLP80ZG=e0P26TG/207bB
P@80Ki6<0P1DRZ@205jgOP808I[00P2@MXH2096DL080AI6[0P27XFh2062=VP80QWf90P2EPWT208J0
QP80N7RG0P1oWWL207B@R@80Q7^;0P1^Q9H206Z>TP80OXj20`1WR9P206nBR`80K8NE0P1hQXd209FI
JP80IjF40P1/XH820729T080Hi2F0P1SP:42089gT080MgnB0P1hRH/207^>Q@80LhFA0P1lQ8/207R=
R080N8n60P1hRhX207B;S080Nhj50P1dRh`207R?QP80M9680P1hS8T207R9R`80N8n60P1hS8T207R9
R`@0N8n60P1dRh`207R?QQ00oooo000>0?ooo`80N8b90P1kSXD207B;S080N8n6101hS8T207B>RPH0
N8b90P1kSXD207B;S080N8b90P1hShH207BBQ`80Lhn:0P1hS8T207^>Q@80NHR:0P1lQHX207R<R@80
MXf90P1nSh8208>@OP80PHR50P1mWWP208>YK080R9]b0P1jV7l207bEOP80LiB60`1nWgL207J=R@80
RXUm0P1nRHH207F3T@80N2g<0P1l=l8607R=R080MhV;0P1kRXL207RXM080H[Ui0P20XW<208QlR080
O5RZ0P2RF8h209AcQ@80OX>:0P1nN9<208]XU080U7en0P28Q88208QiRP80Pgb;0P22PhL206:HT@80
E9nF0P1]TX`407:?R`80N8b90P1nSX<207R<R080O8Z70P22R8<207b:Q`80OXn20P20RX<207n9Q@80
YW]b0P2YLgD208JAN`80O9:10P1_TH`205B:Y080G[Mn0P0QV/02091fQP80TIA`0P15TJ/208NQKP80
H8fJ0P26OHT209F2N@80QX260P1hN9L207nNM`80M9290P24Nh/206j4UP80JXjB0P1nSX8306N8V080
Ki:;0P1/QiD207R6S@80UIUZ0P1WYH@206bQPP80L8V@0P1ST9H206>0X@80PWN@0P1gOi8207R9R`80
Nhj50P1cQI4207b4R`80N8f80P1hShH207R;RP80M8^<0P1kSXD207B;S080N8n60P1dTHP207R<R@80
N8V;0P1hShH207R<R@80N8V;101hShH207B;S080N8n6403oool000h0oooo0P1dTHP<07R<R@80M8j:
0P1hShH207BAR0@0N8b90P1dTHP207R?QP80NHb80P1dSH/207BAR080N9650P1cS8d207R<R@80O8n3
0P1bRhh208:JN080M9mn0P1a[GH207NdK@80N:If0P20VWT208:PL`80Jif60P1hVWl307b:Q`80OYeh
0P1WYX<207RBQ080K6>^0P11DmX207^;Q`80O8N90P1lRXL207R<R080M8j:0P1gT8H209JRHP80LiB6
0P1hS8T207R@QP80CZ^C0P1CbWP206VfMP80JIZ:0P1UZh4204_4PP80IlM[0P1M[h@206F[P@80Ih^F
0P2:R7h207b:Q`80HZ6:0P19X9d207:=S080M8V=0P1gSHT207f:QP80OXB:0P1nRHH207f?P`80O8j4
0P1nRHH20867Q@80PHF70P29Q8420:IiL`80/7Q]0P25NH`208V?N@80BiRR0P21PXT2049[b080FZR;
0P2JVVD205N4Y`80PHR40P1jQ8d205nEU080T6Z>0P2WLgL2072KP`80PXmn0P1hMiP207nINP80HiN@
0P1XSY<207N=R@<0Kh^?0P1^TX`206:<V@80LXn:0P2FUfX208R3P`80N7fC0P1eSXT206N=U080DGf`
0P1hS8T207B9SP80NHj60P1hShH206j8T`80N8b90P1mRHL207^6R`80NhN90P1hRH/207^:Q`@0N8b9
0P1kQhT207R9R`80N8b90P1kRXL207R9R`80N8b90P1kRXL207^7R@80N8V;0P1kRXL@0?ooo`003P3o
ool207BAR0`0N8b90P1dSXX207R?QP80M968101hS8T207BAR080N8n60P1iS8P207B=R`80M9680P1h
THD207><S@80N8b90P1lSh<207:;SP80PYYh0P1dWgh2076]MP80MkA]0P1hYWH2082JN@80PZ1c0P1[
WHH207RJO`<0O8Z70P1nWGP206NVP`80N9:40P1/Hjh2045CfP80Nh^70P1lQhT207b:Q`80N8b80P1d
SXX207N@QP80UZ9R0P1cU8H207R<R@80N9260P1>Zi<205?:N080JKIf0P1YVXX206F[P@80BlB20P1W
af/205f_Q080IJ^10P1WRiH208Z8OP80O8Z70P1RXHX204VPW@80LXf<0P1dRHd207N=R@80OHZ60P1n
Q8X207j9QP80OHn30P1lSX@207j9QP80PHN50P21QHL208V4P@80YWUc0P2`N6d208EiS080RHmi0P1;
V:820862R@80@V_80P1JZ8/209ZJI@80EhBW0P21R8@207Z4S@80GiFD0P2@JXh20:McM`80L9^30P22
Sgh207QgV080OiUj0P1SUi0206R>T`80Mhf90`1_Rhl206jBS080HXbI0P1bShX209JGJP80R8>30P1h
OI<207F>R@80IhfD0P1AOK0207R<R@80M8V>0P1iSXH207R?QP80KXRC0P1hS8T207f9Q`80NhJ;0P1k
QhT207R9R`80NhZ7101hS8T207^7R@80N8V;0P1hS8T207^:Q`80N8V;0P1hS8T207^:Q`80NhN90P1h
RH/207^:Qa00oooo000>0?ooo`80NhN90P1hRH/207^:Q`80N8V;0P1kSXD207B>RP@0N8b90P1hShH2
07R<R@80M8^<0P1kSXD407R<R@80N8V;0P1kQhT207^:Q`80NHb80P1dRXd207R?QP80NHj60P1dS8/2
08VGM080OYEm0P27Wg0207nGN`80PiYf0P1eY7X208>RL@80Kh^@0P20TWh306fUP080OIUk0P1oPhX2
07=hVP80GCWG0P1hFJ`207R<R0@0N9260P1hS8P207RXM@80FKil0P1l_V8206>lMP80BlYo0P1C_X42
05nXQ`80JjUm0P1O[h8205N^R@80KK9f0P1U/Gd206FkM@80E[>70P1MZhH204S8PP80AmEj0P1G_gd2
066oMP80<k^K0P0k^YH205jGU0@0N8b9101hTXD207f9QP80PX^20P1hS8T207j9QP80OH>;0P28S7`2
08J<OP80ZHAY0P2@UG0207^SMP80HH2R0P1OS9/204bUV080CIjL0P21Nhd208^IL@80?iVZ0P2=Wf`2
05J?X080FI>K0P2KNW/20;AUM`80PW:C0P22UgX207V<R080Ogj=0P1WS9D207:DQ`<0K:630P1PTIL2
06Z0V`80MXf90P2@PWd2099lP080NWbB0P29Ph8206elV`80F82Y0P1aS8h207J>R@80Mhj80P1kQ8/2
07B;S080LI2;0P1hS8T207R?QP80M8j:0P1hShH207B>RP80NhZ70P1hRH/:07R<R@80N8n60P1dSXX2
07R?QP80M8j:0P1hS8T@0?ooo`003P3oool207^7R@80N8V;0P1kRXL207R9R`80Nhj50P1dSXX407R<
R@80N8n60P1hS8T207B;S080Nhj5101hS8T207R9R`80NhN90P1kRXL207V<R080M8Z=0P1hShH207V>
QP80M8b;0P29Ug@207jEO@80Qim`0P1oUg/208>JMP80MJAj0P23XW4206n;T080P99n0`1]YH0207fI
N`80Oh>:0P1cN9X205die`80N5V/0P1hS8P407R@QP80N8b80P1hZ7D205VnO080O;iR0P1S_7H204_:
O`80Dkj10P1OZ8L206^YO@80Gjn20P1G[XT206fbMP80IK5m0P1U^gD205JcQ`80GJ^60P18b88204OE
NP80Ekmm0P1Q_gH203>kV`80>kZF0P1NUi@407R<R@@0N9:50P1mRHH208:;PP80N8b90P1nRHH207f3
R`80R8al0P26S7h20:V4J@80T9E`0P1kXgH20660XP80GhbK0P1<YIP204fNW080PG^=0P2;VG4203nI
ZP80SIm/0P1FSj0205VCV`80VgYk0P2dIGL2089bT`80PYMj0P1iS8P207mnS@80IhbE0P1bU8L306bQ
P`80H96G0P1ZP9/207J=R@80T89m0P2BO80207YlTP80RH>20P1]O9/205R0Z@80LHb>0P1fSXT207N>
R080NhB;0P1dRh`2076@R`80N8b90P1hShH207B>RP80N8n60P1dSXX207^:Q`80N8V;2P1hS8T207R?
QP80M8j:0P1hShH207B>RP80N8b9403oool000h0oooo1P1dTHP207B>RP@0NhZ70P1dSXX207R<R@80
NhZ70P1hRH/407R<R@80NhZ70P1hRH/207R<R@80M9680P1hShH207R<R@80M8j:0P1hTHD207J=R@80
N9:40P23UgT208BEN@80Rim]0P1gXWX207fZK`80N:Ig0P1hTHD207N=R080NIMo0`27QX4207alT@80
Qh640P1Y;mH207Q1_@80N9260P1dShT207b8R080OHV60P1hS8P209J4N080U66B0P2aJ7L20:]YN`80
UF>@0P28Lhh207InU080R8F10P22N902089]U`80UWR00P2>MHP209YVRP80TUnE0P2:JY<209eWQP80
SD6]0P2a>9T20;`^V080[2bU0P2;C:L2079hW080N8b90P1hT8H207Z?Q@80NX^80P1hRXX208B9P@80
OXV60P1hS8P207R<R@80QhYo0P29Ph8209V3MP80]hAO0P2?Pgh205fJT`80Dj>D0P1NSiX205>@XP80
DI>P0P2YOVh206^9U@80JYR:0P1gSHT204^AY`80KI:<0P2COGl209j>J`80NiB10P1hO9@207n?P@80
KXRC0P1fSHT3086BO@80Eh2Z0P1/Thd206ZBSP80NhJ:0P2BUfd206N=U080PXio0P1YLZL207=aW`80
M8R>0P1hT8H207>>RP80L8f=0P1kRhL207B;S080M9680P1hS8T207R9R`80NhZ70P1hRH/207R?QP80
M8j:0P1hS8T207R?QP80M8j:0P1hS8T207R?QP80N8b90P1hRH/207^>Q@80M8^<0P1hS8T@0?ooo`00
3P3oool607BAR080M8j:101kRXL207B>RP80N8b90P1kRXL207R9R`@0N8b90P1kRXL207R9R`80N8b9
0P1dTHP207R?QP80N8b90P1dSXX207RAQ@80MXf90P1hTX@208>GN@80Q9Ei0P2;Wfd207NRNP80OJY_
0P1hYWL207RAQ@80Mhf80P1iUgl308N6P@80O7bA0P27PH@206T_eP80N46m0P1hT8H207B?R@80O8R8
0P1mRHH207R<R080UXAh0P2DHI820;5XM`80ZfUk0P2EHi0208QcSP80MWjD0P28QH42089hT080PVfG
0P2FN80208ieR080VVJ:0P2BGiD208YZT`80WFN60P2=@Jd20;4hV@80_2jH0P2/;:D208]<Y`80LWRL
0P1hS8T207R@QP80NXn50P1jRhP207R:RP80Q8V10P1nRHH207R<R080N8b90P27RWl208V3PP80VH=f
0P2gQ5l208n3OP80GIZC0P1CXi@205j?VP80Di2R0P1ATj020:UnKP80JhVE0P1ZV8X207N=R@80Bi6W
0P1]TX`209=mO`80WXi[0P1kU84207QlU080Ohn10P1^R9<207J=R@<0PI9m0P1GP:X206bCS@80JY:>
0P1kQXX209:GK@80IhfD0P22SWl206UbY`80Lg6O0P1dR8h207R@QP80Lhj:0P1`SHd207^;Q`80M8^<
0P1dTHP207R<R@80N8V;0P1kRXL207R9R`80N8n60P1dSXX207R<R@80N8n60P1dSXX207R<R@80N8n6
0P1hS8T207R9R`80Nhj50P1dRh`207R<RA00oooo000>0?ooo`80NhN90P1kRXL207R<R@80M8^<0P1h
ShH207R<R@80NhN90P1hRH/207^>Q@80M8^<0P1kSXD207B;S080NhZ70P1hRH/207^:Q`80NhN90P1k
S8H207J:R`80NhZ70P1iSXH207F>RP80OI220P22UgT208>OL`80RJIY0P1lY7@207fFO@80RhMm0P1h
SHP207RFPP80NY>20`1bShX207R>Q`80MhN=0P0OI>P207NAQP80Mhf80P1hRXX207FAQ`80N8j70P1l
RhL20824R080O7f@0P2LLgl20:m:SP80]cFG0P2l=Y820:diV`80/c:K0P2g=9P20:56V`80/d6A0P2i
:Id20;d`UP80]3FI0P2c>iD20:e3U@80RE:U0P28Lhh208AkS080OWn>0P1nPh/207R6S080N8b90P1l
RXL207b9Q`80NXf60P1fSHT207b@P`@0OXV60P1hS8P207f?P`80PHN50P2CQGT20:b5IP80Y7eb0P26
Rgh205U`]080N82A0P1JW9@204FWW080GZN90P2?WfT204j?YP80OjQ_0P10Xj8205:PU`80KI:=0P2Z
Sf0208Q^TP80PXF60P21TWd206VHR`80JIB>0`21P8X206UnW@80Kij20P1LSi`207>:S@80VYAY0P1]
SI0207FPO080B82d0P1aQY8207N=R080N8b90P1hS8P20726TP@0NhN90P1kRXL207B;S0H0N8b90P1k
RXL207R9R`80N8n6101hS8T207B>RP80NhZ70P1hRH/207R?QP80N8b90P1hRH/207R<RA00oooo000>
0?ooo`80NhN90P1kRXL207R<R@80M8^<0P1hShH207R<R@80NhN90P1hRH/207^>Q@80M8^<0P1kSXD2
07B;S080NhZ70P1hRH/207^:Q`80NhN90P1kS8H207J:R`80NhZ70P1iSXH207F>RP80OI220P22UgT2
08>OL`80RJIY0P1lY7@207fFO@80RhMm0P1hSHP207RFPP80NY>20`1bShX207R>Q`80MhN=0P0OI>P2
07NAQP80Mhf80P1hRXX207FAQ`80N8j70P1lRhL20824R080O7f@0P2LLgl20:m:SP80]cFG0P2l=Y82
0:diV`80/c:K0P2g=9P20:56V`80/d6A0P2i:Id20;d`UP80]3FI0P2c>iD20:e3U@80RE:U0P28Lhh2
08AkS080OWn>0P1nPh/207R6S080N8b90P1lRXL207b9Q`80NXf60P1fSHT207b@P`@0OXV60P1hS8P2
07f?P`80PHN50P2CQGT20:b5IP80Y7eb0P26Rgh205U`]080N82A0P1JW9@204FWW080GZN90P2?WfT2
04j?YP80OjQ_0P10Xj8205:PU`80KI:=0P2ZSf0208Q^TP80PXF60P21TWd206VHR`80JIB>0`21P8X2
06UnW@80Kij20P1LSi`207>:S@80VYAY0P1]SI0207FPO080B82d0P1aQY8207N=R080N8b90P1hS8P2
0726TP@0NhN90P1kRXL207B;S0H0N8b90P1kRXL207R9R`80N8n6101hS8T207B>RP80NhZ70P1hRH/2
07R?QP80N8b90P1hRH/207R<RA00oooo000>0?ooo`80M9680P1hS8T207^7R@80N8V;0P1kRXL207R9
R`80N8n60P1dSXX207^:Q`80N8V;0P1kSXD207B;S080N8n60P1dTHP207B>RP80N8b90P1lSHD207B>
RP80MY270P1kRhL207V?QP80N:Eg0P1cYWX208BTK`80R:MY0P1oWWH207:PO`80LJ1o0P1jU84207RN
O080KIB;0`1hQh`207Z?Q@80KDZo0P1VALP207b:Q`80N8R;0P1hSHL207Z9R@80NX^80P1hRXX207Z:
R080LXf<0P1hS8T207B;S@80NHn50P1mRHL208:2R080M8FA0P22TGh207R<R@80LXn;0P1^UhP207NO
O080KIb50P1cV8<207R@QP80Lh^<0P1kSXD207R9R`80O82>0P21QXD207R<R080MhV;0P1lRXL207b=
Q@@0NX^80P1lSX@207R<R@80OXn20P1hU88207FCQP80N8b90P29TgH209NAK@80WIQT0P29Rgd204ej
]P80N9650P1cJJD208=fT080I7ZT0P2PTFL205fPSP80JI2A0P1lMi@205F5Z080KY6<0P2=NhD209Ub
PP80SXYj0P24R88208AfS`80NX^80`1QXH/2062YQP80IY^;0P1LPJD207>:S@80U9E]0P1jPHl208f6
O@80B7300P1hQXd207RBQ080LI2;0P1hQh`207>5T@@0N8b90P1kSXD207B;S080N8b90P1hShH407BA
R080M8j:0P1kRXL207R9R`80NhZ70P1hRH/407R<R@80NhZ70P1hRH/207R<R@80N8n6403oool000h0
oooo0P1dTHP207R<R@80NhN90P1hRH/207^:Q`80N8V;0P1hShH207B>RP80NhZ70P1hRH/207^>Q@80
M8^<0P1hShH207BAR080M8j:0P1hS8T207b=Q@80M8j:0P1fT8L207^;Q`80NHn60P1hYGL207>VNP80
Q:A_0P28YfT207nNMP80LZ1o0P1aX7l207ZDP@80N9il0P1]U8/307R7S080NXn50P1]B[l206I5b080
O8Z70P1hR8/207R=Q`80NXV90P1jRhP207R:RP80NXZ80P1bSH`207R<R@80M8^=0P1iShD207f9Q`80
PX:80P1dQI4208:AOP80N8b90P1bSh/206jGR080Miml0P1]W8D207>HP`80N9260P1cRh`207^>Q@80
N8V;0P1lP8h20866Q@80N8b80P1gRH/207b:Q`80O8f5101jRhP207b>Q080N8b90P1nSh8207RDPP80
MI>60P1hS8T208VCMP80Ui5]0P2MV6@208V;O@80CGZf0P1hTHD207=YY@80PgJ@0P1TNZ@20:2AI`80
GJ2>0P1YT94207agU080EHFX0P1^TH`208ekQ@80VG:20P2>RWX208B8PP80Q7J?0P1jRhP3066QR`80
H:V60P1VVh/205b1Y@80LhZ=0P2DUFd207Z1S`80SHIm0P18L<0207R6S@80N9:40P1aT8/207R7S080
LhFA101hS8T207^>Q@80M8^<0P1hS8T207R?QP@0M9680P1dSXX207^:Q`80N8V;0P1kRXL207R9R`@0
N8b90P1kRXL207R9R`80N8b90P1hShH@0?ooo`003P3oool207R<R@80M8^<0P1hShH607BAR080N8b9
0P1hSHP207>?RP80N8b90P1kRXL207R9R`80Nhj50P1hRH/207R<R@80M8j:0P1kSXD207V<R080N8b9
0P1fSHT207j9QP80U8ec0P20XG<207ReJ`80OJi/0P1iTh<208ZBM`80M9:80P1hW7d207b<Q@80N7jC
0`1hS8T207b:Q`80:e_U0P1hO9@207R?QP80M8j:0P1iRXT207R<R@80NXj50P1dRHh207f;Q@80MXR=
0P1hS8T207B>RP80N9260P1dSXX207R@QP80M9290P1lTh0207R<R@@0Mhf80P21TGh207R9R`80NhJ;
0P1mRHL207B:S@80O8f50P1dQI0207R?QP80N8b90P22QhD207B=RP80N9>40P1hT8H207R9R`80OX^5
0P1lSX@207R@QP80NH^80P27QH8207f7R080N8b90P29Rg`209N8M080[89X0P2BLHP206ZIR@80BinL
0P1DWiH206:[P`80CjZB0P1hYGL208^2P@80FHJT0P1^X882056JW080G9:I0P1aTH/208BUKP80PXmo
0P28Q8<207><S080QYAh0`1cPI@2086;PP80HH>P0P1RRiX206JFS`80SY5d0P1gU8@207RDP`80BWbf
0P1]TXd207j:QP80N9650P1WRiH207R;R@80M8j:0P1hS8T207^>Q@80M8^<0P1hShH207R<R@@0NhN9
0P1hRH/207R?QP80M8j:101hS8T207R?QP80M9680P1dSXX407R<R@80NhZ7403oool000h0oooo0P1h
S8T207B;S080N8n61P1dTHP207R<R@80N8f80P1cShX207R<R@80NhZ70P1hRH/207^>Q@80N8V;0P1h
S8T207B>RP80Nhj50P1iS8P207R<R@80MXf90P1nRHH209B=L`80P:5c0P1h]F/207f^K080NI>30P2:
TWL207BBR080N9am0P1lS8D207QnT`<0N8b90P1lRXL202]Ki@80N7bD0P1hShH207B>RP80NHZ90P1h
S8T207Z>Q@80M8V>0P1mRhD207J8S@80N8b90P1dSXX207R@QP80M8j:0P1hT8H207B@R@80O9>00P1h
S8T407N=R080PI5n0P1hRH/207^6R`80OHV70P1dRXd207b=Q@80M8F@0P1hShH207R<R@80PXN50P1d
SHX207RCQ080N9260P1hRH/207j;Q@80O8j40P1hT8H207V;R080QhF20P1mQhP207R<R@80RH]l0P2G
R7@20:b2J080TW680P1ZVHT204^OW080E9nF0P1RZh<204nZTP80N:Eg0P2;PX4205V6Y080KZ220P1A
VY`205bBV@80LI6;0P24YFh208:?O`80R8B30P1cS8`208JDN0<0Lh6D0P21Rh820663X080HX^J0P1V
UXl208jAM080MiB40P1hU8<204Yl]P80KI:=0P1nRXH207RAQ@80Ih^F0P1hRhT207B>RP80N8b90P1k
SXD207B;S080N8n60P1hS8T407^7R@80N8V;0P1hShH207B>RP@0N8b90P1hShH207BAR080M8j:101h
S8T207^:Qa00oooo000>0?ooo`80NhN9101hS8T207^:Q`80N8b9101hRH/207b:Q`80N8^90P1dSXX4
07R<R@80NhZ70P1hRH/207^:Q`80N8V;101kRXL207V<R080N8b90P1fXgX207RXM@80TJ9V0P27W782
08FBNP80N9am0P1hUh4208:CO080N8n70P1hT8H206RESP<0N8Z:0P1jUX0200i^k@@0N8n60P1dRh`2
07J<RP80NhZ70P1kQhT207R<R@80MXf90P1hRhX407R<R@80N8j70P1fSHT207R<R@80NI640P1gTHH2
07RFPP80KY6<0P1hUH8207RJO`80Ki6;0P1bSh/207^?Q080Lhf;0P1iRXT207>6T@80PHj00P1`Shd2
07V;R080PWj;0P26QH<207b6RP80N8b80P1jShD207j=Q080O8Z70P1hSXL207RBQ080OI610P1eUX@2
07RDPP80SXeh0P2NSfX208FKM080PI1n0P1KNJ/20724U080MgjD0P1kPHh207AiV@80ShMk0P1ZVXT2
06:ZQ080DXnS0P1KXI0205N[R`80Ph290P2CL8P2092CLP80L8b>0P28VG<30626W`80S8610P1ZNJ02
072AS080HXbI0P25TWX208NHM080JGBU0P1_LJ<206f8U080N8^90P23QHD206j1V080N8b90P1hRH/2
07R<R@80NhZ70P1hRH/207^:Q`80N8b90P1dSXX407R<R@80Nhj50P1dRh`207R?QP80M8j:0P1kRXL2
07^7R@80N8V;1P1hS8T@0?ooo`003P3oool207^7R@@0N8b90P1kRXL207R<R@@0N8V;0P1lRXL207R;
R@80M8j:101hS8T207^:Q`80N8V;0P1kRXL207R9R`@0NhZ70P1iS8P207R<R@80MZ=j0P1hZ7D2096R
IP80Qiab0P25TWX207RLO@80N9N10P22Tg`207R?Q`80N9260P1XUHh307R:RP80NYJ00P0>K^d407R?
QP80M8^<0P1fS8X207^:Q`80NhN90P1hS8T207J=R@80N8^:101hS8T207R>Q`80MXf90P1hS8T207VA
Q080Mi660P1hUX8206jAS080N9F20P1hVWl206nAR`80LXn;0P1kSh@207>=R`80NHZ90P1cQY42086>
P080L8n=0P1iRhP2089nR`80QXF30P1lQXX207R<R080NXn50P1nSH@207b:Q`80N8j70P1hTX@207fA
P@80MIJ40P1hU88208j=N080WXmZ0P25Vg@2086@OP80FgV[0P1`Q9@207MnU080Nh6>0P1dNIT208n7
N`80JYZ90P1RZX@205:?X`80Fj6@0P1GZh/208>0R@80Tg280P2@Tg82072<SP80R9Uc0`1PQYl208b1
P@80JWVP0P1`TH`206:<V@80QI9j0P27V7@206UdY@80Kg6S0P1]R9@207R;R@80PhF50P1^PIP207R<
R@80N8V;0P1hS8T207^:Q`80N8V;0P1kRXL207R<R@80M8j:101hS8T207^>Q@80M8^<0P1hShH207B>
RP80NhZ70P1kQhT207R9R`H0N8b9403oool000h0oooo0P1hS8T207^:Q`80N8V;0P1kRXL207^7R@80
N8V;101hS8T207^:Q`80N8b90P1dSXX607R<R@80N8n6101dTHP207R<R@80NhN90P1lT8<208VLL080
NJAf0P23Xg0208bLKP80N9V00P29R7h207f<Q080PY=m0P1hPY0208N5PP80MgjC0`1fV88207QWX`80
A4_M0P1fT8L207R<R@80M8V=0P1hRhX407R<R@80NhN:0P1lQhT207R>Q`80MXf90P1hS8T207V;R080
N9260P1bUHL207RKOP80KZ610P1aXgh206>KSP80M9f00P1fUh8206fCR`80KIF:0P1dTXL207F>R@80
LXb=0P1cT8X207Z;R080P82;0P1hQ8h207RDP`80NI>30P1iRhP207b>Q080N8j70P1lT8<207R<R@80
OXn20P1hS8P20867Q@80QX:50P21S882082FN`80Uhi_0P2QPg02089gT080KHBF0P1MSiX206^LQP80
HY>D0P1YWHL207:HQ@80S99e0P1[SI4205JYSP80CI>T0P1kK9`2076ER080KjEn0P2CT74207R0T@80
UH]c0`1TRYT206jGR080JHVE0P1eSXT206:4W`80QHao0P2DS7@205E]^@80O8j30P1NRIh207j9QP80
N8>?0P1kPHh207R9R`H0N8b90P1hShH207B>RP80NhZ70P1hRH/407R<R@80NhZ70P1hS8T207R?QP80
M8^<0P1hS8T207R?QP80M8j:1P1hS8T@0?ooo`003P3oool207R<R@80NhZ70P1hRH/207^:Q`80NhN9
0P1hRH/407R<R@80NhZ70P1hS8T207B>RPH0N8b90P1hShH407BAR080N8b90P1kQhT207b@P`80RIa`
0P1iY7H208>SL080S9a^0P1hVH0208V8OP80OHb40P22Tgd207R2T080QhF20P1gOY<307JHPP80N6NS
0P14Bmd207J@Q`80N8b90P1dRHd207R;RP@0N8b90P1kQhX207b7R@80N8j70P1fSHT207R<R@80NH^8
0P1hT8H207:EQ`80N9]n0P1^XH42076SOP80Hi^>0P1dWH0207JGPP80KI>;0P1]UHX207BBQ`80MHj9
0P1bS8d207>@RP80NX^80P20P8/207R4SP80N9B30P1iTh<207V;R080O8j40P1hSXL207b@P`80N8b9
0P1nSh8207R<R080PHN50P26PXD2086<PP80P9Ik0P2GSVl20:63L080PWN@0P1]Q9H205f?VP80Jib6
0P1RTi@206VMQ`80LYR50P2<TWD206^=T@80EZV>0P1=Tj@207]/W080LIF80P1_YGh209>@L@80N82A
0P2ERg<306B:V@80KYN80P1YRID207F>R@80HXBO0P25S7l209B<M080EFfi0P1lSX<205j9WP80OXV6
0P1hPhl207^1SP80N8V;1P1hS8T207R?QP80M8j:0P1kRXL207R9R`@0N8b90P1kRXL207R<R@80N8n6
0P1dRh`207R<R@80N8n60P1dSXX607R<RA00oooo000>0?ooo`80M9680P1dSXX807R<R@80N8n60P1d
SXX407R?QP80M8^<0P1hS8T207R?QP80M8j:0P1kRXL207^7R@80Nhb60P1cS8d207R?QP80OXb40P2D
UFd208ZQK080N:Yc0P1oZ6l207NOO080JZ640P1mVWX207REPP80K9f50P1]TX`207R;R@<0PiEj0P0m
Cml207QPZ0@0N8^:0P1dRHd607R<R@80M8j:0P1hT8H207V>QP80MHb;101hS8T207f?P`80N9B30P1i
V7l207^;Q`80PXmo0P1/TXd207>EQP80N9J10P1]Th/206nAS080LY:90P1aT8/207:?R`80Lhj:0P1c
THT206nAS080Mhf80P20RHD20828QP80NHB=0P26Q8@207n8QP80OXV60P1lRXL207j?PP80N8b90P1h
S8P207fFO@80OI:10P28Qh02096=M@80UII/0P1eZgD205>^S080DIVL0P1`UHP20668W080OIeh0P1M
SI`209>;M@80N82A0P24UgL2035kbP80J:an0P1XZ842075bX080Xh9_0P1hS8T208N8P0<0Ph>60P1^
RI8206bES080J9Z;0P1KR:4207j;Q@80TWZ10P1RMZT207n<P`80IXVH0P1]YWl205j@V0X0N8b90P1k
SXD207B;S0X0N8b90P1kRXL207^7R@80N8V;0P1hS8T207^>Q@80M8^<1P1hS8T@0?ooo`003P3oool2
07BAR080M8j:201hS8T207R?QP80M8j:101hShH207B;S080N8b90P1hShH207B>RP80NhZ70P1kQhT2
07^<QP80Lhb=0P1hShH207j<Q080U9E]0P2:XF`207RZL`80OjQ_0P1gWg`206ZQQ080OIYj0P1hUH82
06bMQ@80KI:<0P1hRhT308>ENP80?DoO0P1hH:P407R;RP80M8V=1P1hS8T207B>RP80N9260P1iSXH2
07F<R`@0N8b90P1mSh<207RDP`80NIQo0P1kRhL208:?O`80K9:=0P1cUHH207RFP@80KI>;0P1_TH`2
07:BR@80LI2;0P1bSh/207>>RP80Li690P1_TH`207N=R080P8V50P20R8H207V4S@80QXB40P1oR8H2
07j9QP80O8Z70P1nSh8207R<R@80N8b80P1mUWd207fBP@80R8N00P2ASGD209FFK080MJ]e0P1C[X`2
056IW080L9F80P1QR9`207fMN080GHfL0P2CRgD207R0T@80Q9Mg0P0aNlX206R/OP80J:R10P1aLZ02
0:>2K`80N8b90P27R80308>3QP80KXVB0P1/UH`206RJR`80FhRQ0P1nRhD2099jP@80HWJY0P1oS8<2
06J9V080KJIo0P1NT9P:07R<R@80Nhj50P1dRh`:07R<R@80NhZ70P1kQhT207R9R`80N8b90P1kSXD2
07B;S0H0N8b9403oool000h0oooo0P1kQhT207R9R`P0N8b90P1kRXL407R<R@80NhN90P1hRH/207R?
QP80N8b90P1hRH/407R<R@80O8Z70P1hR8`207^:Q`80Ni230P2BYf8208VXJ080PZM^0P1hY7P207VH
O`80N9]n0P1/UXX208>;P@80OWj>0P1hPhl207JKO`<0N9el0P0<I?H207R=R0@0MHj90P1bS8d207R?
QP80M8Z=0P1lQXX207b:Q`80N8b90P1jRhP207R=R080M8^<0P1kZ7<205k6M080EijE0P26OHT208>2
R080RHUn0P1k[Vh204g:O@80Dk>80P1TUI4206n[N@80EJV>0P1VUHl2076?R`80LXJA0P20Q8T207R4
SP@0N8^90P20R8D207R<R@80N9F20P1lSh@207Z;Q`80OXf4101nRHH207R<R080QXYo0P21R8D2082F
N`80R95i0P2NRVd20:2<JP80KH6H0P1MTYP205nITP80GYVB0P1hV8020668W080O9:10P1lUWh207j5
R@80CINQ0P1G[hT206YkW`80HYRA0P1oW7P208j8N`80Li290`21Xg4205bKT`80L9V50P1XQYT2069n
X`80NHj60P1hLY/208Z=N`80G8^O0P23VWL206J2W@80N7FI2P1hS8T207^:Q`80N8V;4P1hS8T207^:
Q`80N8V;0P1hS8T207R?QP80M8j:403oool000h0oooo0P1kQhT207R9R`P0N8b90P1kRXL407R<R@80
NhN90P1hRH/207R?QP80N8b90P1hRH/407R<R@80O8Z70P1hR8`207^:Q`80Ni230P2BYf8208VXJ080
PZM^0P1hY7P207VHO`80N9]n0P1/UXX208>;P@80OWj>0P1hPhl207JKO`<0N9el0P0<I?H207R=R0@0
MHj90P1bS8d207R?QP80M8Z=0P1lQXX207b:Q`80N8b90P1jRhP207R=R080M8^<0P1kZ7<205k6M080
EijE0P26OHT208>2R080RHUn0P1k[Vh204g:O@80Dk>80P1TUI4206n[N@80EJV>0P1VUHl2076?R`80
LXJA0P20Q8T207R4SP@0N8^90P20R8D207R<R@80N9F20P1lSh@207Z;Q`80OXf4101nRHH207R<R080
QXYo0P21R8D2082FN`80R95i0P2NRVd20:2<JP80KH6H0P1MTYP205nITP80GYVB0P1hV8020668W080
O9:10P1lUWh207j5R@80CINQ0P1G[hT206YkW`80HYRA0P1oW7P208j8N`80Li290`21Xg4205bKT`80
L9V50P1XQYT2069nX`80NHj60P1hLY/208Z=N`80G8^O0P23VWL206J2W@80N7FI2P1hS8T207^:Q`80
N8V;4P1hS8T207^:Q`80N8V;0P1hS8T207R?QP80M8j:403oool000h0oooo101dTHP207B>RP80N8n6
0P1dTHP207B>RP80N8b90P1kRXL207R9R`80N8n60P1dTHP407R<R@80M8j:201hS8T207R?QP80OYQk
0P2G[UT208>ZJ`80QI]d0P24QHD208N:O`80PhZ10P1hS8T2076CR080M8Z=0P1iUX4207bJO0<0N7RG
0P0TE>l207Z<Q`80N8N<0P1lQH/207R3S`80OhR60P1dSXX2072@R`80O9620P1dSXX207R>Q`80NHb8
0P1eQhl209]nN080YEb90P1hI:D207Z9R@80PhJ40P2:QH020:e_M@80YdRF0P2BDIh2089YV@80X79l
0P1oO8l206>GT@80IXnC0P1^R9<207R;R@H0N8b90P1hU8<207R<R@80PH2:0P26Q8@207f:QP80OX^5
0P1lRXL207j?PP80N9:40P1hTXD2086@O`80R8R00P29QH4209V5M@80ZYMK0P1UUXl206BGT080GI:H
0P1WT982072;S`80K9J:0P1VTY8208jAM080IXnD0P1h^FT202mnb@80MXZ<0P1^XH4206N2W@80WIQT
0P1^Shh309BCK`80JXRF0P1bQY4206Z5V080FiBI0P1]SY0206:BU@80RJQX0P1@Vi`207R3S`80N6FT
0P1hShH207B>RPP0N8b90P1hShH207B>RPH0N8b90P1hShH207B>RPP0N8b90P1hShH207BAR080M8j:
0P1kRXL207R9Ra00oooo000>0?ooo`@0M9680P1dSXX207R?QP80M9680P1dSXX207R<R@80NhZ70P1h
RH/207R?QP80M968101hS8T207B>RPP0N8b90P1hShH207jHN`80UjiI0P23ZV/208FKM080Q8F50P27
RWl208>:P@80N8b90P1aThP207B:S@80NIJ10P1lVW`307QhU`8095C_0P1jS8L207R7S080O8F;0P1h
Phl207n8QP80M8j:0P1`T8/207bAPP80M8j:0P1hSXL207V<R080MHN?0P2KOWP20:ELR@80N6BU0P1j
RHT208>6Q080RXF00P2]KgD20:M8UP80TU6N0P22JIT20:1bO080Ogb?0P1SUi4206J?T`80KXRC0P1h
RhT607R<R@80N9B30P1hS8T20860RP80QXB40P1mRXH207j;Q@80O8Z70P1nSh8207RBQ080N9:50P21
T7l208R8P080RHF10P2IQGD20:ZGF`80IIJ?0P1TUi0205fBV080Ii2B0P1`Rhl206bFRP80IY:B0P2>
TG@206J?U080N;UY0P0_O/T207J:S080KZ610P1WPYd209fHI080KXn>0`2DTfl206Z8UP80LXJA0P1Z
QIP205^DV@80KHj@0P1RTYD208VXJ080D9^L0P1hPhl207QUY080N8n60P1dSXX807R<R@80N8n60P1d
SXX607R<R@80N8n60P1dSXX807R<R@80N8n60P1dTHP207B>RP80NhZ70P1hRH/@0?ooo`003P3oool4
07^7R@80N8V;0P1kRXL207^7R@80N8V;0P1hShH207B>RP80N8b90P1kSXD207R<R@80M8^<0P1kRXL2
07R9R`80N8b90P1hTHD207>?RP80N8b90P1kRXL208RDM`80XjME0P27YF`207RLO@80LjYg0P1/YH02
07N:R`80QXZ00P1gPY0207R6S@80QYUe0P1eUh<305]Z]P80@5oB0P1fS8X207J;R`80M9290P1`SHd2
07^;Q`80OhB80P1hQHd207n9Q@80NhN:0P1jRhP207R=R080L8b>0P1mTX0207R8S080OX6;0P1nPhX2
0867Q@80QHJ30P28Ph8207f6R@80NHV:0P1eShT207b?P`80SH610P1nNI4206f1V@80KhNC0P1hS8T2
07R:RP80NX^80P1hS8T20828Q@80N8b80P1`V8H207RCP`80OXZ5101nRHH208:;PP80P91o0P1eT8P2
07jAP080O9610P21U7`208J>O@80^:1;0P1`PiD207>>RP80Fh>T0P1cP9D207:2U080PiMi0P1FSZ02
08ZGL`80LHZ@0P2MUFH201mcg@80NZ1i0P1`OiL206]iW`80Y9iK0P1^R9<308n>MP80N82A0P1^R9<2
06b=T080IhFJ0P1XQIX207R<R@80RXQn0P1lMYD205ad[`80N8b90P1kSXD207B;S0P0N8b90P1kRXL2
07R9R`80N8n60P1dSXX207R<R@80NhZ70P1hRH/807R<R@@0NhZ70P1dRh`407R<RA00oooo000>0?oo
o`@0NhN90P1hRH/207^:Q`80NhN90P1hRH/207R?QP80M8j:0P1hS8T207^>Q@80N8b90P1dRh`207^:
Q`80N8V;0P1hS8T207RAQ@80Lhn:0P1hS8T207^:Q`80R9Ag0P2SYeD208NUK080N9am0P1cZWL206bU
P080MhZ;0P26RX0207N2T080N8J=0P26VGD207FGP`<0FfZf0P10Gm8207J<RP80MX^;0P1dT8T2072=
S@80Nh^70P1oQ8P207R5S@80OhV50P1kQhX207Z;R080N8f80P1`S8h207fBP080N8R<0P1nPH/207j3
RP80PHN50P25QX<208R3PP80OHJ90P1iRHX207F?R@80O8n30P2=PH4207iiT@80KH6I0P1_Qi<207R<
R@80N8Z:0P1jRhP207R<R@80P8R50P1hS8P2072HQP80N9>30P1nRXD407j9QP80PX^20P20T7l207F@
R080OY600P1lTH42086DO080QXim0P2hX4/20723U@80Lhj:0P1KPj@207>0U@80LX:D0P23UgT205J>
X080RYMc0P1aRY0209fEIP807g?M0P1jX7T2071oU`80JgVO0P2TWU/206j8T`<0Shif0P1hP94206j8
T`80K8f@0P1WQIX206R5VP80N8b90P2:R7h207afU@80G7B_0P1hS8T207^>Q@80M8^<201hS8T207^:
Q`80N8V;0P1hShH207B>RP80N8b90P1kRXL207R9R`P0N8b9101kRXL207B;S0@0N8b9403oool000h0
oooo1P1hS8T207R?QP80M8j:0P1hShH207R<R@80N8V;0P1hShH207R<R@80NhZ70P1dRh`207R<R@80
N9650P1cShX207b=Q@80M8f;0P1dSXX207R?QP80RIYb0P2U/4d208FUK@80MY:60P2@QgX207mnS@80
MHf:0P1mRXH207Z2SP80NHn50P29W70207F7SP<0AT7S0P1hFJ`207J6SP80NhN90P1kPh`207V5S@80
N8^90P1hSHP207N=R@80NHf70P1kRXP207b=Q@80N9:50P1^Ri420867Q@80NHB>0P1hQXd207j9QP80
OXn20P1kSHH208><P@80Oh^30P1gT8H207J?Q`80N8b80P1lSX@207R6S@80LXBC0P1_RI4207R<R@80
MHZ<0P1kSHH207R:RP80NX^80P20R8D20821R`80P8R60P1jRhP207j<Q080NX^80P22RX8208N4P`80
PhB60P21SH42086?P080PY1n0P21UG`20;:EE`80Ohn10P1YU8h205UnZ@80K:Qn0P1=Uj42092:M`80
IW^R0P2:WFl206JES`80T7mo0P1?LkT206RHS080HhFM0P1YUXd209F@L080QHF30`1mRHH20867Q@80
KI:<0P1XVH/205N>X080IhFJ0P1iUH4207B8S`80NV^N0P1dM9`207R<R@80NhZ70P1hRH/607R<R@80
N8n60P1dTHP207B>RP80NhZ70P1hRH/@07R<R@80NhZ70P1hRH/407R<RA00oooo000>0?ooo`H0N8b9
0P1hShH207B>RP80N8n60P1hS8T207R9R`80N8n60P1hS8T207^:Q`80M8^<0P1hS8T207RAQ@80Lhn:
0P1lSHD207B=R`80M8j:0P1hShH208VJLP80YK1=0P25YFd207JBQP80T8Mj0P1oOXd207F=RP80OHZ6
0P1jPXh207V?Q@80RIa`0P1eQhh304I1h`80N5V/0P1fQXh207^7R@80Nh><0P1iQHd207R;R@80N8f8
0P1gSHT207V=Q`80NhZ80P1lSHD207RBQ@80KX^A0P21QhD207V4SP80N8J=0P1nRHH207j?PP80Nhf6
0P23S84207n;P`80Mi260P1fShL207R<R080O8j40P1hQXd207:4T`80KhVA0P1hS8T207F:S080Nhf6
0P1hRXX207Z;R080P8R50P20PH/20828QP80NX^80P1nS8@207Z;R080PXZ20P27Q8<208>4QP80PHf1
0P21Sh0208:@OP80PIEl0P2bUEL207n?P@80JIB>0P1IOZT206bXOP80CINQ0P2@RWL206IkXP80RYe_
0P1VUHl2091oO`80Cg>i0P1XV8`206>5W@80JIJ=0P2ET70208F5P`<0OHV60P21QhD206fBS080J9V;
0P1GSZ0206N5VP80NIF10P1dR8l207Y[WP80M7BL0P1hS8T207^:Q`80N8V;1P1hS8T207R?QP80M968
0P1dSXX207^:Q`80N8V;401hS8T207^:Q`80N8V;101hS8T@0?ooo`003P3oool607R<R@80NhZ70P1h
RH/207^:Q`80N8V;101hShH207B;S080Nhj5101dSXX207b:Q`80N8^90P1hS8T207^7R@80N8V;0P1k
Sh@208bjF@80SLI@0P1mUWh207fPM`80IZJ30P1bVH<207:?RP80MX^;0P1fShP207b[L080LJ200P1a
UXL3001/n@80MhV;0P1dRXd207N@Q`80L8b>0P1hS8T207R=R080N8b90P1hRhT207V<R080N8^90P1o
R8H208:4Q`80M8V>0P1dUHD2076ARP80LI2;0P1hTX@207j<Q080OH^50P1nUWd207RKOP80LiF60P1c
SX/207RBQ@80Mhb90P1fPi0207J0T`80N8B?0P1hRhT207F:S080O8R90P1kRXL207R>Q`80N8b80P1h
S8T20828Q@80P8R60P1mSh<207R<R080OX^50P20R8D208B8PP80QXam0P21T7l208:<P@80RhEo0P2X
P6d20:^6IP80J8NH0P1GSZ02089jSP80KGFQ0P1hTX@206b7U@80SYM`0P1bQY42076FQP80EhnO0P1R
RiT2066CU@80Jhj@0P23N8l20:F>I@<0JIB>0P1mVgX206j<T080N7jC0P1XJj`2079nUP80Pj1a0P1E
TIl205n2XP80N8b90P1dSXX207R?QP@0M9680P1dSXX207R<R@@0NhZ70P1dRh`@07R<R@80N8n60P1d
SXX807R<RA00oooo000>0?ooo`H0N8b90P1kRXL207R9R`80NhZ70P1hRH/407R?QP80M8^<0P1kSXD4
07B>RP80O8Z70P1hRhT207R<R@80NhN90P1hRH/207^?Q080S;YI0P2=aU0207fFOP80OJ1g0P1VYX<2
07:IP`80LXn:0P1fRh/207J?R080O:]`0P1aX802076FQ`<006ci0P1gRH/207B:S@80Mi270P1`S8h2
07R<R@80N8f80P1hS8T207R;R@80NHb80P1hRhT207n8QP80PXB70P1dRHh207BEQ@80LI6:0P1aT8/2
07RBQ080OXb40P1mRhD207jFO@80N9]n0P1cUHH207>>R`80N9:50P1gS8T207J3T080MX2C0P1hQ8l2
07R;R@80MHZ<0P1lR8T207^:Q`80N8j70P1hS8P207R<R@80P8R50P20R8H207f?P`80N8b80P1nRhD2
0828Q@80Q8R20P26S7d2086@O`80PXb10P2;QGl20:R0K@80ZhIV0P1XQiP205N>X080PWZ>0P1]MJ42
07RBQ080K8NE0P2>Ug0207:6T@80LIJ60P1GSil206:;V@80HI>E0P1[SY0208=hS`80YHiU0`1YU8h2
07fKNP80KXb@0P1hOY<206Q[[080LWjF0P23X74205FAW`80Gh:R0P1hS8T207B>RP80N8n6101dTHP2
07B>RP80N8b9101kRXL207B;S100N8b90P1hShH207B>RPP0N8b9403oool000h0oooo101dTHP207B>
RP@0N8b90P1hShH207B>RP80NhZ70P1kQhT207R9R`80NhZ70P1kQhT207R<R@80M8j:0P1kSXD207B;
S0@0N8b90P1lSh<20;>^A080T:1X0P1hVgh208FQL080LGnG0P24OhT207Z4S@80N8b90P1h/Vh2076V
N`80MH^<0P1jQ8`300mDo`80MHR=0P1iQHd207n4R080MhN=0P1gSXP207R=R080Mhf91P1gSXP207N=
R@80O8Z70P1lSHD207R=R080Lhj:0P1aSh`207VBQ080M9J40P1hVGl207fCP080Q8eo0P1gR8`207R8
S080OHV70P1hPI0207QmT`80N8>?101gSHT407B<R`80OHj30P1hRXX207^;Q`@0N8b90P20Sh0207f9
QP80OXV60P1jRhP207j>PP80OHV70P2=QWd208V3P@80QXYo0P20Sh02096ALP80ZiYH0P1`NY/206n4
U@80EYFK0P1/W8H206ZDS@80JiV90P1nR8L208F0R080OhR60P1QMjP206b0V@80L8RB0P1VQYX206eo
VP80]9ID0`1hS8T207bFOP80JXjB0P1TTY<204nCXP80II:B0P2CNh0207QI[@80M7BL0P1kRXL207R9
R`80NhZ7101kQhT207R9R`@0N8b90P1kRXL207R9R`H0N8b90P1hShH207B>RPH0N8b90P1kSXD407B>
RPH0N8b9403oool000h0oooo101dTHP207B>RP@0N8b90P1hShH207B>RP80NhZ70P1kQhT207R9R`80
NhZ70P1kQhT207R<R@80M8j:0P1kSXD207B;S0@0N8b90P1lSh<20;>^A080T:1X0P1hVgh208FQL080
LGnG0P24OhT207Z4S@80N8b90P1h/Vh2076VN`80MH^<0P1jQ8`300mDo`80MHR=0P1iQHd207n4R080
MhN=0P1gSXP207R=R080Mhf91P1gSXP207N=R@80O8Z70P1lSHD207R=R080Lhj:0P1aSh`207VBQ080
M9J40P1hVGl207fCP080Q8eo0P1gR8`207R8S080OHV70P1hPI0207QmT`80N8>?101gSHT407B<R`80
OHj30P1hRXX207^;Q`@0N8b90P20Sh0207f9QP80OXV60P1jRhP207j>PP80OHV70P2=QWd208V3P@80
QXYo0P20Sh02096ALP80ZiYH0P1`NY/206n4U@80EYFK0P1/W8H206ZDS@80JiV90P1nR8L208F0R080
OhR60P1QMjP206b0V@80L8RB0P1VQYX206eoVP80]9ID0`1hS8T207bFOP80JXjB0P1TTY<204nCXP80
II:B0P2CNh0207QI[@80M7BL0P1kRXL207R9R`80NhZ7101kQhT207R9R`@0N8b90P1kRXL207R9R`H0
N8b90P1hShH207B>RPH0N8b90P1kSXD407B>RPH0N8b9403oool000h0oooo101kQhT207R9R`80N8b9
0P1hShH207R<R@80N8V;201hS8T207R?QPP0N8b9101dTHP207V>QP80`:M00P2@Vf`208>GN080PhR3
0P1aOiL207bAPP80M9680P1hS8T20:2=J@80N8J=0P1eSXX206hgc0<0I3?G0P1fRH`207:<S@80NHf7
1P1hS8T207R7S0@0OHB:0P1mRHH207N<RP80N8b90P1oR8H207f6R@80Nhj50P1^RY4207n8QP80PHZ3
0P20T7l207VCP`80OHn20P1hQh`207N7S@80OHB:0P1hPhl20766TP80N8R;0P1lRHL207R:RP80N8^:
0P1dQhl20868Q080NXV90P1jSHH207V<R080N8b90P20T80207R>Q`80O8b60P1lS8D207j>PP80N926
0P1nSh8208N=O@80QY=i0P1nT84208^7O@80^8]I0P1_TX/2066DU080JY>>0P1PSYT207QoT@80OXj2
0P1TT9@207n9QP80QHF40P1KQj8206B0X080O7f@0P1]PiP206:5WP80[jM<0`1gPY42096BLP80HXNM
0P1hSXL2059l/080LgVI0P1jQhX205n0Y080N8V;6P1hS8T207^:Q`80N8V;1P1hS8T207^:Q`80NhN9
0P1hRH/207R<R@80N8n60P1dSXX@0?ooo`003P3oool407^7R@80N8V;0P1hS8T207R?QP80N8b90P1h
RH/807R<R@80N8n6201hS8T407BAR080NHj60P30Yd02092KK080PiMh0P23R8<2075oU`80O9620P1d
THP207R<R@80X8eY0P1hQXd207F>RP80KSO<0`1T<mL207J9S080LXb=0P1iSHL607R<R@80N8N<101m
Q8X207f9QP80Mhb:0P1hS8T207n8QP80OHJ90P1kSXD206j:T@80OhR60P21RX<2082@O`80NI>30P1m
Sh8207R7S080MhN=0P1mQ8X207R3S`80LHJB0P1hR8/207b9Q`80N8Z:0P1hRhX207B7S`80PHR40P1j
RHT207Z=QP80NHb80P1hS8T2082@P080N8j70P1lS8H207b<Q@80OXj20P1hT8H207j?PP80Qhem0P26
TgT207j@P@80RhMm0P2hReT206nBR`80HIBD0P1ZThh2062>V@80N7nA0P1nSX8206B@U080OhV60P25
QH@205^7XP80I82P0P1lOI0206f3V080HXFN0P2_Yd`307N2T@80TI9b0P1RQid207R>Q`80DWb`0P1c
NIT207Z7RP80Gh2T0P1hRH/J07R<R@80NhZ70P1hRH/607R<R@80NhZ70P1kQhT207R9R`80N8b90P1h
ShH207B>RQ00oooo000>0?ooo`H0M9680P1dSXX207^:Q`80N8V;201hS8T407R?QP80M8j:0P1hS8T2
07R9R`80Nhj50P1hS8T207R9R`80Nj=f0P2Ta3l208NPK`80Q9Ih0P1bRHh207N7S@80Ohb30P1jRXP2
07FTNP80N:ab0P1hVH0206X/e`80PaWB0`1hMiL207J8S@80N8:?0P1mRXH207R<R@80N8N<0P1mRHH2
07:?R`@0LYF70P1hTXD207N=R@@0Mhj80P1kRhL20867Q@80M8J@0P1hS8T208:>P080PhJ40P28QH42
07j9QP@0N8N<0P1gS8T207>;S@80LHV?0P1dSHX207R8S080OX2<0P1oR8H2072:T080O9620P1hQh`2
0865Q`80O8J90P1lRHL20867Q@80PX290P20QXH207n9Q@80PXN40P22R8<207f9Q`80QhB30P2GPgL2
08F;O`80OHj30P2[QfH20:9]O`80MFfQ0P25MHl2071kV`80JXVE0P2:RGd2075nV080N8f80P1nUg`2
0625X080FGV]0P1mQhP206f:TP80HHjI0P2[VeP307J<RP80S:UU0P1CS:@207Z?Q@80Bgjc0P1SRIX2
07igT`80LGJM401hS8T207R?QP80M8j:0P1hS8T207R?QP80M9680P1dSXX207R<R@80N8n60P1dSXX2
07R?QP80M8j:201hS8T207^:Q`80N8V;403oool000h0oooo1P1dTHP207B>RP80NhZ70P1hRH/807R<
R@@0N8n60P1dSXX207R<R@80N8V;0P1kSXD207R<R@80N8V;0P1kXgH20:C4?`80Qj1_0P24UWP207:9
SP80MhN=0P1oS8<207Z:R080MJAj0P1h[78207RIP080JRcG0P236M8307QgU`80MXR=0P1hPXl207f:
QP80N8b90P1hQh`207f9QP80LXn;101bUHL207RBQ@80Mhf9101gSXP207^;Q`80PHN50P1dQY0207R<
R@80PXj00P23QX@208R5P@80OXV6101hQh`207N<R@80Lh^=0P1aRHl207B=RP80N8R<0P1nP8`207n8
QP80L8Z@0P1lTH8207R7S080PHF70P1lQXT207b9Q`80PHN50P22P8T20826QP80OhV50P22Qh@208:8
P`80OHV70P27Q8<209N3M`80QH]o0P1mSX<20:^7IP80XVeo0P1eKJ4208EeS`80L7^K0P1ZRID208Z9
O@80LGjH0P1hSHP207jGO080H8FP0P1INJd207f7R080KHZB0P1QSYT20:^KF0<0MXb:0P2<ZFD205><
Y080NXn50P1;O[<206>9VP80OWNC0P1aMYd@07R<R@80N8n60P1dSXX207R<R@80N8n60P1dTHP207B>
RP80N8b90P1hShH207B>RP80N8n60P1dSXX807R<R@80NhZ70P1hRH/@0?ooo`003P3oool207R<R@80
N8V;0P1kRXL207B;S0X0N8b90P1hShH207R<R@80NhN90P1kRXL207B;S080N8b90P1kRXL207^7R@80
N8V;0P2Fcd8207SAF080N:1j0P23Xg0205n<V`80NY630P1dUHD207N=R@80TiA^0P1oO8h2099^RP80
64Wo0P1cQY0307J9S080MhJ>0P1cT8X207RBQ@@0N8N<0P1mSh<207R<R@80N8^90P1iQX`207f9QPH0
N8b90P1gS8X207b?Q080LX^=0P1hS8T207n8QP80PXN50P24Sgd207j?PP80LXZ?0P1hR8/207^6RP80
N8R;0P1aS8h207F:S080LhJ@0P1hT8H207Z;R080NHJ<0P1nR8L207R<R@80MI:60P1hS8T407b:Q`80
NX^80P20S88207b;QP80OXj20P1nRHH208:;PP80N8b80P2?TW<208V:O@80Phmn0P2;UG@208b7O@80
N8>?0P1]TX`206f;TP80K8bB0P1hRhT207R1T080OHn20P20Nhl207MYXP80H7ZW0P1hTHD206nAS080
HYRA0P2>WfX308RGM@80S9i]0P1GPjL207AmUP80I7RU0P1NOjD206enV`80N8J=401hS8T207^:Q`80
N8V;0P1hS8T207^:Q`80NhN90P1hRH/207R<R@80NhZ7101hS8T207R9R`80N8b90P1hShH207B>RPH0
N8b9403oool000h0oooo0P1hS8T207R9R`80NhZ70P1dRh`:07R<R@80N8n60P1hS8T207^7R@80NhZ7
0P1dRh`207R<R@80NhZ70P1kQhT207R9R`80U/m20P1hdEP207RPNP80Pj=`0P1OS9/207ZAP`80M9F5
0P1gSHT209>DKP80Ogb>0P2BKXX201Q9o`80LhJ@0`1fRH`207N6SP80Li2:0P1hTXD407R7S080OHn3
0P1hS8T207R;R@80NHJ<0P1mRHH607R<R@80Mhb:0P1lSh@207:;S@80N8b90P1oR8H208:7Q@80Q8mm
0P1nSh8207::S`80N8R;0P1kQXX207R8R`80LHb>0P1eRX`207>6T080N9260P1jRhP207V6S080OXR7
0P1hS8T207FBQP80N8b9101lRXL207Z;R080P8b20P1lRhH207j>PP80OXV60P22Rh8207R<R080Si9c
0P29RWd208>?OP80RiEd0P2<Qgd207R3S`80KI:<0P1]Ri8206b<TP80N8^90P1hPI0207f?PP80P7^?
0P1gJJ82061jY`80N9650P1_TH`206:HT@80SYmZ0`28UgD208bNK@80Eh>W0P1dOIH206AhY@80GWnU
0P1]OY/207R6SA00N8b90P1kRXL207R9R`80N8b90P1kRXL207^7R@80N8V;0P1hS8T207^:Q`@0N8b9
0P1hRH/207R<R@80N8n60P1dSXX607R<RA00oooo000>0?ooo`80N8b90P1dRh`207^:Q`80N8V;2P1h
S8T207^:Q`80N8V;0P1hS8T207^>Q@80M8^<101hS8T207R?QP80M8j:0P3B[2h208^:O080QI9j0P29
TgL206=jY@80QHN20P1oQhH207FAQ`80Rhmh0P1hS8T206iR[P80ATCP0P1iQh/307>7S`80Mhf90P1h
SHP407R7S080N9:50P1hTHD207V<R080Mhb:0P1cShX207VAQ080N8N<0P1mQ8X207f9QP80Mhf90P1l
RXL207R7S080N8f80P1gU8@207RCQ080Q95k0P1nSh8207:?R`80KXj>0P1gS8T207R6S@80NHJ<0P1d
R8h207:>R`80N9650P1bRhd207R=R080Mi>50P1hTh@207F7SP80OHR70P1iS8P207^>Q@80N8b80P1n
RHH208:7Q@80PXb10P1hS8P208:<P@80OHZ60P2;T7L208R>N`80R99h0P27SG`208RDM`80L9N70P1`
T8/206F<UP80L9B90P1WRYL207R<R@80OXV60P1_TH`205YmZP80MgbE0P1hSHP207R<R@80Khb?0P29
Ph830:>:JP80TGj00P1aM9l206>@UP80FhZO0P1JMZl20760UQP0N8b90P1hShH207B>RP80N8n60P1d
SXX207R<R@80NhZ70P1hRH/407R<R@80NhZ70P1hRH/607R<RA00oooo000>0?ooo`80N8b90P1dRh`2
07^:Q`80N8V;2P1hS8T207^:Q`80N8V;0P1hS8T207^>Q@80M8^<101hS8T207R?QP80M8j:0P3B[2h2
08^:O080QI9j0P29TgL206=jY@80QHN20P1oQhH207FAQ`80Rhmh0P1hS8T206iR[P80ATCP0P1iQh/3
07>7S`80Mhf90P1hSHP407R7S080N9:50P1hTHD207V<R080Mhb:0P1cShX207VAQ080N8N<0P1mQ8X2
07f9QP80Mhf90P1lRXL207R7S080N8f80P1gU8@207RCQ080Q95k0P1nSh8207:?R`80KXj>0P1gS8T2
07R6S@80NHJ<0P1dR8h207:>R`80N9650P1bRhd207R=R080Mi>50P1hTh@207F7SP80OHR70P1iS8P2
07^>Q@80N8b80P1nRHH208:7Q@80PXb10P1hS8P208:<P@80OHZ60P2;T7L208R>N`80R99h0P27SG`2
08RDM`80L9N70P1`T8/206F<UP80L9B90P1WRYL207R<R@80OXV60P1_TH`205YmZP80MgbE0P1hSHP2
07R<R@80Khb?0P29Ph830:>:JP80TGj00P1aM9l206>@UP80FhZO0P1JMZl20760UQP0N8b90P1hShH2
07B>RP80N8n60P1dSXX207R<R@80NhZ70P1hRH/407R<R@80NhZ70P1hRH/607R<RA00oooo000>0?oo
o`80NhN90P1hRH/207R?QP80M8j:0P1hShH207B>RP@0N8b90P1hShH207B>RP@0N8b90P1kRXL207R9
R`@0N8b90P1kRXL207R<R@80bk<_0P21Rh<209F8M@80RX>20P1ZSY8206bHR@80OXb30P1oVGT2072@
R`80Rg6=0P1F=>0207IJ[@80NHV:0`1cRhd407R<R@80LXn;0P1bUHL207RBQ@80Mhf9101hS8T207NB
QP80Lhn90P1bSh/207:EQ`80N9:5101hRhT207REPP80Ki:;0P1nRHH207j2R`80S8Uk0P22Rh8207Z;
R080KXb@0P1cSX/2076@R`80LI6:0P1aSh/207B>RP80N8b9101cSXX207j=P`80NXB=0P1hRXX207NE
P`80M9>60P1hT8H207R<R@80N8j70P1lT8<208:7Q@80PhJ40P1nSX8207f>Q080QhUo0P2AQgX208n5
O080RhUl0P2AR7T208F2Q@80LhR?0P1]TX`206Z=T`80K8VD0P1aTHX207NHP@80LIn00P0lMl@20867
Q@80N9>40P1`T8`207>AR@80KHf@0`2UZE8206V?T@80N8R<0P1]Ri4205N4Y`80CWbd0P1cRHlH07R<
R@80NhZ70P1hRH/207^:Q`80N8V;0P1hShH207B>RQ00N8b9403oool000h0oooo0P1kQhT207R9R`80
N8n60P1dSXX207R?QP80M8j:101hS8T207R?QP80M8j:101hS8T207^:Q`80N8V;101hS8T207^:Q`80
N8b90P3;/bl2086;P`80UHQe0P2:Ph8206Z>TP80K9R90P1nS8<207nIN@80L92;0P2;LHd205Hdh080
MUZ]0P1iRHX307>;S@@0N8b90P1bSh/207:EQ`80N9:50P1gSHT407R<R@80Mi:60P1cShT207:?R`80
LYF70P1hTXD407R;R@80N9F20P1_TX/207j9QP80OX:;0P2<RG/208:;PP80NX^80P1^S90207>>R`80
LI2;0P1aTHX2076?R`80M8j:0P1hS8T407>>RP80OXf30P1jQ8d207R:RP80MiF30P1dThH207R@QP80
N8b90P1hSXL207b@P`80PXN50P23QX@207j>PP80OHj40P27RGl20967NP80ShEl0P2;RG`20968N@80
QH:50P1cR8l206fBS080JXfC0P1/RI@2076ARP80MiR10P1aWh0203aga080PHN50P1hTh@2072@S080
Li690P1]SI030:FYDP80JHnA0P1hR8`206f;T@80EhBW0P1>O;@207>9SaP0N8b90P1kRXL207R9R`80
NhZ70P1hRH/207R?QP80M8j:401hS8T@0?ooo`003P3oool207BAR080M8j:0P1kRXL207R9R`80Nhj5
0P1dRh`207R?QP80M8j:0P1kSXD207B;S0X0N8b90P1hShH207B>RP80NkUV0P2OeCL206ROQ`80PY]f
0P1oPhX208UlQ`80MhB?0P1iW7`207nHN`80KXFE0P1/?LX207DhaP80O8Z70P1dRhd307V8R`H0N8b9
0P1hQh`207f9QP80N8b90P1gS8X207V@Q@80N9B3101_U8T207>BQ`80Lhj;0P1hRhT207RCQ080NHn5
0P1eQXl207R<R@80Mhb:0P28SG`208J<OP80NXj60P1aT8/206fGR@80KY:<0P1bV8@206NDS`80LXf<
0P1fTHL207B;S@80N8b90P1hT8H207:?RP80N9F20P1hTXD207J=R@80N8b80P1gSHT207V<Q`80OXf3
0P1hS8T208:@OP80OhV50P22QhD208>?OP80Qhem0P2>SGL208V=N`80RXYm0P26UWH206^?T080N8b9
0P1US9H206V4V@80OhV60P1nSH<208:1R080?WK40P1eWGh207R<R@80MhJ>0P1j[Vl204NAZP<0_J`n
0P1FU9d20722UP80P7BD0P1WNJ8204]g^@80N8R<701hS8T207R?QP80M8j:0P1kRXL207R9Ra00N8b9
403oool000h0oooo0P1dTHP207B>RP80NhZ70P1hRH/207^>Q@80M8^<0P1hShH207B>RP80Nhj50P1d
Rh`:07R<R@80N8n60P1dSXX207^iIP80WmDg0P1XWhL208:KMP80Oh>:0P29O8L207N4S`80NIal0P1o
V7/206j5U@80K3g:0P1e><H207b:Q`80M8^=0`1iR8/607R<R@80N8N<0P1mRHH207R<R@80Mhb:0P1i
T8D207RDP`@0KiB90P1cTXL207>>R`80N8^90P1hTh@207V?Q@80MHJ?0P1hS8T207N<RP80R8el0P26
S7h207Z>QP80LI2;0P1]UhT206jBS080LYR40P1WU8l207:=S080MY670P1dRhd207R<R@80N9260P1b
ShX207REPP80N9:50P1fSHT207R<R080Mhf90P1iS8L207j=P`80N8b90P22T7h207n9Q@80PXN50P23
Sgh208N=O@80SXeg0P29SG/208Z:O@80QYIf0P1[Si0207R<R@80IHbF0P1YQ9T207n9QP80OXf30P22
PHP203ifa080MIen0P1hS8T207N6SP80NZi_0P17TJX30;f/?P80EYBM0P1`PYH2081dU080IgVR0P1;
MkT207R8S1`0N8b90P1hShH207B>RP80NhZ70P1hRH/@07R<RA00oooo000>0?ooo`80NhN90P1hRH/2
07R<R@80N8n60P1hS8T207R9R`80Nhj50P1dRh`207^:Q`80N8V;2P1hS8T207^>Q@80M8^<0P2Z_T02
08jCL`80UW:40P2:TgH206Z3V@80RXmi0P1bTHT208RIM080M8FA0P1lOI02021UiP80K8n@0P1iUX02
06b;TP<0N8f80P1hQh`207f9QP80N8b90P1bSX/207VAQ080N9260P1bThP207RMO080KYN80P1eSXT2
07>?RP80Li>80P1^TH`207:?RP80Ohj20P1fRX/207F:S080NHb80P1gS8X208:@OP80QYEg0P1gShL2
07NAQ@80LI2;0P1^TX`207N<R@80LX6D0P1dSH/207R;RP80Li69101aVX@206fHR080MI>50P1gShL2
07F>R@80MXj90P1hS8T207R>Q`80O8^60P1lT88207Z<Q`80PXR40P1mSh<208F:P080QhYo0P2>SWL2
08^<NP80QXil0P2CTfl206^GR`80IYF?0P1]R9<205j=V`80N9650P1nRHH207R<R@80BGZh0P1mSH@2
07:>S080LXn;0P2M[e@202R;a@<0`Z=10P1^Q9H205F=XP80KH2I0P1eKZ0205U_]0@0N8b90P1hShH2
07B>RQH0N8b90P1kSXD207B;S1@0N8b9403oool000h0oooo0P1kQhT207R9R`80N8b90P1hShH207R<
R@80N8V;0P1kSXD207B;S080NhZ70P1hRH/:07R<R@80Nhj50P1dRh`20:Zn@080SY=c0P2FLX@208ZC
MP80JX>I0P2:SgT207:AR@80R9Ud0P1dQI4207amT08086GV0P1/Si0207VFP080K8^B0`1hSHP207R7
S080OHV60P1hS8T207:>R`80NI640P1hT8H207:CR080N9el0P1^UhP207F>R@80Lhn:0P1cThP206jA
S080LXn:0P1oSX8207J:R`80MHZ<0P1iS8P207N<RP80PY1n0P26UGL207N?Q`80Mi650P1aT8/206jB
S080Mhb90P1bPI@207B=R`80N8^:0P1cTHT4076JQ080KIR80P1eThD207N?Q`80MHj90P1fSXT207R<
R@80N8j70P1lRhH207b@PP80NXb70P22R8@207f?P`80QHZ00P27RWl208j>M`80Rhaj0P26SW`209>C
K`80JiN;0P1VUHl206f8T`80GXfK0P1hTHD207j9QP80N8b90P19N[P207f=Q080LXj<0P1bSh/209f_
E080:8_50`32Xd4206j4UP80EHfR0P1]P9T207E^X080FFnd101hS8T207R?QP80M8j:5P1hS8T207^>
Q@80M8^<501hS8T@0?ooo`003P3oool607R<R@80Nhj50P1dRh`207R<R@80NhZ70P1hS8T207B>RP@0
N8b90P1hShH607BAR080N8b90P1hRH/20<[:7`80C9FS0P2CWVP208F6P`80Mh:A0P24T7d20828Q@80
RIi_0P1PMZX208/l/P80JT780P1eVH4206^ES080KhJC0`1iS8P207:?R`80N9:50P1hS8T207NAQP80
LiF60P1fUH@207BBQ`80PHb20P1iTX<206RRQ@80Ii^;0P1aTXX2076@R`80KY6<0P1hUh42072CR@80
KXj>0P1hSHP207N<RP80PYQi0P21UgX207RCP`80M9290P1eSXT207:CR080JY6@0P1[Si0207F>R@80
LYJ6101cVH<2072KP`80Jif60P1XXh@206RWP@80HjB70P1XXXD206NKR`80LiF60P1cThL207n=PP80
N8J=0P22T7l207j>PP80OIAo0P21UG`208JCN@80RHYm0P2=Qg`209N3N080Shag0P1MU9L206>GT080
GhbK0P1aT8/207R8S080Phb00P13PkL207F;R`80OYUk0P1PX8`20:F[D@80<VSF0`2kU50208>?OP80
DG^b0P1[NYl206IjX`80HWbU101hS8T207^:Q`80N8V;1P1hS8T207R?QP80M8j:301hS8T207^:Q`80
N8V;101hS8T207R?QP80M8j:301hS8T@0?ooo`003P3oool607R<R@80Nhj50P1dRh`207R<R@80NhZ7
0P1hS8T207B>RP@0N8b90P1hShH607BAR080N8b90P1hRH/20<[:7`80C9FS0P2CWVP208F6P`80Mh:A
0P24T7d20828Q@80RIi_0P1PMZX208/l/P80JT780P1eVH4206^ES080KhJC0`1iS8P207:?R`80N9:5
0P1hS8T207NAQP80LiF60P1fUH@207BBQ`80PHb20P1iTX<206RRQ@80Ii^;0P1aTXX2076@R`80KY6<
0P1hUh42072CR@80KXj>0P1hSHP207N<RP80PYQi0P21UgX207RCP`80M9290P1eSXT207:CR080JY6@
0P1[Si0207F>R@80LYJ6101cVH<2072KP`80Jif60P1XXh@206RWP@80HjB70P1XXXD206NKR`80LiF6
0P1cThL207n=PP80N8J=0P22T7l207j>PP80OIAo0P21UG`208JCN@80RHYm0P2=Qg`209N3N080Shag
0P1MU9L206>GT080GhbK0P1aT8/207R8S080Phb00P13PkL207F;R`80OYUk0P1PX8`20:F[D@80<VSF
0`2kU50208>?OP80DG^b0P1[NYl206IjX`80HWbU101hS8T207^:Q`80N8V;1P1hS8T207R?QP80M8j:
301hS8T207^:Q`80N8V;101hS8T207R?QP80M8j:301hS8T@0?ooo`003P3oool607R<R@80NhZ70P1h
RH/407R<R@80NhZ70P1hRH/207R?QP80M8j:0P1kSXD207R9R`@0NhN90P1hRH/207R7S080l:<N0P1L
OZL208jYH`80IiF?0P1iVWd207:<S@80QjYX0P1dR8l206YjW`80<6oC0P1jW7/206BZPP80HXNM0P1b
Qi4307V=Q`@0N8b90P1hT8H207REPP80M:5m0P1W^GD205;8NP80CKR90P1aYG`2076SOP80FIbD0P1Y
WHP206N?T`80N8R;0P1nSH<207R:RP80KhRB0P1iRhT207R;R@80RX]k0P28Rgd2086AOP80KiF90P1`
VHH20722U@80OXF90P1YR9H207RGP@80L9j20P1^XX0206bZO080I[Aj0P1J]X4205jVR@80L9f3101Y
VhT206J=U@80Mhf90P1hUH8206nJQP80KiV60P1hUH8207f?PP80Phf00P24SWh208R<O080QIAi0P1o
V7X208B=O`80WGig0P22MI42072=S@80F8bP0P1bUHH206JBTP80PY5m0P1?P:l206FKS080PIee0P1^
TH`209^II@80<fOF0`2a[DH2082JN080AWBo0P1]Ri8205B6Z080HgjR0P1mRHH<07R<R@80NhZ70P1h
RH/D07R<R@80NhZ70P1hRH/<07R<RA00oooo000>0?ooo`H0N8b90P1kRXL207R9R`@0N8b90P1kRXL2
07R9R`80N8n60P1dSXX207^>Q@80N8V;101kQhT207R9R`80N8N<0P3`Xah205anY`80SZUS0P1WUHl2
07VJO@80LXb=0P27ZVP207B8S`80JWZO0P0`Km<207ZLN`80I:Z20P1RQid207:7T@<0NHf7101hS8T2
07R@QP80N9F20P1dXGd206NiM@80D/Qj0P1=^8T2076UO080LJ=n0P1IW9@206VMR080IhnC0P1hR8/2
07j=P`80N8Z:0P1_R98207V;R@80N8^90P2:Rg/208R;O@80PI5n0P1_UHT2072IQP80L8:E0P1nQHT2
06V8UP80N9N10P1`WX8206jRP080K:Yl0P1V]7X205ZfP@80GZJ90P1`WH<406VKR@80IXfE0P1gSHT2
07REPP80KiZ60P1_VHH207REPP80OHn20P23SH0208B>OP80R8al0P25U7T207nHNP80Q8eo0P2MOWL2
089eT@80L8f=0P1HS:0207:EQP80IY:B0P22TGd204n0[`80II^<0P21WGD206jAS080ViUU0P0cImH3
0;6]AP80P9Yh0P16M;l206f;TP80E8JX0P1SOZ8207f9QP`0N8b90P1kRXL207R9Ra@0N8b90P1kRXL2
07R9R``0N8b9403oool000h0oooo0P1dTHP207B>RPH0N8b90P1hShH207B>RP80N8n60P1dSXX207^:
Q`80N8V;0P1kRXL207R9R`H0N8b90P1baf@209[=@@80MhV;0P2=XVT206ZDSP80N9V00P1XSI<20:>D
H`80Gg>]0P22@[D206a:`080TIeY0P1^QY@205f3X`80LXn;0`1cShT207R<R@80N9B30P1dXg/206_3
K080F<9j0P1bSh/2099`R080N:Qe0P17dGd205ReQ080EYRI0P1YYh0204jfR`80CZJF0P1hT8H207R>
Q`80K8ZC101hS8T208:AOP80R8el0P29SG/207Z7RP80O8n30P1JV9L2073EF`809n>80P16cH0205fR
S@80NWjA0P2FVVP206g0K080D:RC0P1PY8T205n`P@80Gk220P1I[8X2052PV080J9j80P1gUX8207N=
R@80N8b90P1iTX@207RAQ@80P99n0P20Tgd2086GNP80R91j0P29QH4208F<OP80PX2:0P2ARgH207:E
Q`80F8JU0P1hS8P206f<T@80N8J=0P1UNj<207:6T@80Qi9i0P1cShX2092JK080;g?A0`2mXDH208Mf
S@80FF2o0P20OX`205a_/P80J86L0P1hTXDJ07R<R@80N8n60P1dSXXF07R<RA00oooo000>0?ooo`80
M9680P1dSXX607R<R@80N8n60P1dSXX207R?QP80M8j:0P1kRXL207R9R`80NhZ70P1hRH/607R<R@80
L/MT0P2JcD4207N9R`80SJ9Y0P1ZU8h207RIP080J8fC0P2SU6<205mc[@80PT:e0P1/B/02096MJ@80
KXJD0P1MPj<207:?R`<0Lhn90P1hS8T207RDP`80M:=k0P1[`f`205S2NP80LXn;0P2BL8P207RXM@80
Am5m0P1H]H@205JHV@80JJN00P1>]X/204jVUP80N9260P1hSXL206b:T`@0N8b90P22TGh208R=O080
RHek0P1jQhX207b?P`80FYRG0P1`eE/202OSR080A/f00P1MXXd207YnT@80UYYX0P1]`6`2052XT`80
H:B90P1O/84205n`PP80FJb:0P1@X9P206RNR080MiJ20P1gSHT207R<R@80NI:40P1hTHD2082BOP80
P9=m0P21UgX208R@NP80RHF10P25S7h208:0RP80TH]f0P1bUHL205R6Y@80N8b80P1]S94207R6S@80
IG^S0P1bQY4208NBN@80Lhn:0P2@VV`202mcd@<0_J560P27MXd205UP_`80P7j<0P1LKk8206R1W080
N9:56P1hS8T207R?QP80M8j:5P1hS8T@0?ooo`003P3oool207^7R@80N8V;1P1hS8T207^:Q`80N8V;
0P1kRXL207R9R`@0N8b90P1hShH207B>RPH0N8b90P2d/T420828Q@80UH9i0P2EQgH208:GN@80IYJ?
0P1`PYH209VFJ@80Fj6?0P0?Nn<208><P@80Qhem0P1lOI0206=nXP80N8N<0`1iS8P207>HP`80MJ=k
0P1h^6X207RVMP80MfVR0P1oFjH209F[G@80O[MU0P1dVX8205BHV`80FZ2A0P1WUHl207j9QP80DX^U
0P1YY8<206VES@80KHND0P1hS8T207RBQ@80O9>00P22T7h208V=N`80NIB20P1hXWT2062NS@80Wgie
0P2INW`2055X_`80S4RY0P2<YfH20778H`80Rhmh0P1VMjD207jOMP80HH>P0P2?QG`206VQQ@80BZFJ
0P1JWI<2076FQ`80L92;0P1gSXP207f?PP80N9650P1nSX8208J@N`80Q9=j0P1oSX8208>GN080OiEm
0P1`XH0207jiI080Hij<0P1AQ:/207R7S080N9N10P1JTI/206F5W080KY:<0P21XW8206ZBSP80THaf
0P0mLLP30:fj@080GG^X0P1WKZ/207R;R@80DWBf0P1hPhlF07R<R@80N8n60P1dSXX207R<R@80NhZ7
0P1hS8T207B>RQ@0N8b9403oool000h0oooo0P1kQhT207R9R`H0N8b90P1kRXL207R9R`80NhZ70P1h
RH/407R<R@80N8n60P1dSXX607R<R@80];910P20R8D209F2N@80UHMf0P22UgT206JFS`80L8:F0P2I
UVT205^QS`803g_S0P23S84208N=O@80O7f@0P1SOZ8207R7S0<0NHb80P1cV8<207FSN`80N;QZ0P1h
YWH207MYXP80Oe^V0P2EZed207jgI@80M9Z20P1DV9/205ZPT@80IiF?0P1nRHH205:;Y@80JJB30P1Y
UHd206f7U080N8b90P1hTXD207bCP080PY1n0P29SG/207VDPP80N:9i0P1PWXd209mnM@80VGYl0P1A
J;l208a8Z@80S:MV0P1ab6<208^?N080IWNU0P1nWgH20663X080ShEl0P1YXHD204ZUVP80FYfC0P1a
UXL2072@R`80Mhj80P1mSh8207RAQ@80OXj20P26T7/208BCNP80Ohj20P23UgP207nEO@80L:600P1n
^F@206>NS080DHB[0P1hQh`207RGP@80FY6K0P1UQI`206jBS080PJ9b0P1ZTXh2096<MP80?G780`2]
^T0205ekZ080Ifj[0P1hRhT2059d]P80N8>?5P1hS8T207R?QP80M8j:0P1hS8T207^:Q`80N8b90P1d
SXXD07R<RA00oooo000>0?oooa00N8b90P1hShH207B>RP80N8b90P1kRXL207R9R`@0N8b90P1hQh`2
0<UTJ080/G5a0P23]V<206f/NP80RZ=Z0P1NPZ<2072@R`80SXMk0P2GH90202Y:lP80RIUc0P1dW802
06VBS`80HXVK0P1]Th`307NFPP80NIij0P1f[G<208:dI@80I<aZ0P0H^[0204^ZU@80ZZi;0P26FJ82
0;ZPB@80<:2a0P1]/WH203NfV`80GZV80P1GWYD206BDTP80KWnI0P1aQY8207R<R@@0OHf40P22SH02
08J5P`80THee0P22S84207RJO`80FIbD0P2OOGH205F@X0808kfU0P2acC02065Z/@80/Ji60P0T]ZX2
08:XK@80@Wfk0P2FadP204^kR@80D9BP0P1HVIL206BSQ`80I9N@0P1bUHL207RBQ@80O9Mn0P1_V8H2
08:EN`80QXml0P1oV7X2082HNP80Oh^30P2=WFd208JGM`80LH>D0P1AVY/205:PU`80Q9=k0P1NMjX2
06f>S`80JIb80P22SWl207R0T@80QXil0P17O;T30;bY@@80AGfi0P1QT9L206n2UP80F76d601hS8T2
07^:Q`80N8V;101hS8T207^:Q`80N8V;501hS8T@0?ooo`003P3oool@07R<R@80N8n60P1dSXX207R<
R@80NhZ70P1hRH/407R<R@80N8N<0P39I6P20;5aL@80PkIS0P1][7X208ZSJP80GX:S0P1`T8/208j7
N`80Uf2@0P0ZB_8208VIL`80M9b00P1YTXl206:9V`80KI><0`1gUX8207VNNP80MZec0P22]6D206C<
JP806;Z`0P1;ZYD20:Z^B`80QUVR0P2jX4T2032P/@80KK9f0P0g]Y/205jYR080EijE0P1TU98206io
V@80LHJB0P1hS8T407f=Q080PXf00P26QH<2096=M@80PXb10P1hVWl205VLU080Wgef0P1ET:0202>m
Y@80/Ld`0P1QJ[420;6^AP809;JZ0P22Z6d2049m^`80U/M80P1;^hT2052DX080F9VG0P1TXhL206BG
T080LYF70P1hTXD207bGOP80KiR60P22UG/208J?O080OiQj0P20V7X207n;P`80SIe]0P26UgL20763
U080DIZK0P1BX9L208BCN`80GWNZ0P1]SXl206VLR080PXio0P1hP94208J>O080Agbi0`2lZD4204Em
^@80HI2G0P1_PYH205Qa]1P0N8b90P1kRXL207R9R`@0N8b90P1kRXL207R9Ra@0N8b9403oool000h0
oooo401hS8T207^:Q`80N8V;2P1hS8T207;=G`80>=680P2V]DT209f4LP80Tgin0P2@P7l2071iW080
N8b90P1hQHh207Q]W`80A6[70P24Y6h207RBQ080KHJF0P1XQIX207B9S@<0O9Mn0P1mWgL208FNLP80
RkAN0P25Sg`205>3ZP80?^Af0P1>oeH201G[S`80U;QD0P1UFkT209:6N@80KFfW0P1`NI`207Q_W@80
M7:N0P1_PYH207B<S080M8j:0P1lSX@207f?P`80Ohf20P1mS8@209:8N080SH610P2@Ogl207N9R`80
HjZ30P1kTX82056>Y@80X=4j0P0MeiL208[FA`80E8FX0P1TZh4203biUP80Q[AR0P1lL9X205YoZ080
JhbB0P1]UXX2062FT`80K9N:0P1cU8L2086DO080MiJ20P1eWGl207fVLP80N9il0P1nRhD208:>P080
UXUd0P2BOWl207QgV080PWBB0P1URYP206fIQ`80EhNU0P1dSXX207FAQ`80KIn30P1UTi8208J:O`80
DWJe0`2lV4d205Yb/@80JHNG0P1NKk0206edXBP0N8b90P1hShH207B>RP`0N8b9403oool000h0oooo
401hS8T207^:Q`80N8V;2P1hS8T207;=G`80>=680P2V]DT209f4LP80Tgin0P2@P7l2071iW080N8b9
0P1hQHh207Q]W`80A6[70P24Y6h207RBQ080KHJF0P1XQIX207B9S@<0O9Mn0P1mWgL208FNLP80RkAN
0P25Sg`205>3ZP80?^Af0P1>oeH201G[S`80U;QD0P1UFkT209:6N@80KFfW0P1`NI`207Q_W@80M7:N
0P1_PYH207B<S080M8j:0P1lSX@207f?P`80Ohf20P1mS8@209:8N080SH610P2@Ogl207N9R`80HjZ3
0P1kTX82056>Y@80X=4j0P0MeiL208[FA`80E8FX0P1TZh4203biUP80Q[AR0P1lL9X205YoZ080JhbB
0P1]UXX2062FT`80K9N:0P1cU8L2086DO080MiJ20P1eWGl207fVLP80N9il0P1nRhD208:>P080UXUd
0P2BOWl207QgV080PWBB0P1URYP206fIQ`80EhNU0P1dSXX207FAQ`80KIn30P1UTi8208J:O`80DWJe
0`2lV4d205Yb/@80JHNG0P1NKk0206edXBP0N8b90P1hShH207B>RP`0N8b9403oool000h0oooo201h
S8T207R?QP80M8j:101hS8T207R?QP80M8j:2P1hS8T20;^h=`80@J:R0P26X6l209FIJ@80Oj9c0P1h
PI02089oRP80N9>30P1XUhd205>2Z`80EH:Z0P24UgL207R9R`80KHRC0P1VQI/207B@R@<0PHf10P2=
OH<209abO`80`Uma0P2MG8l208J4Q080TXQh0P2IKHH208aSUP80MWVG0P1YPI/208=_U@80PeNU0P25
G:0207aXW`80OGb@0P1bQI8407R8R`80O8j40P1mSh<207f9Q`80PX:80P2<PX02095oO`80SGV60P2F
Mh42099dQP80MYR20P1JYHd20:UfL`80^3f@0P2XCI4209IbQ080MHV=0P1hS8T206m^Y080SU^J0P24
Gil207aoSP80Ngj@0P1hNiD207R6S@80N9B30P1hTX@208B;P080PI=m0P28VG<207V=Q`80N9:50P1o
SX8208Z6O`80TXYf0P1^PYL207FBQ`80L9N70P1VT9<205Z1Y`80M8:C0P25R842086<PP80IHFL0P1m
P8d2065eZP<0Zi]G0P1POZ@206Z2VP80CWBi0P1aQY8X07R<R@80NhZ70P1hRH/<07R<RA00oooo000>
0?ooo`P0N8b90P1hShH207B>RP@0N8b90P1hShH207B>RPX0N8b90P2k^3L2046RXP80QZ1_0P2EVFT2
07nRL`80N86@0P22OhX207RCP`80J9N=0P1CPZ/205F2ZP80Q9Mg0P1hRH/206f8T`80IXFK0P1dT8T3
086=P@80SGf30P2LLWl20<9OL@80WEb?0P26Q8@209:8N080VFf60P2<HiH207IiU`80JH6K0P23KiD2
08=GY@80QEbP0P1lJ9l207elT080LXFB101hR8/207b>Q080OHn30P1mRHL208:2R080S8:00P2AOgl2
08eiQP80UWN10P2BM8H207JHPP80FZF=0P2YMW<20;PmT080Z4fA0P2FLX@207F9S@80N8b90P1_KZ@2
08iKVP80Q5nO0P1lOhh207]nT080N7^E0P1hQXd207RDP`80N9:40P24Rh02086CO@80R9Uc0P1iSHL2
07RBQ@80Ohj20P2:QWl209::MP80KX:G0P1eTXL2072GQ`80IY2C0P1JPJL207B2T`80QHR10P21S882
06F5W080OH2=0P1QMJX30:^KE`80H7jT0P1ZPYX204id^@80LHJB:01hS8T207^:Q`80N8V;301hS8T@
0?ooo`003P3oool807R<R@80NhZ70P1hRH/407R<R@80NhZ70P1hRH/407R<R@80N8n60P1dSXX207R<
R@80cVQQ0P2YIgh206bcMP80P[]O0P1hWGd2066HT@80L:600P1hWGd206QmW`80HW6/0P1NTIP2076K
P`80MIJ40P1TTY<2066:W080N8V;0`1mQ8X2089lS080TWB60P2QIh@20;=:RP80`CF@0P36:Y@20<4T
V`80_R>N0P307Z020;0/X`80V5^C0P1cNiP206f:TP80JH^D0P1gPhl207b5R`80M8b<0P1gSXP207^;
Q`80PXN50P1mQXT207b:Q`80Pi1n0P22UgX207NAQP80PXmo0P22NXh20:]KQ@80V4bN0P2BKXX208]f
RP80WFN70P2`BXd20;T^V`80]bFR0P2N>ZH208]IWP80TFJ@0P2CIXl208U`S`80OGn>0P1lRXL2086=
P@80N9:40P1gU8@208V<O080Shie0P1iRHX208:<P@80N9em0P1aX7l208FGM`80KXRC0P1lOY0208Ug
R`80N8J=0P1@QZ/206Z2VP80Rhmh0P1lTX4206EnX080MGnC0P1WOYl30:VIF`80I7bS0P1ZHK4206iL
/P80OH>;=01hS8T207R?QP80M8j:403oool000h0oooo201hS8T207^:Q`80N8V;101hS8T207^:Q`80
N8V;101hS8T207R?QP80M8j:0P1hS8T20<iXH@80ZFMn0P1//gH208:kG`80N9em0P1QV942072QP080
N9em0P1XOIl2069a[080GY6H0P1aVh<207FFQ080I9:C0P1QRY`207R9R`<0OHB:0P22O8`2099dQP80
XFN40P2cBXX20<4eT080aRZD0P3199/20;hSWP80`1jP0P2`;:<209QKT`80Lg^H0P1]RY8206V;U080
Mh>?0P1lQH/207B<S080Mhj80P1kRhL208:7Q@80OHJ90P1lRXL208>@OP80PYMj0P1gTHH208:?O`80
PWZ>0P2[FhD209Q<WP80TVj:0P2;MXX209eWQ`80/4Z=0P2i;Y/20;LUXP80WSZV0P2;FIh2095VT080
TfJ?0P29L8l207eoSP80O8Z70P21SH4207RBQ080MiB40P29S7`208n>M@80NHV:0P22S84207RMO@80
LJ1o0P25UgL206j8T`80O7j@0P29Mh/207R6S@80D8J[0P1ZPYX208^?N080O9:10P1UOZ0207EoT`80
IgjO0`2YVE/206AlX`80JV6a0P1^G;8207f3Rc@0N8b90P1hShH207B>RQ00oooo000>0?ooo`@0N8b9
0P1hShH207B>RP80N8b90P1hShH207B>RPP0N8b90P1hShH207R<R@80N8V;0P1hQh`208QnQP80b<XQ
0P1K^7l208F[J080JYf70P1]V8P206f0V@80UHeb0P1=TJD2056KV`80GYBF0P1aT8/207ZFP080I8ZI
0P1RP:8207RAQ@<0KI2>0P1dRHh207f9Q`80PX>80P20Oh`208QkR080S7>;0P2>Qg/2072[N@80DlQj
0P1;eWD205K;M@80DY6R0P1lMi@207QfV080N8:?0P1lRXL207V3SP80OHV60P1gS8X207b;QP80OHV6
0P1mPh/208f6O@80Sh=n0P23U7/2076dL@80CKZ80P1A`X0205>bR@80LX2F0P2FG9@209YHT`80VUZB
0P2BII4208Q`T080R7R:0P1nOHh207b4R`80OXZ50P1mSh8207RIP080KjMl0P1[VHT2082?P080N9F3
0P1hVgh208V?N@80OhZ50P1nTgl208V3PP80RXak0P1kUgl206jBS080H9VA0P1^ZgX206JBTP80GX>R
0P1EV9/207nNMP80O8n30P1LOjH207B6S`80I7^S0`2^Te/206EjY080C72m0P1XQYT207RBQC@0N8b9
0P1kRXL207R9Ra00oooo000>0?ooo`@0N8b90P1hShH207B>RP80N8b90P1hShH207B>RPP0N8b90P1h
ShH207R<R@80N8V;0P1hQh`208QnQP80b<XQ0P1K^7l208F[J080JYf70P1]V8P206f0V@80UHeb0P1=
TJD2056KV`80GYBF0P1aT8/207ZFP080I8ZI0P1RP:8207RAQ@<0KI2>0P1dRHh207f9Q`80PX>80P20
Oh`208QkR080S7>;0P2>Qg/2072[N@80DlQj0P1;eWD205K;M@80DY6R0P1lMi@207QfV080N8:?0P1l
RXL207V3SP80OHV60P1gS8X207b;QP80OHV60P1mPh/208f6O@80Sh=n0P23U7/2076dL@80CKZ80P1A
`X0205>bR@80LX2F0P2FG9@209YHT`80VUZB0P2BII4208Q`T080R7R:0P1nOHh207b4R`80OXZ50P1m
Sh8207RIP080KjMl0P1[VHT2082?P080N9F30P1hVgh208V?N@80OhZ50P1nTgl208V3PP80RXak0P1k
Ugl206jBS080H9VA0P1^ZgX206JBTP80GX>R0P1EV9/207nNMP80O8n30P1LOjH207B6S`80I7^S0`2^
Te/206EjY080C72m0P1XQYT207RBQC@0N8b90P1kRXL207R9Ra00oooo000>0?ooo`@0N8b90P1kRXL2
07R9R`80N8b90P1kRXL207R9R`P0N8b90P1kRXL207R9R`80N8b90P1bVH@206RESP80nL@00P1OU9D2
08ZOK@80L8V@0P1hPhl206B6W080TI5b0P1_KZD206f2V080G9BH0P1VVX`207RDP`80I8bH0P1ERJ@2
07j@PP<0Ki:;0P1WVX`206jAS080NHf70P1gSHT207NDQ080LLAV0P1KeVX206bkL080L:210P1jKY`2
09a1XP80PD^_0P1nNY4207B5T@80N8R<0P1lRXL207>:S@80OHn30P1gS8X207V<R080O8V80P1hS8T2
08>:PP80S7f40P2RMWT20:]`MP80Rh]k0P1XZ80204n`S@80<l2G0P0n^I@206:SR@80JiB<0P1lR8P2
07j3RP80PXV30P1iQh/207b@P`80N9J20P1iWW/207NZM080L8n=0P1hR8`207NHP@80OIQl0P1hVH02
07RCP`80Pi5m0P1nWgH206FVQ080PZA`0P1hRXX207j9QP80KYF:0P1hNi@207aUX080MWNI0P1_OIX2
08::PP80PY5n0P1CQJT207:ARP80EHnQ0`2LU6P2075iV`80AW320P1hPhlj07R<RA00oooo000>0?oo
o`@0N8b90P1kRXL207R9R`80N8b90P1kRXL207R9R`P0N8b90P1kRXL207R9R`80N8b90P1bVH@206RE
SP80nL@00P1OU9D208ZOK@80L8V@0P1hPhl206B6W080TI5b0P1_KZD206f2V080G9BH0P1VVX`207RD
P`80I8bH0P1ERJ@207j@PP<0Ki:;0P1WVX`206jAS080NHf70P1gSHT207NDQ080LLAV0P1KeVX206bk
L080L:210P1jKY`209a1XP80PD^_0P1nNY4207B5T@80N8R<0P1lRXL207>:S@80OHn30P1gS8X207V<
R080O8V80P1hS8T208>:PP80S7f40P2RMWT20:]`MP80Rh]k0P1XZ80204n`S@80<l2G0P0n^I@206:S
R@80JiB<0P1lR8P207j3RP80PXV30P1iQh/207b@P`80N9J20P1iWW/207NZM080L8n=0P1hR8`207NH
P@80OIQl0P1hVH0207RCP`80Pi5m0P1nWgH206FVQ080PZA`0P1hRXX207j9QP80KYF:0P1hNi@207aU
X080MWNI0P1_OIX208::PP80PY5n0P1CQJT207:ARP80EHnQ0`2LU6P2075iV`80AW320P1hPhlj07R<
RA00oooo000>0?oooaH0N8b90P1hShH207B>RP80N8N<0P27/V8203nLZ080ok490P1nPhX208F6P`80
PWN@0P1hTh@205jCU`80Ohj10P1TRIT206^GRP80H:>:0P1FX9<206bGRP80J8VG0P1IPJL207Z7R`<0
PjE^0P1B]XL204ngR080F<1l0P1CbWP2053PJ`80JlYV0P1eO9H209Y2X`80^BNO0P2I>jT2089TW@80
PGV?0P21Oh/207b1S@80N8R<0P1lRXL207R=R080N9:50P1gSHT207N>R080Mhf90P1lRhH207^;Q`80
OXV60P2<NhD20:MRPP80aTEo0P30=Xl20:a;S`80RGR:0P1>/Xd203WCQP80?=am0P0fgh0204;@P@80
E/Ii0P1C`gd205W9M@80E/9l0P1U[Gl20828Q@80MGbF0P1mS8D20867Q@80Qhik0P1oSh4207R<R@80
PiIi0P2:N8T209^<KP80LHZ?0P25Li0208]kQP80RH>20P1KVY@2056FW`80L8BD0P1]RI8207^DP@80
Phmn0P1JO:X207R0T@80KYF90`1^^W0205Qk[@80G6Bj801hS8T207R?QP80M8j:601hS8T@0?ooo`00
3P3ooolF07R<R@80N8n60P1dSXX207R7S080Qk9R0P0oW:P20?na2@80OX>:0P25QX<2089gT080N9>4
0P1NTiL207n>P@80I8VI0P1[UhX2062SRP80EZ2C0P1/UhX206R9U`80FH6W0P1jQh/308>UKP80D[J7
0P1?]hP205S0O080DlYh0P1@h6/206_:IP80MGbF0P2J@Z<20;TWW`80VC^Y0P22I9d2085iS`80PGn;
0P1lPHd207R8S080O8Z70P1hSHP207RBQ@80Mhf90P1gSXP207N=R@80O8^60P1kRhL207j9QP80S7^5
0P2WHX820<I5O`80`3J?0P2/Bhl208UhRP80C[:=0P0idhH203cLO@80=]n00P12d84205K6N@80Dl=m
0P1IbGD205K2O080IJeo0P20R8D207ElUP80OHb50P21QhD208N>N`80Ohn10P1hS8T208>FN@80RWR9
0P2KS6h2076:S`80QG>@0P2;NhH208V3PP80FiZD0P1AUYl20724U080KHVB0P1kU84208>?OP80FWbZ
0P1hP94206jER@<0K[Y`0P1HNjd205aT^R00N8b90P1hShH207B>RQP0N8b9403oool000h0oooo5P1h
S8T207^>Q@80M8^<0P1bSh/20:ZYCP80?=650P2>m2l207bAPP80N7VF0P28O8L2095oO`80L82G0P1g
U8@206V>TP80L92;0P1fRX/206J9V080JIF>0P1OQ:42069mY080LX^>0`2PMgT209YHT`80SgV50P1l
TX4207fBP@80SVf>0P2Q=jD209`fZP80PF2Q0P1lPHd207b5RP80N8R<2P1hS8T207j>PP80N8b90P1h
Qh`207f4RP80O8B;0P1mRHH207b9R080O8N90P1kQhX207j9QP80R8F20P2AMHH20:9PR080]TB=0P35
:i<20;<WX`80^4j50P2>MXL206^GRP80JIn60P1`Vh@207R2S`80RVbA0P28LXl207R1T@80NX>=0P20
QHL207n=PP80Qi9h0P1oS8<207b3S080THmd0P1VYX<208bIL@80O7RD0P1aW882072^MP80JZal0P1]
V8P204Ul]`80LHFC0P1cVH<206b@SP80R8B20P1PN:T20726T`80R:IZ0`1eRXd204eHcP80KWRN801h
S8T207^:Q`80N8V;0P1hShH207B>RQ@0N8b9403oool000h0oooo5P1hS8T207^>Q@80M8^<0P1bSh/2
0:ZYCP80?=650P2>m2l207bAPP80N7VF0P28O8L2095oO`80L82G0P1gU8@206V>TP80L92;0P1fRX/2
06J9V080JIF>0P1OQ:42069mY080LX^>0`2PMgT209YHT`80SgV50P1lTX4207fBP@80SVf>0P2Q=jD2
09`fZP80PF2Q0P1lPHd207b5RP80N8R<2P1hS8T207j>PP80N8b90P1hQh`207f4RP80O8B;0P1mRHH2
07b9R080O8N90P1kQhX207j9QP80R8F20P2AMHH20:9PR080]TB=0P35:i<20;<WX`80^4j50P2>MXL2
06^GRP80JIn60P1`Vh@207R2S`80RVbA0P28LXl207R1T@80NX>=0P20QHL207n=PP80Qi9h0P1oS8<2
07b3S080THmd0P1VYX<208bIL@80O7RD0P1aW882072^MP80JZal0P1]V8P204Ul]`80LHFC0P1cVH<2
06b@SP80R8B20P1PN:T20726T`80R:IZ0`1eRXd204eHcP80KWRN801hS8T207^:Q`80N8V;0P1hShH2
07B>RQ@0N8b9403oool000h0oooo201hS8T207R?QP80M8j:101hS8T207R?QP80M8j:0P1hS8T207^:
Q`80N8V;0P1hS8T20:j=G`80/Y9I0P2ATG8208:7Q@80IgFU0P2CNH8208inPP80PX2:0P1oR8H20724
U080MhN=0P1cRhd206f4UP80MHZ<0P1EQJP205f5X@80M8f;0`1dSXX207b:Q`80TgF50P2QF8h20:I>
T@80T5FM0P1hMIT207::S`h0N8b90P1hS8P207N=R@80OHn2101hQh`207R<R@80N9:50P1gTXD207N>
R080N8f80P1gSHT207^;Q`80OhZ50P1lR8P207b5R`80OHV60P1iRhP207V:R@80UX1j0P2XF8T20;0n
UP80[4FC0P2TDY4208aOV@80QGR=0P26PXD207ilS`80OHb50P1eVh0207NMO@80OIQl0P1kR8T207Z8
RP80THIj0P2KPGH207R<R@80N:Ig0P1^ZW/207RNO080N8b90P1aRXl204MNcP80S8:10P1lUgd2069[
/080WH9d0P1JSid206:9V`80YYAQ0`1PN:P204IUb@80N8>?901hS8T207^:Q`80N8V;501hS8T@0?oo
o`003P3oool807R<R@80N8n60P1dSXX407R<R@80N8n60P1dSXX207R<R@80NhZ70P1hRH/207R<R@80
[XeO0P2bTUT2096ALP80PXN50P1WMJD209=iPP80SWj20P22P8X207n8QP80L8BD0P1gQhd207>;S@80
KHBF0P1eRX`205F5Z080GHFQ0P1dSH/307B>RP80O8Z70P2CMHD20:5HSP80YTjA0P2@EId207QeV@80
LXZ?3P1hS8T207R<R080Mhf90P1mSh8407R7S080N8b90P1hTXD207NBQ@80Mhj80P1hSHP207N=R@80
Nh^70P1oRXD207b8R080O8F;0P1mRHH207V;R080NHZ90P2FP7X20:QHR@80/3jF0P2/AI<20:ABT@80
S5nI0P25N8d208J2Q@80OWb?0P1mS8D207FKP080Miem0P1mV7`207^8R@80NXR:0P2AQWX209^1MP80
N8b90P1hYWL206jZN`80N9il0P1hS8T2076:S`80Aek>0P2<PX4207bGO@80HV^`0P2MPW@205Z?W@80
HXVK0P2VU643061hZ080AVG90P1hPhlT07R<R@80NhZ70P1hRH/D07R<RA00oooo000>0?ooo`@0N8b9
0P1hShH207B>RP80NhZ70P1hRH/207R<R@80N8n60P1hS8T207R9R`P0N8b90P2HY6020:Zo?`80LJ=n
0P1lR8P2065_[P80SXYi0P26TWX207R:RP80Q8B50P1dPi8207J?R080LI2;0P1TQi/207Z>Q@80EX>Y
0P1LPj@207F:S0<0N8V;0P1hS8T207::SP80N8b90P1iSHL207R7S080OHB:0P1hS8T207:DR080Lhn:
101hS8T207RAQ@80Lhn:0P1gSHT207R=R080N8b90P1mSX<207>?RP80LXn;101hTXD207R7S080OHV6
0P1hRhT207V;R@80N8^90P1mRHH207f;Q@80M8b;0P1mSX<207R<R080N8j70P1lT8<207>9SP80NI>2
0P1hU8<207j?PP80N9:40P1gTXD207b?P`80Lhn:0P21U7`207f8Q`80R8>30P27Rgh207B>RP80N8j7
0P1oVWT208F5P`80Vgeh0P2?S7L208F1QP80QGn80P1nMi<208EmRP80;6OL0P2KQG<208f5O@80Ah6e
0P2EV6/207:?R`80BXJ_0P2VWUT305E[^P80DFG10P1mRHHl07R<RA00oooo000>0?ooo`@0N8b90P1h
ShH207B>RP80NhZ70P1hRH/207R<R@80N8n60P1hS8T207R9R`P0N8b90P2HY6020:Zo?`80LJ=n0P1l
R8P2065_[P80SXYi0P26TWX207R:RP80Q8B50P1dPi8207J?R080LI2;0P1TQi/207Z>Q@80EX>Y0P1L
Pj@207F:S0<0N8V;0P1hS8T207::SP80N8b90P1iSHL207R7S080OHB:0P1hS8T207:DR080Lhn:101h
S8T207RAQ@80Lhn:0P1gSHT207R=R080N8b90P1mSX<207>?RP80LXn;101hTXD207R7S080OHV60P1h
RhT207V;R@80N8^90P1mRHH207f;Q@80M8b;0P1mSX<207R<R080N8j70P1lT8<207>9SP80NI>20P1h
U8<207j?PP80N9:40P1gTXD207b?P`80Lhn:0P21U7`207f8Q`80R8>30P27Rgh207B>RP80N8j70P1o
VWT208F5P`80Vgeh0P2?S7L208F1QP80QGn80P1nMi<208EmRP80;6OL0P2KQG<208f5O@80Ah6e0P2E
V6/207:?R`80BXJ_0P2VWUT305E[^P80DFG10P1mRHHl07R<RA00oooo000>0?ooo`@0N8b90P1kRXL2
07R9R`H0N8b90P1kRXL207R9R`X0N8b90P2TSVH20=6K>`80NgVD0P22NXd205f:WP80OJ9e0P22R8<2
089mR`80P8R50P1hSXL207>CQ`80LIB80P1KTI/207BDQP80EXfQ0P1?SjD206f@SP<0M8j:0P1gSHT2
07:?R`80LXn:0P1iS8P207>?RP80LXn;0P1mRHH207b9Q`80LhZ=101hS8T207b:Q`80N8R<1P1hS8T2
07b:Q`80OHF90P1hQh`207f9QP80OHB:0P1hS8T207RBQ@80Mhf90P1gTHH407BBQ`80Nhj50P1hRH/2
07f?P`80N8f80P1iSHL207b8R080N8b90P1lT88207^;Q`80OHn30P1nRHH407f9Q`80O8Z70P21R8D2
07n6Q`80OiMk0P1oUg`207R5S@80OHf40P27Rgh207RIP080O;5[0P1nSh8208F0Q`80QI9k0P1TWH`2
06jMQ0808fgN0P2;TWH208j:NP80Ffnc0P2ESg42086EO080@Xj_0P2EZ5l3041Ff@80KVjU0P1hTXDl
07R<RA00oooo000>0?ooo`@0N8b90P1kRXL207R9R`H0N8b90P1kRXL207R9R`X0N8b90P2TSVH20=6K
>`80NgVD0P22NXd205f:WP80OJ9e0P22R8<2089mR`80P8R50P1hSXL207>CQ`80LIB80P1KTI/207BD
QP80EXfQ0P1?SjD206f@SP<0M8j:0P1gSHT207:?R`80LXn:0P1iS8P207>?RP80LXn;0P1mRHH207b9
Q`80LhZ=101hS8T207b:Q`80N8R<1P1hS8T207b:Q`80OHF90P1hQh`207f9QP80OHB:0P1hS8T207RB
Q@80Mhf90P1gTHH407BBQ`80Nhj50P1hRH/207f?P`80N8f80P1iSHL207b8R080N8b90P1lT88207^;
Q`80OHn30P1nRHH407f9Q`80O8Z70P21R8D207n6Q`80OiMk0P1oUg`207R5S@80OHf40P27Rgh207RI
P080O;5[0P1nSh8208F0Q`80QI9k0P1TWH`206jMQ0808fgN0P2;TWH208j:NP80Ffnc0P2ESg42086E
O080@Xj_0P2EZ5l3041Ff@80KVjU0P1hTXDl07R<RA00oooo000>0?ooo`X0N8b90P1hShH207B>RPh0
N8b90P2CPG`20>BG<080M8j:0P1]Wh<206:QRP80KIj40P1bSh/207RJO`80LiB60P1lSX@207R8R`80
O8V70P1VO:4207ilS`80KgZL0P1KOZP206fAS@<0KHn>0P1gS8T207R;RP80M8Z=0P1hS8T207V=Q`@0
LXn;0P1lRXL207R8S0@0N8b90P1hTHD207>CQ`80Lhn:201hS8T207RBQ@@0LYF70P1hTXD207R<R@80
N9:40P1dTHP407R<R@80N8j70P1eThH207RBQ@80N8b80P1iTh<206nER@80N9>40P1hS8T207b=Q080
OXn20P1hS8T207f=Q080NHb70P1lUWh206nGQ`80N9Yo0P21Sh0208N4P`80N8b90P1kUgh207RPN`80
Oime0P29SgT207F1TP80QIQf0P1nVgT207R<R@80LGjH0P0_O</20769T080WG9o0P1ULjP209FCKP80
S8In0P1OV9<207:0U@<0BTkG0P1hRH/T07R<R@80N8n60P1dSXXF07R<RA00oooo000>0?ooo`X0N8b9
0P1hShH207B>RPh0N8b90P2CPG`20>BG<080M8j:0P1]Wh<206:QRP80KIj40P1bSh/207RJO`80LiB6
0P1lSX@207R8R`80O8V70P1VO:4207ilS`80KgZL0P1KOZP206fAS@<0KHn>0P1gS8T207R;RP80M8Z=
0P1hS8T207V=Q`@0LXn;0P1lRXL207R8S0@0N8b90P1hTHD207>CQ`80Lhn:201hS8T207RBQ@@0LYF7
0P1hTXD207R<R@80N9:40P1dTHP407R<R@80N8j70P1eThH207RBQ@80N8b80P1iTh<206nER@80N9>4
0P1hS8T207b=Q080OXn20P1hS8T207f=Q080NHb70P1lUWh206nGQ`80N9Yo0P21Sh0208N4P`80N8b9
0P1kUgh207RPN`80Oime0P29SgT207F1TP80QIQf0P1nVgT207R<R@80LGjH0P0_O</20769T080WG9o
0P1ULjP209FCKP80S8In0P1OV9<207:0U@<0BTkG0P1hRH/T07R<R@80N8n60P1dSXXF07R<RA00oooo
000>0?ooo`X0N8b90P1kRXL207R9R`h0N8b90P1kQH/20>>h6@80MXV<0P26QH<207R3S`80NGjA0P1l
Ph`208R4PP80OXF90P1lRXL207R<R@80N8J=0P1VPYd206j5U@80LX6E0P1MRIl206f>S`<0KXRC0P1g
RhX207N8S080N8R;0P1hS8T207V<R080NHJ<0P1hQh`207RAQ@80Li>70P1cShX207R<R@80O8j4101h
R8`207RBQ@80LXn;101hS8T207f?P`@0N8b90P1hRhT207V;R@80OhN60P1lPh`207b:Q`80N8b90P1j
SHH207^>Q@@0N8b90P20T80207F?R080M9:70P1cTXP207R@QP80OXb30P1jRhP207b?P`80N8j70P25
RH0207j7R080P8n00P1gTHH207b?P`80PXV30P23SWl208V>N`80QIIh0P1kRhL207bGOP80NZ=f101n
RHH206B=U`80@82k0P1ER:H208:UK`80EYBM0P28TGT208^0PP80SHYj0P14H/d305i]/RH0N8b90P1k
RXL207R9RaH0N8b9403oool000h0oooo2P1hS8T207^:Q`80N8V;3P1hS8T207^5R`80hkPI0P1fRH`2
08J5P`80N8>?0P1iOY4207b3S080R8B20P1nQHT207b:Q`80N8b90P1hQXd206J2W@80KXFE0P1bPID2
05f9W`80KHj?0`1^R9<207N;RP80MhR<0P1hR8/207R<R@80NHb80P1iQX`207R7S080N9650P1cThL2
07>?RP80N8b90P1lSX@407R8S080N9:50P1bSh/407R<R@80OHn3101hS8T207R;R@80NH^90P1oQhH2
07b3S080O8Z70P1hS8T207Z=QP80Nhj5101hS8T2082@P080MHn80P1dTXL207>BR080N9260P1nS8<2
07Z;R080O8n30P1hSXL208F9P080OXN80P20Sh0207NAQP80O8n30P22RH<208>>O`80RHik0P25UWP2
07^;Q`80O9Mn0P1jXgH407j9QP80I8fG0P10P;/205F8YP80PZE_0P1FU9d208RAN@80Rh220P2=RWX2
04ARc@<0GVfb9P1hS8T207^:Q`80N8V;5P1hS8T@0?ooo`003P3ooolL07R<R@80LXZ?0P3_X24208B7
P`80MIJ40P1cP9D207V6S080N9J20P1aUHL207jCO`80Li290P1jP90207eoS@80KHRD0P1TRIT206j<
T080IHVI0P1XRiH306f<T@80Lhf;0P1dSH/207BBQ`80M8j:0P1hS8T407>?RP80O8Z70P1lRhH207:?
R`80Lhn:0P1lRXL207R=R080LYB80P1iS8P207R;R@80LiB70P1bUHL207RAQ@80NHb8101hRhT207R<
R@80N9260P1dSXX207b>Q080N8b90P1jT8@207R:RP80OHV60P1hSHP20829Q@80PHF60P1lQhT207^7
RP80O8^70P1kT8<207R>Q`80OHj30P1hS8P207bFOP80MIB50P20T80207b>Q080N8b90P1oVGX207RF
P@80Pi5m0P2@S7L207R<R@80RIa`0P1jTh42076MPP80L9f20P1UKZ`2069_[P80E9VK0P1nW7T2069k
Y@80PhJ40P26L9820:aSOP80D4GI0`1hMIU007R<RA00oooo000>0?oooa`0N8b90P1bRXl20>nP8@80
Q8N30P1eUX@207>0U@80NHJ<0P1hUX82076EQ`80OY=o0P1cT8T207Z0T080OGn=0P1]R9@206B9V@80
KXb@0P1URIT206R;UP<0KHbA0P1cSH/207B=R`80M9:70P1dSXX207R<R@@0Lhn:0P1lRXL207b;QP80
LXn;0P1cShX207b:Q`80N8f80P1bU8P207V<R080N8^90P1cU8L207:EQ`80N9650P1iS8P407R;R@80
N8b90P1hT8H207B>RP80O8j40P1hS8T207Z@Q080N8Z:0P1mRHH207R=R080P8V50P21QHH207b7R@80
NhN:0P1lRhL207^@P`80N8j70P1mSX<207R<R080O9In0P1eU8D2082@P080O8j40P1hS8T207nINP80
N9J10P23TGd2092<M`80N8b90P29W70207ZCP@80LIf20P1`WH8206E^[080HVn^0P1DVI/207jLN@80
HW^U0P23QX@208I`TP80[6=n0P1@AMT307QeVD00N8b9403oool000h0oooo701hS8T207::S`80d/PJ
0P1kRHP208iTU080PhJ40P1]UhT207j@P@80MXb:0P1nSh8207Z0T080M9^10P1QWXd206f2V080L7nH
0P1bS8d206B;V080IhNI0`1aRXl207:<S@80MXf9101hR8/207R<R@@0N8R<0P1hTXD207R<R@80O8B;
0P1hR8`207RAQ@80NHb80P1lRHL207>@RP80Mhf90P1mRHH207V<R080Mhf9101hS8T207N>R080Mhf9
0P1lRXL207R8R`80O8Z70P1lSh<207R?QP80M8^<0P1kT8<207R<R080N9>30P1eSXT207j=P`80Li:8
0P1hUH8207RAQ@80N8b80P1mSX<207R<R080QI9k0P1eQXl208J<OP80O8f40P1hVGl207bLNP80MiV0
0P1fY7T207RBQ@80RY=f0P22Wg<207RLO@80N8:?0P2:Ph8204A_a080MWfE0P1/S942072OP@80ChjV
0P1hTHD206N@TP80OFfK0P1WF[U307R<RA00oooo000>0?oooa`0N8b90P1bRXl20=;86P80NhV80P2>
I9@208>6Q080KIN90P1nT84207J<RP80OXn20P1jP90207BKP@80HIj=0P1]PYP2071oV080LXb=0P1T
RiP206N7V@<0LHZ?0P1bS8d207J=R@@0N8R;0P1hS8T407R8S080N9:50P1hS8T207b4R`80N8R<0P1h
THD207V<R080O8V70P1cT8X207N=R@80OHV60P1iS8P207N=R@@0N8b90P1gSXP207N=R@80O8Z70P1h
R8/207b:Q`80O8n30P1hShH207B;S080Ni230P1hS8P207RCP`80MHj90P1nSH<207>BR080N9F20P1h
THD207R<R080OHj30P1hS8P208FBN`80MHJ?0P26S7h207b=Q080N9Uo0P1lW7X207NIP080MZAi0P1h
TXD208ZCMP80PYmc0P1hW7d207R2S`80RX>20P14Kl@207ImU@80K8bA0P1`Wh4204n>YP80N9650P1W
T98207e]V`80IeZi@`1hS8T@0?ooo`003P3oool407R<R@80N8n60P1dSXX207R?QP80M8j:401hS8T2
07:?R`80ifE@0P2kCX8207RTM`80M:Ii0P1_UXP206nJQ@80LYR50P1cT8T206nER@80Q8R30P1hN9L2
06J6VP80JXRE0P1hPY02071nV080J8JI0`1aRY0207B;S@80MXR=0P1hR8/207R=R080Mhf90P1cRXd2
07R<R@80OHj30P1cRHh207RAQ@80Lhn:0P1lSX@207>@RP80Mi660P1iQh/207R;R@80N9:50P1hSHP4
07R;R@80NHb80P1iRhT207R<R@80Mhf90P1hS8T207RCQ080NXn50P1kQH/207Z=QP80N8n60P1hS8T2
082@P080L8VA0P21T7h207R<R@80OXn2101hSHP207f9Q`80OHZ60P25S7l207F5S`80QYEg0P1hUh42
07jFO080OHV70P29PX<20961OP80NYF10P1oX7D208^DM@80OhR60P1]PIP208Z<N`80@VW90P1hQHd2
07N8S080PX^20P1EOZd207R7S080N82A0P1EJ;`207QmU4<0N8b9403oool000h0oooo101hS8T207R?
QP80M8j:0P1hShH207B>RQ00N8b90P1bSh/20>MUD080^dj20P1hY7L207BVN@80KiJ80P1_VXD207:H
Q@80Li290P1_UHT208B8P`80N7RG0P1VQYX206Z8U@80N8:@0P1`OYP206R6V@<0LHZ@0P1dRhd207J8
S@80N8R;0P1hSHP207N=R@80LhZ=0P1hS8T207f>P`80LhV>0P1hTHD207>?RP80O8j40P1cT8X207NA
QP80NHN;0P1hRhT207RBQ@80N8f8101hRhT207V<R080NH^90P1hS8T207N=R@80N8b90P1hTh@207Z?
Q@80NhF;0P1jSHH207R?QP80N8b90P20T8020729T@80PI1n0P1hS8T207j?PP@0N8f80P1mRHL207f:
QP80QHao0P1eQHl208JEM`80N9N10P1nUW`207f9Q`80RH:30P2APGh207ZEP@80Oj1e0P2;U7D207n8
QP80KH6H0P2:S7/2049Yb@80N8F=0P1gR8`208:;PP80EGj]0P1hQh`207R0T@80EFRl0P1hOIA307R<
RA00oooo000>0?ooo`@0N8b90P1kRXL207R9R`80NhZ70P1hRH/B07R<R@80R7j60P3AZc02082PM080
N8j70P1hUH82072AR`80N8n70P1`UhL2072BRP80KhNB0P1hQXd206ejW@80Lh>C0P1/QIL207:4TP80
K8BG0`1aRY0207B9SP80M9290P1`T8/207V=Q`80Mhb:0P1cShX207>CQ`80N9650P1cT8X207N=R@80
N8R<0P1lRXL207f5R@80O8Z70P1bT8X207N=R@80OHV60P1iRhT207R;R@H0N8b90P1iS8P207R;R@80
N9>40P1hT8H207R9R`80N8b90P1mSh<207R7S080OHV60P20R8D207R5SP80PH^20P1mRHL207j?PP80
N8b80P1hTHD207:?RP80OHn30P1oR8H207b?P`80PYQi0P20R8H208J4P`80OY=o0P1aWX4207^[L080
N:Ig0P1hWg/207jEOP80OY210P1UTY8207bDP080>V_>0P22QhD207:BR080N9F20P1DN[0207QiUP80
Of^K0P1LJkA507R<RA00oooo000>0?ooo`@0N8b90P1kRXL207R9R`80NhZ70P1hRH/B07R<R@80R7j6
0P3AZc02082PM080N8j70P1hUH82072AR`80N8n70P1`UhL2072BRP80KhNB0P1hQXd206ejW@80Lh>C
0P1/QIL207:4TP80K8BG0`1aRY0207B9SP80M9290P1`T8/207V=Q`80Mhb:0P1cShX207>CQ`80N965
0P1cT8X207N=R@80N8R<0P1lRXL207f5R@80O8Z70P1bT8X207N=R@80OHV60P1iRhT207R;R@H0N8b9
0P1iS8P207R;R@80N9>40P1hT8H207R9R`80N8b90P1mSh<207R7S080OHV60P20R8D207R5SP80PH^2
0P1mRHL207j?PP80N8b80P1hTHD207:?RP80OHn30P1oR8H207b?P`80PYQi0P20R8H208J4P`80OY=o
0P1aWX4207^[L080N:Ig0P1hWg/207jEOP80OY210P1UTY8207bDP080>V_>0P22QhD207:BR080N9F2
0P1DN[0207QiUP80Of^K0P1LJkA507R<RA00oooo000>0?oooah0N8b90P1bSh/20=f3@`80^VY^0P20
RX@207n8QP80N8F=0P1jRXP207n5R080MHV=0P1ZUH`206J?U080IHbG0P1[SY0206V9UP80K8RE0P1_
QI@30769S`80LXZ?0P1kRXL207B7S`80NHf70P1gSHT207N8S080O8^60P1gR8`207f5R@80N8N<101h
S8T207RBQ@80N8b90P1mR8L207>?RP80Mhf90P1lRhH207N=R@80N8f80P1gSHT607R<R@80Ohb30P1h
QHd207b:Q`80N8n60P1jSHH207F>R@80N9:50P1hS8P207R<R@80O9>00P1hTHD207j>P`80NHb80P1m
RHL207R=R080N9650P1hUX4207ZEP080Q8^00P1lTH8207RDP`80RHUn0P27R802092HKP80O9620P25
TG/207R8R`80RXYm0P1bPY@207j7Q`80=f_@0P24OH/208n9N@80LXBC0P1LNZX206>2X080KfRY0P1h
LiX207R?QP<0M8j:@01hS8T@0?ooo`003P3ooolN07R<R@80LXn;0P3MPd<20;YZKP80P8Z40P1oR8H2
07R5S@80NXZ80P1oQHP207F9S@80JYF<0P1VSi@206F<U`80Jhj@0P1YRIH206b8U@80KhFD0`1aRHl2
07::S`80NhZ70P1dQhl207V=Q`80Mhf90P1gR8`207b;QP80MhR<0P1mQHT207R7S0@0N8b90P1hTXD2
07R<R@80OHR70P1cShX207N=R@80O8^60P1gSHT207R=R080Mhf91P1hS8T207n<P`80N8F=0P1lRXL2
07R?QP80NXf60P1eSXT207RBQ@80N8b80P1hS8T207bCP080N9650P1nSX<207V<R080OHV70P1hSHP2
07RAQ@80N9J10P1jUH0208B;P080O9620P1hU8<208V9OP80QhR00P2@V6h207bAPP80QI5k0P1hR8/2
08Z:O@80LX:D0P1nQhL203M[d080Q7f;0P2?RGT207:4T`80G7ZZ0P1SPZ0206mXZ@80N7>J0P1hShH3
07B>RT00N8b9403oool000h0oooo0P1hS8T207R?QP80M8j:6P1hS8T20:9iMP80fhU00P26U7P2072H
QP80L9>90P1eT8P207F>RP80NhV90P1jRhP206>8V`80K8:I0P1cOYH2075nU`80L8>D0P1]Q9H307N7
S@80LXn;0P1bTHT207:?R`80MHj:0P1iRhT207>>R`80NI250P1cSX/207>?RP80N9650P1cShX207RB
Q@80N9650P1cSX/207RBQ@80N8b90P1cShX207RBQ@80Mhb:0P1iS8P207R;R@80N8f80P1gSHT207R<
R@80O8j40P1dSXX207RBQ080NHb80P1jRhP207Z>Q@80N8b90P1hS8P207RAQ@80O8n30P1lQhT20868
Q@80OXZ50P1hS8T207f>P`80N9260P1nSX<207j@P@80MiB40P24TG`207RBQ080N9am0P1lWWT208fJ
K`80O8j40P25SGh207R<R@80OhJ70P1oNhl207n?PP80;X380P1USi@209F>L@80L7:Q0P1_LJ8206Qb
Y`80GGVZ0P1hS8T207^:Q`<0N8V;@01hS8T@0?ooo`003P3oool207R<R@80N8n60P1dSXXJ07R<R@80
XWUf0P3KRD0208JDN080L9R60P1`ThT207F@R080MHj:0P1kRHT207Z;R080HhRK0P1/PYT207=nUP80
LGjG0P1`Pi@206f4UP<0MhN=0P1bSh/207:AR@80LXn;0P1eSXX207V;R@80Lhj;0P1iT8D207>>R`80
Lhn:0P1hTHD207>?RP80N9:50P1hTHD207>>R`80N9:50P1hS8T207>?RP80N9:50P1gS8X207V<R080
N8^90P1hSHP207N=R@80N8b90P1lSX@207B>RP80N9:40P1iS8P207Z;R080NXj50P1hS8T207R<R080
N9650P1lSh<207b7R@80PHR50P1nRXD207R<R@80OHj30P1hT8H207j>P`80OY210P1gU8@208BAO080
N9:40P1hW7d207bNN@80SIY_0P1lSX@208F=OP80N8b90P1oQXL207mkS`80Ohn20P0^P<P206F?U080
UHia0P1`LZ4206maXP80J7:W0P1MNJX207R<R@80NhZ70`1hRH]007R<RA00oooo000>0?ooo`80N8b9
0P1kRXL207R9RaX0N8b90P1kRXL20=VR<080W7Uk0P2>O8<207R1T080OhB90P1jRhP207:=S080OHR8
0P1[PIX206BBT`80GhnI0P1[PiT207EnU080LXJA0`1aSh/207N7S@80NHN;0P1hQh`207R8R`80N8b9
0P1hSHP207N>R080MhR<0P1hR8`207b?P`80LXn;0P1iT8D207R<R@80Mhj80P1hSHP207N=R@80N8b9
0P1iRhT207R<R@80Mhf90P1hS8T207V<R080N8^9101hT8H207R<R@80NXf60P1eSXT207VAQ080N8n7
0P1gSHP207N=R@80OXn20P1hSHP207RAQ@80N9>40P1jT8@207R<R@80OHf40P1nR8L207j?PP80P9El
0P1gT8H2082FN`80NiB00P1oUg`207jJNP80QIUf0P1lRXL208B;P080Ohb30P1aRY0207RIP080N:1k
0P0bNL/206BCTP80O9]k0P1RPZ0206EmX@80I6f]0P1aMia707R<RA00oooo000>0?ooo`80N8b90P1k
RXL207R9RaX0N8b90P1kRXL20=VR<080W7Uk0P2>O8<207R1T080OhB90P1jRhP207:=S080OHR80P1[
PIX206BBT`80GhnI0P1[PiT207EnU080LXJA0`1aSh/207N7S@80NHN;0P1hQh`207R8R`80N8b90P1h
SHP207N>R080MhR<0P1hR8`207b?P`80LXn;0P1iT8D207R<R@80Mhj80P1hSHP207N=R@80N8b90P1i
RhT207R<R@80Mhf90P1hS8T207V<R080N8^9101hT8H207R<R@80NXf60P1eSXT207VAQ080N8n70P1g
SHP207N=R@80OXn20P1hSHP207RAQ@80N9>40P1jT8@207R<R@80OHf40P1nR8L207j?PP80P9El0P1g
T8H2082FN`80NiB00P1oUg`207jJNP80QIUf0P1lRXL208B;P080Ohb30P1aRY0207RIP080N:1k0P0b
NL/206BCTP80O9]k0P1RPZ0206EmX@80I6f]0P1aMia707R<RA00oooo000>0?ooob80N8b90P3;Ffd2
0=l`O080`5Uf0P2@KX`208IjR`80RgF:0P26P8L207J=R@80JXVF0P1bP9D206V2VP80H96G0P1RT9H2
07>9SP<0MhN=101bSh/207B@R@80LY>80P1dShT207R=R080N8b90P1bSh/207:DR080NI250P1hS8T2
07N8S080OHV60P1iS8P207R;R@80NH^90P1hRhT207R<R@80NHn50P1dSH/207R@QP@0M9:70P1hT8H2
07R8R`80O8f50P1gSHT207Z?Q@80Mi260P1hSHP207R<R@80MiB40P1eThD207R=R080O8j40P1kSh@2
07R9R`80OXj20P1fThD207J?R080PiYg0P1hU8<207bEO`80Ni>20P22U7/207bJN`80OiUj0P21QhD2
08F9P@80OXf40P25S7l2076FQ`80N:5j0P1fN9P2059?d080QX260P1lQXX206UgXP80Ih6M0P1=N;H2
07R9R`80M8j:A@1hS8T@0?ooo`003P3ooolR07R<R@80be]]0P3O<7`20<1IMP80T6j<0P26NX/208]e
RP80QX270P1fSHT206Z9UP80LX2E0P1YPYX2062AU`80HY2F0P1cRHh307N7S@@0LXn;0P1dT8T207:C
R080M8n90P1hSHP207R<R@80LXn;0P1bU8P207V@Q@80N8b90P1gR8`207f9QP80NHb80P1hRhT207V;
R@80N8^90P1hS8T207V?Q@80M8f;0P1hT8H407BBQ`80N9260P1hR8/207b=Q@80Mhf90P1jShD207N@
QP80N8f80P1hS8T207NDQ080MI>50P1hSHP207b>Q080Nhn40P1hRH/207j>PP80MY>50P1fShP208>J
M`80N9B30P1lUGl207^CPP80PYAk0P1lVW/207nINP80PHN50P25RH4207j=Q080QHao0P1aUXL207RQ
NP80MWRH0P1BCm0208J0QP80O8J:0P1YMj8206N1W@80CGRf0P1hRH/207B>RTD0N8b9403oool000h0
oooo0P1hS8T207R?QP80M8j:401hS8T207R?QP80M8j:201hS8T207::S`80Z79f0P3A?g`20<eVH`80
O8Z70P1hUh4207ZAQ080P8::0P1`RI42066@U`80J8RG0P1_QY@206B=U`80J8bE0`1gS8T207R<R@80
LXZ?0P1iRhP207R7S080NHR;0P1iShH207F>RP80N8b90P1gS8X207R<R@80NHb80P1cSX/207RAQ@80
NHb80P1hS8T207N=R@@0N8b90P1lRXL207R8R`80O8j4101hS8T207R8R`80N8b90P1kU84207:BR@80
N9640P1hRhT207R<R080N8b90P20S88207V=Q`80M9:70P1hShH207j9QP80N8f80P1mV7`207>>R`80
N9Qo0P1mUWh207f9Q`80Q9Aj0P1eX7`207FWN080N9:40P28Sg/207BGQ080O9In0P1lTX4207b?P`80
QHml0P1lTX4205MBbP80Kf>/0P1nWgH206V;U080IXJJ0P1TMJP205i]/P80NhZ70P1hRH]507R<RA00
oooo000>0?ooo`80N8b90P1hShH207B>RQ00N8b90P1hShH207B>RPP0N8b90P1bRXl20:QbMP80dCml
0P3=IV<207b:Q`80N9N10P1jTH@20822RP80L8VA0P1QT9L206R8U`80KhJD0P1TSIL206R<U@<0Mhb9
0P1hS8T207::S`80NH^80P1hQh`207V8R`80NHn60P1eSXX207R<R@80Mhb:0P1hS8T207V<R080Lhj;
0P1hTHD207V<R080N8b90P1gSHT407R<R@80O8Z70P1hR8/207b>Q0@0N8b90P1hR8/207R<R@80NiB1
0P1bTXT207RAQ080N8^90P1hS8P207R<R@80P8b20P1iSHL207BBQ`80N8n60P1nRHH207R=R080OIQl
0P1cSX/207RHO`80OIIn0P1mRHL208BDNP80MJ1l0P1eYgP207RBQ080R8mk0P1dUh@207bFOP80O9:1
0P1lSh<208F?O080O9:10P1GD/X206mS[080OYmf0P1YRi@206J6VP80I7FX0P1NKK8207^:Q`80N8V;
A@1hS8T@0?ooo`003P3oool207R<R@80NhZ70P1hRH/@07R<R@80NhZ70P1hRH/807R<R@80LXn;0P1b
UHL208:7Q@80fHM30P2KS6h207>EQ@80MYB50P1/TXd207R;RP80JHBI0P1UR9X206b:T`80KHFF0P1X
RiD3076GQP80Ki6<101bSh/207BAR@80LIJ70P1eTHL207F>RP80MHf:0P1hRhT207R<R@80N9260P1d
SXX407R<R@80NHn50P1dSH/207RBQ@80LY>80P1dThL207:CR080N9260P1hS8T207R>Q`80LIF70P1b
VH@207RBQ@80N8b90P1hSHP207N=R@80N8b80P1gSHT207bBP@80NI24101hS8T207RAQ080N9650P23
Rh4207R<R@80PHR50P25RX0207NMO@80Nj1h0P21U7`208>8P`80NHN;0P28Q882096;MP80M9:70P20
TGl207RFPP80O9ei0P1i?<02080m^P80MYN30P1mVG/206AlX`80MVZR0P1WGkD206ijW@80N8n60P1d
THP207B>RT<0N8b9403oool000h0oooo0P1hS8T207^:Q`80N8V;401hS8T207^:Q`80N8V;201hS8T2
07:?R`80LYF70P22QhD20=V7@`80Vha^0P1cUHD207JDQ@80K9:=0P1hRhX206V4V@80IHRJ0P1/RY<2
06f5UP80J8^E0`1aUhH206nAS0@0LXn;0P1dTHT2076FQ`80MI670P1eSXX207F=RP80N8^90P1hS8T2
07R@QP80M8j:101hS8T207V?Q@80M8f;0P1hTXD207:CR080M9>70P1bThP207R@QP80N8b90P1hSXL2
076EQ`80LYV40P1hTXD207R<R@80N8f80P1gSHT207R<R080Mhf90P1lTX4207V@Q0@0N8b90P1hTH@2
07RAQ@80Ph^10P1hS8T20868Q@80QHZ00P1gWGd207^PN080PIAl0P23R8<207V7R`80R8B20P2ARgH2
07BBQ`80P95o0P1hUX8207bMN@80NCc00P20?KX207JGP`80OIUk0P1TO:<207IZXP80Iene0P1^NYd2
07R?QP80M9680P1dSXY307R<RA00oooo000>0?ooobH0N8b90P1bRXl20;V8FP80c:0k0P1MUiD207mg
TP80RGj50P1_PIL207QlU080JXNF0P1YRID206V:U@80KHZB0`1iQh/207J5S`80N8f80P1aT8/207B>
RP80NXV90P1hQXd207b:Q`80M8n90P1bShX207R@QP80N8b90P1hR8/407R<R@80O8Z70P1hS8T207V?
Q@80N8N<0P1mRHL207RAQ@80LXn;0P1hTXD207B>RP80OHb40P1hS8T207R=R080Mhf90P1hS8P207R<
R@80N8f80P1hTX@207V@Q@80OHb50P1gSHP207NBQ@80N9:40P1gT8H207ZMN`80KiJ80P1cUHH2082M
MP80P9=n0P23SH0208:7Q@80Pheo0P1hVH0206bIR080SWF80P2QPW02076RO`80N9B30P24Fj<205E^
]`80GJ:=0P22Sgl207f2R`80J7BU0P1QMjP205ifZ`80M8F@0P1kSXD207R4S`80OHJ9@`1hS8T@0?oo
o`003P3ooolV07R<R@80LXZ?0P2iR5X20<bP>`80GINE0P1oMi8208UnQ@80Kh6G0P1hO9@206Z7UP80
JHVE0P1YRYD206f:TP<0NHN;0P1fQHl207R=R080LI2;0P1dSXX207Z9R@80N8J=0P1lRXL207B?R@80
LXn:0P1hT8H207R<R@80N8R;101hS8T207b:Q`80N8b90P1iShD207R7S080OHV70P1hTHD207:?R`80
N9:50P1dSXX207f<Q080N8b90P1hSHP207N=R@80N8b80P1hS8T207R=R080N9:40P1iT8D207f<Q@80
Mhf80P1gTXD207RBQ080Mi260P1jWG/206nFR080LiF60P20WGH2082COP80Phf00P22QhD208>=O`80
N9V00P1/VHP208ieR080XH9`0P1aXWl207RDP`80Q5^S0P1EK[L205fRS@80PXmo0P1mPX/206QdY@80
HGNX0P1NMZ/207B5T080Nhj50P1hQ8l207f6RD<0N8b9403oool000h0oooo9P1hS8T207::S`80VJQK
0P3>V40208UbSP80G9n@0P1eWgd206EnX@80N8b80P1ZQiH206b5UP80KHFF0P1^THd306VCSP80LHj<
0P1hS8P207N<R@80LXf<0P1dThH206j>S`80O9230P1fSHT207B=R`80N9260P1dSXX607BBQ`80M8j:
0P1lTH8207BAR080L9J80P1bVH@207RBQ@80LYN50P1_UXP207:@RP80Mi>50P1gSHP207R=R0@0Mhf9
0P1hS8P207R<R@80OY9o0P1bThP407RAQ@80Mi:50P1hSHL207Z@Q080QIAi0P1_TH`207FOO@80N:9i
0P1eW80207RLOP80LYmo0P1hV80208B:P@80Nh>=0P1WYX<208VILP80WFV60P2;H9T206igW`80K7^N
0P1hN9H207b3S080PW6D0P1bK:@206]kW`80EGj/0P1hQ8l20867Q@80LXb=0P1hTXE307R<RA00oooo
000>0?ooobH0N8b90P1bRXl209VXF`80cYQ00P29LXh205bOT080MImm0P1UOZ4207R<R080JXNF0P1/
QIH206f5UP80KY6=0`1YThh2076>S080N8b80P1gS8T207:=S080M9>60P1^SXl207b@P`80MXf90P1d
SH/207R@QP80M8j:1P1dTXL207B>RP80O9620P1dTHP2072FR080LYV40P1hTXD207:GQ@80KiJ80P1b
T8X207NCQ@80Mhf80P1hSHP407N=R@80N8b80P1hS8T207jBO`80LY>8101hTHD207NBQ@80N8f70P1j
T8@208FDN@80Ki6<0P1eWgd207RRN@80MIb00P1hW7h207:OO`80N9R00P24RX4207^3S@80IjJ30P29
VG8209eYQP80Rf2I0P1^Mil206akWP80N7RF0P1lPh`2089aU080LVbT0P1[Nil205En[080N8B?0P21
QhD207:<S@80N9:5@`1hS8T@0?ooo`003P3ooolV07R<R@80LXZ?0P2ZZDl209b7L@80[8mO0P1/Thd2
06j?S@80GIfA0P1RWX`206B?U@80I9:C0P1TVHh206VAT0<0L8^?0P1]TX`207:@RP80MiB40P1]T8h2
07Z;R080L8b>0P1hTH@207J@Q`80LYB70P1bThP207B>RP80N8b90P1hR8/207b?Q080KY>;0P1iU842
07F@R080N8n70P1gUH<206nJQ@80MYN20P1]TX`206nAR`80N8b90P1hT8H207>FQ@80L9F90P1bUhD2
06nJQ@80KYZ60P1hVgh207:CR@80M9>70P1hUh4207:EQ`80LYV30P1cXGh207RIP080N9:50P1lTh42
08>AO@80NhR90P28Qh0208FCNP80L9N70P1eVH82072HQP80QIAi0P1_R982086GNP80IVBb0P2TGXL2
06adX`80N9J10P1UMjD208IjRP80IgFV0P1jGjL207QYX@80LXn;0P1hUH8207B>RP80N8b90`1hQh`2
07f9QR00N8b90P1hQh`207f9QQX0N8b9403oool000h0oooo9P1hS8T207::S`80ZZU?0P2LQg420:b?
G`80K9>=0P1^Shd205fMT@80HYj<0P1TSiD206BBT`80I9V>0P1YTI03072;S`80KI:<0P1bT8X207ND
Q080KI2>0P1jRhP2072<SP80N9640P1fT8L207:DQ`80LY>80P1dSXX207R<R@80N8R;0P1lSh@206jC
R`80NIB10P1eT8P207R?Q`80MiF30P1_VXD207JGPP80KI:<0P1_TH/207R<R@80N9260P1cUXD2072E
R@80LYN50P1_VXD206jJQP80N9]n0P1bThT207BCQ`80N9N10P1bUHL207:IP`80Lj5n0P1hVH0207RB
Q@80O9>10P23TGd207^8R@80R8N00P25TgX2072GQ`80MIV20P1`V8H208FDN@80KhRB0P21UgX206IT
/P80Y5j70P1/M:<207RFP@80IGNU0P26NXX206MeYP80NUnW0P1hJJ4207:?R`80N9F20P1dSXX207R<
R@<0N8N<0P1mRHHP07R<R@80N8N<0P1mRHHJ07R<RA00oooo000>0?ooobH0N8b90P1bSh/20:j4IP80
Xf280P3EXS<205nITP80JH>J0P23R8<206:9V`80JHVE0P1ZSi4206b6UP80KhBE0`1bTXT206jAS080
KYB;0P1hU8<206f;TP80MI280P1dTXL207:CR080Mhf90P1lRhL207F>R@80LY:90P1bU8L206jGR080
MiJ20P1cShX207R@QP80N9650P1cV8<207JKP080LiB70P1dTXL207:@RP80KI:<0P1_WX8206jOP`80
LIV50P1^V8P207:NP080KIV80P1aU8P207ZFO`80Ki6<0P1gU8<207NCQ@80MiB40P1eThH2082@P080
N9F20P1dV8<207NAQP80PXmo0P1hT8H207bNN@80PIAm0P1oQ8T208:7Q@80O7FE0P2FLh@208ImR@80
RF^C0P1UGKP208b=N@80Mh:A0P23MI4206U]ZP80Q7:A0P1hM9X20563[080M8j:0P1hS8T207^:Q`80
N8B?0P1mRHH307:?R`80N9:5501hS8T207R?QP80M8j:201hS8T207:?R`80N9:56P1hS8T@0?ooo`00
3P3ooolV07R<R@80LXn;0P2^Q6H20:=PR080eJ8c0P1OVI8206V3VP80PhR30P1RRI/206V9U@80JXnA
0P1/QYH206n4U@<0LY:90P1^TH`206jDR`80N9B30P1]Ri8207F@R080M9:70P1bThP207N=R@80O8^7
0P1eSXT207:BR@80LYB70P1^UhP207NFPP80Lhn:0P1hT8H207RAQ@80LiR30P1fVh0207>DQ`80M9:7
0P1bT8X206fBS080Kij20P1^Wh<2076IQ@80KYR80P1bWX0206fIR080LIB80P1jUWl206nAS080MiB3
0P1gThD207NDQ080MI>60P20T80207REPP80M9R30P1gTHH208:?O`80N9260P1lWWT2086DO@80OhB9
0P22QhD207aeU@80UW>40P26OHT208U[T`80IEfh0P2<SGT207N2T@80PgFA0P1YKJX208AbT@80N7BJ
0P1APj`207B>RP80N8b90P1kRXL207R4S`80OHV60`1bSh/207RBQA@0N8b90P1hShH207B>RPP0N8b9
0P1bSh/207RBQAX0N8b9403oool000h0oooo:01hS8T208R4PP80UYmT0P3;TTH209mNS080J8JI0P1l
RhH207:5T@80HIRA0P1UVXd205NHV080I9N@0`1aQi4207^:Q`80L9>90P1cT8T206jCR`80KI6=0P1i
RhP207R;RP80M8j:0P1hTXD207JCQ@80LIF70P1aUXL2076FQP80LYV40P1]X8<206RUP`80K::20P1b
VX<207JIP@80KiR70P1_WH<206NQQP80IJF50P1[Y84206^MQ`80KIf40P1[WhD2076LP`80KJ230P1R
Z8H206fTP080Iin80P1]XX8206fTP080JjF10P1YVHX207RIO`80O9>10P1hTHD207>POP80KJUl0P1]
VHP208J9P080Q8Z10P1gPY4208]eRP80NI250P1^UHX208YdS080NW>H0P1UT9@207VMO080KGnJ0P1h
QHd205n2XP80KX>G0P1jKY`207IZXP80N8V;101hS8T207:?R`80N9:56@1hS8T207^:Q`80N8V;9P1h
S8T@0?ooo`003P3ooolX07R<R@80R8B20P2FWf@20<^BAP80Wej<0P1XQYT207b;QP80LXFA0P1QV942
06FJS@80EiRH0P1TUi030767T@80NhZ70P1`ThT207>@R@80KY>;0P1]THd207V;R080N8^:0P1dSXX2
07RBQ@80MY>50P1aUHL2076FQ`80LIJ60P1bVH@206fPP`80J:F30P1/XX8207:JP`80MYV10P1_V8L2
06nMP`80Ij660P1UYHD206^TP@80Jif70P1]WH@206^OQ@80LIb30P1]X8<206:XQP80KJB00P1WWhP2
06fRPP80KJB00P1[YH4206VIRP80N9Uo0P1lTh4207RAQ@80Lj1n0P1]ZG`206fIR080QXV00P24RX42
07N2T@80RgF:0P1iT8D206jERP80RWB<0P1jLiP206F@U080NIel0P1]OiX207R5S@80Gh:R0P1^PiL2
07Y^W080MVZR0P1hRH/407R<R@80LXn;0P1hTXDI07R<R@80NhZ70P1hRH/V07R<RA00oooo000>0?oo
obP0N8b90P28Q88209JOI080bi960P2OGX`206R6V@80O8^60P1bQI42066HT@80IIZ=0P1GV9P206BG
T0<0LHNA0P1kRXL2072CR@80Li290P1^Th/206fAS@80NH^80P1hRhX207B>RP80N9:50P1fThD2076E
Q`80LIJ70P1aUXH207:IQ080KJ230P1XYH<206bRPP80LYZ30P1fVH4206nHQ`80Kif30P1WXHH206FU
Q@80JjB10P1[WHL206fMQ080Jin50P1aW8<206fPP`80HZR60P1]Y80206NOR080KJ:20P1]Y80206^U
P@80JIV:0P1hVGl207bCP@80N9650P1cX7h206fYO080KIV80P26RH0208B:P@80Mh:A0P2;MHX207V@
Q@80KYF:0P2:M8`207YcV080II2D0P1iWG`206eoVP80N8F=0P1OPZ8206j3U`80NVjL0P1fJZ8207R9
R`@0N8b90P1bSh/207RBQAT0N8b90P1kRXL207R9RbH0N8b9403oool000h0oooo:P1hS8T20:i_M080
c5a[0P2cLfh208R2Q080JhfA0P1hS8T2079oUP80MgnB0P1^THd205RRT@<0E:b=0P1SX8X207F<R`80
MHN>0P1lPHd207N5SP80MY>5101aUHL207>EQP80MiYo0P1]VhH206fQP@80Iin80P1bT8X2086BO@80
LYB70P1cU8L2076EQ`80N9ik0P1ZVXT207FPO@80J9Z:0P1aWH8206ZDSP80MZ1l0P1RWh/207:VN`80
H:J80P1bYG/206JTQ@80IYf:0P1`W8<206^OQ@80LiZ20P1dTXP206jMQ080JiR90P1lQH/208N7P@80
Qgn70P2BMHD207mhT@80Q8mn0P21SH42079nU`80O7n?0P2LQ7<2076IQ080E:V?0P1VRIP2085fT@80
RWZ80P1^O9`207eeU@80M6nP0P1aRI0205Im[080N8R<2P1hS8T307R?QP80M8j:801hS8T207R7S080
OHV66P1hS8T@0?ooo`003P3ooolZ07R<R@80[Vmd0P3<G6/20;=cKP80R8:40P1[SI4207R<R@80LWnF
0P1gOi8206jAS@80F::A0`1D[8d206>PRP80MHb;0P1eQhh207b1S@80MhF>0P1fThD4076EQ`80LiF6
0P1gVWl206fKQP80KJ610P1WWhP207:@RP80PI9m0P1bU8L207>DQ`80LIF70P1hWW/206ZJR@80MJ1m
0P1XVXX2076MPP80JYB>0P1fX7`206:OR`80LZIk0P1PYXP207:UN`80IZB50P1VWHX2072LP`80Jin5
0P1cVX8207BBR080KYf40P1[V8T207b5R`80QhN10P27OhL2099eQ@80OgRA0P24Sgh2086=P@80LWjG
0P1lOhl209b4L`80LIV40P1DZHl206J9V080PGJA0P2:NXP206ilW080OGFE0P1dKj020769T080EWf/
0P1hR8`:07R<R@<0N8n60P1dSXXP07R<R@80N8N<0P1mRHHJ07R<RA00oooo000>0?ooob`0N8b90P2Z
LGH20=<fP@80fDU_0P2CKhT207bBPP80GYFE0P1YU8h207JUN080FY:K0`1bQ9<206YkW`80O7bA0P1m
OXl207N8S080N9650P1hT8H207RCQ080L9V50P1_X842076LPP80M9>60P1hTH@207:?R`80J9Z;0P1h
Vgh207J>R@80N9Yo0P1ZWhD207RNN`80K9R90P1hVgh206^BS@80MiR10P1UYHD206nRO`80Ji6>0P1l
XgD206FSQ`80JYN;0P1mTX0206BBT`80N9il0P1YWHL206fIR080L9V60P1gU8@206^SP@80E;J60P1W
[Gh206NLRP80MIeo0P1`UXP208>>O`80PWf<0P1iUH4205^ZR@80N9V00P2HKhD208UNW080KWRN0P1`
U8T207B4T@80OVJO0P1nKiT207RFPP80Hg2/0P1hJJ4407R<R@80N8n60P1dSXX407R<R@<0NhZ70P1h
RH/H07R<R@80N8n60P1dSXX407R<R@80LXn;0P1hTXDJ07R<RA00oooo000>0?ooob`0N8b90P2ZLGH2
0=<fP@80fDU_0P2CKhT207bBPP80GYFE0P1YU8h207JUN080FY:K0`1bQ9<206YkW`80O7bA0P1mOXl2
07N8S080N9650P1hT8H207RCQ080L9V50P1_X842076LPP80M9>60P1hTH@207:?R`80J9Z;0P1hVgh2
07J>R@80N9Yo0P1ZWhD207RNN`80K9R90P1hVgh206^BS@80MiR10P1UYHD206nRO`80Ji6>0P1lXgD2
06FSQ`80JYN;0P1mTX0206BBT`80N9il0P1YWHL206fIR080L9V60P1gU8@206^SP@80E;J60P1W[Gh2
06NLRP80MIeo0P1`UXP208>>O`80PWf<0P1iUH4205^ZR@80N9V00P2HKhD208UNW080KWRN0P1`U8T2
07B4T@80OVJO0P1nKiT207RFPP80Hg2/0P1hJJ4407R<R@80N8n60P1dSXX407R<R@<0NhZ70P1hRH/H
07R<R@80N8n60P1dSXX407R<R@80LXn;0P1hTXDJ07R<RA00oooo000>0?ooo`h0N8b90P1hShH207B>
RP80N8n60P1dSXXH07R<R@80PXN50P32X4<208V;O080TWN40P1nMY<207>1U080TV>B0P29EZ8307mo
S@80HH^J0P1YXHD2066VQ`80JIb90P1eUH@407FGP`80MiF30P1hTX@207F=RP80N9]n0P1YVhT2072A
R`80Mi>40P1`WH<206^JR@80OIIn0P1gTh@207NGP@80Li>80P1hWW`206F=UP80PY9m0P1kPHh2089m
S080N9B30P1nQ8T208mjQ080Ki6<0P1dQI4208:1R@80OXR70P23P8T207R:RP80N8R;0P1lPHd209:@
LP80L8^?0P1dQ94207Z6S080OY=o0P1aT8/207R6S@80OY600P23RX8208EkR`80MH:B0P1hShL206j>
S`80LX:D0P20Iid208QOW080MWnD0P1aUHL208=fS`80GV>i1P1hS8T207^5R`80OHJ98@1hS8T207^:
Q`80N8V;8P1hS8T@0?ooo`003P3oool>07R<R@80N8n60P1dSXX207R?QP80M8j:601hS8T208:7Q@80
`Z130P29Rg`2099gQ080OWJC0P1cPI@2099STP80REJR0`1oOhd2066;VP80JJ650P1QYXL206VLR@80
MIF4101eUh<207NEP`80N9:40P1eSHX207RKOP80JI^90P1`TH/207NCQ080L9f30P1[VXT207fFOP80
Mi>40P1gUh4207>CR080N9il0P1USIH208:BO@80Nh6>0P22OH`207RDP`80OXB90P2?NX@206nAS080
M8FA0P22PHT207j8Q`80Ph290P1hRXX207R8R`80O86=0P2BT782072;S`80M8BA0P1jQX`207jCO`80
LI2;0P1hQXd207jAP080PhZ20P25Nh/207F2TP80N8n70P1^SXl207:2U080P6NM0P28Gi`207IoU080
LIF70P23MXl205iS^@H0N8b90P1kQH/207f6RB40N8b90P1kRXL207R9Rb80N8b9403oool000h0oooo
101hS8T207R?QP80M8j:1P1hS8T207^:Q`80N8V;0P1kRXL207R9RaX0N8b90P32Gg020=1]G080L8b>
0P22S84206ZJRP80CZJE0P1MZXL306fSP080GIZC0P1_TH`207R3S`80M8n:0P1`VX@207>JPP80LY:9
0P1kUgh2072HQP80L9N70P1nVgT206bCS@80JYj60P1/Wh@207NHP@80K9>=0P1hVgh207B>RP80PY9l
0P1_WX<207RCQ080IYn90P1WXXH206ZDS@80L9J80P24Tg/206BGT080N9R00P22QXD206IkX`80Rj=Z
0P1NX8h2076NP@80LXR@0P1kRXL206jPP@80Oi]h0P1hT8H2062VR080GkYk0P1Q/gh2062LS`80IZV2
0P1/[7X206JNR@80KYn20P1XU8h207R4SP80O6VN0P23H9l207QRYP80QI1l0P1/UX/207RUM`80AG^k
0P1hMIT607R<R@80LXn;0P1hTXE707R<RA00oooo000>0?ooo`@0N8b90P1hShH207B>RPH0N8b90P1k
RXL207R9R`80NhZ70P1hRH/J07R<R@80`Um`0P3@KE`2072<SP80PXb10P1ZVXX204jVU@80GJZ70`1]
Xh0205fJT`80Ki6<0P1hPhl207B?RP80L9Z40P1cVX8207:BR@80NiMn0P1`V8H2072GQ`80OY]i0P1/
Thd206ZNQP80K9n40P1gV84206bCS@80N9]n0P1dSXX208:BO080Kij30P1hTh@206JOR@80Ij:60P1Z
U8d2072FR080Q9=k0P1TUi0207RHP080PXJ50P1VNj<208^SJP80GZ2>0P1aWX4207:8T080NhZ70P1^
X84207nKN080N9260P1PYXP205njN`80HK=n0P1PW8l206JYPP80K:aj0P1VWXT206jOPP80J9B>0P1h
Q8h207aYWP80Pf2O0P1hHZH208F@O080K9J;0P1hYGL204Ek^`80N7FI1P1hS8T207:?R`80N9:5A`1h
S8T@0?ooo`003P3oool407R<R@80NhZ70P1hRH/X07R<R@80LXn;0P3CG6H20<a9N@80SHEm0P24PHL2
07=^X@80PgBA0`24MXl207i^V@80NWZD0P1hRXX207^;Q`80OYIm0P1`VXD206bJR080N9N10P1hTXD2
076@R`80Q8b00P1hQh`207fBP080KYF:0P1dSXX207RAQ@80Miim0P1UWXX207R/LP80KXf@0P1lP8h2
08fBM@80HJZ40P1DXi<206^XOP80IYZ<0P1oPhX407R<R@80IJ^10P1cZWL207AoU@80OZQ`0P17`HP2
05BeQP80M:9l0P1]WHD207RFPP80Nh:=0P2<NHL208I]T`80Og^?0P23QHD208>6Q080MH:B0P22NHl2
07eA[P80W5VA0P1gJZ4207QcVP80L<5Y0P1?_H@206^TP@80MGZG0P1MClP207f9QP`0N8b90P1hShH3
07B>RT00N8b9403oool000h0oooo101hS8T207^:Q`80N8V;:01hS8T207:?R`80deaV0P3<BGT208f5
O@80Q8670P1cKZ4208=dT@<0Q7J?0P1nKYT207YjU080N8Z:0P1kRhL207jFO@80L9Z50P1/VXP207RG
P@80N9:50P1aT8/208B<P080N8N<0P1mTX0206jERP80M8j:0P1hTHD207NNO@80IIj:0P1h[78206j=
T080O82>0P2=TWD2066ZQ080E:>C0P1[Z7h206JJS080Oh>:101hS8T206F[P@80LjYg0P1dOiD207jX
L080Al680P1D]HH207BRO080KIf50P1hUX8207^2S@80S7V70P26KI<207mkS`80PhF50P23QX@207F2
TP80PWV?0P1mDJh209aIT@80MfZQ0P1hLiX20731J@80Ckf40P1[Y84207EjU`80GDo80P1mRHH<07R<
R@80N8n60`1dSXY007R<RA00oooo000>0?oooc80N8b90P1bSh/20;^OB@80UHMf0P1mW7T204fXU@80
F[am0`1?]8/205>OU`80K9B<0P1fShP207F>R@80RHij0P1mSh<2076EQ`80LI^30P1bUHL2076@R`80
N9N10P1bW88207BGQ080N8R;0P1bUhH2072JQ080P8R50P1oV7/207MlU@80QWJ>0P1bY7`207R0T@80
[Vmd0P1VRiL207R<R@80L8Z?0P1V[Gl206JPR080K:Um0P1fXW/206bHR@80FkJ00P1hYWL207mmS@80
Jh2K0P1nU7h207>BR080M8N?0P1gSHT207:KPP80IZB50P1XWhL207:6T@80SF^@0P2?GiL208YNW080
KGNO0P1hP94208AaT`80M:]f0P2>Zf82061c[080RY=f0P13Gm02079gW080N9:5101hS8T207R?QP80
M8j:0P1hS8T207R?QP80N8b90`1hRH/H07R<R@80N8n60P1dSXX207R<R@80N8N<0P1mRHHN07R<RA00
oooo000>0?oooc80N8b90P1bSh/20;^OB@80UHMf0P1mW7T204fXU@80F[am0`1?]8/205>OU`80K9B<
0P1fShP207F>R@80RHij0P1mSh<2076EQ`80LI^30P1bUHL2076@R`80N9N10P1bW88207BGQ080N8R;
0P1bUhH2072JQ080P8R50P1oV7/207MlU@80QWJ>0P1bY7`207R0T@80[Vmd0P1VRiL207R<R@80L8Z?
0P1V[Gl206JPR080K:Um0P1fXW/206bHR@80FkJ00P1hYWL207mmS@80Jh2K0P1nU7h207>BR080M8N?
0P1gSHT207:KPP80IZB50P1XWhL207:6T@80SF^@0P2?GiL208YNW080KGNO0P1hP94208AaT`80M:]f
0P2>Zf82061c[080RY=f0P13Gm02079gW080N9:5101hS8T207R?QP80M8j:0P1hS8T207R?QP80N8b9
0`1hRH/H07R<R@80N8n60P1dSXX207R<R@80N8N<0P1mRHHN07R<RA00oooo000>0?oooc@0N8b90P2]
JWP20<bDA080L9J70P1lHj<209UeP0<0M82D0P1NSiX2066ET`80LXn;0P1fThD207ZFP080Pj5a0P1V
WhT207BKP@80JXjA0P1hS8T207fBP080Ni]l0P1ZT90207B@R@80Oi=n0P1`QI<207bAPP80RH>20P1/
V8T2062`P@80Phf00P1NVY8207RMO080ShIl0P1OTiH207RLOP80NI640P1[U8`207bEO`80MYB50P1e
ThH208B5Q080N86@0P1hTh<206>RR080K9j50P1eRh/206jCR`80LY^30P1gThD207^1SP80O6fK0P1n
MI@2072;T080L9R60P1ORYd207ikT080Kj=o0P1=dGP2076aL`80OG>G0P1nN98208EFY080KTbm0P1d
THP207B>RP80N8b90P1hShH207R<R@80N8V;0P1hShH207R<R@80N8V;0`1hQh`207f9QPH0N8b90P1h
Qh`207f9QP`0N8b90P1kRXL207R9R`80N8b90P1bSh/207RBQAh0N8b9403oool000h0oooo=01hS8T2
0:eZN080c9A40P1`UXL207aSX`80VGF00`1dP9@205j?VP80HIFC0P1bSh/207JCQ@80NYJ00P23XG42
06JOR@80M9^10P1ZSY4207R<R@80OI:00P1kVg`206Z@T080M9290P1oTgh20725T`80O9620P29Ph82
06bHR@80H;210P23SH0205jJTP80N9el0P2?QW`205nCUP80N9an0P1iTH@206^DS080O9Eo0P1fU8D2
07FCQP80Q8F40P1hPI0207RCP`80Hj:80P1/WXD207F;R`80KY>;0P1bVh<207NCQ@80Nh6>0P1lKI/2
07ieU080L8^@0P1`V8H205n:W@80OW^@0P1_Xgl204gAN080LK5c0P1mLiL207ihTP80QEJT0P1^C;d2
07BAR080M8j:0P1hS8T207R?QP80N8b90P1hRH/207R?QP80N8b90P1hRH/307R7S080OHV61P1hS8T2
07R7S080OHV6301hS8T207^:Q`80N8V;0P1hS8T207:?R`80N9:57P1hS8T@0?ooo`003P3ooold07R<
R@80LXn;0P3VEe/20<a7NP80GkUk0P1CYY8308=cT@80O7VC0P1]TXd2066AUP80PHJ60P23QHD209VF
J080KhJD0P1oT80206JJS080IZ280P1gWWd207bHO080J8bE0P1eTHL207bHO@80I9N@0P1hWg/206RD
SP80T9a[0P1VP9h407n<P`80K9n40P1`/G@206F0W`80R91j0P1`VHD2076@R`80N9:40P1mSX<207NA
QP80L9R60P1`XH0206fUO`80KYF90P1/Thd206VOQP80K9F;0P1hO9@208YnQ@80LHFB0P1VPIh207ec
U`80TFj;0P2:EJ42091KVP80N8f80P2@Vf/208:@OP80IgfP0P1bWX0205Yd/@80N4^g0P21NHl20867
Q@80M8^<0P1hS8T207^:Q`80N8V;0P1hS8T207^:Q`80N8V;0P1hS8T307:?R`80N9:51P1hS8T207:?
R`80N9:5=01hS8T@0?ooo`003P3ooold07R<R@80LXn;0P3VEe/20<a7NP80GkUk0P1CYY8308=cT@80
O7VC0P1]TXd2066AUP80PHJ60P23QHD209VFJ080KhJD0P1oT80206JJS080IZ280P1gWWd207bHO080
J8bE0P1eTHL207bHO@80I9N@0P1hWg/206RDSP80T9a[0P1VP9h407n<P`80K9n40P1`/G@206F0W`80
R91j0P1`VHD2076@R`80N9:40P1mSX<207NAQP80L9R60P1`XH0206fUO`80KYF90P1/Thd206VOQP80
K9F;0P1hO9@208YnQ@80LHFB0P1VPIh207ecU`80TFj;0P2:EJ42091KVP80N8f80P2@Vf/208:@OP80
IgfP0P1bWX0205Yd/@80N4^g0P21NHl20867Q@80M8^<0P1hS8T207^:Q`80N8V;0P1hS8T207^:Q`80
N8V;0P1hS8T307:?R`80N9:51P1hS8T207:?R`80N9:5=01hS8T@0?ooo`003P3ooold07R<R@80N8n6
0P1dSXX20<aJK@80mDQK0P1XV8`303[2T080FZ^90P1]V8P205n4X@80MXV<0P23SGl209ZJIP80Jif6
0P1/Si0208R4PP80L8FC0P24OHT2091hQ@80NXj50P1WUHl208B:P080MiJ20P1^TX`207R5SP80T91d
0P1VQIX207b:Q`80Ph>60P2?PGl208jELP80@jRL0P1cYWX207Q`W080Sh9n0P1eTHL207RON`80KI6=
0P1oS8<207jBO`80Ni630P1ZThh206jNP`80JZ250P1OUYD205jDUP80NGfB0P2>FY`208E]U080J8RG
0P1hOY8206nCR`80HMMU0P1=bWd206bQP`80RhIo0P1TUY4207V6S080C4cG0P1bQY4207:EQ`80Ni23
0P1hRH/207R<R@80N8n60P1dSXX207R7S080OHV65@1hS8T207R?QP80M8j:401hS8T207R7S080OHV6
6P1hS8T@0?ooo`003P3ooold07R<R@80N8n60P1dSXX20<aJK@80mDQK0P1XV8`303[2T080FZ^90P1]
V8P205n4X@80MXV<0P23SGl209ZJIP80Jif60P1/Si0208R4PP80L8FC0P24OHT2091hQ@80NXj50P1W
UHl208B:P080MiJ20P1^TX`207R5SP80T91d0P1VQIX207b:Q`80Ph>60P2?PGl208jELP80@jRL0P1c
YWX207Q`W080Sh9n0P1eTHL207RON`80KI6=0P1oS8<207jBO`80Ni630P1ZThh206jNP`80JZ250P1O
UYD205jDUP80NGfB0P2>FY`208E]U080J8RG0P1hOY8206nCR`80HMMU0P1=bWd206bQP`80RhIo0P1T
UY4207V6S080C4cG0P1bQY4207:EQ`80Ni230P1hRH/207R<R@80N8n60P1dSXX207R7S080OHV65@1h
S8T207R?QP80M8j:401hS8T207R7S080OHV66P1hS8T@0?ooo`003P3oool:07R<R@80N8n60P1dSXXV
07R<R@80NhZ70P1hRH/207:?R`80bWiD0P3IJET306j4U@80F:R<0P1DW9P205VGV080HIj=0P1hT8H2
0:6AIP80R8ik0P1KTIX207N@QP80N9B30P1O[8D206RSQ080Q9Uf0P1UVh`206JOR080Q8ao0P1`SHh2
06ZOQP80OHV60P1nOh`2072JQ080KY:<0P25Q8@20:McM`80SUnG0P20R8D205BXS`80L:9o0P20R8D2
08Z3PP80N7JH0P29Ph4208UXU@80XVF40P2<JY42091VT@80UeBH0P2AD:0208]QV@80LfjQ0P1bOIL2
08QUV080VG>10P1QU9@207j^K080R[=P0P1GTid206R=T`80N8B>0P2CLhH206Xmb`80N5^[201hS8T2
07R7S080PHN50P1hS8T206jAS080N9:51`1hS8T207R7S080OHV62P1hS8T207^:Q`80N8V;0P1hQh`2
07f9QP`0N8b90P1bSh/207RBQAX0N8b9403oool000h0oooo2P1hS8T207R?QP80M8j:9P1hS8T207^:
Q`80N8V;0P1bSh/20<YnE080fFUI0`1^Q9D205RXS080E9bH0P1IUiP2066NS@80N9260P2QTFH208R>
N`80Fi6J0P1gT8H207RDP`80Gjb50P1XXh@208BIMP80II^<0P1VWhP208B<O`80L8f>0P1ZWhH207f9
QP80OWn<0P1`VX@206jBS080QHB40P2WLgL208iOU`80P8R50P1DZ8l2072RO`80P8R50P2:Ph8207Qf
V080RH>10P29J9D20:9UQ080S6ZA0P2@IY4209MDV080TE2P0P2;HIT207=^X@80LWfG0P28IIP209Uc
P@80HIBD0P1n[V`208ZcH080Ei>M0P1XSI<207R4SP80Tg>60P1Z?L/207QKZ`P0N8b90P1hQh`20867
Q@80N8b90P1^TH`207RBQ@L0N8b90P1hQh`207f9QPX0N8b90P1kRXL207R9R`80N8N<0P1mRHH<07R<
R@80LXn;0P1hTXDJ07R<RA00oooo000>0?ooo`X0N8b90P1kRXL207R9Rb`0N8b90P2BOWl20=aQG0<0
`5Uf0P28M8d206FET080C[b60P13^I4205BeQ`80OHV60P2]QFH206JGSP80GY^A0P1nSH<208N4P`80
L9B90P1iXWP2076KP`80Hin;0P1UXHL207BHQ080LXj<0P1/Si0207RMO@80N9F20P1VQYX207j4RP80
RX>20P23PHP209B5N@80PVJL0P2;NhL207REPP80MgZF0P26MXh208UoQ@80LHFC0P24QX@208YYU080
SEnH0P2:F:0209=YS@80Q7:B0P1mI:4208UjR@80FijA0P1l/F/206VKR@80P[AU0P22Rh8207YRY@80
O7n?0P1/UXX206QA_P80OD^b0P1hQh`207f4RP80OHV60P1hShH207B9SP80N8n60P1dSXX20867Q@80
N8b90P1dSXX207R7S080OHV60`1hS8T207:?R`80N9:53P1hS8T207:?R`80N9:51P1hS8T207R7S080
OHV6801hS8T@0?ooo`003P3oool:07R<R@80NhZ70P1hRH//07R<R@80TWio0P3LHE`30<1IMP80R7B=
0P1UUI0204jlQP80@kVA0P1D]HL207f9QP80[HEV0P1VUhh205jKT@80OXf30P27Q8<2072DR@80NJ9h
0P1aVh<206>OR`80IJ670P1dV8@207:>S080K8n@0P1hWGd207REPP80IXJJ0P1nQ8X208Z3PP80Ph68
0P2DQGT2089VW080Rg^70P1hUH8207MjUP80QWJ>0P29OhD20765T`80Q8J40P2:JI@208eOV080RURP
0P2CJHd208AbTP80OFBQ0P29NXT205^NT@80O;5[0P1YVhT208:dI@80PX^20P1jHZD207aoS`80K9J:
0P1XDKh207e;/P80N8N<0P1mQ8X207f9QP80N8n60P1dRHh207R?QP80M8j:0P21QhD207R<R@80M8j:
0P1hQh`207f9QP<0N8b90P1bSh/207RBQ@h0N8b90P1bSh/207RBQ@H0N8b90P1hQh`207f9QR00N8b9
403oool000h0oooo=01hS8T207R7S080OHV6101hS8T209ehNP<0cVYP0P2RNWD208>4QP80Q7V=0P1]
O9`207:;S@80F92N0P2RPG420:=bN`80K9>=0P1RTID208B8PP80R8N00P24Mhl209J0NP80MHb;0P1a
SX`20769S`80NHJ<0P1dRXd208>IM`80KH6I0P1iPHl206b6U@80RhIn0P20NXl209YTR`80RGJ;0P28
V7@207j3RP80JH2L0P1mR8L208=dT@80T6R@0P2:IiD208E`T`80OFbL0P1oLYD208]mQ@80Pi5l0P1?
]8/205o0MP80HL9d0P1IeF`204O8P`80MIF40P1mKIX207B;S080LHNA0P29=KT207Q0_P80N9:5101b
Sh/207f9QP80PHN50P1bS8d207^:Q`80N8V;0P1hTXD207^:Q`80N8V;0P1bSh/207RBQAl0N8b90P1b
Sh/207RBQB00N8b9403oool000h0oooo=01hS8T207R7S080OHV6101hS8T209ehNP<0cVYP0P2RNWD2
08>4QP80Q7V=0P1]O9`207:;S@80F92N0P2RPG420:=bN`80K9>=0P1RTID208B8PP80R8N00P24Mhl2
09J0NP80MHb;0P1aSX`20769S`80NHJ<0P1dRXd208>IM`80KH6I0P1iPHl206b6U@80RhIn0P20NXl2
09YTR`80RGJ;0P28V7@207j3RP80JH2L0P1mR8L208=dT@80T6R@0P2:IiD208E`T`80OFbL0P1oLYD2
08]mQ@80Pi5l0P1?]8/205o0MP80HL9d0P1IeF`204O8P`80MIF40P1mKIX207B;S080LHNA0P29=KT2
07Q0_P80N9:5101bSh/207f9QP80PHN50P1bS8d207^:Q`80N8V;0P1hTXD207^:Q`80N8V;0P1bSh/2
07RBQAl0N8b90P1bSh/207RBQB00N8b9403oool000h0oooo=01hS8T207:CR080M9>60P1hS8T207R?
QP80M8j:0`2ZLGH20==DJ`80Yge_0P1ZThh206b6UP80Mh:@0P1`Q9@2076;SP80Xg9k0P2WKW/206^2
V@80N:5j0P1bSh/207R8R`80S8In0P2@L8X208B:P@80IY^<0P1V[Gl205ZQT080PYQh0P1MQJ4207VB
P`80IGnP0P2:Ph8207aKZ@80Ve2I0P2iDh020;M9R080YS^O0P2U@Y/209mDT`80T5^I0P2@EId20:1=
U`80X5n:0P1nL9L207nMM`80Hl5c0P1Z/7T207NHP@80KJMn0P1fY7T208J1QP80PU^T0P1oGj<208>6
Q080NXn50P1V@LX207Q@/`80N9:50P1hQh`207f9QP80LXn;0P1bUHL207RBQ@80N8b90P1bSh/207RB
Q@80N8n60P1dSXX207R<R@80N8N<0P1mQ8X307f9QT00N8b9403oool000h0oooo=01hS8T207:CR080
M9>60P1hS8T207R?QP80M8j:0`2ZLGH20==DJ`80Yge_0P1ZThh206b6UP80Mh:@0P1`Q9@2076;SP80
Xg9k0P2WKW/206^2V@80N:5j0P1bSh/207R8R`80S8In0P2@L8X208B:P@80IY^<0P1V[Gl205ZQT080
PYQh0P1MQJ4207VBP`80IGnP0P2:Ph8207aKZ@80Ve2I0P2iDh020;M9R080YS^O0P2U@Y/209mDT`80
T5^I0P2@EId20:1=U`80X5n:0P1nL9L207nMM`80Hl5c0P1Z/7T207NHP@80KJMn0P1fY7T208J1QP80
PU^T0P1oGj<208>6Q080NXn50P1V@LX207Q@/`80N9:50P1hQh`207f9QP80LXn;0P1bUHL207RBQ@80
N8b90P1bSh/207RBQ@80N8n60P1dSXX207R<R@80N8N<0P1mQ8X307f9QT00N8b9403oool000h0oooo
=01hS8T207^:Q`80N8V;0P1hS8T207^:Q`80N8B?0`1mRHH20:9eN080gS=k0P3=BWL207>?RP80H;Im
0P1:ZiD206>8V`80OX2=0P2WLWP209I`QP80SgV50P1oLiD208F2QP80PGn;0P24MHl20:I>TP80/eB4
0P2JNW/206anW080Q91l0P1OR9d207MiU`80MVbQ0P29OhD205^NT@80BjZE0P1lTH8208emP`80OW2H
0P2;KI0209EUSP80TW:70P1`V8H205^mO080H[Yi0P1Q]g`207BiK080OYQk0P1bSX`207RWM@80L9n1
0P1eOY@2089aU@80KW2S0P1iTX<207R<R@80QcNi0P1b@l4207RBQ@80N8n60P1^TH`207RBQ@80N8n6
0P1dTHP207B>RP@0N8b90P1hShH207R<R@80N8V;0P1hS8T207:?R`80LYF70`1hTXD207R?QP80M8j:
?01hS8T@0?ooo`003P3ooold07R<R@80NhZ70P1hRH/207R<R@80NhZ70P1hQ8l307f9QP80XWEh0P3N
<g/20<e:M`80Lhn:0P1P]Wd204Z[U@80HhRK0P1nP8d20:MbN080UW260P2?NHD207mcU@80QH:60P21
Oh/208AeS`80YTjB0P2cE8@209YjN`80K7jL0P24T7`205n8W@80MgVG0P1fK:4208UoQ@80FijA0P1;
ZYD207bAPP80SGf30P1nL9P208]]T080UFF>0P2BLXL2072HQP80Fkel0P1R^WT2066gO080M;U/0P1n
V7/207:>S080N:Me0P1`Wh4207EnU080PW6E0P1^L:<207VBP`80N8b90P27=kT20793`@80N9:50P1h
ShH206jAS080N9:50P1hShH207BAR080M8j:101hS8T207R?QP80N8b90P1hRH/207R<R@80LXn;0P1b
UHL307RBQ@80N8n60P1dSXXl07R<RA00oooo000>0?oooc`0N8b90P1bRXl307f?P`80N8b90P1mRHL2
0<MHLP80f5iQ0P2=S7T205b3Y080DinG0P1JXY0207N0TP80YgAf0P2=Ii<209ANU080W5n=0P2HDI/2
09e?V080R7R:0P2GHI020=0RTP80a@2b0P3T0iP20<P<Y`80YcJR0P2EEiT209Y[QP80W5^@0P22H:02
07f3R`80OXB:0P1hPI4207>JPP80ILM]0P1C^X<207f[K`80L:Qj0P1UYX@2076PP080OIig0P1^V8P2
07JOO@80O7n?0P2DF9P208QUV080OWf>0P1ZTXl207Q;]`80`AVS0P1hC[@207R7S080OHb40P1hS8T2
07R9R`80N8b9101kRXL207B;S0@0N8b90P1kRXL207R<R@80M8j:0P1hS8T207R7S080OHV60`1hS8T2
07^>Q@80M8^<0P1hS8T207R?QP80M8j:0P1hQh`207f9QS80N8b9403oool000h0oooo?01hS8T207::
S`<0OHn30P1hS8T207f9Q`80aeQb0P3HGV4208f<N@80G8>T0P1CWiL205ZRT080Mh2B0P2WM7H208eW
T`80U5jD0P2LGhd209QAV`80WDnH0P28N8X209MQT080d2:B0P350;820>@3V080b0bW0P2W=Z8209EG
V@80VV^60P2LFi02089PX080OH>;0P1nQ8X207R1T@80LiZ20P1Uafd205>jP`80OJ]_0P1`Z7X206FV
Q080LJ200P1mWWL206jHR080MYmm0P1lOhl209AHV080R6FH0P1nOHh206ZBS`80N4^g0P316J<207Q>
]080N8N<0P1mS8@207R<R@80N8V;0P1hS8T407^:Q`80M8^<101hS8T207^:Q`80N8b90P1dSXX207R<
R@80N8N<0P1mRHH307R<R@80Nhj50P1dRh`207R<R@80N8n60P1dSXX207R7S080OHV6<P1hS8T@0?oo
o`003P3ooolX07R<R@80N8N<0P1mRHH@07R<R@80LXZ?0`1mSh<407R<R@80LXn;0P3<IFD20=hGS`80
^6Ya0P1KYX/204fLW@80DjFC0P1bUXH208AaTP80PFbH0P2ELh@207QgU`80PHN50P2AMXD207E`W`80
Mi>50P1LY8`206BZPP80LZ5n0P1cShX207j1S080SWb30P1nOhd207b8R@80OYAn0P1[[7/205JTT@80
OJU`0P26UWL206n3U@80QZQZ0P1`VHD207RKOP80Ij270P1lRXL208A`T`80V5VD0P2>DJ4208MiR`80
Ohb30P1hMIT209Hd/@80LT?10P1hUH8207B>RP80LY>80P1hTXD207R9R`H0N8b90P1kRXL207R9R`80
N8n60P1dSXX207R<R@80NhZ70P1hRH/207R<R@80LXn;0P1hTXD307R<R@80NhZ70P1hRH/207R<R@80
NhZ70P1hRH/207:?R`80N9:53P1hS8T207R7S080OHV60P1hS8T207R7S080OHV60P1hShH207B>RQH0
N8b9403oool000h0oooo:01hS8T207R7S080OHV6401hS8T207::S`<0OHn3101hS8T207:?R`80c6EU
0P3N5hl20;QZL@80FjJ;0P1=W9d205>UT`80LYJ60P24LI82085/V080UG>40P1hMiL20867Q@80TGJ5
0P1eL9l207NCQ@80G:B<0P1TZX8207:QOP80Lhn:0P1nPH`208ilP`80OWn=0P1lR8T207jDOP80Jjak
0P1FY94207fYL080QYIg0P1_PiD208JXJP80L9V50P1hVgh206NPQ`80O8Z70P24L9<209QIU080SU6Q
0P27NH/207n<P`80N7FI0P2F=;420793`@80N9F20P1dSXX207:CR080N9:50P1hRH/607R<R@80NhZ7
0P1hRH/207R?QP80M8j:0P1hS8T207^:Q`80N8V;0P1hS8T207:?R`80N9:50`1hS8T207^:Q`80N8V;
0P1hS8T207^:Q`80N8V;0P1bSh/207RBQ@h0N8b90P1hQh`207f9QP80N8b90P1hQh`207f9QP80N8n6
0P1dSXXF07R<RA00oooo000>0?ooobP0N8b90P1bSh/207RBQ@`0N8b90P1hQh`207f9QP80LXZ?1@1m
RHH207R7S080OHV60P1hS8T208QnQP80i4eT0P3:BWT206f7U@80Gin>0P1DUId206NKRP80HJ6;0P1]
WH@207:@RP80N8J=0P1nPXX207R6S@80PhJ40P21M9<208MhR`80QH270P1gQ8l207:;S@80OI:10P1j
TH<207FGP`80OY:00P2AT7<205nUR@80JjMo0P1jXWP205j^Q080P:Ea0P1`OiL209:?L`80LWJL0P22
II`208U[TP80NGfB0P1eVX4207F>RP80RdnU0P2M<:h207QKZ`80N8b90P1kSXD207B;S080NhZ70P1h
RH/207R7S080OHV60P1hQh`207f9QP80N8b90P1hShH207R<R@80N8V;3`1hS8T207R7S080OHV6301h
S8T207R7S080OHV61P1hS8T207R7S080N8b90P1hTXD207R<R@80LXn;0P1hS8T20867Q@80N8V;5P1h
S8T@0?ooo`003P3ooolX07R<R@80LXn;0P1hTXD<07R<R@80N8N<0P1mRHH207::S`D0OHV60P1hQh`2
07f9QP80N8b90P28OXH20>A=I080bTYi0P1]QiD205nOSP80E9FM0P1WVhX2066QR`80KIf40P1bT8X2
07R6S@80OX::0P1hQXd208>6Q080PGBC0P27N8/208F0Q`80MhB?0P1bRhd207fBP@80NY630P1eUh<2
07jBP080TI1c0P1OYHT206^WO`80NZ9h0P1N[X@2082UL@80L7nG0P2BSg<2079fW080PVFL0P29Ji82
07UmTP80MIZ10P1eSXX208]?Y@80WC2^0P1hFj/207R<R@80Nhj50P1dRh`207^:Q`80N8V;0P1hQh`2
07f9QP80N8N<0P1mRHH207R<R@80N8n60P1hS8T207R9R`l0N8b90P1hQh`207f9QP`0N8b90P1hQh`2
07f9QPH0N8b90P1hQh`207R<R@80N9:50P1hS8T207:?R`80N8b90P21QhD207R9RaH0N8b9403oool0
00h0oooo>01hS8T207:?R`80N9:50P1bSh/307:EQ`80N9:50P1bSh/207RBQ@80N8n60P1^TH`208:7
Q@80c5I_0P386Yd20<5HMP80HZ:90P1?`H8204nQV@80Kh^A0P1ePY8207R6S@80N8f80P1gT8H207BG
Q080I9J@0P1dWGl2076LPP80KZ610P1R/Wh205o3M@80ElAi0P1J]8<206BRR080Q9mb0P23TGd206V[
O@80JZQo0P1jMYL209EcQ@80N6JS0P2/FXD2091:Y@80R6fB0P21Tgd206f:T`80T4VV0P2_:Z@208Q=
Z@80N7fC101hS8T207^:Q`80N8B?0P1mRHH207R<R@80LXn;0P1hTXD207:CR080M9>60P1hS8T207^5
R`80OHJ90P1hQh`207f9QP@0N8b90P1hShH207B>RP80N8N<0`1mRHH207:?R`80N9:5101hS8T207R7
S080OHV6101hS8T207:?R`80N9:51P1hS8T207:?R`80N9:50P1hS8T207R7S080OHB:0P1hQh`207fB
P080M8j:2P1hS8T207R7S080OHV6201hS8T@0?ooo`003P3ooolh07R<R@80LXn;0P1hTXD207:?R`<0
LYF70P1hTXD207:?R`80N9:50P1hShH206jAS080PXN50P3<EVl20<PJW@80`EQf0P1RXXT204o1PP80
Cj6I0P1_Ri4207F2TP80N8J=0P1hSHP207N@QP80M9N40P1TUY0207BMO`80LIb20P1^XH4206:bOP80
Gl=e0P1Ga7T205ZdP`80I::80P24Wg8208>AO@80JJ]m0P1ZZ7l207YfU`80UG>50P1hIZ<20:aJQ@80
T4ZU0P28KI82086CO@80KHZC0P2@BJH20:lZY080R4fY0P1hOI<407R<R@80NhZ70P1hQ8l207f9QP80
N8b90P1bSh/207RBQ@80LY>80P1dThH207R<R@80NhF;0P1mQXT207R7S080OHV6101hS8T207R?QP80
M8j:0P1hQh`307f9QP80LXn;0P1hTXD407R<R@80N8N<0P1mRHH407R<R@80LXn;0P1hTXD607R<R@80
LXn;0P1hTXD207R<R@80N8N<0P1mQ8X207R7S080OI:00P1dSXX:07R<R@80N8N<0P1mRHH807R<RA00
oooo000>0?ooobH0N8b90P1hQh`207f9QQT0N8b90P1hShH207B9SP80PHN50P1hRH/207::S`80OHn3
0P1hS8T20;UYL080c2>D0P365J820:9UQ080F[650P1;/I02062]P`80HjN60P1[TXh208:2R080N8>?
0P1nRHH208:1R@80RGZ80P2EOGh208meR080UGJ20P1hPI0207:JP`80M8V>0P2FG9@20;mIM`80STRX
0P2@Cj420:=NR080Q7V=0P1^XH42066>V@80PfNJ0P2g=iD20;0VY`80PEBY0P1mQXT407R<R@80N8N<
0P1mRHH207R<R@80LXn;0P1hTXD207R<R@80N8N<0P1mRHH207^:Q`80N8V;0P1hS8T207:?R`80N9:5
0P1bThP207BCQP@0N8b90P1kRXL207R9R`80LXn;0`1hTXD207R7S080OHV60P1hQh`207f4RP80N8N<
0P1mRHH207f4RP80OHV6201hS8T207R7S080OHV6101hS8T207::S`80N8b90P1hTXD207^:Q`80OHJ9
2P1hS8T207:?R`80N9:5201hS8T@0?ooo`003P3ooolV07R<R@80N8N<0P1mRHHI07R<R@80N8n60P1d
RHh20867Q@80N8V;0P1bRXl207f?P`80N8b90P2iJG020<`SU080aQFR0P2RIH@205ZaQ@80Bk6@0P1P
[H<206>WQP80Ji:>0P22PXP207R3S`80OXV60P22PHT208UjR080UGen0P2?MHP209EfPP80N86@0P1b
VX<207B9SP80UUbD0P2oFGL208i8Z080T4nQ0P2SGXP208AiS@80KZ610P1QSYT208=WVP80]cNE0P2`
9ZL2085DZ@80OHJ9101hS8T207R7S080OHV60P1hS8T207:?R`80N9:50P1hS8T207R7S080OHV60P1k
RXL207R9R`80N8b90P1bSh/207RBQ@80LY>80P1dThH407R<R@80NhZ70P1hRH/207:?R`<0N9:50P1h
Qh`207f9QP80N8N<0P1mQ8X207R7S080OHV60P1mQ8X207f9QPP0N8b90P1hQh`207f9QP@0N8b90P1b
RXl207R<R@80N9:50P1kRXL207f6R@X0N8b90P1bSh/207RBQ@P0N8b9403oool000h0oooo901hS8T2
07R?QP80KY6<0P1hTXDI07R<R@80NhZ70P1bS8d207RBQ@80N8b90P1bSh/207RBQ@80N8b90P1hQh`2
07f9QP80N8N<0P2iJG020;TbU`80Y6N20P1`VX@206JAT`80IZB50P1G[XT206JLR`80LIF70P1aSHd2
07b:Q`80RGZ90P2CH9@20:QJR080Y5N=0P2TFhX208QJX080OWVA0P2HNg`20861R@80HJj20P1QYHP2
08QkR@80WdVJ0P2D?jX2089TWP80LX6E0P1hS8T207REPP80M9>6101hS8T207:?R`80N9:5101hS8T2
07R?QP80M8j:0P1bSh/207REPP80M8j:101hS8T207R?QP80M8j:0P1kRXL207R9R`P0N8b90P1hShH3
07B>RP80LXn;0P1hTXD207:?R`H0LYF70P1bV8D207BCQP80N8N<0P1mS8@207B>RP80N8b90P1bSh/2
07RBQ@80N8b90P1hShH206jAS080LYF70P1hTXD207:?R`80N9F20P1dSXXD07R<RA00oooo000>0?oo
ob@0N8b90P1hShH206jAS080N9:56@1hS8T207^:Q`80LXb=0P1hTXD207R<R@80LXn;0P1hTXD207R<
R@80N8N<0P1mRHH207R7S080^FU`0P2i<YL20:AWPP80L9Z40P1VTI<206JTQ@80Ejj90P1VW8/2076E
Q`80LHf=0P1lRXL208UjR@80Tf2D0P2XFXP20:AGS@80Y5^:0P28FZ0207iiT@80V7]l0P21PHT2066^
PP80HJF80P28NhT209m9VP80U3nZ0P22I9h207:1U@80N8b90P1hUH8207BCQP@0N8b90P1bSh/207RB
Q@@0N8b90P1hShH207B>RP80LXn;0P1hUH8207B>RP@0N8b90P1hShH207B>RP80NhZ70P1hRH/807R<
R@80N8n60`1dSXX207:?R`80N9:50P1bSh/607:EQ`80LYR50P1dThH207R7S080OHb40P1dSXX207R<
R@80LXn;0P1hTXD207R<R@80N8n60P1^TH`207:EQ`80N9:50P1bSh/207REPP80M8j:501hS8T@0?oo
o`003P3ooolT07R<R@80NhZ70P1hQ8l207f9QR40N8b90P1hShH207B>RP80N8b90P1bRXl207fBP080
KYB:0P1dThH207R<R@80ZW5f0P2_@i8209Y:WP80ZU:<0P2JDYP208UYU080RGV90P1hMiL208MnQ`80
N9>40P1Q/H0205fiO@80IjF40P1hTXD207:BR@80M9N40P1eSHX209=]RP80ZT>F0P2P?j4209=EV`80
PVfG0P1hPhl207R<R@80LXZ?0P1hS8T2086=P@80N8B?101mQ8X207f9QPH0N8b90P1kRXL207R<R@80
M9680P1hS8T207R9R`@0N8b90P1kRXL207R9R`80N8n60P1dSXX207R7S080OHb40P1dSXX207R<R@80
NhZ70`1hQ8l207f9QPX0N8b90P1kRXL207R9R`80LXn;0P1kRXL207f6R@80N8N<0P1mRHH407R<R@80
NhZ70P1hRH/607R<R@80NhF;0P1mQXT<07R<R@80N8N<0P1mRHH407R<RA00oooo000>0?ooob@0N8b9
0P1kRXL207R4S`80OHV68@1hS8T207R?QP80M8j:0P1hS8T207::S`80OI:00P1^U8X207BCQP80N8b9
0P2ZLGH20:m3TP80VTZN0P2ZDX`209YBV080RFVD0P29NHT207QgU`80Qgj70P1hTh@2066aP080GKUm
0P1WYH@207RBQ@80LY:90P1dUh@207F=RP80Tff:0P2Z@iH20:0oX@80TeFK0P22KIL207R3S`80N8b9
0P1bRXl207R<R@80PHf10P1hQ8l407f4RP80OHV61P1hS8T207^:Q`80N8b90P1dTHP207R<R@80N8V;
101hS8T207^:Q`80N8V;0P1hShH207B>RP80N8N<0P1mS8@207B>RP80N8b90P1kRXL307R4S`80OHV6
2P1hS8T207^:Q`80N8V;0P1bSh/207^:Q`80OHJ90P1hQh`207f9QP@0N8b90P1kRXL207R9R`H0N8b9
0P1kQH/207f6R@`0N8b90P1hQh`207f9QP@0N8b9403oool000h0oooo9P1hS8T207:?R`80N9F20P1d
SXXE07R<R@80N8N<0P1mS8@207B>RP@0N8b90P1kRXL207R<R@80M8j:0P1bSh/207^@P`80NhN90P1h
RH/407R<R@80NhZ70P1kQhT207^2S@80Qh650P22OX/208QjR@80O7^A0P22PXP209=gP`80VVB<0P2J
Fi82091PUP80Sf6F0P2LH8d209IPT@80TV:B0P22KiH207^1SP80N8V;0P1hQh`207f4RP80OHV60P1h
S8T407:?R`80OHn30P1bSh/407:EQ`80N9F20P1dSXX207R7S080OHV60P1hS8T207^5R`80PHB70P1h
RH/207R<R@80N8N<0P1mRHH207R7S080OHV60P1kQH/207f6R@80LY>80P1hTXD207R9R`80N8n60P1d
SXX307:?R`80N9:5401hS8T207:CR080M9>60P1bSh/207R<R@80OHV61P1hS8T207R7S080OHV60P1h
S8T207:?R`80N9:5301hS8T207:?R`80N9:5101hS8T@0?ooo`003P3ooolV07R<R@80LXn;0P1hUH82
07B>RQD0N8b90P1hQh`207f<Q080M8j:101hS8T207^:Q`80N8b90P1dSXX207:?R`80Ni230P1kQhT2
07R9R`@0N8b90P1kRXL207^7R@80Nh:=0P27PHD2089nR`80R7Z90P1lNi4208:2R080TgN30P2JI8`2
09YKTP80T62F0P2?HIH209aPS@80UV2A0P2BHY82089_UP80Nh6>0P1hRH/207R7S080OHB:0P1mRHH2
07R<R@@0LXn;0P1mSh<207:?R`@0LYF70P1hUH8207B>RP80N8N<0P1mRHH207R<R@80NhF;0P21Q8L2
07R9R`80N8b90P1hQh`207f9QP80N8N<0P1mRHH207^5R`80OHJ90P1bThP207RBQ@80N8V;0P1hShH2
07B>RP<0LXn;0P1hTXD@07R<R@80LY>80P1dThH207:?R`80N8b90P1mRHH607R<R@80N8N<0P1mRHH2
07R<R@80LXn;0P1hTXD<07R<R@80LXn;0P1hTXD407R<RA00oooo000>0?ooobP0N8b90P1kRXL207R9
RaD0N8b90P1bSh/207^@P`80N8V;101hS8T207R?QP80N8b90P1hRH/207R?QP80M8V>0P1mRHH407R<
R@80N8n60P1dSXX207R?QP80KY6<0P1hTXD207R7S080OHb40P1dSXX207R<R@80NhZ71P1kQhT207:7
T@80OHn30P1hS8T207R?QP80M8j:101hS8T207:?R`80LYF70P1hTXD207R7S080OHV60P1bRXl207f?
P`@0N8b90P1hShH207R7S080OHJ90P1bRXl407f9QP80LXn;0P1hTXD407R<R@80LXn;0P1hTXD207:?
R`80N9:50P1bRXl207fBP080N8n60P1dRh`207R?QP80N8b90P1hRH/=07R<R@80N8N<0P1mRHH407R<
R@80NhZ70P1hRH/207R<R@80LXZ?0P1mSh<407R<R@80N8n60P1^TH`207R<R@80OHB:0P1mRHH>07R<
R@80N8N<0P1mRHH207R?QP80M8j:403oool000h0oooo:01hS8T207^:Q`80N8V;5@1hS8T207:?R`80
Ni230P1hRH/407R<R@80N8n60P1hS8T207R9R`80N8n60P1dRHh207f9QP@0N8b90P1hShH207B>RP80
N8n60P1^TH`207RBQ@80N8N<0P1mS8@207B>RP80N8b90P1kRXL607^7R@80LXNA0P1mSh<207R<R@80
N8n60P1dSXX407R<R@80LXn;0P1bUHL207RBQ@80N8N<0P1mRHH207::S`80OHn3101hS8T207R?QP80
N8N<0P1mQXT207::S`@0OHV60P1bSh/207RBQ@@0N8b90P1bSh/207RBQ@80LXn;0P1hTXD207::S`80
OI:00P1hShH207B;S080N8n60P1hS8T207R9R`d0N8b90P1hQh`207f9QP@0N8b90P1kRXL207R9R`80
N8b90P1bRXl207f?P`@0N8b90P1hShH206jAS080N8b90P1mQ8X207f9QPh0N8b90P1hQh`207f9QP80
N8n60P1dSXX@0?ooo`003P3ooolZ07R<R@80N8N<0P1mRHHM07R<R@80NhZ70P1hRH/207R7S080PH:9
0P1hRH/207RBQ@80N8b90P1hShH207R<R@80N8V;0P1kQH/207f6R@80N8b90P1bSh/207^:Q`80OHJ9
0P1hS8T207R7S080OHV6101hS8T207:CR080M9>60P1hS8T207^:Q`80N8V;101hS8T207R?QP80M8j:
0P1hQh`207R<R@80N9:50P1bRXl407f9QP80N8b90P1kRXL207:?R`80M9>60P1bSh/207:HQ@80M9>6
0P1hQh`207f9QPH0N8b90P1hQh`207f9QP80N8b90P1bSh/207^@P`80NhN90P1hRH/207^:Q`80N8V;
0P1hS8T307R7S080OHb40P1dSXX607R<R@80LXZ?0P1mSh<207R<R@80N8N<0P1mRHH207R<R@80N8n6
0P1^TH`207RBQ@@0N8b90P1kRXL207R9R`80LY>80P1^TH`207f?P`h0N8b90P1bSh/207RBQ@80NhF;
0P1mQXT@0?ooo`003P3ooolZ07R<R@80N8N<0P1mRHHM07R<R@80NhZ70P1hRH/207R7S080PH:90P1h
RH/207RBQ@80N8b90P1hShH207R<R@80N8V;0P1kQH/207f6R@80N8b90P1bSh/207^:Q`80OHJ90P1h
S8T207R7S080OHV6101hS8T207:CR080M9>60P1hS8T207^:Q`80N8V;101hS8T207R?QP80M8j:0P1h
Qh`207R<R@80N9:50P1bRXl407f9QP80N8b90P1kRXL207:?R`80M9>60P1bSh/207:HQ@80M9>60P1h
Qh`207f9QPH0N8b90P1hQh`207f9QP80N8b90P1bSh/207^@P`80NhN90P1hRH/207^:Q`80N8V;0P1h
S8T307R7S080OHb40P1dSXX607R<R@80LXZ?0P1mSh<207R<R@80N8N<0P1mRHH207R<R@80N8n60P1^
TH`207RBQ@@0N8b90P1kRXL207R9R`80LY>80P1^TH`207f?P`h0N8b90P1bSh/207RBQ@80NhF;0P1m
QXT@0?ooo`003P3ooolR07R<R@80N8N<0P1mRHH207R<R@80N8n60P1^TH`207RBQ@80N8n60P1dSXXE
07R<R@80N8n60P1dRHh207f9QP80N8b90P1bSh/207:HQ@80M9>6101hS8T207^:Q`80N8b90P1dRHh2
07R?QP80M9>6101hS8T207::S`80OHn30P1hS8T207:?R`80N8b90P1mRHH207R?QP80N8b90P1hRH/2
07R?QP80M8j:1P1hS8T207^:Q`80N8V;0P1bSh/207RBQ@80N8b9101bSh/207f?P`80N8b90P1hShH2
07R<R@80N8B?0P1mRHH207^:Q`80N8V;0P1bThP207B>RP80OHB:0P1mRHH207R<R@80LY>80P1dSXX2
07f9QPH0N8b90P1hQh`207f9QP@0N8b90`1bRXl2086=P@80N8V;0P1hS8T207R7S080OHV60P1bSh/2
07R<R@80OHV60P1bSh/207R<R@80OHB:0P21QhD207R9R`80N8N<0P1mRHH407R<R@80N8n60P1hS8T2
07:<S@80N9:52P1hS8T207R7S080OHV6101hS8T207:?R`80N9:5403oool000h0oooo8P1hS8T207R7
S080OHV60P1hS8T207R?QP80KY6<0P1hTXD207R?QP80M8j:5@1hS8T207R?QP80M8V>0P1mRHH207R<
R@80LXn;0P1bV8D207BCQP@0N8b90P1kRXL207R<R@80M8V>0P1hShH207BCQP@0N8b90P1bRXl207f?
P`80N8b90P1bSh/207R<R@80OHV60P1hShH207R<R@80N8V;0P1hShH207B>RPH0N8b90P1kRXL207R9
R`80LXn;0P1hTXD207R<R@@0LXn;0P1mSh<207R<R@80N8n60P1hS8T207R4S`80OHV60P1kRXL207R9
R`80LY>80P1dSXX207f4RP80OHV60P1hS8T207:CR080M8j:0P1mRHH607R<R@80N8N<0P1mRHH407R<
R@<0LXZ?0P21SH4207R9R`80N8b90P1hQh`207f9QP80LXn;0P1hS8T207f9QP80LXn;0P1hS8T207f4
RP80PHN50P1hRH/207R7S080OHV6101hS8T207R?QP80N8b90P1bS8d207RBQ@X0N8b90P1hQh`207f9
QP@0N8b90P1bSh/207RBQA00oooo000>0?ooob80N8b90P1bSh/207RBQ@80N8b90P1kRXL207R9R`80
N8N<0P21QhD207R9RaD0N8b90P1kRXL207:<S@80N9:5101hS8T207^:Q`80N8V;1P1hS8T207^>Q@80
KXj>0P1kT8<207R9R`80N8N<0P1mS8@206jAS080N8b90P1mRHH207R<R@80LXn;0P1hTXD207^5R`80
OHJ90P1hQh`20867Q@80N8V;201hS8T207R?QP80M8j:0P1hQh`207f9QP80N8b90P1bSh/207RBQ@80
N8b90P1kRXL207R9R`80LXn;0P1hTXD407R<R@80NhZ70P1bS8d207:HQ@80M9>60P1hS8T207^:Q`80
LXb=0P1hTXD207R<R@80N8n60P1dRHh207R?QP80M8j:0P1mRHH207R<R@<0LXZ?0P1mSh<207R<R@80
N8n60P1^TH`207RBQ@80N8b90P1bSh/207RBQ@80N8b90P1bSh/207:EQ`80N9:50P1hS8T207:?R`80
N9:50P1hShH207B>RP80NhZ70P1hRH/<07R<R@80N8n60P1^S90207f?P`P0N8b9403oool000h0oooo
8P1hS8T207:?R`80N9:50P1hS8T207^:Q`80N8V;0P1hQh`20867Q@80N8V;5@1hS8T207^:Q`80LXb=
0P1hTXD407R<R@80NhZ70P1hRH/607R<R@80Nhj50P1^SXh207^@P`80N8V;0P1hQh`207f<Q080KY6<
0P1hS8T207f9QP80N8b90P1bSh/207RBQ@80NhF;0P1mQXT207R7S080PHN50P1hRH/807R<R@80N8n6
0P1dSXX207R7S080OHV60P1hS8T207:?R`80N9:50P1hS8T207^:Q`80N8V;0P1bSh/207RBQ@@0N8b9
0P1kRXL207:<S@80LYR50P1dThH207R<R@80NhZ70P1bS8d207RBQ@80N8b90P1hShH207B9SP80N8n6
0P1dSXX207f9QP80N8b90`1bRXl207f?P`80N8b90P1hShH206jAS080N9:50P1hS8T207:?R`80N9:5
0P1hS8T207:?R`80LYF70P1hTXD207R<R@80LXn;0P1hTXD207R?QP80M8j:0P1kRXL207R9R``0N8b9
0P1hShH206j<T080OHn3201hS8T@0?ooo`003P3ooolX07R<R@80N8N<0P1mRHH207:?R`80N9:55@1h
S8T207R?QP80M8j:4P1hS8T207^>Q@@0M8j:0P1hS8T207:?R`80Ni230P1hS8T206j<T0@0OHV60P1h
S8T207R7S080N8n60P1dThH207:?R`80N9:5101hS8T207R7S080OHV6101hShH207B;S080LXn;0P1h
S8T207f<Q080M8j:0P1hQh`207f9QP80N8N<0P1mRHH207R<R@80N8N<0P1mRHH207R7S080OHV60P1h
S8T207^:Q`80N8V;0P1hS8T207R7S080OHV6101hS8T207^:Q`80LXb=0P1kTh4206j>SP80N8b90P1m
RHH307:?R`80N9:50P1hQh`20867Q@80N8V;0P1hS8T207R7S080OHV60P1hQh`207f9QP80N8b90P1h
Qh`207f<Q080M8j:101hS8T207^:Q`80N8V;0P1hQh`207f9QP80N8b90P1hQh`207f9QPH0N8b90P1k
RXL207:<S@80N9:5101hS8T207R?QP80M968403oool000h0oooo:01hS8T207R7S080OHV60P1bSh/2
07RBQAD0N8b90P1hShH207B>RQ80N8b90P1kSXD407B>RP80N8b90P1bSh/207^@P`80N8b90P1^S904
07f9QP80N8b90P1hQh`207R?QP80M9>60P1bSh/207RBQ@@0N8b90P1hQh`207f9QP@0N8n60P1dRh`2
07:?R`80N8b90P1mS8@207B>RP80N8N<0P1mRHH207R7S080OHV60P1hS8T207R7S080OHV60P1hQh`2
07f9QP80N8b90P1kRXL207R9R`80N8b90P1hQh`207f9QP@0N8b90P1kRXL207:<S@80Ni>10P1^SXh2
07R<R@80OHV60`1bSh/207RBQ@80N8N<0P21QhD207R9R`80N8b90P1hQh`207f9QP80N8N<0P1mRHH2
07R<R@80N8N<0P1mS8@207B>RP@0N8b90P1kRXL207R9R`80N8N<0P1mRHH207R<R@80N8N<0P1mRHH6
07R<R@80NhZ70P1bS8d207RBQ@@0N8b90P1hShH207BAR100oooo000>0?ooobP0N8b90P1bSh/207RB
Q@80N8N<0P1mRHHE07R<R@80NhZ70P1hQ8l207f9QP80N8b90P1hShH207B>RP80N8n60P1dSXX607R<
R@80NhZ70P1kQhT207R4S`80OHV6101hS8T207^:Q`80LXb=0P1bUHL207RBQ@80N8n60P1^S902086=
P@80N8V;201hS8T207:?R`80N9:50P1kRXL207^7R@80N8V;0P1hShH206jAS080NhZ70P1mQXT207::
S`80OHn30P1bSh/207RBQ@80N8n60P1^S90207fBP080KXb@0P1mSh<407R<R@80N8n60P1dSXX207:?
R`80N9:5201hS8T207^:Q`80N8B?0P1hShH207BGQ0<0M8j:0P1hS8T207:?R`80N9F20P1dSXX207R<
R@80LXn;0P1hTXD207::S`80OHn30P1hS8T207:?R`80Ni230P1hRH/407R<R@80N8N<0P1mRHH207:?
R`80N9:50P1hS8T207:?R`80N9:5301hS8T207R?QP80M8j:0P1kQH/20864Qa00oooo000>0?ooobP0
N8b90P1bSh/207RBQ@80N8N<0P1mRHHE07R<R@80NhZ70P1hQ8l207f9QP80N8b90P1hShH207B>RP80
N8n60P1dSXX607R<R@80NhZ70P1kQhT207R4S`80OHV6101hS8T207^:Q`80LXb=0P1bUHL207RBQ@80
N8n60P1^S902086=P@80N8V;201hS8T207:?R`80N9:50P1kRXL207^7R@80N8V;0P1hShH206jAS080
NhZ70P1mQXT207::S`80OHn30P1bSh/207RBQ@80N8n60P1^S90207fBP080KXb@0P1mSh<407R<R@80
N8n60P1dSXX207:?R`80N9:5201hS8T207^:Q`80N8B?0P1hShH207BGQ0<0M8j:0P1hS8T207:?R`80
N9F20P1dSXX207R<R@80LXn;0P1hTXD207::S`80OHn30P1hS8T207:?R`80Ni230P1hRH/407R<R@80
N8N<0P1mRHH207:?R`80N9:50P1hS8T207:?R`80N9:5301hS8T207R?QP80M8j:0P1kQH/20864Qa00
oooo000>0?ooob`0N8b90P1bSh/207REPP80M8j:3`1hS8T207R?QP80M8V>0P1mRHH207:?R`80N9F2
0P1dSXX207^:Q`80N8b90P1hShH207B;S0@0N8b90P1hQh`207f4RP80OHV60P1bSh/207RBQ@80N8n6
0P1dSXX607R<R@80N8n60P1hS8T207:<S@80N8b90P1mRHH207R?QP80M8V>0P1mRHH807R<R@80N8N<
0P1mRHH207^5R`80OHJ90P1bThP207B>RP80N8b90P1hUH8207B>RP80N8n60P1hS8T207:<S@80NhZ7
0P1hRH/207RBQ@80N8n60P1dSXX207^:Q`80N8B?0P1mS8@207B9SP80OHV60P1hShH207B>RP80N8n6
0P1dRHh207R<R@80NhZ70P21Q8L307R9R`80N8b90P1hShH207R<R@80N8V;1P1hS8T207:?R`80N9:5
301hS8T207:?R`80N9:50P1hShH207B>RQ80N8b90P1kRXL207R9R`80LXn;0P1hTXD@0?ooo`003P3o
ool/07R<R@80LXn;0P1hUH8207B>RPl0N8b90P1hShH207B9SP80OHV60P1bSh/207REPP80M8j:0P1k
RXL207R<R@80N8n60P1dRh`407R<R@80N8N<0P1mQ8X207f9QP80LXn;0P1hTXD207R?QP80M8j:1P1h
S8T207R?QP80N8b90P1bS8d207R<R@80OHV60P1hShH207B9SP80OHV6201hS8T207R7S080OHV60P1k
QH/207f6R@80LY>80P1dSXX207R<R@80N9F20P1dSXX207R?QP80N8b90P1bS8d207^:Q`80N8V;0P1h
TXD207R?QP80M8j:0P1kRXL207R4S`80OHb40P1dRHh207f9QP80N8n60P1dSXX207R?QP80M8V>0P1h
S8T207^:Q`80PHB70`1hRH/207R<R@80N8n60P1hS8T207R9R`H0N8b90P1bSh/207RBQ@`0N8b90P1b
Sh/207RBQ@80N8n60P1dSXXB07R<R@80NhZ70P1hRH/207:?R`80N9:5403oool000h0oooo;P1hS8T2
07^:Q`80N8V;3`1hS8T207^:Q`80LXb=0P1hTXD207R<R@80NhF;0P1mQXT207R7S080PHN50P1kRXL2
07B6T080OHB:0P1mRHH207:CR080KY6<0P1mSh<407R<R@80NhZ70P1hRH/607R<R@80NhF;0P1mPH`2
07f9QP80LXn;0P1hTXD207^:Q`80LXNA0P1mSh<807R<R@80LXn;101hS8T207RBQ@80NhZ70P1bS8d2
07RBQ@80NhF;0P1mPH`20862R@80OH6<0P1mRHH207:?R`80N9:50P1hS8T207^>Q@80M8^<0P1hQh`2
07R<R@80Ni230P1bS8d207R<R@80PH:90P1mPH`20862R@80N8V;0P1hTXD207:?R`80N9:51@1hS8T2
07^5R`80OH6<0P1mRHH607R<R@80N8n60P1dSXX:07R<R@80N8N<0P1mRHH207R<R@80NhZ70P1hRH/2
07R7S080OHV61P1hS8T207R7S080OHV60P1hQh`207f9QP80N8b90P1hQh`207f9QP80N8b9403oool0
00h0oooo;P1hS8T207^:Q`80N8V;3`1hS8T207^:Q`80LXb=0P1hTXD207R<R@80NhF;0P1mQXT207R7
S080PHN50P1kRXL207B6T080OHB:0P1mRHH207:CR080KY6<0P1mSh<407R<R@80NhZ70P1hRH/607R<
R@80NhF;0P1mPH`207f9QP80LXn;0P1hTXD207^:Q`80LXNA0P1mSh<807R<R@80LXn;101hS8T207RB
Q@80NhZ70P1bS8d207RBQ@80NhF;0P1mPH`20862R@80OH6<0P1mRHH207:?R`80N9:50P1hS8T207^>
Q@80M8^<0P1hQh`207R<R@80Ni230P1bS8d207R<R@80PH:90P1mPH`20862R@80N8V;0P1hTXD207:?
R`80N9:51@1hS8T207^5R`80OH6<0P1mRHH607R<R@80N8n60P1dSXX:07R<R@80N8N<0P1mRHH207R<
R@80NhZ70P1hRH/207R7S080OHV61P1hS8T207R7S080OHV60P1hQh`207f9QP80N8b90P1hQh`207f9
QP80N8b9403oool000h0oooo901hS8T207R7S080OHV60P1hQh`207f9QP80N8b90P1hShH207B>RP80
N8n60P1dSXX807R<R@<0N8N<0P1mRHH607R<R@80LXn;0P1hTXD207:CR080M9>60P1kSXD206j>SP80
LYR50P1dThH207^:Q`80LXb=0P1hTXD607R<R@80N8n60P1dSXX407R<R@80LXn;0P1bUHL207RBQ@80
N8N<0P1mRHH207R<R@80LXn;0P1hTXD207R7S080OHb40P1dSXX207R7S080OHB:0P1hS8T207RBQ@P0
N8b90P1bSh/607:EQ`80N9:50P1hQh`207f9QP80N8b90P1kRXL207R9R`80LXn;0P1hUH8207B>RP80
N8b90P1bSh/607:EQ`80N8b90P1mRHH207R7S080OHV60`1hS8T207R?QP80KY6<0P1bSh/207f?P`@0
N8b90P1hQh`20867Q@80N8V;2P1hS8T207:?R`80N9F20P1dSXX207R?QP80M8j:0P1bSh/207RBQ@H0
N8b90P1bSh/207RBQ@80LXn;0P1hTXD207R<R@80LXn;0P1hTXD207R<RA00oooo000>0?ooob@0N8b9
0P1hQh`207f9QP80N8N<0P1mRHH207R<R@80N8n60P1dSXX207R?QP80M8j:201hS8T307R7S080OHV6
1P1hS8T207:?R`80N9:50P1bThP207BCQP80Nhj50P1^SXh207:HQ@80M9>60P1kRXL207:<S@80N9:5
1P1hS8T207R?QP80M8j:101hS8T207:?R`80LYF70P1hTXD207R7S080OHV60P1hS8T207:?R`80N9:5
0P1hQh`207f<Q080M8j:0P1hQh`207f4RP80N8b90P1hTXD807R<R@80LXn;1P1bUHL207RBQ@80N8N<
0P1mRHH207R<R@80NhZ70P1hRH/207:?R`80N9F20P1dSXX207R<R@80LXn;1P1bUHL207R<R@80OHV6
0P1hQh`207f9QP<0N8b90P1hShH206jAS080LXn;0P1mSh<407R<R@80N8N<0P21QhD207R9R`X0N8b9
0P1bSh/207REPP80M8j:0P1hShH207B>RP80LXn;0P1hTXD607R<R@80LXn;0P1hTXD207:?R`80N9:5
0P1hS8T207:?R`80N9:50P1hS8T@0?ooo`003P3ooolT07R<R@80LXZ?0P1mSh<207:?R`80N8b90P1m
RHH207^:Q`80N8V;0P1kRXL207R9R`P0N8b90`1bSh/207RBQ@H0N8b90P1hShH207B>RP80NhZ70P1h
RH/207^:Q`80N8V;0P1kRXL207R4S`80OHV60P1hQh`207f9QPH0N8b90P1kRXL207R9R`P0N8b9101h
Qh`207f?P`@0N8b90P1hShH206jAS080Ni230P1hQ8l207R7S0@0N9:54P1hS8T407R7S0@0OHV61P1h
S8T207^:Q`80N8V;2P1hS8T207::S`80OHV60P1hQh`207f?P`<0N8b90P1kRXL207R9R`80LXn;0P1h
TXD407R<R@80LXn;0P1hTXD:07R<R@80N8N<0P1mRHH207^>Q@80M8^<0P1kSXD207B;S080N8b90P1h
Qh`207f9QP80N8b90P1hQh`207f<Q080M8j:301hS8T@0?ooo`003P3ooolT07R<R@80LXZ?0P1mSh<2
07:?R`80N8b90P1mRHH207^:Q`80N8V;0P1kRXL207R9R`P0N8b90`1bSh/207RBQ@H0N8b90P1hShH2
07B>RP80NhZ70P1hRH/207^:Q`80N8V;0P1kRXL207R4S`80OHV60P1hQh`207f9QPH0N8b90P1kRXL2
07R9R`P0N8b9101hQh`207f?P`@0N8b90P1hShH206jAS080Ni230P1hQ8l207R7S0@0N9:54P1hS8T4
07R7S0@0OHV61P1hS8T207^:Q`80N8V;2P1hS8T207::S`80OHV60P1hQh`207f?P`<0N8b90P1kRXL2
07R9R`80LXn;0P1hTXD407R<R@80LXn;0P1hTXD:07R<R@80N8N<0P1mRHH207^>Q@80M8^<0P1kSXD2
07B;S080N8b90P1hQh`207f9QP80N8b90P1hQh`207f<Q080M8j:301hS8T@0?ooo`00o`3ooolQ0?oo
o`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?oo
o`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?oo
o`00o`3ooolQ0?ooo`00G03oool2@0000280oooo0T00000G0?ooo`900000Q@3oool005h0oooo00=0
00000?ooo`3oool08@3oool00d000000oooo0?ooo`0F0?ooo`03@000003oool0oooo0880oooo001@
0?ooo`=000000`3oool3@00000<0oooo0d0000050?ooo`03@000003oool0oooo0080oooo00=00000
0?ooo`3oool0103oool014000000oooo0?ooo`3oool5@00000040?oood0000100000@00000<0oooo
1T000000103ooom000000?ooo`3oool2@0000080oooo0d0000000`3ooom00000@00000020?ooo`03
@000003oool0oooo00=00000403oool2@0000080oooo0d0000020?ooo`=000000`3oool2@0000080
oooo0d0000030?ooo`900000F@3oool00540oooo00=000000?ooo`3oool00`3oool01D000000oooo
0?ooo`3ooom000000080oooo00=000000?ooo`3oool01`3oool00d000000oooo@000000:0?ooo`04
@000003oool0oooo@0000080oooo00E000000?ooo`3oool0oooo@00000020?ooo`03@000003ooom0
00000080oooo00=000000?oood0000000P3oool014000000oooo0?oood0000030?ooo`06@000003o
ool0oooo@000003ooom000000P3oool00d000000oooo0?ooo`0=0?ooo`03@000003oool0oooo00<0
oooo00=000000?ooo`3oool00P3oool01D000000oooo0?ooo`3ooom0000000@0oooo00=000000?oo
o`3oool00P3oool014000000oooo0?oood00001H0?ooo`00D@3oool00d000000oooo0?ooo`030?oo
o`05@000003oool0oooo0?oood0000000P3oool00d000000oooo0?ooo`090?ooo`03@000003oool0
oooo00P0oooo00=000000?ooo`3oool00`3oool01D000000oooo0?ooo`3ooom000000080oooo00=0
00000?oood0000000P3oool00d000000oooo@00000050?ooo`05@000003oool0oooo0?oood000000
0P3oool00d000000oooo@00000020?ooo`03@000003oool0oooo00d0oooo0d0000030?ooo`03@000
003oool0oooo0080oooo00A000000?ooo`3oool0oooo0d0000020?ooo`03@000003oool0oooo0080
oooo00=000000?ooo`3oool0F@3oool00540oooo0T0000030?ooo`900000103oool3@00000T0oooo
0T00000;0?ooo`03@000003oool0oooo0080oooo0T0000040?ooo`=0000000D0oooo@00004000010
00000?ooo`04@0000080oooo0T0000020?ooo`A000000`3oool3@00000l0oooo0d0000020?ooo`=0
00000P3oool3@0000080oooo0d0000020?ooo`=0000000<0oooo@000040000000T00001I0?ooo`00
D@3oool014000000oooo0?oood00000C0?ooo`03@000003oool0oooo00X0oooo00=000000?ooo`3o
ool0303oool00d000000oooo0?ooo`020?ooo`03@000003oool0oooo02D0oooo00=000000?ooo`3o
ool00P3oool00d000000oooo0?ooo`0;0?ooo`03@000003oool0oooo05T0oooo001@0?ooo`E00000
0P3oool00d000000oooo0?ooo`0>0?ooo`=000002@3oool3@00000@0oooo00=000000?ooo`3oool0
1@3oool2@00000X0oooo00=000000?ooo`3oool0803oool00d000000oooo0?ooo`020?ooo`03@000
003oool0oooo06H0oooo003o0?ooob40oooo003o0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-7.15527, -3.20068, 0.495855, 
  0.495855}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .65625 
%%ImageSize: 450 300 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.31746 0.015625 0.31746 [
[.5 .66875 -17 0 ]
[.5 .66875 17 12.5625 ]
[ 0 0 0 0 ]
[ 1 .65625 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .66875 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Angle) show
93.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
0 0 m
1 0 L
1 .65625 L
0 .65625 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.015625 0.321429 0.313244 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00751202 0.0192308 0.00751202 [
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(180) show
81.000000 12.812500 moveto
(deg) show
99.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(.) show
105.000000 12.812500 moveto
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
128 string
128 128 8 [128 0 0 128 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
87888C87828886878E8189738787888C83878787879B8349
B08E8187838D87818E88878881878D878B87848787878788
7F9087878D878787878787858A82878A8B82878787878787
878788878689878788878797917E56A3878D878287878C87
878787878D87858A8E838B8787828D82828780878A878785
9E876A9C978E8B82
87888B8B898781818D8683737587878C87878787889B9749
9C8C828783888D878D8D87878281878C8B87878787878F8D
7F888E888D8E8D8A8B8D8D858D87828A8D87878785878787
878787878687898D87878796A0874D95A687878287878C8C
8C8686868B87888791898D8D8D87878782877F8083878780
82817D92A18E8B87
898A8A87878D8D87878D88816F73878888888A87878B9762
73BD888587878C87838788878887838E948484878784878E
8E8C91928C888B8A84878D87878E87878382828685828787
87878787878682878787878796A06F4A78B28D8787828387
8D888E8E8B83888388878887838783878386878683838392
936E7988A1958983
86868686828782838982878C897475758289878B888B979B
427D9888827E878D8D8D8E8787878285918B878782878187
8784848D928E888B87878887878888888387858483828284
828287878786878787878787878CA0914472A68187868181
838181878B878B878B878786888787818785888287778787
879674839A8B918D
8887878D86878B848D8783828386817A7082838287848795
7C649686867E878787828D8E888781828787888D878C817E
81817E828C8E8D88908F908787878B918D878D9183838A87
8B828588848487878483838783878CA0914A999587848487
878788848784878287888B868783878383828D7D847C7C87
6A907687A1877D87
8789868A8B898986878E8B8B898782867472808385838997
97647588867D82838D87828887878D8D888D8D87878E8787
8787837D808A91898489878E888787878D87858B8B888886
89868287868483878B87878B8787848CA071618E998B8783
848787888586878687878D8C878783878D89979688819B96
8C926D87928B8684
878981848289848E848784878787898784786F7583838283
91906F838B82817E82888C8E8E88879292888D8D87928787
84838484797E7E8D828E86918E8E9088888A8D8A878C8B8B
8B8D8B8D87888B878B888888878B89878CA17861798D8B8B
888B878B878789868982878787878D8894949587946F9083
88977E978E878981
878D8C8B848B8187848D868E8D87878B8787837779828283
8392837083B186868687878787888D878787878B87928E8B
8B87878A81877D8B8B8D888B87899292928E918E888E8E8D
8E888E8C8D8E8A89888E8E8E8E8C8E8E8697A68E72888988
878B8A8D8986898787828C8C8C888C9387959C8BA097918C
928381A18F868E87
878884898487848D87868482868D8A878B8784877A7E797D
7B788377497491898183878787817E8A8383827D7D86928D
8B87878A84827B7E86827E8A828283838C8C929792969392
98929C979296979792929292888C888E888C9BA29782839A
AC988E928D8B8B8D8D87838787A488858397A08778878E87
838387918F868689
828786878C87828387878E8987868C848D8E828D828B8487
8D87878787616E8EA17A87918387818E8E93928E87828D8E
8B8B85878787877E878C84878386827D7D7B777B777E817D
817D817D81817C7E7C7D7D817E8B81817E83817D9190745F
7387CE92978E8D8E8DA3B8B8969287807C878E8D877D82A4
8179A18D93898481
8E8A8D838D8B8E898784838986838786848B828B848B8487
8B8789838D866773AB928C91888781817D8A8B8987828B8E
878D8B8D8784847F83878787838787878387878B817E817E
838486827E838687868787877E87878C828C82828289918B
82387C6F94AAAA9D9E8D7D878D929C8987936E8992898C8C
827D8894898E8E89
81828D87848682848A8C86848B878984898B878789878284
84878D898A876A6C79968B94A387878C818C88898D82878E
8887888B8B878B8383838C8C8787878787837F878F8C8C82
8183898C8D8B8783828F87878787878C838D878E87828887
918F96715F5F7AA1958D87878E8EA29A88A7749C9673A296
799B708C8487868D
8D878387878D87868383878987828B87848487828C8B8787
8687868489866F8266879779B2C08D87828A878789898B8E
878788888B838B8787838387878787878787877F87878C87
8C86838887878C8C868D878787838B87828C868C87878D87
87889BA2A7AF817A8D8A8D878C8887858CA46D8C97799887
819B8787848D8287
82878B87868C838D878E828D8789838D8787878887878789
82878A8782877379625D9B787AB5D1878D878D908883888E
878787878B8787878787878C8C8C8D878C87878387878C87
878E878687878786888C8D878E848C878387898C8C868C88
91888C8F8F87877C7B79919287888C87888D839292879087
8C92848A818C8B87
8D898684868E8287818C828B88878787878C87878D878987
8686828B86897C9276628C877C78CEDA968888848B878B8E
8D878787888C878787878383838787878C8C878383838B8B
868686878B87898A8A898F8187838C8E8381878789878B88
888881808A8287928A777C918C8799899D8A817D7D8D7997
908A87868C898A81
87898D89868D878E878E84828787878C878289828B868789
878789848487799273625F87727476D4D98791889183878C
8787878783878C8C87878C8C878C8B89878787878C838389
8B8A8D848786878790868E878C87868C8C8A949292999292
87979C998D7D799F93836F77878C9B8E9083968787827D88
958B8F8887868D84
898982868787868884878B8B838B838687828B84868C8783
8B888E8787847E817A7269877B7A767FD9E08D819487878E
8C878C8C8C87838C8C8387878383868B8E8C8C8983878A89
89878D8D8D868B83908F918B879187948781858781878D97
94927E9997876C888290878D7D778C8E8C879287A0878789
88878E8D86868D84
868C8A82878289848784898D848C878E8B898D8483838B87
8286898787868D8190678282767E7E7678E0FA8A908D8B8D
8D898787878C83878787878C878983858B8B889087838386
8687868B928B868787828D8A8391878B8D898387878B948E
7A878385878C878E8794979794877B87878C878787877C87
8D80818984828787
8987878B8781878C8B83828B888A84848282878B8D87878B
82868687888280778D547E82727A877E787AE0F4878D838C
87898787878C878783878787868787838687838B898A8889
87898385878D878A948A8F8E7F8C8D8888918788929687A0
7F828F88878788937B77778177878783848788878C959187
888A87878B878B8D
8187848E878B8384878B878984848D8E8B8B84828987848D
898784868889847C87617E82817A7D7E7B8781E087918887
8788898387838C8C8787878B87878A858989878B898E8787
878787878A8D8C878C8A7D928D92919086989188729E738F
8E9C96878C90878D877F7C8D877989868788878887878B81
868387878B848787
8787848C898B8D87898486898782848489878B8687878787
848787828784837F84787E777D8874766E7A87D5D08C8887
82878E838C87878787878587898B8B838887868487848E87
848387858787948E878787928D888F898392879775727F7A
7280837D838693879B98878D9690928787898789877E8D86
878D8A8487868B87
8784838884878B8687838787878487888B8489878E87828D
8B848C868987897C7378877B7D83768774808588E790878D
81878E878B8A878B8A86878886868B8983898B8387878692
8B898A878C878792887D878787829199919C788299888887
9A918882878CA474887F8D798781878787888C9187878E8B
8287878784898784
878787878784848787838B87878782878C828484868E8287
8788898381818876846F87838D8F788B7B7C7E7BF3878C8D
87868983898B83898B8B89878986868B8784878B87908787
888783878291919291879197938D87868E947C8286939389
98918783857997809682A28D88969687878C7D8188878A87
818B8787878B8D87
878287838D87878B8787878B878784838B8B87878487848B
828787878382876F8777797D7E7F838D87837B70EA838C81
888B87858587878786878D87898F8D8B8F868E858787878C
8B8C89878C8798938388878C8887947C8A94717B7C888875
8D918F84817888828F8787938D79878187879287848C8E8C
8A87878684828787
87878B828787878B848787878787878784878784878B848B
868B8B8B87827D6D7E808083877178877A828C87F0839188
8D898686918D888B8D878D9087878A8A8D8B878B8B8D8788
8788877F8890878D8F978D9487887E83879F877C76818F8A
8D87998B987F7F778887798E9C898E838782818C838C8786
8787848B8D8B8D8B
878487878B84848B8784878B8787848784848787848B8487
87848988827D7C7B8277798287798D8F877A8D7DF084877E
87898D7D808D86878A87878D8A8B878D878D8384888C8D87
87878283888E8687878F8D928D908B998F93878276788587
96878987A08B87808987768792888D878B8D8E8C8386868B
878B848284868787
87878784878B87878B8D848787878B878787878787878487
8E8689878B81697F87857B8F8A7E937D7D768776EA879087
8B838D8F808D87858A8B878B8D8F888C8C8B8C878A868E88
88878B81918380858D8B8B828487838E919E9287917D8279
8796A0878D8F8876878A8D92928791898E8181878F87848B
8487878784878784
87878B8B84878B8482878B8D87848B87878B8B898D878784
84818B8489876C7E7C8775847386877C768F9987E67E9187
9187838F87878D87888C8887878C9090948E8E8589878D8D
8D8787878F948D888C877E878C8181848792928277776F77
8E8A94939887888887888E988888968787928787848B8487
87878B8784878D84
8B87848787878C8D8D8782878789878B8487838787848487
87878D8487767B7F7F7E8295788E8091778A908CEA7E8D82
878787878D888C87838C898A878282878D8D908787878787
8D8D88917B868F8E848F877F9F9F9A8B7D87929D8E92825C
72878C878DA08787878787A38D88818E828C878D848E8C87
8787878787868784
8487878484868282848787878287898B848C838B878B878B
898684898675817787837F8787957882777E8383E3878D8E
8D8789878387878D87868D8F8D968B8B90878D9687878787
88878094727F918A838F968587A18987978798968E7C8F6F
79857E8F7D98888787918C928791868D8E84878C81868B87
84878D8787878B87
8787878B848B8B8D8B8B878B87838487838D898B89878486
848786877D7B877C877D877D818E7E8A838C878ADC878787
7E85818881847E7E827B818B898791899191898B8B918887
908F8A997578A08C7F91898C72959C78878388A494888980
8191858D8D87798877838999937C8B87878D838784848B87
8782878487848B87
8B8B84878A8A82878487878B87878D87868389868C87848B
8B87898674787D77877E8487738D6F997D87878CCA877981
797976797E7E7F80817A72707D878B8D8B8B95958F878B87
85858D9A7284968F7E858E937A9C9C87818E879D928F7775
6F838391B087788F8787878B897E818C848C8B878B848787
878B878787848787
84878B848187848B8784848787828B84878684838E878784
878786808181807C83838E9582816D988081839DA686877D
8584877F7C7F79828281817D6D717889908785858B938787
8382879D6A7F877387808C9F699B9C9280868E99989D8885
778077839E908082907B9DA5838D928A8D848B848D8B8D8B
8787878B87878482
8B87848C878B89878D87878787878C87878B87848B848B88
87898771777F837E87797F818E72878F8287838387828784
80857D8782857F7F7D827F817D7B6C6B768F8F9085858F87
878B82A2977A9B588787A3B96C7E9B93718779948D92887B
71768B87958D9387937F968B878A89828B84878784828484
8B8B848787878B87
84878687848387828D8B8C8784838C87848B87878B848282
83898E83758281828A9687818E7091877C875E828A8B8387
8187818B878581877F7F797F83837A7B6A718A8D9487928A
84887B87AD67B74B647673BFA668A59D7A9B7B8797989C88
7B5E85918F838F888785A288848E898A878C838B87878B87
848B8B8787848787
87848787878D8782848387878788878C8484878487878787
86847C8572887E7A798887877C7D978B87B889858D8B8B86
87868081808B8587878787817D83817C7B68746B918B8A8A
87887D81BA5D9B755B9687899C5F77877B879A838F8F9D95
7B677E968D9598827B8FA6918186868B838B848B87878787
8484878B8787878B
8D8D878B8287878C878B8B878687868C87878B8C87878E84
86847C7D77827E82829487916F908F81A28B8D8287878B87
8F878E8F8087858788817D81878382837D728168708F8887
8B7C8882C58F6FA5405868AA99B080998D7A898D879F87A3
86597996808B989C8C878D8E8D8D898E8787878784878B87
8B8B848B8B878787
868B848B8787838B87848784848786878784838787818786
8B8085728185887E7C877E8E7A8C808987888A8787878F86
918A8A918A8A908F8E888E8287878885837D7B79636C8C8E
8785847DABBF5B99826778787F9F8187958F82AA7E9E819D
A06F56879C938A9888878B838E89868A87878B8787848787
848B848487878787
8487848B87878487878B8B8B87848787878B8C8D8B8B847D
87838578848288878787808F8399A28787858A8D8D878B8D
929696999890949298929388888183828783807F7D5D5C7C
7F8579819AB89B689365706C79A69574888F809191878F90
8A865F758185879C949686878489868E84848B848D8B848B
8787878784878787
878787878787878784848487878784878486868784878B81
7C8377767786797D90876F8C83768984898584878A88888B
888E9095959195958B90928D928887818783838387836E66
818B82879FA5AE808AB86D854E7CA2947D7A8C7EA0808F87
9D9A5F7788827E9093A6818F868984878B84878784878487
87878B8787878784
87848B87878787878787848B878787878484878C8C848784
8785738283888C748E8B838792E08B8B8D8B8787878AA6AD
9C978D8D8D8D8DA7A3A7AB8E8D8D88828183828181817E65
5887877E99A8B88756A08178765D6D928F7B8793A48D9095
86997B71877D8F918999928D878E8E89878D86878B878487
8B84878B87878B87
87848B8787878B878787848B87878B8C878486838789817C
7E827C7785838C818975818A87838787878884879D7F7783
5D6B8181746B77777C7D9DAB928D8D878187837D83817F80
5956798390ABA1DE6F6EBA789F796A7987808B7B91958198
9093876A98938F9C9C7D8887848C838787878B848B878B87
8787878787878B87
8B8787878787878B878B87878B87868B8B878C87838D7D8B
8E88877F7D94878381988793BE848383878B88698C8787B1
AC96969AB498A29A9875839DB68D8B888281818283817E7E
76594F7A76B47EBDA565A87E85A06F588F7D87809C978890
919D8D6977878A98AE878B86879187828484878487878487
8784878784848784
84878487848B878787878B848787878484868B87868B7681
78807C8A7C907F9282808CA2878787878787A6839CB4ACA0
94A0A8929A9AA9A2B7B8A89ECCC4A187878787827D878182
7779566F849EA0B3B27E74C072A9A6644B7D7D8680988D93
9F95896F6D857692A78E8988848B8E87878B878B84878787
878787878B878B87
8B8B8B8B84848B87848787878487878B87878B8789877C7B
748882878788867883789687878B838287696B4E546A7789
777D7D6971656D7562724E4353748D87878585877B818787
7876664870A2ACA1ACAE56949588B4926C6184878091897E
A89395846D987D968C8B878C8F848B8B87878487878B8787
8B87878787848B87
8484878B87878487848B848B84878484848984868A827D7C
768382748787858D8788E08888878A87837F836350484352
4C485E4C46424B4C5276777B818187878383858983818187
827E6C535B79A687A5BAA170B180BFAD9255777D7E96967E
9690A38C65928AB78E8887878F8484848B87878784878787
878B848787878787
8B8784878487878B8487848B878B8B87838B898486878C7B
77808D8E85879287859299838787858587858D878B86827D
8B7D878D9188928C878C8487837E87888383858583878187
8A8776686276B2878C7C9B5FA29683AA917266717B7B859E
9F99A38C6B8572B787878E878C8787848B87878B8B8B8487
8487878784878787
878B878B8B8B87878C8784878487878B84868789816B7F87
8286758B8783878783D487878B8687858B8289878B878B87
8B838788887E8784828B838B87877D8B8787878183878678
82877668536D95B4AB9DB08774A691AEA38E7B7D778C798C
7E9E9D99718887B592818798878B87848B8787848487878B
8787878B8B878784
8487878487878783878B8787848784878484868789876E78
7A87877D8787978785F187878B8984848789878787878987
868887918787908D848C868C7E8F867D7983878581838787
828A8771617A7EA48F88848B70959DADA4A87C6C6F8F779F
73958F9D7A78969092877C91878787848784878B8787848B
878B848487878787
878487848487878784878B878787878B8B87848376867C73
8776827D8778888987BB89878B878787848387898786878D
87918E9C8B8992928B8A8D8C857F87878686838783878187
7E797E7F685E7D92A2949D968D7394A9B2848E906C876A9B
91968A9D7A6BAA83A181878487878787878B848787878487
878B87878B878787
8B8B87878787878B87878B87878B8484848C87816B758780
889582879392877CC28787878B8787878B87868A87878287
86847D938C8792908D8E8D8C8C90887F7F86798081838187
878282776E6A8AACAE8F9E82A26C877BCE97978E5C87787C
919397A4816D9D809992A18787878787848B878787878784
848787848B878787
84878787878784878784878787878787838784846D767D87
8687937C81878987F3878A8A8D878B83838785878B84A1A8
797C7684B2AC9B90AA998E8D7F8787877F87878385818181
87797E7F78615F92A2A0A1879E838381B2A8959D80718C7E
A38F979D868775A37C998787878787878487878787878787
878787848787878B
8B8B8B878B8B878487878B87878B878787878781687C7A7B
787C878E8B868387DB85878387808B8F838B87868A645A87
857C7552586D7D5F809C99918787878787877E7982818381
87877E777666559A9BA2988F9399719987D089919862916B
958D95A4929D76AF8787878B87878787878B878787878B87
878787878B8B8487
848487848487878B8784878B848787878C8784775C78878C
9388798887798AA4BF89898B8F848087808485878F828781
817E7A7782868A8372819290878785877F878F878181817D
7F8A81837E79478F8CA48C8D7CA9758E62E0858F945B9170
8791939897877583A387848B878787878487878B87848787
87878784848B8787
878787878B8787878787848B87878C838B8B87765A7A896F
808A828586768AB9878984848687878886848387917E8687
8181847C8088898783878D90878A8487857F7F7F8581857D
787C7E7E7D7E4D8096A693B26F9975996FB0979C966A7A82
7E9297A898868B858B878487878787878B8B848787878787
8787878784878787
8787878487848787878B848B8B8387878487847372828299
8D8D8989838E8EFF888B888F878787878687807D8B8B8E8E
87818281878C8C8788898987878A83848787877F7F828781
7F7B797E7D74575497A87D928793718D8EA89D9E947C5A96
829187978D7CAAA0878B878B8B8B8784848B878787878787
8787878B87878787
8B8B8B8787878B8484878484878B848B8787834C6F877A8E
7B8587878E8A85F08A868088888788888888888383878C8E
868B87827B88878287878788888B8B82878487877F828185
81827276797F6E548F90A9939594817A809E938F99924B87
83959BB09A6C878B84878484848787878487878787878B87
8787848B8B878787
848487878787878787878787878787878B8B863F6F7C7C8E
838B875F878A919B898D8687878787828282888780828491
807E7F8682878882878E878387878B7E858586877F878383
8187817879817447909E959F87819B807AA49B83929D5088
6E9D87AD8C85A08787878787878787878787878787848787
878784848787878B
8B8B8B8B84878787878787878B8787848787845B787B8D88
80858A8787957C878987828787828D8D8D87888888847E8B
877D7C77818787888C8E8B8781808F83877E83837E7D7F80
7D7D8278687A82545D8A7A8F95758E87819FA682929E5489
73AC85B49C818E8787878787878787878B87878B8B87878B
878B878787878487
8787848B8787878787878784848B878484876987877CA085
8B886C806DE78C89888C878787828787868287878788838D
87807D7B818D8784878E8A8C87858681878A878383857F83
81817D8770767C7473879292938787827F889F87909D7177
73A88B9BA192878787878787878787848787848487878487
878787878B878787
878B84878787878787848787848B8787878B2D747A769C7A
808A748791B9868C88878787878786888C86878282888387
8788877B818D918887868B8D878D8788878A82868487817D
7D877D8274777878788F8F9A8F98878190A588878790765C
6E8E9CA4A58E878787878787878787878787878B878B8784
8787878487878787
8487878B878B8787878B8787848787878487347E6A759593
81808F74A989868C87878D8D87888787888C8D8D87878787
908181737D85918C8E8E8E8B878C8C818587888B87878783
7D7C8182786E70746E7A8C9295938E888EC37E878F8C925A
968792A8B18C87878787878787878787878784878487878B
8787878787878787
8B8B8487848B878B848B8787878787878B8460977D807688
868091938A838B8687878787828788868790908C8C878786
8A87887779858E92918D988D898B87878D87878987888681
877D807D7C787176757994879A9680817DC18A878885B842
A98F7F98B4878787878787878787878787878787878B8487
8787878787878787
848787878787848B84878787878787848B5571697595758D
788B83DF938693878782878D86878D87918A8C8C918D8089
8A86887D7988888E91888D8B878C8E8E928A888A89878783
83857D827A787174796C949992A1878187B6828D8D62D73D
91AA928AA68787878B8787878787878787878787848B8787
8787878787878787
878787848B8784878B8787878B8B8B878735B36C7A887B7F
769F74958A9490868D8787888C898B7E8697988E8E91878F
9187887D7E878B8A8D95948A8D8C8C8F9497979C97988C8C
80877D81827E7976726870A29CA08E877CBC8A819F5ACD44
7CAE94999D87878487878787878B87878787878784878787
878B878787878787
878787848787878487878B8487848487870FA37198868D78
8B95CF859B9D8D86878787878B98ADB28E8EA69698878187
90868775777E908F8F8196878F919399A5A18F9696998887
909087827C7B777A807B627D8FA78D997DB09A7E9164CC4E
7FB992AB9C82878787878787848787878787878787878787
8487878787878787
8B8B878787878B878B848784878787878D6588729587975C
A07D936E91A28D8C87878B94A78D6D87B8A7A996B1B18787
9387877D77768583A58FD8B9A2856992AF9FA0A0A6AF9788
888786877F7F7E78767A7D6E8DA78792879A8D788C6FD042
78A67FA3978787878787878787878787878787878B878787
8787878787878787
8487878787848784878787878B8787874B7F6A6A7D998F66
A4F07C78839C87868C8A878788806A818BABA59881AD9696
928787837D7686879F6066AE73738E7499819E7096B5A58E
8F88828781797B807C808F819CAE8787A59A917E956EC252
A29887AD878787878787878787878787878B8784878B8787
8787878787878787
8787878787878787878B878487878787364E7C9275A18F71
68D5768B969D928886897D9BE7B4557945CF92C8A1A89B91
8E8782827D796E7D87A660AADC4E9E4EDB7DBD69B4AFA79B
9B8D8783907D79807F8072798EAEAD7BA192967D8779B843
BA9E90A78787878787878787878787878487878784878787
8787878787878787
8787878787878787848787878787878DC759626C6F8F8787
87BB7B8792978B83827A747AACC1B1EA6B9A6D928F878B90
8B8B838280826D726F889C84AE5FE275AB9BC37983A59492
9F938C7E888A8287817D696D877D9A92A88B8A929A79AD43
A596A1928787878787878787878787878787878787878787
878B878787878787
87878787878B8787878B878787878744BE796A80877D8797
ACAA7B8792998B7E72633D62796D667389967C7C7A83828D
87878382827D736E72696D89A5564757698A8790717B8384
878787877B7E78868780756D918A8F99A58B7A7E9A829E54
9F95B18E8787878787878787878787878787878787878787
8487878787878787
878787878487878784878787878B873156937D879E8F8797
9DA18E8A9B9E87827D6D5E4C3E393E413F4F678C92968883
8B88847D82837C7D887D7D54676D74624F464861746E6C76
82837E87887670867D878E7A91837687AF9574839A8A9856
9B9591828787878787878787878787878787878787878787
878787878787878B
8787878B87878B87878787878787877737A47A9592926AB2
AEA18E859B9D87928B827D7F7773718FACB4A9AD83878783
86828883828272707C8EB2AEAC8D6965656D777781838182
8790947F8787768081767584919F9199A1AA8083A38B9B51
9AB397878787878787878787878787878787878787878787
8787878787878487
87878487878487878787878487878D9706A0758F879B6E90
92A399879BAA819098918688888EA4938F85637E818B8783
8C82888683877C735D547497B0CCC19D9483817D86838786
888F87888287877C819A7D878191878389907D7DAC8DAA63
8EB987878787878787878787878787878787878787878787
8787878787878787
8787878787878787878787878B8778C000817A7D87A1809B
949FA99397A6857CADB0A7ACAF948A6546667D7E7E838783
87878888888384817358393F5376B1C6C3C9BDA9ACA6A99A
7F8A827E7880877C75648E7A7476A4AE8F92847CA5879191
A7A387878787878787878787878787878787878B87878787
8787878787878787
8787878787878787878787848B8D55C3718387776E8F8896
8F899996A09D8D5F65708382715E637E8383878787878787
81878782838283838481776E5D493A4C477194968F877577
87857F807880836E9973838E8F9592B68E8C93779F8F778A
B291878787878787878787878787878787878487878B8787
8787878787878787
87878787878B8787878B87848787514D6E7D986C717D808F
888C928AAAA28B8B836C5E596F878D878787878787878788
8287878787888887888480838382868669574F535B737A79
81828A888284856E6487879187878EB873839D62A59D599F
B98787878787878787878787878787878787878784878787
8787878787878787
8787878B8487878787878787878767558E839E7179877B8B
898E9B85A9A38A87878D87868782878D8C8787878C888787
828C8D8787878287868782828B828787838C868781878883
8C7E8277788B87807A64707A7A817AD36472B86A8DB559AA
AE8287878787878787878787878787878787878787878787
8787878787878787
87878487878787848787878787875B2E847DA2827D7D7F87
8C8EA48BA9B0928B888D8D868C8D82838C87878387878787
8382878282878788888B8B84878287868387838482818282
837E8080808782788783817A7A9B91DC7471A46A7EBD6ABF
918787878787878787878787878787878787878787878787
8787878787878787
8787878787878B878787878787876C1B8B929D928D878C83
8783998190A4929288878B87868D8D83878787878C8C8787
8787878D8D8787878B8787878A8787869087878381878286
8390877E7887848780768A7A81878ED08E629A6A73A08DB5
87878787878787878787878787878787878787878B878787
8787878787878787
8787878787848787878787878787841C8979878683778183
878799918DA2929188888787868687878C8C87838787878D
8787828787878680838387858487877F8A8B8C8781858387
7A817F88837D7C767A84838581819BBFAA7DA9777472BBA1
878787878787878787878787878787878787878487878787
8787878787878787
87878787878787878787878787878D107B8A8C86878E818C
8582929B919A97928C8B8B8B878C8C83838D8C83878D8687
8C8D8786878787878B8387858782877F7E83848384878287
838A7F838780877C6F8776858E8F9A9DAB819D7C7953AF87
878787878787878787878787878787878787878787878787
8787878787878787
87878787878787878787878787878D2D84717C9281898185
8B9E928F8D9B988E8D898787878787878783878786838C88
8286888787888883878383878B8487878A818C8787878287
7A8A79838783888987757D878775BB89938FB08798829887
878787878787878787878787878787878787878787878787
8787878787878787
8787878B878B87878787878787878D1844878B90908D8C90
7B879995878F978E8B898787888C87828C878C838C888687
8787878786868788878785848587877F8F7E878187878282
7A8A79878182766E858074809275BD87887DAA8787AA8787
878787878787878787878787878787878787878787878787
8787878787878787
878784878487878787878787878787772E7F87878F878F8F
9087928C938D938E8B8B8F86888C8C878C88878382838D88
8286878787878687878787878287827F877E828187878D82
80837D7F79818E84878781819A83C57D8D87AB8780A38787
878787878787878787878787878787878787878787878787
8787878787878787
8787878787878787878787878787878D22457F808785808A
95999A949693908E8D848B8688888388828787878787828C
888388878887878780878387858A87878783878186828787
87857B838776786F837A87758D81C87B708DA39C9087878B
878787878787878787878787878787878787878787878787
8787878787878787
87878B878787878787878787878787875D24798F8F8A8A84
859C938C8E8F92888D8D8D8A868C868C8C878C87878C8787
8C87888687878887838B8786858587878783837E81878287
8181887B87878372837A87808080D19A6A8F9097A2878487
878787878787878787878787878787878787878787878787
8787878787878787
87848787878787878787878787878787842663718780858D
82949BA0948A8D8E888687878787888887838D8687888788
87868788878687878787858A868788888187878785878281
817F887F8480817A837B808E8787CD9B839D9A9B8E878787
878787878787878787878787878787878787878787878787
8787878787878787
878787878787878787878787878787878734203F6F797479
89958D969F9D8C888D8D8B8D8B87878D8D86878882868786
8787868B878B8B8787838885888787888A87838487818989
7C8783847D83807E7A817A8E8789AD79839698B2878B8787
878787878787878787878787878787878787878787878787
8787878787878787
87878B8787878787878787878B878787878D572E32838785
7F8F9E97909B9788878D868786868A878887868C87868788
878783878387878787848D878787877F868B878187828C87
82827B8A8A87778B8383837A83A8908196999BA184878787
878787878787878787878787878787878787878787878787
8787878787878787
87848787878787878787878487878787878D8D7D26648C89
9387969A9392978E908D8D8B8E8A8A8A8787878B8787868B
878D8B8D8787878E8D8787878887888386878787877C877E
7A88847E7C86776E8B7F8783867F89829B899891878B8B87
878787878787878787878787878787878787878787878787
8787878787878787
878787878787878787878787878787878787878D4633A280
769087959696928689878E8B8587838B8D87878787878387
868782878D878B828787888787878786828888878885908C
7F7F7C7D7C8793715E8E877BAAA27D82979EA18B84878287
878787878787878787878787878787878787878787878787
8787878787878787
878787878787878787878787878787878787878D663176A3
8A9A8795939291968E87888D8B9183898B878B8B8B8B8B83
8B8F8D878D908D88888788888787818D87878887857A908A
878A878D877B8498766274919387837D8D94AA877E8D8787
878787878787878787878787878787878787878787878787
8787878787878787
878787878787878787878787878787878787878D55635393
91A29D9B9B9B968F928D8892858F87898D8D8B8787839186
8A87889089929087878C8F8D9091878D8B878D8D8C878783
7C84777A8F8A8F7A907E995B93879A799885878D878B8787
828787878787878787878787878787878787828787878787
8787878787878787
878787878787878787878787878787878787878D515C2AA0
967C9D969593908D919187928A8B8D88838A8D8D91888C87
878C898C8B8D9290918E918D928E85908888888A7F878B88
7D87837E807D836979769A73887C967B87AE8B878487828D
8787878787878787878787878B878787878D878787878787
8787878787878787
878787878787878787878787878787878787878777693460
97838D9E9AA89B8E848F8C919286878B87898E8E8E8D9297
938D899090989A949492948E929D9298929294968783878C
9292797B8874869175859A869287A09185898787878D8787
878787878787878787878784878787878787878787878787
8787878787878787
87878787878787878787878787878787878787878751334C
7794878D8891A7AB9C8A8A8388898E8E8C889292988D7E8D
8C8E87958A978E95899D8D9F8D99998F948C8B9194837878
6D807B7E8D83638EAB997E7591828B8EA987878787878787
8B8787878787878787878787878787878787828787878787
8787878787878787
87878787878787878787878787878787878787878787552C
266C83A19689A58D958382888787878F908E8B878D978789
879587938794889A9094839A95829B8796928F8894AB9898
8A8F7C7D86A4876776918F8B8181879C878787878B878784
87878787878787878787878787878B87878D878787878787
8787878787878787
87878787878787878B878B8787878787878787878787877D
3D766D818C6D76809E969E968A8A8A88878A87968F888F94
8288888C879A7D847D878170908B7D817C8787836D8F8B85
818E87817C7A8A87918D7F77898E7CA18787878482878787
878787878787878787878787878487878787878787878787
8787878787878787
8787878B8787878487848787878787878787878787878787
3D2F8F7D95B1A292A290878B8F8C8D848F8F819395938893
878B7D90879998958F7B9B877D9974A18E8D849180879FA0
9E9F999399919787837C877A9387BA878787878D87878787
878787878787878787878787878787878787878787878787
8787878787878787
878784878787878787878787878787878787878787878787
8D2C33727B8C7C7B81858784818F9387878E7B8782918B87
889A879183729EAB94998087879A8C8B81B8AB8B92878473
79807C7C8A7D826388878FB0948AA282878787878787878B
878787878787878787878787878787878787878787878787
8787878787878787
878787878787878787878787878787878787878787878787
878D446A82B2A5B0AC93898A76828E8E8D8E878D8B878D8F
7F8088798D875199878F9999938993A4878094818C8B888D
99978D72707592877B8B719F75BC8D878787878B87878787
878787878787878787878787878B87878287878787878787
8787878787878787
878787878787878787878787878787878787878787878787
878752338F83668BA19E8D89857C998B95878284958B808F
8376939F7CA18770A087869483898A7B87879C938A918D88
8483818F8FA08190B28E82817A918B8B8787878787878787
8287878787828787878787878487878D8787878787878787
8787878787878787
878787878787878787878787878787878787878787878787
87878D1933A0AC7C83929E7E7C66908099998883978A839B
87976F998080938F9A778F8E8782888F8F92919396938775
8E99826E756F876F7D988DA5877E7E8B878487878487878D
878787878D87878787878787878787878787878787878787
8787878787878787
878787878787878787878787878787878787878787878787
8787878B330A97C5A592A0897C659493778F7B6F85987B88
91876F99837C7071BC8C87708A8792808184959195A0A186
717A9787909EB293749B86B38D8D848787878B8782878787
87878787878787878B878787878787878787828787878787
8787878787878787
8787878787878B8787878787878787878787878787878787
878784878D352691A7ABA69E875E77A48887A0977B9A997B
8F9582818F917A58717FAB8F7F758776765D736F686E748C
8D77669E8175A897876C958787878787877E879187878787
87828787878787848787828787878787878D878787878787
8787878787878787
878787878784878787878787878787878787878787878787
87878787876D233F779AB1BCAB825299A181788F868E9C9A
8B8D9387879981757C6B7D74878879768E7B7572756C7B82
76A483967D7D8583939782878282878B878B7E878B878287
8D87878787878787878D8787878787828787878787878787
8787878787878787
878787878787878787878787878787878787878787878787
87878782878762315D7C7B928DA75D5C939D7B777B698A8E
8E868B7C928693747F6576778196827C6F757A8280747CB0
A09EA6B88A828B8E7687878D8D827E8D84878784878D8787
87878787878787878787878787878D878787878787878787
8787878787878787
878787878787878787878787878787878787878787878787
87878D8B87878B552C589593888F8E5C5894878D87736F7B
9999A57DA2869A7583644648595A606F6F5F5F81809C9588
9289797D807C8599878787828D8D87878D87878B87878282
878787878787878787878787878787878787878787878787
8787878787878787
878787878787878787878787878787878787878787878787
87878487878487825D21328C9FB59C81586970807A7E7B59
4C65937BA0888976A4B4837281746A6D8FA49D9E8B818D87
8F8A7D918687788D87879187878B8B8787878787878D8D87
878B87878787878787878787878787878787878787878787
8787878787878787
878787878787878787878787878787878787878787878787
8787878787878D828782382772A3ACA58858726B63676277
682F3A1B37586A65637D8281878C9AAC828F9A8E82918983
6B778195873E87878287878784848B878784878B87878287
848B87878B87828787878787878787878787878787878787
8787878787878787
878787878787878787878787878787878787878787828787
8787878787878D8287878D332147A4B2AC8D7B7E6A877E6E
8A88A39B8D8C817181838194A9827990798F8798837B6771
788087698D878B8D87878787878487878B878487878D8787
84878784878D87878787878787878782878782878B878787
8787878787878787
87878787878787878787878787878787878787878D878787
8787878787828D8282878287771B3592A0AB989E928D8781
877C7E787A888D82858A816EA09485A17F8F6D8D7D76868A
8A74628787848B8487878287828787878787878787878787
87828787878787878782878787878787878D877E87878787
8787878787878787
878787878787878787878787878787878787878787878787
878787878D878D8D878D8787917D33373E9DB0B0908A8787
888B9B8B8E919DA0A8A59B7B7C9695856A87536F777E926F
5077878787848782878D878D8B87848287828787878B8782
8D878787878287878D878787878D8787878287828B878787
8787878287878787
878787878787878787878787878787878787878782878787
878787878787878787878B7E878D82874633395DA5B49F9C
947D87817D766A706A878D8B6940716F5C7B919E7C484F7E
8287878782878D878787828487878D878D8B878784878D87
878287828782828287878787878287878D87878482878787
87878D8787878787
878787878787878787878787878787878787879187878787
878787878787878787848D87878D878787828746465B8F99
99A8998E8E83766C575B5B7781677E9E9E77606B7D8D8787
8B87878D878787878B8D878B8787878B848787878787878B
8D878D8D8D8D8D8B87828B878D878787918D878D878B8787
8787878787878787
878787878787878787878787878787878787848782878787
87878787878787878787878787878B878D82918B87555065
556576768778879EA298878D8B8A6C555F6C7D87878D877E
8782828287878784878B878787878487878B87828B878487
82878787878784878D848287828787848787878784828787
8787878787828787
878787878787878787878787878787878787878D878B8787
878787878787878787828B878784878B8D84848787878484
84787D77837D6C65656F7063696D7D8487878282878D8D82
8D8D8D878B878287847E87878782878284828D8787878B8D
8787878787878787878D8B8D87828787878782878D878787
878787878D878787
878787878787878787878787878787878787878784878787
87878787878787878D84878787878787878B828787878B87
918787828B87848484848D8287878B87878D8D8787828D82
87878787828D82828D8787878D878D878D82878B87878787
8787878787878287878487878D8287878791878282878787
878787878782878B
878787878787878787878787878787878787878787878287
878787878787878787878787878487877E87878787878784
82878D848287878287878D8B8784878787878B8787878D82
8287848D8B8D8D8B87828787878782878D84848784878787
828B8787878D8287878287879187878784878D9182878787
878787878D878482
878787878787878787878787878787878787828787918787
8B87878787878787878787878B82878D8D8B878784878B87
8B87878D82878D8782878787878B87878784878D87878D8D
82878787878284878D8B8282878D8B82878787878287878D
7E878787828D87828D87827E878782878787878D87878787
8787878287878D87
87878787878787878787878787878787878D87878487877E
8787878787878787878787848D8787878487878787849184
878782918782878D878482877E8787878787878B8782878D
878784878D878787848D8D8B87848D8787878B878B82878D
8287879187878D87878D8D87878D87878B84878787878787
8787918287878787
878787878787878787878787878787878787878787828D87
87878787878787878787878B878787878787878787848B8B
878D84879182828787878B8D878787878287878B8D87828B
8782878287878287828784878787828787848D849187828D
87877E8787878287828787828B8787848787828787828787
87848D878787878B
87878787878787878787878787878787878787878D878782
8787878787878787878784878287878B878B878787848487
828787848D8D8787917E87878787878D8784848787918482
8D828D8787918291828787878B8D87878787878487878B8B
878D878B878D878D82878D8487878787828D87878D878787
87878787878B847E
878787878787878787878787878787878787878787878D87
8B87878787878787878B828D878B8487878B87878782828D
87878B87878787878D8782878B8287878787878284828D8B
87878B87878D848787878B8487828B82878B878B87847E87
878787878787878D878787878787878D87878B8787878787
8787878784878D87
878787878787878787878787878787878787878787878784
8787878787878787848D87878482877E848B82828D918287
8784878787878482828D87848D82878787878D878787848D
8784827E82828D8787848B8787848D877E827E87878D8787
87848282878787878B878787878787828784878782878787
8782878287878287
878787878787878787878787878787878787878287828787
8B878B8787878787828787878D878D8B84918D8B848D8787
8787878B87878D8D878782878D8787828B87828787878787
878D8D8D8D8787828784878D878B878D8D8D8D8782878287
87918D828787877E8787878787878D878B878B8D87878787
8D878D87878D8787
8787878787878787878787878787878787878D828D878284
878487878787878D87878787878B84878487848782878287
878784878787878787878287878791848787878787878787
878787878787878282878787848787878787878D82878287
84878D8787878D8787878787878782848B848B8787828787
828B878787878787
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.35119 0.015625 0.64881 0.313244 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00751202 0.0192308 0.00751202 [
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(240) show
81.000000 12.812500 moveto
(deg) show
99.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(.) show
105.000000 12.812500 moveto
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
128 string
128 128 8 [128 0 0 128 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
89898D89838987898F828A748989898D84898989899C8448
B38F8289848E89828F89888982898E898D89858988898989
809189898F898989898989868B83898B8C83898989898889
89898989878A898889898898927F56A5898E898389898D89
898989898F88868B8F848D8989838E83838881898C898886
A0886A9D998F8C83
898A8B86868C89878B8888808289898A8689898888908C55
AC8E8388878987858C8B8989868A898B8D8686888883898B
858A8A898A87898786878B84888986898985898A88898889
898989898889858B8988898E92895C8C988C898389898A87
8B8989898D8689888D858A87878989858389858B89898B96
997978949C8F8985
88898888898A8785888A89898181888888878988868A967A
709B878885838A8C8A8C8988898883899087878886848A8A
85848A898A898A8986898B85888B858B8B8A898A8A868889
898989898987888D898889888E8B7F887E9587858C898789
8E85878B8D878B878B89898B8A8B848784888988878D9092
8D77838A9E908B87
89898A8C868C8A868C8A8987867F8D8584898787868A8C93
679A8F8887858B8B87878B898988838891888688848C8586
8989878A8C8B888A8688898888898B8F8889888B8986898B
8A8689898988898989888989888B928C6F85988A8C88878D
8B878B8C8C868A868A898C8B8985898487868D8696898B8F
7F8A7C87A08E8A87
8889898A888A88848F89878A878B8785808988868B878C9B
846B988A8B8289898C868B8B8889868A8D898587858D8689
8D8A86868D8B8B8486868C8989898A8A8885878F87848A88
8A84888B8987888B8989878B87898A928C5D9E8E8B898989
86898B898B888C878B8A8D87898789848A85919194848B92
749A7685A38F888B
898A868B8986898A88898886898C848B828386878A878C8E
8E7A8C8B8A828A878B89898D8985878B85848789878E8989
8988878887878A86868E8A8B898989898B868B8E84858B87
8A88878C888889898A86868A868B878A9280818B8F8A8987
888B8B8A89898A878A898A8989898485868294948A798981
7F977192A28E8686
898D888B858D868B858D858B8D85898B87858685898B898B
908E79878A8789858A8987878785858686868A8A8591898B
8A898A8B838A858E858E828C88858B8889898B86858A8787
8888868B878787868986888888898789899583888B8B8787
868C888B898789878D868B8B8982847B818B9F8B906F8F84
8C8D749F96888B85
898B8888858E848D8689848C87898A8A89898582878A898B
898F87806F98858685868988888384898C89898A86908B8A
8A89898B82897F8A8688858D86868B868987888885878786
8B848A8984878988848787878786888A848B948876898989
888A878C8987898B8C838A87837F7981869A997D7F7C8C83
8F8480A38F868B85
898C878B898B848A86898B89888A8A898A89848B838E8A8B
8D8D8F837B93888985878989868687908A8B8D8B88888D8B
8C898989878984848B8D868D87898A878A8386877F888685
887F8984838785848286868C868A888A82878F82848A7C78
8C8B878C88868A8B878887856F82829088909282808F8B90
8E7D8F9D8F888888
8A8A88898A89878889878A8687888F84898B838E848D8587
8D8686888B7A817A9781828C878B828B858A8B8886838D8E
8A8C888A898586828B8A848E878B8A88888B8A8B898C8C89
8A898F898B8E8B8C8B8B8F9083908A8A858D8985948A8188
9561A0868A8A8A887B7375777598968D838F92878C87809E
83769F8D918A8A87
87868D838B868887898A878A8B8A8986898E848D858C8489
8B858B868B8668739D7B84928888868B858D8D8A89838C8F
898B868B8787898587898C8C878C89898789838D89898D85
898B8B8B8B8A888A878C8C89858F868A838E868B8A888C88
866FBC7A80828877727D818C9894968380A47F898F798F9E
7C8893948E8A8989
8A878B88878A8B86898988898C858986898A8987898B878B
86878A858B876C827F8C8A819389868A808E8B878B858B90
8988898A8A868A8487878A8A898989898987898989878A86
8A87898A85878C8A848F89898986868D838E848B88868C84
88858F7D888B6F788C8A859291878E878BA9638A9275A08F
76A38499878C898F
87898A88858E85888B8A88898B848A888B898B838B8A8986
848989888A87738671888E6F86988A89848F87888A858A8F
898989888C848A8689878A8C89898988898989838B898D86
87888787898B8A868490898889828D8C838B858E89858785
8882857F726E6C8F9286948C8A8993938C9B69919579A288
84A1898D858F8A8A
8A8A8686888E838E848B838E8589868E898985868C8B8589
86888A8B87887A8D806C906F7C8EA8838D85858C89888B8F
898989898A8689898989868787878B858A89898489898A86
878A84898B8989878A8B8B84888490898487898A87818A82
857B7E757689978B8D888C8D8B919588908B758F8C8C9683
909B8A8B858F8884
87878A88868E878C838F848A8988898C858786898D84898A
858B898B84897A94755D837E7A7697A08D838F8B8C868A8C
8B898989868A89898989878A878C89868A8A89878A84878A
888989878A87878889878F838D87898B87868A8785858682
818278739295898C91808493928991828F808C928B9F798F
9B9489868A888C86
89898986878F8488848E87898988898789868D878A888986
8B89898787897C937175728C797776A5AA8990838E87898F
8C8989898789878A89868787868886898C8C898687848989
89868B878B8589848C878D868A86888B867E85827F848285
77736E8FA18B7498908C8A90897F90859385978999877B9A
9B8789888B888F85
888C88888C89858B8A8B888A858D858B8C848D85878B8888
8A848C85898686868075668975777C85A3A98F809386898F
8A8687878789878A8A84898C8787888A8B87868987868688
88868B87898489828C868B8A828C808C858185868285807C
6B7B87A798847B9F8D93838785828D938E889689927C9296
8F848C8F89888E87
898A8A898C828C8B8B84888D848A848B86868D8789888B89
85888A89898488788D5B7783747C85827E9DB0868E888A8C
8A868989898D848C8986898A848987888989868D86868889
878A85868A8985868C869088818B858A858583857E787A7C
7B949A9D8C8789938483818A86898F91889490898B99918C
8B8A8E8F89898C89
888C8B8A89868A888A87878A848B8A8B898A8A868886898C
848989888887867B91568283757D897F7580AAB68891878D
888A8989898A898C84898989888A8985898B868C87878687
878983888A8B83858C868A8B7E898B84828A8177707E7292
8D949D8B858B899584878D948A948C8991938A8991958989
8F8D8B898A86868A
8A8D838D868A878A898884898B888989888A87868A8B8689
878B878789888380865C7F7C7A81857A76848AF08990898B
89898C878C878A878689868A898789858A888589848A8789
89868687868686868D9183867D8986867B887A7B69917C9E
86959582878C8D928B8C848E92858C8E908A8990928B948E
8F8B89868C848B8C
8986848B87898A858986878D8B848B888B8988868C87858C
8B8989868A86857E736A7F7A7E8D7B7F7B8799B0A4908B8D
86888F848A8689898987888A85888B85898789858B868B8B
878489848680898E928974828A858B8478857783828F9491
8E9D91848A8B95828C89818F8A7E948F89898F94918B968B
88868A8989868D86
8987868C87898B888C848B8C898787868D8489878A89878C
8A848A85888487786F738279858C7285798F927DDC92898F
82898C83898986898988888687898A89858889878787888A
8485868282848C9A8F707E8F8C80817B75907B8592889181
93918983867FA07D9585988389949689898D8E968F89908C
828C8D89848B8B87
89858989888B898B89858D89898984898D878887888E848C
87858C898684896B7A6F807B8482718A8790816DF58C8B8A
86888A84898C8489898787878A88888987878985828C8589
878882847E8A93947871898A837B7C78899A7D868C8E8582
999289828689A17C927D92818C8E8E8989959693898B908B
848E8985868A8A89
89878C838E89868A8689898A898987878B8886898A8D858C
838C8C898383826781747E82857B79918F84777BFA849186
868A89878A89868988858B89858686868D818884888A8686
8784827E848B95827585888A8177847F939D818B8488958A
958D8986958C8D818B858991948E968793959387878C8C86
8A8B86888B898C89
89868A878C86868C8789898B8989868987898B89898A858A
868B888785837D6D7C7B7C808777869B83747D82F0848E7E
8A8D888387888886868589888587888A8786868687898489
8485847E8893857B7B8B828877868B898B9A89887E8E9385
8F80908C99858B7E8A92838F9E898E8D98908A8D848E8A8B
8D8985898886888A
89878B868A87878C8987898A8989878B87898B89858C8589
8B86888B8A81746D807D7B8388748F8B76708D81F4878B85
8F878B83868F84848A87858B86888689858D858786868A85
858883808C8E787C8589827F82907A898D9C8F8788888885
898997869A8A837B93947C949A8995939087878D898D898D
868A878988888C89
8989898789888989868A878B89868A8989898986898B8587
8B848C8A87836477817D71868078977D7C7C947FF2828C86
8A84888A818B858687868686858B84878A8A878286878A85
8882848093807A81878484878F81809292988D858C7E8B7E
898B908D9588898893808493938D9A8B8D8A8D898D8B878C
878B8989858B8B85
8986888A85898C87898A868A89858C89868887868D86868A
8B868E83887E62807A817690778C908071808C84EC7F9082
8C86848B84858984848A8685898584868C86888489848787
84828586837B7E80888B878985838C918F9494918D908275
87899B8D8F8E8E887E7F8B9C938D968C898F858D8C8C878B
89868A8987878A85
88898989868889878889898C8589898A858B868B8C87898B
86858A848A6E727A7D7D7A8C76967C7E6A86908AEB7F8E87
8C86868586848A8684898589878586898B878C8785858982
8487808C787F828B878E8971828793958C8F909387898577
8595928C8B98897F7E8988A48F968F8F878E8991838A8A89
86898B8986888C87
898B8987878A8A8A8B8B89898789878C848D858D868A8687
878A868980697E747E7980848192747E7A8E908CE5828A87
888585878789858886838788808884848C89858A85898282
89887E9675758F9182877B737DA3A1898E828F9493859671
83968692849F7F7F828A95A29396858A8E8B8C8E848A8D89
87878A8689898A89
8989868A858A8688888A868A89878A8B838A8789898B858A
8A87868973707D6F827C8681868B7180828D898ADE88898F
8788858D858988898A838384868588858B86868D84868283
878182976D719C8C787D7B8C89A89C838E87879D918B857A
858D848B9493798D829796999E84898F8D8F8A8C87878C89
89878C878B858C86
888A8787858C878C8989868C89858A8688878A878E89858A
8685898371777975857E848F7A8A6493858B8696D9928E91
878C8B89898B88878A868587828289888785898588868585
85818994667D9B87727B86A182979E88828784A09192848B
7F8C7F7FA789788C8E9291A597818C91888F8A868A878B89
868A898989878985
898988878A8D858C8987898B89848D8789888A858E868986
878A89787276787A837A868A7E80689F868684B7CA939086
898789878A8B838A89868685808982848988898A85888889
828383956C8F9B737B7D94AB6E9E978D7E848F978F978986
7D86758DA686808B9D7E99A781838E8A8F888C848A868888
898B868A89898789
8889868D868789878A89898986858D86868C86858E858985
898A897273777E7982808A828F6682998284ADCCAB8D8C87
868D868C8688858B85878587858682888288878787898B84
7F8479858E83A15B807C8FAD7F8B969B77958795959A8F8B
816D869293838D8F927CAD977D8D948A908788888B898B87
8A8A878B89868A89
8989888C87898C838C878A8987868B89878A86898C87898A
87867F756C7C7C777D89838284659A907DCABFA48D8D878B
868D818A868A8689858B8484858B84847E7E86878D808B83
81867382B565B3617A8C81AA9D6AA198759C8291958F978A
7B6B8E8C8F86998F888FA98287968C8D888A858D89868889
878A8A8989878B89
89878B89858A89878B898C898586898D87878B898B898986
8484787D6A817B7D7F8D848474799A83A2DF8E848C8A8A88
8988868B868A848889858286888885848477927C8A868885
837F7A84B870AA76618387A9AC7D9D90878892889190968E
836E7A94868E9D8E868C989091908A8E858D858C86868B8B
8789898A8989868A
878A868A878C858A86888A86868A878D8686898A89848B84
8680797771837B7D798A7E8C678C9291D4AB8C868C898D84
8B84868C81898688898688868687868685808C777D8C8682
877A8477B39A6D9F649385A7869D778F8B85938D829C849C
8F617A978796948C838D9F988B8A888B8989898B85898C86
888A858A8A86898B
898D858C8989858B89898B8787898A898989898C89868B81
8779816C797A7F7C7D8D8181719B94C7BA8B8D8989868A82
8B83888B838285878B84888089848688878583837E7E8088
827D7E7DA8AD689C89708A9586A2818B8E90749981A0809A
8B78768690938694919A9E878E8D878E89868C8689898989
878C878989898B89
898B858C8989858B898888888989898989878788888A8781
817C7C6A797B807B85897180848FCCBC8C8A878788858581
83858384847E888788828A8588868B858884838688797F88
7D877D8696A29583937D9A7E7996988192827F98968C8B91
929263859C8B829B95A38B8B8E8A878F87878C848A8A858A
898B8989878B8986
8986898B8986898B8789878B8B89878B8588898C89898880
7D83747476857E7B8C846D8F90C6D0898D86858989837F84
828481858583878B84898C848C8989828884868684837C71
7D867D7C91A0AF7673B0719173929391857F9885A1809689
91926D8B8C858A9996A48293868B8A8B8A8787898B8B858B
8B868A8989898987
89858C8986898B898989858C89898989878788898A85877C
7E846C7179808476897A7C8D94E38B8788868688836C7685
7F84848787877C867E83928B8D8B89868687868386867F7B
6F827E7A95A1A48D7DA8888C86838C90888984839A8B888F
8E9781798E818D9996988D8D858B8A898788888A8A898789
8A87898A89868A89
89858C8689898A898989858C8986878A89858A8A8989827E
85786C727F7E8677897D8691CCC28888888B8774797388AA
8E858A93947E828A8B8791968C8B8B898388878387828385
72757B818CA47EC08670AB6E9A8979869777898B96928298
8B958D6A84829096A190928B85918B88868A8C858C868889
8B86898B86868C86
888989898989898A868889898886888B88858D89838E787E
766D767973867F87788384AEDA878987888A866286898693
78768A81826B8481967E878A9D8C8D89868A868384868587
81736D8C79A289C88B65A7848D948E77837E987A9093898F
8C998A6A83938994B0898E86869389878B898B878989898B
89878B8987898B87
898B878B858A898986898C8589898B8987888D86868B747D
707B767A71907E807B8A9AD7AC88868688757C62767F8187
7D8289767D758786827A7D769B969489898585868289868B
7C7E697076A29B989C8D71AA6CA09B7B77937A888D958783
979B897D8092829BA98E89888B8C8B89868A868A878B8989
898989868A868A89
8888888A87878A89878B8989878B898886898A8589847979
6D7A6F7785887F819184D6BD86898886887892777B908E94
81909780888A959386AD9998A5A79C898685888A81868889
7F82765F7E93949AA2A06E958A89A78C7F6B81948193897D
AA8D8E8A6D947FA79F8E868A8D878C88898B878B868A8986
8A8986898B858C89
8987898C8689898B858C858C878B8789868B87868A827973
69747D7D8882828A878DE886888A87878788907F8E97929B
9B989B919D96999595A58E8C8E8B8C898787868983868688
83857966727EB491949C8969A66FA2978D6092867D8B8E8A
9D829C8D69907CB492888988928989878C898989878B8689
898A878B86898B89
8889898B878B868A878B858C86888A89858A878786777A6F
69767F7F817C8B8C85BFC8878B8789888A888C898D858788
917E898B887C8583868C858B8E85888B8785888884898282
8689766D647DB685A590A4678E9194A88C85827A828F888B
868BA58D6D8F7DC08D848B8C918989858C898688888A878B
878B8989878B8986
898C8688888889888A89878B858B898A858889898673736B
6C8377887D85938987E594868A8989858E858D898A868A86
89808988887E8B8B878D85908689858A84868B8584868882
88897C746888899C9683927781A4829C998B6E7F838C7894
82A09A8F748483B68D868596898A89858C868989898B868A
898986888A898987
89898987898B8B87898A8989878B878B878788897A756672
7A7D817C87868E8A80ED86868C8A878989898A8989878989
8486828C827F8B8B848B8991808D888B838A888584878784
818482786A747EAB94948E997B8984A3908B8988728E739F
81A08C997A74A5A394898598898B89878B87898A8989858C
868A87898B898989
89878B87898B898987898A8989898688888989837076706E
807E847D90829382A3DD87898D8A89898A89878989888687
7E817E8E80828B8A87898D8A888B8E838388848783898288
8585827B6F7090969A8694878575918EA49C887E71917399
8895899F7F74B9839E868F8E8B898989868A878B89898789
868C89868A898989
888A89898989868A86868C89868A8789868D86846D6C736F
7C847A82858C897ADFA88A8A8D8989898A86868B89898383
7F877F8D86818B8C898B8B8A898C8885868D848686878289
887D8180756C758C9C889C789C759177CA7E81A06F898086
928C8BA18581A983987F988989898989858C898989898987
898B89858C898989
898B89898989878989898B86898B8989878C878362686E78
7F7E8A818E8F7F7CF68889898D868D8A878988888C737495
89887E6E7D8891798E8F8B91898E89898589828487848686
887F857B796D6A98989292809C817E89A1899F91787B8971
938599A3869B7B9F779D998989898989878B898989898989
898989878B89868A
88888A86888A89878B868889898A89898989867B596B7485
7F8189888D817C97EF878C8B8F868A8B828A87888F7889A5
89848075969E997C8F9193938989898983898A8486858782
84857F8081755B8F9098928F8A92749469C98C819D648E6F
969198999095689C8FA4868A89898989868A898989868A89
89898986888A878B
89898B87898B868A8985898C878B89858A898777556C7D77
808B80908D7583B6D28A8B898D87888D858A88888E808C8B
8A858382898A898381919993898A88898588868385868682
7F8880817C7D4B958AA4959479A0739066DD79979F5B9376
9193909A9A897E95AF89858C89898989878B868A89878B89
89898987878C8989
898989868A86898B8689878C89858A858B8A86724D6D867A
8D8A868E85708EE3AC8E898C8D8988898788858591858E8D
8682868183868788848D9391898C868A88858B8688848882
838681807E7C57818EA97EA177A26F8F7FB98C9D8D708386
858C8BA09A818F9E9C89878B89898986888A878B89898989
89898989878B8989
898989878B878B86868C858A8A878989898B8459507E7783
838A8B88708087F98B8D878E89888989888986878E858A8B
8484857D7E868B858990938F898C89878788898586838885
85827D7F817F6D6698A08EA184957091869F9995908F658E
7A9093AC96719FA2898A8688888A8987878C898989898989
8989868A89898989
88888A8989868A87898B8789898A858C89898344687E7097
898D896E7B8C8CFF8D8D888D888889888888898785888A8C
84847F807F8C8C8790938F89898B8B838A87898980868688
82877D817F8072589B959B868D89878886A899929A9A5489
7E9293A29280AD9C878B8789898B8989878B898989868A89
8989858A8A898989
89898B8986898B898989898689898989888886406C788397
828889698D8ACCD78C8D878989898C8A8A868A8986898591
86837F83828C8D8A8F928B878A8A8F848986888980878685
8286827D79817D598B948E999182948684A2A090989E4C91
729D87B0998AA48B89898989898989898989898989878B89
898987898B89868A
8888888A878B8989898986868A898B85898B763F6F788E8D
83887A7280D7D2978D8F86898C868B878785898888878590
89808481868C8C898D8F8A8C8C8690828C87898785898685
84838783777F83667FA18F9B957D98887CA0AD889299588A
65A485B39A939D8989898989898989868A8986888A89868A
868A89898989878B
898B878C8989898989868989878C8987898B42587A709B83
85896E8E8AFF908C8E8A858C8C8389898C868989898A848D
8986857D828F8B8A8B8E8C9086888C878986898787888286
82868288737D7E747D8F8C92928990828FA2A7858C916A75
6DA796A5A59B8D8989898989898989878B8987898B898789
898B89868A898989
898C878B8989898989878B89858C8989868A2E7C7A77A582
86877889AEE08B8F89888C8C8585888A8A848C8A8689878C
8884847B828B8E898D8C8E8B858D8885848E878885888685
81888186777B787C77878B96899789868CAA9588898F826A
809F969FAF96898989898989898989898989868A868A8987
8B8989878B898989
898B868A868A8989868A8989878B898987892F8375829289
83798B8DE0AD8A8D89898B878589898986898B8785898982
8B868B7B8288908B8B8A8B8A898A8A838D8A838686898783
858482847F7A7C7C79858F8C93948A8180C485848C899052
918C91A7B48F898989898989898989898989878B878B868A
8989898989898989
888A878B858C868A858C8989898989868A663787768A878F
7C7B95CAC6878D8B8989898C86898A85838989878B898485
8F898A7C7E868B898C848F8C878D89868A82858988898783
897E85857E7D777B7D7690899699868388C47E898E6FAA3E
9D9694A2B98C8989898989898989898989898989868A878B
8989898989898989
898B8986898B858C878B8989898989858C40738476997989
749190E6908092888C86898B8486887C88898A888C8A828B
8C888A7E7787858B8C89948B8A8984848885878989898786
82878483807F777A7C6F8B8F939B858689B8848C8B54C541
96A299A0B48989868A8989898989898989898989858C8989
8989898989898989
898989858C8987898A898986888888898B1FA36883917D85
6FAAB2C8818C93888B8589868684878283858B8A8B8C8189
8E888A797A838989889090898683838386848187858B8687
828D7F827F7C797D7C787797909B8B8C80B78B7B8C51D650
7EB29FA3A58989878B898989868A898989898989878B8989
868A898989898989
898989878B8989878B868A858B89898B8C1EA7638F7D8D68
8F9FD37B829D9187898986827D757A897C7E9488938B838A
9289897B7D7E89869589968182807C7A8189838989958982
86868282807E7C797A7F77918DA086927DAF8C758C65D646
78BF92A8A286898989898989878B89898989898989898989
878B898989898989
888A898989868A868A878B878B89898964418B698E809363
ADB5C06994A38B8989837B6C7A8B88757D8499808B968687
9389897E7C7B8A83975B88808D91686C938981828A988882
898984857E7D7A7A817E8A7687A588918DA391798A6CD146
8DBF8CB29C8589898989898989898989898989868A898989
8989898989898989
898B898989878B878B8989868A89898941857976798F9669
8FE3817D90A28C88837B6A76A2A65D65829B918F86A5838D
948985807E7B82798D757CBFA9666378A576A07C859A9387
8B888285827B7A82787D80648CAB8C819B9C8C728E76C840
A8AB89B68F8989898989898989898989868A8987898A8989
8989898989898989
8989898989898989868A89878B89898C6871637A6AA38B7B
90F273808F9B8C827A73656AB0954BA249B1769B88959299
92898484808375817F9476A0A530B146AA6DBB4889A09787
9087857E867B7C7A7A836D77949B977BAA8F887F917CB941
B99796B4898989898989898989898989878B8989878B8989
8989898989898989
8989898989898989878B89898989895F8849727E7F9C898E
9FC76E84969A8D7E77725E7CAA76568F54B979A79C9D9E96
8C8A8483828478817F8B8382A53A9747A88196629AA8928A
938A877C827F727C8580747F98929887A58A8783927FB54D
B197B0A18989898989898989898989898989898989898989
868A898989898989
89898989868A8989868A898989898937A26F6973908A838D
ABAA778B939B8981837F718F84788696979B95A5A09F9092
8B8B84838788807F868186828D739091848D89A49A9F8E90
958D8384807D738785827F7697878793A79381829C8DAA57
A49AB9928989898989898989898989898989898989898989
878B898989898989
89898989878B8989878B8989868A89617E765F7D91807D9F
AC988384939C8B8A8C86848A90949B9EA0A3939892948F8B
8C88878589877E7A867F8E859E8A8A878D9BA2A69E908F8F
8E878184847C758A817D7F7793908B8DAB9A7881A0939F5B
A3B1B28B8989898989898989898989898989898989898989
898989898989868A
8989868A89868A8989898986898B8C86217F6887889972A5
9B968B8099A2858E8E87888C888B7B797A7575A294988F87
8E868A86868B7D7E7B718880899694939291908A8E8B8582
807C8980837E79857F827B7F8C917A92A29B7683A68FA35B
A4BD99858989898989898989898989898989898989898989
898989898989878B
8989878B89878B89898989878B89848E00956D908F9C72A5
98988C8398A4828B8C8C878984666A70819CA2AF91918C87
8D838A888889828479767B808D9794898C888A838B83827B
748D8C817C80837D7684708A868A94A0999A827EA98AA168
9BC28F898989898989898989898989898989898989898989
8989898989898989
8989898989898989898989868A8C62A8098A839084978199
8A8A938A97A78B6E87887C786B6696A39FA99D8F8B8D8C87
888589888986878685827F8F8F8A8D867D8081797D757C7F
859685857B818979896E8F908682949F9492817EAA918970
ADBA89898989898989898989898989898989868A89898989
8989898989898989
8989898989898989898989858C8B4E852F8296877F978492
8B8B988EA1A48E79938581818EA5AAA18D8A8C8989898989
82898C8A8B8688898A868286888D93A385878A86848F918F
918D878278838C7483719482767C88B793838E82A9936A8D
CE9E89898989898989898989898989898989878B868A8989
8989898989898989
89898989868A8989868A89878B895F597285A582828A8694
8D8D968CA8A18B8A87858E919D998F898989898989898889
828C8C8985858888898785888B8688897A89969391998D85
8F85807D7C898A7A7689777B7C898FCE817DB0749D9B61A8
C98F898989898989898989898989898989898989878B8989
8989898989898989
8989868A878B8986898B89898989603F7E88AE797A8A8592
888B9B85A9A48C8B898E89878C8A89888A8989858A898889
838A8B85858C8689898986858B838887838E828382848583
8A7C87837E8A87798378778688938ADC737DB56B8BAF59BA
C18689898989898989898989898989898989898989898989
8989898989898989
8989878B898989878B8989898989663B948D9E75838B8587
87889B86A1A58E8A898B8A888A8B86878D8989878C898989
87898C868A898589868787858B8388878889828783868787
8785877B7C8D847E806B82877B8C84DE767AB3717CAF5FD9
A58589898989898989898989898989898989898989898989
8989898989898989
8989898989868A898989898989897C308A838A848B7F8684
8B87A18F9CA88D8E898A8D89878B8B878C898985878A8989
898985878785898488898987868588838984898482898487
7E877F8083897E7B75799276798998CB907FA86E7E9395D7
8B898989898989898989898989898989898989868A898989
8989898989898989
8989898989878B898989898989898B198C838F918C828987
898D9D95959F8F938A8C8B89888C8C85878A89848C8C858B
89898389898989868C878986858989808887888683888387
8088808683837F7B78877E76868697BBA66F9D79827ACDB2
89898989898989898989898989898989898989878B898989
8989898989898989
89898989898989898989898989898F218384958C82877F89
908D9499909996918B8B878A898A8A87868B8A8788888889
87878588898989868A8489848A86888586898A8783878388
7E858084897A817D778970818282ACAE9B79A584927ED999
898989898989898989898989898989898989898989898989
8989898989898989
89898989898989898989898989898F1A88948489818A8290
818D98988D98998F8D898B8B898C8C85898B8C8588878A89
86888989898889878B8783868C8388838983888285888388
7B8F7E847F7A80798576737D8F82C4959181A685929BB989
898989898989898989898989898989898989898989898989
8989898989898989
8989868A868A89898989898989898B508277798885858989
83979A95909899908D8D8B88898D89838E858A848A868B89
85888989888989898984858B86868980917E898288888786
7F8F77817C87837E81757586987BC98D8C82AD8C91BC9489
898989898989898989898989898989898989898989898989
8989898989898989
8989878B878B89898989898989898986307487828B87878A
928D9D93979297908E898B878A8A87858A898C8789878A89
868989898989888984868B89838C86858E82878288858A83
86837986837F8170777B7E819280CE858882B0969BB48989
898989898989898989898989898989898989898989898989
8989898989898989
8989898989898989898989898989898B436E84868D88888D
8C9497909695948F8F878F87898C868C898C89898589878A
8986898889898989838D8786868985888980858388878885
81808082837E806E827B8B7D9487D08B7993AAA0A99A868A
898989898989898989898989898989898989898989898989
8989898989898989
89868A898989898989898989898989897640788689888A89
889B99969794968D8B898B8A898B858B8A858A85858B8589
8A858A8889888989848A8488888589888583898585898386
8381847C847D796F847E89878F82C89471A1A2A7AA89878B
898989898989898989898989898989898989898989898989
8989898989898989
89878B8989898989898989898989898987307B839089888C
889A93999994918B8D8B8C8B8988888C8C838B8589888889
898989898988898686898689848788898288858484898487
827C867B807C7A7687808390807BCB927BA0A1AD9C898989
898989898989898989898989898989898989898989898989
8989898989898989
89898989898989898989898989898989896D7C768C8B8A87
8996959A97968E8D8B8B89888988898B8885898C86888989
8989858B868787868B85898586888984858884848B828588
77837F827B7B7A8581847F877A98D0868AA29DB68B8A8989
898989898989898989898989898989898989898989898989
8989898989898989
89868A8989898989898989868A898989898F767C63878184
8A91979794979589898F888C8B868A898A89888B85888989
8989878B8489898B898189848988898287878686887C8B7F
7E877A7C78847B847E81837C81CAAC76949AA8B2878B8989
898989898989898989898989898989898989898989898989
8989898989898989
89878B8989898989898989878B898989898B8785436E8585
8D8A999A939695868C8B8B8987878A8A8989868A8989858B
858887888689878784858988898889818489898485818985
807D787C838B8276877F8279C0BA837BA3A2B59D86888A89
898989898989898989898989898989898989898989898989
8989898989898989
898989898989898989898989898989898989898F5A3B9592
859794969595928B8F888B8A898D87898A86898B89898789
858C87858B858A84898889888988848585888584867B8886
767E80857F808888707F83A3B78D7F8BA5A8AB90858F8989
898989898989898989898989898989898989898989898989
8989898989898989
898989898989898989898989898989898989898F5B408E90
7DA1889696968D8E8C88898C868F83898B868A8787878A82
8888848585888A858888898988897F888585858784798C7D
79807E7F80818D837286999F9E968C94A49FAC8F858D8589
898989898989898989898989898989898989898989898989
8989898989898989
898989898989898989898989898989898989898F4F715F8D
8D918C95938E908F8C8A848E888E848787888A898B848B81
88878385828C8B898685898585867E89878187837E808581
7D89807A87828679927AB287A381A58AA6A7A18B828A898C
86898989898989898989898989898989898C868989898989
8989898989898989
898989898989898989898989898989898989898B66883392
9A839B95919695898C8B8392888788898789898788828A86
85838087878A8C828385888088887F8C8385848680828386
7F86797D898595848993B8799191AA919AAC8A89878F868B
8589898989898989898989868A898989898B858989898989
8989898989898989
89898989898989898989898989898989898989898264468C
998691918D9890918789898B8D888A8A8585878786848383
828381878386858187848583838680888280818A7F81857E
7C888081918A858A8C98947C9A8DA2979CA28B89898B8589
8989898989898989898989878B8989898989898989898989
8989898989898989
898989898989898989898989898989898989898989746B6E
84918996928D918D8A8B8E8D8E858787867F8681888A7D87
87877B897D8A828E7C8B7B887B858A8385828884898B8187
85917E81978F73848F9891889C95A090AC8C898989898986
8A898989898989898989898989898989898C868989898989
8989898989898989
898989898989898989898989898989898989898989897681
6F8982958E789B939F918F8C85868485818286848B8B7E89
7F857B897E8D81857F8E75878B80937C8788868481867E8A
7F887F8C818980859C9E89919F9982ACA18989868A898987
8B898989898989898989898989868A89898B858989898989
8989898989898989
89898989898989868A868A89898989898989898989898985
437C84939492A28D9A85878984838383848A7E898B848389
7E8481887C967D8E8C8389848C918987898A8B8D728F918C
7F8B8D80828B92878F949D9C94878FB98989898B89898989
89898989898989898989898989878B898989898989898989
8989898989898989
8989868A898989878B878B89898989898989898989898989
705C8E818A958780938C8F8A8482897E8687798D8684818D
7E8A7C838489868D887B908085A36A8E819087817886887B
7E8F827A89828E8E9E9FA67C8B77BB998989898B85898989
898989898989898989898989898989898989898989898989
8989898989898989
8989878B8989898989898989898989898989898989898989
8B66797D87A1918F99948A877D858881858B808C808A8A85
7D8A72908E7584937E8C8A89898177957088867C85828D87
938F8584928FAE91A19A69848197C886898989898989868A
898989898989898989898989898989898989898989898989
8989898989898989
898989898989898989898989898989898989898989898989
898B497679957D8B978C88897A838783878B8182848B8684
857B958E7C917497898F7F887D7B8980778D9B7E888F8982
85879190979C9F91937662AC76D09C858989868A8986898B
898989898989898989898989868A898C8689898989898989
8989898989898989
898989898989898989898989898989898989898989898989
8989784487A380949A938B85807189819189807C90897E93
8282898180927C7C967E848C7F858684908388858B8B8385
8E9B9490869D907F78739792A4BD888A8986898B86898B8C
868989898C86898989898989878B898B8589898989898989
8989898989898989
898989898989898989898989898989898989898989898989
89898B5B7A7B9291938D9686856894808C887D7C95877D90
7B8E6B9E838384749F7A858B84838686807F898D868B9485
929E978BA19A886B7EA080B1B78F858C89878B89878B898B
858989898B85898989898989898989898989898989898989
8989898989898989
898989898989898989898989898989898989898989898989
8989868A6D5B8C908988A18C7F66869082938985858F8082
8C8E749A87867F729C7A9C7E877B8D837F838E8385959692
9C9497928B657D837F918CD79187838B89868A8C86898989
89898989898989868A89898989898989898C868989898989
8989898989898989
8989898989868A8989898989898989898989898989898989
8989878B8B5459958C98988D86667B9A86838584768C887F
8E86868C848C847797858F7F858298819584919198A099A1
979881946C609D938E86CBAB898989898C85898C85898989
8C868989898989878B8C868989898989898B858989898989
8989898989898989
8989898989878B8989898989898989898989898989898989
89898989897F5C768D9086918786668E9183838978838B87
848C907D829A8A8288799C8782968E8593849498A08D92A1
89916B896582A58F8ABEB28C8A86868E868A85898A8C8689
8B85898989898989898B858989898C868989898989898989
8989898989898989
898989898989898989898989898989898989898989898989
89898C8689897A6075868D9C8D9E717B8D9582808F7A8B8C
8F8C8D77998F957E8F8B8B748A9C87919095939C95857C8B
76746C83849A8C91B9BE858B8B86858D878B85878B8B8589
89898989898989898989898989898B858989898989898989
8989898989898989
898989898989898989898989898989898989898989898989
8989888689868A766B6F8E9690948E7B7B997A8B8B7E8A81
8C7F9078A183A082A99980889F9B93999D978A9777737981
7E7986A4A38485CAB3858C868B8785898B85868A898C8A86
898989898989898989898989898989898989898989898989
8989898989898989
898989898989898989898989898989898989898989898989
8989878B89878F86787B778A7D959B8D78868595868B8F92
847B9C7C9D97A1859195828398908E87867C797C6C7B8C75
819495A38389B9C185868C8586888A898986898B898B8785
868A89898989898989898989898989898989898989898989
8989898989898989
898989898989898989898989898989898989898989898989
8989898989898F838987726179A49790927693948D9B988A
9092B298A7A2998690A08B8A91826D836F7A848077887D8F
98988E8FB7A3B48C84898B8987878C898987898A898C8689
858C89868A8C868989898989898989898989898989898989
8989898989898989
89898989898989898989898989898989898989898C868989
8989898989898F8389898B658F718B9D9386929884978585
9F858C827E8A8C838D897E7B917077956A857E87879394A1
8B8399B1C1828A88858B898989878B868A89878B898B8589
878B89878B8B85898989898989898C86898C86868A898989
8989898989898989
89898989898989898989898989898989898989898B858989
898989898C868F86868C8689866479958E9D8A8B848A8D8A
8D84938B878F8D8183838073897F78847197739C9C929281
8AA5AEAB89858C878B8C868C868986898B89898989898989
8C868989898989898C868989898C8985898B89858B898989
8989898989898989
898989898989898989898989898989898989898989898989
898989898B858B87858B85868C856F9D7689829991928D88
8684907F82817E75798388727D7D7F9785A385A5927D93A6
A4A9938989878F86898B858886898B898C868989868A8C86
8B8589898C8689898B858989898B85898C8A8C808A898989
89898C8689898989
898989898989898989898989898989898989898C86898989
898989898989898989868E858B8F83897094A28485908386
8E888F8689887E888290838E9477A8A1888D81999A95A7A9
8989898C86898B85898C86878B898B8588868989878B8B85
8C868C8A8C868A86898989898C8689898F89858789898989
89898B8589898989
898989898989898989898989898989898989868C85898989
898989898989898989878D85898B85898C868C7097828493
85898B878D878994888D8AA0917C898288899AAA9E958982
8689898B858989868A8B828A8989868A878B89898989868A
8B858B87878785868C848A898B8589868C87858B828A8989
8989898989898989
898989898989898989898989898989898989878F86898989
89898989898989898989898989868A898F808A868976929E
8C989489978784807D848589848A8A96A19B978F898F8981
8F8A8A86898989878988898B8989878B868A8C848A89878F
868989898989878B8B87898C868989878B8989898B898989
898989898C868989
898989898989898989898989898989898989898B828A8989
89898989898989898C848A898987898A8B83898B89898789
8D858B899188838C9296968D9192968E8B8C8A86898B8B83
8B8787828A8C86898B878B898C868C868B8988858B868A8B
85898989898989898988868B89868989898C86898B858989
898989898B858989
8989898989898989898989898989898989898989878B8989
89898989898989898B838B898986898B868E868989868A86
8C858C848A8987898989918389868A89898B87858C868F83
8989868C898F86868B8589898B858B858F80868C86898B89
89898989898C868989878B898F838989868C898A86898989
898989898C86868A
8989898989898989898989898989898989898989898C8689
89898989898989898989898989878B8C898B858986898B8B
89898B8789898C868989888689878B8989868A8C89858F86
8689878B868B85868C868989898C86898B83898B878B898C
848A8989898F83898C8689868C858989878B888C83898989
898989898B858B89
89898989898989898989898989898989898C8689868C8586
8A89898989898989898989868E86898B8586898987898E86
8689898F83898B898686898B868A898989878B8B85898B8B
838986898F86878B888A8A8689888A868989898C8689898F
818B898C868B89868B898A858B8C86898986898D85898989
89898C8689898B85
89898989898989898989898989898989898B8589878B8C85
8B89898989898989898989878D858989878B898989858E83
8B8C848C8986898B858B898C858B89898989868A8C86898B
8589878B8B858989878D858689878D8589868E868A86898F
8389868C85898B85898B8785898B85868A878B8989898989
8986908389898989
89898989898989898989898989898989898989898C868B85
89898989898989898989868A898989898989898989858A8A
898B8389908686898C86868B8589898C8686868C8B89848A
8C868C86898C868C8689878B898C868989878D818E89868B
858C858B898C868C86898C848A8989878B8C86898C868989
89878D8589898688
89898989898989898989898989898989898989898B858C86
89898989898989898989878F8689868A868A89898987898F
868989878D87858690818B898989898B8587898B868C8789
8F838B8586908090838989868A8B8589898989878F86848A
898B828A898B858F83898B838B89898C868B85898B858989
89898989868A8B87
898989898989898989898989898989898989898989898B82
8A89898989898989868E868B828A8789868C89898C8A868B
85868A89898986898D8986868E86898989898C868B89888A
89828A86898D878B85868A878F848E86868A868E8987878B
8986898B8989898B858989898989898B85868A8989898989
89898989878B8B85
898989898989898989898989898989898989898989898987
8B89898989898989878D85898B898C8587908A86888C8389
89878B8989898B8C868B85879183898989898B898985878D
858B8C898C868B8589858C8C89838D89898C898B858B8589
898B8C86898989868A89898989898C8689878B8C86898989
8C868C86898C8689
8989898989898989898989898989898989898C868C868986
8A868A898989898C868989898B858886858E8586878D8589
8989868A89898B87858C86898B858C848A8C8A8985898989
898B878787858C8689878B8B828A898B87878789868C8689
868C8B8389898C858B89898989898B828A868A8B85898989
8B858B85898B8589
8989898989898989898989898989898989898F838B898687
8B878B898989898B85898989868A878B878B878F868C8689
8989878B898989898C8C838989868C838F8C858589898989
89898989898C8C8686898989878B89898989898F868C8389
878B8B8589898B8589898989898C86858C858C898C86898C
848A898989898989
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.678571 0.015625 0.97619 0.313244 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00751202 0.0192308 0.00751202 [
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(300) show
81.000000 12.812500 moveto
(deg) show
99.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(.) show
105.000000 12.812500 moveto
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
128 string
128 128 8 [128 0 0 128 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
73737573717372737570736B7373737471737373737A715A
837570737175737075737373707375737473717373737373
6F7673737573737373737372747073747470737373737373
737373737273737373737379766F607E7375737173737573
737373737573727475717473737175707173707374737272
7B73677B79757471
7374726B6E787B777173777C7D7473716F7373727268666D
8F76707375726B6E71707373767B747175707072726B6A70
76756F726F6A6D6E6C6A706F6C7376716D6D737574737373
7374737374736C707372736B66737269687873717373706C
71757575756F73736E6C6F6B6B73736E7073777E7873778E
9064667774756F6E
71706E7274706B6E7370737B827E72727270717270717587
65556F746F6B71787A7773737373706C6F7475736F70746E
66686A69707371717273706D726F6D777A7B797677767374
7373737373737779737373736B5C80B375576B6E787A7573
756D6A6F75757674767373777A77707172747474757E8275
6D757B74766F7576
7575767975787A74767A736B6D7A8D827372716D6F70676C
8D976A71767877706B6B6F7373737174756D707371777570
7378756F6C6F7271707272727272767C7773747B7876797A
7B76737374747473747373737371666D9784687C7974787F
7B777C79746F717072737877726E7372717278758684777C
6665757580776A6C
7274737074746E707673757A7678777C7F7977767675787E
796F7A76777373737876706F7273767B79736E6B6E75767E
7F7C7A76746F706B66666E737474726A6C6D6A7175707172
717374767875737778787577757370666D767F6B76787873
707376787675787676747572737573717974798987788281
74836A6E7D7C7D76
737371736F6D7277726C6E6B727772787E81777578767669
6B848B7677757A7570737A78746E6A706D666C7371747373
7373767D786E6A6E7379756F7273737370707976676E7572
7374777874757873717070726F767570667E916F6A727475
757676757676747274736F707373716D6867737474635F59
607C6D818B777073
7377797B7377736F71797276796E7276757E8A81787B7A7A
7272777672767A787A726B6B696D6E64646E6F6E6D737377
7878787A7A7F787574746A6D6A676E727271716C6D706C6D
6D6C6B70716F6D70706F7272726F6F736F697B9A86706D6D
6F7372737371727277757777736A665F5B69837770687272
77695F8280727575
73706D6E71777379736E6D706B7374717373727B817B7A7B
78707580535D70716F6F7373736A6673787373716F726F71
71737374717471716C6C6E75706D6B64686A686C6D6A6B6A
6E6C6F6F666A70716C6A6A6A6A6B6B6F6E67626C70727172
73726E71727272777871716D6764585C6F7C755E4B506E66
71726D7D75716F6E
737774757876706F70757978746F7173717370767A848482
868A817DA2966771747573736F767B7A797A80827E736E70
747373717579797778807A76767A7A75706664605A616362
605A5E5B5F615D5C5F64646D6F70726F696C684D5C7A6547
50646A6D6C6B71706B72756D4F4B687F786D666A777C6E7F
7F677C8574737370
7A7474737073767774706E6D717476706D6F717572767171
73707072768782576C766A6E7576706F67696C6B6F707374
71737475736D70737770707A75787B7E7E83868385827F7E
7D7F837E7C80828282828785757A7C7C797E7B79786B7D9D
9A3B4A64656E6E6B5A372327487D8681777C796B777D6D72
7268787372747877
696C7370716B6B6F73787573787A74717677727671747073
736E75747171686A6A5468767272767D7877747373707475
73706B7071757877757377777577737375736B757A7E7F79
7879787B817A747472787873787C6F707276767C7B716D6D
75A4C77859444D423A5E74788377716A678D8071705B768C
677D8174786E6D72
7C77707375777C73706F7477746E72737271737172767679
73716F6C73706A867568715B647370716D76766E70747675
72727371716F7171757570707373737373757B736A6C7076
7B75726F686D777973747373736F6F7570746D6F7276786D
69666D7A9DA15E4069706E80786A5F5E757F525E706C786D
6783858675777576
6B737A726E756E747B7A7272767271737978767172717370
6F73757673726F7675736B5F414C6F7372797073736C7276
737372727471716F7375797773737373737373737673756F
6C74756F7476706A6E777373736E757772716F76736E6B6E
726959483122518A7A6C7D7871738284736E627A746C8572
7280737971767A74
7A746C70747570746D6F71756E72747473736E6F77766E72
74727176767374888E77685F6F4A516B736D676E72777675
73737373716F737373736F6C6C6C706E707373717373706F
716E6D75767373727471706C6B707873717172706C6A7069
645F60505173878287816E6D777E80737C705D716D787D6B
7882787375776E6D
6B6F77767174767872767271737273786E6B7073736D7274
6F7878736D726A77695C67656B693D3D6A6A7B7A746F7170
707373736E707373737375797577736F7070737579716D71
7475757171716E6F716F737279756F6F757674716C6D6B68
6868625D7D89736D7C7979787C736C6865637F8B828C6C6B
857F737170707476
73726E6D72766D6B6D7475797373736C737577767173746D
767372757373707666807E78746F6C4A4C73736A71747377
7873737375736C70736F6C6C6F6D6B727777736F6C717772
6E6C70757670736E6F73726F706F74726A62615E595A5D63
5B44376990816570717D8F8F73626867797478738B766B8A
7E6D6C7177747671
7076777377736F7579766E71727572787772767173717377
706D706E73737975746D6373646874774143756E746F7374
706F6C6C6C73757070717377757574706F6C6A72756F6C70
7070706A6D6E6F6D6E676C716A6D676A6D6F706F706D6150
3C547B8B786D7D9280796B6B787B747B76727B7466608084
7C6D707675737575
75707179787077797670707370706D6F6C6D737578767273
74737373736E6C636F555F70686B787C7432316C726D7171
6E6E737373757177736F73706D7275746F6E6F706F737775
7274706A6A6F706F787677706C6B6D72676C6F6E6457525A
6D849092786C737A6D5E57646273897F727D7D74778A8B78
707C817B78797873
707776717376746D717577716D72787B797A746C6D707374
7275757271777771786273716E71736F6775443F72797674
72737373737073777173737374747373757773736E6E6E6F
7172707475706B6B6A6C6C706D6F706C696A6A5945545266
818988756D76727879818A8A87827777828174737B756973
7B76767471706C70
7C796F7270717579736E6D7279766D6C6E7175747476736E
6F76757273706E72705C6F6666777867666C7BA773737276
737276757775706C6F736F717371717072706D6F6A6E7173
736F6F706C696A6F747B76645C6865666160535F5D677789
686E756A6C6E7A7B76827975817D767D7E74737D81777F80
7E7B747074707678
737070726F6F706E727372787672797675736E7077716E78
797373747473736D58576F706F7873777A7F89584D787679
76727571706F7373737174756C6E73737271757176726F76
7571736F706767748173565E6F6D6E6B60625A5A7C938B8D
919783777A77776963626976665B787C73737B807F807F78
726A717873717670
7375747774737373777177787375716F757072706E737672
7170706F706C6F6865646A6A787D666E7283826383767476
7073716B6E716F6E7174726F7375707272706F757071746A
686C6C69646C78807C5B637C786D5D4D4C6771746D727E68
6E7472716F6077778477837A738986737378767B7C747674
7078797370757675
736E73737379787673727573737372737376767474747278
716E76787672725B61696764676262717E89725A9978716F
6F747371727371726F6D6E717374746F7175736B696E6D73
71736E6C6B6A7778525169655F5A615C6C7F6E76796F6167
7976736F7183856971686562786B6C747480908873767A76
7377736E70717073
73767870747370717073737173737575726E707378797174
717878737070695D68677375786961787B706779AB727A76
6E71737278737075746D70736C68696B706A6B6F73756F6B
6D6768636776735D5B6E7270685A5F727E817F8479718489
7F706B738B87786E6F6D73727E898777818575717574716A
7176707479797873
737071767870707475737376737370737573767873717171
71736E6D6E716E686A68696B7072808D7A5B5F6A96717164
6F77746C666C716B696D6D696D706F716A6C706B6D6C6D72
6C6D6D6E72786E5A586664655A6E80777673737D7681796B
77676B7379777F7574807A757B73747E89847B7471767478
7973716F6D6C6D71
737576707175757473757371737375767578767371747173
767370767A7362596D746F707365766F585E73739B747678
7C6E707677756E6D71706D706C6F706C6D7373746E6A6F6E
6E73706C77745D616E6C645B63735A6171827C768581746E
6473856F72716B688082748280727E82796A6A74787A7575
7071757976747873
73737375736E73736C707576737071737373737073767170
6F6D76746D72606368655F6664667B6E6C7383789F6B6E6F
71716C6D70706D726E6B706C696E6B6C70706C696D716F6D
7269676D776C666B6A6869767F696B7976716D6E6D6F7C74
7367647A7F6A73848264657777798075737C807372767574
7576737371767671
73706E717173747579746C7073717473706E6D6D73707078
7B76776F71635A706A686C816F797D73635F666C9B6E736A
6E6F716F6C6D6D6D6B706E6F736963676A696C6E726C6A6A
666A6E7063525E666D767B7469727F827C7877858A8F8368
69717F6D6A7A7A7264646F7D8178777874716D797B747576
7370717375717071
6E73787370726F6B6D7379786E7273717176747778757876
706E7070746061686B6D65696880685A596C7371956F7576
786F6F6D696C706F716F6C7171747673706A6E716D6D736A
676B666D686762707572735A51586D80837D726B6A687488
84847C78706E74666573737D758582757676747A6F6E7073
7073767370747875
7876737575777A7A7976737376736F74707372757071706D
6F777372685A6A6764626F6D6971666A6F84817B946A6F6A
6B6D6C7175746E6C6F6C6A69616267696E7368666D736A6A
72726B786E60727B6E695057637E93736B696B747A797D6B
7A887A78768064656A6A808C827B6F70737A787573767573
7571707073737173
7373707171716C6D6E7170717375797670706F6F72767177
79717073605D635B6A6C7074766F5B636F7473719172737D
7A75767976777C7E7A7972676E6E686D6C646E756764696B
676066756062747364585E728A90777B7B75707172756C66
74706F707D826D787B8C84778479707B79767A7775757473
7376787576717470
6E7175706B74767878737074736E70707476737375737171
6C6E726D666A69686E6E707B7370596F78776F819D818A85
808789837D807B797D7D8489756A706C6D6A655F696F6A6E
706B6D7057677D685C62688978717C7370696D7D74787E8A
807D6A5B72736C6F7B817E9785727F7A7676717071757673
707173737375736E
78736E747C79717473757876737276757373797274707373
71747564595F646A70636866696D61817776719DAF847E7A
7674747A817F7A7B7A767678838B7A6B6B7276776A667273
6F706B6C69868D6A5F6A7E8B6E7C716D6C6E75756A717372
7377687E85666F7D8771737E6C666F7276767470706C6D6E
7376707173737579
6E737373706D727170737373706E73707074707177716F6E
7374736A6662686869767D7075596A836F6DABD7A47F7875
777B7A787674777F78777778787D87907C6B686873776F6C
666963526B7A806666605F7282807181728581787F817C83
7F5E6B8073656D7B756A96836376817B7A75727379797975
7171757673707173
7873737775787771726D707375747173757170737475797A
756D5F5C5E67676060646B70655A817D6ECFEBA076747576
76796F7170777673767E7C75737B7A7A827C6C6A6C676B68
6C6E61698B647D7B83897E676F687672657A777E736A7274
6D757C6E7473827B737F8468738076767270727573706E73
7571717373757673
737576736E707376797877736E6F73737575767876737370
6E7069655E68697075786D6D62687A6697BA786F72717173
7473777D77716F73746E6A767D7775797A7C947F6B6C6E6B
6B646973817D8D6C6A5B709E8F8DA17D7E726D7777756F6C
786F6974696C7F817D6F6873857F76777275717470707676
7578737173737071
6B70707176786E70706E71707174727570707070736D6F70
716B686562716B696367646E5D6E7886C29F72767873746C
6F6C68707073727272767E7670757475787E7E7C7B6F6F6A
6D6A6B5F6D8366738BB38F795C646169707C80746A756D70
7E6C6D7878827162667A8C827070706F7373737671737470
6E71717171707376
75767174737372727378767575737774737878777376766B
6D656A616460656A6F7971615F898BCABA76767373706D6A
6B686F6B686764696F6C6B6C736D6F747578797A8A81626B
6A66686E7A6B747C79738595797D6F776C765B65727C6E75
5C758D6F68756D727D8B8C75737772777370747073787373
7574757873737673
7876717473737176736E6E6E73787373736D6B6D6E717572
69676358616666606E73595F7169B6BC78776E6A6C6D6A63
605E5B5A5A5B6465605E696D72767B74727172787E89947D
6B7272767364708C7687A5816C657B7C7F626E7F7B796F76
7E826982947A6A77788877767E7372757575747070717171
7376737375767370
737073767370737675787576767375767173757878736E6D
6E6F6769696F736C6E6C657781DCD77877727173716A6567
68655F5F5F616368696A6D666D727371737174746D707B74
696B69616674816152776D81918D6671797384787C6F7E73
676D778877737F82797A717A717579767175717379767176
7670717373737375
737174737073767373737174737373737575726F70717064
646F61576165686D6D5A65797895736D6C6C70726B483746
505C656A6A6A5B4D47495A6F737072757675767276767084
806A64687272667996857988829894736A806D5F6D70696D
7C7575747B73718184776E746E6F6E72716D747471737573
7175737173707173
73717470737371737373717473706D707371777A7372706F
77615664676A6B607276767CD2C8727272767557465D83A7
A78C7C8797827B86837C67606D7070737173757775707576
848C6E6D6E754865896B6E5E72827D7F87616F847B717177
6D7879665A5E766F7F888076717A7B727074747174706E73
7670737670707470
6E73737373737371706E73736E7073726E6E737370746560
524B59655F62657562596D9CAC74787573716F5D6B736F54
354965543B3850547477755E5F727672757B76707176787A
7B86878670677D9457657B777B6A958C6470886668717274
6D7370687C82717282737671707773767978767573737876
7375767375787675
78767576717173737073747173737678757375707173686A
6068655B5D746D5A667C87C6A6736F6F7357414143354157
5650514D4E444C54372A404044456873736D6D767473767C
73737B6A5C7F735A6184666660706C859A8D687381736B5E
6E7F727D83837C837F7371717B746F737071707175767373
7373737071707173
6E6E6E7175757173757673737576736E7073716E726D686A
605D55596E726879837ED0BE6F707776737B9E97969C8C81
7A8792878A99A09598BEC7D1D3B387736F70747576767373
757C7C7B7C655C706F6C817667726E6D82716B837077726D
7F6C6D796872718D8E776F717274746E7376757670717370
7173707376717473
7875737470737876717471747576757873757571716F6860
595B697872696C7071789B6E72756E71747B828CB5CAC9C6
CDCBB9BED6CFCAC4BCAD8C84807C7973757672726F767673
70787A7A82748F7F6358586070575C5F6D70917A6D676B7F
816170756B725F7F79727373797878757473737375767073
7371757670737673
6E7378767576707175767174706E717372716F74705A595B
58615F5F6B616B7870B5BA7577727674757572737470767D
7A6E7370686063676F7471767F797376757274747173706B
6C736C6E6774856E9689856E5F6F887A6E848D757789745E
56647E756A7E798F796D6F787A7373717473706E6E717576
7576737375767370
7374706E6E6E737270737576717673717173737276725E4A
516C6D6D6373817375A483707175737176747773716F716F
6F6C7372726E76797675727A707378726C6F7674716F747A
787374777D8E66606054555A7D795F656D6E5A707B736B7E
747C74696E6B6B836D756E74747173717470737878767071
7373706E71737375
78737375737676757471737375767576757573735C575D63
6D63686C706F6A7569917070747375787372747373717273
6E6E696E6A656E7070727579717074817A7973707275716D
6E696B7270646F867B817E86786555705E547F8F6C736679
7E866E736D678B8E77747A7E737673757675737173737174
7071757876737373
7375767578767373757371737373706E6E73786F635B5C63
6677736C7D7A816798B46F73767473737878717273746F6A
645E5C6462686C6A6D71736F747F7B6B6C7471716F737073
787D7369717C887B70636C62676D72566C936A5A6F7F7475
6876717B7373927176767C7E767373737071757673737573
7074737071737373
6E717373737370717070747370717578737370736A5E5557
605E656A626D746AB09F747476737373716F71737373706B
6774706D6A696C6E6D6F70716E6E7276777B7B7776757073
73696D7872695451666A776272747F688453578D7D73777C
766A65777485897376596F73737373737174737373737375
7876737174737373
787673737373757373787670737673737577756F5857585B
67646974817C64629B727171737075797573747274573961
827D7651354C6A54566A70797B7B747477736A7074727676
737577696E75737E6D666667776D697A6850846763776F5C
64667981718D7274657D8A73737373737576737373737373
7373737576737071
6E6E71706E71737576706E7373717373737370675155647A
7575736C75696587AB73787A7C77716F6E7171737881A39B
76797A90B7AE968D83687077747373736B737F7B75747570
6D6D6F777A7A6869686D6F74696D6E704681755E7D67706C
77797A6B716D57647C9A7071737373737071737373707173
737373706E717576
7878767578767071737173747576736E7073756B585A6355
5A75757D79666895A073746F72747B7A76787472736D777E
7C78797C797670707E867E78737574737773676C75767674
6F6F6E6E6B715F7C717C7F7D687168756A8C5F8086617771
7F77727A7A7377898B737174737373737576707173757673
7373737575747373
737373707170737670737574736E7072727170654F5A6D78
8172757D706378BEA679787C7A7472727275726D74787B79
76707273746F707371797B767375727574777E7774737475
7B7B72706F6A6A706B8157687584626A808C677A696F7A76
786D66717A6A77948B737576737373706E71757673737373
7373737375767373
737373757675767070747171717574737876704539695F59
66707470545F699376756F73737273747374777B766A6E6F
6D737469646A716D737C7F7B747577757173737777707374
7777736F737A7F797871858A6D7868796970746C7187716B
64738194815F6E7D7371706E6E7173757574737373737373
7373707173737373
6E6E7173737071757876757873717174737370515F645E80
807B734D59747BAB777A7B78717272717171727572727170
6D69666C727777767E827C72727373717574737370767674
7176797C75706E65857B6A636B66777F77887F7779806973
69716D6C6D84A68B75767578787673737576737373707173
7373717171737373
787876737073767373737370737373736E6E715864687780
6E6E73727971C8CC767372737373787B7B76737377797175
77756F6C7078787B7C79777675747877767273736F717373
716F70726C6F78746D6B6C7180716F767A787F827C7A587D
6D78718386787F7673737373737373737373737373757673
7373757876737071
6E6E6E7175767373737370707173767173765C3B5F697678
73755B5366D3E688777D75737876706A6A6D727171747879
7371797A76787873747672777F77756E787A7976787F7976
7877767B7C74717892928A8476768172687A867875716473
567370817688897373737373737373707173706E71737071
7071737373737576
737675747373737373707378757473757876302E5F5C736E
6A726B8391B67976796F6D78787073747976737373737074
7377787070757779777375796F747977736D737575747374
717674736D75706A787C6D7473747E708496856E6E676068
617C82878081797373737373737373757673757876737573
7376737071737373
73747576737373737375767371747373707153756D6C8578
786E70739DBB7878727278786D6E7373706E787B76727578
726B6C6E70707173797977716E74726C6C78777371737678
737373756F716D726B686F736B7573766E82837273737C75
818B6F75897F737373737373737373737373707170717375
7673737576737373
7876707170717373707173737576737375734C74777C7167
73666F8ECBA576747373706A6D7273736D70706A6D74746A
6D767D76747473716F6E7071737171727B756A6C6F73716F
7879717176787A76777D776D72766E676088786C6F6E7256
7077747B8376737373737373737373737373757675767071
7373737373737373
6E71757671747071717473737373737071462A60647C837B
63677AC2C7757477737373787673736F6B6B6B6D71746C70
7973737273716F686D676B726E74736F706A6D7273727372
736F76787072727275697073737B76727E89627379516E53
6B7D8B868877737373737373737373737373737370717576
7373737373737373
7876737073767174757673737373737174416C8D6C7C706E
667A829A70697472787673716E6F6C626871706C6E707175
7573736F6A706E6F6D737E72746E6565676C707171737174
6F73777075757173716C686A77726E76738572717050745C
7B727F919073737071737373737373737373737371747373
7373737373737373
7373737174737573717373706E6E6E7376356A61797D6F77
6189C3BE666A7973706D736E6A6A6D736D5D646D6F6E686C
71727367686C6F716C6E707169666664625C585B5D646A6C
72796F716B6A6C75787C736B68736F77737C74665F54976B
708485858373737576737373707173737373737375767373
7071737373737373
73737375767373757670717176787876785C81566A657355
778590635578787273736F6A5E4637475A5C636270777275
77747474746E6A667D7A7768615D554B495962646472726A
65666A707271736B6772818A72736A6D6E7F64626E669852
658B74798176737373737373757673737373737373737373
7576737373737373
6E7173737370717071757675767373733832765D6B66726B
8CBDB562797C7070736B5C3C3D708F572E4A675849596F71
7573736E72727870672A1C325D81653F575B4F4F535F6169
72736D6E6D6C686F7A737F746A7973737984796D70658C5E
899F81907E6D737373737373737373737373737071737373
7373737373737373
787673737375767576737370717373734D777D7868697D69
5E84737282817873675C475996A4544865675F6A76745B6A
78736D6C6F726B5D61818597B758377088607C7A5E5A6269
6F71706E716F6C71686A5E46617B78686E7A6D5D6D738E45
8491748B7C73737373737373737373737071737573717373
7373737373737373
737373737373737370717375767373789B8E49535C7D6F78
9FB566636D766C6961524B33455551A65F5F4D4956616B80
79737272727A72736563826F4232955149578238446B665C
686A6D68676A7067677462687C655F6C887163717F718356
826F7D8E7373737373737373737373737576737375767373
7373737373737373
737373737373737375767373737373322E4A7B817F86737A
92955B6D797A766860614B707C1B001447A4799286908D7D
737171707273777E8076556D712E28297A54464B8F807369
69686B6B6962596174717681888B756678716E606C758967
8D78908B7373737373737373737373737373737373737373
7071737373737373
737373737071737370717373737373475D5F665D7E806C68
7D7D6876777A6F72828DA0A37B77929C867E90A8A397837A
77777170767D7D8086888B675A89C2B28D767391A4A08081
84796B6D746C66726D7179757D6D686F7E7D77737A7F8A64
817D8B797373737373737373737373737373737373737373
7576737373737373
73737373757673737576737370717397984C4462675E6282
8E6E64696D75767B838B98B5CAD5DBDCE1D3A48475747C7A
7371747879756F686E7085A4B3918998B5D1DAC5A699998F
8075726D6B73717673625F6877818879797D706D81808166
839EA37C7373737373737373737373737373737373737373
7373737373737071
7373707173707173737373707376788135475462677F726E
646B6F69757F6E6F76767C80848C78543729346E88897D75
7C767374767C797C6B4B453D4D7FA3A7A59A8F87827B7570
665866706A6470756C7C73686D66546D7C6761708079846C
858F796D7373737373737373737373737373737373737373
7373737373737576
7373757673757673737373757673666A3B6B60767C796E91
7D6B656B73766F6D656E72726B3B29445F91BEB4857A7775
7570737376737582898F74574F3F465C6B777C76786F6961
5570776767666C6E60595B75766A849A8882756E7A6E706B
868F7C737373737373737373737373737373737373737373
7373737373737373
73737373737373737373737071784D634E7C79886C6C7176
685C5F68767E785A49483F351F3583BDD8C49B86807E7775
726D727172747476849DBAC9B4874D2C23202F393C363D52
77837378717073698773758C847C65697B766B70837F6A45
849B73737373737373737373737373737373707173737373
7373737373737373
7373737373737373737373717470562E0B6E8683807F6B71
6F75766A7B827488A7866D6D92C8C99F7E7A777373737373
7173787B7B76767878767A8A9FBBD4D8B1896860647D938D
7E7C7A726D737C7059668763515367837A666F7B87795975
A78773737373737373737373737373737373757670717373
7373737373737373
7373737370717373707173757673726D6E788A86817F777B
78747B757A7A7271758AA7B1AA8A75737373737373737372
707878736D6D7172727475777A7674757FA7C1BAADA0877D
83736462677777797E735955617375A17D68947D70766B87
9A7C73737373737373737373737373737373737375767373
7373737373737373
73737071757673707376737373735B405C7790756D757B7C
706F78717C7C757673757372787B736B7073736E70727273
7170706D6D78767474747674737173716F766C6B706D6D70
706B777C747171657A82737E808882987A7A7E6770796194
9A7673737373737373737373737373737373737373737373
7373737373737373
737375767373737576737373737371648685755D77827771
6C6B6E6B72706F7172707073707076767573737577737373
757A78767B736D726E6D6D717670727277736F7470767676
75777968687A7274664E707F6D6262926D7590706A7157A9
916D73737373737373737373737373737373737373737373
7373737373737373
73737373737071737373737373737E6871605E6170656B71
7776838385816E7073747573727070757773736E6C707373
73736D6A6A6D736D6E7373716C6D736C6A6C737270737273
696865707B73685F60707E6764738183768D8C6C79677FB1
767373737373737373737373737373737373737071737373
7373737373737373
73737373737576737373737373737A47767A7C817C7B7A75
73797D7A7E767177747777737379786E6C70737177776D70
73737073737474787C7573727173736F706D6D6F73747071
7678706E707671716974685C7676727F775A6B6E7F759D92
737373737373737373737373737373737373737576737373
7373737373737373
7373737373737373737373737373755F78697F79696A6C6F
7F8077767376747372726D717370707574707075726B7374
6B6A6E737474736F7171736F757672767A7878746F717173
696B6F717366696E7373636C62629190666384798F9CBA8A
737373737373737373737373737373737373737373737373
7373737373737373
73737373737373737373737373737537769B79686F73707F
64617D8073747875737277777377776D737B776E73766F72
767372737371727577757070746F736C71726D6A6E737173
6D7973726663665B6D6C60637D7C90827360716E6F92A573
737373737373737373737373737373737373737373737373
7373737373737373
7373707170717373737373737373709AB15B596965676F6A
778779777D8179757477777272757371766E70716F6E7874
6D72747473747372736C707A7270736F766F737072727675
737A6A6869767D7E6A5F6B777E73967A777481787F978273
737373737373737373737373737373737373737373737373
7373737373737373
73737576757673737373737373737381545F716A6E70686D
7879857C7A7B7B75766F6F7273706C6E6F7277757A756F72
76747473737373746C6F7673707876777A747670736E7070
777067777B6C615459606A6F6D6B94786D6A858694947373
737373737373737373737373737373737373737373737373
7373737373737373
737373737373737373737373737373707C9575777A757A76
6A70737176777A7675757872727774777A7873736D737770
7274727272737373737A757072716D73736C6E717376726E
696A746E6B7677676E6E77757D789482767B857D978C7071
737373737373737373737373737373737373737373737373
7373737373737373
7370717373737373737373737373737386766B676C6F7176
74777D81817C7B78706E707174716F71706E706D6E716D73
706D73737472727371716D73747173736E7078777573716F
716F6B6E6D6361657172737984707F70718D8E8D86737576
737373737373737373737373737373737373737373737373
7373737373737373
73757673737373737373737373737373755D86837E7B7472
777E6D707C81797078787877737271777770706F73717272
737473727373746F6F7372716E70727270726E6C6F737277
706A6F696B68656675747375665F866C647D829288737373
737373737373737373737373737373737373737373737373
7373737373737373
7373737373737373737373737373737373A4CFA691858A7F
72767F7D6E6F767870706F6C707273706B6F737776737474
747370726F6D6D6F777272706F72736B6C72717076716C70
656B6A6C6B656678767273695E87B07F79887E8776717373
737373737373737373737373737373737373737373737373
7373737373737373
7370717373737373737373707173737373758DC09975686E
7D766F77797273737375747877707173737373716E737372
7373757771737377736B6D6E74737373726D707672677167
69766B5F586D7068696D70706DAD9C6074798A9275767373
737373737373737373737373737373737373737373737373
7373737373737373
7375767373737373737373757673737373706A7878736A6B
6D747B77757A74686E70706E696E717274736F7173737072
6D6C6C6C6F73716A666D73727273726D6F73736E6E747377
75625F6B77787B746D6E6962C3C268668395A085706E7173
737373737373737373737373737373737373737373737373
7373737373737373
7373737373737373737373737373737373737375775F6888
817E8378767575787A726F7176797570706F737773737573
7078766E706D71737372727373726D6F73726D6D6F62696A
626C72787266668A7D5D6BA4915D707D8B88897A717B7973
737373737373737373737373737373737373737373737373
7373737373737373
737373737373737373737373737373737373737557678D60
608173787A7A6E6C717373726C716F72726F716D6D6D716E
6E69666D68696F6C7272727273736D6C6E6E6D726F6B6E60
5D63636067757C5966969F8884877C8E9384817B78736D73
737373737373737373737373737373737373737373737373
7373737373737373
73737373737373737373737373737373737373755678706C
706261706D666E746D6F6B6F74736E6F6B6C717377706C6B
6F706A65686D6E736F696A686565646C6C686A665E666D6C
6E77786C6866676B77689BA18B6988858AA096706A717378
767373737373737373737373737373737378767373737373
7373737373737373
73737373737373737373737373737373737373707B9F5D66
7C77767670797B6D6E6B6B746F6D6C7274716D6B6869706F
6E67646B6D6F6D6160666761666B696E6B6C6B6C6F6A676E
706F616B7B788A8C8294A2727D8A928D8B7C7173757B7670
6D73737373737373737373707173737373706D7373737373
7373737373737373
73737373737373737373737373737373737373737B606DA1
79747A6765676878756C6F6C6E7474716D6C6A6969665F5A
5D656667625E5A5B626260635F575B605D5B5A66666C6E5F
566676757D8A6F6A8B8C6F62807A7D7C9195767373706D73
737373737373737373737375767373737373737373737373
7373737373737373
73737373737373737373737373737373737373737390A38C
7D727380806E5D535F73787E7A6C6A6A6A65645E606F6D6B
6B6A61655F65626B5F6059595A5B626360656D62677A7880
8A87707281807B6656768985838A90768277737373737370
717373737373737373737373737373737378767373737373
7373737373737373
737373737373737373737373737373737373737373738EC9
B6906D6A6B5A6D7B848381776E6F6C665F636C6E70656471
65606167646D675A5D6E5C5C686D6D616266666B5C495263
626971826A556690A1876B7B9990698F9673737071737375
7673737373737373737373737370717373706D7373737373
7373737373737373
737373737373737071707173737373737373737373737378
5F7488897E9CA980745E59636A68686A6D7264646E6C6265
696C686C61726D7E826B7B856E7A7E777F75777E6F747B79
6C6F796E75847D70717D98A0806A899C7373737A79737373
737373737373737373737373737576737373737373737373
7373737373737373
737370717373737576757673737373737373737373737373
A09273736559555C656E7C7065656D686768646C6160676C
64716D616C605D6B696C686779845C5F6177755F646F5945
4C63565361606B7B969F9D6F695A848A737373706D737373
737373737373737373737373737373737373737373737373
7373737373737373
737375767373737373737373737373737373737373737373
70A3B67A7E918B8991857574696565686D6F73786D6A716E
616153727F6D555C57657C7373545580573E4A5D62697D86
92847A797D86AEA6958C3E425B85B0767373737373737071
737373737373737373737373737373737373737373737373
7373737373737373
737373737373737373737373737373737373737373737373
737060786357434B606B707171706A646A6F686368776865
776783895B7F90747375525F565D674959827F6B6D787264
5B607994A0A1887F8E54548C6CA0886D7373707173707376
737373737373737373737373707173787673737373737373
7373737373737373
737373737373737373737373737373737373737373737373
7373956B699C8A7F706A706C695E606471736D646F6F6C7A
6E7C674F726562796C636E6B6A6B6C7A7E6C5D61746C646C
7E928A746775845C2E4E8C87A9B36E717370737670737678
767373737876737373737373757673706D73737373737373
7373737373737373
737373737373737373737373737373737373737373737373
737370A8B846598C866D6E797A69796F655F6167736E6768
606B637F7373604E7F6F666F6D716E675E5A6A6C606A8381
7A7E8C91AAA472646F82618BB48678747375767375767370
6D737373706D737373737373737373737373737373737373
7373737373737373
737373737373737373737373737373737373737373737373
73737071A5B7673D54677B76726562707B7A8287716A7569
6D7A6F7A757C7E6A57598F7D6E606E736D6E6C615F696B82
A59277816C28355E796979B3796A6F767370717876737373
737373737373737071737373737373737378767373737373
7373737373737373
737373737370717373737373737373737373737373737373
737375767081967B576368616F6E716E6F6B535C66646073
72607680656D7B8CA077575D777C897C979A9599ABAF9E91
829A8C6B514C6C727B8CC2A4737373737878736E6D737373
7876737373737375767876737373737373706D7373737373
7373737373737373
737373737375767373737373737373737373737373737373
7373737373819EA68B6A43464A767A6864727B6B5D64605E
677170626A797B7C7E7A99846A8589807A7996A0A7968D9B
85614E644B749D8069AEB4787B7670767071787371787673
706D73737373737373706D73737378767373737373737373
7373737373737373
737373737373737373737373737373737373737373737373
7373787673738795857B8683746F7E8D6C6E7778887F7371
767975667E7E7979859B89677C7F778B97988F938D826E4B
3F3D2A376A927478CABF6D707076787375766D7576706D73
7373737373737373737373737373706D7373737373737373
7373737373737373
737373737373737373737373737373737373737373737373
73736C6C7370718EAB826C797D7B748D917D5E7077798F75
64525E677A6D807CA4AFACB6C4BDABA4AAB2A08F623E4F67
585B7EA4A07970BEAF6D7876706A6D73706D707173787B76
737373737373737373737373737373737373737373737373
7373737373737373
737373737373737373737373737373737373737373737373
7373757673757B768ACCB5704954777F8D8F868C7D808AB1
AB85816F7786938061556E828F929A8D6742454846677158
60818E8F6D73C8BC6D706E6D706E71737370737673706A6D
707173737373737373737373737373737373737373737373
7373737373737373
737373737373737373737373737373737373737373737373
73737373737375707376A7A1737C605D7F8B98A1A0AEB087
9EDDFFFCF3C9A894A49F7C7B7E6538455457595F61676080
A79A826DB4E6B17873737673757574737375737173787673
717473707178767373737373737373737373737373737373
7373737373737373
737373737373737373737373737373737373737378767373
73737373737375707373709AE89559635A698E938C887889
8F6C5B555E707E8380776B535B56697C5766645F758FA6AE
86738ACBBC6A716C6D767373737576707173757673706D73
7576737576706D7373737373737378767378767071737373
7373737373737373
7373737373737373737373737373737373737373706D7373
73737373787675767678767381B2B578606A645E626F797D
79798B877F7B746D6E686D6F5A585D515A8070899A948265
71B0CFA47371747576787678767370737673737373737373
7876737373737373787673737378736D7370737876737373
7373737373737373
737373737373737373737373737373737373737373737373
73737373706D706A6D706D706E78A9E5A75D3E5E747D7972
6F686962635E4D3C3B4B5D606E5457898C99A5B5926C75B6
D5B2827373757B7673706D6C6C737A797876737370717876
706D737378767373706D737373706D73787B786D71737373
7373787673737373
737373737373737373737373737373737373737876737373
7373737373737373737076787675707396DCEA9A4E4E5258
6D7D7C767E85828A897E6576A3A6B7B0A1865E7198C8D9AB
797373787673706D737876757673706D6C6C73737576706D
7876787B78767B76737373737876737375736D7579737373
7373706D73737373
737373737373737373737373737373737373706E6D737373
73737373737373737375736D73706D7378767896CD98656E
5B51636A7275859FA5A8A4A586847E515A84B6C09B7E736A
6C7373706D73737071706A71737370717576737373737071
706D706A6A6A676C78737173706D73706E6A6D706A717373
7373737373737373
737373737373737373737373737373737373757B76737373
73737373737373737373737373707173756D6B6C738EBCB5
ADAD968688816C4E465A6D6D687292BCC0AA927C73757372
7B7B7B7673737375736E737673737576707178737173757B
76737373737375767075797876737375767373737A797373
7373737378767373
73737373737373737373737373737373737373706A717373
73737373737373737873717373757371706F787673737578
7D7E8185847D889BA49F9E9F9F9D907E76787B7673707070
706A6A6A717876737A7B7673787678767A796C6D76707170
6D73737373737373736C6C707376737373787673706D7373
73737373706D7373
737373737373737373737373737373737373737375767373
7373737373737373706F7673737073767076767373707170
6E6D787371737578787878707370717373706A6D78767570
7373707879757676706D7373706D706D756D707470737673
73737373737876737375767375707373706E737B76737373
7373737378767071
737373737373737373737373737373737373737373787673
737373737373737373737373737576787D766D737073767A
797370757973787673736C6C7375767373707178736D7576
767375706C70676C7876737373787673706F787675767378
7371737373757073787673706E6D737375766C6E70737373
73737373706D7A79
7373737373737373737373737373737373787673706E6D70
71737373737373737373737076767370676C737375737670
6C737375707370737670737670717373737576706D737070
707370737B7675766C717B76736C71767373737876737375
727673787670737670737B7876787673737073736D737373
737378767373706D
7373737373737373737373737373737373706D7375767878
767373737373737373737375736D7373757673737371716F
7678736E737673706D7A7978787673737373707178767370
6D737576706D73737573676C7375736D7370767071767375
7073706E6D73706D73706A6D73706D707175767373737373
7370737073737373
73737373737373737373737373737373737373737876706D
737373737373737373737071737373737373737373717171
73706F737376767378706C706D7373787670707470737371
787678767378767876737576737876737375736C71737670
6D7878767378767876737873717373757678767378767373
7375736D7373706E
7373737373737373737373737373737373737373706D7876
73737373737373737373757B76737071707173737375787B
76737375736A6D7073727673737373706D757876706E7579
7570706D70736D737073737071706D73737373757B706871
73706A7173706D757073706F7673737876706D73706D7373
7373737370717A7B
73737373737373737373737373737373737373737373706A
7173737373737373707676706A71757370747373787B7670
6D707173737370737373767076767373737378767A796C71
736A7170737375766D7071757B7376767071707673757B76
73707376737373706D737373737373706D70717373737373
737373737576706D
737373737373737373737373737373737373737373737375
767373737373737375736D737A79787875797B766C6E7073
7375767373737A7E76706D757870737373737073736D7573
6D7A7E7D7E76706D73717478736F73737D7E7D766D706D73
737A7E767373737071737373737378767375767876737373
7876787673787673
737373737373737373737373737373737373787678767370
717071737373737876737373706D6C6C7171676C75736D73
737370717373706A6D787673706D787371787B736D737373
73706A6A6A6D7876737576706A7173706A6A6A7376787673
706E707073737878767373737373706A717071706D737373
706D706D73706D73
737373737373737373737373737373737373757070737675
76757673737373706D737373707175767576757B76787673
73737576737373737878707373706E6F7B786D6D73737373
737373737378787676737373757673737373737576787073
7576706D7373706D73737373737876717471747378767378
7371737373737373
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.343006 0.321429 0.640625 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00751202 0.0192308 0.00751202 [
[.5 1.0125 -17 0 ]
[.5 1.0125 17 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
69.000000 12.812500 moveto
(deg) show
87.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(.) show
93.000000 12.812500 moveto
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
128 string
128 128 8 [128 0 0 128 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
787773787D777978717E768C787877737C78787878647CB6
4F717E787C72787E717778777E78727874787B7878787877
806F7878727878787878787A757D7875747D787878787878
7878777879767878777878686E81A95C7872787D78787378
7878787872787A75717C7478787D727D7D787F787578787A
617895636871747D
7877747476787E7E72797C8C8A78787378787878776468B6
63737D787C777278727278787D7E78737478787878787072
80777177727172757472727A72787D75727878787A787878
7878787879787672787878695F78B26A5978787D78787373
73797979747877786E767272727878787D78807F7C78787F
7D7E826D5E717478
76757578787272787872777E908C7877777775787874689D
8C42777A787873787C78777877787C716B7B7B78787B7871
71736E6D737774757B787278787178787C7D7D797A7D7878
7878787878797D7878787878695F90B5874D7278787D7C78
72777171747C777C777877787C787C787C7978797C7C7C6D
6C9186775E6A767C
797979797D787D7C767D7873768B8A8A7D76787477746864
BD8267777D8178727272717878787D7A6E7478787D787E78
787B7B726D71777478787778787777777C787A7B7C7D7D7B
7D7D7878787978787878787878735F6EBB8D597E78797E7E
7C7E7E7874787478747878797778787E787A777D78887878
78698B7C65746E72
777878727978747B72787C7D7C797E858F7D7C7D787B786A
839B697979817878787D727177787E7D7878777278737E81
7E7E817D737172776F706F787878746E7278726E7C7C7578
747D7A777B7B78787B7C7C787C78735F6EB5666A787B7B78
7878777B787B787D78777479787C787C7C7D72827B838378
956F89785E788278
78767975747676797871747476787D798B8D7F7C7A7C7668
689B8A7779827D7C72787D77787872727772727878717878
78787C827F756E767B7678717778787872787A7474777779
76797D78797B7C787478787478787B735F8E9E716674787C
7B7878777A7978797878727378787C7872766869777E6469
736D92786D74797B
78767E7B7D767B717B787B78787876787B87908A7C7C7D7C
6E6F907C747D7E817D7773717177786D6D777272786D7878
7B7C7B7B868181727D71796E71716F777775727578737474
74727472787774787477777778747678735E879E86727474
7774787478787679767D7878787872776B6B6A786B906F7C
776881687178767E
787273747B747E787B7279717278787478787C88867D7D7C
7C6D7C8F7C4E7979797878787877727878787874786D7174
747878757E7882747472777478766D6D6D716E7177717172
71777173727175767771717171737171796859718D777677
7874757276797678787D73737377736C786A63745F686E73
6D7C7E5E70797178
78777B767B787B7278797B7D7972757874787B7885818682
84877C88B68B6E767E7C7878787E81757C7C7D8282796D72
747878757B7D8481797D81757D7D7C7C73736D686D696C6D
676D63686D6968686D6D6D6D777377717773645D687D7C65
5367716D7274747272787C78785B777A7C685F7887787178
7C7C786E70797976
7D78797873787D7C787871767879737B72717D727D747B78
72787878789E91715E85786E7C787E71716C6D71787D7271
74747A787878788178737B787C797D828284888488817E82
7E827E827E7E83818382827E81747E7E817C7E826E6F8BA0
8C78316D68717271725C4747696D787F8378717278827D5B
7E865E726C767B7E
7175727C72747176787B7C76797C78797B747D747B747B78
7478767C7279988C546D736E77787E7E82757476787D7471
78727472787B7B807C7878787C7878787C7878747E817E81
7C7B797D817C797879787878817878737D737D7D7D766E74
7DC783906B55556261728278726D6376786C91766D767373
7D82776B76717176
7E7D72787B797D7B7573797B7478767B7674787876787D7B
7B787276757895938669746B5C7878737E737776727D7871
777877747478747C7C7C737378787878787C80787073737D
7E7C76737274787C7D707878787878737C727871787D7778
6E70698EA0A0855E6A72787871715D6577588B63698C5D69
86648F737B787972
72787C78787278797C7C7876787D74787B7B787D73747878
7978797B7679907D997868864D3F72787D75787876767471
78787777747C7478787C7C78787878787878788078787378
73797C777878737379727878787C74787D73797378787278
7877645D58507E85727572787377787A735B927368866778
7E6478787B727D78
7D78747879737C7278717D7278767C727878787778787876
7D7875787D788C869DA26487854A2E787278726F777C7771
787878787478787878787873737372787378787C78787378
787178797878787977737278717B73787C78767373797377
6E7773707078788384866E6D7877737877727C6D6D786F78
736D7B757E737478
7276797B79717D787E737D74777878787873787872787678
79797D747976836D899D7378838731256977777B74787471
727878787773787878787C7C7C7878787373787C7C7C7474
79797978747876757576707E787C73717C7E787876787477
77777E7F757D786D7588836E7378667662757E8282728668
6F7578797376757E
787672767972787178717B7D78787873787D767D74797876
7878767B7B78866D8C9DA0788D8B892B26786E776E7C7873
787878787C787373787873737873747678787878737C7C76
7475727B787978786F7971787378797373756B6D6D666D6D
78686366728286606C7C9088787364716F7C6978787D8277
6A7470777879727B
76767D79787879777B7874747C747C79787D747B7973787C
74777178787B817E858D967884858980261F727E6B787871
7378737373787C73737C78787C7C7974717373767C787576
767872727279747C6F706E74786E786B787E7A787E787268
6B6D8166687893777D6F78728288737173786D785F787876
777871727979727B
7973757D787D767B787B76727B7378717476727B7C7C7478
7D7976787879727E6F987D7D89818189871F05756F727472
7276787878737C787878787378767C7A7474776F787C7C79
797879746D747978787D72757C6E787472767C7878746B71
85787C7A78737871786B68686B7884787873787878788378
727F7E767B7D7878
76787874787E7873747C7D7477757B7B7D7D787472787874
7D797978777D7F8872AB817D8D85788187851F0B78727C73
78767878787378787C7878787978787C79787C7476757776
78767C7A787278756B75707180737277776E78776D69785F
807D70777878776C8488887E8878787C7B787778736A6E78
7775787874787472
7E787B7178747C7B787478767B7B727174747B7D76787B72
76787B7977767B83789E817D7E85828184787E1F786E7778
7877767C787C7373787878747878757A7676787476717878
78787878757273787375826D726D6E6F79676E778D618C70
71636978736F78727880837278867679787778777878747E
797C7878747B7878
78787B7376747278767B7976787D7B7B7678747978787878
7B78787D787B7C807B87818882778B899185782A2F737778
7D78717C7378787878787A787674747C7778797B787B7178
7B7C787A78786B717878786D727770767C6D78688A8D8085
8D7F7C827C796C7864677872696F6D787876787678817279
7872757B78797478
787B7C777B787479787C7878787B7877747B767871787D72
747B7379767876838C877884827C89788B7F7A77186F7872
7E7871787475787475797877797974767C76747C7878796D
747675787378786D77827878787D6E666E63877D66777778
656E777D78735B8B77807286787E78787877736E78787174
7D7878787B76787B
78787878787B7B78787C747878787D78737D7B7B79717D78
7877767C7E7E77897B90787C72708774848381840C787372
7879767C76747C767474767876797974787B7874786F7878
77787C787D6E6E6D6E786E686C727879716B837D796C6C76
676E787C7A86687F697D5D72776969787873827E77787578
7E74787878747278
787D787C727878747878787478787B7C747478787B787B74
7D7878787C7D78907888868281807C72787C848F157C737E
7774787A7A78787879787278767072747079717A78787873
747376787378676C7C77787377786B83756B8E848377778A
726E707B7E87777D7078786C7286787E78786D787B737173
757878797B7D7878
7878747D787878747B787878787878787B78787B78747B74
79747474787D8292817F7F7C788E8778857D73780F7C6E77
727679796E7277747278726F787875757274787474727877
78777880776F78727068726B7877817C78607883897E7075
7278667467808088777886716376717C787D7E737C737879
78787B7472747274
787B7878747B7B74787B787478787B787B7B78787B747B78
787B76777D8283847D88867D78867270788572820F7B7881
787672827F727978757878727574787278727C7B77737278
78787D7C777179787870726D726F7466706C787D89877A78
697876785F74787F767889786D777278747271737C797974
78747B7D7B797878
7878787B7874787874727B78787874787878787878787B78
71797678747E9680787A847075816C828289788915786F78
747C72707F72787A75747874727077737374737875797177
7778747E6E7C7F7A7274747D7B787C716E616D786E827D86
78695F78727077897875726D6D786E76717E7E7870787B74
7B7878787B78787B
787874747B78747B7D787472787B7478787474767278787B
7B7E747B7678938183788A7B8C7978838970667819816E78
6E787C70787872787773777878736F6F6B71717A76787272
72787878706B727773788178737E7E7B786D6D7D88889088
71756B6C677877777877716777776978786D78787B747B78
787874787B78727B
74787B787878737272787D78787678747B787C78787B7B78
7878727B7889848080817D6A87717F6E88756F731581727D
78787878727773787C737675787D7D7872726F7878787878
7272776E847970717B7078806060657482786D62716D7DA3
8D787378725F78787878785C72777E717D7378727B717378
787878787879787B
7B78787B7B797D7D7B7878787D7876747B737C7478747874
76797B76798A7E88787C8078786A877D88817C7C1C787271
727876787C78787278797270726974746F78726978787878
77787F6B8D806E757C70697A785E76786878676971837090
867A817082677778786E736D786E7972717B78737E797478
7B78727878787478
787878747B74747274747874787C7B787C72767476787B79
7B78797882847883788278827E7181757C73787523787878
817A7E777E7B81817D847E7476786E766E6E7674746E7778
6F7075668A875F73806E76738D6A6387787C775B6B77767F
7E6E7A7272788677887C76666C83747878727C787B7B7478
787D787B787B7478
74747B7875757D787B78787478787278797C767973787B74
747876798B87828878817B788C729066827878733578867E
868689868181807F7E858D8F8278747274746A6A70787478
7A7A72658D7B6970817A716C856363787E7178626D70888A
907C7C6E4F7887707878787476817E737B737478747B7878
78747878787B7878
7B78747B7E787B74787B7B78787D747B78797B7C7178787B
7878797F7E7E7F837C7C716A7D7E92677F7E7C6259797882
7A7B78808380867D7D7E7E82928E87766F787A7A746C7878
7C7D78629580788C787F73609664636D7F7971666762777A
887F887C616F7F7D6F84625A7C726D75727B747B72747274
7878787478787B7D
74787B737874767872787878787873787874787B747B7477
7876788E88807C817886807E718D78707D787C7C787D787B
7F7A82787D7A8080827D807E828493948970706F7A7A7078
78747D5D688564A778785C469381646C8E78866B726D7784
8E8974786A726C786C8069747875767D747B78787B7D7B7B
74747B7878787478
7B7879787B7C787D727473787B7C73787B747878747B7D7D
7C76717C8A7D7E7D7569787E718F6E788378A17D75747C78
7E787E74787A7E78808086807C7C8584958E75726B786D75
7B778478529848B49B898C4059975A628564847868676377
84A17A6E707C7077787A5D777B71767578737C7478787478
7B747478787B7878
787B78787872787D7B7C7878787778737B7B787B78787878
797B837A8D77818586777878838268747847767A72747479
78797F7E7F747A787878787E827C7E8384978B946E747575
7877827E45A2648AA469787663A088788478657C7070626A
84988169726A677D8470596E7E7979747C747B7478787878
7B7B787478787874
727278747D7878737874747879787973787874737878717B
797B8382887D817D7D6B786E906F707E5D74727D78787478
707871707F787A78777E827E787C7D7C828D7E978F707778
7483777D3A70905ABFA79755664F7F66728576727860785C
79A686697F7467637378727172727671787878787B787478
74747B7474787878
79747B7478787C74787B787B7B787978787B7C78787E7879
747F7A8D7E7A77818378817185737F767877757878787079
6E75756E75756F707177717D7878777A7C8284869C937371
787A7B825440A4667D98878780607E786A707D5581617E62
5F90A978636C75677778747C7176797578787478787B7878
7B747B7B78787878
7B787B7478787B7878747474787B78787874737274747B82
787C7A877B7D777878787F707C665D78787A757272787472
6D696966676F6B6D676D6C77777E7C7D787C7F8082A2A383
807A867E654764976C9A8F9386596A8B77707F6E6E78706F
7579A08A7E7A78636B6979787B7679717B7B747B72747B74
787878787B787878
78787878787878787B7B7B7878787B787B7979787B78747E
837C8889887986826F7890737C89767B767A7B7875777774
77716F6A6A6E6A6A746F6D726D77787E787C7C7C787C9199
7E747D78605A517F7547927AB1835D6B828573815F7F7078
6265A088777D816F6C597E7079767B78747B78787B787B78
787874787878787B
787B74787878787878787B74787878787B7B7873737B787B
787A8C7D7C77738B71747C786D1F74747274787878755952
63687272727272585C5854717272777D7E7C7D7E7E7E819A
A778788166574778A95F7E8789A2926D7084786C5B726F6A
7966848E7882706E76666D72787171767872797874787B78
747B787478787478
787B74787878747878787B7478787473787B797C78767E83
817D83887A7C737E768A7E75787C787878777B786280887C
A2947E7E8B948888838262546D7272787E787C827C7E807F
A6A9867C6F545E219091458760869586787F74846E6A7E67
6F6C7895676C7063638277787B737C787878747B74787478
7878787878787478
74787878787878747874787874787974747873787C728274
71777880826B787C7E67786C417B7C7C787477967378784E
536969654B675D65678A7C62497274777D7E7E7D7C7E8181
89A6B085894B81425A9A57817A5F90A77082787F6368776F
6E6272968878756751787479786E787D7B7B787B78787B78
787B78787B7B787B
7B787B787B7478787878747B7878787B7B7974787974897E
877F8375836F806D7D7F735D787878787878597C634B535F
6B5F576D6565565D48475761333B5E787878787D82787E7D
8886A9907B615F4C4D818B3F8D56599BB48282797F67726C
606A7690927A896D587176777B747178787478747B787878
7878787874787478
747474747B7B74787B7878787B7878747878747876788384
8B777D78787779877C87697878747C7D789694B1AB958876
888282968E9A928A9D8DB1BCAC8B7278787A7A78847E7878
878999B78F5D535E5351A96B6A774B6D939E7B787F6E7681
576C6A7B9267826973747873707B747478787B7878747878
74787878787B7478
7B7B787478787B787B747B747B787B7B7B767B79757D8283
897C7D8B78787A7278771F77777875787C807C9CAFB7BCAD
B3B7A1B3B9BDB4B3AD8988847E7E78787C7C7A767C7E7E78
7D8193ACA48659785A455E8F4E7F40526DAA888281696981
696F5C739A6D754871777878707B7B7B747878787B787878
78747B7878787878
74787B787B7878747B787B74787474787C74767B79787384
887F72717A786D787A6D667C78787A7A787A727874797D82
748278726E776D7378737B787C8178777C7C7A7A7C787E78
757889979D894D78738364A05D697C556E8D998E84847A61
60665C73947A8D48787871787378787B7478787474747B78
7B7878787B787878
787478747474787873787B787B7878747B7978767E948078
7D798A74787C78787C2B78787479787A747D767874787478
747C78777781787B7D747C74787882747878787E7C787987
7D788997AC926A4B54624F788B596E515C71848288738673
816162668E77784A6D7E78677874787B7478787B7B787874
787878747478787B
7B78787B7878787C787478787B787B787B7B797876789187
85787882787868787A0E787874767B7B7876787878787678
7977786E78786F727B73797381707982867C787A7E7C7878
7D75788E9E85815B70777B748F6A62525B57839390708860
8C6A70628587696F6D78836E7878787B787B787478787B74
78747B7B78787878
787B787B7B7878787B7874787878787474787B7C8979838C
78897D827887777678447678747878787B7C787678797872
786E716374766D6D747572737A80787879797C787C787E78
8186818097A1826D5D6B6269728C6B564D7B716F93789564
6E6975628594557C5E7E787B7878787878747B7878787B78
7874787874787878
74747878787878747878747878747B7B7B73787E948A787F
776A7D786C6D78833D787878747878787478797578787D78
797B826C73786D6F72717273736F77808079867F7E7C7E78
787D7D88919575535170617D5D93788431686871A3788783
6E6C685B7E92627F666D5E78787878787B7478787878787B
7B78787B74787878
7B78787878787B78787B7878787878787C787B7B92898278
79786C837E7876780C7875757278747C7C787A78747B5E57
8683897B4D53646F55667172807878788078787C7A7E7E7E
78868180889EA06D5D5F5E78617C7C7E4D576A627F8E7381
5C70686279788A5C83667878787878787B78787878787878
7878787B78787874
747474787474787B78787478787478787878787E97838584
8783787174797C78247A787C787F74707C747879759BA578
7A838AADA79282A07F63666E78787878787881867D7E7C7E
787881888999AA65645D67706C668E66782F766E679D6E94
6A726A5B6D62895078787874787878787874787878787478
7878787874747B78
7B7B787B7B787874787B78747B78787873787B88A3877873
6C7786777886755B40767674707B7F787F7B7A78707D787E
7E8185887D79757C8D7E6D6F78787A78807870787E7E7E82
80757E7C8186B870735B737283568A719D1F7A706BA46E8F
786E6C6768788A7C5C787B74787878787B787874787B7878
7878787B7B747878
787878787478787878787B747878737C74747889A5857690
7F757D7A7989754678767B7B79787877797B7C786E817978
7E7E7B837F7776787C78726F78757B787A8080807A7E7A82
878381818281B27F69596C4D90668A66904F68636995857D
816D68576779747A74787B787878787874747B7878787878
787878787B787878
7878787B787B787878747B74747C78787B787B8C8D7D7D66
727276767C717100777477707878787879787F8274747171
787E7D7E787373787776767878757C7B78787880807D787E
80848681828BA8AB6857826D786C8E72715762616B83A569
7D6E78687283555F787478747474787B7B74787878787878
7878787478787878
747474787878747B7B787B7B78747B7478787CB390788571
847A787871757A0F75797F77777877777777777C7C787371
7974787D8477787D787878777774747D787B7878807D7E7A
7E7D8D89868091AB706F566C6A6B7E857F616C70666DB478
7C6A644F659378747B787B7B7B7878787B78787878787478
78787B7474787878
7B7B7878787878787878787878787878747479C090838371
7C7478A078756E64767279787878787D7D7D77787F7D7B6E
7F8180797D78777D7871787C787874817A7A797880787C7C
7E787E87867E8BB86F616A60787E647F855B647C6D62AF77
91627852737A5F78787878787878787878787878787B7878
78787B7B78787874
747474747B787878787878787478787B78787BA487847277
7F7A7578786A837876787D78787D727272787777777B8174
788283887E787877737174787E7F707C78817C7C8182807F
82827D8797857DABA27585706A8A71787E60597D6D61AB76
8C537A4B637E717878787878787878787478787474787874
7874787878787B78
78787B74787878787878787B7B74787B7B78967878835F7A
7477937F9218737677737878787D7878797D787878777C72
787F82847E72787B78717573787A797E7875787C7C7A807C
7E7E82788F89838B8C786D6D6C78787D807760786F628E88
8C5774645E6D7878787878787878787B78787B7B78787B78
7878787874787878
78747B7878787878787B78787B7478787874D28B85896385
7F758B786E46797377787878787879777379787D7D777C78
787778847E726E77787974727872787778757D797B787E82
8278827D8B888887887070657067787E6F5A7778786F89A3
9171635B5A7178787878787878787878787878747874787B
7878787B78787878
7B78787478747878787478787B7878787B78CB81958A6A6C
7E7F708B5676797378787272787778787773727278787878
6F7E7E8C827A6E73717171747873737E7A7877747878787C
82837E7D87918F8B9185736D6A6C7177713C817870736DA5
69786D574E737878787878787878787878787B787B787874
7878787878787878
74747B787B7478747B74787878787878747B9F68827F8977
797F6E6C757C7479787878787D787779786F6F7373787879
75787788867A716D6E72677276747878727878767877797E
78827F8283878E898A866B7865697F7E823E7578777A47BD
567080674B78787878787878787878787878787878747B78
7878787878787878
7B78787878787B747B7878787878787B74AA8E968A6A8A72
88747C206C796C78787D7872797872786E7573736E727F76
75797782867777716E777274787371716D7577757678787C
7C7A827D85878E8B86936B666D5E787E78497D72729D28C2
6E556D75597878787478787878787878787878787B747878
7878787878787878
7878787B74787B78747878787474747878CA4C9385778480
89608B6A756B6F79727878777376748179686771716E7870
6E78778281787475726A6B75727373706B68686368677373
7F78827E7D8186898D978F5D635F71788343757E60A532BB
83516B666278787B7878787878747878787878787B787878
7874787878787878
7878787B7878787B7878747B787B7B7878F05C8E67797287
746A307A64627279787878787467524D7171596967787E78
6F79788A88816F70707E6978706E6C665A5E706969667778
6F6F787D838488857F849D8270587266824F65816E9B33B1
80466D54637D7878787878787B7878787878787878787878
7B78787878787878
7474787878787478747B787B78787878729A778D6A7868A3
5F826C916E5D72737878746B58729278475856694E4E7878
6C78788288897A7C5A7027465D7A966D50605F5F59506877
7778797880808188898582917258786D7865728773902FBD
8759805C6878787878787878787878787878787874787878
7878787878787878
7B787878787B787B7878787874787878B480959582667099
5B0F83877C63787973757878777F957E74545A677E526969
6D78787C82897978609F99518C8C718B667E618F694A5A71
70777D787E86847F837F707E635178785A656E816A913DAD
5D6778527878787878787878787878787874787B78747878
7878787878787878
78787878787878787874787B78787878C9B1836D8A5E708E
972A897469626D7779768264184BAA86BA306D375E57646E
71787D7D8286918278599F5523B161B1248242964B505864
6472787C6F82867F807F8D86715152845E6D6982788647BC
45616F587878787878787878787878787B7878787B787878
7878787878787878
78787878787878787B7878787878787238A69D9390707878
784484786D68747C7D858B85533E4E159465926D7078746F
74747C7D7F7D928D9077637B51A01D8A54643C867C5A6B6D
606C738177757D787E8296927882656D5774756D658652BC
5A695E6D7878787878787878787878787878787878787878
7874787878787878
787878787874787878747878787878BB4186957F78827868
535584786D6674818D9CC29D8692998C76698383857C7D72
78787C7D7D828C918D9692765AA9B8A89675786F8E847C7B
7878787884818879787F8A926E7570665A748581657D61AB
606A4E717878787878787878787878787878787878787878
7B78787878787878
787878787B7878787B787878787478CEA96C827861707868
625E71756461787D8292A1B3C1C6C1BEC0B098736D69777C
74777B827D7C8382778282AB98928B9DB0B9B79E8B919389
7D7C817877898F79827871856E7C8978506A8B7C657567A9
646A6E7D7878787878787878787878787878787878787878
7878787878787874
78787874787874787878787878787888C85B856A6D6D954D
515E717A6462786D747D8280888C8E70534B56527C78787C
797D777C7D7D8D8F83714D515372969A9A9288887E7C7E7D
786F6B807878897F7E898A7B6E606E665E557F7C5C7464AE
654C68787878787878787878787878787878787878787878
7878787878787B78
78787B78787B78787878787B78787268F95F8A707864916F
6D5C667864557E6F676E797777715B6C707A9C817E74787C
737D77797C78838CA2AB8B684F333E626B7C7E82797C7879
777078777D7878837E6582787E6E787C766F82825372559C
714678787878787878787878787878787878787878787878
7878787878787878
7878787878787878787878787478873FFF7E8582785E7F64
6B60566C68597A83524F5853506B759AB9998281817C787C
78787777777C7B7E8CA7C6C0AC894E393C36425653595665
80757D81877F78838A9B71858B895B51706D7B835A786E6E
585C78787878787878787878787878787878787478787878
7878787878787878
78787878787878787878787B7472AA3C8E7C788891707769
707666695F6272A09A8F7C7D8EA19C817C7C787878787878
7E78787D7C7D7C7C7B7E8891A2B6C5B3B88E6B6970788A88
787A807F877F7C91668C7C71706A6D4971736C8860708875
4D6E787878787878787878787878787878787B7878747878
7878787878787878
78787878787478787874787B7878AEB2918267938E827F70
77736D75555D74747C93A1A6907872787878787878787877
7D78787878777778777B7F7C7C7D797996A8B0ACA48C8586
7E7D75777D7B7A919B78786E787871478C7C629D5A62A660
46787878787878787878787878787878787878787B787878
7878787878787878
787878747B78787878787878787898AA717C618E86788474
7671647A565C757878727879787D78727378787873777878
7D73727878787D7879787D7D747D78787C7379787E78777C
73817D888774787F859B8F85857E852C9B8D4795724AA655
517D78787878787878787878787878787878787878787878
7878787878787878
78787B787878787B787878787878A4D17B825D7D82828078
73715B74564F6D747772727973727D7C7378787C78787878
7C7D787D7D7878777774747B787D78797C787C7B7D7E7D7D
7C817F7F7F787D87787C7E8585646E238B8E5B9581429540
6E7878787878787878787878787878787878787878787878
7878787878787878
787878787878747878787878787893E4746D626D7278737C
787C667E6F5B6D6D777874787972727C7878787873737878
787878727278787874787878757878796F78787C7E787D79
7C6F788187787B787F8975857E78712F719D65958C5F724A
787878787878787878787878787878787878787874787878
7878787878787878
78787878787B78787878787878787BE3768678797C887E7C
7878666E725D6D6E77777878797978787373787C78787872
78787D787878797F7C7C787A7B787880757473787E7A7C78
857E80777C828389857B7C7A7E7E6440558256888B8D445E
787878787878787878787878787878787878787B78787878
7878787878787878
787878787878787878787878787872EF8475737978717E73
7A7D6D646E65686D737474747873737C7C72737C78727978
7372787978787878747C787A787D7880817C7B7C7B787D78
7C75807C787F78839078897A71706562547E628386AC5078
787878787878787878787878787878787878787878787878
7878787878787878
787878787878787878787878787872D27B8E836D7E767E7A
74616D70726467717276787878787878787C7878797C7377
7D7977787877777C787C7C78747B7878757E737878787D78
8575867C787C7776788A8278788A44766C704F78677D6778
787878787878787878787878787878787878787878787878
7878787878787878
787878747874787878787878787872E7BB78746F6F72736F
8478666A78706871747678787773787D7378737C73777978
787878787979787778787A7B7A7878807081787E78787D7D
857586787E7D89917A7F8B7F6D8A42787782557878557878
787878787878787878787878787878787878787878787878
7878787878787878
78787B787B7878787878787878787888D180787870787070
6F786D736C726C7174747079777373787377787C7D7C7277
7D79787878787978787878787D787D8078817D7E7878727D
7F7C8280867E717B78787E7E657C3A82727854787F5C7878
787878787878787878787878787878787878787878787878
7878787878787878
78787878787878787878787878787872DDBA807F787A7F75
6A66656B696C6F71727B747977777C777D78787878787D73
777C7778777878787F787C787A757878787C787E797D7878
787A847C788987907C85788A727E37848F725C636F787874
787878787878787878787878787878787878787878787878
7878787878787878
78787478787878787878787878787878A2DB86707075757B
7A636C7371706D7772727275797379737378737878737878
73787779787877787C7478797A7A7878787C7C817E787D78
7E7E778478787C8D7C85787F7F7F2E6595706F685D787B78
787878787878787878787878787878787878787878787878
7878787878787878
787B78787878787878787878787878787BD99C8E787F7A72
7D6B645F6B7572717779787878787777787C727978777877
787978777879787878787A75797877777E7878787A787D7E
7E8077807B7F7E857C847F71787832647C62656471787878
787878787878787878787878787878787878787878787878
7878787878787878
7878787878787878787878787878787878CBDFC090868B86
766A7269606273777272747274787872727978777D797879
7878797478747478787C777A7778787775787C7B787E7676
83787C7B827C7F81857E8571787652867C69674D78747878
787878787878787878787878787878787878787878787878
7878787878787878
787874787878787878787878747878787872A8D1CD7C787A
807061686F64687778727978797975787778797378797877
78787C787C787878787B7278787878807974787E787D7378
7D7D8475757888747C7C7C857C576F7E6966645E7B787878
787878787878787878787878787878787878787878787878
7878787878787878
787B7878787878787878787B7878787878727282D99B7376
6C7869656C6D68716F727274717575757878787478787974
7872747278787871727878787778777C7978787878837881
85777B81837988917480787C7980767D6476676E78747478
787878787878787878787878787878787878787878787878
7878787878787878
7878787878787878787878787878787878787872B9CC5D7F
896F786A69696D79767871747A787C747278787878787C78
79787D787278747D78787778787878797D777778777A6F73
8080838283786C8EA1717884555D827D68615E747B787D78
787878787878787878787878787878787878787878787878
7878787878787878
787878787878787878787878787878787878787299CE895C
7565786A6C6D6E6971787772746E7C76747874747474747C
74707278726F72777778777778787E72787877787A856F75
7875787278847B67899D8B6E6C787C82726B557881727878
787878787878787878787878787878787878787878787878
7878787878787878
7878787878787878787878787878787878787872AA9CAC6C
6E5D6264646469706D72776D7A70787672727478787C6E79
7578776F766D6F78787370726F6E7872747872727378787C
837B8885707570856F8166A46C786586677A787278747878
7D78787878787878787878787878787878787D7878787878
7878787878787878
7878787878787878787878787878787878787872AEA3D55F
698362696A6C6F726E6E786D757472777C7572726E777378
7873767374726D6F6E716E726D717A6F7777777580787477
82787C817F827C968689658C77836984785174787B787D72
787878787878787878787878747878787872787878787878
7878787878787878
78787878787878787878787878787878787878788896CB9F
687C7261655764717B70736E6D7978747876717171726D68
6C72766F6F67656B6B6D6B716D626D676D6D6B69787C7873
6D6D8684778B796E8A7A65796D785F6E7A76787878727878
78787878787878787878787B787878787878787878787878
7878787878787878
787878787878787878787878787878787878787878AECCB3
886B7872776E58546375757C7776717173776D6D67728172
7371786A7568716A76627260726666706B73746E6B7C8787
927F8481727C9C715466818A6E7D74715678787878787878
7478787878787878787878787878787878787D7878787878
7878787878787878
78787878787878787878787878787878787878787878AAD3
D9937C5E69765A726A7C7D77787878706F71747872687876
786A786C786B77656F6B7C656A7D6478696D70776B546767
75708382795B7898896E70747E7E7863787878787478787B
787878787878787878787878787874787872787878787878
7878787878787878
787878787878787874787478787878787878787878787882
C289927E7392897F6169616975757577787578697077706B
7D7777737865827B82787E8F6F74827E8378787C9270747A
7E71787E838575786E7280887671835E7878787B7D787878
787878787878787878787878787B78787878787878787878
7878787878787878
787878747878787B787B7878787878787878787878787878
C2D070826A4E5D6D5D6F78747073727B70707E6C6A6C776C
7874826F7866676A7084647882668B5E71727B6E7F78605F
6160666C666E68787C8378856C7845787878787278787878
787878787878787878787878787878787878787878787878
7878787878787878
78787B787878787878787878787878787878787878787878
72D3CC8D847383847E7A787B7E706C78787184787D6E7478
7765786E7C8D61546B667F78786573747E4754746D787B8C
867F838375827D9C7778704F6B755D7D7878787878787874
787878787878787878787878787878787878787878787878
7878787878787878
787878787878787878787878787878787878787878787878
7872BB957D4D5A4F536C7675897D71717271787274787270
807F77867278AE66787066666C766C5B787F6B7E73747772
6668728D8F8A6D7884748E608A4372787878787478787878
787878787878787878787878787478787D78787878787878
7878787878787878
787878787878787878787878787878787878787878787878
7878ADCC707C99745E6172767A8366746A787D7B6A747F70
7C896C60835E788F5F78796B7C7675847878636C756E7277
7B7C7E70705F7E6F4D717D7E856E74747878787878787878
7D787878787D7878787878787B7878727878787878787878
7878787878787878
787878787878787878787878787878787878787878787878
787872E6CC5F53837C6D618183996F7F6666777C68757C64
786890667F7F6C7065887071787D7770706D6E6C696C788A
71667D918A9078908267725A78818174787B78787B787872
787878787278787878787878787878787878787878787878
7878787878787878
787878787878787878787878787878787878787878787878
78787874CCF5683A5A6D5F76839A6B6C887084907A678477
6E7890667C838F8E4373788F75786D7F7E7B6A6E6A5F5E79
8E8568786F614D6C8B64794C72727B78787874787D787878
7878787878787878747878787878787878787D7878787878
7878787878787878
787878787878747878787878787878787878787878787878
78787B7872CAD96E5854596178A1885B77785F6884656684
706A7D7E706E85A78E805470808A788989A28C9097918B73
728899617E8A576878936A78787878787881786E78787878
787D78787878787B78787D78787878787872787878787878
7878787878787878
78787878787B787878787878787878787878787878787878
787878787892DCC088654E43547DAD665E7E877079716365
74726C7878667E8A8394828B7877868971848A8D8A93847D
895B7C6982827A7C6C687D787D7D78747874817874787D78
7278787878787878787278787878787D7878787878787878
7878787878787878
787878787878787878787878787878787878787878787878
7878787D78789DCEA283846D7258A2A36C62848884967571
717974836D796C8B809A89887E697D83908A857D7F8B834F
5F615947757D747189787872727D81727B78787B78727878
787878787878787878787878787872787878787878787878
7878787878787878
787878787878787878787878787878787878787878787878
78787274787874AAD3A76A6C777071A3A76B7872788C9084
66665A825D79658A7C9BB9B7A6A59F9090A0A07E7F636A77
6D7686827F837A667878787D727278787278787478787D7D
787878787878787878787878787878787878787878787878
7878787878787878
787878787878787878787878787878787878787878787878
78787B78787B787DA2DECD73604A637EA7968F7F858184A6
B39A6C845F7776895B4B7C8D7E8B9592705B6261747E7278
7075826E7978877278786E78787474787878787878727278
787478787878787878787878787878787878787878787878
7878787878787878
787878787878787878787878787878787878787878787878
787878787878727D787DC7D88D5C535A77A78D949C989D88
97D0C5E4C8A7959A9C827D7E787365537D7065717D6E767C
94887E6A78C178787D7878787B7B7478787B787478787D78
7B74787874787D7878787878787878787878787878787878
7878787878787878
7878787878787878787878787878787878787878787D7878
787878787878727D787872CCDEB85B4D5372848195788191
75775C6472737E8E7E7C7E6B567D866F867078677C84988E
877F78967278747278787878787B787874787B7878727878
7B78787B78727878787878787878787D78787D7874787878
7878787878787878
787878787878787878787878787878787878787872787878
78787878787D727D7D787D7888E4CA6D5F5467616D72787E
788381878577727D7A757E915F6B7A5E8070927282897975
758B9D78787B747B78787D787D7878787878787878787878
787D787878787878787D7878787878787872788178787878
7878787878787878
787878787878787878787878787878787878787878787878
7878787872787272787278786E82CCC8C1624F4F6F757878
77746474716E625F575A648483696A7A9578AC9088816D90
AF887878787B787D7872787274787B7D787D78787874787D
72787878787D78787278787878727878787D787D74787878
7878787D78787878
78787878787878787878787878787878787878787D787878
78787878787878787878748178727D78B9CCC6A25A4B6063
6B82787E8289958F9578727496BF8E90A3846E6183B7B081
7D7878787D78727878787D7B78787278727478787B787278
787D787D787D7D7D78787878787D78787278787B7D787878
7878727878787878
787878787878787878787878787878787878786E78787878
7878787878787878787B727878727878787D78B9B9A47066
66576671717C8993A8A4A4887E98816161889F9482727878
747878727878787874727874787878747B78787878787874
7278727272727274787D7478727878786E72787278747878
7878787878787878
7878787878787878787878787878787878787B787D787878
78787878787878787878787878787478727D6E7478AAAF9A
AA9A8989788778615D677872747593AAA093827878727881
787D7D7D7878787B7874787878787B787874787D74787B78
7D78787878787B78727B7D787D78787B787878787B7D7878
78787878787D7878
787878787878787878787878787878787878787278747878
7878787878787878787D7478787B7874727B7B7878787B7B
7B8782887C82939A9A908F9C9692827B78787D7D7872727D
7272727874787D787B817878787D787D7B7D727878787472
787878787878787878727472787D787878787D7872787878
7878787872787878
78787878787878787878787878787878787878787B787878
7878787878787878727B78787878787878747D7878787478
6E78787D74787B7B7B7B727D7878747878727278787D727D
787878787D727D7D7278787872787278727D787478787878
7878787878787D78787B7878727D7878786E787D7D787878
78787878787D7874
787878787878787878787878787878787878787878787D78
787878787878787878787878787B7878817878787878787B
7D78727B7D78787D78787274787B7878787874787878727D
7D787B7274727274787D787878787D78727B7B787B787878
7D74787878727D78787D78786E7878787B78726E7D787878
7878787872787B7D
7878787878787878787878787878787878787D78786E7878
747878787878787878787878747D7872727478787B787478
747878727D7872787D78787878747878787B787278787272
7D787878787D7B7872747D7D7872747D787878787D787872
817878787D72787D72787D8178787D787878787278787878
7878787D78787278
78787878787878787878787878787878787278787B787881
78787878787878787878787B727878787B787878787B6E7B
78787D6E787D7872787B7D788178787878787874787D7872
78787B78727878787B727274787B727878787478747D7872
7D78786E787872787872727878727878747B787878787878
78786E7D78787878
7878787878787878787878787878787878787878787D7278
7878787878787878787878747878787878787878787B7474
78727B786E7D7D7878787472787878787D78787472787D74
787D787D78787D787D787B7878787D78787B727B6E787D72
7878817878787D787D78787D7478787B78787D78787D7878
787B727878787874
78787878787878787878787878787878787878787278787D
787878787878787878787B787D78787478747878787B7B78
7D78787B727278786E81787878787872787B7B78786E7B7D
727D7278786E7D6E7D787878747278787878787B78787474
78727874787278727D78727B787878787D72787872787878
7878787878747B81
787878787878787878787878787878787878787878787278
747878787878787878747D7278747B7878747878787D7D72
787874787878787872787D78747D78787878787D7B7D7274
7878747878727B787878747B787D747D78747874787B8178
787878787878787278787878787878727878747878787878
787878787B787278
78787878787878787878787878787878787878787878787B
78787878787878787B7278787B7D78817B747D7D726E7D78
787B787878787B7D7D72787B727D78787878727878787B72
787B7D817D7D7278787B7478787B7278817D817878727878
787B7D7D78787878747878787878787D787B78787D787878
787D787D78787D78
787878787878787878787878787878787878787D787D7878
74787478787878787D787878727872747B6E72747B727878
787878747878727278787D787278787D74787D7878787878
787272727278787D787B787278747872727272787D787D78
786E727D7878788178787878787872787478747278787878
7278727878727878
787878787878787878787878787878787878727D72787D7B
787B7878787878727878787878747B787B787B787D787D78
78787B787878787878787D7878786E7B7878787878787878
787878787878787D7D7878787B787878787878727D787D78
7B787278787872787878787878787D7B747B7478787D7878
7D74787878787878
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.35119 0.343006 0.64881 0.640625 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00751202 0.0192308 0.00751202 [
[.5 1.0125 -20 0 ]
[.5 1.0125 20 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(60) show
75.000000 12.812500 moveto
(deg) show
93.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(.) show
99.000000 12.812500 moveto
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
128 string
128 128 8 [128 0 0 128 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
767672767C767876707D758B767676727B76767676637BB7
4C707D767B71767D707677767D76717672767A7677767676
7F6E76767076767676767679747C7674737C767676767776
7676767678757677767677676D80A95A7671767C76767276
7676767670777974707B7276767C717C7C777E7673767779
5F7795626670737C
76757479797376787477777F7D76767579767677776F73AA
53717C777876787A737476767975767472797977777C7674
7A757576757876787978747B77767976767A767577767776
7676767677767A74767776716D76A3736773767C76767578
7476767672797677727A75787876767A7C767A7476767469
6686876B6370767A
777677777675787A777576767E7E77777778767779756985
8F6478777A7C75737573767776777C766F787877797B7575
7A7B7576757675767976747A77747A747475767575797776
76767676767877727677767771748077816A787A73767876
717A7874727874787476767475747B787B77767778726F6D
72887C75616F7478
7676757379737579737576787980727A7B7678787975736C
98657077787A74747878747676777C776E7779777B737A79
767678757374777579777677777674707776777476797674
75797676767776767677767677746D73907A677573777872
747874737379757975767374767A767B7879727969767470
807583785F717578
777676757775777B707678757874787A7F76777974787364
7B946775747D7676737974747776797572767A787A727976
727579797274747B7979737676767575777A7870787B7577
757B777476787774767678747876756D73A2617174767676
7976747674777378747572787678767B757A6E6E6B7B746D
8B65897A5C707774
76757974767976757776777976737B747D7C797875787371
71857374757D757874767672767A78747A7B787678717676
76777877787875797971757476767676747974717B7A7478
757778737777767675797975797478756D7F7E7470757678
77747475767675787576757676767B7A797D6B6B7586767E
80688E6D5D717979
767277747A7279747A727A74727A7674787A797A76747674
6F7186787578767A75767878787A7A79797975757A6E7674
757675747C757A717A717D73777A7477767674797A757878
77777974787878797679777777767876766A7C7774747878
797377747678767872797474767D7B847E7460746F90707B
73728B606977747A
767477777A717B7279767B737876757576767A7D78757674
7670787F90677A797A797677777C7B7673767675796F7475
757676747D76807579777A7279797479767877777A787879
747B75767B7876777B787878787977757B746B7789767676
7775787376787674737C75787C80867E796566828083737C
707B7F5C7079747A
7673787476747B75797674767775757675767B747C717574
7272707C846C77767A7876767979786F7574727477777274
7376767678767B7B7472797278767578757C79788077797A
7780767B7C787A7B7D797973797577757D78707D7B758387
73747873777975747877787A907D7D6F776F6D7D7F70746F
7182706270777777
7575777675767877767875797877707B76747C717B727A78
7279797774857E85687E7D7378747D747A757477797C7271
75737775767A797D74757B71787475777774757476737376
75767076747174737474706F7C6F75757A72767A6B757E77
6A9E5F7975757577848C8A888A6769727C706D7873787F61
7C8960726E757578
7879727C74797778767578757475767976717B727A737B76
747A74797479978C62847B6D777779747A727275767C7370
767479747878767A787673737873767678767C727676727A
7674747474757775787373767A7079757C71797475777377
799043857F7D77888D827E73676B697C7F5B807670867061
83776C6B71757676
757874777875747976767776737A76797675767876747874
7978757A7478937D8073757E6C7679757F717478747A746F
767776757579757B78787575767676767678767676787579
757876757A7873757B707676767979727C717B747779737B
777A70827774908773757A6D6E78717874569C756D8A5F70
895C7B6678737670
787675777A717A7774757776747B75777476747C74757679
7B76767775788C798E777190796775767B707877757A7570
76767677737B757976787573767676777676767C74767279
78777878767475797B6F7677767D72737C747A71767A787A
777D7A808D9193706D796B7375766C6C7364966E6A865D77
7B5E76727A707575
7575797977717C717B747C717A76797176767A7973747A76
79777574787785727F936F908371577C727A7A7376777470
7676767675797676767679787878747A7576767B76767579
78757B76747676787574747B777B6F767B787675787E757D
7A84818A8976687472777372746E6A776F748A707373697C
6F6475747A70777B
78787577797178737C707B75767776737A787976727B7675
7A7476747B76856B8AA27C818589685F727C707473797573
7476767679757676767678757873767975757678757B7875
77767678757878777678707C72787674787975787A7A797D
7E7D878C6D6A76736E7F7B6C6D766E7D707F736D74608670
646B767975777379
7676767978707B777B717876767776787679727875777679
747676787876836C8E8A8D738688895A55766F7C71787670
7376767678767875767978787977797673737679787B7676
76797478747A767B737872797579777479817A7D807B7D7A
888C91705E748B676F73756F76806F7A6C7A687666788465
647876777477707A
7773777773767A74757477757A727A74737B727A78747777
757B737A767979797F8A99768A88837A5C56707F6C797670
7579787878767875757B7673787877757478797678797977
77797478767B767D737974757D737F737A7E7A797D7A7F83
94847858677B8460726C7C787A7D726C717769766D836D69
707B737076777178
76757576737D7374747B77727B757B747979727876777476
7A777576767B778772A4887C8B837A7D81624F7971777573
7579767676727B73767976757B7678777676797279797776
78757A7975767A7973796F777E747A757A7A7C7A81878583
846B65627378766C7B7C7E757976706E776B6F7674666E73
7475717076767376
7773747576797577757878757B7475747675757977797673
7B767677777879846EA97D7C8A8276808A7F5549776E7872
77757676767576737B7676767775767A7674797378787978
78767C7775747C7A737975748176747B7D757E888F818D6D
726B62747A74766A7B78726B756B73766E6C75766E6A7676
7072747675797975
75727C727975787576777B76747776767775787975747976
7874787876777C7F79A38083857E7A85897B750F766F7674
7676737873787578797679757678767A75777A767B757876
7679797879797979726E7C798276797984778584966E8361
796A6A7D7873726D74737B716D7A73716F75766F6D746B71
70747679737B7473
76797B747876757A76797872747B74777476777973787A73
7476767975797A818C958085817284808478664F5B6F7472
7977707B75797676767877757A77747A7678767A74797474
787B767B797F76716D768B7D757A747B877A887C7D706B6E
71626E7B75746A7D73767E7075816B707676706B6E746974
7779757676797279
7678797378767477737B747376787879727B767875767873
757B757A777B7887908C7D867A738D7A86706D82236D7670
7D76737C7676797676777779787675767A77767878787775
7B7A797D7D7B7365708F8170737F7E848A6F847A6D776E7E
6C6E767C79805F826A7A677C766B69767672716970766F73
7D7372767B747478
767A767677747674767A727676767B767278777877717B73
787A7376797B769485907F847B7D8E75786F7E920A737475
7977757B76737B7676787878757777767878767A7D737A76
78777D7B81756C6B878E76757C8483877665827973717A7D
666D767D79765E836D826D7E73717176766A696C76746F74
7B71767A79757576
7678737C7176797579767675767678787477797675727A73
7C7373767C7C7D987E8B817D7A84866E707B8884057B6E79
7975767875767976777A74767A797979727E777B77757979
787B7D817B746A7D8A7A77757E887B806C627E747B776A75
6A7276796A73727E747A766E6B7169786C6A6C7878737379
7574797774767376
767975787379797378767674767679767876747676757A75
797477787A7C82928384837F788879647C8B827D0F7B7181
7572777C78777779797A76777A7877757879797978767B76
7B7A7B81776C7A8484747D77887974767465767781716C7A
707F6F73667A7481756D7C7061767172676F75727B717574
72767A7677797775
76787479757878737678767576767874787674767A737A76
74797774757E8B927F82847C778B7074898F727E0B78747A
7078747C79707B7B75787A74797779767A727A787979757A
7A777C7F737187837A767D807D6F8576726370787777777A
7676687965757C846C6B836B65766A6C6F78787276727672
7975787677777376
767676787677767679757874767975767676767976747A78
747B7375787C9B887E828E797F87688283836B800D7D7379
757B77757E747A79787979797A747B787575787D7978757A
777D7B7F6C7F857E787B7B78707E7F6D6D67727A73817481
76746F726A7776776C7F7B6C6C7265747275727672747873
787476767A74747A
767977757A76737876757975767A73767977787972797975
7479717C77819D7F857E896F88736F7F8E7F737B13806F7D
73797B747B7A767B7B75797A767A7B797379777B767B7878
7B7D7A797C84817F777478767A7C736E706B6B6E726F7D8A
7876647270717177818074636C72697376707A7273737874
767975767878757A
7776767679777678777676737A7676757A74797473787674
797A757B75918D85828285738969838195796F7514807178
7379797A797B75797B767A76787A7976747873787A7A767D
7B787F7387807D747871768E7D786C6A73706F6C78767A88
7A6A6D73746776808176775B706970707871766E7C757576
7976747679777378
767476787875757574747676787678737B727A7279757978
787579767F96818B81867F7B7E6D8B8185716F731A7D7578
777A7A7878767A77797C78777F777B7B73767A757A767D7D
767781698A8A706E7D78848C825C5E76717D706B6C7A698E
7C69796D7B6080807D756A5D6C697A75717473717B757276
7878757976767576
767679757A75797777757975767875747C75787676747A75
757879768C8F82907D83797E79748E7F7D72767521777670
78777A727A767776757C7C7B797A777A747979727B797D7C
787E7D68928E6373878284737657637C717878626E747A85
7A727B746B6C86727D686966617B76707270757378787376
76787378747A7379
777578787A73787376767973767A75797778757871767A75
797A767C8E88868A7A817B7085759B6C7A747969266D716E
787374767674777875797A787D7D7677787A767A77797A7A
7A7E766B998264788D84795E7D6861777D787B5F6E6D7B74
8073808058768773716D6E5A687E736E7770757975787476
797576767678767A
7676777875727A7376787674767B72787677757A71797679
787576878D8987857C857975817F976079797B48356C6F79
7678767875747C757679797A7F767D7B767776757A777776
7D7C7C6A9370648C84826B5491616872817B706870687679
82798A7259797F74628166587E7C71757077737B75797777
7674797576767876
777679727978767875767676797A72797973797A717A767A
7675768D8C8881867D7F757D70997D667D7B523354727378
7972797379777A747A787A787A797D777D7778787876747B
807B867A717C5EA47F83705280746964886A786A6A657074
7E92796D6C7C72706D83526882726B756F78777774767478
7575787476797576
767677737876737C73787576787974767875797673787675
7879808A9383838882767C7D7B9A656F8235405B72727874
79727E75797579767A747B7B7A747B7B81817978727F747C
7E798C7D4A9A4C9E85737E5562955E678A637D6E6A706875
84947173707966707770567D7869737277757A7276797776
7875757676787476
767874767A757678747673767A7976727878747674767679
7B7B8782957E848280727B7B8B86657C5D20717B73757577
7677797479757B77767A7D7977777A7B7B886D837579777A
7C80857B478F55899E7C78565382626F78776D776E6F6971
7C91856B797162717973676F6E6F75717A727A7379797474
7876767576767975
7875797578737A75797775797975787279797675767B747B
797F86888E7C84828675817398736D6E2B5473797376727B
747B79737E76797776797779797879797A7F73888273797D
78857B884C6592609B6C7A5879628870747A6C727D637B63
709E856878696B737C72606774757774767676747A767379
77757A7575797674
76727A7376767A747676747878767576767676737679747E
78867E938685808382727E7E8E646B38457472767679757D
747C77747C7D7A78747B777F767B7977787A7C7C81817F77
7D82818257529763768F756A795D7E74716F8B667E5F7F65
748789796F6C796B6E656178717278717679737976767676
7873787676767476
76747A7376767A747677777776767676767878777775787E
7E83839586847F847A768E7F7B70334373757878777A7A7E
7C7A7C7B7B817778777D757A7779747A777B7C7977868077
82788279695D6A7C6C8265818669677E6D7D80676973746E
6D6D9C7A63747D646A5C7474717578707878737B75757A75
7674767678747679
767976747679767478767874747678747A7776737676777F
827C8B8B897A8184737B92706F392F7672797A76767C807B
7D7B7E7A7A7C78747B76737B7376767D777B79797B7C838E
827982836E5F50898C4F8E6E8C6D6C6E7A80677A5E7F6976
6E6D9274737A7566695B7D6C797475747578787674747A74
7479757676767678
767A73767976747676767A737676767678787776757A7883
817B938E867F7B89768583726B1C7478777979777C93897A
807B7B7878788379817C6D74727476797978797C79798084
907D81856A5E5B7282577773797C736F77767B7C65747770
71687E86717E7266696772727A7475767877777575767876
7578767576797576
767A73797676757676767A7376797875767A757576767D81
7A87938D808179887682796E333D77777774788B868C7755
717A756C6B817D7574786E69737474767C77787C787D7C7A
8D8A847E735B813F798F54916576867968887674696D7D67
746A72957B7D6F695E6F6D747A6E74777975737A73797776
7479767479797379
77767676767676757977767677797774777A72767C718781
899289868C798078877C7B51257876787775799D7976796C
8789757E7D947B7E69817875627372767975797C7B797A78
7E8C9273865D7637749A587B726B71887C8167856F6C7670
736675957C6C766B4F767179796C76787476747876767674
7678747678767478
767478747A7576767976737A767674767877727979748B82
8F8489858E6F817F8475652853777979778A839D89807E78
827D7689828A78797D85828964696B76767A7A797D767974
8381968F895D646763728E55935F6484886C8577726A787C
686476827F6D7D6456717677747374767975797578747676
7676767975797576
777777757878757678747676787476777976757A767B8686
928590887A77807E6E7B29427976777977876D88846F716B
7E6F687F77756A6C795266675A586376797A77757E797776
807D89A0816C6B655D5F916A7576587380947E6B7E6C7682
55727175926B805860717975727873777674787479757679
75767976747A7376
76787673797676747A737A737874787679747879757D868C
968B8282777D7D75787217797775787878776F8071686D64
6467646E6269666A6A5A717371747376787879767C797977
7C7A86998D814B6E6B63769659905D68729F6D7982747175
627D6372966F834B6D7776776D7676787376767678747976
7675787479767476
777676747874797578747A73797775767A75787879888590
968980807E8374737A4037787478767775777376727A7877
6E81767477837A7C79737A74717A7774787A77777B767D7D
797689929B82497A5A6F5B98716E6B57737A7D857D707774
79745A729270823F727B74736E76767A7376797777757874
7874767678747679
7673797777777677757678747A7476757A777676798C8C94
937C8877827A6C76781A6B797576767A717A727675797579
767F76777781747478727A6F79767A757B79747A7B79777D
7776838B97777663697C6D887E5B7D63667491807C73876B
7D5F65708B7B7C4972797A697675767A7379767676747975
7676797775767678
7676767876747478767576767874787478787776858A998D
85827E83787971757F127979737578767676757676787676
7B797D737D8074747B74766E7F7277747C75777A7B78787B
7E7B7D87958B81546B6B716684767B5C6F7476778D718C60
7E5F7366858B5A5C6B767A67767476787478767576767A73
7975787674767676
767874787674767678767576767679777776767C8F898F91
7F817B826F7D6C7D5C227876727576767576787676777978
817E81717F7D7475787672757774717C7C777B787C767D77
7A7A7D84908F6F6965796B787A8A6E715B6377818E6E8C66
776A7660808B467C61797071747676767975787476767876
7973767975767676
777576767676797579797376797578767972797B92938C90
837B857D7A73768520577575727676767579797476767C7C
80788072797E7473767474757673777A79727B7979787D76
77827E7F8A938A7363776387638A6E8835817E5F90767F79
6D73745E7A7E567C67806776767676767A73767676767678
7674767A73767676
767476767676787676767479767476767873787C9D979187
8081757E71708083097776767279727578767777738C8B6A
7677819182776E867170746E767176767A767D7B787B7979
77807A8486929567676D6D7F637E81765E76606E8784768E
6C7A665C7964846088626676767676767874767676767676
7676767874767975
7777757977757678747977767675767676767984A6948B7A
807E7677727E836810787374707975747D7578777087765A
767B7F8A69616683706E6C6C767676767C76757B797A787D
7B7A807F7E8AA4706F676D70756D8B6B9636737E629B7190
696E67666F6A9763705B7975767676767975767676797576
7676767977757874
7676747876747975767A76737874767A75767888AA938288
7F747F6F728A7C492D757476727877727A757777717F7374
757A7C7D7675767C7E6E666C767577767A77797C7A79797D
80777F7E8382B46A755B6A6B865F8C6F9922866860A46C89
6E6C6F656576816A50767A73767676767874797576787476
7676767878737676
767676797579767479767873767A757A7475798DB2927985
727579717A8F711C537176737276777678777A7A6E7A7172
797D797E7C7978777B726C6E76737975777A7479777B777D
7C797E7F8183A87E7156815E885D907080467362728F7C79
7A73745F657E706163767874767676797775787476767676
7676767678747676
767676787478747979737A757578767676747BA6AF81887C
7C7574778F7F7806747278717677767677767978717A7574
7B7B7A828179747A766F6C70767376787877767A797C777A
7A7D82807E809299675F715E7B6A8F6E7960666A6F709A71
856F6C53698E605D76757977777576787873767676767676
7676797576767676
77777576767975787674787676757A7376767CBB97818F68
76727691847373007272777277777677777776787A777573
7B7B807F807373786F6C70767674747C757876767F797977
7D78827E807F8DA7646A6479727678777957666D6565AB76
816D6C5D6D7F526378747876767476767874767676797576
76767A7575767676
76767476797674767676767976767676777779BF93877C68
7D7776967275332873727876767673757579757679767A6E
797C807C7D737275706D74787575707B767977767F78797A
7D797D82867E82A6746B71666E7D6B797B5D5F6F6761B36E
8D62784F66755B7476767676767676767676767676787476
7676787674767975
7777777578747676767679797576747A767489C090877172
7C77858D7F282D687270797673797478787A767777787A6F
767F7B7E797373767270757373796F7D737876787A76797A
7B7C787C88807C99805E70646A826777835F52776D66A775
9A5B7A4C656C627676767676767676797576797775767975
7975767676767874
767478737676767676797676787376787674BDA7858F647C
7A76917175006F7371757A73737C76767379767676757B72
76797A827D7074757471736F797773787679767878777D79
7D797D778C82818B8270736D6D766F7D705D587A736E958A
9258695A5A64727676767676767676787476787674767876
7674767975767676
7673787476767676767874767A7376767975D18385885A7D
79788776511F7470767773737A7A7775757B737579767873
777B7B847D747176727371747A72777A7B7178777A77797A
7E777E7988848783887874697668767973556A7776707D95
7F6069605069767676767676767676767676797579757678
7476767874767676
767479757975767679757676787476767876D07C8A7D6D76
7C8674721F527572767674787A767676797674787A76767D
747974847D776F74747574757675757C72757C797976787C
7A7B7D7B80858383867A70736C6B757E7F3B7A7B73766FAD
6E736E584B70767676767676767676767676787478747975
7676767676767676
777578747A7379757A737676767676797599C87889757870
83846A3539787274767676737976757A7C76767874767B7A
7076758381797476737B707378727679757D7A767776787C
76817A7A8182888482896F766966797C773B8176719055C1
62696B5D4673767676767676767676767676767679757874
7676767676767676
7674767976747A73787476767676767A73BF8C7B89668676
8B6E6F196F7F6D77737976747B7977837776757773757D74
7377758188787A7473766B7475767B7B777A787676767879
7D787B7C7F808885839074706C647A7976477B7374AB3ABE
695D665F4B7676797576767676767676767676767A737676
7676767676767676
7676767A73767876757676797777777674E05C977C6E827A
90554D377E736C77747A7679797B787D7C7A747574737E76
71777586857C7676776F6F76797C7C7C797B7E787A747978
7D72807D80838682838788686F6474737F48748473AE29AF
814D605C5A76767874767676797576767676767678747676
7975767676767676
76767678747676787479757A7476767473E1589C70827297
70602C847D626E787676797D828A857683816B776C747C75
6D767684828176796A76697E7D7F83857E767C76766A767D
79797D7D7F8183868580886E725F796D8250738A739A29B9
87406D575D79767676767676787476767676767676767676
7874767676767676
777576767679757975787478747676769BBE7496717F6C9C
524A3F966B5C7476767C84938574778A827B667F74697978
6C7676818384757C68A4777F726E97936C767E7D7567777D
76767B7A818285857E817589785A776E725C6E8675932EB9
7240734D637A767676767676767676767676767975767676
7676767676767676
76747676767874787476767975767676BE7A868986706996
701C7E826F5D73777C8495895D59A29A7D646E70795A7C72
6B767A7F81847D86728A834056999C875A895F837A656C78
74777D7A7D84857D87827F9B7354737E6463738D718937BF
575476497076767676767676767676767975767876757676
7676767676767676
76767676767676767975767874767673978E9C85955C7484
6F0D8C7F7064737D858C9A954F6AB45DB64E8964776A6D66
6D767B7B7F7C8A7E806B895F5ACF4EB9559244B7765F6878
6F787A8179848385857C92886B646884557077806E8346BE
4668694B7676767676767676767676767874767678747676
7676767676767676
767676767676767678747676767676A077B68D8180637671
6038917B69657281888DA1835589A970AB46865863626169
73757B7C7D7B877E80747C7D5AC568B8577E699D65576D75
6C7578837D808D837A7F8B80676D67785A75787C6D804AB2
4E684F5E7676767676767676767676767676767676767676
7975767676767676
767676767975767679757676767676C85D90968C6F757C72
545588746C64767E7C808E707B87796968646A5A5F606F6D
74747B7C78777F80797E797D728C6F6E7B72765B6560716F
6A727C7B7F828C787A7D80896878786C586C7E7D637255A8
5B65466D7676767676767676767676767676767676767676
7874767676767676
7676767678747676787476767975769E8189A0826E7F8260
53677C7B6C63747573797B756F6B64615F5C6C676D6B7074
7377787A767881857980717A6175757872645D59616F7070
71787E7B7B838A757E8280886C6F74725465877E5F6C60A4
5C4E4D747676767676767676767676767676767676767676
7676767676767975
76767975767975767676767976747379DE80977877668D5A
6469747F665D7A717178777377748486858A8A5D6B677078
7179757979748281848E777F76696B6C6D6E6F7571747A7D
7F83767F7C81867A807D8480736E856D5D64897C59705CA4
5B42667A7676767676767676767676767676767676767676
7676767676767874
76767874767874767676767874767B71FF6A926F70638D5A
6767737C675B7D74737378767B99958F7E635D506E6E7378
727C757777767D7B8689847F72686B767377757C747C7D84
8B72737E837F7C82897B8F7579756B5F66657D8156755E97
643D70767676767676767676767676767676767676767676
7676767676767676
76767676767676767676767975739D57F6757C6F7B687E66
75756C7568587491787783879499695C6056627074727378
777A7677767978797A7D807070757279827F7E86828A8380
7A697A7A847E76867691706F797D6B606B6D7E81556E768F
524576767676767676767676767676767676797576767676
7676767676767676
76767676767676767676767A7374B17AD07D697880687B6D
747467715E5B71866C7A7E7E715A555E7275737676767676
7D7673757479777675797D7977726C5C7A7875797B706E70
6E72787D877C738B7C8E6B7D898377486C7C717D566C9572
316176767676767676767676767676767676787479757676
7676767676767676
7676767679757676797576787476A0A68D7A5A7D7D75796B
72726973575E7475787A716E626670767676767676767776
7D7373767A7A777776787A77747977768576696C6E66727A
707A7F828376758589768884837670317E824F8B62649E57
367076767676767676767676767676767676767678747676
7676767676767676
76767975787476797674767676769FC08177518685757A6D
7774647A565B737476717678737576777576767A75767776
7C75747A7A7379767676797A747C77787C717D7C7D7B7A7C
7583787C817578867C878879776C75238C824A947450A645
3E7976767676767676767676767676767676767676767676
7676767676767676
767678747676767874767676767699C46B72618A7C747A78
787764795E5A717576747577757479787276767873767676
7876737975767A767978787A747C777877767D787C797878
787A788483727B817F947D7884737B2189854C8E8350A026
5A7A76767676767676767676767676767676767676767676
7676767676767676
767676767679757676767676767683CF757C757B7480797B
74785E706357727176757276787474787376767A78757676
76767A78787A767B77767678797A777C767B767B7D767B78
8178807F7C7681848A866D89867667346F805791816C6A28
747676767676767676767676767676767676767975767676
7676767676767676
767676767678747676767676767674E6737C706E737D7678
7672626A6A60706C757374767773737A7875767B73737A74
76767C7676767679737876797A76767F777877797C777C78
7F777F797C7C80848778818979796844599062867D85324D
767676767676767676767676767676767676767874767676
7676767676767676
767676767676767676767676767670DE7C7B6A737D788076
6F726B666F66696E74747875767575787974757877777776
78787A7776767679757B767B7579777A797675787C787C77
817A7F7B76857E8288768F7E7D7D535164865A7B6D812666
767676767676767676767676767676767676767676767676
7676767676767676
767676767676767676767676767670E5776B7B767E757D6F
7E72676772676670727674747673737A7674737A77787576
797776767677767874787C79737C777C767C777D7A777C77
8470817B80857F867A898C82707D3B6A6E7E597A6D644676
767676767676767676767676767676767676767676767676
7676767676767676
767679757975767676767676767674AF7D8886777A7A7676
7C68656A6F67666F727274777672767C717A757B75797476
7A77767677767676767B7A747979767F6E81767D77777879
8070887E83787C817E8A8A7967843672737D52736E436B76
767676767676767676767676767676767676767676767676
7676767676767676
76767874787476767676767676767679CF8B787D74787875
6D72626C686D686F717674787575787A7576737876787576
79767676767677767B7974767C73797A717D787D777A757C
797C86797C807E8F8884817E6D7F317A777D4F69644B7676
767676767676767676767676767676767676767676767676
7676767676767676
76767676767676767676767676767674BC917B7972777772
736B686F696A6B707078707876737973767376767A767875
76797677767676767C72787979767A77767F7A7C7778777A
7E7F7F7D7C817F917D8474826B782F74866C555F56657975
767676767676767676767676767676767676767676767676
7676767676767676
7679757676767676767676767676767689BF877976777576
77646669686B69727476747576747A74757A757A7A747A76
757A7577767776767B757B77777A76777A7C767A7A767C79
7C7E7B837B8286907B817678707D376B8E5E5D5855767874
767676767676767676767676767676767676767676767676
7676767676767676
7678747676767676767676767676767678CF847C6F767773
77656C66666B6E747274737476777773737C747A76777776
7676767676777679797679767B7877767D777A7B7B767B78
7D8379847F838589787F7C6F7F84346D845F5E5263767676
767676767676767676767676767676767676767676767676
7676767676767676
767676767676767676767676767676767692838973747578
76696A65686971727474767776777674777A767379777676
76767A7479787879747A767A7977767B7A777B7B747D7A77
887C807D8484857A7E7B807885672F79755D624974757676
767676767676767676767676767676767676767676767676
7676767676767676
76797576767676767676767975767676767089839C787E7B
756E68686B686A767670777374797576757677747A777676
767678747B767674767E767B7677767D7878797977837480
81788583877B847B817E7C837E3553896B65574D78747676
767676767676767676767676767676767676767676767676
7676767676767676
767874767676767676767678747676767674787ABC917A7A
727566656C696A7973747476787875757676797576767A74
7A777877797678787B7A76777677767E7B76767B7A7E767A
7F8287837C747D8978807D863F457C845C5D4A6279777576
767676767676767676767676767676767676767676767676
7676767676767676
7676767676767676767676767676767676767670A5C46A6D
7A686B696A6A6D7470777475767278767579767476767876
7A73787A747A757B7677767776777B7A7A777A7B79847779
89817F7A807F77778F807C5C487280745A57546F7A707676
767676767676767676767676767676767676767676767676
7676767676767676
7676767676767676767676767676767676767670A4BF716F
825E7769696972717377767379707C76747975787878757D
77777B7A7A77757A77777676777680777A7A7A787B867382
867F81807F7E727C8D7966606169736B5B6053707A727A76
767676767676767676767676767676767676767676767676
7676767676767676
7676767676767676767676767676767676767670B08EA072
726E736A6C716F7073757B7177717B7878777576747B747E
77787C7A7D737476797A767A7A798176787E787C817F7A7E
82767F85787D79866D854D785C7E5A7559585E747D757673
797676767676767676767676767676767673797676767676
7676767676767676
76767676767676767676767676767676767676749977CC6D
657C646A6E696A7673747C6D7778777678767678777D7579
7A7C7F787875737D7C7A777F777780737C7A7B797F7D7C79
80798682767A6A7B766C47866E6E556E6553757678707974
7A76767676767676767676797576767676747A7676767676
7676767676767676
76767676767676767676767676767676767676767D9BB973
66796E6E72676F6E78767674727775757A7A7878797B7C7C
7D7C7E787C797A7E787B7A7C7C797F777D7F7E75807E7A81
83777F7E6E757A7573676B8365725D68635D747676747A76
767676767676767676767678747676767676767676767676
7676767676767676
7676767676767676767676767676767676767676768B9491
7B6E76696D726E7275747172717A78787980797E77758278
7878847682757D7183748477847A757C7A7D777B76747E78
7A6E817E68708C7B70676E77636A5F6F5373767676767679
757676767676767676767676767676767673797676767676
7676767676767676
76767676767676767676767676767676767676767676897E
90767D6A7187646C606E70737A797B7A7E7D797B74748176
807A847681727E7A80718A78747F6C837877797B7E798175
807780737E767F7A6361766E60667D535E76767975767678
7476767676767676767676767679757676747A7676767676
7676767676767676
76767676767676797579757676767676767676767676767A
BC837B6C6B6D5D72657A78767B7C7C7C7B758176747B7C76
817B7E7783698271737C767B736E7678767574728D706E73
8074727F7D746D78706B62636B7870467676767476767676
767676767676767676767676767874767676767676767676
7676767676767676
767679757676767874787476767676767676767676767676
8FA3717E756A787F6C7370757B7D768179788672797B7E72
8175837C7B76797277846F7F7A5C95717E6F787E87797784
81707D85767D71716160598374884466767676747A767676
767676767676767676767676767676767676767676767676
7676767676767676
767678747676767676767676767676767676767676767676
74998682785E6E70666B7578827A777E7A747F737F75757A
82758D6F718A7B6C81737576767E886A8F7779837A7D7278
6C707A7B6D70516E5E65967B7E6837797676767676767975
767676767676767676767676767676767676767676767676
7676767676767676
767676767676767676767676767676767676767676767676
7674B689866A827468737776857C787C78747E7D7B74797B
7A846A71836E8B68767080778284767F887264817770767D
7A786E6F6863606E6C899D53892F637A7676797576797674
767676767676767676767676797576737976767676767676
7676767676767676
767676767676767676767676767676767676767676767676
767687BB785C7F6B656C747A7F8E767E6E767F836F76816C
7D7D767E7F6D838369817B73807A797B6F7C777A74747C7A
71646B6F79626F80878C686D5B4277757679767479767473
797676767379767676767676787476747A76767676767676
7676767676767676
767676767676767676767676767676767676767676767676
767674A485846D6E6C7269797A976B7F737782836A78826F
847194617C7C7B8B60857A747B7C79797F80767279746B7A
6D6168745E657794815F7F4E48707A737678747678747674
7A767676747A767676767676767676767676767676767676
7676767676767676
767676767676767676767676767676767676767676767676
7676797592A4736F76775E738099796F7D6C767A7A707F7D
73718B657879808D638563817884727C807C717C7A6A696D
636B686D749A827C806E73286E787C747679757379767676
767676767676767975767676767676767673797676767676
7676767676767676
767676767679757676767676767676767676767676767676
7676787474ABA66A7367677279998465797C7A7B89737780
717979737B737B88687A70807A7D677E6A7B6E6E675F665E
68677E6B939F626C7179345476767676737A76737A767676
7379767676767678747379767676767676747A7676767676
7676767676767676
767676767678747676767676767676767676767676767676
767676767680A389726F796E787999716E7C7C76877C7478
7B736F827D65757D778663787D69717A6C7B6B675F726D5E
766E94769A7D5A7075414D737579797179757A7675737976
747A76767676767676747A76767673797676767676767676
7676767676767676
767676767676767676767676767676767676767676767676
767673797676859F8A79726372618E84726A7D7F70857473
7073728866706A817074748B7563786E6F6A6C636A7A8374
898B937C7B65736E46417A7474797A7278747A7874747A76
7676767676767676767676767676747A7676767676767676
7676767676767676
767676767676767676767676767676767676767676767676
7676777976797589949071696F6B7184846685747481757E
73806F875E7C5F7D56667F7760646C6662687568888C867E
8186795B5C7B7A354C7A737974787A76747A797576737579
767676767676767676767676767676767676767676767676
7676767676767676
767676767676767676767676767676767676767676767676
767678747678707987848875826A647287797A6A7974706D
7B84638362685E7A6E6A7D7C676F7178798386839384738A
7E6B6A5C7C76463E7A79737A79777576767976747674787A
797576767676767676767676767676767676767676767676
7676767676767676
767676767676767676767676767676767676767676767676
767676767676707C76788D9E865B686F6D896C6B72646775
6F6D4D67585D66796F5F74756E7D927C90857B7F88778270
67677170485C4B737B767476787873767678767576737976
7A7376797573797676767676767676767676767676767676
7676767676767676
767676767676767676767676767676767676767673797676
767676767676707C7676749A708E74626C796D677B687A7A
607A737D8175737C727681846E8F886A957A8178786C6B5E
747C664E3E7D75777A747676767874797576787476747A76
7874767874747A7676767676767673797673797975767676
7676767676767676
7676767676767676767676767676767676767676747A7676
767676767379707979737976799B866A716275747B757275
727B6C747870727E7C7C7F8C7680877B8E688C63636D6D7E
755A5154767A737874737973797679767476767676767676
7379767676767676737976767673767A7674767A74767676
7676767676767676
767676767676767676767676767676767676767676767676
76767676747A74787A747A79737A906289767D666E6D7277
797B6F807D7E818A867C778D828280687A5C7A5A6D826C59
5B566C767678707976747A77797674767379767679757379
747A767673797676747A767676747A767375737F75767676
7676737976767676
767676767676767676767676767676767676767379767676
76767676767676767679717A74707C768F6B5D7B7A6F7C79
71777079767781777D6F7C716B88575E77727E66656A5856
767676737976747A767379787476747A777976767874747A
7379737573797579767676767379767670767A7876767676
7676747A76767676
76767676767676767676767676767676767679737A767676
76767676767676767678727A76747A767379738F687D7B6C
7A7674787278766B7772755F6E83767D77766555616A767D
797676747A76767975747D75767679757874767676767975
747A747878787A79737B7576747A767973787A747D757676
7676767676767676
767676767676767676767676767676767676787079767676
76767676767676767676767676797576707F757976896D61
73676B7668787B7F827B7A767B7575695E6468707670767E
707575797676767876777674767678747975737B75767870
797676767676787474787673797676787476767674767676
7676767673797676
76767676767676767676767676767676767676747D757676
7676767676767676737B757676787675747C767476767876
727A74766E777C736D6969726E6D6971747375797674747C
7478787D7573797674787476737973797476777A74797574
7A76767676767676767779747679767676737976747A7676
76767676747A7676
767676767676767676767676767676767676767678747676
7676767676767676747C7476767976747971797676797579
737A737B7576787676766E7C767975767674787A7379707C
7676797376707979747A7676747A747A707F797379767476
767676767673797676787476707C76767973767579767676
7676767673797975
767676767676767676767676767676767676767676737976
7676767676767676767676767678747376747A7679767474
7676747876767379767677797678747676797573767A7079
7976787479747A797379767676737976747C767478747673
7B75767676707C7673797679737A7676787477737C767676
76767676747A7476
767676767676767676767676767676767673797679737A79
757676767676767676767679717976747A79767678767179
797676707C7674767979767479757676767874747A767474
7C7679767079787477757579767775797676767379767670
7E747673797476797476757A74737976767976727A767676
767673797676747A
7676767676767676767676767676767676747A767874737A
747676767676767676767678727A767678747676767A717C
74737B73767976747A7476737A7476767676797573797674
7A767874747A767678727A797678727A7679717975797670
7C7679737A76747A7674787A76747A797578747676767676
76796F7C76767676
76767676767676767676767676767676767676767379747A
7676767676767676767679757676767676767676767A7575
76747C766F797976737979747A7676737979797374767B75
737973797673797379767874767379767678727E71767974
7A737A74767379737976737B757676787473797673797676
7678727A76767977
7676767676767676767676767676767676767676747A7379
767676767676767676767870797679757975767676787670
7976767872787A796F7E7476767676747A78767479737876
707C747A796F7F6F7C76767975747A767676767870797B75
76747D7576747A707C76747C7476767379747A76747A7676
7676767679757478
76767676767676767676767676767676767676767676747D
7576767676767676797179747D7578767973767673757974
7A7975767676797672767979717976767676737974767775
767D7579767278747A797578707B71797975797176787874
76797674767676747A767676767676747A79757676767676
767676767874747A
767676767676767676767676767676767676767676767678
747676767676767678727A767476737A786F757977737C76
767874767676747379747A786E7C767676767476767A7872
7A7473767379747A767A7373767C7276767376747A747A76
767473797676767975767676767673797678747379767676
7379737976737976
767676767676767676767676767676767676737973797679
757975767676767379767676747A77797A717A7978727A76
76767975767674787A737976747A737B757375767A767676
76747878787A7379767874747D7576747878787679737976
7973747C7676737A747676767676747D757975747A767676
747A747A76747A76
767676767676767676767676767676767676707C74767978
74787476767676747A767676797578747874787079737976
767678747676767673737C767679737C70737A7A76767676
767676767673737979767676787476767676767079737C76
7874747A7676747A767676767673797A737A737673797673
7B75767676767676
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.678571 0.343006 0.97619 0.640625 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00751202 0.0192308 0.00751202 [
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(120) show
81.000000 12.812500 moveto
(deg) show
99.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(.) show
105.000000 12.812500 moveto
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
128 string
128 128 8 [128 0 0 128 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
8C8C8A8C8E8C8D8C8A8F8C948C8C8C8B8E8C8C8C8C858EA5
7C8A8F8C8E8A8C8F8A8C8C8C8F8C8A8C8B8C8E8C8C8C8C8C
90898C8C8A8C8C8C8C8C8C8D8B8F8C8B8B8F8C8C8C8C8C8C
8C8C8C8C8D8C8C8C8C8C8C8689909F818C8A8C8E8C8C8A8C
8C8C8C8C8A8C8D8B8A8E8B8C8C8E8A8F8E8C8F8C8B8C8D8D
848C9884868A8B8E
8C8B8D94918784888E8C8883828B8C8E908C8C8D8D979992
70898F8C8A8D94918E8F8C8C89848B8E8A8F8F8D8D94958F
898A908D9095929193958F90938C898E92928C8A8B8C8C8C
8C8B8C8C8B8C938F8C8D8C94998C8D9697878C8E8C8C8F93
8E8A8A8A8A908C8C91939094948C8C918F8C8881878C8871
6F9B99888B8A9091
8E8F918D8B8F94918C8F8C847D818D8D8D8F8E8D8F8E8A78
9AAA908B90948E8785888C8C8C8C8F93908B8A8C908F8B91
999795968F8C8E8E8D8C8F928D9092888584868988898C8B
8C8C8C8C8C8C88868C8C8C8C94A37F4C8AA8949187858A8C
8A9295908A8A898B898C8C8885888F8E8D8B8B8B8A817D8A
928A848B89908A89
8A8A89868A87858B89858C949285727D8C8D8E92908F9893
7268958E8987888F9494908C8C8C8E8B8A928F8C8E888A8F
8C878A9093908D8E8F8D8D8D8D8D8983888C8B8487898685
84898C8C8B8B8B8C8B8C8C8C8C8E9992687B9783868B8780
848883868B908E8F8D8C87888D918C8D8E8D878A797B8883
999A8A8A7F889593
8D8B8C8F8B8B918F898C8A858987888380868889898A8781
86908589888C8C8C87898F908D8C8984868C9194918A8981
808385898B908F949999918C8B8B8D959392958E8A8F8E8D
8E8C8B89878A8C8887878A888A8C8F99928980948987878C
8F8C8987898A8789898B8A8D8C8A8C8E868B867678877D7E
8B7C959182838289
8C8C8E8C90928D888D9391948D888D87817E888A87898996
947B7489888A858A8F8C85878B91958F9299938C8E8B8C8C
8C8C8982879195918C868A908D8C8C8C8F8F868998918A8D
8C8B88878B8A878C8E8F8F8D90898A8F99816E90958D8B8A
8A89898A89898B8D8B8C908F8C8C8E9297988C8B8B9CA0A6
9F83927E74888F8C
8C8886848C888C908E868D8986918D898A81757E87848585
8D8D88898D898587858D94949692919B9B919091928C8C88
878787858580878A8B8B95929598918D8D8E8E93928F9392
9293948F8E90928F8F908D8D8D90908C90968465798F9292
908C8D8C8C8E8D8D888A88888C9599A0A4967C888F978D8D
8896A07D7F8D8A8A
8C8F92918E888C868C91928F948C8B8E8C8C8D847E848584
878F8A7FACA28F8E90908C8C8C95998C878C8C8E908D908E
8E8C8C8B8E8B8E8E9393918A8F92949B9795979392959495
9193909099958F8E939595959594949091989D938F8D8E8D
8C8D918E8D8D8D88878E8E92989BA7A390838AA1B4AF9199
8E8D92828A8E9091
8C888B8A87898F908F8A86878B908E8C8E8C8F89857B7B7D
79757E825D69988E8B8A8C8C9089848586857F7D818C918F
8B8C8C8E8A868688877F85898985858A8F999B9FA59E9C9D
9FA5A1A4A09EA2A3A09B9B92908F8D90969397B2A3859AB8
AF9B959293948E8F948D8A92B0B497808792999588839180
8098837A8B8C8C8F
858B8B8C8F8C89888B8F91928E8B898F92908E8A8D898E8E
8C8F8F8D89787DA8938995918A898F9098969394908F8C8B
8E8C8B8A8C928F8C888F8F858A878481817C797C7A7D8081
82807C81837F7D7D7D7D787A8A8583838681848687948262
65C4B59B9A919194A5C8DCD8B782797E888386948882928D
8D97878C8D8B8788
96938C8F8E9494908C878A8C87858B8E89888D898E8B8F8C
8C918A8B8E8E979595AB97898D8D898287888B8C8C8F8B8A
8C8F948F8E8A87888A8C88888A888C8C8A8C948A85818086
878687847E858B8B8D87878C8783908F8D898983848E9292
8A5B3887A6BBB2BDC5A18B877C888E9598727F8E8FA48973
98827E8B8791928D
83888F8C8A88838C8F908B888B918D8C8D8E8C8E8D898986
8C8E90938C8F95798A978EA49B8C8F8E928989918F8B898A
8D8D8C8E8E908E8E8A8A8F8F8C8C8C8C8C8A848C95938F89
848A8D90979288868C8B8C8C8C90908A8F8B92908D898792
96999285625EA1BF968F917F8795A0A18A80ADA18F938792
987C7A798A888A89
948C858D918A918B84858D8D898D8E8C8687898E8D8E8C8F
908C8A898C8D90898A8C94A0BEB3908C8D868F8C8C938D89
8C8C8D8D8B8E8E908C8A86888C8C8C8C8C8C8C8C898C8A90
938B8A908B898F9591888C8C8C918A888D8E90898C919491
8D96A6B7CEDDAE75859382878E8C7D7B8C919D858B937A8D
8D7F8C868E89858B
858B938F8B8A8F8B92908E8A918D8B8B8C8C91908889918D
8B8D8E89898C8B77718897A090B5AE948C9298918D88898A
8C8C8C8C8E908C8C8C8C909393938F918F8C8C8E8C8C8F90
8E91928A898C8C8D8B8E8F93948F878C8E8E8D8F93958F96
9BA09FAFAE8C787D787E919288817F8C838FA28E92878294
877D878C8A889192
949088898E8B89878D898D8E8C8D8C8791948F8C8C928D8B
9087878C928D958896A3989A9496C2C2959584858B908E8F
8F8C8C8C918F8C8C8C8C8A868A888C908F8F8C8A868E928E
8B8A8A8E8E8E91908E908C8D868A90908A898B8E93929497
97979DA282768C9283868687838C93979A9C80747D739394
7A808C8E8F8F8B89
8C8D91928D899294928B8A868C8C8C938C8A88898E8C8B92
898C8D8A8C8C8F89997F81878B9093B5B38C8C958E8B8C88
878C8C8C8A8C938F8C9093939092948D88888C90938E888D
91938F8A898F8C91908C8D908F908B8D959D9EA1A6A5A29C
A4BBC8966F7E9A8F8E8270708C9D9798868B878C74899475
8192938E888B898E
8F89888C888C908A8689918E8D8A8D87888D898E8C8E8C88
8F928F918C8C868A8B929C8C9B978B88BEBC8A918B908C8B
8F909393938C8A8F8F8E8C888A8A8B8F9093958D8A90938F
8F8F8F95929190929198938E9592989592908F908F929EAF
C3AB84748792826D7F86949487848B84898D848B999F7F7B
83928F898A8C8A8A
8A8F8E86878F8886898F8F8C8F8F929093928C8A87898D8C
8B8C8C8C8C91939C90AAA08F979487838BCDCE938D928E8E
91918C8C8C8A8E888C908C8F928D8A8B9091908F908C888A
8D8B8F9595908F908789888F9394928D989390919BA8ADA5
927B6F6D87938C8592A1A89B9D8C76808D82828B88757487
8F837E848786878C
8F88898E8C898B928E8A888E928D878486858B93928F8C8B
8D8A8A8D8E88888E879D8C8E918E8C90988ABBC08D86898B
8D8C8C8C8C8F8C888E8C8C8C8B8B8C8C8A888C8C91919190
8E8D8F8B8A8F94949593938F92908F93969595A6BAABAD99
7E76778A92898D87867E7575787D88887D7E8B8C848A968C
8489898B8E8F938F
8386908D8F8E8A868C91928D86899293918E8A8B8B898C91
90898A8D8C8F918D8FA3909999888798999384588C8C8D89
8C8D898A888A8F93908C908E8C8E8E8F8D8F929095918E8C
8C90908F939695908B84899BA3979A999E9FACA0A2988876
97918A9593918584897D868A7E828982818B8C827E88807F
81848B8F8B8F8987
8C8F8F8D90908F918D8C8D87898D86898A8C918F888E9187
868C8C8B8B8C8C92A7A8908F90878C88858076A7B2878986
898D8A8E8F908C8C8C8E8B8A93918C8C8D8E8A8E898D9089
8A8E8C908F98988B7E8CA9A1909291949F9DA5A5836C7472
6E687C88858888969C9D968999A487838C8C847F807F8087
8D958E878C8E898F
8C8A8B888B8C8C8C888E88878C8A8E908A8F8D8F918C898D
8E8F8F908F9390979A9B9595878299918D7C7D9C7C898B89
8F8C8E94918E90918E8B8D908C8A8F8D8D8F908A8F8E8B95
979393969B93877F83A49C838792A2B2B3988E8B928D8197
918B8D8E909F88887B887C858C76798C8C878984838B898B
8F87868C8F8A898A
8C918C8C8C8687898C8D8A8C8C8C8D8C8C89898B8B8B8D87
8E918987898D8DA49E96989B989D9D8E81768DA566878E90
908B8C8E8D8C8E8D9092918E8C8B8B908E8A8C949691928C
8E8C919394958887ADAE969AA0A59EA39380918986909E98
86898C908E7C7A968E979A9D8794938B8B7F6F778C898589
8C888C918F8E8F8C
8C89878F8B8C8F8E8F8C8C8E8C8C8A8A8D918F8C87868E8B
8E87878C8F8F96A297988C8A87969E87848F9886548D8589
918E8C8D878C8F8A8B928F8C939796948F9594908C8A9094
9298979C98898CA2A4918D8F97A5A08D817E807B868E7B76
808F948C7478879190928C8D817678887E7A8A8E8A8B8E95
8E898F8B8686878C
8C8F8E89878F8F8B8A8C8C898C8C8F8C8A8C89878C8E8E8E
8E8C9192918E9197959796948F8D7F7285A4A095698E8E9B
90888B9399938E9496929296928F908E95938F949293928D
939292918D8791A5A7999B9AA5917F88898C8C82897E8694
8898948C8688808A8B7F858A848C8B81767B848B8E898B87
868C8E909293928E
8C8A898F8E8A8A8B8C8A8C8E8C8C8A898A87898C8E8B8E8C
898C8F89858C9DA6928B908F8C9A8990A7A18C8C648B8987
83918F89888A91928E8F928F93908F93928C8C8B91959091
918C8F93888BA29E91939BA49C8CA59E8E7D83897A7E8B91
9B8C7A908D8E94977F7D8B7D7F8D817D8695958B87858A8A
8F8E8A86898B878C
8C8C8C8A8C918C8C938F8A898C8F8E8C8C8C8C8F8C898E8F
9092898B928D9F9C979AA0999B998491938C7C8760949190
8E8E93928F8F928D91948F93969194938F8F9396928E9092
8D969892889399949597968980969486898E92919290838B
8C989B8580958C7B7D9B9A8888867F8A8C837F8C8D898A8B
8A898C8C8E89898E
8C8F918E8E8C8B8A868B938F8C8E8B8C8F9192928C8F8F87
848988908E9CA58F9597937E9086828C9CA0999364918C95
91908E9093929292948F91908C969C98959693918D939595
9995918F9CADA1999289848B968D807D8387887A75707C97
968E80929585858D9B9B90827E8788878B8E9286848B8A89
8C8F8E8C8A8E8F8E
918C878C8F8D9094928C8687918D8C8E8E898B88878A8789
8F918F8F8B9F9E9794929A96977F97A5A6938C8E6A908A89
8790909296938F908E90938E8E8B898C8F95918E92928C95
9894999297989D8F8A8D8CA5AEA7927F7C828D9495978B77
7B7B83878F918B999A8C8C828A7A7D8A89898B8590918F8C
8F8C898C8F8B878A
87898C8A8A88858586898C8C898C908B8F8C8D8A8F8E8F92
90888C8D97A595989B9D9092968E9995907B7E846B959095
9492938E8A8B9193909395969E9D9896918C9799928C9595
8D8D9487919F8D849196AFA89C816C8C9496948B85868294
85778587897F9B9A95957F737D84908F8C85878A8C898A8C
8A8E8F8F8C8C8E8C
8C8C8F8E8E8E9392918E8F8E8C8A86898F8F90908D898E88
868E8F8C9FA29CA495938F8B8990A49C908B8C8E6E8D8C82
858A89868988838185868D9891919792939B918A989B9694
989F998A9F9D8B8C9BA7A18D756F8884848A8F8E8D8A9399
8B8F908F827D928784737B887B868F84868985888A8A8B8C
8C89878A898E8B8F
918E8A8F948B8987878C8F8B8C918F8F8B898C8C8A8C8E8E
93918D929995969791918F848C8FA6908788907E627E757A
7F78767C827F848682827B768A958F9392959AA096909591
8F94928FA8988297A39D9776878E838C8F9692828B878175
7F8295A48D8C9390847E81687A8D808589898E8F8E8A898C
8F8E8C8C8C8A8C91
878C918B83868E8B8C8A87898C8D898A8C8C868D8B8F8C8C
8E8B8A9BA6A09B958F9C979996929E7E88898E62507B8185
898B8B857E808584858989877C748594948D898895998D8C
908F949396797295A095817491838E9293918A8A958E8C8D
8C8897817A999082788E8C819399908D89898B8F8F939291
8C898F8E8C8C8A86
918C8C8C8F928D8E8F8C8C8C8F918C8F8F8B8F8E888E9091
8C8B8C95999D97979689828F8AA6957C909254285B80878A
88848587898B8880878888878782786F839497978C889093
99969CAD94857F99999FA08D7D7F8E7E8D7A7E87807E837C
80A1947F8C9A92848A95697C9C897E84858A8D8C8686868A
8E8E8A898C8F8E8C
878C8C888A87888E8D928F8C8A8B8E8C8A8E8F8C8B8A8685
8A92A0A3A198989F9F9B948F9AA57E829130145F898B8A89
8986908E8F88898C8981838A8C8485857D83939593989497
93919E96749B82847C7681989097898D9A8588818C958D8B
928A83918B8C7D848C807B978C7F89898D8F8D8A8C8F918C
8A8E8E8C8C8A898C
8C8A898C918F8C898687888C91908C8C8A8A8987898C8C8F
918F969AA197968F8A8792929D978599684587908D8E8E8C
8B8C8882888E908C8B91958982888A8685836B8094939194
949B968C7E82729395A48F6170725E82818D9288888A9093
8790968B9693807E8290978C7A8089888D8A8E8B8F8F8989
8A878C8E8C8C8F8E
948F8F8E8987918F8F918E8F8E8B8D8A8F8F8F8F8C92908F
8E94979A9D8E94969C989B91A29187793D608D89878C8B93
9093978F8F8C8D8D8D8981898F8A8B8A8781818384909095
929594A0927C998C744C7086A39B9E968F837F8B958A928F
81939287877D8E9D9985737D8F8F8F908C8C8C898E8C8B8F
918E8E8E8E8F8C89
8A898E8B8C8C8D8D8C87898A8A8C888B8C8787888C898994
929A959E9B9F9A9590868E9EA07674354589898C8C8F9295
9497909497989B96909394938C92908B8A878685757E9D94
9599979185948B83868C7A6A868290889389A49A8D83918A
A38A7290978A928D8274738A8C888D888C8F8B8F8C878C8C
8A8B8A878C8C898C
87898E8B8C8C8E898C9191918C878C8C8C929492918E8A8D
96989CA79E99999F918CA6A08E964943878891959392959C
9FA1A4A5A5A49B9A9FA196928D89848B8D8E8D8781766B82
948D8D898C9B8F7389785A7E939A8483809D918084869089
817D967D6B85958887778889818C8D8A8A8A8B8F8F8E8E8E
8C898C8C8A898C8F
8C8F8C898C8F8C898A878A89898C8A898E8C8A87878C9192
9190989696908C9391939A887E232887888D8E8C8E959A98
979AA0A0A09E9C9796959299928D8C8E8C8E8B8B928F848B
9694969E998B7E9EAD88927E6E72998E868C7B878390818C
98928877888C807D86858E858E8A86898E8A8E8C86898E89
898F8E8C8C8C8C8A
8C8E8B8C8F8C898C8C8C8E8B8C8C8C8C8A8A8D908F8E8F9B
9B909EA89E9A979292A59A86876A8C9293938F8D94B7C8B9
AFA39A959595A4B2B8B6A5908C8F8D8A898A898D89898F7B
7F959B978D8D9986697A86777D676B8C957F92A0928F9692
838A8A8B848C8E7E7B88918B9190918D8E928B8B8E8C8A8C
8E8A8C8E8C8F8E8C
8C8E8B8F8C8C8E8C8C8C8E8B8C8F928F8C8E88858C8D8F90
889EA99B9895949F8D8989832D378D8D8D898AA8B9A27C58
58738378687D84797C83989F928F8F8C8E8C8A888A8F8A89
7B739192918AB79A769491A18D7D8280789E907B848E8E88
92878699A5A1899080777F898E85848D8F8B8B8E8B8F918C
898F8C898F8F8B8F
918C8C8C8C8C8C8E8F918C8C918F8C8D91918C8C8F8B9A9F
ADB4A69AA09D9A8A9DA69263538B878A8C8E90A2948C90AB
CAB69AABC4C7AFAB8B888AA1A08D898D8A84898F8E898785
847978798F98826BA89A848884956A739B8F7799978E8D8B
928C8F97837D8E8D7D8C898E8F888C898687898A8C8C8789
8C8A898C8A87898A
87898A898E8E8C8C8F8C8B8E8C8C89878A8C8A8F8E8C9795
9F979AA4A28B92A599837839598C90908CA8BEBEBCCABEA8
A9AFAEB2B1BBB3ABC8D5BFBFBBBA978C8C9292898B8C8983
8C8C8495A3808CA59E7B99999F8F937A6572978C7E8C94A1
91808D827C7C837C808C8E8E848B908C8F8E8F8E8A898C8C
8C8C8C8F8E8F8E8C
9191918E8A8A8E8C8A898C8C8A898C918F8C8E918D929795
9FA2AAA6918D97867C812F41908F88898C8461686963737E
85786D7875665F6A6741382E2C4C788C908F8B8A89898C8C
8A838384839AA38F90937E89988D91927D8E947C8F888D92
80939286978D8E727188908E8D8B8B918C898A898F8E8C8F
8E8C8F8C898E8B8C
878A8C8B8F8C87898E8B8E8B8A898A878C8A8A8E8E90979F
A6A496878D96938F8E8764918D8A918E8B847D734A353639
323446412930353B4352737B7F83868C8A898D8D9089898C
8F8785857D8B70809CA7A79F8FA8A3A0928F6E8592989480
7E9E8F8A948DA080868D8C8C8687878A8B8C8C8C8A898F8C
8C8E8A898F8C898C
918C87898A898F8E8A898E8B8F918E8C8D8E908B8FA5A6A4
A79EA0A0949E94878F4A458A888D898B8A8A8D8C8B8F8982
85918C8F979F9C98908B8E8980868C898A8D8B8B8E8C8F94
938C9391988B7A9169767A91A0907785917B728A88768BA1
A99B818A9581867086929087858C8C8E8B8C8F91918E8A89
8A898C8C8A898C8F
8C8B8F9191918C8D8F8C8A898E898C8E8E8C8C8D898DA1B5
AE9392929C8C7E8C8A5B7C8F8E8A8C8E898B888C8E908E90
90938C8D8D918986898A8D858F8C878D9390898B8E908B85
878C8B888271999F9FABAAA58286A09A9291A58F848C9481
8B838B969194947C928A918B8B8E8C8E8B8F8C8787898F8E
8C8C8F918E8C8C8A
878C8C8A8C89898A8B8E8C8C8A898A898A8A8C8CA3A8A29C
929C97938F90958A966E8F8F8B8C8A878C8D8B8C8C8E8D8C
91919691959A918F8F8D8A868E8F8B7E85868C8F8D8A8E92
9196948D8F9B9079847E8179879AAA8FA1AB8070938C9986
8179918C92987471888B85818C898C8A898A8C8E8C8C8E8B
8F8E8A87898C8C8C
8C8A898A87898C8C8A8C8E8C8C8C8F91918C87909CA4A39C
99888C9382857E98674B908C898B8C8C87878E8D8C8B9095
9BA1A39B9D979395928E8C908B808494938B8E8E908C8F8C
87828C968E8377848F9C939D98928DA9936C95A590808B8A
97898E848C8C6D8E89898381898C8C8C8F8E8A898C8C8A8C
8F8B8C8F8E8C8C8C
918E8C8C8C8C8F8E8F8F8B8C8F8E8A878C8C8F8C95A1AAA8
9FA19A959D928B954F608B8B898C8C8C8E908E8C8C8C8F94
988B8F929596939192908F8E91918D8988848488898A8F8C
8C9692878D96ABAE9995889D8D8B80977BACA872828C8883
89959A888B7A768C89A6908C8C8C8C8C8E8B8C8C8C8C8C8A
87898C8E8B8C8C8C
87898C8C8C8C8A8C8C87898F8C898C8C8A888A90A7A8A7A4
989B968B7E839B9D648D8E8E8C8F8A868A8C8B8D8BA8C69E
7D8289AECAB395ABA9958F8684848B8B888C958F8B8D8989
8C8A8896918A8C81929999988892968597AF7B989C8890A3
9B99867E8E728D8B9A82758C8C8C8C8C8A898C8C8C8C8C8C
8C8C8C8A898C8F8E
91918E8F918E8C8A898F918C8C8E8C8C8C8C8F98AEAA9B85
8A8A8C938A969A78548C878583888E90918E8E8C877E5C64
8986856F485169727C978F888B8C8C8C948C80848A8B8A8F
92929088858597969792908B9692918FB97E8AA182988F93
888685948E92A89B83658F8E8C8C8C8C8F8E8C8C8C8F8E8C
8C8C8C8F918E8A89
8787898A87898F8E8C8E8C8B8A898C918F8C8A94A7A59CAA
A58A8A828699976A5F8C8B908D8B848589878B8D8C928881
8387868386898F8F817981878C8A8B8C888C98938A89898B
90909191948EA0838E838082978E978A9573A07F799E888E
80888D85858C8876748C8E8B8C8C8C8C8A898F8E8C8A898C
8C8C8C8A8A8B8C8C
8C8C8C8F8E8F8C898F8C8A8B8C918F8D8D8E8F9AB0A59287
7E8D8A828F9C874159868783858B8D8D8D8A8D928B878486
898F8D8C8B908F8C8E8684898C8A8D8A8B8881888B8C8B8A
84848D8F9095958F947EA8978A7B9D957F73988596908589
8792998E8595886B748C8A898C8C8C8F918E8A898C8C8C8C
8C8C8C8C8A898C8C
8C8C8C8A898A898F8F8B8E8E8E8A8B8C87898FBAC696A0A6
998F8B8FABA0966C898A908C8C8D8C8B8C8B888489959190
928C8B969B958E928C8380848B8A888A8E8C8C88888F8C8B
88888C908C858086878E7A7592879786968F8B938E788E94
9B8C7E6B7EA091828C8E8F91918E8C8A8A8B8C8C8C8C8C8C
8C8C8F8E8C8C8C8C
91918E8C8C8F8E8A87898A878C8E8E8B8C8C8FAEA09BA17F
7F848CB2A68B8454888584878E8D8D8E8E8E8D8A8D8D8E8F
929699938D888889817D838D8D8C8C8E8A8B8C8C8F89898B
8E8986838A8F919A7A84959C9499888088778088867F968C
968E9293927B59748A898A8787898C8C8A898C8C8C8F8E8C
8C8C8E8E8E8C8C8C
8787898C8F8C898C8C8C8C8F8C8C8C8C91918EA79B97887F
91918C8D868E3733898C8D8C8C8C878484898C8C88868E8A
888A90938F878784838688898A8B8788898D8C8C908E8C8C
8E908F8D9390878B9294938E7F8E90898587807D8385A782
92878E7C798780898C8C8C8C8C8C8C8C8C8C8C8C8C8A898C
8C8C8A87898C8F8E
9191918E8A898C8C8C8C8F8F8E8C898E8C89A3C4A0968987
8C8AA4AC992C197788828A8C87898F9595928D8E8E8B8786
8C8E86858987878C8B898D8880888A918785868987808689
87888984838B8E876D6D757B89897E8D978579878A8E9B8C
A98C8F7E8977768C8C8C8C8C8C8C8C8F8E8C8F918E8C8F8E
8F8E8C8C8C8C8A89
8C898A8B8C8C8C8C8C8F8C878A8B8C8A8789CFD1A0A38C91
958D947C6E49868986909287878F8C8B86898C8C8C8C8F8B
8C88878F8F8A8886888C8A86908B86888C928C8A8A8B8C8B
8E898B8C928A8F958783928B8C8B818F7B697A9191989F97
9E837D787F7E868C8C8C8C8C8C8C8C8A898C8A87898C8A8C
8C898C8F8E8C8C8C
8C8B8A898C8C8C8C8C8A898C8E8B8C8C8F8EAC8A92937A87
87918F8C624487878D8D878792918C8C8F918784898D8A87
8D9493918F8F8E8C8686888E918B8D939387888C8E8C8987
8C8C8C8A908E928D9497908C948A8C89917D7C8D8C8C838A
7E74908A76808C8C8C8C8C8C8C8C8C8C8C8C8F8E8F8E8C8A
898C8C8A898C8C8C
87898F8E8F8E8C8C8F8E8C8C8A898C8C8A8CB38B88838E98
8C999071345A898B8C8C8F95928D8C8C928F8F95928B8B95
928982898B8B8C8E90918F8E8C8E8E8D848A9593908C8E90
87868E8E89878589888288928D8991989F77879390918DA9
8F888B847C898C8C8C8C8C8C8C8C8C8C8C8C8A898A898F8E
8C8C8C8C8C8C8C8C
918E8A898E8B8F8E8E8B8C8C8C8C8C8F8EB9D59F9B837C84
9C98853D388A8B888C8C8C87898C8C90949494928E8B938F
868C8C8D8C8E90979298948D918B8C908F95928D8C8D8C8D
8C9089878F8D8D8D8A968F8C8C84898D81769D8C86AE91AC
9482747977888C8C8C8C8C8C8C8C8C8C8C8C8C8C8F8E8A89
8C8C8C8C8C8C8C8C
87898C8F8C898E8B8A898C8C8C8C8C8E8BBE937293838F91
99857D658F968B8D87898C8E9190939D978E8F93918F8E8A
8A8C8C90958F9190928C818D8B919A9A98938F8E8E8C8E8B
908C888F8A8A8E8C8E939795888D91898C7A8D8E8FAF8BA3
848D806E6F8C8C8F8E8C8C8C8C8C8C8C8C8C8C8C8E8B8C8C
8C8C8C8C8C8C8C8C
8C8C8C8E8B8C8A8C8E8C8C8F9191918C89CA959E86829088
9E763C419995868C8F928C919595928C92A29B9290919793
8E8D8C989793908E93918F8E9699999B9DA3A7A4A29B9593
8D86908E9495938A87838C94978C90888C838B99A0AB6894
8F7B7A7A7C8C8C8A898C8C8C8F8E8C8C8C8C8C8C8A898C8C
8F8E8C8C8C8C8C8C
8C8C8C8A898C8C8A898F8E8E8987878987A37EA9959A8CAA
887A6F9CAA87878D8C8C9095A1B9C8B8A5A39C9D8F888D8A
888B8B8B8B919599828588979EA2AAB4B6A69D9B9B8D8D95
9A99958F8D8E8C94988D7E758D8C959291809B9D919967AD
9A748B867E898C8C8C8C8C8C8A898C8C8C8C8C8C8C8C8C8C
8A898C8C8C8C8C8C
918E8C8C8C8F8E8F8E8A898A898C8C8CC7CD89A294998D94
73424A9D86838F8F8C94A3C3C28F70A8D1B598A7B6A6908E
8A8C8C918D8D878F98D5E3CDA27E9AC0A8A4B0B0ACA09E96
8D8C929192939790858C808B95868C8C867B86928F9A73A1
76607E6F81928C8C8C8C8C8C8C8C8C8C8C8C8C8F8E8C8C8C
8C8C8C8C8C8C8C8C
87898C8C8C8A898A898C8C8F8E8C8C8CB288828797968296
A17B8C8D7D7E878C98A3B8A6695BABB79A98A095898BA495
878C9293908D94A29E7E7A6848A7C88F779F8385A1A59D96
908E8F918E90938E9795A1B99E848797918592A2928C71BA
7B6E8B74838C8C8C8C8C8C8C8C8C8C8C8F8E8C8A8C8E8C8C
8C8C8C8C8C8C8C8C
8C8C8C8C8C8C8C8C8F8E8C8A898C8C876471B6ACA3829087
604A999C928993969EADB4CCBAAAAE59A0A0B2B6A99E947F
868C8D8D8D858D8C9A9C7D90BDCD6AAEB6A87DC7BB9499A3
9795929798958F98988B9D97839AA093778E9C8E808E7CA9
7D9082718C8C8C8C8C8C8C8C8C8C8C8C8A898C8C8A898C8C
8C8C8C8C8C8C8C8C
8C8C8C8C8C8C8C8C8A898C8C8C8C8CCDD1B5847E80798C85
6D6AA492868589979F9EB48F83E4FFEBB85B866D796F7282
8C8E8E8F8D8C88817F89AA928ED1D7D685ABB9B4707F8C96
96979494969DA69E8B8E897E77748A99878E919F938A7698
72876F748C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C
8F8E8C8C8C8C8C8C
8C8C8C8C8F8E8C8C8F8E8C8C8C8C8CB8A2A099A2817F9397
828297898885908D7D725F5C84886D6379816F575C687C85
88888E8F8982827F79777498A5763D4D72898C6E5B5F7F7E
7B8694928B93998D928E868A829297908182888C8580759B
7E8274868C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C
8A898C8C8C8C8C8C
8C8C8C8C8A898C8C8A898C8C8F8E8C6867B3BB9D98A19D7D
71919B96928A89847C74674A352A24231E2C5B7B8A8B8385
8C8E8B87868A9097918F7A5B4C6E76674A2E253A59666670
7F8A8D92948C8E898C9DA097887E778686828F927E7F7E99
7C615C838C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C
8C8C8C8C8C8C8F8E
8C8C8F8E8C8F8E8C8C8C8C8F8C89877ECAB8AB9D98808D91
9B9490968A8091908989837F7B7387ABC8D6CB917776828A
83898C8B8983868394B4BAC2B2805C585A6570787D848A8F
99A7998F959B8F8A93838C979299AB9283989E8F7F867B93
7A7086928C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C
8C8C8C8C8C8C8A89
8C8C8A898C8A898C8C8C8C8A898C9995C4949F898386916E
82949A948C8990929A918D8D94C4D6BBA06E414B7A85888A
8A8F8C8C898C8A7D76708BA8B0C0B9A3948883898790969E
AA8F8898989993919FA6A48A89957B65777D8A9185918F94
7970838C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C
8C8C8C8C8C8C8C8C
8C8C8C8C8C8C8C8C8C8C8C8F8E87B29CB183867793938E89
97A3A097898187A5B6B7C0CAE0CA7C42273B64797F81888A
8D928D8E8D8B8B897B6245364B78B2D3DCDFD0C6C3C9C2AD
887C8C878E8F8C96788C8A737B839A968489948F7C8095BA
7B648C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8F8E8C8C8C8C
8C8C8C8C8C8C8C8C
8C8C8C8C8C8C8C8C8C8C8C8E8B8FA9D1F491797C7F80948E
908A8995847D8B77587992926D3736608185888C8C8C8C8C
8E8C8784848989878789857560442B274E76979F9B826C72
8183858D928C838FA699789CAEAC987C859990847886A68A
58788C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8A898F8E8C8C
8C8C8C8C8C8C8C8C
8C8C8C8C8F8E8C8C8F8E8C8A898C8D92918775797E808884
878B848A85858D8E8A75584E55758A8C8C8C8C8C8C8C8C8D
8F87878C92928E8D8D8B8A8885898B8A80583E45525F7882
7C8C9B9D98888886818CA6AA9E8C8A5E82976B828F899478
65838C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8A898C8C
8C8C8C8C8C8C8C8C
8C8C8F8E8A898C8F8C898C8C8C8CA4BFA3886F8A928A8483
8F90878E83838A898C8A8C8D87848C948F8C8C918F8D8D8C
8E8F8F929287898B8B8B898B8C8E8C8E908993948F92928F
8F9488838B8E8E9A857D8C817F777D67858581988F869E6B
65898C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C
8C8C8C8C8C8C8C8C
8C8C8A898C8C8C8A898C8C8C8C8C8E9B797A8AA2887D888E
939491948D8F908E8D8F8F8C8F8F89898A8C8C8A888C8C8C
8A858789848C928D9192928E898F8D8D888C908B8F898989
8A88869797858D8B99B18F80929D9D6D928A6F8F958EA856
6E928C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C
8C8C8C8C8C8C8C8C
8C8C8C8C8C8F8E8C8C8C8C8C8C8C81978E9FA19E8F9A948E
88897C7C7A7E918F8C8B8A8C8D8F8F8A888C8C91938F8C8C
8C8C929595928C92918C8C8E93928C9395938C8D8F8C8D8C
96979A8F848C97A09F8F81989B8C7E7C897273938698804E
898C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8F8E8C8C8C
8C8C8C8C8C8C8C8C
8C8C8C8C8C8A898C8C8C8C8C8C8C85B88985837E8384858A
8C86828581898E888B88888C8C868791938F8C8E8888928F
8C8C8F8C8C8B8B87838A8C8D8E8C8C908F9292908C8B8F8E
89878F918F898E8E968B97A389898D8088A59491808A626D
8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8A898C8C8C
8C8C8C8C8C8C8C8C
8C8C8C8C8C8C8C8C8C8C8C8C8C8C8AA08796808696959390
807F88898C898B8C8D8D928E8C8F8F8A8B8F8F8A8D948C8B
9495918C8B8B8C908E8E8C908A898D898587878B908E8E8C
9694908E8C9996918C8C9C939D9D6E6F999C7B8670634575
8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C
8C8C8C8C8C8C8C8C
8C8C8C8C8C8C8C8C8C8C8C8C8C8C8AC889648697908C8F80
9B9E827F8C8B878A8C8D88888C8888928C8488918C89908D
898C8D8C8C8E8D8A888A8F8F8B908C938E8D9295918C8E8C
92868C8D999C99A492939F9C82836F7D8C9F8E91906D5A8C
8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C
8C8C8C8C8C8C8C8C
8C8C8F8E8F8E8C8C8C8C8C8C8C8C8F654EA4A6969A989095
88788688827E868A8B88888D8D8A8C8E89918F8E9091878B
928D8B8B8C8B8C8D8C938F858D8F8C9089908C8F8D8D898A
8C8595979689828195A09488818C6985888B7E8780687D8C
8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C
8C8C8C8C8C8C8C8C
8C8C8A898A898C8C8C8C8C8C8C8C8C7EABA08E95918F9792
87867A838584848A8990908D8C8F9391908D888A858A908D
898B8B8C8C8C8C8B9390898C8F878988858B898F8C918F8F
888F988884939EABA69F959092946B8792957A796B6B8C8C
8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C
8C8C8C8C8C8C8C8C
8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8F836A8A88858A8589
958F8C8E898885898A8A878D8D888B8885878C8C928C888F
8D8B8D8D8D8C8C8C8C858A8F8D8E928C8C93918E8C898D91
96958B91948988989191888A82876B7D89847A8268738F8E
8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C
8C8C8C8C8C8C8C8C
8C8F8E8C8C8C8C8C8C8C8C8C8C8C8C8C7989949893908E89
8B88827E7E8384878F918F8E8B8E908E8F918F92918E928C
8F928C8C8B8D8D8C8E8E928C8B8E8C8C918F87888A8C8E90
8E909491929C9E9A8E8D8C867B8F808F8E727172798C8A89
8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C
8C8C8C8C8C8C8C8C
8C8A898C8C8C8C8C8C8C8C8C8C8C8C8C8AA2797C81848B8D
8881928F837E868F878787888C8D8E88888F8F908C8E8D8D
8C8B8C8D8C8C8B90908C8D8E918F8D8D8F8D9193908C8D88
8F95909694979A998A8B8C8A99A079939B827D6D778C8C8C
8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C
8C8C8C8C8C8C8C8C
8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C5B30596E7A7580
8D898082919089878F8F90938F8D8C8F94908C88898C8B8B
8B8C8F8D90929290888D8D8F908D8C94938D8E8F898E938F
9A949593949A9987898D8C96A1784F8086778178898E8C8C
8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C
8C8C8C8C8C8C8C8C
8C8F8E8C8C8C8C8C8C8C8C8F8E8C8C8C8C8A723F668A9791
82899088868D8C8C8C8A8B87888F8E8C8C8C8C8E918C8C8D
8C8C8A888E8C8C888C9492918B8C8C8C8D928F898D988E98
968994A0A7928F9796928F8F9252639F8B86756D8A898C8C
8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C
8C8C8C8C8C8C8C8C
8C8A898C8C8C8C8C8C8C8C8A898C8C8C8C8F9587878C9594
928B84888A858B97918F8F9196918E8D8B8C908E8C8C8F8D
92939393908C8E9599928C8D8D8C8D92908C8C91918B8C88
8A9DA0948887848B9291969D3C3D97997C6A5F7A8F918E8C
8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C
8C8C8C8C8C8C8C8C
8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8A88A09777
7E817C87898A8A87858D908E89868A8F8F908C888C8C8A8C
8F8789918F928E8C8C8D8D8C8C8D92908C8D9292909D9695
9D938D878D99997582A2945B6EA28F82747776858E84868C
8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C
8C8C8C8C8C8C8C8C
8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8AA898729F
9F7E8C87858591938E8C8C8D938E908D8D908E9292928E91
91969992979690938D8D8D8D8C8C92939191928D9094919F
A29C9C9F988A83A6996960777B7883716C7B7E84878C928C
8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C
8C8C8C8C8C8C8C8C
8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8AA9878F93
8F9D9E8F9299918B929094908B8C919094938E8C888F9394
908F959A9792918C909695979A9A9B9393979599A1999293
91888793979998948897645E7496777A755F698F958E8C87
898C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C87898C8C8C8C8C
8C8C8C8C8C8C8C8C
8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8F8460A299
838889898F8684929194948B9092938D8B8E929497968F90
91989B949290929E9F99989E999496919493949390959891
8F909E94848775737D6B5D8D82756D7274838E8C8A84898F
928C8C8C8C8C8C8C8C8C8C8F8E8C8C8C8C8F928C8C8C8C8C
8C8C8C8C8C8C8C8C
8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C849F925E
868B85989A9897878A939093918B8B8E929395969699A0A5
A29A99989DA1A5A49D9D9F9CA0A8A49FA2A4A599999391A0
A999898A827590957473909D7F8582836E6A898C8C8F928C
8C8C8C8C8C8C8C8C8C8C8C8A898C8C8C8C8C8C8C8C8C8C8C
8C8C8C8C8C8C8C8C
8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C6F5C73
828D8C7F7F91A2ACA08C878185939595959A9BA19F909294
94959E9AA09A9D94A09FA6A6A5A49D9C9F9A929D9885877F
75788F8D7E7F8499A989767A7C756F897D888C8C8C8C8C8F
8E8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C87898C8C8C8C8C
8C8C8C8C8C8C8C8C
8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C7136
496F929594A592847B7C7E8891909399A09C93918F9A9B8E
9A9F9E989B9298A5A291A3A39792929E9D999994A3B6AD9C
9D968E7D95AA996F5E789484666F9670698C8C8F8E8C8C8A
898C8C8C8C8C8C8C8C8C8C8C8C8F8E8C8C8F928C8C8C8C8C
8C8C8C8C8C8C8C8C
8C8C8C8C8C8C8C8F8E8F8E8C8C8C8C8C8C8C8C8C8C8C8C87
A08B77768163567F8BA1A69C95979795928D9B9B91939D9A
969397939E8D92817D94847A91858188808A8881908B8486
939086918A7B828F8E82675F7F9576638C8C8C85868C8C8C
8C8C8C8C8C8C8C8C8C8C8C8C8C8A898C8C8C8C8C8C8C8C8C
8C8C8C8C8C8C8C8C
8C8C8F8E8C8C8C8A898A898C8C8C8C8C8C8C8C8C8C8C8C8C
5F6D8C8C9AA6AAA39A91838F9A9A929798979B939E9F9893
9B8E929E939FA29496939798867BA3A09E888AA09B90A6BA
B39CA9AC9E9F94846960629096A57B758C8C8C8F928C8C8C
8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C
8C8C8C8C8C8C8C8C
8C8C8A898C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C
8F5C4985816E74766E7A8A8B969A9A9792908C8792958E91
9E9EAC8D8092AAA3A89A838C8CABAA7FA8C1B5A29D968279
6D7B8586827951596A73C1BDA47A4F898C8C8C8C8C8C8F8E
8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C
8C8C8C8C8C8C8C8C
8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C
8C8F9F879CA8BCB49F948F8E8E8F959B9590979C9788979A
88987C76A4806F8B8C8AADA0A9A298B6A67D809492878D9B
A49F866B5F5E778071ABAB73935F77928C8C8F8E8C8F8C89
8C8C8C8C8C8C8C8C8C8C8C8C8F8E8C87898C8C8C8C8C8C8C
8C8C8C8C8C8C8C8C
8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C
8C8C6A94966375808F958F9396A19F9B8E8C929B90909385
918398B08D9A9D86939C9194959493858193A29E8B939B93
816D758B988A7BA3D1B17378564C918E8C8F8C898F8C8987
898C8C8C87898C8C8C8C8C8C8A898C8F928C8C8C8C8C8C8C
8C8C8C8C8C8C8C8C
8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C
8C8C8F5747B9A67379929186859686909AA09E988C919897
9F949C808C8C9FB180909990928E9198A1A595939F957C7E
8581736E555B8D9B907D9E744B79878B8C8A898C8A898C8F
928C8C8C8F928C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C
8C8C8C8C8C8C8C8C
8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C
8C8C8F8E5A4898C2AB9884898D9A9D8F84857D788E958A96
928590858A838195A8A67082919F918C9291939EA096947D
5A6D887E93D7CAA18696864C869590898C8F8E87898C8C8C
8C8C8C8C8C8C8C8F8E8C8C8C8C8C8C8C8C87898C8C8C8C8C
8C8C8C8C8C8C8C8C
8C8C8C8C8C8F8E8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C
8C8C8A898F7E6984A89C979E90918E919094ACA3999B9F8C
8D9F897F9A9284735F88A8A28883768368656A665450616E
7D657394AEB3938D84733D5B8C8C8C8C87878C91928C8C8C
87898C8C8C8C8C8A8987898C8C8C8C8C8C8F928C8C8C8C8C
8C8C8C8C8C8C8C8C
8C8C8C8C8C8A898C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C
8C8C8C8C8C7E61597495BCB9B58985979B8D8494A29B9FA1
988E8F9D958684838185667B957A767F8586695F58697264
7A9EB19BB48B627F96514B8784898F898F8E878C8E87898C
8F928C8C8C8C8C8C8C8F928C8C8C87898C8C8C8C8C8C8C8C
8C8C8C8C8C8C8C8C
8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C
8C8C87898C8C786A7A84797C8B9081729391888777808C8E
89868A99818186867A647698838088746867706C727D91B4
C0C2D5C8956D8B873540928F8F89878C8A89928A898F928C
8C8C8C8C8C8C8C8C8C8C8C8C8C8C8F928C8C8C8C8C8C8C8C
8C8C8C8C8C8C8C8C
8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C
8C8C93938C8F8E71547D938682848B726E82A18F8886708A
9BADA19885927F835B5053493B42545B554D5F709DC1B098
A7A4815B5F868F41509287898F95928C8F928F8E8C878489
8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C
8C8C8C8C8C8C8C8C
8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C
8C8C8A898C8A848975334A8FB6AB888072707973827F754E
547A7E9088796C7F9EAA917D706D657298BDBAB7B9988EA7
9F7E7170928C3743928F91928F918E8C8C8F8C898C8F9592
8F8E8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C
8C8C8C8C8C8C8C8C
8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C
8C8C8C8C8C8C8A8F8C89585E8C839FA28074675E5F514F78
612200030C36576B5B608384819AC7BAABA8A6A09E989F7F
58657D924B194E878C8C898C8A8A8B8C8C8A8C8E8C87898C
8E8B8C8F8E87898C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C
8C8C8C8C8C8C8C8C
8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C87898C8C
8C8C8C8C8C8C8A8F8C8C8F65176AA69CA596716C73778776
7093A4AAA18F817C7F8894ACA4A99683A8999BA08A705951
798C753443958E9392898C8C8C8A898F8E8C8A898C8F928C
8A898C8A898F928C8C8C8C8C8C8C87898C87898F8E8C8C8C
8C8C8C8C8C8C8C8C
8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8F928C8C
8C8C8C8C87898A898987898C7E4D4A879F959BA19D908682
8686747880848B9291979290A5A7A2AEA57F8F76656B7D9A
8E4F305B8C8E8B8A89878987898C8F8C898C8C8C8C8C8C8C
87898C8C8C8C8C8C87898C8C8C878C928C8F8C87898C8C8C
8C8C8C8C8C8C8C8C
8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C
8C8C8C8C8F928F95928F928F9187561A58A2C1A18B82868D
9097969D9CA1B2C3C4B4A29F91ABA87673665A4A6D938A49
2A4D7D8C8C8A84898C8F9293938C858687898C8C8F8E8789
8F928C8C87898C8C8F928C8C8C8F928C878487928E8C8C8C
8C8C87898C8C8C8C
8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C87898C8C8C
8C8C8C8C8C8C8C8C8C8F8987898A8F8C69231565B1B1ADA7
92828389817A7D7576819A895C59484F5E79A18E67372654
868C8C87898C8F928C87898A898C8F9293938C8C8A898F92
87898784878984898C8C8C8C87898C8C8A8C928A868C8C8C
8C8C8F928C8C8C8C
8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8F91928C8C8C
8C8C8C8C8C8C8C8C8C8A8C928C8F928C8789876932679A91
A4AE9C958D8A7A605A575B5A797B81AEA57B493F64818C95
938C8C8F928C8C8F8E8F958E8C8C8F8E8A898C8C8C8C8F8E
8F928F9595959893878C8E8C8F928C8F9195928F958E8C8C
8C8C8C8C8C8C8C8C
8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8A84898C8C8C
8C8C8C8C8C8C8C8C8C8C8C8C8C8F8E8C8A9294938C71434A
52526979777E93B1B9A59292978D6D433F556D838C8A8C8D
848484898C8C8C8A8C918C898C8C8A898F8E878C8E8C8A84
898C8C8C8C8C8A898F8A8687898C8C8A898C8C8C85868C8C
8C8C8C8C87898C8C
8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8F958E8C8C
8C8C8C8C8C8C8C8C878C8E8C8C8A8C8E8F9087898C8C8A87
82817E7A7B8277645B60616060626F81898784898C8F8F8F
8F9595958E87898C8584898C8789878985869392898F8E8F
928C8C8C8C8C8C8C8C93938F8C898C8C8C87898C8F928C8C
8C8C8C8C8F928C8C
8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8A898C8C
8C8C8C8C8C8C8C8C8F90898C8C8F8C898F89898C8C8F8E8F
9192878C8E8C8A878787878F8C8F8E8C8C8F959287898A8F
8C8C8F87868A89898F928C8C8F928F928A928F8B8F8C898C
8C8C8C8C8C87898C8C8A898C8A8F8C8C8F918C84898C8C8C
8C8C8C8C87898F8E
8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C87898C
8C8C8C8C8C8C8C8C8C8C8C8C8C8A89878289928C8F8C8985
868C8F8A868C87898C8C93938C8A898C8C8F8E878C928A89
898C8A8F938F989387898C8C8C87898C8F9087898A898C87
8C8E8C8C8C8A8F8C87898C8F91928C8C8A8993918F8C8C8C
8C8C8C8C8F928586
8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C87898C8F91928F
8E8C8C8C8C8C8C8C8C8C8C8F89898C8F98938C8C8A8C898F
938C8C8A8F8C8F8C898F8C898F8E8C8C8C8A898F928C8F8F
8F8C8F8C84898A89938E84898C938E898C8C8C87898C8C8A
8D898C87898F8C898F8C84878987898C8C8F8C8C928C8C8C
8C8C87898C8C8F92
8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8F928C8A898787
898C8C8C8C8C8C8C8C8C8C8A8C928C8C8A898C8C8C8E8E90
89878C918C898C8F9285868787898C8C8C8C8F8E87898C8F
928C8A898F928C8C8A8C98938C8A8C928C8F898F8E898C8A
8F8C8F91928C8F928C8F95928C8F928F8E8A898C8C8C8C8C
8C8F8C8F8C8C8C8C
8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C87898F92
8C8C8C8C8C8C8C8C8C8C8F8E8C8C8C8C8C8C8C8C8C8E8E8E
8C8F908C8C89898C878F938F928C8C87898F8F8B8F8C8C8E
878987898C878987898C8A898C87898C8C8A8C938E8C898F
928787898C878987898C878C8E8C8C8A8987898C87898C8C
8C8A8C928C8C8F91
8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8F928789
8C8C8C8C8C8C8C8C8C8C8A84898C8F8E8F8E8C8C8C8A8784
898C8C8A8C95928F8C8D898C8C8C8C8F928A87898F918A86
8A8F8F928F8C928C8F8C8C8F8E8F928C8C8C8C8A848F978E
8C8F958E8C8F928A8F8C8F90898C8C87898F928C8F928C8C
8C8C8C8C8F8E8584
8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8F95
8E8C8C8C8C8C8C8C8F89898F958E8A8C8F8B8C8C8784898F
928F8E8C8C8C8F8C8C8C898F89898C8C8C8C87898586938E
8C958E8F8C8C8A89928F8E8A848C89898F8E8F898C8A8489
8C8F8C898C8C8C8F928C8C8C8C8C8C8F928F8E8C8C8C8C8C
8C8C8C8C8A898F92
8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8A
898C8C8C8C8C8C8C8A8C928C858687878A86848993918F8C
8C8A898C8C8C8581898F928A878F8C8C8C8C8F8C8C928A8C
9285818281898F928C8E8B878C908C8C82818289928F928C
8C8581898C8C8C8F8E8C8C8C8C8C87898C8A8987898C8C8C
878987898C87898C
8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C878987898C8F
8E8F8E8C8C8C8C87898C8C8C8F9293938E8E98938A8C928C
8C8C8F8E8C8C8F959287898C8F92878C8E87848C928C8C8C
8C8F9595959287898C8A898F958E8C8F9595958C8987898C
8F918F8F8C8C8787898C8C8C8C8C8F958E8F8E8F928C8C8C
8F928F928C8F928C
8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8A8F8F8C898A
898A898C8C8C8C8F928C8C8C8F8E8A898A898A848987898C
8C8C8A898C8C8C8C87878F8C8C8F9190848792928C8C8C8C
8C8C8C8C8C878789898C8C8C8A898C8C8C8C8C8A89878F8C
8A898F928C8C8F928C8C8C8C8C87898E8B8E8B8C87898C87
8C8E8C8C8C8C8C8C
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[34]:=",
  ImageSize->{450, 295.313},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007200019b000`400?l00000o`00003oo`3oooo3
0?ooo`00o`3oooo30?ooo`00o`3oooo30?ooo`00o`3oooo30?ooo`00o`3oooo30?ooo`00o`3oooo3
0?ooo`00o`3oooo30?ooo`00o`3oooo30?ooo`00o`3oooo30?ooo`00o`3oooo30?ooo`00803oool0
2P27QhL0R8R808N7Q`22PX80R8R808J6QP27QhL0SXj>08V9R@1cLg<208N7Q`0308R8R023Ph<0QhN7
00<0QhN700X0Ph>304U9B@2`/;00SXj>0861P@27QhL0SHf=08N7Q`21PH40SXj>0P28R8P01P21PH40
QhN708f=S@27QhL0Rh^;08B4Q0@0QhN700D0Ogmo092@T027QhL0QhN708f=S@0508N7Q`0608F5Q@22
PX80QhN708Z:RP2;Rh/0PX:21P27QhL01P28R8P0QhN708J6QP29RHT0QhN708R8R080QhN700X0UiNG
096AT@1FEUH0Xj>S08N7Q`2=SHd0QhN708:2PP27QhL0S8b<1027QhL01P2=SHd0QhN708F5Q@2:RXX0
SXj>08^;R`80QhN70100PX:208f=S@22PX80QhN70820P027QhL0RXZ:08N7Q`25QHD0WYjN08N7Q`1Z
JVX0W9bL08j>SP2;Rh/0PX:27P3oool308V9R@0708>3P`29RHT0QhN708V9R@2?Shl0RXZ:07AdM003
08V9R@0308B4Q029RHT0RHV90080RHV900X0Q8B404Q8B02c/k<0Shn?08:2PP29RHT0SXj>08V9R@22
PX80Shn?0P29RHT02022PX80RHV908j>SP29RHT0SHf=08F5Q@29RHT0R8R80P29RHT01@20P800TI6A
08V9R@29RHT0Shn?00D0RHV900H0QXJ608>3P`29RHT0Rh^;08b<S023Ph<308V9R@0308R8R029RHT0
RHV90080RHV900<0QhN708Z:RP29RHT00P29RHT02`28R8P0V9RH09:BTP1FEUH0YJFU08V9R@2>SXh0
RHV908>3P`29RHT0SHf=00@0RHV900H0Shn?08R8R026QXH0Rh^;08n?S`2=SHd208V9R@0@08>3P`2>
SXh0Ph>308R8R021PH40RHV908b<S028R8P0QXJ60:2PX028R8P0JVYZ09fMW@2?Shl0S8b<08>3Pah0
oooo0`1cLg<01`1aLG40Lg=c079bLP1cLg<0MGEe07=cL`1[Jf/00`1cLg<00`1aLG40Lg=c07=cL`02
07=cL`0:075aL@1JFUX0Ph>307EeM@1`L700Lg=c07EeM@1cLg<0L71`07EeM@80Lg=c00H0L71`07=c
L`1eMGD0Lg=c07AdM01aLG4407=cL`0506m_K`1fMWH0Lg=c07=cL`1eMGD01@1cLg<00`1bLW80L71`
07=cL`0207AdM003071`L01cLg<0Lg=c00H0Lg=c00<0LW9b07=cL`1cLg<00`1cLg<02P1iNGT0MWIf
061PH01nOWh0Lg=c07EeM@1cLg<0LG5a07=cL`1eMGD407=cL`0607EeM@1cLg<0LW9b07AdM01eMGD0
M7Ad0P1cLg<01`1aLG40MGEe075aL@1cLg<0L71`07=cL`1dM7@00P1bLW801`1kNg/0Lg=c06MWI`1k
Ng/0MGEe07AdM01aLG408P3oool00200oooo00D0QhN708R8R02;Rh/0RHV908N7Q`020861P@0408f=
S@23Ph<0Lg=c07EeM@H0QhN700X0R8R809NGU`19BDT0W9bL08b<S022PX80QhN708R8R02=SHd0QhN7
0P2=SHd01P27QhL0PX:20861P@27QhL0S8b<08^;R`@0QhN700D0Shn?07moO`28R8P0SXj>08R8R002
08f=S@0908Z:RP2;Rh/0SHf=08f=S@25QHD0QhN708:2PP2:RXX0SHf=0080QhN700<0QHF508N7Q`27
QhL01027QhL00`26QXH0QhN708V9R@0308N7Q`0509JFUP2PX:00CDe=09FEU@2VYZH00P27QhL00`22
PX80QhN708b<S00208b<S080QXJ600D0Rh^;08N7Q`28R8P0QhN7096AT@0308f=S@80QhN700h0PX:2
08N7Q`1oOgl0P82008>3P`27QhL0P82008:2PP21PH40OGem09:BTP2>SXh0Rh^;08N7Qah0oooo00/0
RHV908Z:RP26QXH0QXJ608b<S029RHT0QhN708^;R`28R8P0P82008:2PP0208V9R@0308J6QP29RHT0
RHV90080R8R80180S8b<05EEE@2/[:`0SXj>08>3P`28R8P0RHV908N7Q`25QHD0S8b<08^;R`29RHT0
QXJ608Z:RP29RHT0Rh^;08f=S@26QXH208R8R00308>3P`29RHT0QHF50080RXZ:00X0RHV908Z:RP29
RHT0QhN708J6QP27QhL0Rh^;08B4Q029RHT0QXJ60P29RHT01@25QHD0RXZ:08R8R029RHT0R8R800@0
RHV90180R8R808V9R@25QHD0RHV908R8R029RHT0SXj>09:BTP1LG5`0S8b<09RHV02<S8`0RHV908>3
P`29RHT0RXZ:08N7Q`2;Rh/208V9R@0608f=S@26QXH0RHV908R8R02=SHd0RXZ:0P27QhL208V9R@0>
08>3P`29RHT0QHF508^;R`29RHT0Rh^;09JFUP2IVIT0NGUi07QhN02DU9@0Shn?08V9R@25QHDN0?oo
o`0>07=cL`1dM7@0Jf][06i^KP1hN7P0Ng]k07MgM`1aLG40MgMg07alO01mOGd0M7Ad07=cL`1_Kfl2
07=cL`80LW9b0180IVIV06e]K@2?Shl0MWIf071`L01cLg<0LW9b06][J`1^KVh0LG5a071`L01cLg<0
MWIf07]kN`1dM7@0LG5a07EeM@1`L702079bLP0@06][J`1ZJVX0MWIf07EeM@1_Kfl0LW9b06m_K`1]
KFd0KVi^06a/K01ZJVX0L71`06m_K`1cLg<0MWIf075aL@80KFe]00<0MGEe07AdM01cLg<01@1cLg<0
4P1dM7@0Lg=c06a/K01cLg<0LW9b07=cL`1[Jf/0IVIV079bLP1YJFT0J6QX07QhN01cLg<0LG5a07=c
L`1`L700K6a/075aL@<0MGEe00D0Kfm_07=cL`1cLg<0KVi^06m_K`0206][J`80Lg=c00h0L71`07=c
L`1gMgL0OWin07QhN01gMgL0SXj>092@T01TI6@0IVIV07MgM`1eMGD0Kfm_06i^KR80oooo000P0?oo
o`0408V9R@2:RXX0QhN708N7Q`80SHf=0P27QhL01@28R8P0PH6106m_K`1cLg<0QhN70080R8R800d0
RXZ:08N7Q`27QhL0UiNG069RHP1cLg<0_Kfm08R8R025QHD0QhN708b<S027QhL0Ph>30080QhN700H0
R8R808N7Q`23Ph<0SXj>09BDU024Q8@208N7Q`0>08B4Q027QhL0SXj>08b<S02ATI40TY:B08b<S02;
Rh/0RXZ:08B4Q027QhL0SHf=08N7Q`2>SXh208N7Q`0508>3P`22PX80QXJ608F5Q@22PX801P27QhL0
0`26QXH0PX:208N7Q`0308N7Q`0A09JFUP1_Kfl0BTY:07QhN02b/[80SHf=08N7Q`22PX80Ph>308N7
Q`2=SHd0R8R808j>SP2;Rh/0Ph>308R8R023Ph<00P28R8P00`27QhL0Ph>308N7Q`0208>3P`0308J6
QP27QhL0QXJ60080Ph>300P0TY:B09>CT`1^KVh0NGUi08R8R02EUID0RHV908>3Pah0oooo00P0R8R8
08V9R@28R8P0RHV908Z:RP27QhL0QHF508R8R080RHV90P21PH4208R8R00N08N7Q`29RHT0R8R808J6
QP2FUYH0NWYj071`L02KVi/0QhN708R8R023Ph<0RXZ:08b<S02:RXX0S8b<08R8R029RHT0R8R808>3
P`29RHT0T92@08N7Q`28R8P0QXJ608B4Q02:RXX0QHF508B4Q02:RXX0RHV90P2:RXX01`29RHT0QXJ6
08V9R@2;Rh/0QHF508^;R`25QHD00P2;Rh/308Z:RP0308J6QP28R8P0RHV900@0RHV901`0QhN708R8
R029RHT0R8R808V9R@28R8P0SXj>07moO`28R8P0OWin09FEU@27QhL0QHF508V9R@27QhL0RHV908j>
SP25QHD0Rh^;08f=S@27QhL0Rh^;08N7Q`2;Rh/0RHV908^;R`2:RXX0Rh^;0P24Q8@03@28R8P0RHV9
08R8R027QhL0T92@09:BTP2=SHd0MgMg08>3P`2:RXX0T92@08^;R`27QhL07P3oool01`1aLG40L71`
079bLP1dM7@0L71`06][J`1^KVh00P1cLg<00`1kNg/0PX:207inOP02079bLP0?071`L01aLG40LW9b
071`L01eMGD0QhN706EUI@1EEED0Kfm_07AdM01[Jf/0LG5a07QhN01jNWX0MgMg00<0Lg=c00d0L71`
06a/K01_Kfl0MGEe07=cL`1_Kfl0L71`07AdM01VIVH0J6QX06YZJP1YJFT0L71`0080LG5a00h0LW9b
07=cL`1`L700KFe]06m_K`1]KFd0MgMg07YjNP1kNg/0MWIf07MgM`1fMWH0Lg=c07AdM0D0Lg=c00<0
MgMg07=cL`1cLg<00P1cLg<03@1[Jf/0P8200;>c/`1eMGD0EeMG06][J`1^KVh0NWYj07EeM@1cLg<0
MGEe06e]K@1_Kfl00P1eMGD02@1fMWH0M7Ad07IfMP1cLg<0MgMg07YjNP1gMgL0L71`079bLP0307Ad
M00:07EeM@22PX80MGEe06e]K@1eMGD0Ng]k07AdM01_Kfl0MGEe07IfMR80oooo000P0?ooo`0A08R8
R027QhL0SHf=08J6QP27QhL0Rh^;08B4Q02=SHd0Ph>308:2PP23Ph<0QXJ60861P@1`L700PX:208>3
P`22PX800P27QhL01P2EUID0O7al06ATI02FUYH0QXJ607inOP<0QhN700/0PX:208j>SP28R8P0QhN7
0861P@22PX80QhN708R8R02=SHd0QhN708b<S0030861P@0807inOP22PX80S8b<08f=S@28R8P0T92@
08n?S`2@T90208N7Q`0508^;R`2ATI40SHf=08N7Q`2ATI400P23Ph<01@2:RXX0QhN708^;R`25QHD0
R8R80080Q8B400`0QhN708B4Q023Ph<0Ph>308N7Q`23Ph<0S8b<0:2PX02ATI40BTY:09VIV@2EUID2
08B4Q0<0QhN701D0Q8B408N7Q`24Q8@0QhN708:2PP27QhL0Rh^;08J6QP27QhL0Ph>308N7Q`23Ph<0
PX:208f=S@1mOGd0Q8B407alO027QhL0JVYZ092@T01fMWH00P27QhL00`1mOGd0QhN70?ooo`0M0?oo
o`0I08R8R029RHT0RXZ:08R8R02:RXX0R8R808B4Q02?Shl0QhN708Z:RP27QhL0Rh^;08N7Q`20P800
RHV908R8R026QXH0Rh^;08b<S02KVi/0Q8B406][J`2HV9P0RXZ:08:2PP0208V9R@0?08b<S026QXH0
Rh^;08R8R029RHT0QXJ608Z:RP2=SHd0QHF508N7Q`25QHD0SHf=08J6QP2=SHd0RXZ:0080QXJ600<0
SHf=08^;R`24Q8@00P26QXH00`2<S8`0RHV908V9R@0208Z:RP0=08R8R025QHD0Shn?08N7Q`24Q8@0
RXZ:08R8R02:RXX0R8R808^;R`29RHT0QhN708R8R00208V9R@0908N7Q`2;Rh/0QhN708Z:RP2BTY80
S8b<05eMG@2NWYh0SXj>00<0RHV900l0QXJ608V9R@29RHT0Rh^;08R8R02<S8`0QhN708^;R`2=SHd0
QhN708V9R@27QhL0RHV908Z:RP25QHD00P2ATI402P2DU9@0Rh^;09:BTP1dM7@0VYZJ07IfMP25QHD0
Shn?08R8R02;Rh/N0?ooo`03079bLP1dM7@0L71`0080M7Ad00/0KVi^071`L01fMWH0MGEe07YjNP1f
MWH0N7Qh07MgM`1oOgl0NGUi07MgM`0207IfMP0607QhN01nOWh0NGUi06m_K`1jNWX0MWIf0`1cLg<0
501hN7P0MWIf06m_K`1bLW80Lg=c07IfMP1kNg/0NGUi06i^KP1[Jf/0KVi^07EeM@1fMWH0Ogmo07al
O01jNWX0MWIf07AdM01`L700Jf][0P1VIVH04P1^KVh0Lg=c07AdM01bLW80JVYZ06a/K01]KFd0LG5a
07EeM@1`L700LG5a079bLP1aLG40M7Ad07IfMP1hN7P0MGEe07=cL`80N7Qh00T0MGEe07MgM`1eMGD0
L71`06IVIP1]KFd0MWIf07moO`1[Jf/00P1hN7P01`1cLg<0L71`07=cL`1hN7P0MWIf07EeM@1hN7P0
0P1fMWH04`1eMGD0LW9b07=cL`1eMGD0Lg=c07UiN@1dM7@0NGUi08V9R@27QhL0PX:20861P@1dM7@0
Ph>306YZJP1^KVh0O7al07emO@1fMWH08P3oool00200oooo00@0QhN708V9R@2:RXX0Rh^;0P29RHT0
3@26QXH0QhN708^;R`2;Rh/0RHV908N7Q`22PX80M7Ad079bLP20P800Ph>308F5Q@29RHT00P2GUiL0
2@1TI6@0MGEe08R8R01mOGd0PX:208>3P`2=SHd0QhN708R8R00208N7Q`80SHf=00D0R8R808f=S@27
QhL0QhN708j>SP0308N7Q`0908>3P`1mOGd0P820096AT@29RHT0Q8B408V9R@27QhL0SXj>00<0QhN7
00@0SHf=08N7Q`2;Rh/0Rh^;0P28R8P02026QXH0RHV908:2PP27QhL0QXJ608B4Q023Ph<0Rh^;0P27
QhL05@2;Rh/0QhN708B4Q02<S8`0X:2P075aL@1QHF40SXj>08^;R`27QhL0Ph>308B4Q027QhL0R8R8
08F5Q@26QXH0QhN708J6QP27QhL0SHf=08b<S00208N7Q`0?08>3P`2=SHd0RHV909NGU`2FUYH0R8R8
09^KV`2FUYH0S8b<09:BTP1]KFd0QhN708^;R`26QXH0Q8B401h0oooo00L0RHV908Z:RP2;Rh/0RHV9
08J6QP29RHT0RXZ:0080R8R800X0QXJ608V9R@2<S8`0Q8B408:2PP23Ph<0QXJ608N7Q`2:RXX0S8b<
0P2>SXh04P1jNWX0S8b<08^;R`22PX80RXZ:08N7Q`2;Rh/0RHV908f=S@29RHT0QHF508N7Q`2;Rh/0
QHF508N7Q`29RHT0QhN708j>SP80RHV900D0R8R808N7Q`28R8P0QhN708Z:RP0208J6QP0308j>SP2:
RXX0Rh^;00<0RHV900X0Rh^;08J6QP2>SXh0Q8B408F5Q@2;Rh/0QhN708Z:RP27QhL0S8b<0P28R8P0
4P29RHT0RXZ:08J6QP26QXH0RXZ:08J6QP27QhL0RXZ:09:BTP20P800PH6108^;R`2:RXX0RHV908N7
Q`28R8P0Rh^;08Z:RP80RHV900@0RXZ:08N7Q`2:RXX0RXZ:0`29RHT00`24Q8@0QXJ608:2PP0209BD
U00808Z:RP29RHT0PH6107moO`2GUiL0LG5a09:BTP2>SXh208J6QQh0oooo0`1cLg<0901_Kfl0KFe]
079bLP1gMgL0LW9b06i^KP1[Jf/0LW9b07MgM`1bLW80OWin0861P@1gMgL0MGEe07QhN01fMWH0JFUY
06][J`24Q8@0Rh^;07IfMP1eMGD0NWYj07EeM@1`L700Lg=c07QhN01dM7@0KVi^06YZJP1`L700KFe]
06a/K01cLg<0LG5a07AdM0<0Lg=c00T0MWIf07emO@1hN7P0JVYZ06i^KP1cLg<0NGUi07EeM@1_Kfl0
0`1cLg<2071`L00<07IfMP1WIfL0KVi^07EeM@1bLW80Lg=c07MgM`1hN7P0M7Ad07EeM@1hN7P0LG5a
0P1`L7002P1bLW80Kfm_07EeM@1`L700IVIV07inOP2ATI40Kfm_079bLP1dM7@207EeM@0907IfMP1e
MGD0MWIf07IfMP1dM7@0LW9b07AdM01_Kfl0L71`0080Lg=c00@0LG5a06QXJ01WIfL0Lg=c0P1dM7@0
2@1OGel0FEUI061PH01lO7`0KFe]0861P@1gMgL0L71`07=cL`0R0?ooo`00803oool01`27QhL0RHV9
08B4Q022PX80RHV908B4Q02>SXh00P24Q8@308N7Q`0A08V9R@24Q8@0N7Qh06m_K`1eMGD0Ph>308:2
PP23Ph<0TI6A092@T01_Kfl0Ph>308:2PP21PH40OWin08:2PP28R8P00P2>SXh01028R8P0QhN709:B
TP2BTY8208f=S@0508N7Q`2BTY80QhN708B4Q023Ph<00P24Q8@02@1iNGT0OWin08f=S@22PX80SXj>
08J6QP2ATI40SXj>092@T00208R8R080RXZ:00<0QhN708b<S02;Rh/00`2;Rh/00`2=SHd0QhN708R8
R00208^;R`<0R8R800P0QhN708V9R@27QhL0S8b<0:6QX@1hN7P0HF5Q08f=S@80Rh^;00<0R8R808^;
R`2;Rh/00P27QhL00`29RHT0QXJ608V9R@0408N7Q`0?08f=S@2DU9@0U9BD09FEU@27QhL0U9BD092@
T023Ph<0R8R809NGU`1nOWh0UiNG08N7Q`29RHT0PH6101h0oooo00L0RHV908f=S@2;Rh/0QHF508f=
S@26QXH0Rh^;0080QHF500P0Rh^;08f=S@25QHD0RHV908N7Q`25QHD0QXJ608F5Q@80RHV900@0Rh^;
092@T02>SXh0NGUi0P27QhL01029RHT0QHF508Z:RP29RHT208N7Q`80QHF50P26QXH208Z:RP0A08F5
Q@2ATI40RHV908Z:RP29RHT0RXZ:08^;R`23Ph<0QHF508j>SP25QHD0SXj>08:2PP2<S8`0QHF508^;
R`28R8P00P29RHT00`26QXH0QHF508Z:RP0208N7Q`0308R8R026QXH0Rh^;00<0QhN700<0RHV908J6
QP28R8P00P28R8P01`27QhL0RHV908V9R@2EUID0Ph>308R8R02;Rh/00P27QhL02026QXH0S8b<08^;
R`29RHT0QhN708V9R@27QhL0SHf=0P2;Rh/04@29RHT0PX:208B4Q021PH40Rh^;09nOW`2;Rh/0T92@
08n?S`24Q8@0S8b<08f=S@1dM7@0WinO08R8R02;Rh/0QHF501h0oooo0180Lg=c07MgM`1kNg/0Lg=c
07MgM`1cLg<0Kfm_075aL@1bLW80MWIf07UiN@1^KVh0LW9b07EeM@1nOWh0RXZ:0861P@1hN7P207Yj
NP80LW9b00/0MgMg07IfMP1fMWH0NWYj07QhN01jNWX0LW9b06][J`1YJFT0KFe]06i^KP0206ATI003
06m_K`1^KVh0KFe]0080Lg=c0`1hN7P207YjNP0807QhN01eMGD0M7Ad07AdM01ZJVX0KFe]06MWI`1^
KVh2079bLP05075aL@1/K6`0KFe]071`L01/K6`00P1]KFd01`1[Jf/0L71`075aL@1_Kfl0KFe]071`
L01_Kfl00`1bLW801`1_Kfl0Lg=c06m_K`1YJFT0Ng]k09ZJVP1`L7000P1]KFd01@1_Kfl0Lg=c07=c
L`1cLg<0LG5a0080LW9b0`1gMgL0201cLg<0JVYZ06IVIP1KFe/0JFUY08>3P`1gMgL0L71`0P1bLW80
1@1gMgL0JFUY05mOG`22PX80LW9b0080MGEe8P3oool00200oooo00/0QhN708f=S@2;Rh/0Q8B408^;
R`21PH40QhN708B4Q026QXH0SXj>08f=S@0408N7Q`0408>3P`1gMgL0NGUi08:2PP80Ph>300@0TY:B
08>3P`1`L700/K6a0`26QXH308N7Q`0308R8R02=SHd0QhN70080QhN700D0Rh^;08N7Q`2BTY80SXj>
08^;R`0208N7Q`0308Z:RP21PH40OGem0080Rh^;00@0SHf=08R8R02;Rh/0RHV90`2BTY8208j>SP04
08R8R02>SXh0SXj>08f=S@80SXj>00D0S8b<08f=S@2>SXh0RXZ:08R8R00608j>SP0=08J6QP2GUiL0
YZJV08j>SP28R8P0RHV908R8R027QhL0Rh^;08f=S@29RHT0QXJ608V9R@0208N7Q`<0S8b<0100R8R8
08b<S027QhL0UIFE09bLW02;Rh/0X:2P096AT@2<S8`0TY:B08>3P`21PH40XJ6Q08J6QP2>SXh0QhN7
7P3oool03@29RHT0Rh^;08R8R025QHD0SXj>08B4Q02=SHd0QXJ608B4Q02<S8`0QhN708V9R@2:RXX0
0P29RHT03P25QHD0PX:208N7Q`29RHT0Rh^;08V9R@2?Shl0QhN70820P02HV9P0QHF508J6QP25QHD0
QXJ60P28R8P02P23Ph<0Q8B408V9R@2<S8`0RHV908Z:RP26QXH0T92@08^;R`2:RXX208V9R@0?08^;
R`22PX80Ogmo08Z:RP26QXH0R8R808F5Q@2=SHd0QXJ608^;R`26QXH0RHV908N7Q`28R8P0QHF50080
QhN700P0QXJ608^;R`2:RXX0RHV908B4Q027QhL0RHV908B4Q0@0QhN700H0R8R808Z:RP24Q8@0Rh^;
09BDU028R8P308V9R@0K08R8R02:RXX0S8b<08V9R@27QhL0RHV908^;R`2<S8`0RXZ:08N7Q`23Ph<0
Ogmo07UiN@26QXH0VYZJ09VIV@1mOGd0Ogmo08b<S023Ph<0Shn?08B4Q020P800Xj>S08J6QP2;Rh/0
QHF501h0oooo00d0Lg=c071`L01^KVh0LG5a07MgM`1cLg<0NGUi07=cL`1]KFd0L71`06][J`1cLg<0
M7Ad0080Lg=c00`0LW9b07]kN`21PH40NWYj07]kN`1hN7P0L71`07EeM@20P800GEeM071`L01aLG42
06m_K`80Lg=c00X0JVYZ06IVIP1cLg<0N7Qh07=cL`1aLG40Kfm_079bLP1_Kfl0LG5a0P1cLg<0101d
M7@0LG5a075aL@1aLG4206a/K00=06i^KP1eMGD0KFe]06][J`1TI6@0J6QX06YZJP1/K6`0KFe]06YZ
JP1[Jf/0JVYZ06i^KP0206m_K`0406IVIP1ZJVX0L71`06a/K0@0JVYZ00`0Jf][06m_K`1^KVh0IfMW
069RHP1/K6`0LW9b075aL@1bLW80Lg=c079bLP1aLG43079bLP0E07MgM`1hN7P0LG5a06e]K@1WIfL0
I6AT05QHF01_Kfl0O7al07EeM@1NGUh0Bd];06i^KP1VIVH0LG5a079bLP1]KFd0OGem075aL@1_Kfl0
KVi^0280oooo000P0?ooo`0M08N7Q`28R8P0RHV908B4Q027QhL0Q8B408f=S@27QhL0Q8B408:2PP26
QXH0SHf=08Z:RP2;Rh/0QhN708B4Q027QhL0NWYj07UiN@1mOGd0Ng]k07QhN023Ph<0MgMg07AdM02A
TI40RHV90861P@23Ph<00P27QhL01@21PH40OWin08Z:RP23Ph<0PX:20080OGem00<0QXJ609:BTP2;
Rh/00P27QhL02@2:RXX0Q8B407]kN`1nOWh0QXJ608:2PP1nOWh0RXZ:08:2PP0208>3P`80S8b<00/0
UiNG09:BTP2FUYH0Ti>C09:BTP2HV9P0W9bL09NGU`2BTY80UYJF09NGU`0409:BTP80R8R800`0SXj>
08R8R02<S8`0Vi^K0::RXP22PX80Ph>309ZJVP2/[:`0V9RH09:BTP2=SHd208^;R`80SHf=00`0Ph>3
08N7Q`27QhL0Y:BT08R8R023Ph<0UiNG0:2PX027QhL0N7Qh08j>SP27QhL208>3P`0508N7Q`2ATI40
QXJ608J6QP29RHT07P3oool02`29RHT0S8b<08^;R`29RHT0Rh^;08B4Q02:RXX0QXJ608^;R`29RHT0
R8R800<0RXZ:00H0RHV908B4Q02;Rh/0Ph>308Z:RP2;Rh/208f=S@0808n?S`23Ph<0Ti>C08R8R029
RHT0QHF508N7Q`29RHT208J6QP0508N7Q`2@T900RXZ:08f=S@2;Rh/00P28R8P00`2=SHd0S8b<08V9
R@0208V9R@0H08N7Q`24Q8@0Q8B408^;R`2=SHd0QXJ608f=S@29RHT0RXZ:08N7Q`2:RXX0Ph>308N7
Q`1oOgl0R8R808J6QP25QHD0R8R808V9R@24Q8@0Ph>308N7Q`25QHD0PX:20P26QXH04P2<S8`0QXJ6
08R8R02:RXX0PX:208N7Q`2?Shl0PX:208Z:RP1lO7`0N7Qh08b<S02;Rh/0S8b<08R8R026QXH0RXZ:
08^;R`80QhN700l0QHF506m_K`22PX80PX:208R8R02@T900TY:B08:2PP20P800Rh^;092@T02>SXh0
OGem08n?S`2MWId00`28R8PN0?ooo`0<07=cL`1gMgL0MGEe07QhN01fMWH0L71`06m_K`1`L700NGUi
07QhN01dM7@0Kfm_0P1aLG406`1cLg<0L71`07IfMP1jNWX0Q8B408:2PP26QXH0RXZ:0861P@1mOGd0
UYJF06MWI`1aLG40M7Ad07EeM@1cLg<0Kfm_07IfMP1kNg/0NWYj07UiN@20P800PX:207inOP1cLg<0
KVi^07AdM00207=cL`08075aL@1eMGD0NGUi07MgM`1hN7P0P82007YjNP1fMWH207YjNP0?07EeM@1`
L700IVIV061PH01JFUX0HF5Q06=SH`1RHV80H61P05iNGP1KFe/0GemO065QH@1MGEd0GemO0080I6AT
01h0KFe]06m_K`1bLW80Kfm_06UYJ@1/K6`0J6QX04e=C@1jNWX0IFEU04M7A`1@D500I6AT06e]K@1/
K6`0Jf][075aL@1`L700Jf][07EeM@1]KFd0Cdm?04];B`1XJ6P0N7Qh06e]K@1VIVH0JVYZ07MgM`1^
KVh207moO`0306MWI`1lO7`0QHF50080Lg=c00<0L71`0?ooo`3oool0803oool00200oooo0140SXj>
08Z:RP23Ph<0SHf=08^;R`2>SXh0RHV908N7Q`23Ph<0RHV908J6QP23Ph<0QhN708B4Q02;Rh/0PX:2
08^;R`0208B4Q00=08N7Q`2;Rh/0QhN708V9R@23Ph<0QXJ606MWI`1cLg<0Zj^[09:BTP2ATI40R8R8
08N7Q`020861P@0>07emO@2;Rh/0RHV908N7Q`22PX80Rh^;08N7Q`2=SHd0Rh^;08f=S@27QhL0Q8B4
07moO`23Ph<608N7Q`0<08>3P`27QhL0Rh^;0861P@1nOWh0PH6107inOP23Ph<0QXJ608:2PP1nOWh0
Ph>30P26QXH308N7Q`0507inOP27QhL0S8b<08:2PP2<S8`00P22PX801`29RHT0TI6A08^;R`22PX80
>3Ph06m_K`2DU9@00P2ZZZX0302MWId0WYjN07emO@27QhL0SHf=09:BTP2LW9`0QhN709>CT`1^KVh0
RHV909:BTP80S8b<00@0PX:207emO@28R8P0U9BD0P2>SXh00`29RHT0oooo0?ooo`0L0?ooo`0<08N7
Q`26QXH0Ph>308^;R`26QXH0R8R808N7Q`29RHT0QhN708Z:RP2;Rh/0RXZ:0P29RHT02@2>SXh0Q8B4
08f=S@25QHD0Q8B408V9R@2;Rh/0QHF508^;R`0208J6QP0506QXJ01cLg<0WIfM07]kN`2BTY800P28
R8P04@26QXH0Rh^;08F5Q@2=SHd0RXZ:08V9R@23Ph<0S8b<08V9R@2;Rh/0QXJ608^;R`27QhL0RHV9
08F5Q@27QhL0RHV900<0S8b<0P29RHT00`27QhL0RHV908f=S@0208V9R@0308f=S@25QHD0RHV900<0
Rh^;00<0RXZ:08R8R027QhL00P2<S8`07029RHT0QHF508J6QP2:RXX0Ph>308j>SP26QXH0Rh^;08R8
R02<S8`0R8R808J6QP1_Kfl0NWYj0820P022PX80R8R807MgM`1bLW80PH6108b<S02HV9P0U9BD09JF
UP20P800Y:BT07moO`29RHT208n?S`0609jNWP1lO7`0R8R809>CT`2DU9@0RXZ:0P29RHTN0?ooo`04
06UYJ@1/K6`0L71`075aL@80Jf][00d0Kfm_07=cL`1eMGD0Lg=c07QhN01jNWX0M7Ad07IfMP1gMgL0
LW9b07IfMP1aLG40L71`0080Lg=c00D0KVi^07EeM@1dM7@0LG5a06QXJ00206YZJP0805ADE01fMWH0
LW9b079bLP1fMWH0OGem07QhN01dM7@207=cL`0;071`L01dM7@0Lg=c071`L01[Jf/0L71`075aL@1h
N7P0MgMg07EeM@1cLg<00`1gMgL207=cL`0707EeM@1cLg<0MGEe07YjNP1nOWh0Ogmo07UiN@0207Qh
N00507]kN`21PH40NWYj07AdM01bLW800P1hN7P01@1cLg<0N7Qh06m_K`1`L700LW9b0080MWIf01l0
O7al075aL@1]KFd0KFe]07EeM@2TY:@0N7Qh05UIF@14A4@0CDe=0492@P0j>SX0M7Ad07QhN023Ph<0
MgMg075aL@1WIfL0SHf=0820P01aLG40L71`07IfMP2<S8`0IfMW07emO@21PH40M7Ad06i^KP1]KFd0
LW9b0280oooo000P0?ooo`0<0861P@22PX80QhN708B4Q026QXH0PX:208B4Q02:RXX0QXJ608B4Q02;
Rh/0QhN70P29RHT01@2;Rh/0QhN708N7Q`29RHT0PX:20080Q8B400X0QhN708f=S@29RHT0QhN706YZ
JP1/K6`0NGUi09JFUP2DU9@0Xj>S0P27QhL02P2<S8`0PH6108R8R029RHT0SHf=08:2PP27QhL0R8R8
08N7Q`28R8P308^;R`<0Ph>30P2<S8`408N7Q`0308>3P`27QhL0Shn?0080S8b<00T0PX:20861P@29
RHT0S8b<08f=S@2;Rh/0QhN708:2PP2?Shl01027QhL02`2<S8`0Ph>308f=S@27QhL0SXj>08:2PP28
R8P0QhN7096AT@2?Shl0LG5a0080GemO00<0NWYj0:6QX@2EUID00P27QhL208j>SP0?0::RXP28R8P0
YjNW07AdM02LW9`0UYJF0::RXP2FUYH0NGUi09^KV`1`L700S8b<08N7Q`26QXH0SHf=01h0oooo00`0
RXZ:08N7Q`28R8P0QhN708Z:RP2;Rh/0QXJ608V9R@28R8P0RHV908b<S025QHD208V9R@0M08Z:RP29
RHT0QhN708V9R@27QhL0Rh^;08J6QP27QhL0RXZ:08F5Q@27QhL0K6a/08:2PP1oOgl0S8b<0861P@2C
Ti<0RHV908J6QP2:RXX0P82008^;R`27QhL0Rh^;08F5Q@2;Rh/0RHV908R8R029RHT00`2:RXX00`24
Q8@0QhN708N7Q`0208Z:RP@0RHV900h0QhN708V9R@29RHT0QhN708Z:RP26QXH0RXZ:08V9R@2:RXX0
QHF508N7Q`2<S8`0Q8B408n?S`<0RHV902@0QXJ608f=S@23Ph<0SXj>08B4Q02;Rh/0QXJ608b<S024
Q8@0R8R808F5Q@1mOGd0R8R808^;R`1_Kfl0N7Qh08b<S025QHD0TY:B096AT@27QhL0SXj>08^;R`2Y
ZJT0Hf=S08Z:RP2BTY80X:2P08n?S`1fMWH0Xj>S08B4Q02IVIT0S8b<08V9R@2?ShlN0?ooo`0<07al
O01gMgL0Lg=c07EeM@1gMgL0O7al07=cL`1`L700M7Ad07MgM`1dM7@0KVi^0P1bLW806P1aLG40Lg=c
075aL@1bLW80MWIf07UiN@1cLg<0LG5a06m_K`1/K6`0L71`06YZJP26QXH0MGEe06QXJ01KFe/0I6AT
07=cL`1`L700LG5a06e]K@1fMWH0KVi^071`L01dM7@0MWIf0P1bLW800`1cLg<0LG5a075aL@02075a
L@80MGEe0P1`L70407=cL`0>07EeM@1cLg<0JVYZ06a/K01`L700MWIf07]kN`1bLW80Kfm_06QXJ01]
KFd0MgMg07=cL`1dM7@307=cL`0T06m_K`1eMGD0L71`07AdM01]KFd0Kfm_07IfMP1hN7P0KFe]06UY
J@1VIVH0NWYj09fMW@2QXJ40GUiN0410@01YJFT0KVi^0820P01hN7P0JVYZ05mOG`1eMGD0Ogmo059B
DP1NGUh0L71`07QhN01]KFd0IfMW08>3P`25QHD0QXJ607MgM`1eMGD0MWIf8P3oool00200oooo00d0
SHf=08N7Q`27QhL0QhN708f=S@27QhL0QXJ608>3P`27QhL0RHV908N7Q`22PX80Rh^;0080Q8B400<0
QhN708:2PP2<S8`00P27QhL03`26QXH0QhN708J6QP24Q8@0QXJ606m_K`22PX80IVIV08N7Q`1iNGT0
/[:b0<30`02=SHd0QhN708:2PP0208N7Q`80RHV900<0Rh^;08N7Q`27QhL00P28R8P208^;R`80QhN7
0P23Ph<608N7Q`0807moO`27QhL0QhN708b<S027QhL0S8b<08>3P`28R8P208N7Q`0308b<S026QXH0
SHf=00<0QhN700P0Rh^;08N7Q`22PX80S8b<08J6QP2<S8`0QhN708f=S@80QhN700H0R8R80::RXP2W
YjL0[jn_0861P@1jNWX208f=S@0=08N7Q`2<S8`0R8R808N7Q`2<S8`0Y:BT06e]K@2<S8`0UiNG09RH
V027QhL0PH6109^KV`0208N7Q`0308f=S@22PX80QhN701h0oooo01D0QhN708V9R@28R8P0QHF508j>
SP25QHD0R8R808^;R`28R8P0RHV908^;R`24Q8@0RXZ:08^;R`29RHT0Rh^;08>3P`2;Rh/0RHV908J6
QP24Q8@00P29RHT04@28R8P0QhN707=cL`26QXH0LG5a08R8R01_Kfl0QXJ609RHV02:RXX0RHV908B4
Q027QhL0R8R808Z:RP25QHD0RXZ:00<0RHV900P0R8R808b<S02:RXX0QXJ608V9R@27QhL0RXZ:08b<
S080RHV900P0R8R808V9R@29RHT0Ph>308^;R`29RHT0SHf=08J6QP<0QhN702X0RHV908^;R`2:RXX0
Q8B4092@T029RHT0R8R808V9R@2=SHd0S8b<08>3P`2;Rh/0QHF508j>SP25QHD0QhN708F5Q@28R8P0
PX:207moO`1bLW80KVi^06a/K02?Shl0TY:B09BDU02<S8`0RXZ:08V9R@2CTi<0S8b<09^KV`1YJFT0
TI6A09FEU@2RXZ80R8R808B4Q02QXJ40RHV908f=S@2?Shl208Z:RQh0oooo00P0Jf][07=cL`1bLW80
KVi^07EeM@1^KVh0M7Ad07]kN`80LW9b01X0MWIf079bLP1aLG40NGUi07QhN01fMWH0LG5a079bLP1c
Lg<0L71`06m_K`1cLg<0MGEe07IfMP1bLW80Kfm_07IfMP1eMGD0Lg=c05mOG`11@D40C4a<06m_K`1c
Lg<0LW9b071`L080Lg=c00@0K6a/079bLP1cLg<0Lg=c0P1bLW801`1dM7@0LG5a06m_K`1cLg<0MGEe
07UiN@1gMgL01P1cLg<0301fMWH0Lg=c07EeM@1_Kfl0K6a/07EeM@1_Kfl0M7Ad07IfMP1`L700KVi^
07MgM`<0Lg=c01`0MGEe07MgM`1bLW80LG5a06m_K`1fMWH0KVi^06][J`1^KVh0LW9b06UYJ@18B4P0
<C4a028R8P1ADE40RXZ:07YjNP1mOGd0N7Qh075aL@1cLg<0PX:207=cL`1^KVh0HV9R07YjNP1dM7@0
QHF50P1bLW801P20P800Lg=c07UiN@1fMWH0NWYj07AdM280oooo000P0?ooo`0=08:2PP27QhL0QhN7
08J6QP2<S8`0Ph>308f=S@27QhL0PX:208f=S@27QhL0RHV908>3P`0308N7Q`0708R8R027QhL0QhN7
08V9R@22PX80QhN708Z:RP0208N7Q`0907=cL`1iNGT0HV9R05eMG@1hN7P0NWYj0;Fe]@3AdM40QhN7
0080SHf=00@0T92@08R8R023Ph<0R8R81027QhL00`2;Rh/0QhN708N7Q`0308N7Q`80S8b<00D0SHf=
08N7Q`2<S8`0QhN708>3P`0208N7Q`0508b<S027QhL0QhN708N7Q`26QXH00`27QhL04028R8P0S8b<
08f=S@27QhL0SXj>08b<S027QhL0Ph>308N7Q`29RHT0S8b<08J6QP2<S8`0R8R8096AT@28R8P208n?
S`80QhN700X0O7al07]kN`2ATI40TY:B08N7Q`28R8P0S8b<08R8R02=SHd0Ph>30P2BTY802@2@T900
QhN708b<S02BTY80Q8B408Z:RP2<S8`0Rh^;08N7Q`0N0?ooo`80RXZ:00/0QXJ608R8R02>SXh0Ph>3
08j>SP24Q8@0Ph>308j>SP25QHD0RHV908J6QP0208V9R@0I08F5Q@26QXH0S8b<08F5Q@29RHT0QXJ6
08R8R02:RXX0Rh^;08R8R01jNWX0SHf=0820P01/K6`0Kfm_07alO02>SXh0Z:RX08>3P`2=SHd0QHF5
08b<S029RHT0R8R808^;R`0408V9R@0308Z:RP29RHT0RHV90080RHV900P0QXJ608N7Q`27QhL0Rh^;
08F5Q@2:RXX0RHV908B4Q080RHV900H0RXZ:08J6QP27QhL0Q8B408V9R@2;Rh/208V9R@0Y08Z:RP2;
Rh/0Rh^;08B4Q028R8P0T92@08V9R@24Q8@0QhN708V9R@2:RXX0PH6108Z:RP22PX80QHF507]kN`1e
MGD0MWIf08V9R@2GUiL0Rh^;08f=S@2<S8`0SHf=08^;R`2ATI40UIFE092@T02;Rh/0MGEe08n?S`2<
S8`0UYJF08>3P`2@T900Vi^K08Z:RP2;Rh/0Shn?08R8R024Q8@07P3oool03@1jNWX0M7Ad071`L01d
M7@0MGEe071`L01dM7@0KFe]075aL@1eMGD0KVi^079bLP1dM7@00P1cLg<06@1^KVh0Kfm_07MgM`1^
KVh0LW9b07AdM01bLW80LG5a07IfMP1cLg<0M7Ad08R8R02>SXh0MgMg05mOG`1_Kfl0BTY:055AD@1[
Jf/0Lg=c06MWI`1^KVh0LW9b07MgM`1fMWH0101cLg<00`1aLG40Lg=c07=cL`0207=cL`0806m_K`1/
K6`0K6a/071`L01^KVh0L71`07=cL`1aLG4207=cL`06071`L01_Kfl0LG5a06e]K@1eMGD0MWIf0P1c
Lg<01`1dM7@0LG5a071`L01/K6`0Jf][07QhN01cLg<00P1aLG40801bLW80L71`06YZJP1`L700JFUY
06ATI01OGel0D51@055AD@1cLg<0QhN708:2PP27QhL0KVi^06e]K@1gMgL0OWin0820P01lO7`0L71`
05eMG@1aLG40KFe]07emO@1[Jf/0N7Qh08:2PP1hN7P0Lg=c07MgM`1^KVh0KFe]8P3oool00200oooo
00/0SHf=08V9R@24Q8@0QXJ608j>SP22PX80QhN70861P@22PX80Rh^;08R8R00308N7Q`0608b<S027
QhL0QhN708f=S@29RHT0QhN70P26QXH04`22PX80Rh^;08V9R@1lO7`0TY:B07IfMP1RHV80QhN707al
O01hN7P0c/k>0=[JfP2FUYH0R8R808B4Q02;Rh/0QhN708^;R`2=SHd00`27QhL00`28R8P0QhN708N7
Q`0208N7Q`80Ph>30`27QhL208b<S0<0Ph>30P2;Rh/208J6QP0=08N7Q`2;Rh/0QhN708V9R@2:RXX0
RHV908n?S`21PH40QhN708b<S02>SXh0Ph>30861P@0308N7Q`0B08^;R`28R8P0R8R808R8R020P800
RXZ:08:2PP27QhL0TY:B08Z:RP1lO7`0TI6A08b<S027QhL0VIVI09fMW@2:RXX0PH610P1mOGd02@1i
NGT0UiNG092@T02:RXX0QhN708J6QP29RHT0RXZ:0861P@0N0?ooo`80QhN702L0R8R808J6QP2>SXh0
QhN708b<S023Ph<0Q8B408Z:RP29RHT0R8R808V9R@25QHD0QhN708J6QP29RHT0SHf=08V9R@2:RXX0
QHF508^;R`29RHT0Rh^;08V9R@1jNWX0U9BD07EeM@1MGEd0OWin07YjNP1fMWH0UiNG0:2PX02=SHd0
Shn?08^;R`2<S8`0QXJ608Z:RP2;Rh/00`29RHT00`26QXH0RHV908V9R@0208V9R@0508N7Q`2:RXX0
S8b<08V9R@26QXH00P2:RXX02@27QhL0RXZ:08B4Q027QhL0RXZ:08R8R029RHT0QhN708Z:RP0208N7
Q`0Y08V9R@27QhL0Shn?08>3P`2=SHd0RHV908^;R`27QhL0QXJ608Z:RP27QhL0QHF508J6QP22PX80
PH6108:2PP1cLg<0TY:B09FEU@29RHT0S8b<096AT@24Q8@0Ti>C09:BTP29RHT0TI6A08n?S`20P800
S8b<09:BTP2;Rh/0NGUi08n?S`2KVi/0U9BD08V9R@26QXH0R8R808b<S026QXH07P3oool01`1[Jf/0
Kfm_07IfMP1aLG40M7Ad07IfMP1hN7P00P1bLW801`1aLG40Lg=c079bLP1cLg<0KVi^06][J`1`L700
0P1cLg<00`1bLW80M7Ad06m_K`0207QhN00907=cL`1bLW80JVYZ07MgM`1YJFT0G5aL06EUI@1[Jf/0
JFUY0080?Cdm00L0JVYZ07]kN`1jNWX0M7Ad06m_K`1aLG40L71`00<0Lg=c00<0KVi^07=cL`1cLg<0
0P1cLg<01@1eMGD0NGUi07MgM`1cLg<0Kfm_0080L71`00L0MGEe07UiN@1aLG40KFe]075aL@1dM7@0
MGEe00<0LG5a00H0KVi^075aL@1_Kfl0Lg=c079bLP1iNGT206m_K`0607EeM@1fMWH0M7Ad075aL@1]
KFd0Jf][0`1XJ6P06@1MGEd0OGem08V9R@1cLg<0KFe]07alO01iNGT0N7Qh07alO01cLg<0K6a/06EU
I@1SHf<0Ogmo08^;R`22PX80K6a/06][J`25QHD0Ogmo07=cL`1aLG40L71`07AdM01fMWH08P3oool0
0200oooo0P29RHT01P26QXH0QhN708N7Q`26QXH0R8R808B4Q080Rh^;01`0Ph>308^;R`23Ph<0QhN7
08:2PP2;Rh/0Q8B408J6QP27QhL0Ph>308^;R`28R8P0SXj>08N7Q`24Q8@0OWin0861P@1jNWX0LW9b
08N7Q`1kNg/0NWYj07IfMP1oOgl0fMWI08f=S@21PH40U9BD0P27QhL00`2<S8`0QhN708b<S00208b<
S00408>3P`2<S8`0S8b<08>3P`80QhN700T0Ph>308J6QP2;Rh/0SXj>08b<S029RHT0Ph>308N7Q`2:
RXX00P29RHT308f=S@0608J6QP2;Rh/0T92@08n?S`2ATI40Rh^;0P27QhL0102DU9@0QhN70861P@25
QHD208N7Q`0>08f=S@2GUiL0U9BD09:BTP2IVIT0UiNG08N7Q`1/K6`0R8R808:2PP27QhL0SHf=07em
O@1gMgL208b<S00=08N7Q`2BTY80QhN70:2PX027QhL0RHV908R8R027QhL0SXj>08f=S@26QXH0SHf=
08B4Q00N0?ooo`0B08R8R02<S8`0R8R808b<S029RHT0QHF508^;R`2:RXX0R8R808Z:RP25QHD0SHf=
08F5Q@2<S8`0Q8B408f=S@25QHD0QhN70P28R8P0102:RXX0Q8B408b<S025QHD308J6QP0?0820P01e
MGD0RHV907EeM@1gMgL0O7al08F5Q@2SXj<0Shn?0820P02CTi<0QXJ608V9R@2:RXX0QXJ600@0QhN7
0P2:RXX02P24Q8@0RHV908b<S027QhL0R8R808Z:RP2;Rh/0QhN708V9R@27QhL208J6QP80R8R802@0
Rh^;08N7Q`29RHT0Q8B408V9R@2<S8`0QXJ608^;R`2:RXX0PX:20820P02<S8`0QHF50861P@25QHD0
QXJ608F5Q@20P800O7al06][J`1kNg/0YjNW09RHV024Q8@0Ng]k09nOW`2=SHd0Ph>308N7Q`25QHD0
PX:208f=S@2>SXh0R8R809JFUP29RHT209:BTP0809JFUP2?Shl0Q8B408b<S02?Shl0R8R808j>SP27
QhLN0?ooo`0A071`L01fMWH0Lg=c07MgM`1cLg<0Kfm_07EeM@1iNGT0KVi^075aL@1bLW80MGEe079b
LP1gMgL0LW9b07IfMP1aLG400P1cLg<05`1gMgL0L71`06e]K@1`L700KVi^07=cL`1iNGT0MGEe07Ad
M01]KFd0Lg=c06ATI01XJ6P0M7Ad07MgM`11@D40MGEe06i^KP1dM7@0Kfm_07=cL`1`L700Kfm_00<0
K6a/00l0MGEe071`L01`L700LG5a07=cL`1gMgL0MGEe07AdM01`L700Kfm_06a/K01bLW80MGEe06m_
K`1/K6`00`1`L7006P1ZJVX0KFe]06i^KP1_Kfl0KVi^06MWI`1/K6`0LG5a06YZJP1WIfL0JVYZ06e]
K@1_Kfl0L71`06m_K`1]KFd0HF5Q051@D00l?3`0E5AD08^;R`1hN7P0KFe]07emO@2BTY80P8200P1[
Jf/03`1hN7P0Ng]k07AdM01fMWH0LW9b07]kN`1dM7@0IVIV0820P024Q8@0O7al06e]K@1`L700MWIf
07=cL`0207EeMB80oooo000P0?ooo`0O08J6QP2<S8`0PX:208N7Q`22PX80RHV908B4Q027QhL0RHV9
08f=S@24Q8@0S8b<08N7Q`2;Rh/0RHV908f=S@24Q8@0Ph>308^;R`27QhL0PX:208J6QP29RHT0QhN7
08J6QP2=SHd0PH61092@T01WIfL0PX:207IfMP0207inOP0907IfMP1hN7P0n_[j08Z:RP2@T900SHf=
08^;R`2=SHd0RHV900<0QhN700<0Ph>308N7Q`27QhL00P27QhL0102<S8`0RHV908>3P`25QHD208^;
R`04092@T027QhL0Ph>308>3P`<0QXJ601X0Rh^;09:BTP2;Rh/0QXJ608N7Q`22PX80SHf=08Z:RP23
Ph<0QhN708^;R`2=SHd0RHV908>3P`27QhL0Rh^;09BDU02>SXh0NWYj08N7Q`25QHD0QhN708b<S027
QhL0SXj>08N7Q`80UiNG00D0U9BD08N7Q`1kNg/0QhN708b<S00308N7Q`0707alO027QhL0SHf=0820
P021PH40RHV908:2PP0208N7Qah0oooo00H0RHV908Z:RP29RHT0S8b<08:2PP2<S8`208^;R`0508R8
R02=SHd0Q8B408Z:RP24Q8@00P26QXH0602=SHd0QhN708V9R@2;Rh/0RHV908F5Q@28R8P0RXZ:08V9
R@24Q8@0R8R807QhN02=SHd0Fe]K08>3P`1dM7@0O7al08F5Q@22PX80OWin0;2`/026QXH0SXj>08R8
R080RXZ:00d0QXJ608V9R@29RHT0RHV908B4Q02<S8`0RHV908J6QP29RHT0RXZ:08V9R@27QhL0R8R8
0080RHV90180SHf=08J6QP26QXH0R8R808V9R@27QhL0QHF508J6QP2:RXX0RHV908F5Q@2<S8`0QXJ6
092@T028R8P0PH6108F5Q@2:RXX208F5Q@0P08>3P`25QHD0N7Qh07YjNP1lO7`0Ng]k09BDU02MWId0
S8b<08N7Q`29RHT0Ti>C08B4Q021PH40RXZ:08J6QP29RHT0Shn?08R8R02DU9@0T92@08V9R@2;Rh/0
TI6A08b<S02;Rh/0RXZ:08j>SP2?Shl0RHV908b<S029RHTN0?ooo`0:07EeM@1`L700NGUi07QhN01`
L700MgMg07UiN@1fMWH0L71`07=cL`80L71`00T0KFe]06a/K01]KFd0Lg=c07EeM@1hN7P0LW9b07=c
L`1dM7@00`1cLg<0401^KVh0K6a/06=SH`1_Kfl0EEEE071`L01XJ6P0Jf][07QhN01lO7`0M7Ad034a
<@1/K6`0LW9b06e]K@1aLG4206i^KP<0Lg=c0180LG5a07MgM`1cLg<0Kfm_07=cL`1`L700LW9b07Ee
M@1dM7@0Kfm_06i^KP1`L700Kfm_07=cL`1gMgL0MGEe079bLP1`L70206YZJP0N06m_K`1`L700N7Qh
07IfMP1gMgL0L71`06a/K01]KFd0LW9b06MWI`1/K6`0Kfm_06i^KP1GEeL0DU9B05YJFP1]KFd0Q8B4
09:BTP1hN7P0K6a/07=cL`1jNWX0KFe]05MGE`1TI6@0HV9R07=cL`29RHT0LW9b0P1mOGd02`1dM7@0
MgMg08^;R`1hN7P0L71`07alO021PH40Ng]k07UiN@1hN7P0Lg=c0280oooo000P0?ooo`0=08V9R@27
QhL0Rh^;08N7Q`21PH40QhN708b<S02;Rh/0PX:208^;R`28R8P0RXZ:08B4Q00208:2PP0608N7Q`2;
Rh/0SHf=08N7Q`2;Rh/0PX:20P26QXH04`27QhL0PX:20820P01gMgL0SHf=05ADE022PX80LW9b07Yj
NP27QhL0OWin07QhN03Ph>00m?Cd08N7Q`2=SHd0Ph>308N7Q`29RHT01@27QhL00`23Ph<0QhN708N7
Q`0308N7Q`0D08>3P`26QXH0QhN708^;R`29RHT0RXZ:08R8R029RHT0QhN708>3P`25QHD0QhN708f=
S@27QhL0U9BD08Z:RP2?Shl0SXj>07moO`2=SHd208R8R009096AT@27QhL0R8R809JFUP27QhL0X:2P
07moO`22PX80R8R80080QhN700H0R8R809>CT`1kNg/0MgMg0861P@1gMgL208N7Q`0908B4Q027QhL0
R8R808N7Q`2<S8`0TI6A08N7Q`28R8P0RXZ:00<0QhN700<0Rh^;08f=S@3oool07@3oool03P28R8P0
S8b<08Z:RP29RHT0QXJ608Z:RP28R8P0RXZ:08N7Q`2:RXX0Q8B408^;R`2:RXX0RHV90P2:RXX01@26
QXH0R8R808V9R@2<S8`0Q8B40080RHV901<0R8R808N7Q`26QXH0Ng]k096AT@1FEUH0Ph>307EeM@1m
OGd0RHV907moO`1eMGD0ZZZZ0;Jf]P28R8P0TI6A08N7Q`28R8P0RXZ:00@0RHV900<0S8b<08B4Q029
RHT00P29RHT01P2:RXX0RHV908F5Q@29RHT0Rh^;08b<S080QhN702P0QXJ608N7Q`27QhL0Ph>308R8
R02:RXX0Rh^;08>3P`2<S8`0QXJ608Z:RP2;Rh/0OWin08^;R`24Q8@0PX:208Z:RP21PH40MgMg07in
OP1bLW80TY:B08f=S@2DU9@0Rh^;08F5Q@2;Rh/0RHV909FEU@24Q8@0SHf=09BDU02:RXX0U9BD08b<
S02ATI40Ti>C08Z:RP29RHT0TI6A0P29RHT0102?Shl0SHf=08^;R`29RHT208J6QP0308Z:RP3oool0
oooo01`0oooo01D0L71`07MgM`1aLG40Lg=c07IfMP1dM7@0KFe]075aL@1gMgL0LG5a06e]K@1bLW80
N7Qh07UiN@1jNWX0M7Ad06a/K01]KFd0Lg=c07AdM01bLW800P1eMGD04P1bLW80MgMg07MgM`1aLG40
N7Qh069RHP1aLG40KVi^075aL@1cLg<0Kfm_06MWI`14A4@0?clo079bLP1iNGT0MWIf079bLPD0Lg=c
00<0MgMg075aL@1cLg<00P1cLg<01P1dM7@0Lg=c07=cL`1eMGD0MgMg07=cL`<0KVi^00P0Kfm_075a
L@1`L700M7Ad07EeM@1`L700Jf][06YZJP80K6a/00D0L71`06e]K@1`L700K6a/06UYJ@0206YZJP0<
05UIF@1DE5@0DU9B06IVIP21PH40RHV907EeM@1]KFd0MWIf079bLP1hN7P0NGUi0P2:RXX02`27QhL0
PX:207MgM`22PX80PH6107AdM01cLg<0Ng]k06UYJ@1cLg<0Ng]k0080MWIf00@0M7Ad071`L01/K6`0
L71`8P3oool00200oooo00L0PH6108N7Q`2>SXh0QhN708^;R`23Ph<0Q8B40080QhN700@0RHV908B4
Q024Q8@0SHf=0P2;Rh/07P24Q8@0PX:208V9R@24Q8@0SHf=08V9R@27QhL0Q8B408J6QP29RHT0Q8B4
07alO027QhL0HF5Q08:2PP21PH40NWYj07emO@1nOWh0Ng]k0861P@3Ph>00QhN7096AT@28R8P0QhN7
08R8R029RHT0Ph>308N7Q`80S8b<0`27QhL0102;Rh/0QhN708Z:RP25QHD208V9R@0308^;R`29RHT0
SXj>00D0QhN702L0RXZ:08f=S@2<S8`0S8b<08Z:RP1mOGd0TY:B08f=S@2ATI40T92@08J6QP2HV9P0
TI6A08R8R02NWYh0Lg=c08n?S`2>SXh0W9bL08N7Q`2<S8`0T92@08N7Q`2=SHd0QhN707alO02=SHd0
QhN707UiN@29RHT0QhN708R8R027QhL0R8R808N7Q`2;Rh/0PH6108J6QP23Ph<00P27QhL00`24Q8@0
QhN708N7Q`0N0?ooo`0F08Z:RP2=SHd0SHf=08J6QP2:RXX0QhN708Z:RP29RHT0Q8B408V9R@2;Rh/0
R8R808V9R@28R8P0RXZ:08N7Q`26QXH0RXZ:08J6QP29RHT0QhN708^;R`80QhN700l0R8R808>3P`20
P800QXJ605aLG01lO7`0NWYj0861P@25QHD0NWYj07IfMP2:RXX0l?3`08V9R@2@T9000`29RHT04P2<
S8`0QhN708b<S02:RXX0QhN708J6QP29RHT0QXJ608Z:RP27QhL0RHV908F5Q@2:RXX0R8R808V9R@24
Q8@0RXZ:08N7Q`80RHV900<0QXJ608N7Q`26QXH00P26QXH01@2=SHd0TI6A08>3P`26QXH0OGem0080
QXJ60280Ng]k08R8R01jNWX0Ng]k096AT@1lO7`0WYjN08J6QP2EUID0PX:208N7Q`2<S8`0SHf=09:B
TP2;Rh/0Q8B408j>SP2BTY80QHF508b<S02@T900RXZ:08V9R@2@T900TY:B09BDU02>SXh0Shn?08^;
R`29RHT0QXJ608B4Q02;Rh/0S8b<7P3oool0401lO7`0NGUi079bLP1`L700LG5a07EeM@1iNGT0Lg=c
06e]K@1bLW80NGUi07IfMP1]KFd0KVi^075aL@1eMGD207AdM00;07=cL`1^KVh0Kfm_07IfMP1eMGD0
LW9b071`L01^KVh0LW9b071`L01LG5`00P1VIVH01P1gMgL0N7Qh06MWI`1VIVH0Ng]k0:NWY`80Lg=c
00/0LW9b07=cL`1bLW80MWIf07EeM@1gMgL0L71`06a/K01_Kfl0Lg=c06m_K`03075aL@07071`L01b
LW80L71`06m_K`1ZJVX0KVi^075aL@0207=cL`0Z06m_K`1`L700K6a/06UYJ@1ZJVX0M7Ad07]kN`1f
MWH0I6AT05aLG01UIFD0IVIV065QH@1PH600De=C05mOG`1WIfL0MgMg08V9R@1XJ6P0KVi^06YZJP1/
K6`0KVi^07YjNP1kNg/0MWIf07UiN@1eMGD0PH6107emO@1fMWH0OWin07AdM01cLg<0OGem0861P@1o
Ogl0P82007inOP1kNg/0M7Ad0P1`L7000`1fMWH0N7Qh0?ooo`0Q0?ooo`00803oool208N7Q`0?08b<
S029RHT0Rh^;08f=S@27QhL0RHV908J6QP29RHT0QhN708:2PP24Q8@0RHV908N7Q`2;Rh/0QXJ600<0
QhN701T0Q8B408N7Q`27QhL0PX:208B4Q023Ph<0Ogmo08B4Q01hN7P0MgMg07emO@28R8P0M7Ad07If
MP1^KVh0QhN70=GEe@3@d=00S8b<08R8R022PX80QhN708j>SP23Ph<0S8b<00@0QhN700l0QHF508N7
Q`2;Rh/0Rh^;08>3P`28R8P0QhN708B4Q027QhL0Q8B408j>SP27QhL0Q8B408N7Q`25QHD00P27QhL0
:P2DU9@0QhN708N7Q`27QhL0TY:B08f=S@2?Shl0RHV908>3P`2BTY80QhN709NGU`1bLW80Ogmo07Yj
NP1bLW80P82007emO@23Ph<0QXJ609>CT`27QhL0Vi^K08N7Q`2=SHd0UYJF092@T02BTY80QhN708V9
R@27QhL0RHV908N7Q`2=SHd0QXJ608N7Q`2=SHd0RXZ:08B4Q026QXH0Rh^;08N7Qah0oooo00`0RHV9
08J6QP2;Rh/0QhN708V9R@2:RXX0QHF508V9R@27QhL0SHf=08^;R`24Q8@208^;R`0708V9R@28R8P0
QXJ608b<S025QHD0S8b<08^;R`0208V9R@80QXJ601@0QHF507inOP1cLg<0JVYZ07YjNP1nOWh0SHf=
07]kN`1oOgl0Ng]k09VIV@2`/;00Y:BT092@T02;Rh/0QXJ608R8R02?Shl0Q8B408Z:RP<0RHV900/0
QhN708R8R02:RXX0R8R808^;R`25QHD0RHV908N7Q`25QHD0Rh^;08J6QP0208^;R`0Q08N7Q`29RHT0
Q8B408J6QP20P800RHV909:BTP29RHT0M7Ad08:2PP2:RXX0Rh^;08B4Q01hN7P0QHF507MgM`23Ph<0
Shn?09BDU02ATI40SXj>09fMW@24Q8@0RXZ:08^;R`2EUID0PX:208b<S021PH40Shn?08Z:RP1nOWh0
U9BD0080RHV900`0Shn?09BDU02ATI40UYJF08^;R`28R8P0QXJ608Z:RP29RHT0QXJ608f=S@26QXHN
0?ooo`0307=cL`1`L700LW9b0080Kfm_0100L71`06i^KP1bLW80LW9b07QhN01fMWH0LW9b07UiN@1e
MGD0Lg=c06i^KP1`L700MgMg06i^KP1hN7P0NGUi0P1cLg<0401dM7@0Lg=c07=cL`1]KFd0F5QH05MG
E`1`L700Kfm_07QhN01cLg<0MgMg07YjNP29RHT0F5QH04e=C@1hN7P207IfMP04079bLP1eMGD0LG5a
071`L0<0Lg=c00@0LG5a07AdM01eMGD0KVi^0P1cLg<02`1bLW80LG5a075aL@1fMWH0LW9b06m_K`1f
MWH0MGEe07=cL`1_Kfl0L71`0080IfMW00T0PH6107=cL`1FEUH0GUiN06m_K`1^KVh0Jf][061PH01R
HV800P1JFUX01`2CTi<0Rh^;08f=S@2ATI40UiNG07MgM`1jNWX00P1gMgL01`1YJFT0Hf=S06UYJ@1f
MWH0IVIV05]KF`1hN7P00P1cLg<0301kNg/0P82007moO`1oOgl0N7Qh079bLP1ZJVX0LG5a07QhN01a
LG40MWIf071`L280oooo000P0?ooo`@0QhN70P24Q8@208N7Q`0708^;R`27QhL0QhN708N7Q`22PX80
S8b<08:2PP0208B4Q00N08J6QP22PX80QhN708N7Q`28R8P0RHV908>3P`21PH40R8R807IfMP24Q8@0
Kfm_08>3P`2=SHd0Shn?07QhN02;Rh/0Ng]k07inOP1kNg/0lo?c08N7Q`2<S8`0QhN708J6QP29RHT0
Ph>308V9R@23Ph<0RHV90P2;Rh/02P29RHT0QhN708J6QP26QXH0Rh^;08N7Q`24Q8@0Rh^;08N7Q`2@
T90208N7Q`0408R8R023Ph<0QhN708:2PP<0TI6A00X0QhN7096AT@2GUiL0Ti>C08N7Q`26QXH0SXj>
09BDU01lO7`0PX:20P2CTi<03029RHT0V9RH096AT@23Ph<0QHF507UiN@2GUiL0P82009JFUP2RXZ80
SHf=08R8R080UYJF00T0QhN708b<S01mOGd0PH6108R8R02:RXX0QhN70861P@2;Rh/00P27QhL00`2;
Rh/0SHf=08N7Q`0N0?ooo`0908V9R@25QHD0RHV908R8R02;Rh/0RHV908^;R`29RHT0SHf=00<0RHV9
0280Q8B408f=S@27QhL0R8R808N7Q`28R8P0Q8B408b<S027QhL0QHF508b<S029RHT0Q8B408V9R@1[
Jf/0NWYj06m_K`1kNg/0Q8B408:2PP1aLG40RXZ:08N7Q`21PH40KFe]0?Gem@2<S8`0Rh^;08J6QP28
R8P0RXZ:08B4Q029RHT0Q8B40P29RHT308N7Q`80R8R802<0RHV908N7Q`27QhL0QHF508:2PP2<S8`0
QHF508V9R@27QhL0PX:208B4Q01nOWh0RXZ:09>CT`1hN7P0LG5a08V9R@2:RXX0Ph>307alO01hN7P0
RHV909ZJVP1mOGd0QXJ608j>SP25QHD0PX:209VIV@2BTY80PX:208J6QP29RHT0XJ6Q07alO00209:B
TP0?0861P@2<S8`0SXj>08j>SP29RHT0UIFE09JFUP2CTi<0RHV9092@T02;Rh/0Q8B408j>SP29RHT0
QHF50080RXZ:00<0RHV90?ooo`3oool0703oool02@1cLg<0KVi^07=cL`1cLg<0NGUi07QhN01fMWH0
Lg=c07EeM@0307=cL`04079bLP1cLg<0MWIf07IfMP80M7Ad00H0LW9b07QhN01aLG40KVi^07IfMP1h
N7P2079bLP0505]KF`1QHF40JFUY06ATI01WIfL00P1RHV804P1aLG40OWin079bLP1JFUX0VIVI07Qh
N01aLG40Kfm_07AdM01cLg<0LG5a079bLP1aLG40LW9b06m_K`1]KFd0KVi^075aL@80M7Ad03L0Kfm_
075aL@1eMGD0Jf][06UYJ@1^KVh0KFe]07=cL`1aLG40KVi^06a/K01[Jf/0JVYZ07MgM`1BDU80DE5A
06UYJ@1UIFD0GemO065QH@1LG5`0K6a/07moO`1^KVh0MWIf06m_K`1QHF40IfMW07UiN@1fMWH0Kfm_
075aL@23Ph<0QHF506UYJ@1aLG40IFEU069RHP1hN7P0Jf][06a/K01dM7@0P820092@T028R8P0Lg=c
07YjNP1fMWH0Lg=c07MgM`1cLg<0KVi^075aL@1`L700Lg=c0280oooo000P0?ooo`0408N7Q`22PX80
Ph>308f=S@80QhN700@0Rh^;08N7Q`27QhL0Rh^;0P27QhL00`24Q8@0Rh^;08^;R`0208N7Q`80Q8B4
00<0Rh^;08:2PP27QhL00P27QhL04`22PX80QhN706m_K`27QhL0MgMg07emO@1nOWh0Ogmo08>3P`2=
SHd0QhN707]kN`1`L700j^[Z08>3P`2<S8`0R8R808^;R`27QhL00P25QHD208N7Q`0:08J6QP27QhL0
SHf=08N7Q`2?Shl0SHf=08^;R`2?Shl0QXJ608F5Q@<0QhN70180S8b<08^;R`29RHT0QhN708b<S027
QhL0V9RH08>3P`28R8P0QhN708b<S028R8P0U9BD07alO02:RXX0U9BD075aL@1kNg/208R8R00=07Ee
M@2=SHd0TI6A08B4Q021PH40N7Qh08R8R022PX80Shn?08N7Q`2CTi<0SHf=07UiN@0308N7Q`0609:B
TP27QhL0Q8B408j>SP2<S8`0RXZ:0P27QhL01026QXH0PX:208N7Q`27QhLN0?ooo`0:08V9R@27QhL0
Ph>308j>SP29RHT0QXJ608Z:RP26QXH0RHV908Z:RP80RHV900T0QhN708^;R`28R8P0QXJ608V9R@2:
RXX0QHF508b<S023Ph<00P2<S8`07029RHT0Ph>308:2PP1WIfL0PH6107AdM022PX80QHF507]kN`1i
NGT0TI6A08n?S`1gMgL0Ng]k0?[jnP24Q8@0TI6A08J6QP2:RXX0RHV908N7Q`2:RXX0QXJ608V9R@28
R8P0QHF508^;R`29RHT308J6QP0508f=S@21PH40Q8B408R8R02:RXX00P26QXH09027QhL0PX:207in
OP24Q8@0Rh^;09FEU@1eMGD0QHF508R8R02:RXX0PH6108B4Q01oOgl0Ti>C09fMW@21PH40Rh^;08R8
R02EUID0RXZ:09FEU@2=SHd0QXJ609FEU@2<S8`0SHf=0861P@2;Rh/0RHV9096AT@2DU9@0SXj>09JF
UP2CTi<0UIFE09>CT`80QhN700T0S8b<08J6QP2:RXX0Rh^;08J6QP28R8P0RHV908b<S029RHT07P3o
ool02P1cLg<0MWIf071`L01dM7@0Lg=c071`L01aLG40L71`07=cL`1aLG4207=cL`0907EeM@1bLW80
KVi^071`L01cLg<0N7Qh075aL@1dM7@0LG5a0080N7Qh05D0Lg=c071`L01YJFT0GEeM06QXJ01WIfL0
MGEe07QhN01YJFT0HF5Q07QhN01kNg/0IfMW07UiN@2[Zj/0LW9b07YjNP1^KVh0LG5a07=cL`1bLW80
N7Qh071`L01eMGD0M7Ad06e]K@1`L700Lg=c06QXJ01YJFT0Jf][071`L01ZJVX0Kfm_07=cL`1eMGD0
Kfm_06][J`1]KFd0J6QX06=SH`1WIfL0MWIf07=cL`1KFe/0KVi^079bLP1`L700J6QX05mOG`1bLW80
OWin0861P@1oOgl0Q8B4075aL@24Q8@0RHV907moO`1`L700Lg=c08^;R`27QhL0N7Qh06i^KP1_Kfl0
Lg=c079bLP1nOWh0RHV908N7Q`21PH40QHF507EeM@1aLG40MGEe075aL@1ZJVX0LG5a07IfMP1`L700
M7Ad07UiN@1hN7P0Lg=c0280oooo000P0?ooo`80QhN700H0PX:208N7Q`27QhL0QhN708^;R`24Q8@5
08N7Q`0808B4Q027QhL0QhN708B4Q027QhL0Q8B408^;R`26QXH308^;R`0B08:2PP1mOGd0KFe]07in
OP20P800Ph>308N7Q`1aLG40N7Qh08N7Q`1jNWX0S8b<08N7Q`3`l?00Ph>3096AT@2=SHd0RHV90P26
QXH0202ATI40R8R808^;R`2=SHd0QhN708f=S@2@T900QhN70P2:RXX01`2=SHd0Rh^;08^;R`2;Rh/0
SHf=08N7Q`28R8P00P27QhL05P1oOgl0R8R8092@T027QhL0Shn?09NGU`2=SHd0U9BD08N7Q`1nOWh0
Ph>308N7Q`2OWil0QhN707alO021PH40Shn?08Z:RP2=SHd0QhN708^;R`2HV9P207moO`0>07MgM`28
R8P0NGUi08j>SP2LW9`0RHV908j>SP27QhL0PX:20861P@2<S8`0Ph>308N7Q`26QXH208N7Q`0508B4
Q02;Rh/0Rh^;08f=S@2;Rh/07P3oool01029RHT0QXJ608N7Q`2<S8`208J6QP0408b<S027QhL0RHV9
08^;R`80RHV900@0QXJ608N7Q`29RHT0Rh^;0P29RHT07025QHD0RXZ:08J6QP2;Rh/0R8R808N7Q`23
Ph<0OGem06e]K@1lO7`0Ng]k0820P027QhL0MgMg08J6QP2KVi/0Ph>307emO@22PX80l?3`08B4Q02>
SXh0RXZ:08f=S@28R8P0Ph>308N7Q`28R8P208J6QP0708F5Q@29RHT0R8R808N7Q`28R8P0RXZ:08N7
Q`0208J6QP0408N7Q`29RHT0Q8B408V9R@80Q8B402d0OWin08R8R02CTi<0QHF507]kN`2;Rh/0PX:2
08R8R01gMgL0Rh^;08V9R@2;Rh/0VYZJ08V9R@28R8P0SXj>09>CT`25QHD0Shn?0820P02<S8`0VIVI
08F5Q@2;Rh/0OWin08Z:RP23Ph<0Shn?09jNWP29RHT0SXj>09RHV02@T900RXZ:08f=S@24Q8@0RXZ:
08^;R`2=SHd0RHV908F5Q@29RHT0QXJ608R8R02:RXX07P3oool0101cLg<0L71`07IfMP1hN7P2071`
L00407AdM01eMGD0Lg=c07IfMP80Lg=c00H0L71`07EeM@1cLg<0MWIf07QhN01cLg<3075aL@0A07=c
L`1^KVh0KFe]075aL@1^KVh0J6QX06YZJP1XJ6P0Jf][071`L01bLW80P82008f=S@1jNWX0GemO06YZ
JP2FUYH00P1aLG40201_Kfl0MgMg07AdM01/K6`0IVIV075aL@1[Jf/0JFUY0P1]KFd06@1YJFT0L71`
06m_K`1aLG40JVYZ06a/K01[Jf/0KFe]06a/K01]KFd0LW9b06a/K01]KFd0KVi^079bLP1hN7P0KVi^
05QHF01VIVH0I6AT06EUI@1JFUX0P82007MgM`1fMWH00P1cLg<07`1mOGd0PH6107UiN@1[Jf/0MgMg
06MWI`1cLg<0NGUi07MgM`1oOgl0MGEe07AdM01jNWX0MGEe07]kN`1cLg<0M7Ad08V9R@24Q8@0Ng]k
07AdM01aLG40M7Ad07QhN01iNGT0Lg=c075aL@1_Kfl0K6a/06e]K@1aLG408P3oool00200oooo00@0
QhN708B4Q027QhL0Rh^;0P24Q8@0102;Rh/0QhN708N7Q`2;Rh/208N7Q`<0Q8B40P27QhL208B4Q080
QhN70180Q8B408V9R@28R8P0OGem07alO01kNg/0PX:207MgM`22PX80QhN707UiN@2=SHd0Shn?08N7
Q`2=SHd0OGem0?3`l024Q8@208N7Q`0708V9R@2=SHd0OGem0820P026QXH0QhN708Z:RP0208N7Q`0:
08f=S@2;Rh/0QhN708f=S@27QhL0SHf=08B4Q028R8P0S8b<08f=S@80QhN701@0PX:208>3P`28R8P0
SXj>08J6QP27QhL0Shn?08f=S@2BTY80SHf=08^;R`2IVIT0Shn?09>CT`27QhL0PX:207QhN025QHD0
QhN709JFUP80QhN701H0X:2P08^;R`27QhL0P82008V9R@1fMWH0QhN709:BTP28R8P0SHf=08^;R`2=
SHd0SXj>08b<S023Ph<0QXJ608^;R`27QhL0Rh^;08B4Q022PX80QXJ60P27QhLN0?ooo`0408V9R@27
QhL0QXJ608Z:RP80QhN700@0S8b<08V9R@29RHT0RXZ:0P29RHT208N7Q`0308V9R@2;Rh/0RHV90080
QHF501X0RHV908^;R`26QXH0R8R808^;R`21PH40M7Ad06e]K@20P800OGem08>3P`28R8P0M7Ad08n?
S`2;Rh/0MWIf08f=S@21PH40m?Cd08N7Q`2;Rh/0Shn?08N7Q`2;Rh/0Ph>308J6QP80Q8B400X0RXZ:
08N7Q`25QHD0Rh^;08R8R026QXH0RHV908F5Q@2=SHd0QhN70P26QXH04`2:RXX0QHF508F5Q@23Ph<0
P82008b<S02>SXh0N7Qh08F5Q@29RHT0PX:207moO`22PX80NWYj08V9R@2=SHd0W9bL08n?S`27QhL0
0P28R8P03`25QHD0RHV908V9R@26QXH0VYZJ08Z:RP23Ph<0Ng]k09>CT`1lO7`0U9BD09ZJVP29RHT0
UIFE092@T00208N7Q`0;08f=S@29RHT0RHV908f=S@26QXH0RXZ:08N7Q`29RHT0R8R808b<S029RHT0
7P3oool0101cLg<0MGEe071`L01aLG4207EeM@0407AdM01cLg<0Lg=c075aL@80Lg=c0P1eMGD00`1h
N7P0MWIf07=cL`02075aL@0@07=cL`1fMWH0Lg=c071`L01fMWH0Lg=c069RHP1IFET0KFe]07AdM01`
L700Lg=c06EUI@1fMWH0Kfm_05QHF080Lg=c01L0Vi^K07AdM01fMWH0O7al06i^KP1`L700MWIf07Mg
M`1^KVh0KFe]075aL@1`L700KFe]071`L01_Kfl0L71`06a/K01]KFd0Lg=c07AdM01^KVh0JVYZ06m_
K`0206i^KP0Q071`L01/K6`0MgMg07AdM01MGEd0KVi^06a/K01TI6@0Fe]K06=SH`1JFUX0HF5Q075a
L@22PX80O7al07IfMP21PH40M7Ad06i^KP1TI6@0Lg=c06m_K`1bLW80LG5a06][J`1XJ6P0P82007Ad
M022PX80P820079bLP1nOWh0NGUi0080JVYZ00/0M7Ad07QhN01eMGD0MGEe071`L01aLG40MGEe07Ui
N@1dM7@0N7Qh07=cL`0R0?ooo`00803oool208N7Q`0308B4Q027QhL0Rh^;0080QhN700<0Rh^;08B4
Q027QhL00P27QhL00`2;Rh/0QhN708N7Q`0308N7Q`0?08B4Q027QhL0SXj>08J6QP29RHT0QhN70861
P@1YJFT0Ogmo08N7Q`25QHD0Shn?08Z:RP1nOWh0Ti>C0080OGem0180QhN707IfMP3Zj^X0QhN7092@
T02;Rh/0Ph>308f=S@2?Shl0P82008N7Q`25QHD0RXZ:08^;R`27QhL0Rh^;08n?S`28R8P208b<S005
08^;R`27QhL0RXZ:08J6QP2>SXh00P28R8P01P2;Rh/0PH61096AT@23Ph<0P82008f=S@80Rh^;01@0
PX:208B4Q023Ph<0SXj>096AT@2NWYh0TY:B08N7Q`1mOGd0PX:207UiN@27QhL0UYJF08N7Q`2=SHd0
Shn?08R8R01fMWH0QhN708f=S@80TY:B00<0QhN7096AT@2>SXh00P21PH401@27QhL0Shn?08B4Q02;
Rh/0Q8B400D0QhN700<0Q8B40?ooo`3oool0703oool208V9R@0308N7Q`29RHT0R8R80080RHV900H0
QXJ608N7Q`2;Rh/0RHV908J6QP2:RXX308V9R@0P08J6QP29RHT0QHF508N7Q`2;Rh/0Q8B408b<S02:
RXX0Ph>306ATI01gMgL0PH6107emO@26QXH0P82007QhN02GUiL0OGem07alO02DU9@0Ogmo0?;blP22
PX80S8b<08Z:RP24Q8@0R8R808Z:RP21PH40QHF508J6QP27QhL308J6QP0308^;R`24Q8@0QhN70080
RXZ:00`0PX:208J6QP27QhL0RXZ:08F5Q@28R8P0Q8B40820P02CTi<0P82007YjNP27QhL208B4Q003
08N7Q`2?Shl0P8200080TY:B00l0V9RH08f=S@25QHD0OWin08^;R`1nOWh0RHV908^;R`2=SHd0UIFE
08R8R029RHT0R8R809>CT`24Q8@00P2CTi<02`2=SHd0VYZJ08f=S@2:RXX0SHf=08V9R@2=SHd0QhN7
08b<S027QhL0Rh^;0080RHV90P2;Rh/00`25QHD0oooo0?ooo`0L0?ooo`80Lg=c00<0MGEe07=cL`1^
KVh00P1cLg<01P1/K6`0MGEe07IfMP1cLg<0L71`075aL@<0Lg=c01P0L71`07=cL`1aLG40L71`06m_
K`1]KFd0MWIf07AdM01bLW80H61P06=SH`1XJ6P0IFEU06IVIP1TI6@0IVIV07]kN`1^KVh0K6a/08>3
P`1hN7P0WinO06][J`1^KVh2075aL@0<06a/K01]KFd0L71`06e]K@1bLW80KVi^06][J`1`L700K6a/
06i^KP1[Jf/0K6a/0P1`L7008P1YJFT0KFe]075aL@1_Kfl0KFe]079bLP1WIfL0KFe]07MgM`1/K6`0
IVIV06YZJP1XJ6P0JFUY07IfMP1oOgl0Jf][07UiN@1fMWH0LG5a06e]K@1^KVh0Kfm_07alO01dM7@0
Lg=c06MWI`1jNWX0Ogmo06YZJP1cLg<0Q8B408:2PP1UIFD207MgM`0;07UiN@20P800Lg=c07alO020
P800Lg=c079bLP1eMGD0M7Ad07EeM@1fMWH00P1cLg<207IfMP03075aL@3oool0oooo0200oooo000P
0?ooo`0308^;R`27QhL0QhN70080QhN700@0S8b<08f=S@2=SHd0PX:20P27QhL01@29RHT0QhN708B4
Q027QhL0Ph>30080QhN700P0Q8B408N7Q`27QhL0QhN708f=S@24Q8@0MWIf07]kN`80Ogmo00`0OWin
09FEU@1hN7P0SXj>0820P02ATI40MgMg092@T02<S8`0j^[Z07inOP2=SHd408N7Q`0708f=S@2<S8`0
QhN708>3P`2<S8`0RHV908Z:RP0208:2PP0308N7Q`2=SHd0SHf=00D0QhN701D0SHf=08R8R02ATI40
Ng]k08J6QP2?Shl0Q8B408n?S`27QhL0Ogmo09nOW`2JVYX0Rh^;07emO@27QhL0TY:B09fMW@2BTY80
PX:205aLG01bLW800P27QhL00`2=SHd0X:2P08N7Q`0308N7Q`0:0:>SX`2=SHd0R8R80861P@22PX80
S8b<08N7Q`2=SHd0Q8B408b<S0D0QhN700<0QXJ608N7Q`24Q8@07P3oool02`28R8P0RHV908V9R@26
QXH0R8R808V9R@27QhL0R8R808V9R@2<S8`0QHF50080RHV900h0QHF508^;R`26QXH0Rh^;08b<S029
RHT0Rh^;08J6QP25QHD0RXZ:08B4Q01^KVh0LW9b07YjNP80OGem00`0S8b<07IfMP2FUYH0O7al07in
OP1ZJVX0T92@08Z:RP3[jn/0Ogmo08j>SP2<S8`208J6QP0<08F5Q@26QXH0RXZ:08J6QP24Q8@0RHV9
08F5Q@29RHT0QHF508J6QP29RHT0Rh^;0P27QhL208F5Q@0a08V9R@22PX80Q8B40820P02<S8`0N7Qh
07moO`22PX80QhN708j>SP29RHT0LG5a08:2PP2CTi<0UIFE08b<S02?Shl0T92@09>CT`29RHT0QHF5
07MgM`25QHD0UIFE08b<S02;Rh/0V9RH08V9R@1oOgl0OWin08R8R02TY:@0Shn?09JFUP2?Shl0QhN7
08j>SP29RHT0TI6A08>3P`2:RXX0RHV908J6QP29RHT0Rh^;08V9R@28R8P0S8b<08N7Q`0N0?ooo`0A
06i^KP1cLg<0Lg=c071`L01bLW80Kfm_06][J`1]KFd0NGUi07QhN01^KVh0LW9b07=cL`1aLG40MWIf
07AdM01gMgL00P1hN7P00`1fMWH0L71`06i^KP02071`L00A061PH01QHF40J6QX06][J`1]KFd0JFUY
06QXJ020P800J6QX05YJFP1IFET0Lg=c075aL@2EUID0Kfm_07EeM@1hN7P00P1_Kfl03P1]KFd0JFUY
071`L01_Kfl0LG5a06m_K`1/K6`0LG5a07AdM01fMWH0Lg=c071`L01ZJVX0LG5a0P1]KFd05P1cLg<0
JVYZ06MWI`1VIVH0KFe]06QXJ01WIfL0HV9R07EeM@1bLW80Lg=c05YJFP1ADE40KFe]0820P023Ph<0
OGem079bLP1[Jf/0J6QX07AdM028R8P208B4Q00;07QhN01`L700KVi^07AdM01VIVH0IFEU07=cL`1m
OGd0MGEe08F5Q@22PX800P1fMWH0301dM7@0NWYj06m_K`1`L700Lg=c071`L01cLg<0MWIf07=cL`1d
M7@0N7Qh07EeMB80oooo000P0?ooo`0508B4Q027QhL0Q8B408B4Q026QXH00P22PX802P24Q8@0QhN7
08N7Q`22PX80QhN708V9R@24Q8@0S8b<08>3P`2;Rh/208N7Q`0:08^;R`29RHT0QXJ608B4Q029RHT0
MGEe0861P@1gMgL0QhN708>3P`80QhN700@0UIFE07QhN022PX80MgMg0P23Ph<03`3Shn<0QhN708f=
S@2=SHd0QhN708V9R@27QhL0Ph>308N7Q`2=SHd0QhN708J6QP2=SHd0Shn?09JFUP0208^;R`03092@
T027QhL0UYJF00@0QhN701X0R8R80820P02DU9@0LW9b07moO`2ATI40Ph>308n?S`2FUYH0QHF508N7
Q`29RHT0QhN709NGU`27QhL0V9RH09JFUP1lO7`0Shn?06m_K`1iNGT0QHF508n?S`1mOGd0V9RH08R8
R080QhN700l0S8b<09:BTP27QhL0TI6A08J6QP2>SXh0Q8B408N7Q`2<S8`0PH6108^;R`27QhL0Q8B4
08N7Q`2=SHd00P27QhL00`2;Rh/0QhN70?ooo`0M0?ooo`0408V9R@2;Rh/0QhN708N7Q`<0RXZ:00X0
Rh^;08V9R@29RHT0QhN708V9R@27QhL0Q8B408f=S@25QHD0SHf=0P26QXH208N7Q`0D08Z:RP26QXH0
RHV906UYJ@1nOWh0M7Ad07inOP1iNGT0Q8B40861P@2BTY80M7Ad07inOP1jNWX0T92@08b<S03UiND0
PX:208Z:RP28R8P208F5Q@80QhN700D0QHF508R8R026QXH0Ph>308N7Q`0208R8R080Q8B400D0S8b<
08V9R@2:RXX0QHF508V9R@0208:2PP0308V9R@1nOWh0UYJF0080MGEe01@0Shn?08:2PP27QhL0Ng]k
07=cL`1mOGd0XJ6Q08V9R@2>SXh0PX:208n?S`2DU9@0QHF509JFUP1aLG40Ph>309JFUP2BTY80Q8B4
09nOW`80Ogmo00d0PX:209FEU@2RXZ80Ti>C09JFUP25QHD0SXj>08^;R`2<S8`0SXj>08B4Q02=SHd0
RHV90080QhN700D0RXZ:08J6QP29RHT0RXZ:08V9R@0N0?ooo`0507QhN01fMWH0MGEe07EeM@1gMgL0
0P1jNWX02P1iNGT0Lg=c07=cL`1fMWH0Lg=c06m_K`1`L700Lg=c079bLP1eMGD2071`L00X06e]K@1_
Kfl0MgMg07=cL`1bLW80FUYJ06YZJP1WIfL0I6AT069RHP1]KFd0JFUY075aL@1VIVH0JVYZ06m_K`21
PH40Ng]k09BDU01ZJVX0Kfm_06][J`1]KFd0K6a/075aL@1eMGD0KVi^06a/K01_Kfl0K6a/06YZJP1Y
JFT0HV9R06MWI`1YJFT0KVi^07=cL`1VIVH0KFe]07=cL`80JVYZ02X0LW9b06][J`1hN7P0KVi^061P
H01bLW80KVi^06UYJ@1@D500EeMG06=SH`2CTi<0Lg=c06][J`1YJFT0Jf][07AdM01iNGT0OGem06][
J`1jNWX0R8R807QhN01fMWH0P82006ATI01UIFD0JVYZ0820P02<S8`0PX:207]kN`1_Kfl0Lg=c07Yj
NP1hN7P0MGEe07=cL`1eMGD0Lg=c07EeM@1aLG42071`L00307=cL`1aLG40Lg=c0280oooo000P0?oo
o`80QhN701X0Rh^;08B4Q02;Rh/0Rh^;08f=S@2;Rh/0QhN708^;R`27QhL0Ph>308B4Q023Ph<0SHf=
08V9R@2;Rh/0RHV908B4Q026QXH0Q8B408N7Q`26QXH0QhN707]kN`27QhL0O7al08N7Q`80OGem00P0
PH6108j>SP1nOWh0RXZ:08>3P`27QhL0RXZ:0=cLg080QhN700D0OWin08F5Q@21PH40R8R80861P@02
07inOP0708:2PP1kNg/0PH6108^;R`27QhL0TI6A08V9R@02096AT@80Rh^;01T0TI6A08R8R027QhL0
T92@08Z:RP2IVIT0MGEe07QhN02PX:00Ogmo096AT@29RHT0S8b<079bLP2LW9`0N7Qh08N7Q`23Ph<0
R8R80:BTY028R8P0RHV90820P021PH40TI6A0080SHf=00l0QhN707UiN@28R8P0MgMg08V9R@2IVIT0
Ti>C07alO02;Rh/0QhN708f=S@23Ph<0QhN708B4Q02;Rh/00P27QhL01P22PX80QhN708B4Q024Q8@0
Rh^;08N7Qah0oooo0P29RHT0102:RXX0QHF508Z:RP26QXH208R8R00808J6QP2:RXX0RHV908N7Q`2:
RXX0Ph>308Z:RP27QhL208V9R@0N08F5Q@2:RXX0RXZ:08N7Q`26QXH0RHV9071`L01mOGd0Kfm_08:2
PP1lO7`0PH6108J6QP2;Rh/0LG5a0820P022PX80RHV908Z:RP3Ng]h0R8R808V9R@27QhL0R8R808F5
Q@2=SHd0QHF508R8R029RHT0RXZ:0P23Ph<06@24Q8@0QHF508R8R025QHD0Rh^;08J6QP2=SHd0Q8B4
08J6QP22PX80Ph>308N7Q`22PX80UiNG06e]K@1aLG40W9bL07QhN01mOGd0Ng]k08b<S029RHT0W9bL
08>3P`2>SXh00P27QhL05`2MWId0Rh^;08F5Q@1jNWX0QHF508f=S@2;Rh/0U9BD09>CT`1iNGT0SHf=
08:2PP2FUYH0VIVI09jNWP24Q8@0RHV908f=S@2?Shl0RXZ:08b<S027QhL0S8b<0080RHV900H0QhN7
08b<S027QhL0QHF508b<S026QXHN0?ooo`80Lg=c0`1aLG40201/K6`0KFe]06i^KP1`L700LG5a07=c
L`1eMGD0NGUi0P1`L70206m_K`0h079bLP1aLG40MgMg07UiN@1aLG40L71`07=cL`1MGEd0Hf=S05]K
F`1ZJVX0K6a/07AdM01fMWH0Kfm_05]KF`1SHf<0Kfm_07=cL`1aLG40TI6A079bLP1cLg<0NWYj07Ee
M@1fMWH0NGUi07IfMP1lO7`0OWin07YjNP1iNGT0LW9b06MWI`1^KVh0J6QX06e]K@1/K6`0I6AT07Ee
M@1WIfL0I6AT06UYJ@1[Jf/0IfMW06IVIP1eMGD0H61P069RHP1dM7@0I6AT05QHF01NGUh0LW9b08Z:
RP1gMgL207]kN`0707EeM@1`L700LG5a07EeM@1/K6`0IVIV07AdM002071`L00@07emO@22PX80KFe]
07QhN01kNg/0Q8B407MgM`24Q8@0NGUi071`L01iNGT0MWIf07YjNP1gMgL0MGEe07AdM080Lg=c00H0
MWIf07QhN01eMGD0LG5a07AdM01`L70R0?ooo`00803oool208^;R`0808N7Q`2:RXX0RXZ:08:2PP27
QhL0Q8B408N7Q`2;Rh/208N7Q`0708f=S@26QXH0Ph>308V9R@26QXH0S8b<08B4Q00208^;R`0B08N7
Q`29RHT0QXJ607QhN01mOGd0MgMg08N7Q`1nOWh0QhN707=cL`2=SHd0Kfm_09VIV@1mOGd0QhN708b<
S03:b/X0QhN70`1iNGT0301fMWH0NGUi07inOP1oOgl0P8200861P@1jNWX0LW9b071`L027QhL0Rh^;
08f=S@80Rh^;0200UIFE08n?S`27QhL0Rh^;08N7Q`25QHD0SHf=09ZJVP1bLW80Q8B409JFUP1nOWh0
QHF508j>SP2CTi<0NWYj09bLW027QhL0PH6108j>SP27QhL0WIfM08n?S`1gMgL0MGEe06m_K`23Ph<0
TI6A0;2`/027QhL0N7Qh08n?S`80QhN700T0Rh^;08V9R@1nOWh0PH6108B4Q02<S8`0Rh^;08N7Q`2;
Rh/00`27QhL0102;Rh/0QhN708N7Q`24Q8@208N7Qah0oooo02/0R8R808Z:RP27QhL0QHF508b<S027
QhL0S8b<08V9R@26QXH0S8b<08V9R@25QHD0RXZ:08R8R027QhL0RXZ:08N7Q`2>SXh0QHF508Z:RP26
QXH0QHF508V9R@23Ph<0MgMg07UiN@1eMGD0QHF507inOP2?Shl0NWYj08Z:RP1TI6@0Ti>C08F5Q@26
QXH0UYJF0=WIf@2BTY80SXj>08N7Q`2<S8`0Rh^;0080RHV900X0R8R808N7Q`2:RXX0QXJ608F5Q@27
QhL0PX:208V9R@28R8P0QhN70P25QHD00`28R8P0QXJ608F5Q@0208F5Q@0Y08V9R@2DU9@0IVIV07em
O@2KVi/0LW9b07]kN`26QXH0XJ6Q08:2PP2NWYh0R8R808:2PP27QhL0Q8B40:2PX02BTY80Q8B408^;
R`1oOgl0S8b<07moO`2WYjL0RHV907QhN02<S8`0SXj>096AT@2UYJD0UiNG0861P@2<S8`0R8R808n?
S`2:RXX0QXJ608Z:RP2;Rh/0RHV908J6QP2:RXX00P29RHT00`27QhL0RHV908F5Q@0N0?ooo`0606i^
KP1aLG40L71`06][J`1dM7@0MWIf0P1hN7P01`1`L700M7Ad07=cL`1^KVh0L71`07AdM01fMWH00P1c
Lg<02P1eMGD0LG5a075aL@1/K6`0KVi^079bLP1]KFd0JVYZ06UYJ@1XJ6P206i^KP0B07]kN`1cLg<0
L71`05UIF@1_Kfl0N7Qh06m_K`21PH40WIfM0861P@2:RXX0P82008N7Q`29RHT0Ph>307emO@1kNg/0
NGUi0P1mOGd0;@24Q8@0RHV906YZJP1`L700K6a/06e]K@1ZJVX0GemO06UYJ@1_Kfl0JVYZ06i^KP1`
L700KFe]071`L01GEeL0IfMW07emO@1LG5`0HV9R06QXJ029RHT0N7Qh07alO01cLg<0L71`06UYJ@1]
KFd0OGem07QhN01nOWh0RXZ:0820P01mOGd0Fe]K079bLP1cLg<0K6a/06m_K`1kNg/0OWin09NGU`25
QHD0LW9b07moO`0207IfMP07075aL@1`L700LG5a07IfMP1cLg<0L71`075aL@0207=cL`0307EeM@1c
Lg<0KVi^0280oooo000P0?ooo`0908B4Q027QhL0Q8B40861P@27QhL0Q8B408^;R`27QhL0Q8B40080
QhN700T0PX:208^;R`27QhL0QXJ608B4Q023Ph<0SXj>08N7Q`24Q8@00P27QhL01@26QXH0P8200861
P@20P800O7al0080Ph>30140UIFE08:2PP21PH40KFe]09RHV020P800Ph>309fMW@2VYZH0QXJ608N7
Q`25QHD0Q8B408N7Q`1oOgl0O7al07UiN@0208:2PP80PH6100T0OGem075aL@1hN7P0RHV9092@T027
QhL0QHF508^;R`2CTi<00P27QhL01@23Ph<0QhN709fMW@1ZJVX0Ogmo0080QhN701h0P82008b<S02O
Wil0JFUY09bLW02BTY80P82008J6QP2>SXh0VIVI09fMW@28R8P0QHF507MgM`20P800Ph>309jNWP2@
T900P82008:2PP2@T900WIfM0:FUY@23Ph<0SHf=09:BTP2=SHd0Q8B408^;R`24Q8@208f=S@0808^;
R`27QhL0QhN708N7Q`2;Rh/0QhN708B4Q022PX8N0?ooo`80RHV900D0QhN708Z:RP2=SHd0QHF508b<
S00208V9R@0W08^;R`29RHT0Q8B408f=S@29RHT0R8R808Z:RP25QHD0SXj>08V9R@26QXH0QhN708Z:
RP29RHT0N7Qh07IfMP1hN7P0NWYj08>3P`1jNWX0RXZ:07inOP20P800J6QX09nOW`26QXH0Q8B40;Ng
]`3:b/X0Ti>C092@T029RHT0QhN708V9R@27QhL0RXZ:08>3P`2:RXX0RHV90080QXJ600P0QHF508V9
R@22PX80Q8B408V9R@28R8P0RXZ:08F5Q@80R8R80140RHV908:2PP23Ph<0UIFE06a/K02?Shl0Vi^K
07]kN`1mOGd0U9BD0:^[Z`1^KVh0UiNG08f=S@1nOWh0Q8B408n?S`0209NGU`0D08V9R@26QXH0OGem
08J6QP2=SHd0YZJV08J6QP20P800Rh^;09fMW@2IVIT0YjNW0861P@23Ph<0SXj>08n?S`28R8P0S8b<
08B4Q02:RXX208R8R00708V9R@2;Rh/0QXJ608Z:RP29RHT0QhN708V9R@0N0?ooo`0=07QhN01cLg<0
M7Ad07alO01iNGT0LG5a07AdM01cLg<0N7Qh07IfMP1cLg<0LW9b07IfMP0207=cL`0307UiN@1bLW80
M7Ad0080Lg=c01D0LG5a07AdM01eMGD0I6AT05mOG`1TI6@0JVYZ071`L01SHf<0IVIV06UYJ@1]KFd0
HF5Q0861P@1gMgL0LG5a09fMW@2_[jl0Q8B407inOP1fMWH00P1dM7@01@1jNWX0PH6107YjNP1kNg/0
NWYj0080MWIf00<0N7Qh08^;R`1jNWX00P1[Jf/05@1bLW80MgMg06YZJP1VIVH0LW9b07=cL`1_Kfl0
Jf][06a/K01YJFT0QXJ608f=S@1OGel0JVYZ07inOP2;Rh/0KVi^075aL@1]KFd0K6a/06i^KP0207Ee
M@0@075aL@1cLg<0LW9b07=cL`1gMgL0OWin08F5Q@1VIVH0Kfm_07emO@27QhL0Lg=c07inOP1/K6`0
IVIV06m_K`80MWIf00`0M7Ad071`L01`L700KFe]06i^KP1cLg<0MWIf071`L01aLG40Lg=c07EeM@1i
NGTR0?ooo`00803oool0202;Rh/0QhN708b<S027QhL0Rh^;08V9R@27QhL0SHf=1027QhL01@2<S8`0
QhN708^;R`27QhL0Q8B40080Rh^;0100R8R808N7Q`29RHT0QhN7075aL@1oOgl0Ph>307inOP27QhL0
NGUi0861P@2>SXh0LW9b08N7Q`2?Shl0PX:20P23Ph<02027QhL0PX:208N7Q`20P800QHF507emO@27
QhL0PX:20P1oOgl02P1mOGd0PX:207moO`21PH40Ng]k06a/K01[Jf/0MWIf08n?S`2@T90208F5Q@08
08n?S`27QhL0QhN708:2PP2RXZ80UiNG07YjNP2KVi/208N7Q`0K0:>SX`2i^KT0K6a/09^KV`2CTi<0
LG5a08N7Q`1iNGT0U9BD09:BTP28R8P0Ng]k075aL@1fMWH0QhN709FEU@2=SHd0Ti>C08N7Q`2CTi<0
UYJF08^;R`27QhL0RXZ:08V9R@2;Rh/0Q8B40080QhN70`24Q8@208^;R`0508B4Q027QhL0QhN708^;
R`27QhL07P3oool02028R8P0RHV908f=S@26QXH0QhN708V9R@27QhL0RXZ:0P29RHT0;P26QXH0QHF5
08f=S@26QXH0S8b<08J6QP25QHD0SXj>08V9R@25QHD0RHV908Z:RP29RHT0LW9b07MgM`1nOWh0NGUi
08:2PP20P800PX:208n?S`1VIVH0PX:209VIV@22PX80[Jf]0<c<c02[Zj/0SHf=08b<S026QXH0SHf=
08J6QP2<S8`0QXJ608F5Q@2;Rh/0QHF508N7Q`25QHD0QhN708J6QP22PX80R8R808:2PP28R8P208N7
Q`0V08V9R@2;Rh/0Q8B407moO`1iNGT0QHF508j>SP23Ph<0XJ6Q0820P01lO7`0Shn?0:f][@1oOgl0
UYJF09^KV`1gMgL0UIFE08N7Q`2EUID0VYZJ08n?S`2;Rh/0PH6106e]K@2BTY80Ti>C08>3P`2=SHd0
Shn?09:BTP2][Jd0UiNG07emO@2=SHd0U9BD092@T027QhL208R8R080Rh^;00P0QhN708Z:RP2:RXX0
QhN708^;R`26QXH0RXZ:08V9RAh0oooo00P0KVi^07=cL`1cLg<0L71`06e]K@1bLW80LG5a071`L080
Lg=c00l0L71`06i^KP1cLg<0L71`07AdM01`L700LG5a07MgM`1_Kfl0KVi^07=cL`1dM7@0Lg=c06YZ
JP1RHV800P1XJ6P05@1YJFT0MWIf071`L01eMGD0FEUI06YZJP23Ph<0Kfm_0:^[Z`3GemL0Y:BT07mo
O`1hN7P0MgMg07]kN`1jNWX0N7Qh07IfMP1gMgL0Ogmo07QhN00207MgM`0`07QhN01mOGd0QhN7092@
T01lO7`0Jf][06QXJ01cLg<0MgMg06m_K`1/K6`0IVIV06=SH`1BDU80Jf][07YjNP20P800IVIV061P
H01OGel0LW9b08:2PP1aLG40PH61079bLP25QHD0PH6107QhN021PH40O7al08>3P`1oOgl0GUiN0820
P01cLg<0IFEU06e]K@1kNg/0MGEe09JFUP23Ph<0Hf=S07IfMP21PH40NWYj07EeM@1bLW80Lg=c0P1i
NGT0201eMGD0LG5a075aL@1eMGD0MWIf071`L01aLG40Lg=c8P3oool00200oooo00P0QhN708B4Q027
QhL0QhN708f=S@27QhL0PX:208B4Q0<0QhN700H0R8R808N7Q`24Q8@0Q8B408N7Q`24Q8@308N7Q`0B
08J6QP24Q8@0O7al08F5Q@28R8P0OWin07YjNP1iNGT0R8R808N7Q`1lO7`0OGem09NGU`2;Rh/0QhN7
08V9R@25QHD0SHf=0P2;Rh/01P27QhL0QXJ60820P021PH40P82008F5Q@@0QhN700T0PH6108>3P`21
PH40O7al07]kN`1XJ6P0Jf][096AT@2;Rh/00P2:RXX07`27QhL0OGem0861P@2j^[X0GEeM09^KV`1K
Fe/0UYJF08N7Q`29RHT0W9bL07MgM`27QhL0Ng]k08N7Q`2JVYX0Ph>308n?S`2MWId0UIFE07]kN`1W
IfL0UYJF08f=S@2EUID0V9RH08:2PP1kNg/0YZJV096AT@21PH400P26QXH01023Ph<0Rh^;08B4Q02;
Rh/308N7Q`80Q8B400D0QhN708^;R`27QhL0QhN708^;R`0N0?ooo`0=08V9R@27QhL0RHV908F5Q@2:
RXX0RHV908N7Q`2;Rh/0S8b<08V9R@25QHD0QXJ608V9R@0208N7Q`0508^;R`29RHT0Rh^;08V9R@26
QXH00P24Q8@0401hN7P0OGem0861P@1kNg/0OGem07moO`2=SHd0Q8B407AdM01iNGT0VYZJ08>3P`2R
XZ80SXj>08B4Q02<S8`208Z:RP0=08V9R@28R8P0QXJ608^;R`26QXH0Q8B408R8R029RHT0QHF508:2
PP26QXH0R8R808F5Q@0208B4Q00/07MgM`1lO7`0RXZ:08J6QP28R8P0QHF508>3P`1jNWX0Q8B40;Rh
^01`L700ZZZZ065QH@23Ph<0QhN70:VYZ@2/[:`0WIfM092@T027QhL0R8R809:BTP28R8P0T92@09JF
UP2>SXh0Ph>306i^KP2DU9@0QXJ608j>SP2MWId0SXj>08J6QP2HV9P0T92@096AT@2@T900RXZ:08F5
Q@2=SHd0QHF508b<S026QXH208^;R`0708N7Q`29RHT0RHV908Z:RP29RHT0QXJ608Z:RP0N0?ooo`0=
07=cL`1eMGD0Lg=c06i^KP1`L700Lg=c07IfMP1iNGT0MgMg07=cL`1^KVh0Kfm_07=cL`0207EeM@0G
07IfMP1hN7P0MWIf07=cL`1`L700KVi^071`L01YJFT0IFEU06QXJ01YJFT0L71`07EeM@1hN7P0KFe]
069RHP1XJ6P0NWYj06IVIP2GUiL0N7Qh06m_K`1bLW800P1aLG40501dM7@0Lg=c07MgM`1mOGd0MgMg
06m_K`1cLg<0M7Ad06i^KP1ZJVX0MWIf07MgM`1eMGD0NGUi07YjNP1lO7`0Ogmo06][J`1/K6`0KVi^
0P1[Jf/09@1YJFT0Lg=c0861P@1mOGd0SHf=06YZJP1KFe/0L71`09jNWP2?Shl0XJ6Q07emO@1nOWh0
LW9b06e]K@1gMgL0MGEe06m_K`1/K6`0N7Qh06m_K`1dM7@0JFUY06a/K01oOgl0PH6107emO@1XJ6P0
Lg=c08F5Q@1oOgl0MWIf079bLP1eMGD0LG5a07AdM01`L7000P1fMWH01`1eMGD0N7Qh07=cL`1aLG40
Lg=c071`L01aLG408P3oool00200oooo0P2=SHd02`2;Rh/0PX:208N7Q`27QhL0S8b<08N7Q`2;Rh/0
QhN708J6QP27QhL0QXJ60080QhN700/0Rh^;08b<S027QhL0SXj>08B4Q026QXH0Q8B407alO01mOGd0
PX:207inOP0208:2PP0909BDU02ATI40Kfm_092@T02?Shl0PH610::RXP2=SHd0PX:20080QhN703@0
Rh^;08n?S`27QhL0SXj>08n?S`20P800QHF508N7Q`28R8P0PH6107emO@21PH40Ph>308:2PP23Ph<0
OGem079bLP1XJ6P0L71`08n?S`28R8P0QhN708^;R`28R8P0PX:20<G5a@2?Shl0Kfm_0410@01HF5P0
J6QX0:ZZZP2IVIT0P82009VIV@2=SHd0NWYj08V9R@2=SHd0WinO08N7Q`2SXj<0QXJ605UIF@2FUYH0
P82008^;R`2HV9P0W9bL08b<S02=SHd0SXj>0P2=SHd00`29RHT0QhN708N7Q`0208N7Q`0308B4Q02;
Rh/0QhN70080Rh^;00<0Q8B408^;R`27QhL00P27QhLN0?ooo`0908N7Q`2:RXX0RXZ:08N7Q`2<S8`0
QHF508Z:RP26QXH0RXZ:0080QXJ602T0RXZ:08N7Q`26QXH0QXJ608V9R@2:RXX0RHV908^;R`24Q8@0
QXJ60820P01iNGT0MgMg08>3P`1kNg/0OGem07UiN@2:RXX0S8b<06MWI`2<S8`0TY:B096AT@3De=@0
S8b<08J6QP2<S8`0RHV908f=S@2;Rh/0Q8B408J6QP2<S8`0PH6108J6QP28R8P0RHV908J6QP28R8P0
QXJ608N7Q`0208J6QP0X08F5Q@20P800MgMg07emO@2<S8`0QXJ608:2PP27QhL0Q8B407MgM`2c/k<0
VYZJ06e]K@1TI6@0Ti>C08F5Q@2WYjL0QXJ607MgM`2?Shl0Rh^;08F5Q@2CTi<0SHf=09bLW024Q8@0
W9bL08n?S`1QHF40UiNG08N7Q`2FUYH0U9BD08b<S023Ph<0WinO09RHV02;Rh/0RXZ:08R8R0<0RHV9
00/0Rh^;08F5Q@2<S8`0QXJ608R8R02:RXX0QHF508Z:RP26QXH0RHV908^;R`0N0?ooo`0606][J`1`
L700LG5a07IfMP1hN7P0KVi^0P1`L7001@1aLG40L71`075aL@1dM7@0LW9b00@0L71`01X0Lg=c06m_
K`1`L700LG5a06][J`1XJ6P0IFEU075aL@1[Jf/0JFUY06=SH`1WIfL0KVi^05eMG@1^KVh0N7Qh08J6
QP32`/80LW9b07IfMP1hN7P0Lg=c07AdM01_Kfl0K6a/06QXJ080L71`0`1bLW802P1fMWH0OWin07If
MP1eMGD0M7Ad07EeM@1hN7P0OWin07alO01kNg/206m_K`0G06YZJP1]KFd0Jf][05mOG`1]KFd0Ph>3
06IVIP2;Rh/0/k>c08n?S`1iNGT0G5aL065QH@1YJFT0L71`07alO020P800M7Ad07EeM@1]KFd0L71`
07inOP1/K6`00P1hN7P01P22PX80LG5a069RHP1VIVH0S8b<08:2PP<0L71`0`1cLg<01@1fMWH0LG5a
07AdM01`L700KVi^00<0LG5a00<0L71`07=cL`1fMWH08P3oool00200oooo00<0QXJ608^;R`2;Rh/0
0P27QhL01023Ph<0Rh^;08N7Q`27QhL208B4Q00508N7Q`26QXH0QhN708B4Q023Ph<00`27QhL04@26
QXH0Rh^;0820P025QHD0LW9b08F5Q@28R8P0OWin07alO027QhL0SXj>07YjNP2<S8`0P82008V9R@27
QhL0RXZ:00<0QhN701h0Shn?096AT@2:RXX0RXZ:096AT@2:RXX0T92@08n?S`2>SXh0R8R808j>SP22
PX80QhN708R8R025QHD0Ph>307emO@1iNGT0Hf=S06a/K02<S8`0SXj>08N7Q`24Q8@0OGem0:^[Z`2o
_kl0Fe]K08:2PP1WIfL207QhN00G07moO`21PH40QhN709FEU@2?Shl0PX:20:ZZZP2NWYh0PH6109fM
W@2PX:00Kfm_08N7Q`2LW9`0Ti>C08Z:RP2HV9P0R8R808^;R`23Ph<0SXj>08V9R@26QXH00P27QhL0
0`2;Rh/0QhN708N7Q`0208N7Q`0408B4Q02;Rh/0Q8B408B4Q0<0QhN77P3oool00`29RHT0SHf=08b<
S00208V9R@0408F5Q@2;Rh/0RHV908^;R`80QhN700<0RHV908Z:RP29RHT00P29RHT0502<S8`0RHV9
08^;R`21PH40QhN707UiN@21PH40K6a/07YjNP1oOgl0O7al07emO@2=SHd0PH61075aL@2KVi/0U9BD
0<O7a`2j^[X0SHf=0P29RHT04`26QXH0RXZ:08^;R`23Ph<0R8R808^;R`23Ph<0QHF508N7Q`2;Rh/0
Q8B408R8R020P800Q8B408J6QP28R8P0QhN708F5Q@23Ph<00P1nOWh09`20P800R8R808:2PP1nOWh0
OGem0:RXZ02][Jd0J6QX08V9R@1`L700RXZ:09FEU@26QXH0PH6108^;R`2>SXh0T92@07AdM02IVIT0
X:2P0820P02JVYX0Rh^;07QhN026QXH0T92@09>CT`26QXH0U9BD096AT@2NWYh0QhN708j>SP2=SHd0
QhN708V9R@26QXH0S8b<08J6QP0308V9R@0308N7Q`2<S8`0QhN70080RHV900<0Rh^;08V9R@3oool0
7@3oool00`1eMGD0MWIf07AdM00207=cL`80LW9b00L0Lg=c07IfMP1eMGD0MGEe07=cL`1gMgL0Lg=c
0080N7Qh01@0MgMg07=cL`1fMWH0Jf][06e]K@1UIFD0JVYZ065QH@1PH600IFEU06YZJP1_Kfl0NGUi
065QH@1OGel0RHV908^;R`3:b/X0^[Zj07IfMP80Lg=c03`0L71`06e]K@1[Jf/0J6QX06m_K`1[Jf/0
J6QX06ATI01YJFT0Kfm_06a/K01[Jf/0K6a/06e]K@1_Kfl0M7Ad07EeM@1hN7P0NWYj08Z:RP21PH40
HV9R06][J`1ZJVX0J6QX06i^KP1jNWX0Jf][07AdM01iNGT0Lg=c08F5Q@2EUID0NGUi06m_K`1gMgL0
K6a/07IfMP1KFe/0IFEU07alO01^KVh0MGEe05aLG01eMGD0Kfm_06QXJ01eMGD0KFe]079bLP1mOGd0
S8b<07EeM@1cLg<0MgMg079bLP1cLg<0L71`07AdM01`L70307=cL`0707EeM@1dM7@0MGEe07QhN01c
Lg<0MWIf07=cL`0R0?ooo`00803oool00`24Q8@0QhN708^;R`0208N7Q`0308B4Q027QhL0QhN70080
Rh^;0100QhN708B4Q027QhL0QhN708^;R`2<S8`0SHf=08^;R`24Q8@0OGem08N7Q`23Ph<0QHF507Qh
N022PX80R8R80`27QhL0102?Shl0Ph>309VIV@2RXZ8208N7Q`0608Z:RP2=SHd0SHf=08N7Q`2;Rh/0
TY:B0P2FUYH0<`2IVIT0V9RH09BDU02BTY80V9RH09:BTP2CTi<0R8R80861P@23Ph<0PX:208N7Q`23
Ph<0Ogmo07emO@1MGEd0G5aL07alO01oOgl0NGUi0861P@2JVYX0^;Rh09^KV`2CTi<0IFEU071`L01/
K6`0NGUi09FEU@1dM7@0R8R808n?S`20P800TI6A08N7Q`2?Shl0T92@08Z:RP26QXH0MGEe0861P@25
QHD0QhN709bLW02DU9@0QXJ608N7Q`24Q8@0RHV908J6QP0208B4Q00508^;R`24Q8@0SHf=08B4Q02;
Rh/01`27QhLN0?ooo`0308V9R@2;Rh/0S8b<0080RHV900<0QHF508^;R`29RHT00P28R8P408V9R@80
QhN70P28R8P00`27QhL0PH610861P@0207alO00<06YZJP1kNg/0P82007]kN`25QHD0RHV90820P024
Q8@0Shn?0<c<c02l_;`0S8b<0P27QhL01P28R8P0QHF508F5Q@23Ph<0QHF508>3P`80Q8B40100R8R8
08N7Q`28R8P0PX:208Z:RP25QHD0QXJ608^;R`25QHD0R8R808B4Q026QXH0R8R807UiN@1oOgl0R8R8
0P1mOGd04P26QXH0UYJF0::RXP2EUID0Ti>C07emO@2JVYX0OWin07UiN@2HV9P0PH6109:BTP22PX80
Ogmo09RHV02<S8`0Rh^;096AT@80TY:B00H0QHF509bLW02;Rh/0PX:209^KV`2EUID208^;R`0308j>
SP2:RXX0QhN70080QhN700L0S8b<08B4Q02:RXX0QHF508Z:RP29RHT0Rh^;0080RHV900<0Rh^;08V9
R@26QXH07P3oool00`1hN7P0MWIf07AdM00207=cL`03075aL@1fMWH0Lg=c0080KVi^00h0Lg=c07Qh
N01cLg<0Lg=c06e]K@1[Jf/0KFe]06i^KP1eMGD0LW9b06UYJ@1WIfL0Hf=S05QHF080IVIV0140H61P
06i^KP1cLg<0GemO075aL@1YJFT0][Jf0;bl_01hN7P0KVi^06YZJP1/K6`0KFe]06YZJP1PH600GUiN
05]KF`0205YJFP0U06ATI01UIFD0H61P05iNGP1YJFT0KFe]07IfMP1kNg/0M7Ad079bLP1aLG40N7Qh
07inOP29RHT0U9BD07emO@1[Jf/0LW9b07IfMP1cLg<0I6AT071`L01fMWH0QhN70:FUY@21PH40K6a/
07]kN`1lO7`0Ogmo069RHP1^KVh0Ogmo07UiN@1_Kfl0MWIf07inOP0208:2PP0:09BDU01jNWX0JVYZ
07MgM`1hN7P0MgMg07IfMP1nOWh0Lg=c079bLP80MGEe00<0M7Ad071`L01`L7000P1aLG401`1cLg<0
MWIf07=cL`1cLg<0MWIf07=cL`1`L7008P3oool00200oooo1`27QhL208B4Q0<0QhN70P24Q8@208J6
QP0F08N7Q`24Q8@0Rh^;0861P@1lO7`0Ph>307MgM`1fMWH0QXJ607UiN@1mOGd0T92@08N7Q`2<S8`0
Ph>307IfMP29RHT0Q8B408V9R@24Q8@0QhN708Z:RP<0R8R800<0SXj>092@T02EUID00`2EUID0202;
Rh/0T92@09:BTP2=SHd0R8R808N7Q`21PH40QhN70P23Ph<09`27QhL0Ph>306i^KP1VIVH0PH6108:2
PP27QhL0WinO0:FUY@2^[Zh0RXZ:0;Rh^01]KFd0QHF504i>CP2RXZ80U9BD07emO@1jNWX0S8b<07in
OP20P800Shn?08N7Q`2MWId0VYZJ07MgM`28R8P0PX:207inOP2@T900Ti>C0861P@2?Shl0QXJ608V9
R@24Q8@0Rh^;08B4Q00208N7Q`80Q8B40`27QhL01@2;Rh/0QhN708N7Q`27QhL0Q8B401h0oooo00L0
RHV908J6QP2;Rh/0RHV908J6QP29RHT0Rh^;0080QhN70P2;Rh/02`29RHT0QhN708F5Q@28R8P0RHV9
08b<S029RHT0R8R80820P01mOGd0Ph>30080M7Ad00`0QHF507inOP1kNg/0S8b<08B4Q02?Shl0T92@
0<K6aP3@d=00RHV908f=S@25QHD208V9R@0508>3P`1oOgl0PX:208B4Q021PH400P25QHD01P27QhL0
Rh^;08B4Q029RHT0S8b<08B4Q080RHV900P0PX:208R8R024Q8@0QXJ608B4Q023Ph<0O7al075aL@80
OGem01h0O7al096AT@2PX:00[jn_07=cL`2`/;00LG5a096AT@1cLg<0Ti>C096AT@25QHD0Ogmo09RH
V025QHD0P82009JFUP29RHT0TI6A09:BTP2;Rh/0S8b<08F5Q@2:RXX0VIVI09JFUP22PX80Ti>C08J6
QP2;Rh/208Z:RP80QhN700<0RHV908^;R`25QHD00P2;Rh/00`26QXH0RXZ:08V9R@0208V9R@0308N7
Q`3oool0oooo01`0oooo00L0Lg=c071`L01fMWH0Lg=c071`L01cLg<0MWIf0080MGEe0P1fMWH01@1c
Lg<0MGEe075aL@1cLg<0MGEe0080N7Qh01P0KVi^06e]K@1^KVh0Kfm_06MWI`1YJFT0Kfm_07=cL`1/
K6`0KVi^06a/K01gMgL0PH610=cLg03GemL0N7Qh07MgM`1aLG40Lg=c075aL@1ZJVX0IFEU06QXJ01U
IFD305mOG`0@06=SH`1XJ6P0JFUY06YZJP1]KFd0IVIV079bLP1cLg<0LG5a07=cL`1aLG40M7Ad06e]
K@1`L700Ng]k07AdM080JFUY02D0HF5Q06IVIP1dM7@0PH61059BDP1gMgL0KFe]0861P@2ATI40IVIV
075aL@1iNGT0Lg=c08B4Q01hN7P0Kfm_07inOP1cLg<0IfMW06e]K@28R8P0MgMg07=cL`1oOgl0PX:2
07UiN@1aLG40NWYj075aL@1eMGD0NGUi075aL@1eMGD0LG5a07=cL`1iNGT0LG5a0080MWIf00<0L71`
075aL@1cLg<00P1cLg<00`1eMGD0oooo0?ooo`0P0?ooo`00803oool00`27QhL0Q8B408N7Q`0208N7
Q`0508^;R`27QhL0QhN708B4Q02;Rh/00P27QhL0502;Rh/0QhN708B4Q026QXH0Ph>308N7Q`21PH40
O7al07inOP22PX80O7al07MgM`23Ph<0S8b<0861P@29RHT0MGEe08Z:RP27QhL0Ph>30`27QhL01`24
Q8@0QhN709fMW@1oOgl0MgMg05eMG@1[Jf/00P21PH401`1dM7@0MgMg07MgM`1lO7`0OGem09fMW@2[
Zj/00P2=SHd08P27QhL0PH6108N7Q`1mOGd0Ph>30861P@1oOgl0P82005UIF@1iNGT0Ph>3092@T02[
Zj/0XJ6Q06m_K`1^KVh0^[Zj07QhN02OWil0JVYZ07UiN@27QhL0P82008^;R`1kNg/0UIFE0861P@2H
V9P0T92@09>CT`1ZJVX0V9RH09>CT`2?Shl209bLW00508R8R027QhL0Q8B408b<S023Ph<00P27QhL0
102;Rh/0Q8B408^;R`2;Rh/608N7Q`0308^;R`27QhL0oooo01d0oooo00<0RHV908F5Q@26QXH00P29
RHT02P2:RXX0RHV908V9R@25QHD0S8b<08V9R@26QXH0QhN708V9R@25QHD208Z:RP0?08V9R@22PX80
OWin08F5Q@1hN7P0K6a/079bLP1nOWh0QXJ607MgM`29RHT0OGem096AT@3<c<`0`/;200<0R8R80100
QhN707AdM01iNGT0Lg=c08R8R02>SXh0QHF508Z:RP2CTi<0U9BD08:2PP2:RXX0Rh^;08N7Q`2ATI40
UYJF0P2;Rh/0=`29RHT0Ph>308R8R023Ph<0QhN708:2PP23Ph<0QHF5079bLP1kNg/0PH6108b<S02T
Y:@0OWin08J6QP1`L700Zj^[06i^KP2JVYX0NGUi08J6QP2GUiL0MgMg08V9R@2;Rh/0TY:B08:2PP2H
V9P0Rh^;09FEU@1ZJVX0Q8B408:2PP2@T900UYJF0:6QX@2BTY80Rh^;08F5Q@2ATI40Rh^;08J6QP2:
RXX0S8b<08F5Q@2<S8`0R8R808V9R@2;Rh/0QXJ608V9R@2;Rh/0QXJ608b<S026QXH07P3oool00`1c
Lg<0LG5a071`L00207=cL`0K075aL@1cLg<0Lg=c075aL@1dM7@0Lg=c071`L01]KFd0Lg=c075aL@1g
MgL0NWYj07=cL`1`L700Kfm_07MgM`1QHF40EUIF06ATI01ZJVX0Jf][061PH01bLW80MWIf07alO03B
d]80b<S800<0LW9b0100MGEe05MGE`16ATH0GEeM08>3P`2WYjL0S8b<07alO027QhL0UiNG07]kN`26
QXH0Ph>307alO01WIfL0H61P0P1`L7006@1cLg<0LG5a07=cL`1gMgL0MGEe071`L01eMGD0MWIf08B4
Q01^KVh0KFe]06i^KP1eMGD0B4Q808V9R@1[Jf/0KVi^05iNGP1bLW80OGem07moO`27QhL0HF5Q06m_
K`24Q8@00P1aLG403`1gMgL0KFe]07QhN01VIVH0FUYJ05iNGP1fMWH0Kfm_07moO`20P800MWIf075a
L@1jNWX0Ng]k071`L00207AdM00;075aL@1dM7@0KVi^07=cL`1fMWH0L71`07=cL`1fMWH0L71`07Ad
M01`L7008P3oool00200oooo00<0Rh^;08N7Q`27QhL00`27QhL06P2;Rh/0QhN708N7Q`27QhL0Rh^;
08N7Q`26QXH0Rh^;08N7Q`2<S8`0QhN708>3P`1mOGd0Rh^;08j>SP28R8P0QhN707moO`2DU9@0QhN7
08>3P`21PH40V9RH09>CT`2n_[h0Q8B40P23Ph<01027QhL0R8R806UYJ@2<S8`208N7Q`0C0:b/[02F
UYH0UYJF09ZJVP2d];@0XZ:R09ZJVP2HV9P0MGEe08>3P`2MWId0SHf=08^;R`28R8P0PX:20861P@22
PX80Ph>30861P@0207inOP0Q07IfMP1?Cdl0NWYj07IfMP2d];@0OWin0:FUY@1UIFD0Z:RX07inOP25
QHD0Kfm_05QHF02?Shl0OGem08N7Q`20P800UiNG08R8R02@T900TI6A09fMW@1YJFT0MgMg08N7Q`2:
RXX0V9RH0:j^[P2;Rh/0QXJ608N7Q`2ATI40QhN70080Q8B400@0QhN708B4Q027QhL0Q8B40P27QhL0
1P24Q8@0QhN708N7Q`24Q8@0QhN708B4Q1h0oooo00<0R8R808V9R@29RHT00`29RHT01P2:RXX0QXJ6
08V9R@29RHT0R8R808J6QP80R8R804`0QHF508f=S@29RHT0Ph>307QhN01nOWh0MWIf06e]K@1fMWH0
NGUi08J6QP1oOgl0QhN707QhN023Ph<0[Zj^0=[JfP27QhL0RHV908N7Q`28R8P0QXJ6069RHP26QXH0
RHV908J6QP1hN7P0MWIf08Z:RP21PH40PX:208B4Q021PH40UYJF07inOP27QhL0RXZ:08b<S02=SHd0
RHV908J6QP2:RXX0Ph>308B4Q026QXH0QHF508N7Q`21PH40KFe]08b<S01iNGT0XZ:R08V9R@2;Rh/0
IFEU0:NWY`24Q8@0SHf=08j>SP1gMgL0Ph>307inOP2HV9P0NWYj09>CT`29RHT0Shn?08b<S02IVIT0
JVYZ08>3P`2CTi<0RHV909BDU02`/;00SXj>0P26QXH01P2CTi<0RHV908^;R`29RHT0Rh^;08N7Q`80
RHV900@0Rh^;08V9R@27QhL0Rh^;0P29RHT00`2;Rh/0QhN70?ooo`0M0?ooo`0306i^KP1cLg<0Lg=c
00<0Lg=c00L0LG5a071`L01cLg<0Lg=c06i^KP1`L700Lg=c0080KVi^0P1cLg<0F`1`L700IFEU061P
H01BDU80Bd];05UIF@1UIFD0HV9R06EUI@1eMGD0HV9R05UIF@2LW9`0[:b/07AdM01hN7P0MGEe07=c
L`1_Kfl0GEeM06][J`1cLg<0Kfm_03De=@19BDT0IFEU05ADE00k>c/0D51@05ADE01dM7@0MgMg07Ee
M@1NGUh0LW9b07IfMP1bLW80MGEe07]kN`1`L700LG5a07IfMP1hN7P0NWYj07]kN`27QhL0QXJ6071`
L01WIfL0OGem05MGE`1UIFD0Ng]k07MgM`1kNg/0UIFE08b<S01TI6@0L71`08R8R01VIVH0LG5a079b
LP1dM7@0KFe]07=cL`1XJ6P0O7al08:2PP1aLG40LW9b08:2PP1fMWH0LG5a071`L01gMgL0Lg=c07Ui
N@1hN7P0MWIf07EeM@1cLg<0N7Qh07IfMP1cLg<0MGEe07IfMP1cLg<0N7Qh07IfMP1eMGD08P3oool0
0200oooo00D0Q8B408N7Q`27QhL0Q8B408^;R`0308N7Q`0308^;R`24Q8@0QhN70080QhN70140Q8B4
08J6QP2;Rh/0QhN708J6QP1fMWH0PH6107QhN020P800O7al08Z:RP2@T900Ogmo09:BTP22PX80P820
0::RXP0508N7Q`0B0:JVYP23Ph<0W9bL0;Bd]02/[:`0U9BD0:2PX02XZ:P0TY:B09ZJVP2YZJT0XZ:R
0;Ng]`2h^;P0Z:RX09jNWP34a<@0XJ6Q0`27QhL04`22PX80OGem08N7Q`21PH40PX:207MgM`1FEUH0
Kfm_08B4Q02NWYh0X:2P0;:b/P1nOWh0M7Ad0<30`01bLW80YZJV06ATI01;Bd/00P1mOGd05P26QXH0
V9RH08f=S@2CTi<0WinO09FEU@1_Kfl0KFe]08F5Q@1fMWH0TY:B0:NWY`29RHT0R8R808B4Q02;Rh/0
SXj>08N7Q`2;Rh/0QhN708^;R`24Q8@708N7Q`0308^;R`27QhL0oooo01d0oooo00D0RHV908^;R`2;
Rh/0QHF508Z:RP0208V9R@0308J6QP2<S8`0QHF50080RHV900@0Rh^;08N7Q`28R8P0SHf=0P26QXH0
3P1dM7@0OGem071`L01kNg/0MWIf07YjNP2@T900OWin0820P01kNg/0RXZ:0=OGe`2/[:`0R8R80P26
QXH04`28R8P0O7al069RHP1fMWH0Ogmo0861P@1mOGd0PX:208V9R@1fMWH0OGem08N7Q`26QXH0PX:2
07YjNP1mOGd0MWIf09JFUP2DU9@00P29RHT0;025QHD0QXJ608:2PP29RHT0QXJ608^;R`1lO7`0JFUY
071`L01fMWH0XZ:R09^KV`2LW9`0SHf=075aL@2ZZZX0K6a/09^KV`1kNg/0MgMg09>CT`1jNWX0R8R8
09FEU@27QhL0Ph>309NGU`2KVi/0OGem0820P02BTY80PX:209^KV`2YZJT0RHV908R8R02;Rh/0S8b<
08^;R`26QXH0RXZ:08J6QP2:RXX0QhN71@29RHT208J6QP0308Z:RP29RHT0oooo01d0oooo00<0N7Qh
07IfMP1fMWH00P1aLG4207=cL`03071`L01dM7@0LG5a0080Lg=c01@0MWIf07EeM@1cLg<0MGEe071`
L01aLG40J6QX06YZJP1PH600J6QX06EUI@1KFe/0M7Ad06e]K@1JFUX0IVIV07alO036a/H0YZJV07=c
L`80Kfm_00l0Lg=c0451@@11@D40@d=303De=@11@D40EUIF051@D01ADE40CDe=04i>CP1<C4`0E5AD
03Lg=`0Z:RX00P10@4004P15ADD0J6QX07=cL`1cLg<0KFe]07IfMP1dM7@0Lg=c07IfMP1lO7`0Lg=c
07]kN`1ZJVX0G5aL07moO`1cLg<0HF5Q08B4Q080IVIV00H0H61P06a/K025QHD0VYZJ08f=S@1XJ6P2
07=cL`0506][J`1NGUh0KVi^07moO`1mOGd00P23Ph<00`1lO7`0Ph>307moO`02075aL@0807]kN`1d
M7@0Kfm_071`L01aLG40L71`075aL@1eMGD507=cL`80L71`00<0LG5a07=cL`3oool08@3oool00200
oooo0`2;Rh/208B4Q00308^;R`27QhL0Q8B40080QhN700<0Q8B408N7Q`27QhL00P27QhL03P2;Rh/0
QhN708V9R@1lO7`0Ng]k07AdM028R8P0PX:208N7Q`28R8P0QXJ607QhN023Ph<0N7Qh0P27QhL0202;
Rh/0Ph>308:2PP27QhL0Jf][04i>CP1DE5@0JVYZ0P1gMgL207emO@0:06UYJ@1aLG40KFe]07EeM@1R
HV80LW9b04i>CP13@d<0M7Ad08f=S@80QhN700@0QHF508N7Q`1kNg/0PH610P27QhL01@1hN7P0IVIV
04Q8B01`L700XZ:R0080[:b/01X0[Zj^05IFEP2DU9@0UIFE0;Bd]02BTY80K6a/065QH@24Q8@0QhN7
096AT@29RHT0OWin0:RXZ02CTi<0Q8B406e]K@2HV9P0OGem09JFUP2<S8`0QhN708b<S02?Shl0Q8B4
08^;R`80QhN700<0Q8B408N7Q`27QhL00P27QhL01`2;Rh/0QhN708N7Q`27QhL0Q8B408^;R`27QhL0
7P3oool208R8R00608Z:RP27QhL0QhN708Z:RP29RHT0QhN70P29RHT02027QhL0Rh^;08V9R@26QXH0
RHV908Z:RP25QHD0RHV90P1iNGT0F01]KFd0NWYj06m_K`1gMgL0R8R807moO`21PH40TI6A08B4Q02m
_Kd0QXJ608V9R@28R8P0QXJ608R8R02BTY80MgMg07]kN`2@T900SXj>0861P@2@T900UiNG0820P028
R8P0UIFE09>CT`26QXH0[Jf]09VIV@2HV9P0YjNW09bLW029RHT0QXJ608F5Q@2:RXX0PH6108J6QP28
R8P0RHV907moO`1fMWH0GemO07inOP2CTi<0U9BD0::RXP2PX:00KVi^09FEU@2:RXX0YjNW08b<S01o
Ogl0Jf][0861P@2DU9@0Ti>C08V9R@1mOGd0ZZZZ08f=S@2:RXX0KFe]09BDU01oOgl0YjNW09nOW`26
QXH0RXZ:08f=S@27QhL0S8b<08V9R@2;Rh/0QhN708^;R`26QXH0RHV908J6QP2:RXX0RHV908J6QP29
RHT0QHF508b<S029RHTN0?ooo`80KVi^00H0LG5a07EeM@1eMGD0LG5a07=cL`1eMGD207=cL`0_07Ee
M@1fMWH0Lg=c071`L01cLg<0LG5a06i^KP1bLW80J6QX06YZJP1PH600GEeM05EEE@1IFET0LW9b06QX
J01iNGT0Ph>307inOP2n_[h0Kfm_071`L01gMgL0MWIf07=cL`2NWYh0UiNG09JFUP2LW9`0S8b<07Yj
NP27QhL0TY:B08N7Q`2:RXX0X:2P09FEU@2HV9P0_[jn0<O7a`3AdM40/k>c08N7Q`1cLg<0Kfm_071`
L01eMGD00P1fMWH207=cL`0O07EeM@1lO7`0Ng]k07alO01UIFD0G5aL06m_K`1/K6`0PH6107IfMP1W
IfL0KVi^06e]K@22PX80LG5a06][J`23Ph<0MgMg079bLP1]KFd0Ogmo06a/K01iNGT0J6QX079bLP1a
LG40SHf=08j>SP1_Kfl0LG5a079bLP0207AdM00>07=cL`1fMWH0MGEe07IfMP1`L700Lg=c071`L01a
LG40Lg=c071`L01cLg<0LG5a07AdM01cLg<R0?ooo`00803oool208B4Q00508^;R`27QhL0QhN708B4
Q027QhL00P24Q8@00`2;Rh/0Q8B408N7Q`0208B4Q00>08V9R@24Q8@0QXJ608Z:RP1mOGd0O7al07If
MP23Ph<0PX:207AdM027QhL0QHF508f=S@27QhL308R8R00308N7Q`2:RXX0QhN70080Ph>30100Hf=S
051@D018B4P0@d=304a<C018B4P0GUiN04a<C016ATH0Bd];04a<C01BDU80MWIf07MgM`1kNg/0PH61
0P27QhL208>3P`0F08V9R@23Ph<0PH610861P@27QhL0PX:206a/K01CDe<0Fe]K07UiN@2VYZH0YJFU
0;Zj^P2QXJ40L71`0;6a/@2o_kl0[Jf]09:BTP1EEED0MgMg07emO@80UYJF00T0OWin09JFUP2@T900
S8b<06EUI@2BTY80RXZ:0;Ng]`2>SXh00P27QhL0102?Shl0Q8B408B4Q02;Rh/308N7Q`0608B4Q027
QhL0QhN708N7Q`2;Rh/0Q8B41027QhLN0?ooo`0408V9R@27QhL0S8b<08J6QP80RHV90100Rh^;08F5
Q@25QHD0S8b<08N7Q`2;Rh/0QhN708J6QP2;Rh/0QhN708J6QP2:RXX0NGUi07=cL`1YJFT0M7Ad0P1m
OGd208:2PP0608Z:RP27QhL0SHf=08J6QP28R8P0RXZ:0`27QhL02`2@T900Ogmo08j>SP2GUiL0TY:B
09^KV`2HV9P0Vi^K096AT@2MWId0VIVI0080UIFE00H0YJFU08j>SP2<S8`0Rh^;08b<S029RHT208N7
Q`0T08V9R@23Ph<0QXJ608J6QP28R8P0Ph>307UiN@1VIVH0LW9b07inOP2d];@0U9BD09bLW029RHT0
JFUY0:JVYP2RXZ80UiNG08f=S@1PH600TY:B08J6QP2;Rh/0SXj>08Z:RP2MWId0PX:208f=S@1YJFT0
T92@07alO02d];@0TY:B08V9R@28R8P0TY:B0P29RHT01P2<S8`0RHV908V9R@29RHT0QhN708J6QP80
RHV900H0RXZ:08N7Q`2;Rh/0RHV908^;R`29RHTN0?ooo`0707QhN01eMGD0M7Ad071`L01cLg<0N7Qh
07IfMP02075aL@0507AdM01eMGD0MWIf07EeM@1cLg<00P1eMGD2075aL@0X06QXJ01PH600FEUI05]K
F`1YJFT0N7Qh06UYJ@1/K6`0L71`075aL@1hN7P0KVi^079bLP1eMGD0KVi^075aL@1dM7@0PX:208b<
S02e]KD0b/[:0<W9b@3=cLd0bl_;0;Vi^@2n_[h0e]KF0<[:bP34a<@0_;bl0:f][@2<S8`0Q8B407al
O01iNGT0Lg=c07EeM@1fMWH0LW9b06m_K`80MWIf00P0Lg=c071`L01jNWX0NWYj08:2PP1dM7@0Shn?
06=SH`80F5QH01<0H61P071`L01LG5`0GemO06e]K@1`L700TI6A07YjNP1WIfL0Jf][07moO`21PH40
HF5Q07EeM@1[Jf/0LW9b05mOG`1oOgl0NGUi0080Lg=c00@0NGUi07QhN01hN7P0M7Ad0`1cLg<02P1e
MGD0L71`07=cL`1cLg<0LG5a07EeM@1fMWH0Lg=c07IfMP1cLg<R0?ooo`00803oool00`27QhL0Rh^;
08^;R`0208^;R`80QhN700@0S8b<08B4Q027QhL0Q8B40P27QhL03024Q8@0QXJ608N7Q`29RHT0PH61
07moO`27QhL0PX:208J6QP1eMGD0Rh^;08>3P`80QhN700`0Ph>30=CDe027QhL0Rh^;08J6QP27QhL0
QHF508^;R`29RHT0QhN708^;R`27QhL208^;R`0=08>3P`27QhL0R8R808R8R027QhL0Q8B408:2PP2;
Rh/0Ph>308^;R`27QhL0OGem08^;R`0208N7Q`0W0861P@23Ph<0QhN708J6QP1hN7P0PX:207IfMP1X
J6P0De=C06e]K@2EUID0Zj^[09fMW@2`/;00QhN707AdM02ATI40[Zj^0:>SX`2>SXh0Ng]k07emO@2<
S8`0NGUi08b<S01nOWh0WYjN09VIV@1aLG40R8R808N7Q`2e]KD0TY:B08N7Q`2HV9P0QhN708^;R`27
QhL0Rh^;0080QhN70P24Q8@00`27QhL0Rh^;08N7Q`0208N7Q`0408^;R`27QhL0QhN708B4Q1h0oooo
00<0RHV908b<S028R8P00P28R8P02P29RHT0R8R808Z:RP27QhL0Rh^;08F5Q@2;Rh/0RHV908F5Q@28
R8P208V9R@0>08J6QP1cLg<0Jf][06a/K023Ph<0MgMg08R8R025QHD0Ti>C08V9R@27QhL0iNGU08J6
QP2:RXX208V9R@0:08F5Q@2>SXh0SHf=08V9R@2:RXX0QXJ608Z:RP29RHT0P82008V9R@80R8R80P2;
Rh/0<@27QhL0SHf=08F5Q@2@T900RHV908F5Q@2:RXX0Q8B408J6QP25QHD0Q8B408J6QP28R8P0PX:2
08R8R01lO7`0M7Ad06QXJ028R8P0RHV909JFUP23Ph<0TY:B07MgM`21PH40PX:209bLW02IVIT0Rh^;
06i^KP1oOgl0S8b<07QhN02DU9@0PX:20:2PX02?Shl0M7Ad08B4Q023Ph<0][Jf08f=S@25QHD0UYJF
08V9R@2:RXX0RHV908b<S026QXH00`29RHT01P26QXH0RXZ:08V9R@29RHT0QXJ608R8R080RHV900<0
QhN70?ooo`3oool0703oool00`1cLg<0M7Ad06i^KP0206i^KP0907=cL`1bLW80L71`07EeM@1fMWH0
LG5a07IfMP1cLg<0LG5a0080Lg=c00H0LW9b07IfMP1NGUh0BTY:055AD@1/K6`206e]K@0C07=cL`21
PH40Lg=c07EeM@2TY:@0L71`075aL@1eMGD0Lg=c075aL@1fMWH0MgMg07=cL`1aLG40Kfm_075aL@1_
Kfl0K6a/07=cL`02079bLP0X07IfMP1iNGT0MWIf07EeM@1bLW80NWYj07=cL`1hN7P0LW9b06a/K01_
Kfl0M7Ad075aL@1_Kfl0M7Ad07YjNP1hN7P0M7Ad07MgM`1mOGd0SXj>06IVIP1PH600E5AD05EEE@1J
FUX0OGem05mOG`1UIFD0KFe]06i^KP1JFUX0L71`07=cL`1[Jf/0OWin07AdM01lO7`0JFUY06i^KP80
Jf][00<0Ph>306e]K@1^KVh00P1dM7@01@1aLG40Lg=c07AdM01`L700Lg=c0080N7Qh00H0L71`075a
L@1cLg<0Lg=c071`L01^KVh207=cL`0307EeM@3oool0oooo0200oooo000P0?ooo`0308B4Q027QhL0
Q8B400<0QhN700H0Ph>308N7Q`27QhL0QhN708B4Q027QhL308B4Q00608J6QP27QhL0RHV906i^KP1h
N7P0NWYj0P27QhL02@1mOGd0QhN709NGU`27QhL0QHF50?7al@27QhL0Rh^;08V9R@0208B4Q0D0QhN7
01@0RHV908J6QP28R8P0QhN7096AT@27QhL0T92@08f=S@24Q8@0S8b<08J6QP2<S8`0Shn?08J6QP1m
OGd0NGUi08>3P`25QHD0PH6108>3P`80QhN701h0PX:208N7Q`1aLG40HF5Q07YjNP1nOWh0Shn?08R8
R024Q8@0Rh^;071`L02MWId0[Jf]0:BTY02XZ:P0O7al06a/K02?Shl0MgMg09nOW`1cLg<0UIFE09fM
W@1jNWX0N7Qh09JFUP2@T900TY:B07alO02ATI4408N7Q`0808B4Q027QhL0Rh^;08N7Q`24Q8@0Rh^;
08N7Q`2;Rh/208B4Q0<0QhN77P3oool208V9R@0508N7Q`29RHT0Rh^;08^;R`27QhL00`29RHT00`27
QhL0Rh^;08N7Q`0208N7Q`0B08R8R029RHT0NWYj06IVIP1bLW80NWYj07emO@21PH40O7al08J6QP2>
SXh0RXZ:0820P03]kNd0QXJ608b<S02:RXX0QhN70P29RHT02P2:RXX0RHV908V9R@27QhL0RHV908B4
Q026QXH0PX:208b<S022PX8208^;R`0;08B4Q02;Rh/0RHV9096AT@2=SHd0R8R808^;R`23Ph<0RXZ:
08F5Q@24Q8@00P27QhL01`24Q8@0PH6108:2PP1hN7P0JVYZ07AdM01nOWh00P2DU9@08`2>SXh0VIVI
07]kN`24Q8@0Xj>S092@T02;Rh/0RHV908R8R02>SXh0Lg=c09nOW`21PH40X:2P09VIV@1jNWX0M7Ad
0:FUY@2SXj<0U9BD08F5Q@2HV9P0RHV908^;R`29RHT0Rh^;08N7Q`29RHT0RXZ:08V9R@25QHD0S8b<
08J6QP2:RXX0QhN700@0RHV97P3oool0101hN7P0Lg=c07EeM@1cLg<207IfMP0607EeM@1dM7@0Lg=c
07=cL`1eMGD0MWIf0`1eMGD207=cL`0C05aLG01MGEd0Hf=S06e]K@1SHf<0J6QX06a/K01_Kfl0JVYZ
07EeM@1YJFT0TI6A071`L01dM7@0Lg=c07EeM@1hN7P0Lg=c07AdM00207=cL`08075aL@1bLW80KVi^
06i^KP1YJFT0KVi^06YZJP1^KVh2071`L00i079bLP1eMGD0NGUi071`L01dM7@0PH6107YjNP1iNGT0
L71`079bLP1eMGD0LG5a06e]K@1^KVh0Jf][079bLP1`L700I6AT06m_K`1kNg/0PH6107inOP26QXH0
N7Qh05EEE@1`L700GUiN05ADE01oOgl0Shn?07=cL`1VIVH0NGUi07inOP26QXH0Lg=c06e]K@1WIfL0
Rh^;08j>SP1gMgL0NWYj07inOP1cLg<0MWIf07=cL`1fMWH0MGEe07=cL`1aLG40Lg=c075aL@1dM7@0
L71`075aL@1eMGD0N7Qh00<0Lg=c8P3oool00200oooo00@0QhN708B4Q024Q8@0Q8B40`27QhL00`24
Q8@0Rh^;08N7Q`0308N7Q`0B08^;R`27QhL0Q8B408>3P`1fMWH0O7al07=cL`27QhL0MWIf08:2PP1m
OGd0N7Qh08R8R029RHT0QhN70;^k^`27QhL0Rh^;0`27QhL01@24Q8@0QhN708V9R@27QhL0QXJ60080
QhN700@0TI6A08j>SP2LW9`0Rh^;0P2BTY801@2;Rh/0RXZ:08f=S@2<S8`0Ogmo0080QhN70P26QXH0
1@27QhL0Ph>308N7Q`21PH40QhN70080OWin01`0Ogmo06QXJ01NGUh0OGem0::RXP2DU9@0WIfM09JF
UP2=SHd0U9BD0:VYZ@2b/[80Q8B408j>SP2@T900QhN706YZJP2KVi/0TI6A09JFUP2MWId0NWYj06][
J`2ZZZX0Ph>30:6QX@27QhL0Q8B41027QhL01@2;Rh/0Q8B408N7Q`27QhL0Q8B40080QhN700<0Rh^;
08N7Q`27QhL00`27QhLN0?ooo`0508V9R@27QhL0QhN708V9R@2;Rh/00P29RHT00`27QhL0RXZ:08V9
R@0208V9R@0508J6QP28R8P0RHV908V9R@23Ph<00P1`L7003@1^KVh0P82007inOP24Q8@0OGem08:2
PP2CTi<0PX:20:>SX`3MgMd0RHV908f=S@2:RXX00P29RHT04`2:RXX0QhN708V9R@29RHT0R8R808J6
QP1nOWh0PH6107inOP2>SXh0P82008^;R`2:RXX0QhN708V9R@2=SHd0RXZ:08^;R`2>SXh00P23Ph<0
9@28R8P0QhN708>3P`29RHT0PX:208R8R025QHD0PX:207]kN`1_Kfl0L71`092@T02JVYX0QXJ609BD
U027QhL0QHF5096AT@2>SXh0Y:BT09bLW028R8P0OWin096AT@1cLg<0VIVI08R8R02EUID0WinO07mo
O`1dM7@0^KVi08>3P`2NWYh0Shn?08j>SP2;Rh/00P29RHT02`26QXH0RXZ:08N7Q`2;Rh/0RHV908N7
Q`29RHT0QXJ608b<S029RHT0QXJ600<0RHV97P3oool01@1cLg<0MGEe07EeM@1hN7P0MWIf0080Lg=c
00<0MGEe075aL@1cLg<00P1cLg<0501`L700KVi^07=cL`1hN7P0Kfm_06=SH`1LG5`0Hf=S06IVIP1g
MgL0Lg=c06a/K01jNWX0PH6106MWI`2HV9P0];Bd07=cL`1fMWH0M7Ad0P1cLg<0<P1hN7P0LG5a079b
LP1cLg<0M7Ad06m_K`1TI6@0GUiN05aLG01TI6@0HV9R06a/K01ZJVX0KFe]075aL@1cLg<0Kfm_07mo
O`1kNg/0Jf][06a/K01dM7@0LG5a06m_K`1cLg<0L71`07=cL`1hN7P0Lg=c06UYJ@1aLG40O7al08R8
R01`L700Hf=S06a/K01RHV80IfMW079bLP1FEUH0K6a/09>CT`1ZJVX0FUYJ07moO`1dM7@0MGEe06QX
J01fMWH0Ng]k0P1cLg<01P2BTY80LG5a07IfMP1lO7`0OWin07IfMP80Lg=c00/0L71`075aL@1eMGD0
MWIf07=cL`1eMGD0Lg=c071`L01dM7@0Lg=c071`L00307=cLb80oooo000P0?ooo`80Rh^;1027QhL0
0`2;Rh/0QhN708^;R`0208N7Q`0A08^;R`24Q8@0Q8B408b<S027QhL0PH6106][J`27QhL0P82008R8
R02EUID0PX:208N7Q`2BTY80QhN707alO032`/800P27QhL01`2;Rh/0QhN708N7Q`27QhL0Rh^;08J6
QP2:RXX00P27QhL03P22PX80QXJ608B4Q01mOGd0Ti>C08b<S02BTY80T92@08f=S@2>SXh0SHf=08b<
S02@T900R8R80P1oOgl01@26QXH0P8200861P@23Ph<0PH610080QhN700d0PX:207MgM`1^KVh0JVYZ
08Z:RP2^[Zh0Shn?09jNWP22PX80XZ:R08N7Q`1kNg/0c/k>0080UiNG00d0SXj>08N7Q`1hN7P0O7al
096AT@2CTi<0Y:BT0861P@1]KFd0WIfM0820P02IVIT0XJ6Q00@0QhN700<0Q8B408^;R`27QhL00`27
QhL208B4Q080QhN700@0Q8B408N7Q`27QhL0QhN77P3oool00`28R8P0RXZ:08V9R@0208V9R@0J08J6
QP2:RXX0QXJ608b<S029RHT0QXJ608Z:RP27QhL0QXJ608f=S@26QXH0Q8B406e]K@1cLg<0Kfm_07al
O024Q8@0NWYj08:2PP2<S8`0RHV907YjNP3Ogml0Z:RX08Z:RP2=SHd308V9R@0308Z:RP26QXH0Rh^;
0080RHV900T0Ph>307moO`27QhL0Ogmo08f=S@26QXH0Rh^;08b<S029RHT00P2;Rh/01P2:RXX0S8b<
08R8R025QHD0QXJ608f=S@80QXJ601h0QhN708:2PP29RHT0R8R80861P@20P800MGEe06a/K01eMGD0
W9bL08R8R02LW9`0N7Qh09bLW02ATI40MgMg0<[:bP1nOWh0PH610:2PX029RHT0P82008J6QP2BTY80
S8b<0:6QX@25QHD0PH610:VYZ@23Ph<209RHV0@0RHV900<0QHF508b<S029RHT00`29RHT01@27QhL0
RHV908^;R`29RHT0QHF500<0RHV97P3oool00`1^KVh0LG5a07=cL`0207=cL`08071`L01aLG40L71`
07AdM01cLg<0L71`075aL@1eMGD207=cL`0@071`L01cLg<0JVYZ05EEE@1GEeL0H61P05iNGP1UIFD0
JVYZ06e]K@1dM7@0JVYZ0;2`/02OWil0M7Ad07IfMP<0Lg=c0P1aLG4307=cL`0E071`L01WIfL0M7Ad
071`L01]KFd0JVYZ06a/K01^KVh0KFe]06m_K`1`L700LG5a06i^KP1bLW80MWIf07MgM`1kNg/0MgMg
07IfMP1eMGD0L71`0080Lg=c01`0KFe]07QhN01bLW80JFUY05ADE01VIVH0JVYZ07MgM`1RHV80LW9b
07moO`1XJ6P0Q8B405=CD`1GEeL0SHf=07=cL`1gMgL0O7al07IfMP1ZJVX0MgMg07AdM025QHD0RHV9
07=cL`1fMWH0Kfm_101cLg<00`1aLG40M7Ad07=cL`0307=cL`0507EeM@1hN7P0MWIf07=cL`1aLG40
0`1cLg<R0?ooo`00803oool00`24Q8@0QhN708N7Q`0208N7Q`0308B4Q027QhL0QhN700D0QhN701@0
Ph>308N7Q`24Q8@0Q8B406e]K@1mOGd0QhN708J6QP27QhL0Ti>C07alO027QhL0RHV908N7Q`3clo<0
QhN708Z:RP2=SHd0QhN708^;R`80Ph>30100QHF508N7Q`2;Rh/0Q8B40:6QX@1iNGT0O7al07IfMP24
Q8@0/[:b09^KV`2@T900ZZZZ09VIV@2>SXh0SHf=0`27QhL0101oOgl0QhN708>3P`25QHD30861P@0L
08N7Q`1nOWh0Ogmo07QhN01QHF40GemO0::RXP2PX:00XJ6Q08N7Q`2NWYh0Ph>30861P@2b/[80Z:RX
09FEU@2MWId0LG5a08b<S01nOWh0Xj>S08n?S`2MWId0QXJ608N7Q`1eMGD0Xj>S07alO0D0QhN700<0
Q8B408N7Q`27QhL01`27QhL01024Q8@0QhN708N7Q`2;Rh/N0?ooo`0308V9R@2;Rh/0RHV90080RHV9
01h0QhN708V9R@29RHT0Rh^;08J6QP29RHT0Rh^;08V9R@27QhL0S8b<08N7Q`23Ph<0HV9R06i^KP1h
N7P0Ogmo07inOP2:RXX0PH6108n?S`1oOgl0O7al0?KfmP28R8P0RHV908f=S@26QXH0SHf=08Z:RP27
QhL208R8R00?08b<S01cLg<0M7Ad08V9R@28R8P0OWin06i^KP1mOGd0TI6A07UiN@2>SXh0Shn?08^;
R`2ATI40SXj>0080RHV900D0QHF508V9R@24Q8@0QhN708B4Q00208J6QP0708R8R025QHD0Ng]k07Ui
N@1]KFd0JVYZ09RHV00209:BTP0D0820P02LW9`0OWin08V9R@2QXJ40RHV909nOW`2ATI40Ng]k08V9
R@1aLG40Ti>C08F5Q@2SXj<0QXJ609^KV`1kNg/0WinO07MgM`2IVIT408V9R@0308N7Q`2;Rh/0RHV9
00L0RHV900@0QhN708V9R@26QXH0RXZ:7P3oool00`1hN7P0MWIf07=cL`0207=cL`0<07EeM@1cLg<0
Lg=c07IfMP1`L700Lg=c07IfMP1cLg<0MGEe07MgM`1eMGD0Kfm_0P1HF5P08@1KFe/0IfMW06ATI01Y
JFT0M7Ad07alO01TI6@0HV9R09^KV`1bLW80LG5a07=cL`1`L700MGEe07UiN@1eMGD0M7Ad079bLP1d
M7@0EeMG03Ti>@22PX80OGem07IfMP1ADE40=CDe06YZJP1DE5@0EUIF06YZJP1`L700NGUi07]kN`02
07AdM00507MgM`1cLg<0L71`07AdM01bLW800P1fMWH01`1cLg<0MgMg06UYJ@1^KVh0MGEe07=cL`1]
KFd00P1VIVH0501WIfL0MgMg06UYJ@1jNWX0J6QX051@D024Q8@0IfMW07MgM`1_Kfl0G5aL06ATI01V
IVH0PH61075aL@2=SHd0LW9b07AdM01UIFD0RXZ:101cLg<00`1eMGD0MWIf07=cL`0707=cL`0407Ee
M@1cLg<0L71`075aLB80oooo000P0?ooo`@0Q8B40P27QhL01@2;Rh/0QhN708N7Q`2;Rh/0Q8B40080
QhN702X0S8b<08N7Q`24Q8@0MgMg05aLG027QhL0S8b<09>CT`28R8P0NGUi08R8R01iNGT0RXZ:0:BT
Y02o_kl0RHV908^;R`2?Shl0Q8B40820P027QhL0P82008F5Q@27QhL0Shn?08:2PP27QhL0PH6107in
OP1jNWX0MgMg08:2PP2:RXX0Ph>3079bLP21PH40TY:B092@T027QhL0QHF508N7Q`1oOgl208N7Q`<0
PH6101l0OGem07moO`21PH40Ph>307inOP1iNGT0AdM708b<S02TY:@0S8b<08f=S@1lO7`0MGEe08j>
SP1RHV80h>3P08F5Q@2?Shl0Fe]K096AT@1`L700QhN7096AT@2HV9P0UiNG08N7Q`1eMGD0Ph>30:>S
X`24Q8@0Rh^;00<0QhN700@0Q8B408N7Q`27QhL0Rh^;1P27QhL01024Q8@0Rh^;08N7Q`27QhLN0?oo
o`80RHV900D0QhN708V9R@2;Rh/0QXJ608Z:RP0208V9R@0J08b<S027QhL0Rh^;08V9R@2:RXX0RHV9
08N7Q`1gMgL0EEEE07emO@1gMgL0P82008^;R`20P800T92@07EeM@23Ph<0][Jf0=;BdP2:RXX0RHV9
08f=S@27QhL0R8R808f=S@25QHD208R8R00708j>SP20P800S8b<08Z:RP25QHD0Ph>308:2PP0208V9
R@0<08>3P`21PH40TI6A09VIV@2CTi<0RXZ:08R8R029RHT0QHF508R8R023Ph<0QHF50P26QXH05`22
PX80Ogmo0820P021PH40O7al07emO@1;Bd/0RXZ:0:BTY02EUID0U9BD07UiN@1cLg<0T92@06IVIP3M
gMd0NGUi09NGU`1KFe/0Ti>C07IfMP2ATI40Ti>C0080VYZJ00H0RHV907inOP2EUID0[jn_08F5Q@2<
S8`308V9R@0608N7Q`2;Rh/0QXJ608Z:RP29RHT0Rh^;1029RHT01027QhL0S8b<08V9R@29RHTN0?oo
o`80N7Qh00D0MGEe07QhN01fMWH0L71`075aL@0207=cL`0<07AdM01eMGD0MWIf07=cL`1`L700Lg=c
07EeM@1[Jf/0F5QH06=SH`1EEED0FUYJ0P1eMGD05P1mOGd0IVIV06QXJ02EUID0X:2P07=cL`1_Kfl0
LW9b07AdM01kNg/0NWYj07IfMP1dM7@0LW9b07=cL`1]KFd0MgMg07alO01hN7P0NGUi07alO01iNGT2
071`L00;07inOP26QXH0OWin07QhN01eMGD0M7Ad07=cL`1gMgL0Lg=c06a/K01eMGD00P1fMWH02`1d
M7@0Kfm_06i^KP1^KVh0Jf][075aL@1OGel0LG5a07alO01oOgl0OGem0080J6QX00X0MGEe06YZJP2<
S8`0GemO0820P01QHF40MgMg075aL@1oOgl0MgMg0P1jNWX01P1cLg<0MgMg08V9R@2;Rh/0LG5a07Ad
M0<0Lg=c00H0MGEe07IfMP1`L700LG5a07=cL`1fMWH407=cL`0407EeM@1dM7@0Lg=c07=cLb80oooo
000P0?ooo`<0QhN700<0Rh^;08N7Q`27QhL00P27QhL01@24Q8@0Rh^;08N7Q`27QhL0S8b<0080Rh^;
0100QhN707IfMP1JFUX0RHV906m_K`20P800RXZ:08:2PP25QHD0MWIf08Z:RP2i^KT0QhN708V9R@24
Q8@0QXJ60P27QhL01`28R8P0QXJ608>3P`27QhL0TI6A07inOP26QXH00P21PH403@24Q8@0O7al0820
P029RHT0QhN708>3P`27QhL0SHf=092@T02:RXX0Q8B408N7Q`25QHD00P1oOgl01@25QHD0PH6108F5
Q@1mOGd0N7Qh0080OWin01X0OGem07inOP1=CDd0UYJF0:JVYP2CTi<0/[:b06m_K`1eMGD0VIVI06m_
K`2`/;00UiNG09bLW01ZJVX0NWYj08:2PP1nOWh0TY:B0:RXZ02HV9P0QXJ608^;R`25QHD0Rh^;08B4
Q0@0QhN70P2;Rh/00`24Q8@0QhN708N7Q`0908N7Qah0oooo0P29RHT08@26QXH0RXZ:08J6QP29RHT0
Rh^;08J6QP27QhL0S8b<08V9R@25QHD0RXZ:08^;R`2:RXX0QXJ6079bLP1=CDd0QXJ607YjNP2=SHd0
RXZ:08J6QP2>SXh0L71`08j>SP3Shn<0[:b/08j>SP2<S8`0SHf=08V9R@28R8P0RHV908N7Q`0208F5
Q@0f096AT@25QHD0SXj>08J6QP22PX80QXJ60861P@23Ph<0QhN708R8R024Q8@0SHf=09>CT`2ATI40
S8b<08J6QP2:RXX0R8R808F5Q@26QXH0R8R808B4Q028R8P0PX:208>3P`21PH40P82007inOP1lO7`0
EeMG08j>SP2YZJT0OWin0:6QX@1gMgL0Kfm_08n?S`1oOgl0^KVi08b<S02MWId0L71`08>3P`26QXH0
QHF508b<S02PX:00VYZJ0861P@2?Shl0WYjN09bLW027QhL0Rh^;0`29RHT01028R8P0RXZ:08N7Q`2;
Rh/708V9R@0308^;R`29RHT0RHV901h0oooo0P1cLg<07P1`L700LG5a071`L01cLg<0MWIf071`L01e
MGD0M7Ad07=cL`1^KVh0L71`079bLP1aLG40L71`06EUI@1?Cdl0KFe]07QhN021PH40LW9b07EeM@1m
OGd0Hf=S07QhN02n_[h0YZJV07UiN@1lO7`0NWYj07AdM0@0LW9b01<0KFe]07AdM01hN7P0Ng]k07If
MP1`L700LW9b07=cL`1dM7@0L71`07=cL`1aLG40NGUi07]kN`1fMWH0MGEe079bLP1eMGD0M7Ad0080
MgMg00P0M7Ad07=cL`1dM7@0MGEe07]kN`1bLW80L71`06m_K`80JVYZ01P0Jf][0861P@1GEeL0J6QX
07EeM@1RHV80JVYZ0820P02<S8`0IfMW07YjNP1_Kfl0NWYj07IfMP1hN7P0KFe]075aL@1jNWX0JVYZ
07MgM`2DU9@0Rh^;07EeM@1fMWH307=cL`0406i^KP1aLG40MGEe07IfMPL0Lg=c00<0MWIf07=cL`1c
Lg<08P3oool00200oooo0P27QhL00`24Q8@0QhN708B4Q00308N7Q`0<08B4Q02;Rh/0Rh^;08>3P`27
QhL0Q8B408N7Q`24Q8@0Lg=c079bLP22PX80VIVI0P2=SHd208V9R@80SXj>00@0oooo08R8R02;Rh/0
Shn?1027QhL00`26QXH0P82007emO@0208^;R`0908j>SP27QhL0PH6108:2PP21PH40QhN708b<S027
QhL0R8R80080RHV900@0QhN708Z:RP23Ph<0Q8B40P27QhL207moO`0N08:2PP27QhL0PH6107moO`1i
NGT0OWin07emO@1dM7@0EeMG09NGU`2XZ:P0OGem09:BTP27QhL0LG5a08f=S@2>SXh0Z:RX09fMW@2N
WYh0O7al05YJFP2FUYH0PX:2096AT@2GUiL0SHf=07alO02ZZZX0X:2P0P27QhL308^;R`0308N7Q`24
Q8@0Rh^;00P0QhN700@0Rh^;08N7Q`27QhL0QhN77P3oool208V9R@0408N7Q`2;Rh/0QhN708^;R`80
QXJ600@0QHF508Z:RP2:RXX0QhN70P29RHT01@2;Rh/0Q8B405UIF@1@D500MgMg0080Ph>300/0RXZ:
08^;R`28R8P0P82008N7Q`3inOT0Rh^;08f=S@2>SXh0RHV908R8R00208V9R@0608R8R026QXH0QhN7
08j>SP25QHD0RXZ:0P24Q8@02`25QHD0OGem07inOP2;Rh/0QHF508V9R@2@T900Ti>C08n?S`2<S8`0
RHV90080QhN700D0R8R808F5Q@26QXH0Ph>308R8R00208F5Q@0L07emO@1oOgl0PH6107moO`1]KFd0
V9RH0:2PX02>SXh0XJ6Q08B4Q01`L700TI6A08J6QP2OWil0VIVI09FEU@2?Shl0IFEU08j>SP1jNWX0
T92@0:b/[02FUYH0LG5a09nOW`2RXZ80RHV908J6QP80R8R800@0RXZ:08V9R@27QhL0S8b<1`29RHT0
0`26QXH0RXZ:08V9R@0208V9RAh0oooo0P1cLg<0101eMGD0MWIf07EeM@1fMWH2071`L0<0LG5a0180
MGEe07AdM01hN7P0MWIf071`L015ADD0>CTi05mOG`1IFET0IVIV071`L01dM7@0L71`05mOG`1YJFT0
Ti>C07IfMP1eMGD207=cL`0I079bLP1cLg<0M7Ad07=cL`1gMgL0Ng]k07IfMP1ZJVX0KVi^06e]K@1c
Lg<0M7Ad06UYJ@1TI6@0LG5a06e]K@1cLg<0O7al07moO`1kNg/0MGEe07MgM`1eMGD0LG5a07=cL`02
07MgM`0P071`L01cLg<0M7Ad07MgM`1cLg<0Kfm_07=cL`1jNWX0Ogmo07QhN01aLG40QHF508Z:RP1]
KFd0J6QX07UiN@1YJFT0L71`07AdM01/K6`0QhN7075aL@1[Jf/0I6AT07=cL`2DU9@0PH6105mOG`1^
KVh0OGem07=cL`1`L70206i^KP04075aL@1cLg<0MGEe07AdM0L0Lg=c00<0L71`075aL@1cLg<00P1c
Lg<R0?ooo`00803oool208^;R`<0QhN700<0Rh^;08B4Q024Q8@00P24Q8@00`27QhL0Rh^;08B4Q002
08N7Q`0708>3P`1<C4`0Kfm_07YjNP2>SXh0Ng]k08F5Q@0208N7Q`0508Z:RP25QHD0l?3`08Z:RP26
QXH00P28R8P00`27QhL0R8R808R8R00208R8R080Ph>300T0QhN708b<S026QXH0Rh^;08N7Q`22PX80
Ng]k08N7Q`22PX800`27QhL09P28R8P0Rh^;08^;R`22PX80QhN708B4Q027QhL0Ogmo08:2PP21PH40
QHF50861P@1bLW80MWIf07UiN@1oOgl0KVi^08n?S`2@T900ZJVY09>CT`2EUID0PH6107YjNP20P800
WYjN09>CT`2?Shl0TY:B04];B`27QhL0Ph>309FEU@2`/;00VYZJ06a/K027QhL0Rh^;1024Q8@208N7
Q`0308B4Q027QhL0QhN70080QhN700H0Rh^;08N7Q`27QhL0QhN708B4Q02;Rh/308N7Qah0oooo0P28
R8P208V9R@0508J6QP2:RXX0QhN708V9R@27QhL00P29RHT03@2:RXX0QHF508V9R@29RHT0Ph>304A4
A01XJ6P0L71`09NGU`29RHT0SHf=08V9R@1^KVh00P2<S8`0103oool0SHf=08f=S@2=SHd208R8R008
08V9R@28R8P0R8R808V9R@27QhL0QHF508R8R02:RXX208B4Q00907moO`20P800Ogmo08b<S027QhL0
T92@09>CT`2?Shl0RHV90080Rh^;00D0Ph>308Z:RP27QhL0RHV90820P00208J6QP0L08R8R022PX80
OGem0861P@1oOgl0P820079bLP2KVi/0UIFE09^KV`26QXH0SHf=08N7Q`28R8P0QXJ60:RXZ02IVIT0
TY:B09ZJVP1DE5@0RHV907inOP2BTY80XZ:R09:BTP20P800[Jf]09bLW080QhN70P29RHT0102;Rh/0
RHV908N7Q`2;Rh/308V9R@0608Z:RP29RHT0RHV908V9R@25QHD0RXZ:0`29RHTN0?ooo`80KVi^0P1c
Lg<01`1`L700LG5a07EeM@1hN7P0MGEe07QhN01cLg<00P1aLG4207=cL`04071`L01ADE40GemO05iN
GP80P82000X0Ng]k07=cL`1=CDd0M7Ad07]kN`2[Zj/0MgMg07YjNP1hN7P0LG5a0P1bLW82075aL@0@
079bLP1eMGD0LW9b079bLP1aLG40KFe]06UYJ@1VIVH0K6a/079bLP1gMgL0MWIf07inOP22PX80O7al
079bLP80Lg=c00D0LG5a07EeM@1dM7@0Lg=c071`L00207IfMP0L07AdM01aLG40NGUi07alO01eMGD0
L71`06i^KP25QHD0Ng]k06YZJP1SHf<0Jf][07MgM`1oOgl0MgMg08R8R01oOgl0MgMg0820P01YJFT0
Lg=c06UYJ@1aLG40K6a/06e]K@24Q8@0YZJV08^;R`80MGEe0P1hN7P0101fMWH0Lg=c07EeM@1fMWH3
07=cL`04075aL@1cLg<0Lg=c07=cL`80LG5a0`1cLg<R0?ooo`00803oool208B4Q0/0QhN70P2;Rh/0
3P26QXH0?clo06m_K`1lO7`0SXj>08>3P`2;Rh/0QhN705mOG`2:RXX0TI6A09^KV`29RHT0SHf=1027
QhL208:2PP0C08R8R027QhL0P82008:2PP24Q8@0P82007inOP1oOgl0QXJ608:2PP28R8P0PX:208N7
Q`2>SXh0QhN708>3P`27QhL0Rh^;07inOP0208F5Q@0308N7Q`1oOgl0QhN70080Ph>30P21PH40601h
N7P0NGUi0861P@1dM7@0T92@09jNWP2EUID0WinO08N7Q`2KVi/0P82007YjNP2TY:@0Vi^K08>3P`2M
WId0D51@08R8R01^KVh0WIfM0:f][@2<S8`0QHF50:2PX100QhN70P24Q8@208N7Q`0308^;R`3oool0
oooo01`0oooo0`29RHT00`26QXH0RHV908^;R`0308V9R@0408J6QP29RHT0RHV908V9R@80R8R800h0
QXJ60410@01/K6`0Ph>309NGU`22PX80R8R808V9R@1YJFT0RXZ:0<c<c03GemL0S8b<08f=S@<0RHV9
01d0S8b<08Z:RP2:RXX0RXZ:08V9R@26QXH0RHV908F5Q@26QXH0Ph>307moO`23Ph<0PX:208f=S@2:
RXX0Shn?09:BTP2;Rh/0QhN708Z:RP2?Shl0Q8B408V9R@26QXH0RHV90820P027QhL0QXJ608F5Q@02
08:2PP0I07emO@1iNGT0PH6107emO@2;Rh/0U9BD08j>SP2IVIT0TI6A09BDU026QXH0Q8B40::RXP2P
X:00T92@09jNWP1<C4`0TI6A079bLP2MWId0/;2`09VIV@2:RXX0Y:BT08^;R`0;08V9R@0508^;R`29
RHT0RHV908V9R@27QhL00P29RHT00`26QXH0RXZ:0?ooo`0M0?ooo`80N7Qh00@0Lg=c071`L01cLg<0
MWIf0`1cLg<0101`L700Lg=c07=cL`1cLg<206i^KP05075aL@1HF5P0I6AT07MgM`20P8000P1^KVh0
1P1cLg<0LW9b075aL@38b<P0c<c<07IfMP@0Lg=c00<0N7Qh07]kN`1kNg/00P1cLg<05P1gMgL0NGUi
075aL@1gMgL0MGEe06m_K`1/K6`0L71`07QhN01kNg/0O7al07UiN@1gMgL0MWIf07AdM01hN7P0MgMg
07IfMP1bLW80Lg=c06m_K`1aLG4207=cL`0K075aL@1`L700LW9b06a/K01_Kfl0N7Qh06e]K@1[Jf/0
K6a/075aL@20P800Kfm_07IfMP1jNWX0N7Qh07moO`22PX80NWYj05QHF01mOGd0KFe]07QhN023Ph<0
QXJ607QhN01oOgl0MWIf00/0Lg=c00T0MWIf07=cL`1cLg<0Lg=c07EeM@1hN7P0Lg=c071`L01aLG40
8P3oool00200oooo0P27QhL00`2;Rh/0QhN708N7Q`0408N7Q`80Q8B400D0Rh^;08N7Q`24Q8@0QhN7
06UYJ@0208N7Q`0;0:2PX025QHD0Rh^;08R8R01/K6`0P8200>OWi`2<S8`0RHV908R8R02<S8`00P27
QhL01022PX80QhN708N7Q`26QXH308N7Q`0B08R8R023Ph<0QhN70820P01mOGd0Ng]k0861P@27QhL0
Q8B408N7Q`2>SXh0RXZ:08b<S025QHD0QXJ60861P@27QhL0RXZ:0P23Ph<02`25QHD0Ogmo08>3P`21
PH40OGem08N7Q`1`L700MWIf07alO01cLg<0QhN70080TY:B00l0Ti>C08N7Q`22PX80Ogmo08R8R02O
Wil0QhN709fMW@1aLG40MgMg07=cL`2XZ:P0Vi^K0:6QX@2BTY802P27QhL208B4Q00308N7Q`24Q8@0
QhN700L0QhN77P3oool00`29RHT0Rh^;08b<S00708V9R@0C08N7Q`2<S8`0RHV908V9R@2;Rh/0@T92
05QHF01jNWX0Vi^K08>3P`25QHD0RHV906i^KP2>SXh0oooo092@T02<S8`0SXj>08Z:RP0208b<S004
08>3P`29RHT0RHV908b<S0<0RHV90180RXZ:08B4Q029RHT0QXJ608F5Q@1mOGd0PX:208^;R`2:RXX0
Rh^;08j>SP2<S8`0T92@08R8R02<S8`0QhN708V9R@26QXH208N7Q`0308R8R022PX80QXJ60080PX:2
00L0R8R807=cL`1mOGd0OWin07emO@2?Shl0S8b<0080TY:B00/0T92@08:2PP2?Shl0XZ:R0:NWY`25
QHD0TI6A06YZJP1eMGD0KFe]0:NWY`020:FUY@0309^KV`2=SHd0RHV900H0RHV900H0Rh^;08V9R@27
QhL0RHV908^;R`27QhL208V9R@0308^;R`29RHT0QXJ600<0RHV97P3oool00`1cLg<0MWIf07AdM006
07=cL`0D07QhN01eMGD0M7Ad07=cL`1hN7P0MWIf030`<00^;Rh0GemO07=cL`1^KVh0JVYZ079bLP1[
Jf/0Ph>30;Jf]P1iNGT0MWIf07UiN@1_Kfl207QhN004071`L01cLg<0M7Ad07UiN@@0Lg=c00@0L71`
07=cL`1gMgL0N7Qh0P1`L7002`1gMgL0NGUi07MgM`1cLg<0MGEe07UiN@1dM7@0NGUi07MgM`1cLg<0
KFe]0080MGEe01d0M7Ad07=cL`1dM7@0LG5a07AdM01cLg<0KFe]07EeM@1`L700N7Qh07alO01]KFd0
M7Ad07=cL`1nOWh0L71`08B4Q02FUYH0QHF506i^KP1WIfL0H61P06QXJ01QHF40O7al08N7Q`20P800
PH6107UiN@0707=cL`0607IfMP1cLg<0MGEe07QhN01fMWH0MGEe0P1cLg<00`1fMWH0Lg=c071`L003
07=cLb80oooo000P0?ooo`0308N7Q`2;Rh/0QhN700L0QhN70180Q8B408^;R`27QhL0QhN708^;R`0]
;Bd0M7Ad07YjNP2LW9`0NWYj0820P02:RXX0M7Ad08N7Q`2i^KT0QXJ608b<S028R8P408N7Q`0408J6
QP28R8P0S8b<08N7Q`80PX:200`0R8R808>3P`27QhL0R8R808N7Q`1kNg/0PH61096AT@28R8P0QhN7
08J6QP2;Rh/208f=S@0808N7Q`28R8P0QhN708Z:RP26QXH0Q8B408N7Q`21PH4307emO@0308:2PP1d
M7@0MgMg0080N7Qh0P2?Shl0402JVYX0Shn?08N7Q`21PH40T92@0:FUY@28R8P0QhN7092@T01fMWH0
G5aL06i^KP2>SXh0Y:BT0:FUY@2>SXh;08N7Q`0408^;R`27QhL0QhN708B4Q0<0QhN700@0Q8B408N7
Q`27QhL0QhN77P3oool00`29RHT0S8b<08^;R`0508V9R@0F08^;R`29RHT0QHF508b<S029RHT0QXJ6
08Z:RP0^;Rh0O7al07YjNP2UYJD0PX:208J6QP27QhL0N7Qh08V9R@3Ph>00Rh^;08n?S`29RHT0R8R8
08b<S080QHF500T0R8R808Z:RP2:RXX0S8b<08Z:RP26QXH0RHV908N7Q`28R8P00P24Q8@04P1kNg/0
PX:208j>SP29RHT0SHf=08b<S02>SXh0Rh^;08f=S@28R8P0QHF508B4Q02>SXh0R8R808F5Q@28R8P0
QXJ608F5Q@80PH6100P0QXJ607MgM`1kNg/0N7Qh07MgM`27QhL0Rh^;09JFUP80RHV900T0QXJ608b<
S02ZZZX0UIFE08R8R02?Shl0PX:206YZJP20P8000P2OWil00`2_[jl0UYJF08V9R@0908V9R@0608J6
QP2:RXX0QXJ608V9R@27QhL0Rh^;0P29RHT01027QhL0RHV908V9R@29RHTN0?ooo`0307=cL`1dM7@0
MWIf00D0Lg=c00/0MWIf07=cL`1aLG40M7Ad07=cL`1`L700LG5a05=CD`1eMGD0KFe]08F5Q@0207Qh
N00406i^KP1`L700Lg=c0;^k^`80N7Qh0P1bLW800`1hN7P0KFe]06i^KP0207=cL`0=071`L01hN7P0
Ng]k07IfMP1bLW80MGEe079bLP1[Jf/0K6a/06i^KP1`L700LG5a07=cL`0207UiN@0407MgM`1aLG40
M7Ad079bLP80K6a/00H0N7Qh07=cL`1aLG40Lg=c07IfMP1hN7P207=cL`0G07EeM@1_Kfl0LG5a06e]
K@1[Jf/0J6QX06m_K`1cLg<0Jf][07=cL`1fMWH0KVi^08:2PP23Ph<0LW9b07=cL`1lO7`0MGEe0861
P@2;Rh/0MGEe08V9R@1oOgl02P1cLg<01P1`L700LG5a071`L01cLg<0MGEe07IfMP80Lg=c00@0MGEe
07=cL`1cLg<0Lg=c8P3oool00200oooo00D0Q8B408N7Q`2;Rh/0QhN708^;R`0508N7Q`0A08B4Q027
QhL0QhN708B4Q027QhL0=3@d07inOP1ZJVX0UIFE09>CT`21PH40P82008n?S`1dM7@0RHV908J6QP2<
S8`00P27QhL00`2=SHd0QhN708R8R00208N7Q`0308R8R02=SHd0SHf=00<0QhN700L0T92@0861P@21
PH40Lg=c07emO@2ATI40S8b<00<0SXj>00L0Rh^;08b<S02<S8`0PH6108F5Q@27QhL0Rh^;00<0QhN7
01X0Ph>307emO@21PH40PX:207QhN01^KVh0L71`06i^KP1jNWX0S8b<09:BTP2EUID0SXj>08R8R02>
SXh0`l?307inOP27QhL0S8b<09:BTP1JFUX0UYJF08N7Q`2XZ:P0/K6a08b<S0X0QhN700D0Q8B408N7
Q`24Q8@0QhN708^;R`0708N7Qah0oooo00D0RHV908^;R`2:RXX0QXJ608Z:RP0208V9R@0D08J6QP29
RHT0RHV908N7Q`2;Rh/0RHV908N7Q`29RHT0;bl_08>3P`1eMGD0TY:B08V9R@23Ph<0NGUi08^;R`2=
SHd0[Jf]08Z:RP2=SHd208V9R@0308N7Q`25QHD0RHV90080RHV900@0QXJ608^;R`27QhL0QHF50P29
RHT01P2;Rh/0QXJ608^;R`1kNg/0PX:2092@T080Rh^;00<0RXZ:08^;R`2:RXX00P2:RXX00`23Ph<0
SHf=08Z:RP0208J6QP0L08V9R@27QhL0Ph>308F5Q@22PX80Q8B407moO`1jNWX0O7al07UiN@25QHD0
Shn?08b<S02CTi<0RXZ:0861P@20P800a<C408F5Q@24Q8@0RHV9092@T01BDU80TI6A08b<S02WYjL0
];Bd08n?S`X0RHV900D0QhN708^;R`27QhL0QXJ608Z:RP0708V9RAh0oooo00D0N7Qh07IfMP1aLG40
L71`075aL@0207=cL`0D071`L01cLg<0Lg=c07EeM@1fMWH0Lg=c07EeM@1cLg<0C4a<07AdM01gMgL0
LG5a06MWI`1cLg<0IVIV06m_K`2>SXh0YJFU07IfMP1dM7@207=cL`0306YZJP1]KFd0LW9b0080Lg=c
00@0KFe]071`L01ZJVX0KFe]0P1dM7@02P1]KFd0MWIf07emO@1fMWH0M7Ad07=cL`1aLG40Kfm_06i^
KP1`L703075aL@09079bLP1kNg/0MGEe06a/K01_Kfl0Lg=c075aL@1_Kfl0N7Qh0080LG5a01H0MWIf
07QhN01jNWX0MgMg07emO@1gMgL0KFe]079bLP1^KVh0IfMW061PH028R8P0N7Qh06a/K01^KVh0LW9b
05IFEP1`L700MgMg07]kN`23Ph<0MWIf2P1cLg<01@1eMGD0MWIf07EeM@1`L700LG5a00L0Lg=c8P3o
ool00200oooo0P2;Rh/01P27QhL0Q8B408^;R`27QhL0Rh^;08B4Q0D0QhN700h0Rh^;08B4Q01PH600
UiNG07emO@1fMWH0R8R808J6QP20P800TI6A09>CT`23Ph<0Rh^;08J6QP<0QhN700H0PX:208N7Q`28
R8P0QXJ608N7Q`2@T90208b<S080QhN700`0RXZ:08N7Q`28R8P0MgMg07UiN@2>SXh0TY:B096AT@2=
SHd0V9RH08f=S@2;Rh/208N7Q`0O08f=S@27QhL0RHV908N7Q`28R8P0QXJ60861P@27QhL0P82007em
O@1lO7`0N7Qh075aL@1eMGD0NGUi09BDU027QhL0VYZJ0820P021PH40OGem0<71`@2:RXX0QhN708F5
Q@2h^;P0@T920:VYZ@2?Shl0V9RH0;Bd]00>08N7Q`0308B4Q027QhL0QhN700H0QhN77P3oool02028
R8P0RXZ:08^;R`25QHD0S8b<08J6QP2:RXX0QHF51@29RHT03P2:RXX0IVIV03Lg=`27QhL0MWIf08N7
Q`2?Shl0O7al07]kN`2EUID0b/[:08N7Q`2=SHd0Rh^;0P29RHT08@2<S8`0QXJ608V9R@2:RXX0QHF5
08>3P`29RHT0QhN708^;R`29RHT0Q8B408n?S`29RHT0RXZ:07alO01nOWh0Rh^;08V9R@2<S8`0Q8B4
08n?S`2<S8`0SHf=08V9R@26QXH0RXZ:08:2PP29RHT0R8R808V9R@27QhL0Ph>308V9R@0208F5Q@0F
07inOP1mOGd0MgMg07emO@1fMWH0T92@08V9R@2FUYH0QXJ608>3P`28R8P0a<C407inOP29RHT0Kfm_
0:ZZZP0n?Sh0WIfM09JFUP2RXZ80^KVi08b<S0`0RHV900<0QXJ608N7Q`2;Rh/01`29RHTN0?ooo`06
06i^KP1aLG40MWIf075aL@1dM7@0L71`0P1aLG4507=cL`0>075aL@16ATH0:RXZ061PH01TI6@0Ph>3
07]kN`1SHf<0IfMW07YjNP32`/80MGEe07AdM01gMgL207=cL`0507QhN01fMWH0Lg=c07=cL`1_Kfl0
0P1[Jf/01@1]KFd0LG5a07AdM01/K6`0NGUi0080Lg=c01H0LW9b07=cL`1_Kfl0J6QX06e]K@1WIfL0
Jf][079bLP1dM7@0Lg=c06m_K`1`L700JVYZ079bLP1cLg<0LW9b07=cL`1bLW80Lg=c07IfMP1hN7P0
L71`0P1bLW800`1eMGD0JFUY071`L00207=cL`0>07IfMP1bLW80OWin08V9R@1RHV80Lg=c055AD@1^
KVh0De=C06][J`1mOGd0QXJ608R8R01gMgL<07=cL`03071`L01eMGD0MWIf00L0Lg=c8P3oool00200
oooo00<0Q8B408N7Q`27QhL00P27QhL00`24Q8@0Rh^;08B4Q00508N7Q`0408^;R`1EEED0LG5a06UY
J@80MGEe00L0SHf=07QhN02;Rh/0Ph>30=oOg`26QXH0Ti>C0080QhN700L0PX:208f=S@26QXH0QhN7
08f=S@27QhL0TI6A0080S8b<00l0TI6A08f=S@20P800RXZ:08J6QP28R8P0OGem07UiN@28R8P0SXj>
096AT@28R8P0SHf=08^;R`2<S8`00P2>SXh0102BTY80RXZ:08Z:RP29RHT208N7Q`80Ph>301L0OGem
08:2PP1jNWX0N7Qh075aL@1iNGT0K6a/09BDU02IVIT0TY:B08N7Q`21PH40QhN70;Jf]P22PX80SHf=
069RHP3GemL0?Cdm096AT@2ZZZX0RXZ:0:JVYP0308N7Q`0308^;R`27QhL0QhN700L0QhN700<0Q8B4
08N7Q`27QhL01`27QhLN0?ooo`0808V9R@2;Rh/0QXJ608V9R@2;Rh/0QHF508b<S027QhL508V9R@0W
08b<S010@400Lg=c08B4Q01fMWH0NGUi08V9R@1dM7@0TI6A092@T03Vi^H0P82009:BTP28R8P0S8b<
08J6QP2;Rh/0Q8B408J6QP28R8P0O7al08R8R02:RXX0R8R808b<S02:RXX0PX:208b<S028R8P0RXZ:
07inOP1gMgL0QHF508^;R`2<S8`0RHV909BDU02;Rh/0RHV90080Q8B400<0R8R808F5Q@29RHT00P29
RHT06P27QhL0QXJ608:2PP24Q8@0Ph>30820P01oOgl0MgMg07alO01_Kfl0Rh^;08n?S`2CTi<0QHF5
08J6QP29RHT0^;Rh08B4Q02<S8`0E5AD0<G5a@11@D40UYJF0::RXP2PX:00];Bd0P29RHT00`26QXH0
RXZ:08V9R@0808V9R@0308F5Q@29RHT0RHV900L0RHV97P3oool0201hN7P0MWIf071`L01cLg<0MWIf
075aL@1dM7@0MGEe1@1cLg<0701dM7@0@D5106a/K02=SHd0K6a/071`L01^KVh0IVIV07YjNP22PX80
VYZJ06UYJ@1dM7@0LW9b07QhN01fMWH0LG5a06i^KP1_Kfl0K6a/069RHP1XJ6P0L71`06a/K01^KVh0
L71`075aL@1eMGD207=cL`0906m_K`1ZJVX0KVi^06m_K`1]KFd0Lg=c07inOP1bLW80KVi^0080IFEU
00X0IfMW06a/K01aLG40LG5a07=cL`1aLG40M7Ad06m_K`1gMgL0L71`0P1eMGD2075aL@0A06a/K01X
J6P0JVYZ07MgM`1^KVh0MWIf07=cL`25QHD0LW9b075aL@1@D500M7Ad05aLG01kNg/0LW9b096AT@2@
T9000P1cLg<00`1`L700LG5a07=cL`0807=cL`03075aL@1cLg<0Lg=c00L0Lg=c8P3oool00200oooo
0P27QhL02@24Q8@0QhN708N7Q`27QhL0Q8B408N7Q`2;Rh/0Q8B408N7Q`0208B4Q00>08N7Q`0?3`l0
Xj>S075aL@2HV9P0SHf=07QhN02;Rh/0UIFE0<o?c`25QHD0WIfM08f=S@26QXH308N7Q`0@08^;R`2H
V9P0[Jf]0;:b/P2>SXh0YZJV09JFUP2HV9P0QhN70861P@2@T900QXJ608N7Q`1eMGD0MgMg092@T080
Shn?00P0PH6109JFUP27QhL0TI6A09>CT`2IVIT0YJFU0:6QX@80UYJF01`0VIVI08R8R027QhL0T92@
08N7Q`22PX80O7al07]kN`1gMgL0P82007]kN`1RHV80OGem08n?S`2=SHd0VIVI07emO@2`/;00VYZJ
07inOP1TI6@0c<c<04i>CP1oOgl0^KVi0:^[Z`2LW9`0PX:21@27QhL00`24Q8@0QhN708N7Q`0708N7
Q`0308B4Q027QhL0QhN700@0QhN77P3oool208V9R@0908N7Q`2;Rh/0RHV908V9R@27QhL0Rh^;08Z:
RP25QHD0Rh^;0080RHV900h0S8b<01hN7P2WYjL0Hf=S08n?S`2=SHd0J6QX08n?S`2OWil0dm?C07]k
N`2MWId0TI6A08N7Q`80RHV900`0PX:207emO@1eMGD0NWYj08V9R@1lO7`0U9BD08R8R02CTi<0Rh^;
08>3P`2BTY8208V9R@0<07]kN`1mOGd0RHV908J6QP2EUID0RHV909JFUP21PH40P82007alO01jNWX0
PH610`29RHT0102EUID0RHV908:2PP26QXH208:2PP0F0820P01nOWh0O7al07YjNP1oOgl0MgMg096A
T@2=SHd0QXJ609:BTP1mOGd0[jn_08b<S01eMGD0IFEU0=KFeP16ATH0N7Qh0;no_`2XZ:P0XZ:R08J6
QPD0RHV900<0QhN708^;R`29RHT01`29RHT00`27QhL0Rh^;08V9R@0408V9RAh0oooo0P1cLg<01P1e
MGD0MWIf07=cL`1cLg<0MGEe07IfMP80LG5a00h0MWIf07QhN01hN7P0N7Qh05aLG021PH40EUIF06YZ
JP1cLg<0EEEE07MgM`25QHD0T92@06=SH`80N7Qh00l0LW9b07=cL`1cLg<0JVYZ05iNGP16ATH0=cLg
04M7A`1JFUX0Hf=S069RHP1`L700MgMg079bLP1gMgL0101dM7@02`1ZJVX0IVIV07emO@1jNWX0MgMg
06QXJ01MGEd0EEEE04];B`19BDT0FEUI0080I6AT0P1bLW806P1ZJVX0IFEU06YZJP1`L700LW9b075a
L@1cLg<0IfMW079bLP21PH40RXZ:079bLP1ZJVX0KFe]06i^KP1oOgl0I6AT069RHP1VIVH0V9RH059B
DP1UIFD0Rh^;07UiN@21PH40MWIf1@1cLg<00`1eMGD0MWIf07=cL`0707=cL`0307EeM@1fMWH0Lg=c
00@0Lg=c8P3oool00200oooo0P2;Rh/308N7Q`0508^;R`27QhL0Rh^;08N7Q`24Q8@00`27QhL03P2=
SHd0IFEU08R8R01bLW80UIFE09NGU`1LG5`0X:2P07emO@2CTi<0KVi^0::RXP2=SHd0S8b<0P27QhL0
202DU9@0YjNW08f=S@1]KFd0QhN70;Rh^02YZJT0UYJF0P2a/K405@27QhL0Ti>C08N7Q`27QhL0OGem
07MgM`25QHD0Ph>30:FUY@2?Shl0f=SH0;Vi^@25QHD0JFUY09:BTP2_[jl0WinO0:2PX02VYZH0[jn_
09NGU`0208R8R00G08J6QP27QhL0Ogmo07moO`1nOWh0MWIf07YjNP1mOGd0KVi^08f=S@27QhL0TY:B
08N7Q`2JVYX0SHf=07QhN01_Kfl0d=3@0492@P1hN7P0YZJV0:>SX`2GUiL03@27QhL00`2;Rh/0QhN7
08N7Q`0708N7Qah0oooo00/0R8R808Z:RP29RHT0RHV908J6QP2:RXX0QXJ608Z:RP2;Rh/0QhN708^;
R`0208V9R@0=06ATI011@D40Rh^;06UYJ@2>SXh0Ti>C06=SH`2][Jd0]KFe0<30`01YJFT0Xj>S08^;
R`0208V9R@0=08>3P`1/K6`0NWYj08^;R`28R8P0MGEe07emO@2IVIT0P82008^;R`2FUYH0QXJ609>C
T`0208V9R@0[07inOP1lO7`0RXZ:08>3P`2GUiL0Fe]K08R8R020P800TI6A06QXJ01/K6`0Ti>C08V9
R@22PX80RXZ:09RHV028R8P0PX:208V9R@24Q8@0QHF507inOP1mOGd0NWYj0861P@1nOWh0RXZ:07If
MP27QhL0R8R8096AT@2=SHd0Xj>S096AT@1iNGT0K6a/0=7Ad@16ATH0SHf=0;no_`2b/[80W9bL08F5
Q@0;08V9R@0308J6QP2:RXX0RHV900P0RHV97P3oool02`1^KVh0LG5a07=cL`1cLg<0L71`075aL@1`
L700LG5a07IfMP1eMGD0MWIf0080Lg=c00`0>3Ph038b<P1fMWH0GEeM06][J`1bLW80Jf][08b<S02m
_Kd0]KFe069RHP1lO7`2071`L00>07=cL`1[Jf/0?3`l03dm?@1`L700Shn?05MGE`0^;Rh0IfMW05QH
F019BDT0FEUI06m_K`1eMGD207=cL`0M06i^KP1bLW80N7Qh071`L01WIfL0:RXZ01`L700b<S80PH61
06EUI@0o?cl0EeMG05]KF`1?Cdl0De=C05mOG`1QHF40JFUY079bLP1]KFd0KVi^06e]K@1/K6`0J6QX
07YjNP1cLg<0Ogmo07AdM01ZJVX00P1cLg<0301iNGT0Q8B407UiN@1]KFd0IFEU08b<S01NGUh0RHV9
09nOW`2@T900OWin06e]K@/0Lg=c00<0L71`075aL@1cLg<0201cLg<R0?ooo`00803oool01`24Q8@0
QhN708N7Q`27QhL0Q8B408N7Q`24Q8@00`27QhL01@2;Rh/0QhN708N7Q`1;Bd/0Ogmo0080JVYZ01P0
OGem08n?S`1VIVH0Y:BT0?3`l01lO7`0N7Qh09bLW027QhL0QXJ608b<S02:RXX0QhN708R8R020P800
JVYZ0861P@2;Rh/0YJFU09RHV021PH40[Jf]09JFUP2BTY8208N7Q`0M08>3P`1mOGd0QXJ608N7Q`2O
Wil0H61P06IVIP2^[Zh0Lg=c08j>SP1dM7@0VIVI0861P@1`L700UYJF0;Fe]@2UYJD0SXj>08n?S`22
PX80QhN70861P@1iNGT0Ng]k07alO020P800Shn?0861P@2LW9`00P27QhL02P2UYJD0VYZJ096AT@1n
OWh0KVi^0<;2`P1BDU80XZ:R09RHV02][Jd;08N7Q`0308^;R`27QhL0Q8B400X0QhN77P3oool02`29
RHT0Rh^;08V9R@29RHT0QhN708^;R`27QhL0Rh^;08V9R@26QXH0RXZ:0080RHV903X0@D5108F5Q@1i
NGT0MWIf07UiN@2FUYH0JFUY08n?S`3Shn<0PH6107emO@2RXZ80S8b<08R8R023Ph<0Ng]k07IfMP2R
XZ80YZJV05eMG@1UIFD0PX:2096AT@2?Shl0QXJ60:FUY@23Ph<0U9BD08V9R@25QHD0P82007inOP22
PX80NGUi08f=S@1eMGD0O7al0;no_`1VIVH0Hf=S07QhN02UYJD0MWIf07alO025QHD0VYZJ09>CT`27
QhL0Rh^;08:2PP25QHD0PX:207]kN`1jNWX0N7Qh07emO@20P800I6AT0P2<S8`03021PH40Vi^K09bL
W02<S8`0LW9b07IfMP38b<P0@4100:RXZ02[Zj/0][Jf08n?S`T0RHV900@0QXJ608Z:RP29RHT0QhN7
2P29RHTN0?ooo`0;07QhN01fMWH0Lg=c07=cL`1eMGD0MWIf07EeM@1fMWH0Lg=c071`L01aLG400P1c
Lg<0B01=CDd0MgMg07emO@1hN7P0J6QX07emO@1YJFT0GUiN08B4Q01cLg<0LW9b0861P@1hN7P0Lg=c
06MWI`1LG5`0FEUI09JFUP2TY:@0E5AD04Q8B01UIFD0GemO06YZJP1fMWH0M7Ad05]KF`1hN7P0Lg=c
06e]K@1/K6`0Kfm_06][J`1MGEd0HF5Q0861P@25QHD0UiNG05QHF00g=cL0L71`08R8R01PH600NWYj
05iNGP1JFUX0HV9R06UYJ@1_Kfl0L71`06i^KP1aLG40Kfm_06a/K01XJ6P0JVYZ05iNGP16ATH0HF5Q
07QhN01XJ6P0KVi^07YjNP1]KFd0GEeM07=cL`2>SXh0ADE508B4Q02ATI40Rh^;07alO0T0Lg=c00@0
L71`075aL@1cLg<0MGEe2P1cLg<R0?ooo`00803oool908N7Q`0Q08B4Q027QhL0QhN708N7Q`0f=SH0
CTi>07alO02BTY80MGEe08n?S`1aLG40J6QX0=GEe@1fMWH0Rh^;09fMW@2BTY80R8R808J6QP29RHT0
Vi^K0>OWi`2d];@0EEEE07UiN@15ADD0TY:B0<S8b02QXJ40Z:RX09^KV`2>SXh0QhN70080PX:20100
OGem06i^KP1mOGd0QhN70:JVYP1PH600ZZZZ04i>CP2NWYh0CTi>0=_Kf`1mOGd0JFUY0;Bd]02_[jl0
YjNW0P2KVi/05P27QhL0Ph>3092@T01mOGd0NGUi07moO`20P800LW9b07UiN@2>SXh0[Jf]07]kN`2Q
XJ40TY:B09JFUP1mOGd0NGUi0;Rh^013@d<0^[Zj09jNWP2WYjL:08N7Q`0508B4Q027QhL0QhN708N7
Q`24Q8@02@27QhLN0?ooo`L0RHV900@0QXJ608V9R@27QhL0Rh^;0P29RHT06P1XJ6P0LG5a06=SH`1j
NWX0JVYZ08^;R`1kNg/0T92@0?;blP1cLg<0P82009^KV`2<S8`0PX:207YjNP1cLg<0JVYZ0;2`/02E
UID0Bd];0::RXP19BDT0MWIf09^KV`28R8P0UIFE0P2BTY80:`29RHT0Q8B408B4Q020P800MGEe0861
P@1oOgl0U9BD07IfMP2PX:00<30`0;6a/@16ATH0ZZZZ06e]K@18B4P0RHV90:2PX02GUiL0QhN7092@
T025QHD0OWin08J6QP1kNg/0O7al07YjNP23Ph<0KFe]07MgM`2DU9@0UiNG07]kN`2ZZZX0Shn?08R8
R01oOgl0O7al0;Vi^@11@D40^KVi09NGU`2d];@02P29RHT01@27QhL0Rh^;08V9R@29RHT0QhN700T0
RHV97P3oool707=cL`04071`L01cLg<0MGEe07IfMP80Lg=c01d0Vi^K08j>SP19BDT0De=C05aLG01_
Kfl0N7Qh09nOW`2e]KD0IVIV06=SH`1fMWH0K6a/06UYJ@1QHF40DU9B03<c<`15ADD0EEEE055AD@2V
YZH0GemO04e=C@19BDT0EUIF065QH@1[Jf/0NGUi07=cL`04079bLP0O07=cL`1UIFD0Hf=S08:2PP1_
Kfl0<S8b09FEU@1ADE40BDU905MGE`0h>3P0A4A406][J`1VIVH0G5aL06QXJ01]KFd0J6QX06MWI`1Z
JVX0L71`06MWI`1dM7@0HV9R06QXJ01lO7`0GemO06a/K028R8P0LG5a06=SH`02075aL@0508>3P`1F
EUH0PX:206m_K`2>SXh02P1cLg<01@1eMGD0MWIf07=cL`1cLg<0MGEe00T0Lg=c8P3oool00200oooo
1`27QhL00`24Q8@0QhN708N7Q`0308N7Q`050<O7a`1IFET0HV9R06a/K01_Kfl00`27QhL01`2k^k/0
Ng]k08N7Q`2GUiL0Rh^;08>3P`22PX800P1jNWX02@2/[:`0`L710;6a/@3Zj^X0Jf][06e]K@2BTY80
Shn?08N7Q`0308^;R`0Z08>3P`22PX80P82006e]K@1bLW80Kfm_08R8R02LW9`0Q8B405mOG`3Rh^80
MGEe0:^[Z`2KVi/0NGUi08>3P`2UYJD0U9BD09:BTP2OWil0S8b<07inOP28R8P0RXZ:08:2PP21PH40
OGem06UYJ@1]KFd0QhN709ZJVP2BTY80Z:RX08^;R`2:RXX0TY:B07UiN@2][Jd0@d=30:FUY@2FUYH0
TY:B4P27QhL00`2;Rh/0QhN708N7Q`0308N7Qah0oooo1`29RHT00`27QhL0RHV908V9R@0308V9R@0j
08R8R019BDT0LW9b07inOP1oOgl0RHV908j>SP2OWil0alO706i^KP24Q8@0VYZJ08f=S@1nOWh0MgMg
079bLP1lO7`0ZZZZ07IfMP1FEUH0Shn?05ADE01iNGT0YjNW09bLW02MWId0WYjN08b<S02:RXX0Q8B4
08>3P`22PX80N7Qh0861P@1oOgl0Rh^;08>3P`22PX80>SXj09NGU`17AdL0Z:RX0861P@1RHV80VYZJ
0:RXZ02BTY80RXZ:09>CT`27QhL0O7al08:2PP1oOgl0LW9b08F5Q@20P800M7Ad07moO`80V9RH00/0
QhN70:FUY@2:RXX0QhN708>3P`1oOgl0]KFe04e=C@2a/K40UiNG0:6QX@0A08V9R@0308J6QP2:RXX0
RHV900@0RHV97P3oool707=cL`0307EeM@1cLg<0Lg=c00<0Lg=c01`0;Rh^04Y:BP1kNg/0PH6107mo
O`1cLg<0NWYj09:BTP2EUID0Fe]K06e]K@1jNWX0MWIf06QXJ01PH600HF5Q071`L01lO7`06a/K0000
000D51@0AdM707UiN@2BTY80QXJ6092@T02=SHd0Lg=c0P1aLG404@1`L700LW9b07MgM`1nOWh0P820
07IfMP1EEED0KFe]02h^;P0X:2P0:BTY07YjNP1DE5@0Bd];08n?S`20P800Lg=c0080JFUY0P1[Jf/0
501YJFT0HV9R05UIF@1dM7@0LG5a07IfMP21PH40R8R807EeM@1VIVH0N7Qh075aL@1^KVh0H61P07Ee
M@29RHT0IfMW08f=S@1hN7P0Rh^;4@1cLg<00`1`L700LG5a07=cL`0407=cLb80oooo000P0?ooo`<0
QhN700D0Q8B408N7Q`27QhL0QhN708B4Q00308N7Q`0U08^;R`27QhL0EUIF09>CT`1mOGd0QhN709jN
WP27QhL0UiNG09fMW@2QXJ40SXj>08Z:RP2NWYh0QhN708:2PP1mOGd0KFe]04a<C00n?Sh0>CTi03hn
?P11@D40?clo06MWI`2<S8`0TY:B09JFUP28R8P0Rh^;08R8R024Q8@0OGem08:2PP1lO7`0OGem08R8
R00207emO@0R05ADE01]KFd0M7Ad069RHP1?Cdl0ATI6065QH@1dM7@0KVi^06a/K01fMWH0PX:207in
OP27QhL0R8R807IfMP1`L700OGem08N7Q`2>SXh0NWYj096AT@1fMWH0QhN70:n_[`2EUID0M7Ad08>3
P`2:RXX0V9RH05IFEP2KVi/0UIFE08:2PQL0QhN700<0Rh^;0?ooo`3oool0703oool308V9R@0508N7
Q`2;Rh/0RHV908V9R@27QhL00P29RHT0:@26QXH0RXZ:08V9R@1nOWh0MWIf05mOG`1mOGd0TI6A07em
O@2OWil0[:b/09RHV023Ph<0Q8B409bLW02;Rh/0RXZ:08b<S026QXH0RXZ:092@T02DU9@0Vi^K09jN
WP2PX:00Ti>C09RHV02BTY80U9BD08n?S`2<S8`0R8R808N7Q`25QHD0RHV907inOP1jNWX0QXJ607mo
O`2>SXh0QHF50080RXZ:00H0QhN708f=S@2KVi/0YZJV09jNWP2@T90208n?S`0G08j>SP21PH40Q8B4
08B4Q01lO7`0MGEe0861P@1mOGd0Ogmo07MgM`2CTi<0Rh^;08f=S@2[Zj/0VYZJ07QhN021PH40Ti>C
09nOW`1KFe/0Xj>S0;6a/@2;Rh/05P29RHT00`26QXH0RXZ:0?ooo`0M0?ooo`<0Lg=c00D0MGEe07If
MP1cLg<0Lg=c07EeM@0207=cL`0`071`L01aLG40Lg=c09RHV01<C4`0A4A4069RHP1WIfL0HV9R08:2
PP2>SXh0KVi^06ATI01YJFT0MGEe07IfMP1kNg/0Ph>308^;R`2e]KD0b/[:0=GEe@3Kfm/0g=cL0>7Q
h@2TY:@0Q8B407EeM@1dM7@0O7al07=cL`1aLG40M7Ad07QhN01iNGT0Kfm_06QXJ01^KVh0L71`08F5
Q@2TY:@0TI6A08V9R@2HV9P0]KFe0=7Ad@35aLD0YZJV0P2IVIT03@2?Shl0P820079bLP1]KFd0Jf][
07=cL`1aLG40Lg=c069RHP1OGel0J6QX07MgM`28R8P00P1iNGT02@1mOGd0L71`06e]K@20P800PH61
06IVIP23Ph<0WYjN07alO00F07=cL`03071`L01aLG40oooo0240oooo000P0?ooo`80QhN700@0Rh^;
08N7Q`27QhL0Rh^;1`27QhL06@0g=cL0Y:BT07YjNP2EUID0TY:B06YZJP2b/[80[Zj^0:6QX@2>SXh0
QHF509fMW@27QhL0TY:B08^;R`22PX80Ogmo07MgM`1cLg<0LG5a08n?S`2/[:`0ZJVY0:f][@23Ph<0
0P27QhL03@26QXH0PX:208R8R023Ph<0PX:2079bLP1`L700O7al08j>SP2b/[80[Zj^08f=S@1YJFT0
0P1UIFD02@1]KFd0MgMg0861P@23Ph<0PH6108:2PP27QhL0U9BD07moO`0208N7Q`0507IfMP21PH40
MWIf07EeM@24Q8@00P2ATI402P2IVIT0XJ6Q0:ZZZP20P800Ph>308^;R`2KVi/0DE5A09ZJVP2c/k<G
08N7Q`0308B4Q027QhL0oooo01d0oooo0P29RHT0102:RXX0RHV908J6QP2:RXX308V9R@0A08J6QP29
RHT0Rh^;08b<S00Q8B40Ogmo06QXJ027QhL0R8R8079bLP2UYJD0Vi^K09JFUP2;Rh/0P8200::RXP25
QHD00P2>SXh03`27QhL0S8b<08R8R02;Rh/0Ng]k07UiN@1jNWX0MGEe0::RXP2DU9@0V9RH08n?S`2>
SXh0QXJ608Z:RP0208J6QP0W07emO@1nOWh0Ng]k075aL@28R8P0P82009JFUP2DU9@0Ti>C09:BTP2A
TI40RXZ:08j>SP2;Rh/0QHF508:2PP20P800RHV90820P023Ph<0OWin07UiN@1oOgl0PX:207]kN`1o
Ogl0S8b<07YjNP2BTY80XZ:R09^KV`1fMWH0Ph>308n?S`2SXj<0Fe]K0:BTY02m_Kd0QHF501H0RHV9
00<0QhN708^;R`3oool07@3oool207=cL`04075aL@1cLg<0L71`075aL@<0Lg=c0180L71`07=cL`1f
MWH0N7Qh03De=@17AdL0E5AD069RHP1WIfL0LW9b06i^KP1TI6@0Jf][06m_K`1YJFT0Ogmo06i^KP1_
Kfl207IfMP0P0820P024Q8@0S8b<07QhN01DE5@0=cLg03@d=01^KVh0R8R808V9R@1mOGd0O7al07If
MP1cLg<0M7Ad07IfMP1iNGT0O7al06][J`1;Bd/0ADE503dm?@1oOgl0Xj>S0:NWY`2UYJD0VYZJ08N7
Q`22PX80Ng]k07EeM@1`L70206IVIP0E071`L01ZJVX0I6AT071`L01/K6`0O7al07=cL`1XJ6P0KFe]
05ADE01]KFd0O7al06MWI`1QHF40L71`07UiN@24Q8@0K6a/08F5Q@2?Shl0KFe]01H0Lg=c00<0MGEe
07IfMP3oool08@3oool00200oooo1027QhL00`24Q8@0QhN708N7Q`0208N7Q`0D08B4Q027QhL0QhN7
08f=S@061PH0X:2P07EeM@2?Shl0QhN706i^KP2@T900TY:B0:>SX`2IVIT0QhN70:ZZZP21PH40T92@
09RHV02ATI4208R8R00R08j>SP2TY:@0Ti>C08n?S`1SHf<0OWin0861P@2;Rh/0QhN708b<S022PX80
R8R808J6QP23Ph<0O7al07=cL`1MGEd0E5AD07AdM02GUiL0c<c<0<71`@2MWId0U9BD08>3P`1mOGd0
QXJ608>3P`27QhL0QXJ608R8R027QhL0R8R808:2PP80QhN700T0PH6109ZJVP1mOGd0QhN70861P@27
QhL0Ph>308V9R@2@T9000P1mOGd01@2=SHd0ZZZZ06=SH`2>SXh0^KVi01T0QhN77P3oool208V9R@04
08^;R`29RHT0QhN708^;R`<0RHV900/0QhN708^;R`29RHT0Q8B40000002EUID0KFe]092@T02?Shl0
LW9b0:FUY@0209RHV00508b<S023Ph<0Y:BT08:2PP2;Rh/00P2<S8`02029RHT0Q8B406IVIP1ZJVX0
L71`0861P@2RXZ80[jn_0P2ATI40102<S8`0SHf=08>3P`2:RXX208R8R00V08:2PP24Q8@0NGUi07If
MP1kNg/0P82009NGU`2DU9@0RHV908b<S028R8P0Ph>308^;R`23Ph<0PX:207]kN`1dM7@0S8b<0861
P@1lO7`0P82008>3P`1fMWH0Q8B4071`L02:RXX0QXJ609BDU02PX:00VIVI09ZJVP22PX80OWin08Z:
RP2QXJ40J6QX09^KV`32`/8I08V9RAh0oooo0P1cLg<0101fMWH0Lg=c07EeM@1fMWH307=cL`0Q07Ee
M@1fMWH0Lg=c06IVIP0k>c/0Jf][061PH01fMWH0O7al06i^KP2ATI40OGem06][J`1UIFD0Jf][07If
MP1_Kfl0KFe]06EUI@1^KVh0LW9b06][J`0k>c/0:BTY04A4A01OGel0_[jn0;Bd]025QHD0NWYj07Mg
M`1eMGD0L71`0080Lg=c01<0MWIf07EeM@22PX80RHV908n?S`1dM7@0EeMG03lo?`16ATH0G5aL06][
J`1gMgL0MWIf07QhN01_Kfl0JFUY065QH@1EEED0MgMg0080IfMW00`0IVIV06a/K01PH600FEUI05]K
F`1eMGD0MWIf08B4Q02JVYX0R8R808:2PP1eMGD206i^KP04071`L01[Jf/0QXJ608n?SaT0Lg=c8P3o
ool00200oooo2P27QhL06P2;Rh/0QhN707QhN0000000PH6107YjNP1mOGd0QhN70820P02KVi/0U9BD
09nOW`2YZJT0Ti>C0:JVYP25QHD0O7al0:f][@2`/;00[:b/0:n_[`2DU9@0RXZ:06EUI@16ATH0OGem
0P1nOWh01023Ph<0QhN708N7Q`27QhL308R8R00R08B4Q021PH40Lg=c05QHF00i>CT0?clo07IfMP2a
/K40a/K60<?3``39bLT0ZJVY0:b/[02VYZH0ZJVY09ZJVP1oOgl0PX:207inOP1hN7P0P82008N7Q`1e
MGD0I6AT08j>SP1jNWX0M7Ad0:BTY02^[Zh0Shn?09:BTP24Q8@0O7al08N7Q`80TI6A00<0YjNW0:>S
X`27QhL03@27QhL00`2;Rh/0QhN708N7Q`0808N7Qah0oooo2@29RHT02`26QXH0RXZ:08b<S01RHV80
2@T908Z:RP23Ph<0T92@08B4Q021PH40VIVI0080RXZ:02L0Ti>C08Z:RP2WYjL0Rh^;06i^KP27QhL0
R8R807QhN01[Jf/0IVIV09JFUP2SXj<0WinO09fMW@2?Shl0Rh^;08f=S@2<S8`0R8R808F5Q@29RHT0
R8R808V9R@27QhL0QXJ608F5Q@22PX80Ogmo08n?S`2:RXX0SHf=08J6QP1mOGd0P82007UiN@1mOGd0
MGEe07alO01oOgl00`25QHD04`1kNg/0PH6108V9R@29RHT0KVi^08n?S`2@T900QXJ609BDU02OWil0
U9BD09:BTP21PH40OWin096AT@29RHT0L71`0:f][@2j^[X03@29RHT00`26QXH0RXZ:08V9R@0908V9
RAh0oooo2@1cLg<0BP1`L700LG5a07QhN01=CDd0CTi>07alO01iNGT0R8R806a/K01aLG40MWIf06QX
J01LG5`0GemO06QXJ01nOWh0N7Qh05YJFP19BDT0B4Q803De=@0O7al0=CDe08>3P`2m_Kd0f=SH09^K
V`26QXH0P82007inOP1gMgL0LW9b06e]K@1bLW80LG5a079bLP1dM7@0MWIf08B4Q02MWId0^[Zj0<W9
b@27QhL0CDe=02`/;00S8b<0820P03Ti>@0l?3`0=SHf03dm?@1BDU80MgMg07=cL`1hN7P0LG5a071`
L01cLg<0QhN707=cL`1eMGD0S8b<08B4Q01UIFD0JFUY07]kN`1fMWH0Jf][071`L01oOgl0JVYZ04E5
A@24Q8@0Vi^K3@1cLg<00`1`L700LG5a07=cL`0907=cLb80oooo000P0?ooo`T0QhN701X0Q8B408^;
R`2=SHd0EEEE075aL@23Ph<0QhN707MgM`1^KVh0R8R809JFUP2?Shl0RHV909VIV@2FUYH0WIfM08f=
S@1OGel0IFEU071`L022PX80LG5a05iNGP1SHf<0OWin08>3P`D0QhN700@0PH6108N7Q`27QhL0PX:2
0`23Ph<09024Q8@0PH6107MgM`1^KVh0BDU903Xj>P1<C4`0AdM7075aL@2FUYH0Shn?08N7Q`1eMGD0
MgMg08N7Q`1oOgl0P82007QhN020P800Ph>309VIV@1cLg<0Ph>308j>SP2?Shl0TY:B0;Jf]P2>SXh0
S8b<09>CT`1gMgL0Shn?07MgM`2:RXX0/[:b096AT@d0QhN700<0Q8B408N7Q`27QhL02@27QhLN0?oo
o`T0RHV900/0QHF508b<S02;Rh/0CTi>02l_;`22PX80UYJF08N7Q`1oOgl0Q8B409:BTP0208^;R`0>
09RHV02>SXh0Y:BT08j>SP1iNGT0Ti>C08F5Q@21PH40SXj>0:FUY@2ZZZX0XJ6Q08f=S@2<S8`408V9
R@0[08:2PP29RHT0S8b<08Z:RP2;Rh/0R8R808V9R@2:RXX0QXJ608:2PP26QXH0SHf=09>CT`2SXj<0
QHF508N7Q`26QXH0Q8B408n?S`2ATI40Shn?096AT@27QhL0PX:207QhN023Ph<0S8b<08>3P`1aLG40
U9BD08:2PP1fMWH0R8R80;Ng]`2CTi<0Ph>308j>SP22PX80Ti>C06YZJP2=SHd0c/k>09jNWP0=08V9
R@0308N7Q`2;Rh/0QXJ600T0RHV97P3oool907=cL`0K075aL@1dM7@0L71`05IFEP0;2`/0KVi^08J6
QP23Ph<0P82006][J`1aLG40Kfm_07EeM@1fMWH0JVYZ08:2PP1dM7@0R8R80:NWY`26QXH0KFe]09:B
TP38b<P0bLW909nOW`1nOWh0MgMg00@0Lg=c00<0LG5a07=cL`1hN7P00P1kNg/09P1fMWH0N7Qh07Qh
N01fMWH0NWYj08Z:RP2k^k/0e=CD0=SHf02a/K40RHV9061PH01TI6@0OGem09>CT`2=SHd0OWin07Yj
NP1bLW80KFe]07=cL`1lO7`0FEUI06IVIP27QhL0Hf=S055AD@1WIfL0Ph>307YjNP1VIVH0Kfm_07]k
N`1iNGT0FEUI07EeM@2WYjL0QhN73@1cLg<00`1eMGD0MWIf071`L00907=cLb80oooo000P0?ooo`80
QhN700<0Rh^;08B4Q027QhL01`27QhL03P1WIfL0SXj>08>3P`2NWYh0LG5a07UiN@1kNg/0Rh^;08V9
R@2>SXh0Vi^K08F5Q@2SXj<0RXZ:0P27QhL01`2=SHd0QXJ608N7Q`22PX80QhN708f=S@2<S8`00P27
QhL01P2<S8`0R8R808N7Q`22PX80S8b<08f=S@80QhN700@0PX:208N7Q`26QXH0QhN70`22PX8208N7
Q`0@08>3P`2<S8`0QhN70861P@27QhL0R8R808>3P`2<S8`0PX:207MgM`1hN7P0Rh^;08N7Q`1jNWX0
I6AT071`L0<0NWYj00X0dm?C06ATI01bLW80^;Rh06YZJP2e]KD0FEUI0:ZZZP2^[Zh0PX:26@27QhLN
0?ooo`80RHV900D0RXZ:08N7Q`2;Rh/0RHV908J6QP0508V9R@0O061PH01nOWh0R8R80:j^[P1iNGT0
NWYj08F5Q@2BTY80R8R808^;R`2KVi/0QHF50:BTY02<S8`0Rh^;08V9R@2>SXh0QhN708b<S02:RXX0
RHV908R8R02:RXX0RHV908F5Q@2:RXX0RHV908R8R023Ph<0RXZ:08^;R`0208F5Q@0V08J6QP29RHT0
RHV908V9R@26QXH0QHF508>3P`28R8P0QhN708>3P`2>SXh0Ph>308:2PP24Q8@0QHF508>3P`2:RXX0
QhN708>3P`1nOWh0RXZ:08N7Q`23Ph<0N7Qh07MgM`26QXH0R8R808Z:RP3Lg=`0Lg=c07emO@2e]KD0
Jf][0:n_[`1IFET0^[Zj0<71`@26QXHI08V9RAh0oooo0P1cLg<01@1aLG40MGEe07IfMP1cLg<0L71`
00D0Lg=c01X0Fe]K05aLG01gMgL0T92@07EeM@1]KFd0Ng]k07alO01`L700Kfm_07QhN01aLG40O7al
07EeM@1fMWH0Lg=c07EeM@1bLW80N7Qh07]kN`1cLg<0Jf][071`L01cLg<0KVi^071`L080LW9b00<0
LG5a071`L01`L7000P1]KFd03@1fMWH0M7Ad07AdM01dM7@0MWIf07AdM01aLG40Lg=c075aL@1_Kfl0
MWIf06][J`1`L7000P1]KFd2071`L00307MgM`1lO7`0M7Ad0080LG5a00L0NWYj08:2PP1cLg<0OWin
0820P022PX80V9RH0080NWYj00L0OWin06MWI`1iNGT0HF5Q09BDU02JVYX0MWIf01T0Lg=c8P3oool0
0200oooo1P27QhL00`24Q8@0QhN708N7Q`0308N7Q`0I05]KF`24Q8@0OGem0::RXP22PX80OGem07mo
O`27QhL0S8b<08j>SP2TY:@0Rh^;0;2`/02BTY80Rh^;08R8R02=SHd0QXJ608b<S02=SHd0PX:208>3
P`2<S8`0QhN708>3P`0308N7Q`0308>3P`22PX80QhN70080PX:200<0QhN708R8R028R8P00P2;Rh/0
2@24Q8@0PX:208N7Q`26QXH0Ph>308N7Q`24Q8@0PX:20861P@0208:2PP0908>3P`20P800P8200820
P027QhL0PX:208N7Q`23Ph<0PH610080NWYj00X0TI6A0=cLg01dM7@0LG5a0:BTY01ZJVX0_Kfm06YZ
JP2o_kl0TI6A6P27QhLN0?ooo`80RHV900H0Rh^;08V9R@29RHT0RHV908N7Q`2;Rh/408V9R@0706IV
IP2DU9@0SHf=09jNWP1eMGD0Ph>308F5Q@0208N7Q`0A08R8R02KVi/0QXJ60:FUY@2>SXh0RXZ:08V9
R@2;Rh/0R8R808Z:RP2;Rh/0QXJ608N7Q`2=SHd0RHV908N7Q`2<S8`00P29RHT02027QhL0RHV908b<
S026QXH0RXZ:08F5Q@29RHT0QXJ60P27QhL02@25QHD0Ph>308R8R027QhL0R8R808V9R@27QhL0Ph>3
08J6QP0408N7Q`0D07]kN`1lO7`0SHf=08B4Q020P800Jf][08:2PP27QhL0Ng]k08B4Q03Ng]h0MWIf
07YjNP2c/k<0LG5a0:n_[`1OGel0fMWI0:FUY@25QHDI08V9RAh0oooo0P1cLg<01P1fMWH0Lg=c07=c
L`1cLg<0MGEe07IfMP@0Lg=c00D0LG5a08J6QP25QHD0MGEe05eMG@0207MgM`0;075aL@1/K6`0Jf][
06i^KP1[Jf/0L71`06m_K`1aLG40LW9b071`L01cLg<00P1`L70207IfMP0407EeM@1cLg<0MGEe07Mg
M`80Lg=c00P0MGEe07YjNP1hN7P0MWIf07]kN`1]KFd0LW9b06i^KP80KFe]00P0LG5a071`L01bLW80
LW9b07MgM`1cLg<0M7Ad071`L0<0MWIf01H0MGEe07UiN@1XJ6P0J6QX07YjNP1bLW80IVIV04i>CP1`
L700Ogmo06e]K@1RHV80TY:B06e]K@1eMGD0T92@071`L01aLG40EeMG0:VYZ@2ATI40KFe]6@1cLg<R
0?ooo`00803oool508N7Q`0308^;R`27QhL0QhN700@0QhN700d0K6a/08^;R`2BTY80WIfM09:BTP2=
SHd0S8b<08>3P`27QhL0Ph>309VIV@21PH40Y:BT0080TY:B00@0R8R808N7Q`27QhL0QXJ60P2=SHd0
1023Ph<0QhN708N7Q`27QhL208b<S0@0QhN70P2=SHd208N7Q`0308^;R`27QhL0QhN700<0QhN701`0
QXJ6092@T027QhL0Ph>30861P@27QhL0PX:208J6QP23Ph<0QhN707inOP1hN7P0QhN708B4Q020P800
MWIf08Z:RP1jNWX0PH6108j>SP3@d=00SXj>069RHP2JVYX0JVYZ0:2PX02=SHd0]KFe4@27QhL00`2;
Rh/0QhN708N7Q`0708N7Qah0oooo1029RHT00`26QXH0RXZ:08V9R@0508V9R@0C07alO02:RXX0Ph>3
08Z:RP24Q8@0Rh^;08J6QP24Q8@0Rh^;08N7Q`2QXJ40Shn?0:RXZ02=SHd0SXj>08V9R@2:RXX0RHV9
08N7Q`0208^;R`0608N7Q`2<S8`0RHV908F5Q@27QhL0RXZ:0`29RHT01P25QHD0QhN708N7Q`29RHT0
Q8B408R8R080RHV900D0QhN708F5Q@28R8P0Ph>308V9R@0208B4Q00I08:2PP29RHT0Q8B408N7Q`1n
OWh0Ogmo0820P023Ph<0RHV907inOP1eMGD0NGUi09:BTP1fMWH0NGUi09RHV03;bl/0T92@07moO`2X
Z:P0KVi^09>CT`2EUID0emOG08^;R`0?08V9R@0308J6QP2:RXX0RHV900P0RHV97P3oool407=cL`03
071`L01aLG40Lg=c00D0Lg=c00X0OWin075aL@1PH600GUiN065QH@1`L700Jf][075aL@1gMgL0MWIf
0P23Ph<01`21PH40KVi^071`L01cLg<0M7Ad07=cL`1bLW800P1`L7001P1eMGD0MgMg07=cL`1^KVh0
K6a/071`L0<0Lg=c00H0KFe]06YZJP1ZJVX0Lg=c06e]K@1^KVh207=cL`0P075aL@1]KFd0Lg=c06a/
K01ZJVX0K6a/079bLP1`L700Lg=c079bLP1cLg<0JFUY06EUI@1`L700Ng]k07=cL`1XJ6P0H61P071`
L01nOWh0IfMW06ATI021PH40Ph>307IfMP2=SHd0S8b<06a/K01WIfL0Ogmo0;6a/@1fMWH?07=cL`03
071`L01aLG40Lg=c00P0Lg=c8P3oool00200oooo1027QhL00`24Q8@0QhN708N7Q`0508N7Q`0808B4
Q029RHT0NGUi08N7Q`26QXH0Ph>30861P@23Ph<208N7Q`0509VIV@2ATI40XZ:R09:BTP2ATI400P28
R8P00`27QhL0QXJ608J6QP0208N7Q`0308b<S027QhL0Ph>300D0QhN700D0PX:208N7Q`27QhL0QXJ6
0820P00208>3P`0P08N7Q`25QHD0QhN708N7Q`1oOgl0RXZ:08^;R`27QhL0PH6108F5Q@23Ph<0QhN7
07YjNP1oOgl0R8R808>3P`1mOGd0O7al07YjNP24Q8@0Ph>308F5Q@21PH40Vi^K0;no_`2ZZZX0OGem
0:VYZ@1gMgL0LW9b0;^k^`2QXJ4@08N7Q`0308B4Q027QhL0QhN700P0QhN77P3oool408V9R@0308N7
Q`2;Rh/0RHV900D0RHV901<0Rh^;08b<S023Ph<0Shn?096AT@2<S8`0RHV908N7Q`29RHT0SHf=09fM
W@2EUID0WinO08n?S`2CTi<0RXZ:08b<S029RHT0R8R80080S8b<00@0QHF508N7Q`29RHT0Q8B40P2<
S8`01025QHD0RHV908V9R@23Ph<308V9R@0508J6QP2<S8`0QhN708V9R@26QXH00P29RHT02020P800
R8R808N7Q`26QXH0Ph>308R8R023Ph<0QhN70P20P8004P26QXH0Ph>308>3P`1oOgl0N7Qh08N7Q`1n
OWh0MWIf08J6QP2GUiL0^k^k0:JVYP1_Kfl0WIfM07UiN@1jNWX0cLg=0;:b/Q00RHV900<0QhN708^;
R`29RHT02029RHTN0?ooo`@0Lg=c00<0MGEe07IfMP1cLg<01@1cLg<04@1jNWX0MWIf07YjNP1lO7`0
PH6107alO01jNWX0MGEe07=cL`1iNGT0OGem07YjNP1fMWH0LG5a07MgM`1dM7@0MgMg0080Lg=c00H0
NGUi07QhN01^KVh0K6a/07=cL`1aLG4207MgM`0406e]K@1cLg<0Lg=c071`L080Lg=c00H0M7Ad07Qh
N01lO7`0MGEe07=cL`1bLW8207=cL`0L06m_K`1`L700KFe]06m_K`1cLg<0M7Ad071`L01aLG40MWIf
071`L01^KVh0L71`07IfMP1aLG40JFUY07AdM01XJ6P0G5aL07IfMP1bLW80Ogmo07MgM`1JFUX0Jf][
06i^KP1eMGD0WIfM09:BTQ00Lg=c00<0MGEe07IfMP1cLg<0201cLg<R0?ooo`00803oool<08N7Q`0@
08f=S@1kNg/0RXZ:08b<S026QXH0QhN70861P@2<S8`0QHF508:2PP2BTY80Vi^K09ZJVP2GUiL0TY:B
08b<S080Rh^;00<0QhN708b<S02<S8`00P23Ph<02@2<S8`0Ph>308N7Q`2=SHd0QXJ608b<S02=SHd0
QhN708J6QP0308N7Q`0808^;R`23Ph<0QhN708F5Q@22PX80QhN707moO`1nOWh208>3P`0G08B4Q027
QhL0PX:208N7Q`23Ph<0Ogmo08>3P`27QhL0P82008N7Q`1_Kfl0QhN707IfMP25QHD0SXj>09ZJVP2M
WId0Zj^[0861P@2MWId0O7al05=CD`2_[jl07027QhLN0?ooo``0RHV900/0Shn?08>3P`24Q8@0UIFE
08b<S022PX80Ogmo08V9R@2@T900SHf=09BDU00209VIV@0609JFUP2ATI40Rh^;08^;R`2:RXX0RHV9
0P2:RXX01027QhL0QXJ608Z:RP27QhL308R8R080QhN702L0QHF508R8R029RHT0RHV908J6QP2:RXX0
Q8B408V9R@24Q8@0QXJ608R8R025QHD0QXJ608V9R@27QhL0Ph>308N7Q`23Ph<0R8R807inOP20P800
Q8B408V9R@1jNWX0PH6107MgM`29RHT0L71`0861P@22PX80[:b/0:j^[P2KVi/0NGUi0:FUY@24Q8@0
OWin0=WIf@2IVIT06`29RHTN0?ooo``0Lg=c00/0MGEe07QhN01YJFT0Ogmo07UiN@1YJFT0K6a/06m_
K`1oOgl0P82007MgM`0207IfMP0607AdM01cLg<0LW9b079bLP1aLG40Lg=c0P1`L7003P1eMGD0M7Ad
071`L01eMGD0LW9b06][J`1cLg<0Jf][06YZJP1^KVh0Lg=c07AdM01cLg<0Kfm_0P1aLG402@1cLg<0
Kfm_07IfMP1bLW80MWIf07YjNP1hN7P0M7Ad06m_K`02075aL@0707=cL`1YJFT0Kfm_075aL@1cLg<0
IVIV06UYJ@0207=cL`0<06=SH`1/K6`0HV9R096AT@2@T900IVIV06=SH`24Q8@0NGUi09bLW02j^[X0
RXZ:6`1cLg<R0?ooo`00803oool208N7Q`0308^;R`27QhL0Rh^;00L0QhN700@0SHf=04A4A027QhL0
Rh^;0P2@T900402<S8`0T92@07]kN`27QhL0VIVI09FEU@2?Shl0UiNG08j>SP2;Rh/0RHV908N7Q`28
R8P0S8b<08N7Q`22PX8208b<S00408>3P`2<S8`0R8R808J6QP@0QhN700<0QXJ608N7Q`28R8P00P27
QhL02025QHD0Q8B408N7Q`27QhL0Ogmo08n?S`1nOWh0PH610P27QhL208:2PP0B07YjNP1iNGT0QhN7
0861P@22PX80MWIf08F5Q@20P800M7Ad0820P02BTY80_Kfm08N7Q`28R8P0OGem0:ZZZP27QhL0ZZZZ
7@27QhLN0?ooo`80RHV900<0RXZ:08J6QP2:RXX01`29RHT01P2;Rh/0PX:207MgM`1iNGT0R8R808F5
Q@80RHV900L0Ph>309NGU`2JVYX0UIFE09RHV02IVIT0T92@0080SHf=00d0R8R808V9R@2=SHd0RHV9
08>3P`2>SXh0RXZ:08B4Q02:RXX0QXJ608^;R`25QHD0R8R80080RHV900d0R8R808V9R@29RHT0RHV9
08B4Q025QHD0Rh^;08J6QP29RHT0P820096AT@1nOWh0PX:20080R8R800T0QhN708J6QP1oOgl0MgMg
0861P@1lO7`0QhN708>3P`21PH400P1eMGD02P26QXH0V9RH0<W9b@2=SHd0S8b<08:2PP2][Jd0S8b<
0;bl_02DU9@L08V9RAh0oooo0P1cLg<00`1aLG40L71`075aL@0707=cL`0A071`L02a/K40Fe]K05UI
F@1YJFT0IFEU06m_K`1ZJVX0MgMg08N7Q`1iNGT0MgMg0861P@1iNGT0MGEe07AdM01gMgL00P1bLW80
2`1eMGD0Lg=c075aL@1fMWH0L71`075aL@1_Kfl0KVi^07QhN01]KFd0LW9b0080M7Ad0P1cLg<02`1b
LW80Lg=c06a/K01`L700NWYj071`L01cLg<0Kfm_07IfMP1_Kfl0L71`0080LW9b01D0MWIf07EeM@1c
Lg<0JVYZ06QXJ01YJFT0MWIf07emO@1ZJVX0GemO06][J`1gMgL0OWin09JFUP1jNWX0MgMg07AdM021
PH40N7Qh09NGU`22PX80701cLg<R0?ooo`00803oool308N7Q`0308B4Q027QhL0QhN700L0QhN700@0
;Rh^07moO`27QhL0QhN70`2?Shl01`2@T900QhN709:BTP2<S8`0SHf=09>CT`2>SXh00P2;Rh/03@26
QXH0R8R808b<S02<S8`0QhN708b<S027QhL0Ph>308:2PP23Ph<0SHf=08:2PP26QXH00`27QhL00`26
QXH0QhN708N7Q`0408N7Q`0508:2PP1oOgl0QhN707inOP21PH400P27QhL0202=SHd0PX:20820P01m
OGd0Ogmo07UiN@21PH40SXj>0P27QhL20861P@0809ZJVP35aLD0OGem08f=S@27QhL0Zj^[08N7Q`2S
Xj<M08N7Qah0oooo0P29RHT00`2;Rh/0QhN708^;R`0808V9R@0A030`<01dM7@0QhN708:2PP2;Rh/0
QhN708Z:RP2BTY80SHf=09fMW@2CTi<0TY:B09NGU`2@T900SXj>08V9R@27QhL00P2:RXX02@27QhL0
QHF508Z:RP2<S8`0QhN708V9R@27QhL0RXZ:08J6QP0408V9R@0:08R8R029RHT0Q8B408J6QP2;Rh/0
RHV908b<S026QXH0QHF508j>SP80PX:201H0R8R808F5Q@2:RXX0Ph>308J6QP1iNGT0QXJ608>3P`1o
Ogl0PH6107MgM`1kNg/0OWin0861P@2BTY80c/k>08F5Q@28R8P0PX:20;2`/02FUYH0];Bd7@29RHTN
0?ooo`80Lg=c00<0MWIf07EeM@1fMWH0201cLg<02`1DE5@0GemO075aL@1ZJVX0KVi^06QXJ01]KFd0
N7Qh07UiN@25QHD0O7al0080Ng]k00l0MGEe07IfMP1_Kfl0LW9b07=cL`1`L700K6a/06i^KP1_Kfl0
MgMg07EeM@1jNWX0MGEe06m_K`1fMWH00P1dM7@307=cL`0=07AdM01/K6`0Kfm_07IfMP1cLg<0N7Qh
07IfMP1gMgL0NWYj07AdM01`L700Lg=c06i^KP02071`L00B07MgM`1WIfL0MgMg07]kN`1/K6`0HF5Q
05UIF@1PH600JVYZ06m_K`1]KFd0U9BD07QhN01]KFd0JVYZ08F5Q@26QXH0U9BD7@1cLg<R0?ooo`00
803oool=08N7Q`0A028R8P15ADD0Ogmo0820P027QhL0P82008Z:RP2EUID0VIVI09ZJVP2DU9@0Ti>C
092@T02>SXh0SHf=08B4Q026QXH00P28R8P00`23Ph<0R8R808:2PP0408N7Q`0608:2PP28R8P0Ph>3
08R8R027QhL0R8R80P27QhL01@20P800QhN708>3P`27QhL0RXZ:00<0QhN700@0Ph>30861P@26QXH0
PX:20`27QhL0401kNg/0Ph>308N7Q`1fMWH0N7Qh08>3P`1jNWX0QhN707EeM@2=SHd0b<S807]kN`1`
L700SHf=0:>SX`2LW9`208N7Q`0308^;R`27QhL0QhN701T0QhN77P3oool=08V9R@0=04=3@`1^KVh0
Q8B408J6QP2=SHd0R8R808f=S@2<S8`0U9BD09NGU`2@T900UIFE09BDU00208n?S`80QhN700@0RHV9
08b<S026QXH0S8b<0`29RHT01`25QHD0RHV908N7Q`29RHT0QXJ608V9R@28R8P00`29RHT08P23Ph<0
SHf=08N7Q`26QXH0RHV908F5Q@28R8P0RHV90820P023Ph<0R8R808N7Q`28R8P0QHF50861P@20P800
PX:208>3P`1nOWh0P82008:2PP1kNg/0Rh^;07emO@2DU9@0d=3@08^;R`1iNGT0Ti>C0:ZZZP2PX:00
VYZJ08J6QP2:RXXK08V9RAh0oooo3@1cLg<0101lO7`0UIFE07EeM@1gMgL207YjNP0807IfMP1ZJVX0
L71`07=cL`1aLG40MgMg07YjNP1fMWH207EeM@80LW9b00@0MgMg07AdM01gMgL0NWYj0P1cLg<01@1]
KFd0Lg=c07MgM`1bLW80M7Ad00<0LW9b0`1cLg<01@1jNWX0MGEe071`L01aLG40KFe]0080Lg=c00`0
K6a/075aL@1cLg<0MWIf079bLP1^KVh0JFUY07AdM01^KVh0Jf][07IfMP1gMgL206i^KP0<07MgM`1e
MGD0OGem09BDU022PX80MWIf07]kN`25QHD0OGem08b<S01`L700LG5a6`1cLg<R0?ooo`00803oool=
08N7Q`0305eMG@0T92@0NGUi0080Shn?00T0RXZ:08B4Q025QHD0W9bL09>CT`2<S8`0Shn?09:BTP28
R8P00P2=SHd0102:RXX0QXJ608b<S026QXH308b<S080QhN700h0S8b<08N7Q`2<S8`0QhN708R8R026
QXH0QhN708R8R027QhL0Ph>308^;R`27QhL0QXJ608F5Q@<0QhN700T0Ph>307inOP21PH40QhN708:2
PP27QhL0PH6108R8R01kNg/00P27QhL208>3P`0<07YjNP27QhL0P8200820P03AdM40VYZJ06YZJP2?
Shl0T92@09NGU`27QhL0Q8B47027QhLN0?ooo`0308V9R@26QXH0RHV900X0RHV901D0MWIf0410@01h
N7P0QXJ608V9R@2:RXX0RHV908R8R02KVi/0VIVI09JFUP2DU9@0UYJF08f=S@2;Rh/0RHV908Z:RP29
RHT0Rh^;08F5Q@2;Rh/00P2:RXX208F5Q@0608^;R`25QHD0RXZ:08F5Q@2:RXX0R8R80`29RHT02@24
Q8@0RXZ:08B4Q028R8P0QHF508V9R@28R8P0QHF508>3P`0208F5Q@0G08V9R@23Ph<0QXJ608>3P`24
Q8@0O7al08B4Q01mOGd0NGUi08B4Q01nOWh0RHV908N7Q`2?Shl0b<S809BDU01aLG40XJ6Q0::RXP2W
YjL0RHV908N7Q`2;Rh/06`29RHTN0?ooo`0307=cL`1`L700Lg=c00X0Lg=c01D0QXJ607IfMP1[Jf/0
IfMW06a/K01aLG40MWIf07AdM01gMgL0OGem0861P@1lO7`0Ng]k07QhN01`L700KVi^075aL@1dM7@0
LG5a06m_K`1aLG400P1`L7001P1]KFd0KVi^075aL@1]KFd0L71`06e]K@80Lg=c00<0M7Ad079bLP1c
Lg<00P1aLG400`1]KFd0Lg=c075aL@0207=cL`0K06i^KP1`L700MgMg07EeM@1cLg<0LG5a06m_K`1a
LG40Jf][06i^KP1]KFd0Hf=S065QH@1aLG40LW9b07=cL`1iNGT0Q8B407moO`1`L700LG5a08f=S@2>
SXh0SHf=07=cL`1eMGD0MWIf01/0Lg=c8P3oool00200oooo00<0QhN708B4Q027QhL02P27QhL04024
Q8@09RHV06=SH`1aLG40QhN708F5Q@2=SHd0PX:209BDU02KVi/0X:2P08Z:RP2=SHd0SXj>08R8R026
QXH308N7Q`80R8R800D0QhN708f=S@26QXH0QhN708R8R00208N7Q`0308J6QP27QhL0R8R800D0QhN7
00<0QHF508Z:RP27QhL00P28R8P01P21PH40QhN708N7Q`25QHD0QhN708:2PP80PH610100R8R807mo
O`24Q8@0P8200861P@23Ph<0Ng]k0820P02>SXh0QhN70<g=c@2KVi/0Ph>309fMW@2JVYX0Vi^K7P27
QhLN0?ooo`0308V9R@27QhL0RHV900X0RHV900l0QhN7030`<01kNg/0Ph>3092@T028R8P0S8b<08R8
R02JVYX0Ti>C09VIV@2DU9@0TI6A08^;R`2=SHd00P2;Rh/00`29RHT0R8R808R8R00208b<S00308^;
R`25QHD0RHV90080R8R81P29RHT208J6QP0808V9R@26QXH0RHV908N7Q`28R8P0RHV908:2PP28R8P2
08B4Q00D08V9R@24Q8@0QhN708:2PP26QXH0Ng]k0820P01lO7`0NWYj08N7Q`20P800Ph>3092@T020
P800bl_;09:BTP1kNg/0X:2P0:6QX@2][JdN08V9RAh0oooo00<0Lg=c07EeM@1cLg<02P1cLg<03P1e
MGD0GEeM08J6QP23Ph<0OWin07AdM01bLW80MgMg07inOP1]KFd0L71`0861P@1iNGT0L71`0P1hN7P0
101gMgL0Lg=c079bLP1aLG4207MgM`0;071`L01_Kfl0Lg=c075aL@1bLW80Lg=c07AdM01cLg<0LW9b
07=cL`1dM7@00P1_Kfl0101cLg<0LW9b075aL@1`L702079bLP0H071`L01bLW80K6a/06m_K`1cLg<0
LW9b07MgM`1`L700Kfm_06UYJ@1[Jf/0J6QX06EUI@1eMGD0M7Ad07=cL`1eMGD0IVIV08J6QP1/K6`0
I6AT07emO@22PX80TY:B7P1cLg<R0?ooo`00803oool:08N7Q`0D08^;R`27QhL0QhN708N7Q`2=SHd0
EeMG02h^;P0b<S80QhN708F5Q@1oOgl0Shn?09jNWP2GUiL0Vi^K09NGU`28R8P0QhN708f=S@27QhL2
08J6QP0708Z:RP27QhL0R8R808J6QP2<S8`0QhN708J6QP0308N7Q`0308>3P`27QhL0Ph>300<0QhN7
00<0Q8B408f=S@27QhL00P27QhL02P1oOgl0QXJ608^;R`21PH40QhN708:2PP2<S8`0QhN708:2PP1k
Ng/208Z:RP0308N7Q`1gMgL0Ph>30080Ph>300P0NWYj08>3P`2@T900PH6109JFUP2IVIT0Vi^K0:6Q
XAh0QhN77P3oool00`29RHT0QXJ608V9R@0608V9R@0308J6QP2:RXX0RHV90080RHV900P0Shn?07If
MP1lO7`0Hf=S0861P@24Q8@0RXZ:096AT@<0UiNG00h0UIFE08V9R@29RHT0Shn?08b<S02;Rh/0QXJ6
08Z:RP29RHT0RXZ:08R8R02;Rh/0QHF508R8R0<0RHV900`0QhN708^;R`24Q8@0RHV908^;R`29RHT0
PH6108V9R@24Q8@0R8R808V9R@22PX8208N7Q`0G08J6QP28R8P0O7al08^;R`1oOgl0OWin07YjNP1l
O7`0N7Qh08B4Q01kNg/0OWin0861P@23Ph<0O7al0861P@2/[:`0MWIf09BDU02JVYX0Z:RX0;:b/P2;
Rh/07@29RHTN0?ooo`0307=cL`1`L700Lg=c00H0Lg=c00<0L71`075aL@1cLg<00P1cLg<02`1eMGD0
SHf=0<30`02IVIT0J6QX06i^KP1mOGd0MWIf06m_K`1gMgL0LW9b00<0Lg=c00D0MGEe07QhN01gMgL0
L71`075aL@0307=cL`03075aL@1^KVh0Lg=c00<0Lg=c00T0MGEe07MgM`1aLG40Lg=c07MgM`1cLg<0
Jf][06e]K@1^KVh00`1cLg<03`1bLW80KFe]07IfMP1bLW80IfMW075aL@1WIfL0JFUY06][J`1OGel0
F5QH06e]K@1`L700JFUY06e]K@02071`L00806e]K@2LW9`0H61P07AdM01iNGT0RXZ:09:BTP1fMWHM
07=cLb80oooo000P0?ooo`0308N7Q`24Q8@0QhN700H0QhN700<0Q8B408N7Q`27QhL00P27QhL208f=
S@0?07emO@0V9RH0S8b<08V9R@2CTi<0QhN709JFUP2JVYX0TY:B09NGU`2>SXh0T92@08f=S@2;Rh/0
SXj>00<0RXZ:0P27QhL0202;Rh/0QhN708N7Q`26QXH0QhN708f=S@2;Rh/0SHf=0P27QhL00`2>SXh0
SHf=08N7Q`0308N7Q`0308R8R023Ph<0QXJ600<0QhN701@0O7al08N7Q`1nOWh0NWYj08B4Q01nOWh0
O7al08J6QP1gMgL0Rh^;07moO`27QhL0Ph>308J6QP29RHT0PX:209^KV`29RHT0V9RH096AT@80Rh^;
7027QhLN0?ooo`0308V9R@27QhL0RHV900H0RHV900<0QhN708^;R`29RHT00P29RHT0102;Rh/0QhN7
08F5Q@13@d<208F5Q@0:08f=S@2:RXX0VIVI09ZJVP2FUYH0UIFE08J6QP2<S8`0Rh^;08V9R@80QhN7
0P2:RXX00`29RHT0QXJ608Z:RP0208V9R@80QHF500@0R8R808N7Q`28R8P0QXJ60P27QhL00`24Q8@0
QHF508V9R@0208R8R00L08V9R@21PH40Q8B408V9R@24Q8@0QHF50861P@29RHT0QHF50820P01hN7P0
O7al08>3P`2;Rh/0PX:208N7Q`1oOgl0PX:207UiN@30`<00Ph>307]kN`2SXj<0XZ:R0;Fe]@2MWId0
R8R808Z:RQ`0RHV97P3oool00`1cLg<0MGEe07=cL`0607=cL`0307EeM@1fMWH0Lg=c0080Lg=c01L0
L71`06YZJP1hN7P0N7Qh06YZJP1[Jf/0KFe]07AdM01kNg/0MgMg07YjNP1dM7@0J6QX06i^KP1`L700
KVi^06UYJ@1^KVh0LG5a079bLP1dM7@0Kfm_075aL@0207=cL`03071`L01]KFd0K6a/0080K6a/00`0
Kfm_075aL@1ZJVX0IVIV06e]K@1cLg<0LW9b07=cL`1bLW80KFe]06m_K`1cLg<206i^KP0F07AdM01c
Lg<0MgMg07EeM@1OGel0Jf][07MgM`1hN7P0Ng]k06e]K@1^KVh0JFUY069RHP33`l<0J6QX06IVIP23
Ph<0UIFE0:2PX025QHD0KVi^075aLA`0Lg=c8P3oool00200oooo4027QhL04`2=SHd0ATI60::RXP20
P800MWIf092@T027QhL0UIFE09JFUP2BTY80QXJ608V9R@27QhL0Rh^;08F5Q@27QhL0Ph>308^;R`2=
SHd01027QhL02023Ph<0QXJ608N7Q`22PX80QhN708f=S@2;Rh/0PX:20P27QhL07`28R8P0QhN708N7
Q`27QhL0QXJ608:2PP28R8P0QhN708R8R025QHD0T92@08b<S01oOgl0O7al07emO@1lO7`0QhN709>C
T`1NGUh0SXj>08N7Q`1kNg/0ZZZZ07emO@22PX80UiNG09jNWP2QXJ40Rh^;08N7Q`22PX807027QhLN
0?oooa00RHV901D0Shn?05YJFP2EUID0TY:B08F5Q@2GUiL0U9BD09JFUP2EUID0TY:B08^;R`2?Shl0
R8R808Z:RP29RHT0SHf=08N7Q`29RHT0RXZ:08V9R@2;Rh/00P29RHT02`27QhL0QHF508b<S027QhL0
QHF508^;R`2:RXX0Q8B408V9R@28R8P0RHV90080R8R801/0Q8B408F5Q@25QHD0R8R808B4Q026QXH0
Ng]k08R8R026QXH0MWIf0820P025QHD0Ogmo0820P028R8P0L71`07moO`23Ph<0Xj>S0;Ng]`1oOgl0
Rh^;0:FUY@2XZ:P0Zj^[092@T02?Shl07@29RHTN0?oooa00Lg=c00P0MGEe07MgM`1XJ6P0R8R80861
P@1nOWh0Ph>307QhN080MGEe00L0N7Qh07YjNP1bLW80LG5a07IfMP1iNGT0MGEe0080L71`00/0Lg=c
07MgM`1cLg<0Lg=c07EeM@1`L700N7Qh07IfMP1^KVh0L71`075aL@0207=cL`80LW9b00l0Lg=c079b
LP1]KFd0Kfm_07=cL`1bLW80KFe]06m_K`1RHV80JFUY06YZJP1RHV80LW9b07QhN01bLW800P1VIVH0
3@1mOGd0GEeM06][J`2TY:@0TI6A071`L01mOGd0Rh^;08R8R029RHT0NWYj07]kN`1iNGT0701cLg<R
0?ooo`00803oool@08N7Q`0B08f=S@1VIVH0MWIf0:>SX`2:RXX0VYZJ08N7Q`2EUID0TY:B096AT@2F
UYH0SXj>08N7Q`2=SHd0Rh^;096AT@23Ph<0RHV91`2;Rh/00`2?Shl0SHf=08N7Q`0208f=S@80R8R8
00H0QhN708R8R028R8P0QhN70861P@2=SHd308N7Q`0408F5Q@1jNWX0T92@08Z:RP80QhN70100SHf=
08N7Q`1kNg/0Q8B407IfMP1RHV80M7Ad096AT@2CTi<0Ph>307emO@2=SHd0U9BD0:ZZZP27QhL0SHf=
7@27QhLN0?oooa00RHV900L0Shn?05]KF`2>SXh0T92@07emO@2QXJ40R8R80080UYJF00/0SHf=08j>
SP2<S8`0R8R808b<S026QXH0Shn?08>3P`29RHT0Rh^;08Z:RP0308N7Q`0408Z:RP28R8P0R8R808B4
Q080QHF500@0RXZ:08F5Q@28R8P0R8R80`29RHT0701oOgl0R8R808F5Q@25QHD0QhN708B4Q01iNGT0
S8b<07emO@1iNGT0OWin07moO`20P800PH6108f=S@1bLW80QXJ609VIV@2OWil0WYjN08b<S02DU9@0
Y:BT09nOW`2/[:`0Shn?08f=S@25QHDL08V9RAh0oooo401cLg<00`1eMGD0EeMG08f=S@02061PH00<
0861P@1cLg<0N7Qh07YjNP1^KVh0K6a/075aL@1cLg<0LW9b06a/K01aLG40Kfm_0P1bLW80301aLG40
KFe]06e]K@1]KFd0LG5a06i^KP1YJFT0IVIV06e]K@1XJ6P0Kfm_06a/K0@0LW9b00<0Lg=c06e]K@1/
K6`00P1^KVh0601bLW80Kfm_06][J`1^KVh0H61P05eMG@1SHf<0H61P06MWI`1eMGD0O7al06IVIP2F
UYH0WinO08R8R024Q8@0O7al08j>SP2CTi<0Q8B40861P@1kNg/0Lg=c06e]KA`0Lg=c8P3oool00200
oooo4027QhL01`2=SHd0EEEE05=CD`2CTi<0TI6A0::RXP2MWId00P2KVi/02`2FUYH0Shn?09:BTP2=
SHd0TY:B08F5Q@2?Shl0QhN708V9R@2=SHd0Rh^;0080QhN700P0Ph>3096AT@2:RXX0QhN708R8R02@
T900RHV9092@T080QhN700X0S8b<08n?S`2=SHd0TI6A08N7Q`2=SHd0Rh^;08N7Q`2=SHd0S8b<0P27
QhL04`23Ph<0O7al07MgM`1jNWX0Shn?08Z:RP2?Shl0T92@07inOP2IVIT0Fe]K09>CT`2JVYX0NGUi
09RHV025QHD0QhN708f=S@2;Rh/00P27QhL00`22PX80QhN708N7Q`0<08N7Q`0308:2PP27QhL0QhN7
00T0QhN77P3oool@08V9R@0308n?S`1?Cdl0GemO0080SHf=00`0TI6A08b<S02EUID0SXj>092@T02?
Shl0S8b<08Z:RP2>SXh0R8R808j>SP24Q8@208N7Q`0_08Z:RP29RHT0Rh^;08B4Q02;Rh/0R8R808N7
Q`23Ph<0QHF508:2PP2;Rh/0RHV908J6QP25QHD0RHV908F5Q@26QXH0OWin08V9R@27QhL0PH6108>3
P`1nOWh0P82008F5Q@21PH40OGem0820P01jNWX0QhN708:2PP26QXH0TY:B07YjNP2b/[80QhN70:>S
X`2UYJD0RXZ:0:JVYP2WYjL0XJ6Q08^;R`2:RXX0RHV908b<S026QXH03@29RHT00`2<S8`0QXJ608V9
R@0:08V9RAh0oooo401cLg<0301eMGD0EUIF071`L01/K6`0L71`069RHP1QHF40L71`06IVIP1^KVh0
M7Ad06e]K@80Kfm_01L0M7Ad07=cL`1^KVh0Kfm_06][J`1aLG40Lg=c07MgM`1`L700K6a/06m_K`1`
L700JVYZ06EUI@1XJ6P0KVi^07=cL`1_Kfl0JFUY06YZJP1XJ6P0IFEU06ATI00206a/K00K06QXJ01V
IVH0GUiN06IVIP1]KFd0K6a/06i^KP1hN7P0K6a/06QXJ01VIVH0IfMW07MgM`1XJ6P0Vi^K0:6QX@2;
Rh/0R8R808F5Q@2:RXX0X:2P09JFUP1`L700LG5a07=cL`1hN7P0MWIf00d0Lg=c00<0N7Qh07IfMP1c
Lg<02P1cLg<R0?ooo`00803ooolA08N7Q`0B07MgM`0d=3@0H61P09NGU`23Ph<0SHf=09jNWP2XZ:P0
Vi^K08j>SP24Q8@0Shn?096AT@2BTY80QXJ608N7Q`2;Rh/0QhN70`2>SXh01@2=SHd0TY:B09>CT`2=
SHd0RHV90080T92@00T0VYZJ09BDU02DU9@0TY:B09BDU02>SXh0WIfM09:BTP2HV9P00P2BTY80502F
UYH0QhN708>3P`27QhL0S8b<09:BTP1iNGT0Ng]k08R8R01dM7@0QXJ607EeM@25QHD0VYZJ08J6QP2B
TY80X:2P096AT@25QHD0RHV90P27QhL00`2=SHd0QhN708N7Q`0908N7Q`0308B4Q027QhL0QhN700l0
QhN77P3ooolA08V9R@0508:2PP16ATH0S8b<09VIV@26QXH00P2ATI40202HV9P0T92@096AT@27QhL0
RHV908^;R`2=SHd0R8R80P2:RXX0;P25QHD0QhN708N7Q`26QXH0Q8B408>3P`22PX80Ph>30861P@27
QhL0Ph>308F5Q@21PH40QhN708B4Q025QHD0Ph>308J6QP20P800R8R808:2PP20P800RXZ:07moO`21
PH40QHF507inOP1lO7`0P8200861P@2ATI40RXZ:08F5Q@2<S8`0V9RH09BDU01lO7`0VYZJ0::RXP2G
UiL0W9bL0::RXP2;Rh/0RHV908^;R`25QHD:08V9R@0308N7Q`2;Rh/0RHV900l0RHV97P3ooolA07=c
L`0607]kN`1]KFd0XJ6Q07UiN@1dM7@0NWYj0P1WIfL00`1XJ6P0N7Qh07EeM@0206a/K00606i^KP1d
M7@0M7Ad075aL@1]KFd0JVYZ0P1YJFT02@1VIVH0GemO05eMG@1UIFD0IVIV06MWI`1RHV80FUYJ05]K
F`02069RHP07061PH01SHf<0EeMG05]KF`1PH600GEeM05]KF`0206IVIP0F06a/K01^KVh0GemO05IF
EP1fMWH0MGEe07emO@2:RXX0Kfm_08^;R`2<S8`0Kfm_069RHP20P800OGem07alO02ATI40UIFE07If
MP1cLg<0L71`06e]K@X0Lg=c00<0MGEe07IfMP1cLg<03`1cLg<R0?ooo`00803ooolB08N7Q`0>03<c
<`1<C4`0MgMg09BDU027QhL0SHf=096AT@2WYjL0Zj^[09bLW02:RXX0Ph>308R8R029RHT208j>SP0A
08b<S02BTY80TY:B09RHV02=SHd0OWin08b<S02>SXh0QhN709FEU@2:RXX0SXj>09FEU@29RHT0WIfM
08f=S@2OWil00P2IVIT01P2?Shl0U9BD08b<S02ATI40U9BD08>3P`80N7Qh00h0KFe]07]kN`1nOWh0
SHf=08>3P`1SHf<0Zj^[09VIV@1nOWh0MGEe096AT@2;Rh/0SXj>0:VYZ@H0QhN700<0Rh^;08N7Q`27
QhL03027QhL00`22PX80QhN708N7Q`0908N7Qah0oooo4P29RHT03P1[Jf/0KVi^08B4Q02ATI40RHV9
09JFUP2=SHd0TI6A08f=S@2:RXX0Rh^;08f=S@2>SXh0QHF50P27QhL208J6QP040861P@28R8P0RXZ:
07emO@80QhN70280Ng]k08V9R@1mOGd0PX:208j>SP1lO7`0Rh^;07]kN`28R8P0QHF508Z:RP23Ph<0
QHF508:2PP24Q8@0RHV908^;R`21PH40QhN708F5Q@1nOWh0PH6109NGU`2?Shl0Lg=c08n?S`2HV9P0
TI6A08R8R02LW9`0X:2P092@T02/[:`0S8b<1029RHT00`26QXH0RXZ:08V9R@0<08V9R@0308b<S026
QXH0RHV900X0RHV97P3ooolB07=cL`0>0:>SX`2<S8`0OGem079bLP1cLg<0P82006i^KP1MGEd0De=C
05mOG`1cLg<0OWin07YjNP1/K6`306YZJP0>06ATI01NGUh0H61P06m_K`1]KFd0Jf][06YZJP1QHF40
IFEU05mOG`1RHV80Jf][05mOG`1PH60205UIF@0I05]KF`1RHV80Hf=S061PH01UIFD0HV9R06MWI`1j
NWX0N7Qh0820P02:RXX0L71`079bLP21PH40P82007]kN`1FEUH0MWIf08V9R@25QHD0Ph>3092@T01f
MWH0PX:207MgM`0407=cL`03071`L01aLG40Lg=c00`0Lg=c00<0N7Qh07IfMP1cLg<02P1cLg<R0?oo
o`00803ooolB08N7Q`0<05EEE@0/;2`09RHV06a/K023Ph<0XJ6Q08V9R@2UYJD0SHf=09FEU@23Ph<0
R8R80`27QhL01P2?Shl0T92@08^;R`27QhL0SHf=09NGU`80QhN70180UIFE08N7Q`2CTi<0QhN708R8
R02JVYX0T92@09BDU023Ph<0VYZJ08:2PP2KVi/0QhN709JFUP2BTY80R8R809BDU02[Zj/209RHV00=
08Z:RP1lO7`0OGem08J6QP2TY:@0QhN707IfMP2ATI40Shn?08^;R`21PH40QhN709bLW00608N7Q`03
08B4Q027QhL0QhN700X0QhN700<0Rh^;08N7Q`2=SHd03027QhLN0?oooa80RHV901<0MWIf0861P@1_
Kfl0RHV908:2PP2EUID0N7Qh09^KV`2CTi<0WinO096AT@2<S8`0QHF508J6QP24Q8@0QHF50861P@26
QXH0Q8B40080Rh^;01H0OWin07moO`25QHD0Ng]k08V9R@1nOWh0PH6108F5Q@1oOgl0SXj>07EeM@27
QhL0P82009>CT`1lO7`0QhN708R8R024Q8@0PH6108J6QP1nOWh0RXZ:0P1oOgl0302<S8`0PH6108V9
R@20P800W9bL09jNWP29RHT0TI6A09nOW`22PX80[:b/0:6QX@80RHV900D0QXJ608V9R@29RHT0QhN7
08^;R`0:08V9R@0508J6QP2:RXX0RHV908^;R`25QHD02`29RHTN0?oooa80Lg=c01l0SXj>0<W9b@2f
][H0T92@06e]K@1ZJVX0FUYJ06e]K@1kNg/0Q8B408>3P`1gMgL0KVi^06m_K`1/K6`0IVIV05mOG`1/
K6`0KVi^071`L01UIFD0I6AT06EUI@1PH600HF5Q06MWI`1TI6@0IfMW05YJFP1MGEd0KVi^0080G5aL
0P1]KFd05P1QHF40HV9R06IVIP1[Jf/0G5aL04U9B@1BDU80Hf=S069RHP1aLG40PX:206YZJP1EEED0
IVIV0:6QX@27QhL0Jf][07]kN`2IVIT0JFUY08n?S`2FUYH207=cL`05071`L01cLg<0Lg=c07EeM@1f
MWH02P1cLg<01@1`L700LG5a07=cL`1`L700KFe]00/0Lg=c8P3oool00200oooo1`27QhL208^;R`X0
QhN700T0OGem03dm?@1fMWH0KFe]0861P@1]KFd0MWIf0820P02NWYh00P2FUYH308Z:RP0808R8R027
QhL0QhN709JFUP2?Shl0R8R808n?S`22PX8208R8R00O08b<S027QhL0OGem08B4Q01mOGd0QhN70861
P@1`L700Rh^;07emO@21PH40O7al08N7Q`23Ph<0KFe]08n?S`2;Rh/0QHF50861P@27QhL0PH6107al
O01jNWX0RXZ:096AT@2=SHd0Ogmo07MgM`29RHT0O7al0:6QX@0308N7Q`0308B4Q027QhL0QhN700`0
QhN700<0Q8B408N7Q`27QhL03@27QhLN0?ooo`H0RHV900<0QXJ608Z:RP2:RXX02P29RHT03025QHD0
@d=307alO024Q8@0Ti>C09:BTP2RXZ80SHf=09ZJVP25QHD0RHV908B4Q0<0Ph>302P0Q8B407inOP29
RHT0Rh^;08B4Q023Ph<0OWin08B4Q021PH40R8R807alO01mOGd0SXj>08b<S023Ph<0RHV908B4Q02A
TI40RHV908N7Q`29RHT0RXZ:08f=S@1bLW80Shn?096AT@2<S8`0Ogmo08f=S@20P800PX:208^;R`2B
TY80Shn?09BDU02MWId0W9bL09BDU02?Shl0^KVi0`29RHT00`2;Rh/0RHV908V9R@0<08V9R@0308N7
Q`2;Rh/0RHV900d0RHV97P3oool607=cL`03071`L01aLG40LG5a00X0Lg=c00`0N7Qh05mOG`1dM7@0
R8R808V9R@2LW9`0ZJVY0820P01dM7@0GUiN06=SH`1ZJVX206QXJ00Y06YZJP1]KFd0I6AT06ATI01^
KVh0K6a/069RHP1YJFT0K6a/06QXJ01/K6`0HF5Q06e]K@1nOWh0PX:206][J`1kNg/0QHF507YjNP1n
OWh0MgMg07moO`1eMGD0OWin06m_K`1dM7@0Ng]k07UiN@1/K6`0NGUi06i^KP1eMGD0Q8B407emO@1a
LG40OGem09RHV02PX:00P82008V9R@2LW9`00`1cLg<00`1jNWX0Lg=c07=cL`0<07=cL`0307EeM@1f
MWH0Lg=c00d0Lg=c8P3oool00200oooo0P27QhL01@2;Rh/0QhN708N7Q`27QhL0Q8B400d0QhN703D0
?Cdm02l_;`2?Shl0OGem0;6a/@2RXZ80TY:B0::RXP2@T900Rh^;08n?S`2<S8`0SHf=08B4Q02?Shl0
PH6109>CT`2EUID0Ti>C08R8R027QhL0Rh^;07emO@2@T900QhN709RHV02EUID0Shn?07]kN`2KVi/0
QhN709VIV@1dM7@0XJ6Q08j>SP2=SHd0TI6A0820P027QhL0WinO0:2PX02NWYh0VIVI09>CT`2IVIT0
TI6A09NGU`23Ph<0O7al08N7Q`1jNWX0Ti>C0;Zj^P0408N7Q`0308f=S@27QhL0QhN701`0QhN77P3o
ool208V9R@0508Z:RP29RHT0RHV908V9R@27QhL00P2;Rh/;08V9R@0f071`L01LG5`0SXj>0861P@2E
UID0QhN70820P02CTi<0S8b<08Z:RP24Q8@0PX:208V9R@1nOWh0QXJ607UiN@2=SHd0QXJ608B4Q021
PH40OWin08Z:RP1lO7`0Ph>308B4Q026QXH0SHf=08R8R01kNg/0T92@0820P02SXj<0JVYZ08j>SP21
PH40T92@0861P@1hN7P0QXJ608R8R01kNg/0OWin08:2PP1jNWX0RHV908:2PP2>SXh0WYjN09nOW`2V
YZH0O7al08^;R`2k^k/0VIVI0`29RHT00`2;Rh/0RHV908V9R@0L08V9RAh0oooo0P1cLg<01@1aLG40
Lg=c07=cL`1cLg<0MGEe0080MWIf2`1cLg<02P2PX:00TY:B07=cL`1cLg<0FEUI05EEE@1LG5`0IFEU
06i^KP1`L70206EUI@0Z06e]K@1XJ6P0IfMW06ATI01/K6`0HF5Q061PH01WIfL0I6AT075aL@1]KFd0
HF5Q06a/K01MGEd0Jf][06UYJ@1/K6`0J6QX06MWI`24Q8@0G5aL05mOG`1QHF40MgMg05mOG`1TI6@0
Kfm_05UIF@15ADD0C4a<05IFEP1CDe<0HF5Q061PH01[Jf/0UYJF09nOW`2MWId0Kfm_06UYJ@24Q8@0
RXZ:0`1cLg<00`1`L700Lg=c07=cL`0L07=cLb80oooo000P0?oooa@0QhN700d0SHf=02`/;00c<c<0
LW9b08b<S01lO7`0Ng]k0861P@25QHD0Q8B40861P@2?Shl0Ti>C0080QhN701/0Ng]k08N7Q`22PX80
TI6A08^;R`28R8P0VYZJ08N7Q`2ATI40Ph>309jNWP2[Zj/0U9BD09VIV@20P800QhN709ZJVP2<S8`0
Rh^;0861P@2h^;P0Rh^;09:BTP27QhL0Q8B407=cL`1iNGT00P1lO7`02P2:RXX0OGem08:2PP28R8P0
QhN708n?S`2`/;00U9BD0::RXP22PX8608N7Q`0308^;R`27QhL0QhN701T0QhN77P3oool208V9R@03
08^;R`29RHT0RHV900l0RHV90180Rh^;06IVIP1iNGT0OGem0:6QX@2ATI40Shn?09VIV@2DU9@0QhN7
07emO@25QHD0R8R80861P@25QHD0P82008b<S020P80208Z:RP0R07emO@2:RXX0LW9b092@T02>SXh0
Q8B409>CT`1nOWh0S8b<08Z:RP29RHT0PH6107MgM`2EUID0L71`08R8R01lO7`0QHF508:2PP2=SHd0
QhN709>CT`25QHD0Q8B409:BTP2?Shl0[Zj^0:6QX@2JVYX0JFUY08B4Q021PH40b<S808J6QPD0RHV9
00<0QXJ608Z:RP29RHT06P29RHTN0?ooo`80Lg=c00<0MWIf07=cL`1cLg<03`1cLg<02`1`L700Xj>S
0;Jf]P1jNWX0TI6A08^;R`29RHT0TI6A08F5Q@1dM7@0JFUY0080IFEU00L0J6QX06e]K@1cLg<0N7Qh
06e]K@1ZJVX0LG5a0080HF5Q0200De=C079bLP1oOgl0EEEE05aLG01GEeL0IFEU07alO01cLg<0E5AD
05EEE@20P800EeMG03hn?P1MGEd0HV9R06UYJ@1mOGd0QXJ609:BTP1jNWX0NGUi07emO@26QXH0[Zj^
09FEU@2<S8`0?Shn0492@P1KFe/0/;2`07IfMPD0Lg=c00<0L71`075aL@1cLg<06P1cLg<R0?ooo`00
803ooolF08N7Q`0P059BDP0c<c<0Ph>306IVIP2;Rh/0XJ6Q09jNWP29RHT0QHF507alO02IVIT0Rh^;
09FEU@22PX80Q8B409FEU@2;Rh/0P82008>3P`1fMWH0Ti>C09nOW`1lO7`0QhN7071`L02PX:00QhN7
08J6QP2DU9@0RHV908Z:RP1kNg/208N7Q`0709>CT`2:RXX0TI6A08f=S@28R8P0Q8B40861P@0208n?
S`070:2PX021PH40/[:b08j>SP22PX80PH6107YjNP0208^;R`L0QhN700D0PX:208N7Q`27QhL0QhN7
08:2PP0508N7Q`0308B4Q027QhL0QhN700h0QhN77P3ooolF08V9R@0B07QhN014A4@0Xj>S0820P02D
U9@0VYZJ09>CT`25QHD0P820075aL@29RHT0PH61096AT@20P800O7al092@T029RHT0OWin0P22PX80
0`29RHT0PH610820P00207alO00:09JFUP1nOWh0Q8B408b<S025QHD0QXJ608B4Q02@T900Ph>308F5
Q@80Rh^;01L0Ph>308F5Q@2>SXh0U9BD092@T026QXH0WIfM092@T01hN7P0Lg=c09NGU`2BTY80Y:BT
08R8R02:RXX0RHV908J6QP29RHT0Rh^;08V9R@2;Rh/0S8b<08J6QP0208V9R@0308b<S026QXH0RHV9
00@0RHV900@0QhN708^;R`29RHT0QHF53@29RHTN0?oooaH0Lg=c00l0UIFE06][J`2LW9`0RXZ:07mo
O`1`L700JVYZ06a/K01YJFT0GUiN061PH01TI6@0LG5a06e]K@1TI6@00P1_Kfl02`1/K6`0KVi^07al
O01WIfL0Cdm?079bLP1RHV80NGUi06a/K01SHf<0KVi^0080Jf][01h0K6a/07YjNP1nOWh0K6a/065Q
H@1dM7@0K6a/06ATI01/K6`0OWin08Z:RP1dM7@0IfMW07EeM@24Q8@0;Rh^04i>CP2<S8`0QhN70:VY
Z@1^KVh0LG5a07=cL`1`L700Lg=c07IfMP1cLg<0MWIf07QhN01fMWH207=cL`0307QhN01fMWH0Lg=c
00@0Lg=c00@0MGEe07IfMP1cLg<0KFe]3@1cLg<R0?ooo`00803ooolF08N7Q`0O08f=S@0I6AT0X:2P
0:b/[01lO7`0Ph>309:BTP1nOWh0O7al06IVIP2@T900P82009VIV@28R8P0Ph>309NGU`2:RXX0Ph>3
08N7Q`2GUiL0Kfm_09VIV@20P800Ti>C08n?S`2JVYX0MgMg08n?S`2>SXh0PX:208R8R00208n?S`0E
09:BTP2CTi<0UYJF09>CT`27QhL0MGEe08j>SP22PX80KVi^07EeM@1_Kfl0QhN707emO@2HV9P0SHf=
0:FUY@27QhL0OWin08^;R`27QhL0Q8B400@0QhN700D0SHf=08N7Q`27QhL0QhN708f=S@0G08N7Qah0
oooo5P29RHT07P2;Rh/0Fe]K07]kN`2BTY80TI6A09>CT`2=SHd0QXJ608F5Q@1XJ6P0U9BD0820P02<
S8`0OGem07alO02EUID0QhN707emO@1kNg/0SXj>06][J`2NWYh0Ph>308B4Q01dM7@0WinO07YjNP25
QHD0Rh^;08>3P`80QXJ601`0P82007moO`2=SHd0QXJ608^;R`2DU9@0QHF509:BTP2GUiL0Rh^;0:6Q
X@2JVYX0R8R807inOP2PX:00P8200;6a/@2g]kL0QHF508b<S029RHT0QhN708^;R`29RHT0Rh^;08V9
R@2;Rh/0QHF50P29RHT00`2;Rh/0QHF508V9R@0E08V9RAh0oooo5P1cLg<0?01`L700Z:RX04I6AP1I
FET0S8b<08J6QP1]KFd0NGUi07YjNP1YJFT0NGUi06m_K`1UIFD0HF5Q06MWI`1cLg<0KVi^06MWI`1P
H600Jf][06=SH`1oOgl0Lg=c061PH01>CTh0Ogmo06m_K`1VIVH0Kfm_075aL@1^KVh0IfMW05iNGP1J
FUX0K6a/061PH01ZJVX0Ph>30861P@1jNWX0S8b<096AT@2ZZZX0Y:BT079bLP1_Kfl0PX:2065QH@2;
Rh/0];Bd07QhN01dM7@0Lg=c07EeM@1fMWH0Lg=c07IfMP1cLg<0L71`06e]K@80Lg=c00<0L71`06e]
K@1cLg<05@1cLg<R0?ooo`00803ooolG08N7Q`0b08^;R`0:2PX0UiNG0<G5a@2UYJD0TY:B08V9R@1l
O7`0IFEU09BDU02CTi<0MgMg07]kN`1_Kfl0QHF509RHV01kNg/0TI6A08N7Q`1_Kfl0VIVI08>3P`1`
L700LG5a0;bl_02<S8`0QhN7071`L027QhL0TY:B0820P021PH40Q8B4096AT@2EUID0X:2P0:6QX@26
QXH0LG5a09NGU`27QhL0T92@09jNWP2b/[80M7Ad09^KV`26QXH0/k>c08f=S@24Q8@308N7Q`0308^;
R`27QhL0QhN700T0QhN700<0Rh^;08N7Q`27QhL01@27QhL00`22PX80QhN708N7Q`0908N7Qah0oooo
5P29RHT03P26QXH0RXZ:05]KF`2<S8`0T92@08V9R@28R8P0S8b<07moO`1VIVH0QXJ6092@T022PX80
RHV90P25QHD04@2?Shl0P82008b<S02>SXh0M7Ad09ZJVP27QhL0Ogmo079bLP2LW9`0NWYj09bLW01n
OWh0Ng]k08f=S@23Ph<0Ogmo0080Ph>301D0QHF509FEU@2FUYH0TY:B09bLW02GUiL0TY:B08^;R`1U
IFD0OGem07moO`2ATI40S8b<0=OGe`2ATI40Ph>308^;R`29RHT0QXJ608Z:RP2<S8`02@29RHT00`26
QXH0RXZ:08V9R@0508V9R@0308b<S026QXH0RHV900X0RHV97P3ooolF07=cL`0h071`L01aLG40]kNg
06MWI`0m?Cd0E5AD06MWI`1fMWH0LW9b06EUI@1RHV80L71`07]kN`22PX80QhN7075aL@1ZJVX0MGEe
06e]K@1jNWX0Kfm_07YjNP1eMGD0OWin06YZJP1GEeL0FEUI08n?S`1mOGd0H61P06i^KP1cLg<0KFe]
06i^KP1QHF40GemO06UYJ@1[Jf/0PX:20:FUY@1gMgL0PH6106a/K00X:2P0=CDe07UiN@1YJFT0NGUi
0;>c/`1iNGT0Kfm_07IfMP1cLg<0L71`075aL@1hN7P907=cL`03071`L01aLG40Lg=c00D0Lg=c00<0
N7Qh07IfMP1cLg<02P1cLg<R0?ooo`00803oool508N7Q`0308^;R`27QhL0QhN700h0QhN701l0Q8B4
08N7Q`0e=CD09RHV096AT@2WYjL0Zj^[09jNWP27QhL0GUiN07MgM`2TY:@0R8R80:2PX02GUiL0Ng]k
09ZJVP2IVIT0Shn?09FEU@22PX80PH6108n?S`1jNWX0F5QH075aL@1oOgl0Zj^[08n?S`1eMGD0QhN7
0080MWIf00l0GEeM06m_K`1XJ6P0KVi^07AdM02<S8`0SHf=06IVIP2NWYh0PH6107EeM@2XZ:P0QhN7
06a/K02EUID01@27QhL00`1nOWh0QhN7096AT@0408N7Q`0308:2PP27QhL0QhN70080QhN700<0Q8B4
08N7Q`22PX801@27QhL00`2=SHd0QhN708N7Q`0:08N7Qah0oooo1029RHT00`26QXH0RXZ:08V9R@0?
08V9R@0C08N7Q`2;Rh/0E5AD05UIF@2EUID0S8b<09RHV02=SHd0QXJ606IVIP1kNg/0VYZJ08J6QP25
QHD0Q8B407IfMP2<S8`0R8R808j>SP0208J6QP0L08b<S024Q8@0Q8B407MgM`2GUiL0QHF508n?S`1o
Ogl0PX:209RHV021PH40UIFE08B4Q02ATI40V9RH0:2PX02IVIT0XJ6Q09NGU`21PH40U9BD06a/K01P
H600WIfM08j>SP26QXH0bl_;0:^[Z`<0RHV900@0S8b<08F5Q@29RHT0S8b<0`29RHT00`2<S8`0QXJ6
08V9R@0308V9R@0308N7Q`2;Rh/0QXJ600D0RHV900<0Rh^;08F5Q@29RHT02P29RHTN0?ooo`@0Lg=c
00<0L71`075aL@1cLg<03`1cLg<0<@1eMGD0MWIf0861P@2FUYH0Ng]k05MGE`1SHf<0HF5Q06m_K`1^
KVh0LG5a06i^KP1_Kfl0De=C05aLG01VIVH0I6AT061PH01bLW80H61P07IfMP20P800IFEU07]kN`2<
S8`0X:2P07MgM`1GEeL0GEeM07alO029RHT0O7al09NGU`2JVYX0VIVI0:^[Z`2_[jl0WYjN096AT@22
PX80S8b<06][J`1ADE40C4a<06a/K01kNg/0S8b<0<;2`P2TY:@00`1cLg<207QhN00307=cL`1^KVh0
Lg=c0080Lg=c00<0N7Qh07IfMP1cLg<00`1cLg<00`1eMGD0MWIf07IfMP0507=cL`03071`L01]KFd0
Lg=c00X0Lg=c8P3oool00200oooo1027QhL00`24Q8@0QhN708N7Q`0A08N7Q`0C06e]K@0S8b<0?clo
07MgM`2JVYX0_;bl0:^[Z`22PX80DU9B09VIV@2QXJ40N7Qh08n?S`26QXH0SXj>09bLW02;Rh/0SHf=
09>CT`0208N7Q`0C0861P@1eMGD0O7al06][J`1mOGd0M7Ad08R8R01iNGT0MWIf08j>SP1kNg/0LW9b
07EeM@1/K6`0Ng]k08:2PP1fMWH0Ph>309JFUP0207emO@0;08F5Q@2CTi<0UiNG08:2PP27QhL0PX:2
08N7Q`2;Rh/0QhN708^;R`1nOWh00P27QhL00`22PX80QhN708f=S@0J08N7Qah0oooo1029RHT00`27
QhL0Rh^;08V9R@0A08V9R@0k07moO`1LG5`0MWIf08f=S@2@T900TI6A08N7Q`26QXH0IVIV08j>SP2A
TI40Ph>308V9R@1hN7P0Ph>308^;R`24Q8@0S8b<092@T01mOGd0PX:208Z:RP22PX80R8R807UiN@2L
W9`0QhN709JFUP2>SXh0QHF509>CT`24Q8@0V9RH0:2PX02=SHd0TY:B0:6QX@29RHT0Jf][08V9R@1U
IFD0PX:20:FUY@2:RXX0_[jn0;:b/P2<S8`0RXZ:08J6QP2>SXh0QXJ608Z:RP25QHD0RHV908b<S026
QXH0RHV908^;R`25QHD01P29RHT01@25QHD0RHV908V9R@29RHT0S8b<00h0RHV97P3oool407=cL`03
07EeM@1fMWH0Lg=c0140Lg=c03/0PH6109jNWP2VYZH0Rh^;06YZJP16ATH0BTY:07IfMP1jNWX0J6QX
06ATI01kNg/0Jf][05eMG@1TI6@0H61P06MWI`1aLG40L71`069RHP1ZJVX0Ng]k07alO01nOWh0NWYj
09VIV@24Q8@0QHF508V9R@20P800NWYj07UiN@2PX:00YjNW09JFUP2=SHd0Vi^K08F5Q@1>CTh0I6AT
04];B`1dM7@0WIfM06UYJ@2^[Zh0];Bd07QhN01kNg/0L71`07IfMP1`L700LG5a07QhN01cLg<0N7Qh
07IfMP1cLg<0L71`06e]K@0607=cL`0506e]K@1cLg<0Lg=c07=cL`1hN7P03P1cLg<R0?ooo`00803o
oolF08N7Q`0B08f=S@2;Rh/0QhN708^;R`1EEED0;2`/05QHF02CTi<0R8R808n?S`2>SXh0G5aL05QH
F027QhL0SHf=08N7Q`1cLg<0Kfm_0P2IVIT02`2UYJD0OGem0::RXP2JVYX0MGEe08>3P`1TI6@0ATI6
04Q8B01JFUX0H61P0080Kfm_00`0GemO0861P@20P800W9bL09FEU@28R8P0TY:B07UiN@1mOGd0P820
07alO025QHD308N7Q`0508:2PP2=SHd0QhN708N7Q`2=SHd00P27QhL0102;Rh/0QhN708:2PP22PX8K
08N7Qah0oooo5P29RHT02`28R8P0QXJ608J6QP2:RXX0MWIf06][J`1_Kfl0UYJF092@T02DU9@0SXj>
0080Ng]k01@0NWYj08^;R`2;Rh/0OWin08Z:RP2<S8`0Ogmo092@T01hN7P0XJ6Q0:2PX022PX80ZJVY
09VIV@20P800R8R809^KV`2CTi<0VIVI09fMW@80UiNG01P0MgMg07=cL`1iNGT0PH6107inOP26QXH0
Y:BT0:>SX`24Q8@0QHF50;>c/`25QHD0S8b<08J6QP2;Rh/0QHF508V9R@2;Rh/0QHF508J6QP2:RXX0
S8b<08Z:RP26QXHK08V9RAh0oooo5P1cLg<206a/K00i071`L01aLG40SXj>0:^[Z`22PX80NGUi07em
O@1kNg/0M7Ad08f=S@2ATI40GUiN071`L01gMgL0NGUi08n?S`1TI6@0DU9B05iNGP1WIfL0NWYj0820
P01lO7`0Y:BT0:n_[`2/[:`0][Jf0;fm_@2[Zj/0Y:BT0:ZZZP2b/[80Shn?069RHP0n?Sh0Cdm?06MW
I`1HF5P0OWin0:BTY02PX:00NGUi071`L02_[jl0KFe]07QhN01fMWH0L71`06e]K@1cLg<0L71`06e]
K@1`L700LG5a07QhN01kNg/0MWIf01/0Lg=c8P3oool00200oooo5P27QhL0;@24Q8@0QhN708B4Q027
QhL0PX:205eMG@0Q8B40S8b<09nOW`2e]KD0W9bL0861P@1HF5P0L71`0820P01jNWX0OWin07]kN`1<
C4`0IFEU09>CT`1kNg/0X:2P08V9R@1fMWH0Y:BT0;Bd]023Ph<0LW9b07AdM01ZJVX0KFe]08n?S`2T
Y:@0WYjN08^;R`21PH40SHf=08N7Q`2?Shl0OGem096AT@26QXH0QhN707QhN00208N7Q`04096AT@27
QhL0QhN708^;R`D0QhN70P2=SHd208N7Q`0308^;R`27QhL0QhN701L0QhN77P3ooolF08V9R@0Q08N7
Q`2;Rh/0QhN708n?S`26QXH0N7Qh07]kN`2:RXX0OGem09FEU@2KVi/0SHf=07QhN025QHD0UIFE08J6
QP2;Rh/0Shn?08B4Q01kNg/0W9bL07alO02MWId0XJ6Q08F5Q@2ATI40UIFE08:2PP23Ph<0T92@08j>
SP27QhL0QXJ60080O7al0100K6a/07]kN`2<S8`0MGEe0861P@2EUID0Xj>S08>3P`29RHT0^KVi08F5
Q@26QXH0S8b<08F5Q@26QXH0RXZ:0P29RHT02026QXH0RHV908^;R`2;Rh/0QhN708F5Q@26QXH0RXZ:
6@29RHTN0?oooaH0Lg=c03<0MGEe07IfMP1eMGD0Ng]k07IfMP2:RXX0c<c<071`L019BDT0E5AD07Mg
M`1oOgl0SHf=08J6QP2<S8`0OGem0820P02:RXX0Zj^[08F5Q@21PH40Kfm_07MgM`2CTi<0P820065Q
H@1EEED0KVi^08:2PP2BTY80VYZJ08f=S@1WIfL0@T9204Q8B016ATH0IfMW075aL@1HF5P0H61P08j>
SP2?Shl0KFe]07=cL`38b<P0KFe]071`L01^KVh0KFe]071`L01aLG400P1cLg<0201`L700Lg=c07If
MP1`L700JVYZ06e]K@1`L700LG5a6@1cLg<R0?ooo`00803ooolI08N7Q`0[08f=S@22PX80QhN708:2
PP0W9bL0LW9b0:>SX`2/[:`0YJFU08R8R01bLW80Jf][06=SH`1WIfL0HV9R06QXJ00_;bl0>SXj01/K
6`0g=cL0JVYZ06EUI@1SHf<0OGem08:2PP21PH40S8b<09ZJVP2/[:`0PX:208n?S`2>SXh0PX:2096A
T@29RHT0Ph>306][J`21PH40UIFE08N7Q`0n?Sh0QhN708:2PP0308N7Q`0@08B4Q02;Rh/0QhN708N7
Q`24Q8@0QhN708^;R`27QhL0PX:208N7Q`24Q8@0Rh^;08N7Q`2;Rh/0QhN708:2PQD0QhN77P3ooolI
08V9R@0`08n?S`23Ph<0RHV908N7Q`1QHF40NGUi0:BTY02GUiL0T92@09:BTP2CTi<0U9BD08f=S@2K
Vi/0V9RH092@T02BTY80/[:b09RHV02WYjL0VIVI08J6QP2@T900X:2P08^;R`2:RXX0PX:206e]K@23
Ph<0Kfm_07YjNP20P800MgMg08R8R01mOGd0Shn?09RHV02>SXh0Shn?0;Ng]`2SXj<0];Bd08B4Q029
RHT0Rh^;08V9R@27QhL0S8b<0P29RHT03027QhL0RHV908Z:RP2<S8`0QXJ608V9R@25QHD0S8b<08J6
QP2:RXX0S8b<08J6QQD0RHV97P3ooolI07=cL`0Z07EeM@1`L700Lg=c07IfMP2QXJ40Lg=c07alO01P
H600GEeM07moO`2HV9P0XJ6Q0:2PX02^[Zh0/;2`09jNWP3MgMd0oooo0?clo03clo<0Z:RX09BDU02T
Y:@0WinO07alO01kNg/0IFEU03Ph>015ADD0E5AD05MGE`1OGel0HF5Q06MWI`1PH600P8200:NWY`22
PX80KFe]0;Bd]03Vi^H0/K6a0P1cLg<0101fMWH0Lg=c07EeM@1dM7@207=cL`0<07EeM@1cLg<0LG5a
07QhN01fMWH0Lg=c075aL@1dM7@0L71`075aL@1hN7P0MWIf5@1cLg<R0?ooo`00803ooolI08N7Q`0Z
08f=S@22PX80QhN708N7Q`0c<c<08B4Q04M7A`2TY:@0/[:b0:b/[01kNg/0OWin06YZJP27QhL0OWin
08Z:RP28R8P0Xj>S09^KV`2=SHd0PH61075aL@21PH40Ph>30861P@2DU9@0PX:207UiN@2@T900NGUi
08n?S`2HV9P0Ph>307]kN`1WIfL0LG5a07QhN027QhL0JFUY08f=S@27QhL0Rh^;1`27QhL01@2;Rh/0
QhN708B4Q027QhL0SHf=0080QhN700D0Q8B408N7Q`24Q8@0QhN708f=S@0:08N7Q`0308:2PP27QhL0
Rh^;00T0QhN77P3ooolA08V9R@0308b<S029RHT0RHV900D0RHV901l0Shn?08>3P`29RHT0RHV906EU
I@2?Shl0LG5a08^;R`2MWId0Ti>C09:BTP2HV9P0Q8B409NGU`25QHD0WinO08F5Q@2<S8`0PX:207in
OP2<S8`0Ph>308f=S@29RHT0OWin07]kN`1`L700MgMg09FEU@1ZJVX0QHF50080QhN700/0Ti>C09BD
U02QXJ40Rh^;09VIV@2a/K40`L7108:2PP2:RXX0QHF508^;R`0308V9R@0508^;R`26QXH0RXZ:08V9
R@27QhL00P2;Rh/01@25QHD0RHV908N7Q`2;Rh/0QhN70080Rh^;00<0QHF508V9R@29RHT01029RHT0
0`2<S8`0RHV908b<S00208J6QP0308Z:RP29RHT0RHV900L0RHV97P3ooolA07=cL`0307QhN01cLg<0
Lg=c00D0Lg=c02`0MGEe071`L01cLg<0Lg=c09ZJVP3Xj>P0UIFE05UIF@1SHf<0FUYJ08j>SP2CTi<0
S8b<08R8R01hN7P0Shn?06a/K01KFe/0EEEE05iNGP1nOWh0Ph>30820P01gMgL0Jf][05=CD`1FEUH0
JFUY07alO01GEeL0IVIV05mOG`1eMGD0Shn?0:JVYP2^[Zh0QXJ608Z:RP3;bl/0_;bl06YZJP1aLG40
KFe]07IfMP<0Lg=c00l0MWIf071`L01aLG40Lg=c07EeM@1fMWH0L71`06e]K@1cLg<0MGEe07IfMP1e
MGD0MWIf071`L01]KFd01P1cLg<01P1hN7P0Lg=c07QhN01fMWH0L71`075aL@T0Lg=c8P3oool00200
oooo4@27QhL00`2=SHd0QhN708N7Q`0408N7Q`0408:2PP2=SHd0PX:208:2PP80QhN700T0MgMg01/K
6`0e=CD0TY:B0:2PX02HV9P0WYjN09:BTP2=SHd00P27QhL04`1lO7`0OWin07QhN01jNWX0SHf=08:2
PP25QHD0RXZ:0861P@1^KVh0U9BD08F5Q@2QXJ40Ogmo08n?S`2=SHd0OGem07IfMP26QXH00P2:RXX0
1@1RHV80QhN708N7Q`24Q8@0Rh^;0080QhN700<0PX:208N7Q`22PX802P27QhL00`22PX80QhN708N7
Q`0:08N7Q`0308f=S@27QhL0OWin00X0QhN77P3ooolA08V9R@0308^;R`29RHT0RHV900@0RHV900l0
QXJ608n?S`26QXH0QXJ608b<S029RHT0QXJ606ATI01iNGT0UIFE08j>SP2:RXX0Rh^;08B4Q02:RXX0
0P2=SHd01P24Q8@0Ti>C08^;R`27QhL0SHf=0861P@80Ph>300L0P82007=cL`1oOgl0N7Qh08B4Q01a
LG40UiNG0080W9bL0P2BTY802`21PH40RXZ:0:j^[P2[Zj/0RHV908F5Q@2<S8`0Rh^;08b<S026QXH0
S8b<0080QXJ600<0RHV908^;R`29RHT01@29RHT00`2<S8`0QXJ608V9R@0408V9R@0508b<S029RHT0
RHV908V9R@2<S8`00P29RHT0102;Rh/0RHV908F5Q@2;Rh/908V9RAh0oooo4@1cLg<00`1`L700Lg=c
07=cL`0407=cL`0?07IfMP1eMGD0MWIf07IfMP1hN7P0Lg=c0861P@2b/[80]KFe07QhN01PH600I6AT
05iNGP1RHV80Kfm_00<0NGUi0240Rh^;08N7Q`1oOgl0M7Ad06e]K@1^KVh0J6QX06e]K@1_Kfl0F5QH
05eMG@1ADE40FUYJ0820P029RHT0VYZJ09BDU022PX80IFEU075aL@3?cll0Y:BT07=cL`1aLG40M7Ad
07IfMP1hN7P0MWIf07QhN01fMWH0L71`07=cL`1fMWH01P1cLg<00`1hN7P0MWIf07=cL`0407=cL`05
07QhN01cLg<0Lg=c07=cL`1hN7P00P1cLg<0101`L700Lg=c07QhN01fMWH907=cLb80oooo000P0?oo
oa40QhN700<0PX:208N7Q`27QhL02@27QhL08@1nOWh0QhN708f=S@22PX80QhN704I6AP0i>CT0GEeM
0:FUY@2d];@0WinO09BDU01mOGd0QhN70861P@1mOGd0JVYZ071`L01ZJVX0QhN708f=S@2;Rh/0@410
075aL@1_Kfl0G5aL07]kN`2NWYh0O7al04Q8B01?Cdl0OWin08:2PP0208N7Q`0308:2PP27QhL0SHf=
0080QhN700L0PX:208B4Q027QhL0SHf=08N7Q`2=SHd0Rh^;00<0QhN700<0SHf=08N7Q`27QhL00P22
PX801027QhL0PX:208:2PP22PX8408N7Q`0308:2PP27QhL0SHf=0080QhN700<0Q8B408:2PP27QhL0
0`27QhL00`2=SHd0QhN708N7Q`0208N7Qah0oooo4029RHT00`2<S8`0QXJ608V9R@0908V9R@0Q08J6
QP25QHD0Rh^;08n?S`23Ph<0RHV9071`L02RXZ80Q8B408F5Q@2@T900Ph>308j>SP28R8P0Shn?08J6
QP29RHT0OWin08R8R022PX80T92@08>3P`2>SXh0MgMg0:RXZ02QXJ40R8R808f=S@2IVIT0VYZJ09FE
U@2WYjL0ZJVY0080RHV900P0S8b<08J6QP29RHT0Rh^;08V9R@2<S8`0QXJ608N7Q`80Rh^;00<0QHF5
08R8R026QXH00P29RHT208^;R`0808F5Q@2<S8`0QXJ608Z:RP2<S8`0QXJ608Z:RP26QXH308V9R@07
08b<S026QXH0RHV908n?S`29RHT0QHF508N7Q`0508V9R@0308^;R`25QHD0RHV90080RHV97P3oool@
07=cL`0307QhN01fMWH0Lg=c00T0Lg=c00T0L71`07QhN01fMWH0MGEe071`L01cLg<0UYJF0>[ZjP2J
VYX00P1>CTh08`1BDU80KFe]07emO@1lO7`0MWIf07inOP22PX80RXZ:08V9R@1nOWh0IFEU07IfMP2V
YZH0]kNg0;2`/02QXJ40QXJ6075aL@2HV9P0b<S80=WIf@2[Zj/0NGUi07=cL`1hN7P0MWIf07=cL`1`
L700Lg=c07QhN01fMWH0MGEe07IfMP1`L700KFe]0080K6a/0P1cLg<02P1fMWH0L71`06e]K@1hN7P0
MWIf07]kN`1hN7P0MWIf07]kN`1fMWH307=cL`0807QhN01fMWH0Lg=c07EeM@1cLg<0KFe]07EeM@1i
NGT407=cL`03071`L01]KFd0Lg=c0080Lg=c8P3oool00200oooo4027QhL00`2ATI40QhN708N7Q`09
08N7Q`0408B4Q027QhL0QhN708f=S@@0QhN70P16ATH01@1KFe/0Shn?09VIV@2XZ:P0VIVI0080SXj>
00<0MWIf06a/K01GEeL00P1KFe/00`1gMgL0IfMW07inOP0209jNWP0407MgM`1[Jf/0OGem08f=S@80
QhN700<0Rh^;08N7Q`2=SHd00`27QhL0102;Rh/0SHf=08N7Q`2;Rh/208N7Q`0308^;R`24Q8@0QhN7
00@0QhN700<0Rh^;08f=S@27QhL0102=SHd01@2;Rh/0QhN708^;R`27QhL0SHf=0080QhN700@0TI6A
08f=S@27QhL0SHf=2P27QhLN0?ooo`l0RHV900<0QXJ608b<S025QHD02P29RHT01P27QhL0QHF508V9
R@2;Rh/0QHF508V9R@80S8b<01d0L71`09NGU`22PX80Q8B408F5Q@29RHT0Rh^;08N7Q`2=SHd0RHV9
09BDU028R8P0SHf=08Z:RP2PX:00O7al08V9R@22PX80R8R808V9R@2ZZZX0WYjN09FEU@29RHT0PX:2
08J6QP29RHT0Rh^;08F5Q@0208V9R@0908Z:RP2;Rh/0PX:208Z:RP29RHT0QXJ608Z:RP27QhL0Rh^;
00<0RHV900@0QXJ608Z:RP2;Rh/0QHF50`27QhL03@25QHD0QXJ608b<S02:RXX0RHV908^;R`25QHD0
RHV908b<S027QhL0QHF508^;R`22PX802@29RHTN0?ooo`l0Lg=c00<0L71`06i^KP1]KFd02P1cLg<0
1P1eMGD0KFe]07=cL`1`L700KFe]07=cL`80N7Qh01d0UYJF0<g=c@2HV9P0IFEU05]KF`1ADE40Hf=S
06YZJP1bLW80QHF509nOW`2UYJD0Z:RX0:BTY02UYJD0Q8B407inOP1ADE40FUYJ08B4Q030`<00Vi^K
07inOP1cLg<0JVYZ06a/K01cLg<0L71`06e]K@0207=cL`09075aL@1`L700JVYZ075aL@1cLg<0L71`
075aL@1eMGD0MWIf00<0Lg=c00@0L71`075aL@1`L700KFe]0`1ZJVX03@1WIfL0K6a/07QhN01aLG40
Lg=c071`L01]KFd0Lg=c06i^KP1ZJVX0KFe]071`L01ZJVX02@1cLg<R0?ooo`00803oool?08N7Q`03
08B4Q027QhL0PX:200h0QhN700X0Rh^;08N7Q`2=SHd0TI6A08^;R`27QhL0EEEE051@D01EEED0IFEU
0P1fMWH208N7Q`0:09jNWP2RXZ80V9RH08N7Q`2=SHd0RXZ:06a/K01EEED0GemO06a/K080QhN700@0
SHf=08N7Q`1nOWh0QhN70P22PX8408N7Q`0508^;R`27QhL0QhN708N7Q`24Q8@00P27QhL01`2;Rh/0
QhN708:2PP27QhL0Q8B408N7Q`22PX801027QhL01P24Q8@0QhN708f=S@22PX80QhN708:2PPH0QhN7
00<0Q8B408N7Q`27QhL01027QhL00`22PX80QhN708N7Q`0N0?ooo`l0RHV900<0QhN708n?S`26QXH0
3@29RHT05026QXH0RXZ:08V9R@2?Shl0RXZ:08J6QP29RHT0MWIf09:BTP2<S8`0V9RH09BDU029RHT0
UiNG08B4Q020P800OGem08B4Q025QHD0RHV90P2:RXX02`2FUYH0XJ6Q09^KV`2?Shl0RHV908n?S`29
RHT0PH6108n?S`2:RXX0QXJ600@0RHV900h0R8R808V9R@2;Rh/0RHV908N7Q`2;Rh/0QXJ608Z:RP2<
S8`0Q8B408V9R@27QhL0Shn?08J6QP@0RHV900H0QhN708^;R`2;Rh/0RHV908b<S026QXH208V9R@05
08^;R`29RHT0RHV908V9R@2;Rh/01P29RHT00`26QXH0RHV908V9R@0N0?ooo`l0Lg=c00<0MGEe07]k
N`1fMWH03@1cLg<02@1`L700LG5a07=cL`1eMGD0Jf][06a/K01cLg<0SXj>0;bl_0020:f][@0709JF
UP26QXH0R8R806a/K01>CTh0ATI605YJFP0206e]K@0:079bLP2BTY80_;bl0<30`02ZZZX0O7al07=c
L`1eMGD0Lg=c079bLP80Ng]k00<0MWIf07=cL`1cLg<00P1cLg<02@1^KVh0Lg=c07IfMP1cLg<0MGEe
07IfMP1`L700LG5a07QhN00207=cL`0307EeM@1kNg/0MWIf00@0Lg=c00H0MGEe07IfMP1`L700NGUi
07QhN01fMWH207=cL`0507IfMP1cLg<0Lg=c07=cL`1jNWX01P1cLg<00`1fMWH0Lg=c07=cL`0R0?oo
o`00803oool@08N7Q`0308f=S@27QhL0QhN700T0QhN700P0PX:208N7Q`27QhL0Q8B408N7Q`2;Rh/0
SHf=08B4Q0<0QhN70P24Q8@01@1hN7P0OGem07MgM`23Ph<0K6a/0080IFEU00H0Kfm_071`L01SHf<0
KFe]07emO@24Q8@208N7Q`0508:2PP27QhL0SHf=08f=S@22PX800P2=SHd01P27QhL0Rh^;08N7Q`22
PX80Q8B407inOP@0QhN700@0PX:208B4Q022PX80SHf=0P27QhL00`2;Rh/0SHf=08N7Q`0708N7Q`04
08^;R`2=SHd0QhN708:2PP<0QhN700<0PX:208N7Q`2=SHd02@27QhLN0?oooa00RHV900<0Rh^;08:2
PP29RHT02029RHT02P2<S8`0Q8B408V9R@29RHT0QhN708V9R@2:RXX0Rh^;08V9R@2;Rh/208V9R@09
08N7Q`2=SHd0QHF508^;R`29RHT0TI6A08>3P`2<S8`0TY:B0080UYJF00P0SHf=09:BTP2FUYH0SXj>
08^;R`2<S8`0QXJ608V9R@80Rh^;00/0Ph>308^;R`27QhL0PX:208Z:RP2<S8`0QXJ608^;R`27QhL0
Rh^;08V9R@0208b<S00908J6QP2;Rh/0RHV908R8R025QHD0QXJ608Z:RP2;Rh/0QHF500L0RHV900@0
QXJ608^;R`29RHT0QXJ60P29RHT0102<S8`0QXJ608V9R@2;Rh/608V9R@0308F5Q@29RHT0RHV901h0
oooo401cLg<00`1`L700JVYZ07=cL`0807=cL`0:07QhN01cLg<0Lg=c07=cL`1eMGD0Lg=c075aL@1`
L700N7Qh07IfMP80Lg=c01<0MGEe07emO@1nOWh0PH6108F5Q@24Q8@0R8R809^KV`2TY:@0WinO09jN
WP2OWil0WIfM092@T01nOWh0MWIf07QhN01fMWH0Lg=c00@0L71`0P1ZJVX01`1aLG40N7Qh07IfMP1j
NWX0Ng]k07IfMP1cLg<00P1hN7P02@1fMWH0NWYj07UiN@1/K6`0KFe]071`L01aLG40L71`06e]K@07
07=cL`0406a/K01`L700Lg=c07IfMP80Lg=c00@0N7Qh07IfMP1cLg<0L71`1P1cLg<00`1]KFd0Lg=c
07=cL`0R0?ooo`00803ooolA08N7Q`0308B4Q027QhL0QhN700L0QhN700<0SHf=08B4Q027QhL01@27
QhL01P22PX80QhN708N7Q`27QhL0Rh^;096AT@80QhN700<0PX:208^;R`24Q8@00`24Q8@0102=SHd0
PX:208N7Q`2;Rh/208N7Q`0608f=S@27QhL0QhN708:2PP2=SHd0PX:20`27QhL01022PX80SHf=08:2
PP2=SHd308N7Q`80SHf=00D0QhN708f=S@22PX80QhN708^;R`0808N7Q`0308:2PP27QhL0QhN70080
QhN700H0SHf=08:2PP27QhL0QhN7096AT@27QhL208:2PPH0QhN700<0PX:208N7Q`2;Rh/07P3ooolA
08V9R@0308N7Q`29RHT0RHV900L0RHV900L0Rh^;08>3P`29RHT0RHV908J6QP29RHT0Rh^;0080QXJ6
0P29RHT02026QXH0RXZ:08b<S025QHD0S8b<08B4Q02:RXX0QhN70`29RHT0102ATI40Ph>308J6QP2:
RXX208V9R@0>08^;R`25QHD0S8b<08J6QP2?Shl0Ph>308V9R@26QXH0S8b<08V9R@2?Shl0QXJ608^;
R`25QHD208V9R@80Rh^;00L0QHF508n?S`20P800QXJ608b<S029RHT0Rh^;00D0RHV900h0S8b<08J6
QP29RHT0RHV908^;R`29RHT0Shn?08>3P`29RHT0QXJ608b<S029RHT0RXZ:08J6QPH0RHV90P26QXH0
0`2:RXX0oooo0?ooo`0L0?oooa40Lg=c00<0MGEe07=cL`1cLg<01`1cLg<02@1`L700Kfm_07=cL`1c
Lg<0L71`07=cL`1fMWH0L71`07IfMP0207=cL`08071`L01aLG40KVi^06e]K@1hN7P0Lg=c075aL@1e
MGD407QhN080L71`0140LG5a07=cL`1cLg<0L71`06e]K@1hN7P0MWIf07EeM@1`L700Lg=c071`L01h
N7P0NGUi07EeM@1fMWH0L71`06e]K@0207=cL`80L71`00L0KFe]07EeM@1]KFd0L71`07AdM01cLg<0
MWIf00D0Lg=c00h0N7Qh07IfMP1cLg<0Lg=c07IfMP1cLg<0MGEe071`L01cLg<0L71`06i^KP1cLg<0
Ng]k07IfMPH0Lg=c00<0MWIf071`L01aLG408P3oool00200oooo3`27QhL00`22PX80QhN708N7Q`02
08N7Q`0308^;R`27QhL0QhN700L0QhN700<0Rh^;08:2PP27QhL00P2=SHd208N7Q`0408B4Q027QhL0
Rh^;08^;R`80QhN700D0SHf=08:2PP2=SHd0QhN708:2PP0308N7Q`0608^;R`27QhL0QhN708N7Q`24
Q8@0SHf=0P27QhL208f=S@0808:2PP27QhL0QhN708N7Q`22PX80Q8B408f=S@2;Rh/208:2PP0308N7
Q`2;Rh/0PX:200H0QhN700/0SHf=07inOP27QhL0QhN708:2PP2=SHd0QhN708:2PP2=SHd0PX:207in
OP0208N7Q`0508:2PP27QhL0QhN708N7Q`2=SHd01P27QhL01022PX80QhN708f=S@27QhLN0?ooo`h0
RHV900L0S8b<08J6QP29RHT0QXJ608F5Q@26QXH0RXZ:00P0RHV900H0QXJ608j>SP26QXH0RHV908^;
R`25QHD208V9R@0408N7Q`29RHT0SXj>08J6QP80RHV900@0Shn?08>3P`2;Rh/0RHV90P26QXH00`29
RHT0Rh^;08Z:RP0308V9R@0408N7Q`2;Rh/0QHF508V9R@80Rh^;00L0Ph>308J6QP29RHT0Shn?08J6
QP27QhL0R8R80080RXZ:00@0QXJ608V9R@2:RXX0QXJ60`29RHT05P2<S8`0RHV908V9R@2?Shl0PH61
08^;R`2<S8`0QXJ608^;R`29RHT0QXJ608^;R`2:RXX0QHF508^;R`2<S8`0QXJ608V9R@26QXH0RHV9
08f=S@25QHD408V9R@0508b<S026QXH0RHV908^;R`25QHD07P3oool>07=cL`0707QhN01fMWH0Lg=c
071`L01]KFd0L71`075aL@0807=cL`06071`L01fMWH0MWIf07=cL`1`L700IfMW0P1cLg<0101eMGD0
Lg=c07IfMP1/K6`207=cL`0907EeM@1`L700L71`07=cL`1fMWH0L71`07=cL`1fMWH0LG5a00<0Lg=c
00@0MGEe071`L01]KFd0Lg=c101`L7002`1cLg<0Ng]k07IfMP1eMGD0K6a/075aL@1kNg/0MWIf07=c
L`1aLG40MWIf00<0Lg=c01<0N7Qh07=cL`1cLg<0MGEe079bLP1fMWH0N7Qh07IfMP1`L700Lg=c07If
MP1`L700Ng]k07QhN01fMWH0N7Qh07IfMP1cLg<0L71`0080Lg=c00<0KFe]07=cL`1cLg<00P1cLg<0
1@1hN7P0MWIf07=cL`1`L700KFe]0280oooo000P0?ooo`h0QhN700H0SHf=08N7Q`27QhL0Q8B408N7
Q`1nOWh908N7Q`0308B4Q02=SHd0QhN70080QhN700H0Q8B408N7Q`27QhL0QhN708B4Q02ATI4208N7
Q`0808:2PP2ATI40QhN708N7Q`2=SHd0QhN708B4Q022PX8608N7Q`0908^;R`27QhL0PX:208N7Q`2=
SHd0QhN708B4Q027QhL0SHf=0080QhN700H0Q8B408f=S@2=SHd0Rh^;08N7Q`2=SHd308N7Q`0808^;
R`27QhL0PX:208N7Q`2=SHd0PX:208N7Q`2ATI4208N7Q`0408f=S@27QhL0QhN708f=S@80QhN700@0
SHf=08N7Q`2;Rh/0Q8B41`27QhL00`2ATI40PX:208N7Q`0208N7Qah0oooo3P29RHT01`2;Rh/0QHF5
08V9R@27QhL0S8b<08F5Q@2;Rh/02029RHT00`27QhL0SHf=08F5Q@0208V9R@0:08N7Q`29RHT0RHV9
08V9R@25QHD0SXj>08^;R`2<S8`0Q8B408b<S080RHV900H0Rh^;08F5Q@2;Rh/0RHV908b<S02;Rh/4
08V9R@0708Z:RP2<S8`0QXJ608V9R@2;Rh/0QHF508N7Q`0208^;R`0<08F5Q@29RHT0QhN708f=S@25
QHD0QXJ608V9R@2=SHd0QHF508V9R@26QXH0SXj>0P26QXH04P29RHT0Shn?08>3P`29RHT0S8b<08F5
Q@29RHT0Rh^;08F5Q@29RHT0QhN708F5Q@29RHT0Rh^;08F5Q@2:RXX0QhN708^;R`D0RHV900<0QXJ6
092@T023Ph<00`29RHTN0?ooo`h0Lg=c00@0L71`06e]K@1cLg<0MGEe0P1hN7P00`1fMWH0Lg=c07=c
L`0607=cL`0307EeM@1cLg<0KFe]0080Lg=c00@0MGEe07=cL`1cLg<0Lg=c0P1aLG40101fMWH0N7Qh
07=cL`1^KVh207=cL`06071`L01]KFd0NWYj07UiN@1hN7P0MWIf101cLg<03`1aLG40N7Qh07IfMP1c
Lg<0L71`06e]K@1eMGD0MWIf071`L01]KFd0Lg=c07EeM@1cLg<0IfMW06a/K00207=cL`0H06e]K@1c
Lg<0L71`07IfMP1`L700MWIf07=cL`1eMGD0L71`07=cL`1^KVh0KFe]07=cL`1`L700KFe]07=cL`1Z
JVX0KFe]07=cL`1`L700KFe]075aL@1eMGD0MWIf1@1cLg<00`1`L700Lg=c071`L00307=cLb80oooo
000P0?oooa80QhN700<0SHf=08N7Q`27QhL02027QhL00`2;Rh/0QhN708N7Q`0608N7Q`0808B4Q02;
Rh/0QhN708f=S@24Q8@0QhN7096AT@22PX8308N7Q`0308^;R`2=SHd0QhN70080QhN700L0PX:208N7
Q`2;Rh/0SHf=08N7Q`22PX80Rh^;0080QhN700<0PX:208N7Q`27QhL00P22PX801@27QhL0Q8B408N7
Q`27QhL0PX:20080QhN700H0Q8B408f=S@24Q8@0QhN708:2PP2=SHd508N7Q`0608:2PP27QhL0PX:2
08N7Q`22PX80Rh^;1027QhL00`22PX80QhN708N7Q`0308N7Q`0308B4Q02=SHd0QhN70080QhN700<0
Rh^;0?ooo`3oool0703ooolA08V9R@0308b<S02;Rh/0QHF500T0RHV900<0RXZ:08V9R@29RHT01P29
RHT02P25QHD0RXZ:08V9R@2;Rh/0Ph>308V9R@2@T900QXJ608V9R@2<S8`208J6QP0408^;R`29RHT0
RHV908b<S080QXJ600D0S8b<08^;R`29RHT0Q8B408Z:RP0208b<S00308J6QP29RHT0S8b<0080QXJ6
00D0RHV908N7Q`2;Rh/0RHV908J6QP0208V9R@0A08N7Q`2=SHd0PH6108V9R@26QXH0Rh^;08F5Q@2<
S8`0Rh^;08V9R@2<S8`0QXJ608b<S026QXH0S8b<08B4Q02:RXX00P29RHT01@2;Rh/0S8b<08J6QP29
RHT0S8b<00<0RHV900H0QhN708f=S@25QHD0RHV908J6QP28R8PN0?oooa40Lg=c00<0N7Qh071`L01]
KFd02@1cLg<00`1aLG40Lg=c07=cL`0607=cL`80LG5a00<0Lg=c071`L01_Kfl00P1cLg<01P1fMWH0
Lg=c07QhN01`L700K6a/071`L080Lg=c00D0N7Qh07IfMP1`L700M7Ad071`L00207=cL`06075aL@1h
N7P0N7Qh07IfMP1cLg<0N7Qh0P1fMWH01@1cLg<0MGEe07IfMP1cLg<0MWIf0080Lg=c0140MGEe07=c
L`1/K6`0Lg=c07IfMP1`L700KFe]07QhN01fMWH0Lg=c07QhN01fMWH0N7Qh07IfMP1hN7P0Lg=c075a
L@0207=cL`0507IfMP1hN7P0MWIf07=cL`1hN7P00`1cLg<01P1eMGD0Lg=c06e]K@1cLg<0L71`06i^
KR80oooo000P0?oooa40QhN700<0SHf=08N7Q`22PX802P27QhL01022PX80QhN708N7Q`2;Rh/408N7
Q`80Q8B400D0PX:208N7Q`27QhL0Q8B408f=S@0208N7Q`03096AT@1nOWh0QhN700<0QhN700<0SHf=
08N7Q`24Q8@00P27QhL00`2ATI40Q8B408:2PP0208f=S@80QhN700<0TI6A08:2PP22PX800`27QhL0
0`2;Rh/0QhN708N7Q`0308N7Q`0>08B4Q027QhL0Rh^;08^;R`27QhL0SHf=08^;R`27QhL0SHf=08N7
Q`2=SHd0PX:208f=S@24Q8@308N7Q`0508:2PP2=SHd0QhN708N7Q`2=SHd01P27QhL00`2;Rh/0Q8B4
07inOP0N0?oooa40RHV900<0Rh^;08b<S026QXH02@29RHT01P2?Shl0QXJ608V9R@26QXH0RXZ:08J6
QP<0RHV900<0QhN708V9R@26QXH00P29RHT01`27QhL0SHf=08F5Q@26QXH0T92@0861P@2;Rh/00`29
RHT03`2;Rh/0QHF508N7Q`2;Rh/0QXJ608b<S027QhL0RHV908n?S`2;Rh/0QHF508J6QP2@T900P820
08>3P`0208V9R@0308J6QP2:RXX0QHF500@0RHV900l0QhN708J6QP24Q8@0RXZ:08V9R@2;Rh/0RXZ:
08V9R@2;Rh/0QHF508n?S`23Ph<0Rh^;08>3P`2;Rh/00P29RHT01@26QXH0Rh^;08F5Q@29RHT0Rh^;
00H0RHV900<0RXZ:08^;R`27QhL07P3ooolA07=cL`03071`L01hN7P0MWIf00T0Lg=c00H0Ng]k07If
MP1cLg<0L71`075aL@1`L70307=cL`0307EeM@1hN7P0MWIf0080Lg=c00L0MGEe07=cL`1]KFd0L71`
07=cL`1bLW80MWIf00<0Lg=c00l0L71`06e]K@1eMGD0MWIf071`L01^KVh0MGEe07UiN@1eMGD0L71`
06e]K@1`L700Lg=c06e]K@1`L7000P1cLg<00`1`L700LG5a06e]K@0407=cL`0;07EeM@1`L700J6QX
075aL@1cLg<0L71`075aL@1cLg<0L71`06e]K@1eMGD00P1`L7002@1_Kfl0MWIf07=cL`1cLg<0MWIf
071`L01]KFd0Lg=c071`L00607=cL`03075aL@1jNWX0Ng]k0280oooo000P0?oooa80QhN700<0SHf=
08N7Q`2;Rh/01`27QhL01@2;Rh/0SHf=08N7Q`2;Rh/0Q8B400D0QhN70P22PX8208N7Q`0308^;R`27
QhL0QhN70080QhN700D0SHf=08N7Q`22PX80QhN708:2PP0408N7Q`0708:2PP24Q8@0PX:208f=S@2;
Rh/0QhN708^;R`0208N7Q`0?08f=S@24Q8@0QhN708N7Q`2;Rh/0Q8B408N7Q`2;Rh/0PX:208N7Q`2;
Rh/0QhN708^;R`24Q8@0OWin00L0QhN700<0SHf=08N7Q`27QhL01P27QhL00`2;Rh/0QhN708N7Q`07
08N7Q`0308f=S@27QhL0oooo01d0oooo4P29RHT00`2;Rh/0PX:208Z:RP0608V9R@0808J6QP2>SXh0
Rh^;08:2PP2:RXX0QhN708V9R@26QXH208V9R@0608b<S02:RXX0QXJ608F5Q@26QXH0RXZ:0P29RHT0
1026QXH0RHV908f=S@29RHT308J6QP@0RHV90140QXJ608^;R`29RHT0R8R808Z:RP29RHT0RXZ:08J6
QP29RHT0SHf=08N7Q`25QHD0QXJ608Z:RP27QhL0Shn?08j>SP0208J6QP0308Z:RP26QXH0SXj>0080
QhN700@0Rh^;08V9R@26QXH0Rh^;0`29RHT00`2;Rh/0QHF508V9R@0408V9R@0308F5Q@26QXH0RXZ:
00P0RHV90P2;Rh/00`25QHD0oooo0?ooo`0L0?oooa80Lg=c00<0L71`06YZJP1aLG401P1cLg<0201`
L700MWIf071`L01ZJVX0LG5a07EeM@1cLg<0L71`0P1cLg<01P1hN7P0Ng]k07IfMP1]KFd0L71`075a
L@80Lg=c00L0L71`07=cL`1cLg<0Lg=c07IfMP1`L700MWIf00@0Lg=c00P0MWIf07YjNP1iNGT0K6a/
075aL@1cLg<0LG5a071`L080Lg=c00H0MGEe06e]K@1`L700LG5a07EeM@1kNg/207IfMP0:071`L01a
LG40L71`07IfMP1eMGD0Ng]k07IfMP1cLg<0L71`07IfMP<0Lg=c00<0L71`06e]K@1cLg<0101cLg<0
0`1]KFd0L71`075aL@0807=cL`0307IfMP1`L700KFe]0280oooo000P0?oooa00QhN700L0PX:208N7
Q`27QhL0QhN708^;R`27QhL0Rh^;00@0QhN700`0PX:208N7Q`27QhL0SHf=08N7Q`2=SHd0Rh^;08B4
Q02=SHd0Rh^;08B4Q02=SHd408N7Q`0408^;R`27QhL0SHf=08f=S@80QhN700H0PX:208N7Q`27QhL0
QhN708:2PP2;Rh/708N7Q`<0SHf=0`27QhL00`24Q8@0QhN708f=S@0208N7Q`@0SHf=0P27QhL01@22
PX80QhN708N7Q`2ATI40PX:200<0QhN700<0OWin08N7Q`27QhL00`27QhL01@2=SHd0Rh^;08N7Q`2;
Rh/0SHf=00<0QhN700D0SHf=08N7Q`2=SHd0QhN708f=S@0208N7Qah0oooo3`29RHT0202<S8`0QXJ6
08b<S029RHT0QXJ608Z:RP26QXH0RXZ:0`29RHT0202<S8`0QXJ608V9R@29RHT0Rh^;08F5Q@28R8P0
QXJ60P25QHD01026QXH0QhN708f=S@25QHD208V9R@0@08J6QP2:RXX0RHV908^;R`27QhL0QHF508b<
S026QXH0RHV908F5Q@2<S8`0Q8B408Z:RP2<S8`0RHV908F5Q@@0RHV90`27QhL01025QHD0S8b<08V9
R@27QhL208^;R`0308:2PP29RHT0Rh^;00<0QhN700L0RHV908b<S026QXH0RHV908J6QP2<S8`0Ph>3
0080RHV900<0S8b<08F5Q@2;Rh/01029RHT01P2;Rh/0RXZ:08J6QP2:RXX0Rh^;08F5Q@80RHV900L0
Rh^;08F5Q@2;Rh/0QHF508^;R`25QHD0RHV901h0oooo3`1cLg<0201hN7P0MWIf07QhN01cLg<0L71`
075aL@1`L700LG5a0`1cLg<01P1hN7P0MWIf07=cL`1cLg<0L71`06e]K@80K6a/00H0LG5a06MWI`1/
K6`0MGEe07=cL`1]KFd207=cL`0@071`L01aLG40Lg=c071`L01ZJVX0KFe]07QhN01fMWH0Lg=c06e]
K@1hN7P0Lg=c075aL@1hN7P0Lg=c06e]K@@0Lg=c0`1ZJVX02@1]KFd0N7Qh07=cL`1eMGD0MWIf071`
L01ZJVX0Lg=c071`L00306YZJP0707=cL`1hN7P0MWIf07=cL`1`L700KVi^071`L00207=cL`80N7Qh
00<0MWIf07=cL`1cLg<00P1cLg<01P1`L700LG5a071`L01aLG40L71`06e]K@80Lg=c00L0L71`06e]
K@1`L700KFe]071`L01]KFd0Lg=c0280oooo000P0?ooo`l0QhN700L0SHf=08:2PP2=SHd0PX:208B4
Q027QhL0Q8B400@0QhN700<0SHf=08N7Q`27QhL00P27QhL00`2;Rh/0Q8B408N7Q`0208B4Q00408N7
Q`22PX80QhN708:2PP80QhN700<0Q8B408N7Q`27QhL01027QhL01@22PX80QhN708N7Q`2ATI40Q8B4
00d0QhN700D0PX:208N7Q`27QhL0QhN708B4Q00508N7Q`0508f=S@27QhL0PX:208N7Q`24Q8@01027
QhL00`2=SHd0QhN708N7Q`0408N7Q`0408:2PP2;Rh/0Q8B408^;R`@0QhN700<0PX:208^;R`27QhL0
1027QhLN0?ooo`l0RHV900P0Shn?08>3P`2;Rh/0QXJ608N7Q`2;Rh/0QhN708^;R`<0RHV900P0Rh^;
08F5Q@29RHT0RHV908J6QP2:RXX0QhN708^;R`80QhN700@0Shn?08J6QP2<S8`0QXJ60P29RHT00`27
QhL0Rh^;08V9R@0208V9R@80S8b<00P0Ph>308V9R@26QXH0S8b<08>3P`2?Shl0S8b<08F5Q@P0RHV9
0P2<S8`01@26QXH0RHV908V9R@29RHT0QhN700D0RHV900L0Shn?08b<S023Ph<0RHV908N7Q`2;Rh/0
QHF50080RHV900<0Rh^;08F5Q@29RHT00`29RHT02`2<S8`0QXJ608b<S025QHD0S8b<08V9R@2<S8`0
RHV908b<S024Q8@0RXZ:00D0RHV97P3oool?07=cL`0807EeM@1`L700L71`07IfMP1eMGD0MWIf07Ee
M@1fMWH307=cL`08071`L01]KFd0Lg=c07=cL`1`L700LG5a07EeM@1fMWH207EeM@0407]kN`1fMWH0
N7Qh07IfMP80Lg=c00<0MGEe07IfMP1cLg<00P1cLg<207QhN008071`L01cLg<0L71`06i^KP1_Kfl0
Ng]k07QhN01]KFd807=cL`80N7Qh00D0MWIf07=cL`1cLg<0Lg=c07EeM@0507=cL`0707EeM@1hN7P0
L71`07=cL`1eMGD0MWIf06e]K@0207=cL`03071`L01]KFd0Lg=c00<0Lg=c00/0N7Qh07IfMP1dM7@0
LG5a07AdM01cLg<0N7Qh07=cL`1hN7P0Lg=c075aL@0507=cLb80oooo003o0?oool<0oooo003o0?oo
ol<0oooo003o0?oool<0oooo003o0?oool<0oooo003o0?oool<0oooo001O0?ooo`900000R03oool2
@00008P0oooo0T00001=0?ooo`00H@3oool00d000000oooo0?ooo`270?ooo`03@000003oool0oooo
08L0oooo00=000000?ooo`3oool0BP3oool00440oooo1D0000020?ooo`03@000003oool0oooo0080
oooo00=000000?ooo`3oool01@3oool3@0000080oooo0T0000030?ooo`=000001@3oool00d000000
oooo0?ooo`1R0?ooo`=000000`3oool3@0000080oooo00=000000?ooo`3oool01@3oool3@0000080
oooo0T0000030?ooo`=000001@3oool00d000000oooo0?ooo`1R0?ooo`900000103oool00d000000
oooo0?ooo`020?ooo`03@000003oool0oooo00D0oooo0d0000020?ooo`9000000`3oool3@00000D0
oooo00=000000?ooo`3oool0A03oool004<0oooo00M000000?ooo`3oool0oooo@000003ooom00000
0080oooo00=000000?oood0000001@3oool01T000000oooo0?oood000000oooo@00000@0oooo00A0
00000?ooo`3ooom00000JP3oool00d000000oooo0?ooo`040?ooo`06@000003oool0oooo@000003o
oom000001@3oool01T000000oooo0?oood000000oooo@00000@0oooo00A000000?ooo`3ooom00000
K03oool01T000000oooo0?oood000000oooo@0000080oooo00=000000?oood0000001@3oool01T00
0000oooo0?oood000000oooo@00000@0oooo00A000000?ooo`3ooom00000C03oool004<0oooo00M0
00000?ooo`3oool0oooo@000003ooom000000080oooo00=000000?oood0000001@3oool01D000000
oooo0?oood000000oooo00=000000P3oool014000000oooo0?oood00001[0?ooo`04@000003oool0
oooo0?ooo`A0000000@0oooo@000003ooom000001@3oool01D000000oooo0?oood000000oooo00=0
00000P3oool014000000oooo0?oood00001[0?ooo`07@000003oool0oooo0?oood000000oooo@000
00020?ooo`03@000003ooom0000000D0oooo00E000000?ooo`3ooom000000?ooo`03@0000080oooo
00A000000?ooo`3ooom00000C03oool004<0oooo00=000000?ooo`3oool00P3oool01d000000oooo
0?ooo`3ooom000000?oood0000001P3oool3@00000040?oood0000100000@00000<0oooo0d00001[
0?ooo`07@000003oool0oooo0?oood000000oooo@00000020?ooo`03@000003ooom0000000H0oooo
0d000000103ooom00000@000040000030?ooo`=00000K03oool01T000000oooo0?oood000000oooo
@0000080oooo00=000000?oood0000001P3oool3@00000040?oood0000100000@00000<0oooo0d00
001<0?ooo`00@`3oool01d000000oooo0?ooo`3ooom000000?oood0000000P3oool00d000000oooo
@00000080?ooo`03@000003oool0oooo0780oooo00=000000?oood0000000`3oool2@0000080oooo
00=000000?oood000000203oool00d000000oooo0?ooo`1b0?ooo`03@000003ooom000000080oooo
00=000000?oood0000000P3oool00d000000oooo@00000080?ooo`03@000003oool0oooo05@0oooo
00120?ooo`900000103oool00d000000oooo0?ooo`020?ooo`03@000003oool0oooo00H0oooo0T00
001e0?ooo`03@000003oool0oooo00<0oooo00E000000?ooo`3oool0oooo@00000080?ooo`900000
M@3oool00d000000oooo0?ooo`020?ooo`03@000003oool0oooo0080oooo00=000000?ooo`3oool0
1P3oool2@00005H0oooo003o0?oool<0oooo003o0?oool<0oooo003o0?oool<0oooo003o0?oool<0
oooo003o0?oool<0oooo003o0?oool<0oooo003o0?oool<0oooo003o0?oool<0oooo003o0?oool<0
oooo003o0?oool<0oooo003o0?oool<0oooo003o0?oool<0oooo003o0?oool<0oooo003o0?oool<0
oooo003o0?oool<0oooo003o0?oool<0oooo003o0?oool<0oooo003o0?oool<0oooo000P0?ooo`0:
07QhN01gMgL0N7Qh07emO@1gMgL0NGUi07QhN01aLG40MWIf08b<S080N7Qh00<0MgMg07alO01hN7P0
0`1hN7P02P1lO7`0][Jf04m?C`1aLG40OWin07QhN01bLW80N7Qh07inOP1aLG4207MgM`0607inOP1h
N7P0LW9b07QhN01dM7@0Ng]k101hN7P01@20P800Kfm_07QhN01hN7P0LW9b00D0N7Qh00H0NWYj07em
O@1hN7P0MGEe07AdM01mOGd607QhN00607MgM`1hN7P0NGUi07IfMP1hN7P0MgMg0P1hN7P02P1XJ6P0
KVi^0:VYZ@1LG5`0N7Qh079bLP1hN7P0OGem07QhN01cLg<407QhN006079bLP1hN7P0NWYj07EeM@1a
LG40M7Ad0P1hN7P0401mOGd0LW9b07emO@1hN7P0Ogmo07QhN01eMGD0N7Qh07YjNP1QHF40N7Qh09FE
U@1SHf<0LG5a07AdM01mOGdN0?ooo`<0MWIf00L0O7al07IfMP1hN7P0MWIf071`L01eMGD0Rh^;00<0
MWIf00<0Ng]k07IfMP1fMWH00P1fMWH02P1kNg/0]kNg04a<C01`L700OGem07IfMP1aLG40MWIf07em
O@1`L70207IfMP0807emO@1fMWH0LG5a07IfMP1bLW80NWYj07IfMP1gMgL207IfMP0507moO`1^KVh0
MWIf07IfMP1`L7001@1fMWH01P1iNGT0O7al07IfMP1dM7@0Lg=c07alO0<0MWIf00<0MgMg07IfMP1f
MWH00P1fMWH00`1hN7P0MGEe07IfMP0207IfMP0;07MgM`1WIfL0KFe]0:VYZ@1JFUX0MWIf075aL@1f
MWH0O7al07IfMP1bLW80101fMWH01P1`L700MgMg07UiN@1dM7@0L71`079bLP80MWIf0100O7al075a
L@1lO7`0MgMg07inOP1fMWH0Lg=c07MgM`1iNGT0GemO07MgM`2EUID0HV9R071`L01cLg<0O7al7P3o
ool308b<S00708j>SP2<S8`0SHf=08b<S02:RXX0S8b<09BDU00308b<S00308j>SP2<S8`0S8b<0080
S8b<00X0SXj>0:FUY@1lO7`0RXZ:08n?S`2<S8`0RXZ:08b<S02?Shl0RXZ:0P2<S8`01P2?Shl0S8b<
08Z:RP2<S8`0Rh^;08j>SP@0S8b<00D0T92@08V9R@2<S8`0S8b<08Z:RP0508b<S00308f=S@2?Shl0
S8b<0080Rh^;00<0Shn?08b<S02<S8`01P2<S8`00`2=SHd0S8b<08b<S00308b<S00:08J6QP29RHT0
WinO0861P@2<S8`0RXZ:08b<S02>SXh0S8b<08Z:RP@0S8b<00H0RXZ:08b<S02=SHd0Rh^;08Z:RP2;
Rh/208b<S00708j>SP2:RXX0SXj>08b<S02?Shl0S8b<08^;R`0208f=S@0708B4Q02<S8`0V9RH08B4
Q02:RXX0Rh^;08j>SP0R0?ooo`00803oool01@1hN7P0MgMg07AdM01fMWH0N7Qh0080OWin00@0LW9b
07alO02<S8`0RXZ:1P1hN7P02P1gMgL0J6QX0;Jf]P1SHf<0Lg=c07emO@1hN7P0MgMg079bLP1hN7P2
079bLP0607QhN01mOGd0OWin07QhN01cLg<0M7Ad101hN7P01@1`L700P82007MgM`1aLG40MgMg0080
LW9b00T0MGEe07AdM01bLW80LW9b07YjNP1hN7P0OGem07EeM@1bLW800P1hN7P00`1jNWX0N7Qh07Qh
N00407QhN00307UiN@1hN7P0MWIf00<0N7Qh00D0JFUY05mOG`2b/[80JVYZ05UIF@0207QhN00307em
O@1hN7P0Lg=c0080Lg=c0P1iNGT01@1dM7@0N7Qh07MgM`1hN7P0KVi^00<0LW9b0P1hN7P03P1mOGd0
N7Qh0820P01oOgl0O7al07QhN01oOgl0OGem07inOP22PX80KFe]075aL@1dM7@0N7Qh7P3oool02`1f
MWH0MGEe07UiN@1iNGT0Lg=c07IfMP1hN7P0M7Ad07MgM`1oOgl0OGem0080MWIf00<0NGUi07IfMP1f
MWH00P1gMgL04P1cLg<0ZZZZ05=CD`1aLG40O7al07MgM`1fMWH0N7Qh07YjNP1cLg<0M7Ad07IfMP1i
NGT0MGEe07IfMP1dM7@0LW9b07UiN@80MgMg00<0O7al07IfMP1jNWX00P1eMGD02P1fMWH0MGEe07If
MP1hN7P0NGUi07QhN01dM7@0Ng]k07IfMP1iNGT207IfMP0507YjNP1eMGD0MgMg07IfMP1gMgL0101f
MWH04P1gMgL0MWIf07YjNP1fMWH0MgMg07IfMP1aLG40KFe]0:>SX`1cLg<0IfMW07=cL`1fMWH0O7al
07IfMP1eMGD0N7Qh07AdM080MWIf00H0LW9b07UiN@1fMWH0MgMg079bLP1eMGD207QhN080MWIf00h0
O7al07IfMP1jNWX0M7Ad07IfMP1dM7@0JFUY06IVIP26QXH0QhN706][J`1`L700MWIf07YjNQh0oooo
00h0S8b<08^;R`2DU9@0TI6A08N7Q`24Q8@0R8R808j>SP28R8P0Ph>308:2PP2;Rh/0S8b<092@T080
S8b<0P2=SHd04P2IVIT0TY:B071`L029RHT0Shn?08b<S02=SHd0U9BD096AT@2>SXh0Shn?08b<S029
RHT0Q8B408^;R`2>SXh0RXZ:08n?S`80SHf=0100U9BD09FEU@29RHT0RXZ:092@T02=SHd0T92@09:B
TP2ATI40Ti>C09FEU@2?Shl0T92@08b<S029RHT0SXj>0P2BTY800`2:RXX0Rh^;08b<S00508b<S00B
08^;R`2<S8`0Ti>C08b<S02=SHd0S8b<09BDU02IVIT0SHf=09JFUP2GUiL0QhN708b<S02>SXh0S8b<
08n?S`2CTi<0SXj>0`2:RXX01@2@T900S8b<08b<S02ATI40T92@0080U9BD0P2<S8`03P2?Shl0S8b<
08R8R021PH40QhN708R8R01aLG40Kfm_09^KV`2IVIT0R8R808Z:RP2@T900TI6A8P3oool00200oooo
00@0MWIf07EeM@1hN7P0N7Qh0P1bLW8207QhN00507MgM`1nOWh0T92@08b<S01hN7P00P1gMgL03@1e
MGD0N7Qh07QhN01XJ6P0WIfM08b<S012@T80MgMg07YjNP1hN7P0Lg=c07QhN01lO7`00P1hN7P01P1g
MgL0N7Qh07alO01aLG40Jf][07]kN`80N7Qh00h0Ng]k07QhN01aLG40Lg=c06i^KP1]KFd0Lg=c07Ad
M01eMGD0Ng]k07QhN01bLW80N7Qh075aL@80N7Qh00D0O7al07emO@1iNGT0NWYj07emO@0607QhN003
07UiN@1mOGd0N7Qh00<0N7Qh0140JFUY092@T02e]KD0QhN704e=C@1bLW80N7Qh07emO@1lO7`0N7Qh
079bLP1gMgL0LG5a07AdM01lO7`0MgMg07alO00207MgM`0307QhN01lO7`0N7Qh0080O7al00<0NGUi
07QhN01iNGT00P1lO7`0201]KFd0K6a/096AT@26QXH0MgMg06YZJP1fMWH0O7al7P3oool0201gMgL0
MWIf07MgM`1fMWH0MGEe07QhN01jNWX0MgMg0P1fMWH207inOP80MgMg01h0N7Qh07IfMP1gMgL0NGUi
06UYJ@25QHD0Shn?06ATI01hN7P0MgMg07alO01eMGD0Lg=c07EeM@1cLg<0MgMg07IfMP1gMgL0O7al
07IfMP1_Kfl0N7Qh07MgM`1iNGT0Ng]k07EeM@1jNWX0Ng]k07EeM@1fMWH207EeM@0707IfMP1iNGT0
MWIf07AdM01jNWX0M7Ad07YjNP0207AdM0<0MGEe00<0NGUi07MgM`1fMWH0101fMWH0701hN7P0MgMg
07IfMP1gMgL0MWIf07MgM`1aLG40P82007MgM`21PH40JVYZ07QhN01jNWX0MWIf07QhN01fMWH0LG5a
07YjNP1dM7@0LW9b07QhN01dM7@0N7Qh07AdM01fMWH0M7Ad07EeM@1dM7@207]kN`0=07MgM`1fMWH0
MgMg07QhN01_Kfl0KFe]079bLP28R8P0O7al07EeM@1_Kfl0M7Ad07QhN00N0?ooo`0708j>SP2?Shl0
SHf=08^;R`2?Shl0U9BD096AT@0208b<S00308B4Q01mOGd0PH610080SHf=00l0Shn?08j>SP2=SHd0
Shn?08Z:RP1hN7P0VYZJ0:ZZZP2@T900Rh^;09BDU02>SXh0QhN708F5Q@28R8P00`2<S8`03@2?Shl0
Ti>C092@T02:RXX0S8b<092@T02?Shl0Rh^;09VIV@2GUiL0UIFE09JFUP2?Shl00P2>SXh03P2=SHd0
S8b<08n?S`2BTY80T92@09:BTP28R8P0QHF508B4Q029RHT0R8R808V9R@2<S8`0Rh^;1@2<S8`00`28
R8P0S8b<08b<S00208b<S00=09BDU01oOgl0C4a<08Z:RP2XZ:P0U9BD096AT@25QHD0RXZ:08b<S02:
RXX0TY:B092@T00208Z:RP0908V9R@2;Rh/0RHV908b<S028R8P0QHF508R8R02?Shl0SHf=00<0Rh^;
00X0RXZ:07emO@2:RXX0TY:B08Z:RP24Q8@0Rh^;092@T02:RXX0RHV98P3oool00200oooo0140MgMg
07QhN01bLW80NGUi07QhN01dM7@0Ng]k079bLP1lO7`0OGem07alO01iNGT0OWin08n?S`1mOGd0O7al
07emO@0207QhN00606YZJP23Ph<0Vi^K06UYJ@1iNGT0PH610`1hN7P02`1mOGd0LG5a07MgM`1hN7P0
OWin07emO@1hN7P0MgMg079bLP1hN7P0Lg=c00<0OWin00P0PH6107emO@1cLg<0LW9b07MgM`1_Kfl0
L71`06m_K`80N7Qh00D0M7Ad06i^KP1bLW80N7Qh06i^KP0207alO00507EeM@1hN7P0M7Ad07YjNP1g
MgL00P1kNg/0301hN7P0Ng]k07alO01lO7`0N7Qh07alO01cLg<0GemO06i^KP2e]KD0IVIV06YZJP80
Ng]k0`1hN7P05@1kNg/0N7Qh07]kN`1hN7P0OGem07QhN01dM7@0NGUi07QhN01lO7`0N7Qh07alO01m
OGd0LW9b08:2PP1kNg/0Ph>307QhN02EUID0Kfm_08V9R@0207QhN00308:2PP1hN7P0oooo01d0oooo
01T0MgMg07IfMP1eMGD0MgMg07EeM@1gMgL0Ng]k071`L01hN7P0MGEe07QhN01dM7@0N7Qh07moO`1f
MWH0MgMg07UiN@1dM7@0Lg=c06ATI01kNg/0U9BD06MWI`1eMGD0OGem0080MWIf00l0Lg=c07UiN@1d
M7@0MgMg07IfMP1iNGT0MGEe079bLP1jNWX0N7Qh07YjNP1bLW80NGUi079bLP1eMGD00P1iNGT00`1b
LW80M7Ad07]kN`0207UiN@0307=cL`1fMWH0MWIf0080MGEe00d0MgMg07YjNP1`L700N7Qh07]kN`1e
MGD0MgMg07EeM@1gMgL0M7Ad07IfMP1hN7P0MgMg0080MWIf00T0N7Qh07AdM01hN7P0MGEe06e]K@1c
Lg<0XZ:R065QH@1aLG400`1fMWH03`1iNGT0MWIf07IfMP1dM7@0MgMg07=cL`1hN7P0M7Ad079bLP1h
N7P0MWIf07QhN01fMWH0MGEe07YjNP0206i^KP0:06][J`1dM7@0KFe]08^;R`1UIFD0RHV907YjNP1`
L700MgMg07AdM1h0oooo00<0SHf=08^;R`2?Shl00P2;Rh/02`2ATI40Shn?08V9R@2:RXX0QHF508V9
R@27QhL0R8R80820P026QXH0R8R80080RHV900H0QhN70861P@26QXH0T92@08F5Q@29RHT308b<S00D
08N7Q`29RHT0T92@08f=S@2<S8`0RHV908B4Q026QXH0TI6A09BDU02ATI40RXZ:08V9R@20P800Ph>3
08F5Q@29RHT0Rh^;08n?S`2DU9@209VIV@0B096AT@2<S8`0Rh^;08f=S@2EUID0Ti>C09:BTP2>SXh0
RXZ:08n?S`2>SXh0SHf=08j>SP2;Rh/0RHV908N7Q`2:RXX0S8b<0P27QhL02@2:RXX0R8R808Z:RP2?
Shl0VIVI09:BTP29RHT0P82009BDU00208N7Q`0708b<S02?Shl0S8b<08N7Q`29RHT0RXZ:08N7Q`02
08V9R@0C08Z:RP2=SHd0S8b<08Z:RP2<S8`0QXJ608^;R`26QXH0MWIf07QhN01mOGd0OWin08^;R`1l
O7`0UIFE096AT@23Ph<0PX:208V9R@0R0?ooo`00803oool0101hN7P0MWIf07EeM@1dM7@207IfMP0=
07UiN@1hN7P0M7Ad07AdM01fMWH0N7Qh07emO@2;Rh/0SHf=07moO`1lO7`0NWYj07IfMP0206QXJ009
09^KV`2:RXX0MgMg08:2PP1mOGd0O7al079bLP1hN7P0MgMg0080N7Qh0P1bLW801@1gMgL0LW9b07Qh
N01hN7P0LG5a00<0N7Qh00T0O7al08:2PP1oOgl0KVi^07IfMP1kNg/0MWIf07QhN01aLG400`1hN7P0
101bLW80N7Qh07AdM01dM7@207MgM`0807UiN@1fMWH0OGem07QhN01iNGT0Ng]k07alO01dM7@207Qh
N00E07AdM01hN7P0Ng]k07=cL`1OGel0SXj>09jNWP1aLG40M7Ad07QhN01lO7`0Ng]k07QhN01gMgL0
NWYj07UiN@1hN7P0NGUi07QhN01bLW80Lg=c0080N7Qh00l0O7al079bLP1fMWH0J6QX06UYJ@1gMgL0
I6AT06UYJ@1cLg<0KFe]09:BTP1hN7P0M7Ad07UiN@1kNg/07P3oool01`1fMWH0MGEe07AdM01fMWH0
NGUi07IfMP1eMGD00P1gMgL02P1iNGT0MWIf07=cL`1kNg/0OGem07alO01iNGT0N7Qh07EeM@1cLg<2
075aL@0B08F5Q@1cLg<0M7Ad07emO@1eMGD0N7Qh07AdM01fMWH0LW9b07IfMP1jNWX0N7Qh07AdM01j
NWX0N7Qh07IfMP1hN7P0LG5a0P1fMWH01@1gMgL0N7Qh07MgM`1hN7P0MGEe0080NGUi00<0LG5a07Ee
M@1dM7@00`1fMWH02P1dM7@0NGUi075aL@1kNg/0NWYj07AdM01hN7P0MGEe07QhN01cLg<207MgM`0B
07IfMP1eMGD0NGUi07UiN@1eMGD0NGUi07QhN01eMGD0KFe]07moO`1nOWh0M7Ad07EeM@1fMWH0N7Qh
07MgM`1dM7@0MGEe0P1fMWH0101eMGD0N7Qh07EeM@1eMGD307IfMP0307]kN`1iNGT0OGem0080Jf][
00P0MGEe07IfMP1nOWh0P82006QXJ02>SXh0KFe]075aL@80NGUi7P3oool308b<S00T092@T02BTY80
SHf=08R8R02=SHd0TI6A09BDU02=SHd0R8R808f=S@21PH40OWin08R8R02:RXX0QhN708V9R@2FUYH0
U9BD07]kN`1dM7@0RHV908Z:RP25QHD0RXZ:08n?S`2<S8`0QhN708^;R`2ATI40UIFE08n?S`2BTY80
Ti>C08b<S02>SXh0Rh^;0`2<S8`02@29RHT0PX:208N7Q`2EUID0TI6A08b<S026QXH0RXZ:092@T003
08b<S080Shn?00`0RHV909RHV02ATI40RXZ:08f=S@2<S8`0R8R808N7Q`2;Rh/0RXZ:08N7Q`2>SXh2
08n?S`0:08f=S@2@T900RXZ:08n?S`2IVIT0PH6106i^KP2@T900SHf=08^;R`80RXZ:00T0RHV908Z:
RP29RHT0RHV908^;R`2=SHd0Rh^;092@T02?Shl00P2<S8`0102>SXh0UiNG09RHV02<S8`208^;R`09
0:2PX02VYZH0WinO08>3P`2BTY80OWin08R8R02?Shl0S8b<0280oooo000P0?ooo`0707QhN01fMWH0
Ng]k07emO@1fMWH0Ng]k075aL@0207]kN`<0N7Qh0140MWIf07]kN`27QhL0T92@08Z:RP1lO7`0OGem
07alO01^KVh0Kfm_092@T01lO7`0OGem07inOP21PH40OGem07MgM`02075aL@0407MgM`1hN7P0KFe]
06e]K@80LW9b00D0N7Qh06e]K@1hN7P0Ng]k07alO00207]kN`0908J6QP21PH40LW9b07emO@1aLG40
NGUi06i^KP1aLG40Kfm_0080MgMg0P1eMGD00`1hN7P0Lg=c07AdM00307AdM003079bLP1hN7P0MgMg
0080M7Ad0`1gMgL0201hN7P0MWIf07QhN01cLg<0GUiN08N7Q`2NWYh0LW9b0P1dM7@00`1gMgL0M7Ad
07AdM00207QhN00307IfMP1iNGT0MWIf00@0N7Qh00l0LW9b06][J`1[Jf/0JVYZ07QhN01[Jf/0Kfm_
07alO01gMgL0J6QX0861P@1XJ6P0N7Qh07IfMP1nOWh07P3oool01`1fMWH0LW9b07AdM01jNWX0LW9b
07UiN@1dM7@00P1jNWX0201dM7@0LW9b07YjNP1fMWH0N7Qh07YjNP1iNGT0NWYj0P1fMWH0101dM7@0
Kfm_075aL@26QXH207QhN00407IfMP1jNWX0MGEe07IfMP80N7Qh0P1jNWX207UiN@80MGEe0140NWYj
06i^KP1fMWH0MGEe07IfMP1eMGD0M7Ad07alO01jNWX0LG5a07YjNP1aLG40OGem07=cL`1jNWX0M7Ad
07MgM`0207IfMP0307UiN@1jNWX0MGEe0080N7Qh00<0MgMg07UiN@1dM7@00`1hN7P00`1fMWH0NGUi
07MgM`0207MgM`0707QhN01fMWH0MWIf06YZJP1lO7`0MgMg07AdM00207QhN00807UiN@1cLg<0M7Ad
07IfMP1hN7P0MWIf07QhN01bLW8207AdM00A07IfMP1mOGd0Ng]k07inOP1dM7@0H61P07AdM01_Kfl0
L71`07]kN`1cLg<0LW9b08^;R`1PH600MgMg07AdM01jNWX07P3oool04P2<S8`0R8R808B4Q02<S8`0
R8R808b<S02@T900SXj>08f=S@29RHT0QXJ6096AT@2=SHd0RXZ:0861P@1eMGD0OWin08N7Q`80QHF5
0P2=SHd02`28R8P0RHV908V9R@25QHD0QhN708F5Q@2=SHd0U9BD09JFUP2BTY80TI6A0080Vi^K00<0
T92@096AT@2BTY800P2<S8`308N7Q`80QHF500P0QhN708Z:RP2;Rh/0Rh^;09FEU@2BTY80V9RH096A
T@80SHf=00D0SXj>09>CT`2BTY80Shn?09>CT`0209:BTP0709BDU02?Shl0SXj>092@T02BTY80Shn?
092@T00308f=S@07092@T02<S8`0T92@09JFUP24Q8@0IFEU08n?S`0209:BTP05092@T02<S8`0S8b<
08b<S02>SXh00P2=SHd308R8R00808b<S02EUID0VIVI0:BTY02FUYH0O7al08R8R02?Shl208f=S@05
08R8R02FUYH0X:2P07emO@2=SHd00P2:RXXR0?ooo`00803oool02`1hN7P0LW9b07AdM01kNg/0M7Ad
07inOP1hN7P0Ng]k07UiN@1aLG40LW9b00@0N7Qh00@0O7al08R8R026QXH0OGem0P1lO7`0101]KFd0
O7al08n?S`1>CTh307UiN@<0N7Qh00<0MgMg079bLP1hN7P00P1hN7P01@1dM7@0N7Qh06e]K@1aLG40
M7Ad0080N7Qh00<0MGEe07inOP22PX800P1dM7@0101bLW80MgMg07AdM01fMWH306e]K@80LG5a00@0
MgMg075aL@1aLG40LW9b0P1aLG401@1cLg<0LW9b075aL@1eMGD0MgMg00H0LG5a00d0NGUi06QXJ01I
FET0LG5a07MgM`1fMWH0MgMg07QhN01dM7@0LW9b07IfMP1iNGT0MWIf0080N7Qh0`1cLg<0401gMgL0
Lg=c07QhN01ZJVX0Hf=S07AdM01OGel0KVi^07=cL`1]KFd0O7al07inOP1NGUh0NGUi075aL@1hN7PN
0?ooo`0=07IfMP1dM7@0MgMg07YjNP1aLG40Ng]k079bLP1iNGT0Ng]k07=cL`1hN7P0MWIf07EeM@02
07IfMP0>07YjNP1mOGd0N7Qh07IfMP1dM7@0MWIf071`L01hN7P0Ogmo06MWI`1jNWX0NGUi07YjNP1i
NGT207MgM`0:07alO01kNg/0MWIf07=cL`1fMWH0MGEe07UiN@1_Kfl0M7Ad07EeM@80MWIf00l0M7Ad
07emO@20P800MGEe07UiN@1gMgL0NWYj079bLP1iNGT0M7Ad07UiN@1fMWH0N7Qh07MgM`1jNWX00P1h
N7P0201iNGT0M7Ad07EeM@1fMWH0Ng]k07QhN01fMWH0Ng]k101hN7P01P1gMgL0MGEe07]kN`1dM7@0
Jf][07MgM`<0MWIf01/0MgMg07EeM@1cLg<0MWIf07QhN01fMWH0M7Ad07=cL`1eMGD0N7Qh07alO020
P800QXJ607UiN@1UIFD0IVIV08:2PP20P800Lg=c07alO01`L700Ng]k07moO`1LG5`0NGUi07AdM01j
NWX07P3oool03@2<S8`0Shn?096AT@2>SXh0R8R808b<S026QXH0S8b<09:BTP2?Shl0U9BD08b<S02;
Rh/00P2<S8`0302=SHd0Q8B407inOP25QHD0Q8B408N7Q`2?Shl0RXZ:07moO`2RXZ80Shn?08j>SP80
T92@0P2<S8`02P2EUID0VIVI08b<S027QhL0S8b<08j>SP2@T900SHf=092@T02>SXh208b<S00408^;
R`2>SXh0SXj>08j>SP80Ti>C00d0TI6A08Z:RP2BTY80U9BD09^KV`2GUiL0UIFE09>CT`2BTY80UIFE
09BDU02EUID0TI6A0080T92@00@0VIVI09FEU@2?Shl0Ti>C102EUID0302DU9@0T92@096AT@2HV9P0
WIfM09>CT`2=SHd0SXj>08f=S@2<S8`0SHf=08j>SP<0SHf=01D0R8R808N7Q`2>SXh0TY:B09RHV02K
Vi/0YjNW092@T023Ph<0RXZ:0:6QX@2d];@0TI6A09VIV@2>SXh0SHf=09:BTP22PX80SXj>092@T02A
TI408P3oool00200oooo01d0N7Qh07MgM`1fMWH0Ng]k07QhN01kNg/0LW9b07QhN01kNg/0OGem07Ui
N@1bLW80MGEe07AdM01hN7P0Ng]k07QhN025QHD0QXJ608:2PP24Q8@0QhN707alO028R8P0Rh^;06i^
KP1fMWH0OWin07alO00207QhN00507inOP21PH40MGEe07alO01mOGd00P22PX800`1iNGT0KFe]07Ad
M00207QhN00907EeM@1kNg/0Q8B40861P@1iNGT0OGem0861P@1eMGD0OGem0080O7al0P1cLg<02`1X
J6P0KFe]06UYJ@1/K6`0KFe]06MWI`1SHf<0J6QX06e]K@1YJFT0J6QX00@0KFe]0P1gMgL0301aLG40
MgMg07=cL`1TI6@0GEeM07emO@1lO7`0IFEU05=CD`1WIfL0KFe]079bLP80M7Ad0P1bLW80301lO7`0
N7Qh07QhN01KFe/0MgMg07alO01XJ6P0GemO07QhN027QhL0LG5a07QhN080O7al00D0N7Qh06i^KP1i
NGT0NGUi07IfMP0N0?ooo`0;07IfMP1cLg<0M7Ad07IfMP1dM7@0Ng]k07EeM@1iNGT0M7Ad07IfMP1g
MgL00`1eMGD01P1fMWH0Ng]k07AdM01lO7`0MGEe07AdM080LW9b00P0L71`07alO01/K6`0MgMg07If
MP1jNWX0N7Qh07IfMP80NGUi00D0N7Qh06m_K`1eMGD0LW9b07AdM00207MgM`03079bLP1cLg<0MWIf
0080MWIf01P0N7Qh07]kN`1kNg/0M7Ad079bLP1iNGT0LW9b07IfMP1eMGD0N7Qh07EeM@1lO7`0N7Qh
0820P01gMgL0NGUi07YjNP1gMgL0MWIf07]kN`1lO7`0N7Qh07YjNP1mOGd207UiN@0B07=cL`1iNGT0
MgMg07EeM@1mOGd0N7Qh071`L01mOGd0MGEe08>3P`27QhL0Lg=c07AdM01cLg<0MgMg07UiN@1eMGD0
M7Ad0P1hN7P03`1jNWX0T92@07emO@1mOGd0MgMg06m_K`1]KFd0OGem07moO`1dM7@0Kfm_075aL@22
PX80L71`069RHP0307MgMah0oooo00`0S8b<08R8R02:RXX0QhN708V9R@2?Shl0T92@08n?S`26QXH0
QhN708^;R`2@T90208j>SP0K08b<S02?Shl0RHV908F5Q@1kNg/0OGem07UiN@1eMGD0OWin08:2PP1Y
JFT0V9RH08j>SP2;Rh/0RXZ:08b<S02@T900RHV908B4Q025QHD0QXJ607moO`1mOGd0PH6108b<S02A
TI40Rh^;0080S8b<00P0SXj>08Z:RP26QXH0R8R808N7Q`1oOgl0QHF508V9R@80QHF500l0RXZ:08n?
S`2IVIT0WinO0:FUY@2NWYh0W9bL09fMW@2OWil0XJ6Q0:BTY02PX:00WYjN0::RXP2PX:000P2KVi/0
7P2BTY80T92@08f=S@2@T900UYJF09>CT`2GUiL0/[:b08F5Q@2JVYX0^;Rh0:n_[`2KVi/0TY:B09>C
T`2DU9@0SXj>08n?S`2DU9@0RXZ:09:BTP2`/;00];Bd09NGU`27QhL0TY:B09VIV@2EUID0R8R8096A
T@80P82000<0V9RH08>3P`1jNWX00P2<S8`00`2?Shl0oooo0?ooo`0P0?ooo`00803oool04@1aLG40
MGEe07alO01bLW80M7Ad075aL@1fMWH0N7Qh07alO01fMWH0NGUi07alO01hN7P0Ng]k07AdM01mOGd0
M7Ad0080Ng]k00d0N7Qh07AdM01hN7P0MWIf07alO01iNGT0V9RH08b<S01DE5@0KFe]06i^KP1gMgL0
N7Qh0080OWin00h0PX:207AdM01fMWH0N7Qh07emO@1dM7@0N7Qh079bLP1dM7@0LW9b07QhN01kNg/0
P82007alO0H0N7Qh00`0O7al07QhN01dM7@0OWin0861P@1nOWh0PH6107alO01iNGT0OGem0861P@1l
O7`207UiN@<0N7Qh00D0PH6107QhN01cLg<0OGem07=cL`0207emO@0707IfMP1^KVh0M7Ad07emO@37
alL0T92@06][J`0205EEE@0<069RHP1QHF40PX:207QhN01bLW80KFe]06=SH`1hN7P0K6a/096AT@1f
MWH0KFe]0P1cLg<0101mOGd0PX:207MgM`1[Jf/2075aL@0307IfMP3oool0oooo01`0oooo00`0N7Qh
07UiN@1lO7`0M7Ad07UiN@1gMgL0N7Qh07IfMP1hN7P0MGEe07AdM01eMGD207IfMP09075aL@1kNg/0
LW9b07YjNP1kNg/0MWIf07AdM01jNWX0M7Ad0080NGUi00D0UiNG08b<S01RHV80Q8B406e]K@0207Mg
M`0A07UiN@1dM7@0NWYj079bLP1eMGD0MWIf07alO01cLg<0MWIf07AdM01iNGT0M7Ad07QhN01fMWH0
NWYj07QhN01fMWH00`1cLg<207IfMP0307QhN01fMWH0LW9b0080MWIf00<0LW9b07YjNP1fMWH00`1d
M7@00`1eMGD0MgMg07QhN00207=cL`0L07IfMP1jNWX0NGUi07EeM@1lO7`0LG5a07UiN@1dM7@0MgMg
07=cL`1gMgL0NGUi092@T025QHD0Ogmo07emO@1gMgL0R8R808f=S@1nOWh0Lg=c06MWI`1[Jf/0JFUY
07moO`1KFe/0P82007IfMP80L71`00H0HF5Q08>3P`1gMgL0K6a/06][J`1eMGD207IfMQh0oooo00@0
UYJF09>CT`2?Shl0SXj>0P2DU9@03@2@T900S8b<08Z:RP2<S8`0QhN708F5Q@2;Rh/0RHV908R8R02=
SHd0RHV908j>SP2?Shl00P2<S8`01@2ATI40RXZ:08^;R`2>SXh0UiNG0080UIFE00P0Zj^[08V9R@2=
SHd0SHf=08V9R@22PX80QhN708^;R`80S8b<00/0Shn?08^;R`2<S8`0Shn?09BDU02?Shl0SXj>08N7
Q`28R8P0RXZ:08b<S00308R8R080S8b<00L0RXZ:08b<S02:RXX0QHF50861P@20P800QXJ60080QhN7
00D0Q8B407inOP25QHD0Rh^;08f=S@0208N7Q`0508b<S027QhL0T92@08n?S`2=SHd00P29RHT07`23
Ph<0SXj>09:BTP2BTY80RXZ:05]KF`27QhL0YZJV0;^k^`2b/[80_Kfm0<G5a@2;Rh/0QhN707alO028
R8P0SXj>09RHV01bLW80Ogmo08j>SP2?Shl0RHV907=cL`2HV9P0PX:207inOP2;Rh/0TI6A09:BTP2=
SHd08P3oool00200oooo00`0OWin07emO@1hN7P0Ng]k07UiN@1mOGd0Ng]k07EeM@1iNGT0Ng]k07Ad
M01hN7P207IfMP0507AdM01hN7P0N7Qh07IfMP1mOGd00P1kNg/02P1hN7P0LW9b07IfMP1hN7P0UIFE
09>CT`26QXH0JFUY06][J`1LG5`207QhN00:07=cL`1nOWh0MgMg07IfMP1bLW80OGem07QhN01gMgL0
N7Qh07MgM`<0M7Ad0`1lO7`207=cL`@0N7Qh00<0O7al07QhN01`L7000P1cLg<02@1mOGd0OWin07If
MP1cLg<0LW9b07AdM01hN7P0OGem071`L00407QhN00;07=cL`1lO7`0LW9b07QhN01aLG40OGem07Mg
M`1hN7P0KVi^071`L02>SXh00P2PX:000`25QHD0GUiN06YZJP0207QhN080LG5a00l0GEeM07MgM`1H
F5P0Rh^;06=SH`1YJFT0GEeM06UYJ@26QXH0I6AT08n?S`1cLg<0N7Qh07UiN@1bLW807P3oool0301e
MGD0N7Qh07MgM`1hN7P0MGEe07AdM01iNGT0MWIf07MgM`1fMWH0Lg=c07YjNP80MWIf01d0MGEe07If
MP1hN7P0MWIf07QhN01dM7@0NGUi07QhN01eMGD0NWYj07QhN02CTi<0OGem0820P01cLg<0OWin06a/
K01fMWH0NGUi07EeM@1oOgl0M7Ad07QhN01dM7@0NWYj07AdM01fMWH0MgMg07IfMP0307EeM@0307]k
N`1hN7P0N7Qh0080MGEe101fMWH03P1hN7P0MWIf07IfMP1hN7P0MGEe07UiN@1eMGD0MWIf07EeM@1j
NWX0N7Qh07=cL`1kNg/0L71`0`1fMWH0901iNGT0LW9b07alO01aLG40Ng]k07AdM01iNGT0Lg=c07]k
N`1gMgL0NWYj08:2PP1gMgL0M7Ad092@T027QhL0Lg=c07YjNP1]KFd0KVi^07QhN01aLG40M7Ad05IF
EP2LW9`0MGEe06e]K@1OGel0L71`08V9R@1LG5`0Ng]k06IVIP1cLg<0MWIf071`L1h0oooo00`0Ph>3
08R8R02<S8`0RXZ:08R8R023Ph<0S8b<08n?S`2;Rh/0R8R808^;R`2ATI4208f=S@0J08j>SP2<S8`0
SXj>08f=S@29RHT0QXJ608b<S02>SXh0T92@09>CT`2?Shl0UIFE07UiN@2:RXX0UiNG0:BTY02KVi/0
S8b<08n?S`2>SXh0TY:B08V9R@2ATI40Shn?08^;R`29RHT208f=S@0308b<S02>SXh0SXj>0080SXj>
0P2:RXX208n?S`@0S8b<00h0RXZ:08b<S02EUID0Ti>C08n?S`29RHT0Q8B408f=S@2@T900UiNG09:B
TP28R8P0S8b<08^;R`<0S8b<02@0T92@08Z:RP2?Shl0Rh^;09:BTP2@T900RHV908N7Q`2BTY80UYJF
09VIV@25QHD0HV9R05iNGP2QXJ40_kno09JFUP2ATI40Ogmo08N7Q`2EUID0X:2P08Z:RP20P800[Jf]
0:6QX@2?Shl0QhN709:BTP2HV9P0O7al07YjNP1iNGT0R8R808Z:RP29RHTR0?ooo`00803oool03@1b
LW80N7Qh07QhN01hN7P0LW9b07QhN01iNGT0O7al07QhN01fMWH0N7Qh07emO@1dM7@00P1kNg/00`1h
N7P0OGem07=cL`0207QhN00?07UiN@1hN7P0NGUi07]kN`1iNGT0T92@07emO@2IVIT0N7Qh08J6QP1=
CDd0?clo079bLP1hN7P0OGem0080N7Qh0P1fMWH00`1dM7@0N7Qh07QhN00207MgM`80M7Ad0P1hN7P2
07alO0H0N7Qh00P0P82007QhN01hN7P0Lg=c07QhN01cLg<0O7al07MgM`80N7Qh00<0Lg=c07UiN@1b
LW800`1hN7P0201dM7@0N7Qh07emO@1cLg<0NGUi07=cL`1hN7P0LW9b0P1hN7P01P1gMgL0GEeM05QH
F01@D500OWin08F5Q@80LW9b00d0N7Qh07=cL`1gMgL0N7Qh07=cL`1KFe/0TY:B07=cL`1XJ6P0IfMW
07QhN01nOWh0I6AT0080N7Qh00<0LW9b07emO@1hN7P07P3oool05@1hN7P0MWIf07MgM`1jNWX0LG5a
07YjNP1gMgL0M7Ad07MgM`1fMWH0M7Ad07]kN`1eMGD0M7Ad07IfMP1dM7@0O7al07AdM01fMWH0NGUi
07]kN`0207IfMP0A07MgM`1hN7P0S8b<07UiN@2>SXh0MgMg092@T01iNGT0IfMW07EeM@1fMWH0Ng]k
07QhN01gMgL0MGEe07YjNP1eMGD00`1fMWH0201gMgL0Lg=c07EeM@1iNGT0MWIf07QhN01eMGD0Lg=c
0P1fMWH0201gMgL0MWIf07IfMP1lO7`0M7Ad07IfMP1bLW80NGUi0`1hN7P0:P1fMWH0M7Ad07EeM@1k
Ng/0Kfm_07IfMP1gMgL0MWIf079bLP1cLg<0O7al07AdM01jNWX0LG5a07YjNP1hN7P0NWYj07MgM`1m
OGd0P82008f=S@2ATI40Ti>C071`L01]KFd0Jf][07=cL`1eMGD0MWIf06a/K01cLg<0I6AT09JFUP1^
KVh0JVYZ05eMG@1gMgL0Ng]k05iNGP1fMWH0LW9b071`L080MGEe7P3oool0202DU9@0S8b<08f=S@2A
TI40RXZ:096AT@2;Rh/0Q8B40P2=SHd06P29RHT0SHf=08j>SP26QXH0QhN708V9R@2>SXh0SHf=08b<
S02?Shl0T92@08b<S02:RXX0RHV908f=S@2@T900RHV908Z:RP2<S8`0X:2P0;jn_P2c/k<0T92@08b<
S02=SHd0Shn?0P2<S8`0102CTi<0SHf=08b<S02<S8`208f=S@0708^;R`2>SXh0T92@08b<S02:RXX0
QXJ608R8R00608b<S00<08V9R@2<S8`0RXZ:092@T02CTi<0RXZ:092@T02;Rh/0RHV908n?S`2ATI40
R8R80`2<S8`0702:RXX0R8R808f=S@2>SXh0T92@08V9R@2ATI40U9BD096AT@2=SHd0UYJF0;Ng]`3>
c/h0gMgM0:j^[P1eMGD0QHF508:2PP27QhL0SXj>08b<S01mOGd0S8b<096AT@2MWId0QHF508^;R`1j
NWX208f=S@0607moO`2<S8`0QXJ608V9R@25QHD0Rh^;8P3oool00200oooo00d0OGem07QhN01hN7P0
NGUi07=cL`1lO7`0LW9b07QhN01mOGd0LW9b07QhN01fMWH0O7al00<0N7Qh00L0MgMg07QhN01hN7P0
MWIf07emO@1hN7P0MGEe0080N7Qh00T0S8b<08J6QP2MWId0XZ:R08N7Q`25QHD0BTY:02h^;P1hN7P0
0P1bLW80101_Kfl0MgMg07alO01gMgL407QhN00307AdM01hN7P0N7Qh00<0N7Qh0P1cLg<01@1bLW80
N7Qh07=cL`1hN7P0O7al0080N7Qh00D0Lg=c07QhN01hN7P0N7Qh07UiN@0307QhN00@07MgM`1cLg<0
LW9b07QhN01aLG40Lg=c07QhN01lO7`0N7Qh07IfMP1cLg<0NGUi07=cL`1gMgL0KVi^07MgM`80L71`
0P1hN7P02P23Ph<0Q8B406i^KP1]KFd0N7Qh07MgM`1cLg<0MgMg079bLP1lO7`206e]K@0906m_K`1h
N7P0Lg=c06e]K@1kNg/0MGEe07=cL`1dM7@0N7Qh01h0oooo0P1eMGD02`1iNGT0MgMg075aL@1lO7`0
LG5a07]kN`1lO7`0LG5a07YjNP1fMWH0NGUi0080MWIf01T0NWYj07UiN@1cLg<0NWYj07IfMP1iNGT0
MgMg07EeM@1dM7@0MgMg08F5Q@1bLW80Ogmo09>CT`2@T900Ph>3075aL@1GEeL0O7al079bLP1jNWX0
Lg=c07IfMP1gMgL0M7Ad00@0MWIf00<0MGEe07IfMP1fMWH00P1fMWH0201iNGT0N7Qh07QhN01dM7@0
NWYj07EeM@1fMWH0Ng]k0P1fMWH01P1eMGD0NGUi07QhN01kNg/0MWIf07AdM080MWIf02T0MGEe07Ad
M01dM7@0Ng]k07MgM`1_Kfl0MWIf07]kN`1hN7P0MWIf07EeM@1nOWh0MGEe07emO@1jNWX0Q8B408Z:
RP29RHT0MWIf06QXJ01dM7@0LW9b07=cL`1bLW80M7Ad06i^KP1ZJVX0Kfm_07AdM02:RXX0L71`07=c
L`1YJFT0O7al06m_K`1TI6@0MGEe07AdM01`L700MgMg07]kN`0N0?ooo`0=08F5Q@2;Rh/0Shn?08^;
R`2:RXX0Shn?08^;R`2BTY80SXj>08Z:RP2ATI40SHf=08^;R`0208b<S00I096AT@2@T900R8R8096A
T@2=SHd0Rh^;08f=S@2>SXh0RHV908b<S02;Rh/0MgMg075aL@28R8P0X:2P092@T02e]KD0[Zj^09BD
U02<S8`0V9RH096AT@2=SHd0R8R808V9R@0408b<S00308j>SP2<S8`0S8b<0080S8b<00P0T92@09>C
T`2CTi<0Shn?096AT@2?Shl0S8b<08j>SP80S8b<00H0Shn?092@T02>SXh0TY:B08Z:RP29RHT208b<
S00708^;R`2>SXh0Shn?09>CT`2DU9@0QhN708b<S00208j>SP0P08f=S@2?Shl0UIFE08n?S`2FUYH0
Vi^K0:2PX02_[jl0[Zj^08b<S01hN7P0OGem07QhN02ATI40TY:B08R8R021PH40Ogmo08>3P`2?Shl0
XZ:R08j>SP2BTY80PX:209BDU027QhL0OGem08N7Q`2<S8`0R8R8096AT@2BTY8R0?ooo`00803oool0
2`1bLW80MWIf07]kN`1iNGT0LG5a07emO@1hN7P0OWin07emO@1dM7@0MgMg00<0N7Qh00H0Lg=c07Qh
N01hN7P0LW9b07IfMP1hN7P207UiN@0C07emO@1dM7@0MWIf08>3P`1]KFd0RHV909fMW@1hN7P0Ph>3
08N7Q`0a<C409BDU06UYJ@1gMgL0Ng]k07AdM01hN7P0M7Ad079bLP0307QhN00307MgM`1hN7P0N7Qh
0080N7Qh0P1lO7`307QhN080Lg=c0`1lO7`207AdM080NGUi00d0N7Qh07AdM01hN7P0MWIf07EeM@1f
MWH0L71`07inOP1hN7P0Lg=c075aL@1lO7`0OWin00<0N7Qh0180M7Ad07MgM`1gMgL0MgMg07moO`1e
MGD0OGem07QhN01]KFd0MGEe08>3P`1^KVh0Lg=c07QhN01VIVH0HV9R07EeM@1nOWh208:2PP0908J6
QP1XJ6P0Kfm_07EeM@1hN7P0NGUi07IfMP1eMGD0OWin01h0oooo0P1hN7P09`1gMgL0NGUi075aL@1h
N7P0Lg=c07alO01kNg/0MGEe07IfMP1gMgL0MWIf07YjNP1hN7P0NGUi07IfMP1bLW80MWIf07EeM@1j
NWX0M7Ad07IfMP1dM7@0MWIf08F5Q@1[Jf/0RXZ:0::RXP21PH40QHF508V9R@1XJ6P0GemO079bLP1`
L700M7Ad07=cL`1iNGT0MGEe07AdM00307IfMP0307UiN@1fMWH0MWIf0080MWIf00D0N7Qh07EeM@1c
Lg<0MWIf07UiN@0207EeM@0907QhN01eMGD0Ng]k07QhN01eMGD0MgMg07IfMP1hN7P0MGEe0080N7Qh
02T0MWIf07QhN01`L700O7al079bLP1fMWH0M7Ad07QhN01iNGT0MGEe07QhN01jNWX0NGUi07emO@1n
OWh0OGem08b<S01]KFd0JVYZ07IfMP1cLg<0KVi^07]kN`1/K6`0KFe]07IfMP1^KVh0L71`07moO`1c
Lg<0KFe]07AdM026QXH0L71`06ATI01[Jf/0MWIf07UiN@1gMgL0Lg=c07UiN@0N0?ooo`0709BDU02@
T900RHV908j>SP2;Rh/0RHV908N7Q`0208f=S@0708j>SP2<S8`0SHf=08b<S02ATI40U9BD08n?S`02
08b<S00308f=S@2;Rh/0T92@0080QhN700T0S8b<08f=S@2EUID0R8R809JFUP2SXj<0VYZJ09BDU02F
UYH00P32`/801`2EUID0Q8B408F5Q@2;Rh/0T92@08j>SP2?Shl00`2<S8`00`2ATI40S8b<08b<S002
08b<S00508Z:RP26QXH0R8R808b<S02@T9000P2?Shl01`2:RXX0QXJ608j>SP2BTY80SXj>08^;R`2:
RXX00`2>SXh01P2ATI40SXj>092@T02<S8`0SHf=08J6QP80T92@00H0RXZ:08V9R@2;Rh/0SXj>09:B
TP2DU9@309NGU`0I0::RXP22PX80MWIf08b<S02BTY80Ph>308J6QP27QhL0Ph>308b<S02CTi<0VYZJ
09bLW020P800M7Ad07emO@2CTi<0U9BD07YjNP20P800S8b<08j>SP2?Shl0Rh^;08V9R@0R0?ooo`00
803oool207IfMP0607UiN@1hN7P0N7Qh07UiN@1gMgL0Ng]k0P1dM7@0701lO7`0M7Ad07alO01hN7P0
OGem07AdM01kNg/0NGUi07QhN01lO7`0M7Ad07MgM`1aLG40N7Qh07]kN`21PH40OWin08F5Q@2=SHd0
N7Qh08B4Q025QHD0RHV90820P00V9RH0LW9b07inOP1[Jf/207QhN00307=cL`1hN7P0Lg=c0080Lg=c
00@0O7al07=cL`1cLg<0O7al0P1hN7P02@1lO7`0NGUi07AdM01aLG40Lg=c07IfMP1lO7`0N7Qh07Ee
M@0207IfMP<0LW9b00H0NGUi07AdM01_Kfl0L71`06i^KP1dM7@207QhN00406][J`1hN7P0OWin07Yj
NP80N7Qh00h0LW9b06QXJ01[Jf/0KFe]06IVIP1XJ6P0N7Qh09>CT`1gMgL0OGem07QhN01bLW80PX:2
08R8R080Lg=c00d0N7Qh06e]K@1hN7P0GemO07QhN01fMWH0MgMg07QhN01aLG40LW9b07UiN@1bLW80
Ng]k01h0oooo0180MgMg07=cL`1gMgL0Lg=c07IfMP1jNWX0M7Ad07EeM@1gMgL0MGEe07YjNP1bLW80
NWYj07=cL`1kNg/0LW9b07YjNP1hN7P207MgM`0407EeM@1kNg/0Lg=c07YjNP<0NGUi00l0Ogmo08Z:
RP1fMWH0RXZ:08R8R023Ph<0NWYj05aLG01`L700Ogmo06a/K01iNGT0MWIf07EeM@1iNGT0101hN7P2
07EeM@0:07]kN`1fMWH0Lg=c07QhN01gMgL0MGEe07AdM01hN7P0MWIf07QhN080NGUi0P1gMgL0901d
M7@0N7Qh07IfMP1kNg/0MWIf07=cL`1iNGT0M7Ad07EeM@1mOGd0Ogmo07=cL`1jNWX0OWin07YjNP1i
NGT0NWYj07moO`23Ph<0U9BD08B4Q01HF5P0IfMW07]kN`24Q8@0H61P079bLP1lO7`0N7Qh07YjNP1m
OGd0LW9b075aL@1gMgL0JFUY07IfMP80KFe]00P0JFUY071`L01kNg/0Lg=c071`L01gMgL0LG5a07Qh
N1h0oooo0140Shn?08V9R@2<S8`0R8R808b<S02@T900RXZ:08J6QP2ATI40SXj>08f=S@2:RXX0SHf=
08R8R02=SHd0RHV908j>SP0208b<S00G08R8R02?Shl0TY:B08n?S`2ATI40S8b<08J6QP2:RXX0Rh^;
09:BTP2<S8`0Vi^K09NGU`2;Rh/0R8R80;jn_P2:RXX0TI6A08^;R`2@T900S8b<08n?S`2@T9000`2C
Ti<03`2:RXX0Shn?08n?S`2>SXh0S8b<08R8R02:RXX0Rh^;08n?S`2@T900Ti>C08f=S@2:RXX0T92@
09>CT`0308n?S`0J09FEU@2BTY80TI6A092@T02ATI40V9RH09>CT`2>SXh0UIFE09RHV02EUID0TY:B
092@T02?Shl0T92@09:BTP2NWYh0[jn_0<?3``2[Zj/0M7Ad08N7Q`2BTY80PX:206e]K@1oOgl209BD
U00?08N7Q`24Q8@0Rh^;08V9R@2=SHd0Q8B408^;R`2IVIT0Ogmo07]kN`23Ph<0TY:B08n?S`29RHT0
S8b<0080RXZ:8P3oool00200oooo01l0NGUi07=cL`1mOGd0N7Qh07emO@1fMWH0Ng]k07QhN01fMWH0
LW9b07]kN`1cLg<0N7Qh07AdM01fMWH0LW9b07]kN`1lO7`0M7Ad07QhN01mOGd0NGUi07IfMP1hN7P0
NGUi079bLP1nOWh0Kfm_09RHV01mOGd0RHV90080PH6100T0RHV908N7Q`051@D0MGEe06m_K`1bLW80
M7Ad079bLP1fMWH00`1hN7P00`1lO7`0N7Qh07QhN00207QhN00407=cL`1fMWH0O7al07YjNP80M7Ad
00@0Kfm_07QhN01lO7`0O7al0`1iNGT06P1dM7@0KFe]07AdM01iNGT0N7Qh07emO@1bLW80MGEe07al
O01hN7P0M7Ad079bLP1fMWH0O7al07QhN01dM7@0Jf][075aL@25QHD0N7Qh07YjNP1hN7P0Lg=c07Qh
N01aLG40N7Qh0P1XJ6P01@1[Jf/0N7Qh08B4Q01hN7P0Lg=c00<0N7Qh00L0Ph>307QhN01bLW80Ogmo
07inOP1fMWH0OGem0080N7Qh7P3oool01P1fMWH0MGEe07IfMP1cLg<0OGem07=cL`80M7Ad00D0MgMg
079bLP1kNg/0MGEe07]kN`0207UiN@0H079bLP1hN7P0MWIf07AdM01fMWH0NWYj07MgM`1eMGD0MWIf
07]kN`1gMgL0QhN7079bLP2TY:@0O7al08^;R`23Ph<0NWYj07emO@21PH40Cdm?07UiN@1aLG40MgMg
0P1eMGD03@1iNGT0MWIf07IfMP1fMWH0Ng]k07=cL`1fMWH0NGUi07IfMP1eMGD0MWIf07QhN01gMgL0
0P1fMWH04P1bLW80NGUi07UiN@1gMgL0MWIf07QhN01jNWX0NGUi07EeM@1fMWH0NWYj07=cL`1iNGT0
Kfm_07MgM`1nOWh0NWYj07EeM@80NWYj0200O7al07YjNP27QhL0QHF508>3P`24Q8@0Jf][069RHP1c
Lg<0N7Qh07IfMP1/K6`0Ng]k07inOP1eMGD0NGUi07IfMP1`L700MgMg06][J`1_Kfl0MWIf07AdM01^
KVh0Lg=c07AdM01eMGD0LG5a071`L01fMWH0Lg=c07IfMQh0oooo00X0RXZ:08n?S`26QXH0QhN708n?
S`28R8P0QXJ608V9R@2?Shl0S8b<0P2?Shl02@2BTY80Ti>C09:BTP2<S8`0RXZ:08N7Q`2=SHd0S8b<
08^;R`0308b<S00@096AT@2CTi<0W9bL092@T02ZZZX0Shn?09NGU`2DU9@0QhN708>3P`2;Rh/0c/k>
09>CT`2=SHd0TY:B08j>SP80TI6A0`2<S8`04P2>SXh0R8R808b<S02@T900S8b<08n?S`2=SHd0RXZ:
08^;R`2@T900TI6A08n?S`2@T900S8b<08R8R02:RXX0SHf=08n?S`80UIFE01h0T92@08n?S`27QhL0
RHV908R8R02?Shl0Ti>C09:BTP2=SHd0V9RH09>CT`2@T900TI6A0:RXZ02][Jd0YJFU09:BTP1kNg/0
KFe]08N7Q`2CTi<0S8b<08F5Q@2BTY80Z:RX09^KV`2MWId0S8b<07IfMP2=SHd208:2PP0;08^;R`28
R8P0M7Ad08N7Q`2?Shl0Ph>307inOP24Q8@0QXJ608N7Q`2<S8`08P3oool00200oooo00d0MWIf07Qh
N01dM7@0N7Qh07inOP1hN7P0Lg=c07AdM01mOGd0M7Ad07MgM`1eMGD0Ng]k0080OGem00H0N7Qh07Ad
M01bLW80N7Qh07AdM01mOGd207UiN@0C07QhN01mOGd0Ogmo08R8R01bLW80Zj^[07emO@2=SHd0QHF5
07QhN021PH40QhN701lO7`0;2`/0N7Qh079bLP1lO7`0N7Qh07IfMP0507QhN00307alO01hN7P0N7Qh
00<0N7Qh01@0O7al07UiN@1hN7P0M7Ad07IfMP1eMGD0MgMg07IfMP1hN7P0O7al07YjNP1hN7P0LW9b
07QhN01[Jf/0MGEe071`L01aLG40P820079bLP80MgMg00T0KVi^07QhN01gMgL0JFUY07QhN01OGel0
P82007emO@1gMgL00P1hN7P01P1gMgL0K6a/08B4Q028R8P0OWin08R8R080N7Qh00T0Ng]k07QhN01g
MgL0N7Qh07=cL`1^KVh0N7Qh07MgM`1eMGD00`1hN7P00`1dM7@0LW9b0?ooo`0M0?ooo`0>07MgM`1c
Lg<0MGEe07IfMP1iNGT0MGEe07MgM`1eMGD0N7Qh07EeM@1kNg/0M7Ad07EeM@1fMWH207EeM@0507Ui
N@1gMgL0MWIf07=cL`1kNg/00P1fMWH04`1gMgL0N7Qh07UiN@24Q8@0KVi^0:VYZ@1lO7`0RXZ:08:2
PP1fMWH0P82008Z:RP1EEED0BDU907MgM`1^KVh0N7Qh07MgM`1eMGD0101fMWH00`1cLg<0Ng]k07If
MP0207IfMP0607EeM@1fMWH0NWYj07IfMP1dM7@0Lg=c0P1hN7P0:01iNGT0N7Qh07QhN01lO7`0MgMg
07EeM@1dM7@0O7al07=cL`1iNGT0MGEe07AdM021PH40M7Ad07]kN`1mOGd0MGEe07inOP28R8P0PH61
08f=S@1]KFd0LW9b06][J`1dM7@0NWYj07AdM01fMWH0JVYZ07]kN`1bLW80Jf][07EeM@1[Jf/0Lg=c
06i^KP1/K6`0MGEe07IfMP1^KVh207IfMP04071`L01bLW80M7Ad07IfMP80NGUi00<0MGEe0?ooo`3o
ool0703oool05@2?Shl0R8R808j>SP2<S8`0RHV908^;R`2BTY80SXj>08R8R02>SXh0TY:B08f=S@27
QhL0QXJ608F5Q@2;Rh/0Ti>C09:BTP2<S8`0Rh^;08f=S@0208Z:RP0B08f=S@28R8P0R8R808j>SP27
QhL0WIfM08j>SP2ATI40SXj>08b<S02@T900V9RH0;^k^`30`<00SHf=08J6QP29RHT0SHf=1@2<S8`0
0`28R8P0SXj>08b<S00208b<S00608^;R`2<S8`0S8b<08Z:RP28R8P0S8b<0`2ATI40202@T900SXj>
08n?S`2;Rh/0RXZ:08n?S`2DU9@0UIFE0P2CTi<01@2?Shl0TY:B08n?S`2CTi<0UYJF0080UIFE00`0
YZJV0:^[Z`2][Jd0VIVI07inOP1fMWH0RXZ:09:BTP29RHT0SHf=08N7Q`26QXH207EeM@0;07QhN01m
OGd0R8R807emO@1nOWh0Rh^;08b<S024Q8@0UYJF08b<S024Q8@00P29RHT0102;Rh/0Shn?09>CT`2?
ShlR0?ooo`00803oool01`1nOWh0N7Qh075aL@1hN7P0M7Ad07alO01kNg/00P1hN7P0101fMWH0Ng]k
07]kN`1bLW8207AdM00N07]kN`1mOGd0MWIf07]kN`1bLW80MWIf07QhN01kNg/0NGUi07IfMP1kNg/0
Ph>307QhN02NWYh0OGem07inOP25QHD0PX:20861P@24Q8@0OWin01lO7`1hN7P0KVi^07MgM`1hN7P0
MgMg07IfMP1lO7`0N7Qh0P1cLg<307QhN00407AdM01hN7P0MGEe07YjNP80MWIf00<0M7Ad07IfMP1a
LG401@1hN7P09`1eMGD0LW9b07=cL`1cLg<0MGEe08:2PP1]KFd0LW9b06i^KP1_Kfl0NGUi06MWI`1^
KVh0MgMg065QH@2<S8`0L71`075aL@1SHf<0N7Qh07=cL`1_Kfl0N7Qh079bLP1hN7P0Ph>3079bLP1h
N7P0QXJ607IfMP1hN7P0MgMg07QhN01gMgL0N7Qh07AdM01nOWh0NGUi07alO00207QhN00307]kN`1h
N7P0N7Qh01h0oooo01H0MGEe079bLP1bLW80NGUi07EeM@1hN7P0MGEe07IfMP1kNg/0MWIf07AdM01g
MgL0MWIf07MgM`1eMGD0N7Qh07UiN@1eMGD0NGUi07IfMP1hN7P0M7Ad0P1hN7P03`1gMgL0O7al07mo
O`1iNGT0Xj>S08>3P`25QHD0OWin07YjNP25QHD0RHV907EeM@0?3`l0MWIf06m_K`0307IfMP0B07=c
L`1hN7P0Lg=c07EeM@1hN7P0NGUi07IfMP1iNGT0MGEe07QhN01fMWH0NWYj07EeM@1gMgL0MWIf07]k
N`1eMGD0N7Qh0P1fMWH00`1iNGT0N7Qh07UiN@0207UiN@05079bLP1^KVh0O7al07UiN@22PX800P1i
NGT08P24Q8@0MgMg08F5Q@24Q8@0KVi^08>3P`1QHF40NGUi06YZJP1mOGd0N7Qh07=cL`1bLW80KFe]
07AdM01kNg/0LG5a06e]K@1jNWX0Lg=c06m_K`1eMGD0MWIf06m_K`1]KFd0Jf][075aL@1`L700M7Ad
07IfMP1iNGT0Ng]k07AdM01cLg<N0?ooo`0@08>3P`26QXH0SHf=08n?S`2>SXh0RXZ:08J6QP2<S8`0
TY:B08f=S@26QXH0RHV909:BTP2ATI40SXj>08Z:RP80Rh^;00/0S8b<096AT@2@T900RHV908Z:RP2=
SHd0Shn?096AT@2=SHd0Shn?0:>SX`0209VIV@0608R8R027QhL0V9RH09VIV@24Q8@0F5QH0P2<S8`0
2`2=SHd0S8b<08f=S@29RHT0RXZ:08R8R02?Shl0Ti>C092@T02<S8`0T92@00<0SXj>00L0Shn?08f=
S@2?Shl0T92@09FEU@2ATI40SXj>0080S8b<02X0T92@08n?S`2CTi<0UYJF09FEU@2;Rh/0Q8B408V9
R@2KVi/0Xj>S09ZJVP2IVIT0WYjN09nOW`2/[:`0X:2P09RHV028R8P0MWIf09NGU`2ATI40UIFE09>C
T`2ATI40QHF508B4Q029RHT0QXJ608Z:RP1nOWh0PX:208V9R@21PH40Rh^;08b<S022PX80OWin0820
P01oOgl0PH6108B4Q02;Rh/208n?S`0308V9R@27QhL0oooo0240oooo000P0?ooo`80N7Qh00l0Lg=c
07IfMP1dM7@0LW9b07QhN01fMWH0NGUi07IfMP1hN7P0OGem07]kN`1fMWH0N7Qh07AdM01iNGT00`1h
N7P06@1kNg/0N7Qh07QhN01mOGd0Ng]k07alO020P800Ng]k08N7Q`28R8P0PX:207MgM`2;Rh/0RHV9
096AT@1hN7P0:RXZ02l_;`1cLg<0MgMg07emO@1hN7P0LG5a07alO01cLg<0101hN7P03`1jNWX0N7Qh
07AdM01dM7@0O7al07MgM`1hN7P0Ng]k07QhN01kNg/0LG5a07QhN01kNg/0N7Qh07YjNP0207QhN00Z
06][J`1hN7P0N7Qh07QhN01]KFd0LW9b071`L01fMWH0O7al06e]K@1hN7P0J6QX08f=S@20P800QHF5
08f=S@1oOgl0PX:207alO01iNGT0K6a/07QhN01TI6@0N7Qh079bLP1YJFT0Kfm_06e]K@1hN7P0MWIf
07QhN01fMWH0N7Qh079bLP1iNGT0N7Qh079bLP1eMGD0Ng]k07UiN@1dM7@0N7Qh7P3oool0301fMWH0
NGUi07AdM01hN7P0MWIf07EeM@1jNWX0MWIf07QhN01bLW80M7Ad07]kN`80M7Ad00L0MWIf07MgM`1i
NGT0Lg=c07YjNP1cLg<0M7Ad0080MWIf0P1iNGT0501jNWX0PH6108b<S02EUID0QHF50861P@1bLW80
Q8B40820P024Q8@0IVIV04m?C`1KFe/0Kfm_07AdM01iNGT0MgMg071`L01kNg/0MGEe0`1fMWH02`1h
N7P0MgMg07EeM@1gMgL0M7Ad07YjNP1fMWH0N7Qh07YjNP1dM7@0NGUi0080M7Ad0240N7Qh07IfMP1k
Ng/0NGUi07moO`1fMWH0KFe]07IfMP2;Rh/0OGem07EeM@1dM7@0Ng]k08N7Q`1jNWX0R8R807alO01`
L700Jf][06i^KP1aLG40HV9R07]kN`1eMGD0M7Ad06YZJP1mOGd0Lg=c07inOP1`L700MGEe0861P@1[
Jf/00P1fMWH0301`L700Jf][06i^KP1YJFT0M7Ad07MgM`1iNGT0MGEe07IfMP1iNGT0LW9b07UiNAh0
oooo00<0S8b<08n?S`2=SHd00P2@T900402?Shl0TI6A08f=S@2=SHd0QhN708V9R@2=SHd0QXJ608Z:
RP2<S8`0TI6A08n?S`28R8P0TI6A08N7Q`26QXH208b<S00@08^;R`2<S8`0S8b<09:BTP2WYjL0Z:RX
08n?S`2@T900QhN708b<S028R8P0QHF507IfMP2WYjL0/[:b08N7Q`80RHV900@0SHf=08Z:RP2>SXh0
Shn?0`2<S8`0102>SXh0Rh^;08Z:RP2ATI4208b<S00;08f=S@2>SXh0SXj>08V9R@2=SHd0T92@08V9
R@2:RXX0S8b<092@T02?Shl00P2HV9P02@1nOWh0S8b<0:VYZ@2QXJ40T92@096AT@2DU9@0WinO09fM
W@020:FUY@0706a/K01dM7@0LW9b06i^KP1XJ6P0R8R808F5Q@0208R8R00709JFUP2LW9`0UYJF08V9
R@2IVIT0Y:BT08N7Q`0208b<S00<08B4Q01oOgl0P8200820P027QhL0SHf=09FEU@2>SXh0QhN708j>
SP29RHT0Shn?8P3oool00200oooo101hN7P207]kN`80N7Qh00L0M7Ad07QhN01hN7P0N7Qh07emO@1c
Lg<0OGem0080Ng]k01h0NGUi07emO@1hN7P0N7Qh07MgM`1fMWH0O7al07inOP1gMgL0RHV907]kN`2@
T900O7al079bLP1`L700QhN707AdM024Q8@0PH6108B4Q00<30`0N7Qh07=cL`1hN7P0NGUi07IfMP1l
O7`0MWIf07alO01fMWH207AdM00:07IfMP1hN7P0NGUi07UiN@1dM7@0N7Qh07]kN`1dM7@0N7Qh06m_
K`80N7Qh00@0MgMg07alO01hN7P0OGem0`1^KVh02P1hN7P0KVi^06QXJ01/K6`0N7Qh07UiN@1aLG40
Jf][08>3P`1mOGd206a/K00<07IfMP1WIfL0KVi^07alO01jNWX0QXJ606QXJ01oOgl0JFUY05eMG@1b
LW80MgMg0P1YJFT02@1hN7P0Lg=c08:2PP1nOWh0MgMg07EeM@1hN7P0OWin07AdM00207QhN00307Ad
M01bLW80N7Qh01h0oooo00T0MWIf07YjNP1fMWH0MgMg07AdM01fMWH0M7Ad07IfMP1bLW800`1fMWH0
8P1kNg/0LW9b07QhN01gMgL0N7Qh07MgM`1kNg/0Lg=c07QhN01jNWX0Lg=c07IfMP1kNg/0MWIf09BD
U025QHD0T92@08B4Q01kNg/0OGem08j>SP1eMGD0N7Qh07inOP2BTY802PX:07=cL`1dM7@0NGUi07Mg
M`1eMGD0Ng]k07IfMP1kNg/207IfMP<0N7Qh0P1gMgL08`1fMWH0N7Qh07QhN01jNWX0OGem07=cL`1j
NWX0MWIf07QhN01mOGd0Ng]k0861P@1eMGD0K6a/08N7Q`2>SXh0MWIf07EeM@1lO7`0Ph>308N7Q`1f
MWH0IFEU08:2PP1iNGT0LG5a07YjNP1mOGd0IVIV06e]K@1mOGd0NGUi07IfMP1NGUh0Ph>30080KFe]
00l0OWin07=cL`1aLG40LG5a07IfMP1ZJVX0JFUY06a/K01fMWH0Kfm_07AdM01kNg/0LG5a07IfMP1j
NWX00P1eMGD00`1fMWH0oooo0?ooo`0L0?ooo`0908b<S02ATI40S8b<08b<S026QXH0QhN708V9R@2<
S8`0RXZ:00<0S8b<00@0SHf=08b<S029RHT0RHV90P2;Rh/01P2=SHd0QhN708j>SP2ATI40RHV908N7
Q`80SHf=00D0Y:BT09jNWP2FUYH0Vi^K09RHV00209fMW@0B08j>SP21PH40SHf=0:FUY@1VIVH0QhN7
08j>SP2@T900Rh^;08b<S02>SXh0SHf=08j>SP2=SHd0T92@09:BTP2ATI40SXj>0P2;Rh/0=`2@T900
SXj>08Z:RP2DU9@0UYJF096AT@2BTY80S8b<08j>SP2ATI40Ti>C09BDU02EUID0R8R80:f][@2^[Zh0
UYJF09ZJVP2PX:00WYjN0:>SX`2CTi<0P820096AT@29RHT0T92@09jNWP2HV9P0QXJ608V9R@2@T900
SXj>07alO01jNWX0UYJF08j>SP2JVYX0WIfM08N7Q`2DU9@0Ti>C08^;R`1oOgl0Kfm_07MgM`2<S8`0
QHF508V9R@2<S8`0R8R808b<S02ATI40SXj>08n?S`2<S8`08P3oool00200oooo00@0N7Qh07emO@1l
O7`0LW9b0P1hN7P0101dM7@0N7Qh07QhN01dM7@207QhN00307]kN`1dM7@0M7Ad0080N7Qh0P1kNg/0
0`1dM7@0OGem07QhN00207QhN00C07emO@1hN7P0T92@07QhN028R8P0PX:20861P@20P800O7al079b
LP1hN7P0Q8B408n?S`0E5AD0O7al07=cL`1gMgL0M7Ad07QhN00207YjNP80N7Qh00X0NGUi07QhN01b
LW80N7Qh071`L01bLW80M7Ad071`L01iNGT0NWYj0`1hN7P04P1cLg<0M7Ad07IfMP1hN7P0Lg=c07Qh
N01WIfL0O7al07MgM`1hN7P0Lg=c07MgM`1[Jf/0Ph>307EeM@1[Jf/0SXj>08B4Q080MgMg00d0RXZ:
079bLP1^KVh0Ng]k07inOP27QhL0MgMg07emO@1`L700N7Qh06a/K01bLW80QXJ600<0N7Qh00H0KFe]
07QhN01kNg/0LG5a07=cL`1eMGD207QhN00407UiN@1mOGd0N7Qh07QhN1h0oooo00X0MWIf07QhN01l
O7`0LG5a07IfMP1iNGT0MGEe07UiN@1fMWH0MGEe0P1fMWH02@1hN7P0M7Ad07MgM`1iNGT0MWIf07Ee
M@1jNWX0Lg=c07alO00207=cL`0L07IfMP1lO7`0OGem09RHV01nOWh0Rh^;07emO@1jNWX0Q8B408J6
QP1^KVh0L71`08R8R024Q8@01@D507]kN`1^KVh0NGUi07EeM@1fMWH0N7Qh07EeM@1iNGT0MWIf07Mg
M`1jNWX0M7Ad07IfMP<0NGUi00D0LW9b07inOP1kNg/0MgMg07EeM@0207UiN@0T07QhN01mOGd0PH61
07]kN`1dM7@0JVYZ08Z:RP1jNWX0MgMg07EeM@1nOWh0Ng]k0820P01/K6`0HV9R07inOP1dM7@0MgMg
06YZJP1eMGD0JVYZ079bLP1iNGT0JVYZ07=cL`1bLW80OWin07AdM01fMWH0KVi^06][J`1aLG40JFUY
06a/K01ZJVX0K6a/0P1hN7P02@1cLg<0NGUi07EeM@1dM7@0NGUi07MgM`1fMWH0Lg=c07IfMP0N0?oo
o`0:08b<S029RHT0Shn?08^;R`2<S8`0Shn?08j>SP2?Shl0S8b<08j>SP80S8b<00T0RXZ:08f=S@2A
TI40Shn?08b<S027QhL0SXj>08^;R`2>SXh00P27QhL0E@2<S8`0Shn?09JFUP2RXZ80UiNG09RHV02:
RXX0QhN709JFUP2NWYh0QhN708B4Q02HV9P0QXJ605ADE02=SHd0QHF5096AT@2>SXh0S8b<08f=S@27
QhL0Shn?08Z:RP2;Rh/0TY:B08n?S`2<S8`0UiNG09JFUP2DU9@0Shn?09FEU@2@T900S8b<08Z:RP2@
T900U9BD09:BTP2GUiL0W9bL09RHV029RHT0S8b<0:BTY02ATI40SHf=08n?S`2GUiL0X:2P08f=S@21
PH40OWin0820P01kNg/0SXj>07]kN`1fMWH0P82008n?S`2<S8`0M7Ad07QhN027QhL0TI6A092@T02<
S8`0SHf=0861P@1fMWH0N7Qh07inOP1jNWX0RXZ:08j>SP2:RXX0SXj>09FEU@2>SXh0RHV908n?S`2;
Rh/0QXJ608N7Q`2<S8`08P3oool00200oooo0P1hN7P01P1mOGd0N7Qh07QhN01hN7P0M7Ad07]kN`D0
N7Qh00P0Ng]k07QhN01hN7P0Ng]k07QhN01kNg/0M7Ad07UiN@<0M7Ad0180OGem08:2PP2BTY80PH61
07moO`1lO7`0N7Qh08j>SP27QhL0N7Qh08F5Q@1cLg<0N7Qh00l?3`1lO7`0KVi^079bLP1fMWH207Ui
N@0806i^KP1gMgL0M7Ad079bLP1hN7P0LW9b06m_K`1hN7P207EeM@07079bLP1dM7@0M7Ad07AdM01b
LW80N7Qh07MgM`0207QhN00F0820P01gMgL0Kfm_07QhN01`L700J6QX079bLP1[Jf/0N7Qh0861P@1l
O7`0N7Qh061PH01hN7P0Ph>307inOP1`L700MGEe079bLP1hN7P0M7Ad06MWI`80P82000h0R8R807Mg
M`26QXH0LG5a06=SH`1fMWH0LG5a07QhN01mOGd0OWin07=cL`1lO7`0N7Qh07UiN@80N7Qh00D0Ng]k
07AdM01dM7@0LW9b07AdM00N0?ooo`0407IfMP1iNGT0N7Qh07=cL`80NGUi00@0Lg=c07QhN01fMWH0
M7Ad0P1fMWH0101iNGT0N7Qh07IfMP1dM7@207IfMP0L07YjNP1eMGD0NGUi07AdM01gMgL0N7Qh07al
O022PX80TY:B08>3P`24Q8@0Ogmo07QhN028R8P0NGUi06ATI01lO7`0PX:207emO@0?3`l0Ng]k075a
L@1eMGD0LW9b07MgM`1lO7`0N7Qh07MgM`80NGUi00L0NWYj07IfMP1gMgL0N7Qh07MgM`1eMGD0N7Qh
0080NGUi00@0N7Qh07IfMP1kNg/0MWIf0P1kNg/0;@21PH40MgMg06a/K01jNWX0Q8B407AdM01mOGd0
MgMg08R8R01dM7@0MWIf07AdM01UIFD0MWIf07MgM`1aLG40K6a/07YjNP1`L700Ogmo07=cL`1VIVH0
NWYj07AdM021PH40MGEe07alO01`L700HF5Q07IfMP1aLG40IfMW06m_K`1eMGD0LW9b07]kN`1eMGD0
M7Ad079bLP1fMWH0NWYj07IfMP1iNGT0MgMg07EeM@0N0?ooo`0408b<S02?Shl0RHV908N7Q`80Shn?
00@0Rh^;08Z:RP2<S8`0RHV90P2<S8`01P2?Shl0RXZ:08b<S029RHT0QhN708b<S0<0SXj>0140S8b<
096AT@2BTY80SXj>096AT@2GUiL0UIFE09NGU`2DU9@0Shn?08f=S@1oOgl0LW9b08F5Q@2PX:00UIFE
06UYJ@0208j>SP08092@T028R8P0Rh^;09>CT`2IVIT0SXj>09BDU02FUYH209:BTP0I09JFUP2?Shl0
T92@08j>SP2EUID0Ti>C09BDU02BTY80Ti>C09:BTP2=SHd0Ti>C09:BTP2ATI40SHf=08N7Q`2ATI40
YjNW09VIV@2KVi/0VYZJ0:FUY@1oOgl0R8R808V9R@0208b<S00O08:2PP1nOWh0QXJ609BDU028R8P0
V9RH08b<S026QXH0R8R80820P02:RXX0Rh^;08F5Q@2:RXX0Q8B408b<S02;Rh/0MWIf07]kN`24Q8@0
Rh^;08j>SP2;Rh/0QhN708J6QP2<S8`0SXj>092@T02CTi<0TY:B08j>SP0R0?ooo`00803oool0101h
N7P0Ng]k07QhN01dM7@207]kN`0407AdM01hN7P0N7Qh07AdM080N7Qh0`1kNg/207QhN080Ng]k0P1h
N7P04P1kNg/0MWIf07MgM`22PX80Ph>308B4Q01mOGd0R8R807emO@1hN7P0QXJ6079bLP1`L700N7Qh
079bLP22PX803`l?07]kN`80N7Qh00L0MWIf079bLP22PX80Ogmo07UiN@1hN7P0MGEe0080N7Qh00X0
LW9b07AdM01hN7P0LW9b07QhN01bLW80Ng]k07MgM`1cLg<0LW9b0P1hN7P0501mOGd0O7al07MgM`1a
LG40NGUi07QhN01`L700LW9b06e]K@1bLW80M7Ad06IVIP1`L700K6a/07QhN01mOGd0QhN707YjNP1h
N7P0JFUY0P1hN7P05P1OGel0M7Ad07QhN01oOgl0MWIf08V9R@1hN7P0KFe]07MgM`1bLW80M7Ad079b
LP1aLG40Lg=c07alO01iNGT0M7Ad07QhN01dM7@0Ng]k07emO@1iNGT207QhN1h0oooo00@0MWIf07Qh
N01iNGT0MGEe0P1hN7P0101cLg<0MWIf07IfMP1eMGD207IfMP80N7Qh00<0MWIf07AdM01fMWH00P1j
NWX06P1fMWH0M7Ad07UiN@1gMgL0M7Ad07inOP2;Rh/0TY:B07moO`22PX80O7al07MgM`2;Rh/0L71`
07AdM029RHT0LW9b07inOP0;2`/0N7Qh07AdM01`L700N7Qh07AdM01lO7`0NGUi0P1kNg/02P1eMGD0
N7Qh07YjNP1dM7@0MgMg07UiN@1fMWH0NWYj079bLP1hN7P207UiN@0C07EeM@1jNWX0NWYj07alO01o
Ogl0Lg=c075aL@27QhL0NWYj07IfMP1mOGd0P82007emO@25QHD0MWIf079bLP1SHf<0L71`07QhN002
07MgM`0?07YjNP1fMWH0MWIf07UiN@1UIFD0MGEe07alO024Q8@0K6a/08>3P`1[Jf/0IFEU07IfMP1Z
JVX0Kfm_0080N7Qh00/0LW9b07IfMP1fMWH0LW9b07UiN@1eMGD0N7Qh07IfMP1gMgL0Lg=c07IfMP0N
0?ooo`0408b<S02:RXX0Shn?08j>SP80RXZ:00@0Rh^;08b<S02<S8`0SXj>0P2<S8`208Z:RP0308N7
Q`29RHT0S8b<0080SXj>0100S8b<08V9R@2<S8`0Shn?08V9R@2<S8`0WIfM0:JVYP2BTY80Rh^;08n?
S`2<S8`0VYZJ08V9R@2@T900YjNW0P2<S8`05`1TI6@0Rh^;08V9R@23Ph<0TI6A08n?S`29RHT0R8R8
096AT@2BTY80SXj>08n?S`2BTY80Shn?092@T02?Shl0Ti>C09:BTP2<S8`0Rh^;096AT@2EUID0T92@
0080TI6A0240Shn?09>CT`28R8P0Rh^;0::RXP2ATI40Ti>C09^KV`2TY:@0W9bL0:FUY@2NWYh0SXj>
07emO@23Ph<0RHV907inOP2;Rh/0TI6A09^KV`2<S8`0T92@08f=S@2>SXh0U9BD09NGU`1oOgl0Rh^;
07emO@1oOgl0SHf=0861P@26QXH00P2EUID02`2;Rh/0QhN708Z:RP2:RXX0Shn?08j>SP2:RXX0QXJ6
08^;R`27QhL0S8b<0280oooo000P0?ooo`80N7Qh00<0Ng]k07QhN01dM7@00P1hN7P00`1dM7@0Ng]k
07QhN00207QhN00307AdM01hN7P0N7Qh00<0N7Qh00l0Ng]k07QhN01aLG40NGUi07IfMP1hN7P0OWin
09JFUP20P800N7Qh07YjNP1`L700MGEe0861P@1/K6`00P22PX804P1hN7P0RHV901DE5@1hN7P0Kfm_
07AdM01lO7`0LW9b071`L01oOgl0N7Qh07YjNP1eMGD0M7Ad07QhN01dM7@0L71`07MgM`80Lg=c00D0
M7Ad07QhN01eMGD0NGUi075aL@0207MgM`0607AdM01nOWh0KVi^07alO01oOgl0LW9b0P1dM7@0501m
OGd0Ng]k07alO01aLG40KVi^065QH@1]KFd0N7Qh08:2PP1mOGd0QXJ607QhN01YJFT0N7Qh079bLP1`
L700MgMg08V9R@1hN7P0LW9b0P1]KFd00`1hN7P0KVi^075aL@0207inOP0507QhN01`L700Ng]k07Ad
M01kNg/01@1hN7P00`1kNg/0oooo0?ooo`0L0?ooo`80MWIf00<0N7Qh07IfMP1gMgL00P1fMWH01P1i
NGT0N7Qh07AdM01fMWH0NGUi07EeM@<0MWIf0200NGUi07IfMP1jNWX0N7Qh07AdM01kNg/0Lg=c07Ee
M@1lO7`0Vi^K08R8R01nOWh0PX:207UiN@1oOgl0QhN706QXJ022PX80Ph>306][J`20P8003@d=07em
O@1cLg<0MGEe07]kN`1gMgL0MGEe07inOP1jNWX0NGUi07QhN0<0NGUi00<0M7Ad07]kN`1hN7P00P1e
MGD0301mOGd0NGUi07QhN01eMGD0NWYj07MgM`1kNg/0Ogmo06a/K01oOgl0QHF507QhN080Ng]k00<0
N7Qh071`L01oOgl00P1]KFd03`1WIfL0LW9b07YjNP21PH40M7Ad0861P@1fMWH0M7Ad079bLP1ZJVX0
MgMg07IfMP1gMgL0K6a/07]kN`0206a/K00;079bLP1UIFD0LW9b07EeM@1bLW80MWIf079bLP1hN7P0
Lg=c07QhN01dM7@00P1fMWH207AdM00307YjNP3oool0oooo01`0oooo0P2<S8`00`2:RXX0S8b<096A
T@0208b<S00609>CT`2:RXX0RHV908b<S02?Shl0SXj>0`2<S8`0602?Shl0S8b<08j>SP2?Shl0T92@
09:BTP29RHT0Rh^;08f=S@2OWil0W9bL09NGU`2JVYX0VIVI09^KV`2IVIT0Q8B4096AT@2CTi<0O7al
08N7Q`1PH600U9BD096AT@80SXj>00`0Ti>C09:BTP2?Shl0TY:B08f=S@2ATI40U9BD08n?S`2CTi<0
TI6A09BDU02CTi<208n?S`0R09JFUP2BTY80SXj>092@T02BTY80SHf=09RHV02BTY80R8R809>CT`2I
VIT0UIFE09NGU`2FUYH0RHV90820P02DU9@0QXJ608V9R@2>SXh0TY:B096AT@2@T900Ph>308^;R`2<
S8`0V9RH08F5Q@20P800UIFE08b<S01kNg/0OGem09ZJVP80R8R800/0QXJ607moO`2<S8`0Ph>307mo
O`2<S8`0SHf=08Z:RP2;Rh/0RXZ:08V9R@0208b<S080RHV900<0SXj>0?ooo`3oool0803oool00200
oooo00<0M7Ad07QhN01hN7P00P1hN7P0101cLg<0LW9b079bLP1mOGd207QhN00507IfMP1hN7P0Ng]k
07QhN01lO7`00P1hN7P0201kNg/0N7Qh07QhN01hN7P0LW9b07]kN`29RHT0Q8B40P20P8003021PH40
JVYZ08N7Q`1aLG40Ogmo06i^KP28R8P0Kfm_07=cL`0E5AD0PH61079bLP@0N7Qh00L0LW9b07=cL`1h
N7P0O7al07=cL`1fMWH0MGEe0080OGem00<0N7Qh079bLP1bLW801@1hN7P05@1bLW80MgMg06i^KP24
Q8@0NGUi071`L01kNg/0L71`07QhN020P800H61P06EUI@1dM7@0PX:207QhN01]KFd0HV9R06e]K@1m
OGd0Xj>S08f=S@0207QhN003079bLP1OGel0N7Qh00<0N7Qh00X0G5aL079bLP1gMgL0OWin07emO@1c
Lg<0N7Qh079bLP1kNg/0Lg=c1@1hN7P00`1iNGT0N7Qh07]kN`0N0?ooo`0;07MgM`1fMWH0MWIf07Ui
N@1gMgL0MWIf07QhN01gMgL0MWIf07=cL`1jNWX00P1fMWH03P1jNWX0M7Ad07UiN@1dM7@0Lg=c07If
MP1dM7@0NGUi07YjNP1eMGD0Ng]k096AT@2=SHd0QHF50P22PX80301cLg<0RHV906UYJ@23Ph<0PH61
09FEU@1_Kfl0MGEe01@D5020P800LG5a07=cL`80NGUi00`0NWYj07UiN@1eMGD0NGUi07]kN`1fMWH0
NWYj07IfMP1jNWX0NGUi07IfMP1dM7@207QhN080NWYj0340MWIf07emO@1kNg/0Ogmo07=cL`27QhL0
P82007emO@1hN7P0LG5a07IfMP2>SXh0OGem06a/K01ZJVX0Lg=c071`L01_Kfl0K6a/07IfMP1jNWX0
R8R807YjNP1ZJVX0Lg=c07AdM01WIfL0MWIf0820P021PH40MgMg05]KF`1`L700JFUY071`L01hN7P0
LG5a07IfMP1^KVh0O7al07EeM@1fMWH0NGUi07IfMP1dM7@0MWIf07MgM`1cLg<0N7Qh01h0oooo0140
TI6A08b<S02<S8`0Shn?08f=S@2@T900U9BD09:BTP26QXH0QhN7096AT@2=SHd0S8b<08j>SP29RHT0
Rh^;08R8R00208N7Q`0308V9R@2?Shl0TI6A0080Shn?0140WinO09jNWP2GUiL0U9BD09:BTP2FUYH0
UiNG07moO`2GUiL0YJFU0:JVYP2<S8`0SXj>06YZJP2@T900RXZ:08N7Q`02092@T00>09:BTP2FUYH0
Shn?092@T02>SXh0T92@09>CT`2>SXh0Rh^;08V9R@2<S8`0Shn?09FEU@2>SXh209:BTP0F08b<S02E
UID0V9RH09VIV@2BTY80UiNG09RHV02MWId0RXZ:08f=S@2<S8`0YJFU0:j^[P2BTY80Ogmo07alO022
PX80SHf=09BDU02GUiL0Rh^;07MgM`80Ng]k00/0QhN708n?S`2ATI40Rh^;09VIV@2JVYX0S8b<08:2
PP2:RXX0NWYj07emO@0208V9R@0<08^;R`25QHD0T92@08n?S`2<S8`0Shn?08b<S029RHT0S8b<08^;
R`27QhL0RXZ:8P3oool00200oooo00D0Ng]k07QhN01kNg/0Ng]k07UiN@0207emO@0:07]kN`1hN7P0
N7Qh07emO@1hN7P0MWIf07]kN`1cLg<0O7al07AdM080N7Qh00X0M7Ad07IfMP1iNGT0Ng]k07IfMP2:
RXX0OWin08R8R01hN7P0O7al0P1hN7P0101ZJVX0QhN707emO@28R8P207alO00?01`L701hN7P0LW9b
079bLP1hN7P0MWIf07QhN01lO7`0N7Qh079bLP1hN7P0NGUi079bLP1`L700JFUY0080M7Ad00<0Kfm_
07QhN01YJFT0101hN7P06P1gMgL0Ogmo06][J`2=SHd0P82006i^KP1lO7`0L71`06UYJ@1jNWX0N7Qh
07IfMP1hN7P0J6QX07QhN01WIfL0JFUY08>3P`1`L700T92@08J6QP1jNWX0L71`08:2PP1WIfL0MgMg
0P1hN7P03`1cLg<0KFe]07QhN01^KVh0NGUi075aL@1kNg/0N7Qh07=cL`1nOWh0M7Ad07QhN01kNg/0
N7Qh079bLP0207QhN00307AdM01hN7P0oooo01d0oooo00@0MWIf07AdM01hN7P0N7Qh0`1eMGD02P1d
M7@0MWIf07IfMP1hN7P0MWIf07QhN01kNg/0LW9b07YjNP1bLW8207UiN@80N7Qh01@0MGEe07UiN@1f
MWH0UYJF0861P@2;Rh/0PH6108J6QP1kNg/0OWin06e]K@2;Rh/0PH6108F5Q@1_Kfl0Lg=c01XJ6P1m
OGd0MGEe07MgM`80NWYj0P1hN7P01@1jNWX0MgMg07UiN@1lO7`0N7Qh0080MgMg0P1kNg/01@1cLg<0
MWIf07EeM@1jNWX0MWIf0080OGem00<0MWIf0861P@1YJFT00P2:RXX0501`L700OGem07QhN024Q8@0
S8b<08:2PP1NGUh0MWIf075aL@1mOGd0L71`06][J`1jNWX0JFUY08j>SP1lO7`0JFUY06e]K@1kNg/0
H61P0P20P8003@1mOGd0JVYZ05eMG@1/K6`0JFUY07YjNP1aLG40M7Ad07=cL`1aLG40Ng]k079bLP1f
MWH00P1hN7P01@1eMGD0NGUi07IfMP1eMGD0MWIf01h0oooo00D0QhN708V9R@2:RXX0RXZ:08R8R002
08F5Q@0:08J6QP2<S8`0S8b<08V9R@2<S8`0T92@08n?S`2<S8`0SHf=08Z:RP80Shn?02P0TY:B092@
T028R8P0S8b<08f=S@2UYJD0UIFE09RHV02KVi/0WIfM09:BTP2FUYH0SXj>09VIV@2EUID0T92@07in
OP24Q8@0Jf][09FEU@2@T900U9BD09:BTP2CTi<0SXj>08Z:RP2ATI40Ti>C092@T02CTi<0UIFE09JF
UP2MWId0V9RH09JFUP2ATI40S8b<09VIV@2BTY80S8b<0P2EUID0:P2=SHd0U9BD08N7Q`2ATI40WinO
08f=S@2ATI40UYJF0:n_[`2XZ:P0W9bL06a/K02<S8`0U9BD09JFUP2DU9@0Rh^;08J6QP22PX80U9BD
08F5Q@1gMgL0QhN708V9R@1oOgl0Vi^K09ZJVP2EUID0Ogmo07=cL`1mOGd0Q8B4092@T02<S8`0QHF5
08N7Q`2:RXX0S8b<08Z:RP2<S8`0RXZ:08j>SP80Shn?00<0S8b<08j>SP2<S8`08P3oool00200oooo
0P1hN7P06P1dM7@0Ng]k07AdM01dM7@0LW9b07AdM01hN7P0M7Ad07QhN01lO7`0Ng]k07alO01bLW80
MWIf07AdM01fMWH0Ng]k07UiN@1kNg/0N7Qh07UiN@1hN7P0Q8B407QhN023Ph<0N7Qh0P22PX80201n
OWh0LG5a0861P@1eMGD0O7al07QhN01eMGD08b<S0P1hN7P01@21PH40NWYj07inOP1gMgL0OWin0080
PH6100L0OGem08B4Q01nOWh0M7Ad07QhN01^KVh0MWIf0080KVi^0P1dM7@06@1^KVh0MgMg07QhN01_
Kfl0MGEe06IVIP2:RXX0QhN705mOG`20P800KVi^07IfMP1cLg<0SHf=06=SH`27QhL0N7Qh07alO01g
MgL0Fe]K07MgM`1fMWH0Ogmo07inOP1^KVh00P1bLW803`1hN7P0QXJ607MgM`28R8P0MWIf06IVIP1/
K6`0Ph>307AdM01hN7P0LW9b07alO01hN7P0Ng]k07AdM00207QhN00607emO@1hN7P0Ng]k07]kN`1d
M7@0N7Qh7P3oool207IfMP0407EeM@1jNWX0MGEe07UiN@80MgMg00P0NGUi07EeM@1fMWH0N7Qh07Ee
M@1lO7`0MGEe07QhN080MWIf01h0NWYj07EeM@1eMGD0N7Qh07UiN@1fMWH0Shn?08:2PP2@T900OGem
08>3P`1nOWh0NGUi07AdM02>SXh0Ogmo07emO@1fMWH0MGEe024Q8@1gMgL0MWIf07QhN01gMgL0NWYj
079bLP1jNWX0MgMg07IfMP1eMGD207alO00I07]kN`1jNWX0MgMg07YjNP1dM7@0NGUi079bLP1kNg/0
NGUi07emO@1lO7`0N7Qh07emO@1XJ6P0TY:B08j>SP1SHf<0QhN708:2PP24Q8@0Lg=c07IfMP1SHf<0
O7al075aL@0207QhN00G069RHP1dM7@0NWYj08F5Q@1jNWX0LW9b07AdM01[Jf/0K6a/08J6QP1bLW80
OGem06UYJ@1VIVH0HF5Q07]kN`1fMWH0LW9b071`L01eMGD0Lg=c07QhN01cLg<00P1fMWH01P1hN7P0
Lg=c07QhN01jNWX0Lg=c07UiNAh0oooo0P2<S8`308j>SP0809>CT`2BTY80TI6A08n?S`2>SXh0S8b<
08Z:RP26QXH208n?S`80T92@03P0SHf=08j>SP28R8P0QXJ608j>SP2?Shl0S8b<0::RXP2LW9`0Y:BT
09FEU@2CTi<0Rh^;08V9R@2@T900Y:BT09bLW02@T900S8b<08j>SP1^KVh0SHf=08b<S025QHD0RXZ:
08V9R@26QXH0RHV908>3P`21PH40QHF508J6QP2=SHd0V9RH096AT@2GUiL0TY:B09>CT`2KVi/0RXZ:
09RHV02KVi/0UYJF09BDU02HV9P0VIVI08Z:RP2OWil0WIfM08^;R`2KVi/0YjNW0:6QX@2=SHd0MGEe
08R8R080Q8B400L0RXZ:08n?S`2>SXh0RXZ:09>CT`2IVIT0Rh^;0080Shn?0100PX:207emO@2BTY80
QhN708B4Q01kNg/0R8R807]kN`26QXH0Shn?08J6QP29RHT0QHF508R8R02:RXX0Rh^;0P2<S8`01P29
RHT0QhN708Z:RP2>SXh0Rh^;08n?Sb80oooo000P0?ooo`80M7Ad00P0N7Qh07EeM@1eMGD0OGem07Qh
N01kNg/0N7Qh07AdM080N7Qh00L0LW9b07UiN@1lO7`0MWIf07UiN@1cLg<0Ng]k0080M7Ad0180N7Qh
07IfMP1iNGT0QhN708:2PP28R8P0N7Qh0861P@1hN7P0S8b<079bLP2@T900IVIV08:2PP1hN7P0Lg=c
03De=@1hN7P308J6QP0<08V9R@26QXH0PH610820P01oOgl0OWin08F5Q@2=SHd0Shn?07QhN01dM7@0
LW9b0P1dM7@0801ZJVX0L71`07QhN01dM7@0N7Qh07YjNP1bLW80IFEU08f=S@1kNg/0JFUY0861P@1j
NWX0LG5a06a/K025QHD0Hf=S07QhN01nOWh0LG5a07QhN01RHV80L71`08R8R02:RXX0T92@07alO01^
KVh0Cdm?07QhN027QhL0L71`0P1hN7P02@1dM7@0MWIf0861P@1nOWh0Ng]k07=cL`1dM7@0N7Qh07Ad
M00307QhN00407AdM01hN7P0N7Qh07]kN`80N7Qh7P3oool0:`1gMgL0MGEe07QhN01jNWX0Lg=c07Qh
N01cLg<0MWIf07UiN@1cLg<0MWIf07YjNP1eMGD0MgMg07QhN01eMGD0N7Qh075aL@1jNWX0MGEe07Ui
N@1jNWX0MWIf07alO028R8P0QXJ608Z:RP1jNWX0PH61071`L025QHD0MGEe09^KV`1/K6`0NWYj07Ui
N@1YJFT09RHV06e]K@1aLG40N7Qh07=cL`1dM7@00P1fMWH02P1gMgL0N7Qh07EeM@1iNGT0NWYj07Qh
N01mOGd0MWIf07MgM`1hN7P207YjNP0307MgM`1iNGT0NWYj0080NWYj02T0MWIf06][J`2IVIT0PX:2
06ATI02=SHd0Q8B407UiN@1NGUh0OGem065QH@1gMgL0OGem07QhN01kNg/0GemO06e]K@1kNg/0M7Ad
0820P01cLg<0P82005QHF01fMWH0QhN707=cL`1aLG40KVi^05YJFP1XJ6P0OWin07=cL`1gMgL0L71`
07EeM@1iNGT0MGEe07AdM01fMWH0NGUi07EeM@0207IfMP0307QhN01fMWH0NWYj01h0oooo00H0TI6A
08j>SP2?Shl0U9BD08^;R`29RHT208N7Q`0708n?S`2;Rh/0S8b<096AT@2?Shl0Rh^;08V9R@0208b<
S00:08Z:RP2>SXh0SXj>09>CT`2ATI40SHf=09:BTP2EUID0UYJF09NGU`80TI6A0180Q8B408b<S02?
Shl0YZJV092@T027QhL0T92@07inOP1RHV80OWin07EeM@1oOgl0N7Qh07IfMP1lO7`0PX:208B4Q026
QXH208:2PP0]07]kN`1fMWH0UIFE08n?S`2CTi<0TY:B09FEU@2PX:00UYJF092@T02EUID0TI6A08n?
S`2BTY80Shn?0:RXZ02HV9P0PX:20:>SX`2MWId0UiNG07IfMP27QhL0Ph>308b<S02?Shl0UYJF09:B
TP22PX80QhN70861P@1eMGD0Ogmo08:2PP2TY:@0SHf=08b<S02CTi<0T92@08B4Q021PH40J6QX07Yj
NP2=SHd0P8200080RHV900L0SXj>08n?S`2>SXh0RHV908b<S02?Shl0SXj>0080S8b<00<0RXZ:08b<
S02ATI408P3oool00200oooo00T0Ng]k07QhN01kNg/0OWin07QhN01kNg/0M7Ad07QhN01kNg/00P1h
N7P02@1mOGd0M7Ad07QhN01iNGT0Ng]k07alO01aLG40N7Qh07]kN`0207QhN00507UiN@1oOgl0OWin
07moO`23Ph<00P1lO7`04@1ZJVX0OGem07inOP2BTY80IfMW07moO`1lO7`0HV9R05UIF@1iNGT0N7Qh
07YjNP1kNg/0N7Qh0820P023Ph<0QXJ60080OGem0P1nOWh02@22PX80SXj>08N7Q`1fMWH0Kfm_07Qh
N01jNWX0M7Ad06a/K00207QhN00507alO01hN7P0HV9R09FEU@20P8000P1hN7P07P1oOgl0Lg=c061P
H02FUYH0Hf=S06e]K@1oOgl0NGUi075aL@1VIVH0HV9R07MgM`1jNWX0R8R807moO`1lO7`0HF5Q06m_
K`1oOgl0OGem06m_K`1RHV80FUYJ07alO01bLW80KFe]079bLP1kNg/0M7Ad07]kN`80LW9b00P0M7Ad
07QhN01hN7P0N7Qh07AdM01hN7P0Ng]k07emOAh0oooo0P1fMWH01@1hN7P0MGEe079bLP1jNWX0Lg=c
0080MWIf02L0M7Ad07IfMP1kNg/0LW9b07IfMP1gMgL0MGEe07YjNP1aLG40MWIf07UiN@1hN7P0MGEe
07IfMP27QhL0RHV908N7Q`25QHD0O7al08F5Q@1eMGD0PH6107moO`2GUiL0H61P07UiN@1kNg/0B4Q8
03De=@1/K6`0Kfm_07IfMP1hN7P0MWIf07QhN01eMGD0O7al07EeM@1fMWH00P1iNGT0201jNWX0MWIf
07emO@1kNg/0MWIf07MgM`1eMGD0NWYj0P1gMgL04@1fMWH0OGem07alO01ZJVX0Ti>C071`L01TI6@0
Q8B408:2PP1[Jf/0E5AD096AT@1XJ6P0LW9b0861P@1kNg/0L71`0080J6QX01@0MWIf07UiN@22PX80
NGUi079bLP1IFET0NGUi07moO`1dM7@0HV9R06IVIP1HF5P0OWin07alO01aLG40L71`07MgM`1cLg<0
Ng]k07EeM@80MgMg00L0MWIf07AdM01iNGT0MGEe07IfMP1hN7P0MWIf01h0oooo00d0QhN708b<S02;
Rh/0Ph>308J6QP2>SXh0Rh^;08b<S027QhL0RHV908b<S02=SHd0RHV90080S8b<00<0QXJ608f=S@2;
Rh/00P2<S8`05@2>SXh0Rh^;08Z:RP2KVi/0X:2P09^KV`2EUID0Shn?09bLW02IVIT0UYJF09:BTP2N
WYh0OWin08R8R02>SXh0HV9R051@D01kNg/0PH6108V9R@0208^;R`0508F5Q@1nOWh0QHF508B4Q025
QHD00P29RHT00`27QhL0M7Ad08F5Q@0209BDU00E08f=S@28R8P0UIFE09VIV@2=SHd0S8b<092@T02D
U9@0Ti>C09JFUP1iNGT0LW9b0:2PX02EUID0PH6107AdM02ATI40SXj>09:BTP2CTi<0TI6A0080RXZ:
0100SXj>08b<S02=SHd0S8b<08R8R021PH40NWYj09VIV@2@T900PX:207QhN02<S8`0PH6109>CT`2I
VIT0T92@0P29RHT0302;Rh/0Shn?08n?S`2BTY80TI6A08b<S029RHT0Shn?08j>SP2<S8`0RXZ:08J6
QR80oooo000P0?ooo`0807AdM01hN7P0Lg=c07QhN01dM7@0MWIf07QhN01bLW8407QhN00507=cL`1h
N7P0M7Ad07QhN01kNg/00P1dM7@0401gMgL0N7Qh07IfMP1hN7P0SXj>0820P01lO7`0PH6107QhN026
QXH0OWin075aL@2=SHd0N7Qh071`L01mOGd207alO00807QhN01mOGd0N7Qh07moO`1jNWX0PX:207Qh
N01mOGd20820P00:08:2PP1mOGd0P82007inOP24Q8@0Ti>C09BDU029RHT0L71`06m_K`80NWYj00P0
L71`07QhN01hN7P0OGem05eMG@1XJ6P0QHF506ATI080N7Qh01/0G5aL04I6AP2CTi<0I6AT06a/K02>
SXh0N7Qh08J6QP1[Jf/0KFe]07MgM`24Q8@0SXj>08V9R@1hN7P0JVYZ079bLP1/K6`0N7Qh06a/K01Y
JFT0M7Ad07QhN01eMGD0MWIf07AdM01kNg/00P1hN7P307]kN`80M7Ad00D0Ng]k07QhN01hN7P0M7Ad
07QhN00N0?ooo`0807MgM`1fMWH0LW9b07UiN@1hN7P0MWIf07QhN01eMGD207IfMP0^07UiN@1jNWX0
LW9b07UiN@1cLg<0NGUi07YjNP1aLG40MWIf07YjNP1fMWH0MGEe07IfMP2=SHd0R8R80861P@26QXH0
OGem07moO`1mOGd0L71`09VIV@1mOGd0IVIV07emO@1BDU80<c<c05ADE01bLW80Lg=c07UiN@1bLW80
NGUi07=cL`1iNGT0NWYj07AdM01jNWX0N7Qh07YjNP1hN7P0NGUi07emO@1gMgL0OGem07MgM`80N7Qh
02H0MWIf07AdM01kNg/0P82008J6QP1jNWX0LG5a07alO01NGUh0Ogmo08>3P`1`L700DU9B0820P01Y
JFT0I6AT08R8R01ZJVX0N7Qh06YZJP1UIFD0L71`07AdM01nOWh0TY:B06e]K@1/K6`0O7al079bLP1`
L700KFe]059BDP1XJ6P0PX:2079bLP1[Jf/0Kfm_07QhN080MgMg0P1dM7@0201hN7P0MGEe07EeM@1h
N7P0M7Ad07UiN@1eMGD0MWIf7P3oool0202ATI40S8b<08b<S02?Shl0TY:B08f=S@2>SXh0Shn?0P2<
S8`03`2?Shl0TI6A08b<S02?Shl0Rh^;08n?S`2>SXh0R8R8092@T02ATI40S8b<08^;R`2<S8`0UIFE
09fMW@0209NGU`0E09JFUP29RHT0Shn?08Z:RP2VYZH0UIFE07alO02@T900E5AD02PX:01KFe/0P820
08N7Q`28R8P0Q8B408F5Q@27QhL0RHV908R8R020P800QhN70080R8R80300QhN708:2PP1hN7P0Kfm_
08>3P`2DU9@0UiNG08b<S028R8P0T92@09>CT`2IVIT0W9bL0:f][@2DU9@0QHF507moO`2IVIT0WinO
0:2PX02=SHd0OGem08j>SP1nOWh0SHf=07YjNP1nOWh0QhN707inOP23Ph<0O7al0820P02QXJ40Ogmo
08b<S02JVYX0TY:B08B4Q02:RXX0JFUY07alO02LW9`0RHV907inOP25QHD0RXZ:08f=S@2<S8`208J6
QP0808Z:RP2>SXh0SXj>08Z:RP29RHT0Shn?08j>SP2<S8`R0?ooo`00803oool0201hN7P0Ng]k07Qh
N01hN7P0LW9b07QhN01mOGd0Ng]k0`1hN7P01P1gMgL0N7Qh07]kN`1kNg/0N7Qh07]kN`<0N7Qh0180
NGUi07]kN`23Ph<0NWYj07MgM`21PH40QHF508J6QP1gMgL0N7Qh08>3P`22PX80J6QX07AdM01hN7P0
MWIf07YjNP1bLW8207AdM00607QhN01iNGT0Ogmo07inOP1oOgl0NWYj101hN7P02@1nOWh0O7al07in
OP23Ph<0Q8B409NGU`2DU9@0KVi^07AdM00207EeM@0O07QhN022PX80OWin04E5A@2RXZ80I6AT0:BT
Y01YJFT0N7Qh07IfMP1SHf<0R8R807QhN024Q8@0N7Qh06EUI@1lO7`0L71`069RHP1ZJVX0Q8B409RH
V01YJFT0LW9b06YZJP1WIfL0OGem08B4Q01IFET0KVi^07inOP0207UiN@0407alO01dM7@0Ng]k07Ad
M0<0N7Qh0P1kNg/01@1hN7P0M7Ad07QhN01hN7P0M7Ad01h0oooo00d0MWIf07QhN01fMWH0NWYj07Ee
M@1fMWH0N7Qh07AdM01cLg<0MWIf07YjNP1iNGT0MWIf0080N7Qh00D0M7Ad07IfMP1dM7@0MWIf07Ui
N@0207]kN`0@08N7Q`22PX80OWin08B4Q022PX80P820079bLP1kNg/0Rh^;08J6QP1UIFD0O7al05eM
G@1aLG40Ng]k07=cL`80MGEe00d0MWIf07MgM`1iNGT0M7Ad07UiN@1kNg/0MgMg07IfMP1jNWX0OGem
07UiN@1gMgL0NWYj0080Ng]k02`0R8R808>3P`1eMGD0NGUi07MgM`1jNWX0O7al08F5Q@1kNg/0AdM7
08n?S`1EEED0WYjN07alO01hN7P0EUIF05=CD`1RHV80Kfm_07QhN01gMgL0KFe]07MgM`1_Kfl0JFUY
075aL@1lO7`0TI6A06][J`1iNGT0LG5a069RHP1aLG40NGUi06MWI`1_Kfl0KVi^06m_K`1eMGD0NWYj
079bLP1jNWX0Lg=c07UiN@80M7Ad00L0N7Qh07IfMP1fMWH0MGEe07IfMP1iNGT0MGEe01h0oooo00d0
S8b<08Z:RP2<S8`0TI6A08n?S`2<S8`0RHV908J6QP28R8P0S8b<096AT@2@T900S8b<0080RXZ:01L0
RHV908N7Q`29RHT0S8b<08n?S`2ATI40Shn?09JFUP2JVYX0UiNG09JFUP2?Shl0RXZ:08N7Q`2BTY80
WIfM09NGU`25QHD0VIVI06QXJ027QhL0T92@08f=S@0208j>SP0D08^;R`2<S8`0R8R808:2PP28R8P0
T92@08b<S02;Rh/0TI6A09FEU@29RHT0R8R808Z:RP26QXH0QHF508>3P`20P800U9BD09>CT`2ATI42
09BDU00U09JFUP2<S8`0OWin08:2PP1bLW80UIFE0:BTY02?Shl0HF5Q071`L01NGUh0PX:20861P@2=
SHd0TY:B08R8R02:RXX0T92@09>CT`27QhL0T92@08^;R`2FUYH0Ti>C0820P01nOWh0PX:209NGU`2<
S8`0NWYj0820P029RHT0SHf=08Z:RP2>SXh0Rh^;08n?S`0208V9R@0708Z:RP27QhL0S8b<08j>SP2<
S8`0Shn?08j>SP0R0?ooo`00803oool2079bLP0;07AdM01mOGd0N7Qh07QhN01cLg<0N7Qh07AdM01h
N7P0NGUi07QhN01iNGT00P1hN7P02`1dM7@0Lg=c07QhN01aLG40Ng]k07UiN@1kNg/0Ph>308:2PP1m
OGd0PH610080OGem00T0Jf][06i^KP2@T900Kfm_071`L01nOWh0GEeM079bLP1mOGd00P1hN7P0=01d
M7@0L71`07QhN01aLG40L71`07moO`1jNWX0N7Qh07MgM`1nOWh0PX:207inOP1lO7`0OGem07alO022
PX80SHf=09NGU`2?Shl0L71`07MgM`1hN7P0M7Ad07MgM`1mOGd0>SXj071`L02@T900_kno0:NWY`2G
UiL0EEEE06IVIP1oOgl0IVIV079bLP25QHD0MWIf079bLP1PH600N7Qh05aLG01iNGT0YZJV06UYJ@1o
Ogl0M7Ad06MWI`1SHf<0Lg=c079bLP1aLG42079bLP0307IfMP1hN7P0N7Qh0080N7Qh00<0Ng]k07Ad
M01hN7P00P1dM7@00`1kNg/0M7Ad07QhN00207QhN1h0oooo00T0N7Qh07EeM@1eMGD0N7Qh07=cL`1j
NWX0MGEe07UiN@1eMGD00P1iNGT0:@1eMGD0N7Qh07UiN@1iNGT0MWIf07EeM@1fMWH0M7Ad07]kN`1i
NGT0Ogmo08J6QP28R8P0O7al08B4Q022PX80QXJ607EeM@1cLg<0V9RH07=cL`1]KFd0KVi^02/[:`1c
Lg<0NGUi07=cL`1fMWH0LW9b07AdM01kNg/0NGUi07=cL`1nOWh0NGUi07MgM`1fMWH0NGUi07MgM`1i
NGT0N7Qh0080NGUi02P0NWYj07moO`28R8P0PX:207=cL`1iNGT0OGem07QhN01kNg/0R8R804a<C01U
IFD0TY:B09^KV`1/K6`0NWYj05QHF01iNGT0R8R8071`L01dM7@0NWYj06a/K01bLW80Hf=S07]kN`1S
Hf<0L71`09jNWP1XJ6P0N7Qh06UYJ@1[Jf/0Lg=c07alO01PH600IfMW07AdM01eMGD0MgMg0`1fMWH0
2`1dM7@0NWYj07=cL`1iNGT0MgMg07EeM@1jNWX0MGEe07UiN@1fMWH0M7Ad01h0oooo00H0U9BD08n?
S`2>SXh0RHV908N7Q`2ATI4208n?S`0508j>SP2?Shl0SXj>08^;R`2=SHd0102?Shl06P2<S8`0T92@
08n?S`2>SXh0U9BD09NGU`2JVYX0SXj>09BDU02FUYH0W9bL09RHV02ATI40XZ:R096AT@27QhL0NGUi
03dm?@2=SHd0RHV908N7Q`2<S8`0Rh^;092@T02CTi<0UiNG0P2?Shl308f=S@0:08V9R@21PH40RHV9
08Z:RP2;Rh/0RXZ:08N7Q`21PH40Ph>308B4Q080T92@01L0UIFE09:BTP2DU9@0X:2P09:BTP1lO7`0
VIVI07AdM01<C4`0L71`08J6QP2SXj<0WYjN09JFUP2?Shl0Ph>307moO`2;Rh/0RXZ:09:BTP2?Shl0
PH6109>CT`0208N7Q`0607emO@2>SXh0WIfM09VIV@1cLg<0OGem0`2?Shl308b<S00508V9R@2>SXh0
Rh^;08n?S`2ATI400`2>SXh00`2?Shl0S8b<08V9R@0R0?ooo`00803oool00`1iNGT0M7Ad07AdM002
07QhN00407alO01dM7@0N7Qh07QhN080Ng]k00D0N7Qh07UiN@1hN7P0Ng]k07alO00307QhN00A07Ui
N@1dM7@0Ogmo07YjNP2=SHd0NWYj07MgM`21PH40Ph>307QhN01aLG40QHF507=cL`1oOgl0MWIf07Qh
N01eMGD00`1hN7P07P1`L700KVi^07EeM@1eMGD0KVi^07EeM@1_Kfl0L71`075aL@1gMgL0LG5a07em
O@1hN7P0MgMg07YjNP1lO7`0PX:208J6QP2LW9`0Ti>C07=cL`1aLG40N7Qh07]kN`22PX80E5AD0410
@02TY:@0OGem09RHV080QhN701L0P82007inOP1hN7P0JVYZ071`L01mOGd0EEEE065QH@1nOWh0HV9R
05mOG`2@T900N7Qh06=SH`1/K6`0MGEe06MWI`1gMgL0M7Ad07alO01aLG40MWIf07UiN@0207QhN003
07AdM01hN7P0N7Qh0080N7Qh00@0Ng]k07AdM01kNg/0Ng]k0`1hN7PN0?ooo`0307IfMP1bLW80Lg=c
0080MWIf00@0NWYj07AdM01fMWH0M7Ad0P1hN7P00`1fMWH0MGEe07IfMP0207IfMP0D07=cL`1fMWH0
M7Ad07inOP1hN7P0QXJ607inOP2CTi<0QHF50820P023Ph<0PX:2079bLP1nOWh0SXj>06ATI01[Jf/0
>3Ph04E5A@1bLW8207IfMP0C07UiN@1eMGD0M7Ad07alO01gMgL0M7Ad07alO01jNWX0N7Qh07AdM01k
Ng/0MgMg07moO`1kNg/0NGUi07MgM`1hN7P0NWYj07alO0020861P@0W07moO`1gMgL0OGem0861P@22
PX80EeMG059BDP2GUiL0MWIf08n?S`1eMGD0JVYZ07UiN@1nOWh0M7Ad075aL@1_Kfl0Rh^;06IVIP1O
Gel0Ogmo06EUI@1dM7@0QhN707UiN@1_Kfl0K6a/07UiN@1[Jf/0KVi^065QH@1hN7P0LG5a079bLP1h
N7P0MWIf07UiN@1cLg<0NGUi00<0MWIf00<0N7Qh07=cL`1hN7P00P1fMWH00`1dM7@0MWIf0?ooo`0M
0?ooo`0308Z:RP29RHT0Rh^;0080S8b<0P2=SHd01`2<S8`0RHV908Z:RP2:RXX0S8b<08R8R02<S8`0
0P27QhL05028R8P0S8b<08V9R@2DU9@0TY:B09ZJVP2EUID0WYjN09nOW`2JVYX0UIFE092@T026QXH0
WYjN0:2PX01fMWH0M7Ad03De=@15ADD0RHV90P2<S8`0?02?Shl0TY:B09BDU02GUiL0T92@09BDU02G
UiL0Vi^K09JFUP2@T900Ti>C09BDU02CTi<0TY:B092@T02;Rh/0RXZ:08N7Q`25QHD0MGEe07inOP2M
WId0U9BD09FEU@2GUiL0TI6A08F5Q@2DU9@0Rh^;08J6QP2<S8`0NWYj06YZJP26QXH0T92@08R8R02C
Ti<0RHV90:BTY02JVYX0Ph>3096AT@2:RXX0Xj>S08Z:RP2@T900UiNG08Z:RP2BTY80SHf=08:2PP1c
Lg<0RXZ:08b<S028R8P0SHf=08b<S02?Shl0Rh^;08n?S`<0S8b<00L0RXZ:08^;R`2:RXX0QhN708b<
S029RHT0S8b<0280oooo000P0?ooo`0307]kN`1hN7P0M7Ad0080N7Qh00<0Ng]k07QhN01hN7P00P1d
M7@0401hN7P0Ng]k07QhN01hN7P0M7Ad07=cL`1bLW80M7Ad07]kN`22PX80N7Qh07alO01jNWX0QhN7
07emO@1gMgL307QhN004071`L01lO7`0IVIV05eMG@80N7Qh00H0MGEe079bLP1bLW80N7Qh07AdM01]
KFd206UYJ@0c06IVIP1WIfL0Jf][06e]K@1WIfL0KFe]06a/K01gMgL0OWin07alO01mOGd0N7Qh07al
O020P800PX:20::RXP2SXj<0Ph>30820P026QXH0OWin06EUI@17AdL0I6AT06a/K02JVYX0Shn?09>C
T`26QXH0JVYZ08^;R`1gMgL0L71`07moO`1^KVh0N7Qh071`L01_Kfl0MGEe07UiN@2:RXX0OWin07Yj
NP1hN7P0Hf=S06][J`1iNGT0N7Qh07]kN`1fMWH0NGUi0080Ng]k00D0M7Ad07]kN`1bLW80Ng]k07Ad
M00707QhN1h0oooo00<0MWIf07AdM01cLg<00P1fMWH00`1jNWX0M7Ad07IfMP0207MgM`@0MWIf0P1h
N7P207MgM`0307QhN01nOWh0OWin0080Ph>300`0UIFE08B4Q01oOgl0Q8B407YjNP1fMWH0Ogmo07]k
N`1`L700<c<c04=3@`1cLg<207QhN00607MgM`1jNWX0NWYj07alO01jNWX0O7al0P1kNg/0401gMgL0
N7Qh07MgM`1mOGd0MGEe07YjNP1iNGT0M7Ad07YjNP1gMgL0Ng]k07UiN@1gMgL0QXJ60820P01gMgL2
08:2PP0B07UiN@1YJFT0GEeM06YZJP1/K6`0PX:206EUI@21PH40QXJ606MWI`1nOWh0KFe]07emO@20
P800IfMW07=cL`1dM7@0KVi^0P1]KFd01P1jNWX0Hf=S07AdM01mOGd0I6AT06YZJP80M7Ad00<0LG5a
07EeM@1hN7P00P1hN7P01`1cLg<0Ng]k07EeM@1jNWX0MGEe07IfMP1dM7@00P1fMWH00`1dM7@0MWIf
07UiN@0N0?ooo`0308N7Q`29RHT0Rh^;0080S8b<00<0SXj>08V9R@2<S8`00P2ATI403P2<S8`0QhN7
08b<S02<S8`0TY:B09BDU02BTY80TI6A08Z:RP2=SHd0UYJF09RHV02LW9`0YjNW0P2IVIT04@2OWil0
TI6A08b<S02PX:00SXj>09JFUP19BDT0@d=308N7Q`2ATI40UIFE09>CT`2BTY80UIFE09nOW`2QXJ40
Y:BT0080YJFU02D0Vi^K09ZJVP2OWil0XJ6Q09JFUP2BTY80RHV908B4Q02;Rh/0SHf=08j>SP27QhL0
PH6107IfMP1[Jf/0PX:209BDU02=SHd0RHV908b<S02KVi/0Shn?08V9R@1hN7P0FUYJ07inOP2CTi<0
Q8B408>3P`20P800WIfM096AT@20P800QXJ6092@T029RHT0PH610080OGem00X0Jf][08F5Q@2EUID0
R8R808N7Q`28R8P0RHV90861P@2<S8`0SHf=0P2:RXX00`2;Rh/0Shn?08n?S`0208j>SP0708b<S029
RHT0S8b<08b<S029RHT0S8b<08n?S`0R0?ooo`00803oool707QhN080Ng]k0`1hN7P207]kN`80NGUi
01H0N7Qh07]kN`1dM7@0OWin08>3P`1lO7`0R8R808V9R@1iNGT0QXJ608:2PP1_Kfl0N7Qh07=cL`1l
O7`0RHV907IfMP1kNg/0MWIf07]kN`1hN7P0MGEe0`1gMgL00`1aLG40Kfm_06YZJP0306YZJP0807Ad
M01_Kfl0KFe]079bLP1gMgL0N7Qh07inOP1hN7P207alO00W07QhN01lO7`0TI6A09VIV@1nOWh0OGem
07QhN01PH600FUYJ055AD@1eMGD0AdM709:BTP1jNWX0/K6a05eMG@1[Jf/0PX:208F5Q@1cLg<0PH61
07moO`1`L700N7Qh069RHP1UIFD0R8R807MgM`1mOGd0PH6106m_K`1/K6`0OWin071`L01iNGT0MWIf
07]kN`1dM7@0Ng]k0080N7Qh0P1kNg/307QhN00507AdM01hN7P0N7Qh07QhN01kNg/07P3oool01`1f
MWH0NGUi07AdM01fMWH0NGUi07IfMP1dM7@00P1hN7P207AdM00;07IfMP1hN7P0NWYj07MgM`1fMWH0
Lg=c07IfMP1gMgL0Ogmo08:2PP1lO7`00P2;Rh/0301jNWX0PH6108B4Q01cLg<0Ng]k071`L01_Kfl0
>CTi02l_;`1fMWH0LW9b07YjNP80MWIf00D0O7al0820P01mOGd0Ng]k07inOP0207YjNP0607QhN01d
M7@0Ng]k07IfMP1cLg<0Ng]k0P1fMWH0201mOGd0MgMg07]kN`1iNGT0Ng]k07alO023Ph<0SXj>0P22
PX807P23Ph<0KVi^05mOG`1@D500S8b<04m?C`2>SXh0KVi^08b<S01/K6`0KVi^07YjNP20P800IfMW
07YjNP1oOgl0JFUY07IfMP1^KVh0KFe]07AdM01cLg<0NWYj07EeM@1VIVH0JFUY07emO@1/K6`0NGUi
07AdM080MGEe0P1hN7P00`1fMWH0M7Ad07YjNP0207AdM00307UiN@1eMGD0MWIf0080MWIf00<0N7Qh
0?ooo`3oool0703oool01`2<S8`0Shn?08V9R@2<S8`0Shn?08b<S029RHT00P2:RXX208V9R@0508b<
S02:RXX0SXj>08b<S02:RXX00P27QhL0602ATI40TY:B096AT@2@T900V9RH09JFUP2@T900S8b<09>C
T`2ATI40Ti>C08R8R01nOWh08b<S02PX:027QhL0R8R808j>SP2<S8`0SXj>09FEU@2JVYX0UiNG09ZJ
VP<0X:2P0100W9bL09NGU`2FUYH0UIFE09:BTP2IVIT0SHf=08b<S02>SXh0S8b<08j>SP2;Rh/0TY:B
08n?S`24Q8@0Rh^;0P2FUYH09@2NWYh0VIVI08^;R`1nOWh0[Jf]08R8R02BTY80OWin06i^KP2IVIT0
SXj>08J6QP2<S8`0Ng]k08N7Q`2@T900PH6108b<S02HV9P0TY:B07MgM`28R8P0S8b<0820P01mOGd0
QXJ608j>SP25QHD0SXj>08Z:RP26QXH0SXj>08Z:RP2>SXh0S8b<08J6QP2>SXh00P29RHT00`2?Shl0
SXj>08b<S00208b<S00308Z:RP3oool0oooo0200oooo000P0?ooo`0307QhN01kNg/0N7Qh0080N7Qh
00D0M7Ad07QhN01hN7P0Ng]k07AdM00207QhN00D07AdM01hN7P0Ng]k07UiN@1lO7`0N7Qh07inOP23
Ph<0PH6107emO@23Ph<0R8R807alO01cLg<0OWin07IfMP2:RXX0MGEe07QhN01lO7`307QhN00707]k
N`1hN7P0HV9R0820P028R8P0XZ:R09BDU00207inOP0708^;R`28R8P0R8R808>3P`22PX80HV9R05AD
E002079bLP0R07QhN01nOWh0N7Qh08:2PP1lO7`0OWin0820P01oOgl0YZJV08J6QP1lO7`0Kfm_05AD
E01NGUh0T92@096AT@15ADD0QhN7061PH02EUID0QXJ607QhN01oOgl0M7Ad08B4Q01ZJVX0OWin06MW
I`1_Kfl0K6a/09FEU@1WIfL0K6a/071`L080Hf=S00D0MgMg07QhN01kNg/0Lg=c07alO00207QhN004
07AdM01kNg/0M7Ad07AdM0H0N7Qh00<0M7Ad07QhN03oool07@3oool00`1fMWH0NWYj07UiN@0207If
MP0:07EeM@1fMWH0MWIf07YjNP1cLg<0MWIf07UiN@1hN7P0MWIf07YjNP80MGEe00l0MWIf07emO@21
PH40NWYj08N7Q`2CTi<0SHf=0861P@1iNGT0R8R807IfMP22PX80KVi^03<c<`0m?Cd00`1gMgL0401h
N7P0Rh^;08J6QP2<S8`0MgMg075aL@1jNWX0MGEe06a/K01[Jf/0OGem07EeM@1dM7@0N7Qh06i^KP1Y
JFT207AdM00g07IfMP1lO7`0MgMg07alO01hN7P0OGem07alO01jNWX0SHf=08B4Q01nOWh0Lg=c05]K
F`21PH40NGUi08n?S`1DE5@0TI6A06EUI@26QXH0NGUi06QXJ028R8P0MWIf07AdM01]KFd0OGem06MW
I`1dM7@0JVYZ09FEU@1kNg/0OGem06m_K`1YJFT0GUiN06e]K@1dM7@0NWYj06i^KP1dM7@0NGUi07Ee
M@1cLg<0NWYj07=cL`1gMgL0MWIf07AdM01iNGT0MWIf07AdM01iNGT0Lg=c07UiN@0N0?ooo`0308b<
S02>SXh0Shn?0080S8b<01/0SXj>08b<S02<S8`0SXj>08^;R`2<S8`0Shn?09:BTP2<S8`0SXj>08R8
R025QHD0S8b<08n?S`2@T900R8R809jNWP2YZJT0Vi^K09FEU@2DU9@0WinO08f=S@29RHT0Ph>302d]
;@0g=cL00`2=SHd0402:RXX0Z:RX0;Vi^@2RXZ80O7al05QHF01cLg<0Ph>307QhN01XJ6P0Q8B407Ui
N@1lO7`0Ph>309RHV02OWil208n?S`0I08b<S02>SXh0S8b<08R8R02:RXX0Shn?08Z:RP29RHT0Ng]k
096AT@2BTY80TI6A08Z:RP2g]kL0MWIf09BDU02ATI40XJ6Q08f=S@22PX80P82007QhN02NWYh0T92@
07]kN`0208j>SP0?08R8R02BTY80QhN709VIV@2UYJD0XJ6Q08V9R@2@T900P82007moO`29RHT0SXj>
08F5Q@24Q8@0Shn?0080Rh^;00/0SXj>08^;R`2ATI40S8b<08V9R@2?Shl0S8b<08V9R@2?Shl0Rh^;
08n?S`0R0?ooo`00803oool00`1dM7@0N7Qh07QhN00307QhN00J07AdM01hN7P0N7Qh07QhN01dM7@0
N7Qh07UiN@1dM7@0N7Qh07=cL`1hN7P0O7al08:2PP1dM7@0LG5a07MgM`1hN7P0P82006][J`1hN7P0
O7al07inOP1WIfL0K6a/0451@@1kNg/207alO00407QhN01gMgL0UYJF07=cL`80N7Qh01<0De=C06UY
J@1YJFT0IFEU04];B`1MGEd0IFEU06MWI`2:RXX0O7al069RHP1bLW80M7Ad07MgM`1mOGd0OWin07em
O@1lO7`0OWin0080PH610240RHV90;2`/025QHD0RHV904];B`21PH40FUYJ09ZJVP1GEeL0PH6107Yj
NP2@T900YjNW071`L022PX80N7Qh07moO`1XJ6P0MgMg06m_K`1^KVh0HV9R09JFUP28R8P0N7Qh07Ee
M@1WIfL0DE5A07AdM01iNGT0N7Qh06i^KP1hN7P00P1kNg/0101hN7P0Ng]k07QhN01kNg/207QhN006
07]kN`1hN7P0N7Qh07]kN`1hN7P0Ng]k7P3oool00`1gMgL0MWIf07IfMP0307IfMP0607EeM@1iNGT0
MWIf07IfMP1gMgL0NGUi0P1gMgL0C01jNWX0LW9b07IfMP1lO7`0QhN70861P@29RHT0TY:B08V9R@26
QXH0NGUi0820P01hN7P0QhN707alO01ADE409BDU07QhN01fMWH0N7Qh07MgM`1iNGT0WIfM07UiN@1f
MWH0NGUi08N7Q`29RHT0MGEe07inOP1mOGd0Ng]k07inOP1YJFT0PH6107QhN01eMGD0Lg=c079bLP1f
MWH0NGUi07EeM@1lO7`0Ng]k07UiN@1jNWX0N7Qh07inOP2BTY80Lg=c08J6QP1MGEd0MWIf07AdM02J
VYX0F5QH07]kN`1bLW80LG5a08R8R01lO7`0PH6106MWI`25QHD0K6a/07IfMP1`L700Lg=c06IVIP2E
UID0O7al06a/K01fMWH0Jf][04m?C`1aLG4207UiN@0606a/K01fMWH0M7Ad07IfMP1dM7@0N7Qh0P1f
MWH0101dM7@0MWIf07QhN01dM7@207IfMP0307AdM01hN7P0oooo01d0oooo00<0TI6A08b<S02<S8`0
0`2<S8`01`2>SXh0Shn?08b<S02<S8`0TI6A08n?S`2<S8`00P2ATI4208b<S01K08n?S`2JVYX0WinO
0:f][@2d];@0YZJV09ZJVP2MWId0VYZJ08Z:RP2MWId0YZJV06=SH`1CDe<0Rh^;08N7Q`2:RXX0S8b<
092@T02RXZ80U9BD08b<S02@T900b/[:0;Jf]P2JVYX0Zj^[0<C4a02_[jl0Zj^[08^;R`28R8P0RXZ:
0:6QX@2=SHd0RHV908f=S@2:RXX0Q8B408n?S`2>SXh0RHV908N7Q`25QHD0Q8B407QhN01iNGT0Shn?
09RHV022PX80Z:RX09ZJVP24Q8@0R8R808B4Q01ZJVX0Lg=c09^KV`2?Shl0MgMg09VIV@2>SXh0SHf=
08^;R`2BTY80S8b<09NGU`23Ph<0OGem08j>SP2=SHd0OGem08V9R@2>SXh0Shn?08R8R02<S8`0QXJ6
08N7Q`29RHT0RXZ:08b<S027QhL0RHV908b<S02:RXX0RHV908b<S027QhL0RHV908Z:RP0R0?ooo`00
803oool01@1kNg/0N7Qh07QhN01kNg/0M7Ad00<0N7Qh00<0M7Ad07]kN`1hN7P00P1hN7P04@1kNg/0
NGUi07AdM01hN7P0NGUi08V9R@1nOWh0QhN707moO`23Ph<0MGEe06m_K`20P800KFe]07emO@1oOgl0
GEeM00D0N7Qh0180FEUI07alO01SHf<0Bd];05=CD`1[Jf/0GemO05MGE`1]KFd0IFEU05IFEP1MGEd0
B4Q804M7A`1GEeL0HF5Q03/k>`1NGUh307QhN00C07emO@22PX80N7Qh07inOP1mOGd0R8R80:VYZ@2@
T900Ng]k065QH@1OGel0CDe=0861P@2;Rh/0?clo08f=S@1IFET0Vi^K0;Bd]00208:2PP0F07UiN@1W
IfL0LW9b06a/K01PH600JVYZ092@T02BTY80NWYj08V9R@1]KFd0F5QH07IfMP1gMgL0Ng]k07AdM01a
LG40N7Qh07AdM01hN7P0M7Ad07]kN`L0N7Qh00<0M7Ad07QhN03oool07@3oool01@1fMWH0M7Ad07Ad
M01jNWX0MGEe0080MWIf00<0NGUi07=cL`1jNWX00P1fMWH0101dM7@0N7Qh07MgM`1bLW8207UiN@0>
08^;R`22PX80Shn?08B4Q029RHT0QHF506m_K`21PH40Ogmo08B4Q01eMGD0:2PX05=CD`1gMgL207Ui
N@0C07MgM`23Ph<0WIfM08V9R@20P800OWin08:2PP1mOGd0MWIf08V9R@22PX80N7Qh07UiN@1mOGd0
QHF508:2PP29RHT0JFUY06][J`0207IfMP0/07YjNP1iNGT0OGem07IfMP1iNGT0M7Ad08>3P`2FUYH0
Shn?08V9R@1MGEd0I6AT06=SH`1bLW80SXj>05EEE@2CTi<0I6AT08B4Q028R8P0K6a/08F5Q@1gMgL0
JVYZ07QhN01lO7`0J6QX06ATI022PX80Ogmo06e]K@1mOGd0I6AT05IFEP1fMWH0MgMg07AdM01cLg<0
M7Ad07UiN@1eMGD0NGUi07EeM@1hN7P507IfMP80NGUi00<0MGEe07IfMP3oool07@3oool00`27QhL0
RHV908V9R@0208j>SP80S8b<00<0Shn?08^;R`2>SXh00P2<S8`05029RHT0RXZ:08b<S02:RXX0Shn?
08j>SP2GUiL0UIFE09nOW`2GUiL0VYZJ0:BTY02;Rh/0TY:B0:FUY@2IVIT0Ph>303Ti>@1IFET0S8b<
0P2@T9003`2<S8`0_[jn0;jn_P2l_;`0b/[:0;jn_P2YZJT0[jn_0:j^[P2b/[80/K6a0;>c/`2[Zj/0
b<S80=GEe@020;no_`0B0;Zj^P2GUiL0S8b<08b<S02BTY80RHV908^;R`2<S8`0RHV908>3P`2<S8`0
Q8B409FEU@2SXj<0P82008b<S02NWYh0Ng]k0P2IVIT01P2OWil0Ti>C07YjNP1UIFD0LW9b09NGU`80
S8b<00D0U9BD0:6QX@2ATI40P82008:2PP0207alO00308>3P`1lO7`0P8200080SXj>00P0Q8B408^;
R`2@T900Shn?08j>SP2?Shl0SXj>08Z:RPD0S8b<0P2?Shl00`2>SXh0S8b<0?ooo`0Q0?ooo`00803o
ool307AdM080Ng]k00<0M7Ad07QhN01kNg/00P1hN7P00`1kNg/0N7Qh07QhN00207QhN00>07AdM01h
N7P0MWIf08>3P`24Q8@0Rh^;07MgM`1mOGd0N7Qh07MgM`1iNGT0QhN707alO027QhL207QhN00807Ad
M01lO7`0OGem07QhN02DU9@0/K6a0:^[Z`2EUID208R8R080PX:200X0UYJF08j>SP2BTY80RXZ:09fM
W@2=SHd0/K6a0;bl_02;Rh/0LW9b0P1hN7P0101jNWX0N7Qh08B4Q01nOWh207QhN00508N7Q`2IVIT0
]kNg08n?S`1MGEd00P1CDe<06P1ADE40ZJVY06][J`1ZJVX0Bd];06e]K@2CTi<0WYjN07]kN`1hN7P0
KVi^07IfMP21PH40EeMG06a/K01kNg/0TY:B06MWI`22PX80JFUY07=cL`1hN7P0Lg=c071`L01kNg/0
M7Ad0P1hN7P00`1kNg/0N7Qh07QhN00207QhN00707AdM01hN7P0N7Qh07QhN01kNg/0M7Ad07QhN00N
0?ooo`80MgMg00H0MGEe07QhN01hN7P0MGEe07IfMP1hN7P207IfMP0807QhN01dM7@0MWIf07UiN@1f
MWH0MGEe07YjNP1fMWH208J6QP1H09:BTP25QHD0T92@08R8R01gMgL0P82007inOP1^KVh0Ng]k0492
@P1iNGT0MWIf07MgM`1iNGT0MgMg06e]K@28R8P0Q8B406m_K`1aLG40OWin06m_K`1XJ6P0Ogmo07Mg
M`1ZJVX0K6a/07UiN@1BDU80IVIV06MWI`1HF5P0Hf=S07IfMP1iNGT0NWYj07EeM@1nOWh0NGUi07Mg
M`1fMWH0P82008V9R@2PX:00PH6106a/K01[Jf/0GEeM05mOG`2ATI40JVYZ07EeM@1HF5P0Lg=c0820
P02DU9@0OWin06][J`1/K6`0MWIf08:2PP1EEED0LW9b07EeM@2BTY80Jf][0820P01HF5P0H61P07Ui
N@1eMGD0LW9b07QhN01cLg<0MWIf07AdM01hN7P0M7Ad07UiN@1fMWH0NGUi07EeM@1fMWH0NGUi07If
MP1jNWX0Lg=c07IfMQh0oooo0P2ATI401P2>SXh0RXZ:08Z:RP2>SXh0S8b<08Z:RP80S8b<02l0RXZ:
08V9R@2<S8`0Shn?08b<S02>SXh0TI6A08f=S@2GUiL0UIFE09nOW`2RXZ80ZZZZ0:JVYP2=SHd0UiNG
08J6QP1lO7`0PH610451@@2@T900Shn?08R8R029RHT0S8b<065QH@1XJ6P0JFUY06=SH`1cLg<0QHF5
07QhN01]KFd0N7Qh07EeM@1OGel0JVYZ06MWI`11@D40>3Ph02h^;P1<C4`0N7Qh08b<S02@T900Shn?
08Z:RP0208V9R@80S8b<01l0RXZ:08>3P`24Q8@0Ph>309ZJVP2SXj<0T92@09>CT`1nOWh0RHV909RH
V02ATI40TY:B07emO@2>SXh0U9BD07alO028R8P0SHf=09:BTP20P800Ti>C08J6QP2GUiL0SHf=08j>
SP1bLW80LG5a092@T02>SXh0SHf=0080Rh^;00h0S8b<08V9R@2:RXX0RHV908n?S`2<S8`0Shn?08j>
SP2<S8`0Shn?08b<S02>SXh0Rh^;08b<S280oooo000P0?ooo`80Ng]k00D0M7Ad07QhN01hN7P0Ng]k
07QhN00207]kN`0307AdM01kNg/0N7Qh0080Ng]k00h0MWIf07]kN`1iNGT0MGEe08:2PP23Ph<0RHV9
07alO01mOGd0Rh^;07QhN01jNWX0LW9b07QhN0<0MgMg00<0N7Qh07EeM@1hN7P00P1lO7`0402LW9`0
[jn_0;Ng]`2l_;`0/k>c0;Ng]`2QXJ40/k>c0;Vi^@2d];@0/k>c0:f][@29RHT0R8R808B4Q01nOWh2
07QhN080O7al01H0MWIf07alO01nOWh0OWin07QhN01mOGd0Ti>C0:b/[02TY:@0QXJ605UIF@1JFUX0
ADE505iNGP2?Shl0CTi>0410@01BDU80KFe]0:ZZZP28R8P0PX:20P1YJFT02@21PH40JFUY06m_K`1c
Lg<0VYZJ06e]K@1eMGD0B4Q8075aL@0207QhN004071`L01kNg/0Ng]k07AdM0<0N7Qh00H0Ng]k07Qh
N01hN7P0N7Qh07AdM01kNg/407QhN1h0oooo00@0MWIf07QhN01cLg<0NGUi0P1fMWH0401dM7@0NWYj
07YjNP1cLg<0N7Qh07AdM01hN7P0NGUi07AdM01hN7P0NGUi07EeM@26QXH0S8b<09JFUP2;Rh/208:2
PP80OGem00H0MGEe07QhN01bLW80NGUi07MgM`1eMGD307QhN00;06m_K`20P800LG5a06QXJ01]KFd0
I6AT06MWI`1TI6@0KVi^069RHP1VIVH00P1ZJVX01P1JFUX0LG5a07=cL`1dM7@0Lg=c07IfMP80N7Qh
02@0MWIf07alO01iNGT0NGUi07MgM`1lO7`0QXJ609VIV@2=SHd0PH6104];B`1[Jf/0Hf=S07IfMP2F
UYH0FEUI05eMG@1XJ6P0LW9b09nOW`1]KFd0NGUi07AdM01aLG40MGEe069RHP1mOGd0LW9b09JFUP1_
Kfl0Ph>304];B`1]KFd0MWIf07MgM`1]KFd207IfMP0607=cL`1fMWH0MWIf07IfMP1hN7P0NGUi0P1f
MWH01P1eMGD0N7Qh07AdM01fMWH0M7Ad07IfMQh0oooo00L0QhN708Z:RP2;Rh/0Shn?08b<S027QhL0
RHV90080SXj>00D0Rh^;08Z:RP29RHT0RXZ:08b<S00208Z:RP80SXj>02P0UiNG09nOW`2VYZH0Y:BT
09JFUP27QhL0UYJF09>CT`2?Shl0SXj>08N7Q`2ATI40SHf=08Z:RP2ATI40SXj>08^;R`1mOGd0Lg=c
04Y:BP0e=CD0=SHf038b<P0d=3@0ATI60451@@0Y:BT0=CDe03/k>`13@d<0DU9B07=cL`1kNg/0Ph>3
08J6QP2<S8`0RXZ:08V9R@2=SHd0T92@0P29RHT0202<S8`0Shn?08F5Q@25QHD0OGem08^;R`1`L700
W9bL0P2WYjL04`2OWil0Shn?0:>SX`2PX:00TY:B08n?S`1^KVh0QHF509RHV02DU9@0P82007inOP2N
WYh0RXZ:09BDU02=SHd0X:2P0820P026QXH00P2<S8`01026QXH0QhN708N7Q`2;Rh/308b<S00:08Z:
RP2?Shl0S8b<08b<S02>SXh0RXZ:08V9R@2<S8`0RHV908b<S280oooo000P0?ooo`0307QhN01dM7@0
M7Ad0080M7Ad0P1hN7P0101cLg<0Ng]k07QhN01kNg/207QhN00<07]kN`1iNGT0N7Qh07IfMP1nOWh0
P82007QhN01mOGd0NGUi08Z:RP1dM7@0O7al0P1hN7P0301lO7`0:b/[07QhN01dM7@0NGUi07QhN01j
NWX0M7Ad07IfMP1hN7P0M7Ad07QhN080M7Ad00d0O7al07QhN01gMgL0MgMg07QhN01kNg/0OGem07Ad
M01lO7`0M7Ad07QhN022PX80M7Ad0080N7Qh02L0OWin07alO01hN7P0NGUi08N7Q`1mOGd0RHV909NG
U`2/[:`0TY:B06YZJP1DE5@0HV9R04m?C`1hN7P0Rh^;06i^KP1ADE40G5aL075aL@24Q8@0PX:207=c
L`26QXH0Lg=c0861P@1QHF40IVIV08j>SP1gMgL0N7Qh04Y:BP1]KFd0N7Qh06MWI`1hN7P0M7Ad07Qh
N01dM7@00P1hN7P207]kN`0307QhN01dM7@0N7Qh0080N7Qh00@0M7Ad07QhN01hN7P0Ng]k7P3oool0
0`1fMWH0Lg=c07MgM`0207MgM`0:07IfMP1gMgL0MGEe07QhN01dM7@0NWYj07AdM01fMWH0NWYj07Mg
M`80MWIf00h0NGUi08b<S02DU9@0Ti>C07alO028R8P0MgMg07YjNP1/K6`0MWIf07QhN00J6QX0NGUi
07EeM@80MWIf00X0NWYj075aL@1bLW80MWIf07EeM@1iNGT0MGEe07IfMP1oOgl0MWIf0P1gMgL207Ad
M00a07QhN01bLW80NWYj06m_K`1fMWH0NWYj07EeM@1kNg/0NGUi07YjNP1kNg/0NGUi07MgM`1mOGd0
MgMg08>3P`2;Rh/0UiNG07MgM`1fMWH0JFUY07alO01]KFd0R8R807inOP1mOGd0Hf=S06IVIP1dM7@0
TI6A0820P01cLg<0QhN706][J`1mOGd0GemO071`L02;Rh/0Ng]k07alO019BDT0LW9b07YjNP1YJFT0
MWIf07EeM@1fMWH0Lg=c07UiN@0307IfMP0607UiN@1eMGD0MWIf07IfMP1iNGT0MgMg0P1fMWH00`1h
N7P0oooo0?ooo`0L0?ooo`0308b<S02;Rh/0TI6A0080TI6A00T0S8b<08f=S@2?Shl0RXZ:08V9R@2>
SXh0RHV908b<S02>SXh00P2<S8`01P2=SHd0RHV90:6QX@2e]KD0[Zj^09>CT`80TY:B01<0S8b<07in
OP2<S8`0RXZ:05]KF`2?Shl0SXj>08Z:RP2<S8`0SXj>08V9R@28R8P0S8b<08j>SP2@T900SXj>092@
T02CTi<0S8b<0080SHf=02P0RHV908J6QP29RHT0RXZ:08f=S@25QHD0S8b<08N7Q`2=SHd0Ti>C092@
T02;Rh/0SXj>092@T02;Rh/0QHF508N7Q`2;Rh/0R8R808:2PP1aLG40VIVI09nOW`2[Zj/0ZZZZ0:FU
Y@22PX80X:2P09ZJVP2BTY80TI6A0:FUY@2?Shl0S8b<09BDU021PH40Rh^;08>3P`2FUYH0TI6A0P2D
U9@00`1lO7`0TY:B096AT@0208^;R`0508j>SP2<S8`0Rh^;08n?S`2<S8`00P27QhL01P2?Shl0SXj>
08b<S02<S8`0Shn?096AT@80S8b<00<0RXZ:0?ooo`3oool0803oool00200oooo00<0Ng]k07QhN01k
Ng/00`1hN7P01P1lO7`0N7Qh07QhN01hN7P0Ng]k07QhN0<0Ng]k00H0NGUi07QhN01fMWH0TI6A08N7
Q`25QHD207QhN00908:2PP1hN7P0J6QX07QhN01jNWX03Ph>07QhN01dM7@0MWIf0080Ng]k1@1hN7P0
501fMWH0NGUi07MgM`1hN7P0KVi^07QhN01_Kfl0LW9b07]kN`1cLg<0NGUi07=cL`1`L700NGUi08:2
PP26QXH0O7al07YjNP1nOWh0O7al0P1hN7P07P1mOGd0N7Qh08j>SP2NWYh0QHF50861P@1`L700MgMg
07]kN`1dM7@0Shn?069RHP1BDU80Fe]K05MGE`23Ph<0Ti>C071`L028R8P0H61P08b<S01ZJVX0HV9R
08F5Q@27QhL0JFUY06m_K`1]KFd0Ph>306i^KP@0N7Qh00P0Ng]k07QhN01dM7@0N7Qh07]kN`1dM7@0
N7Qh07AdM080Ng]k0`1hN7PN0?ooo`80MWIf00D0N7Qh07IfMP1dM7@0M7Ad07QhN00307IfMP0307Qh
N01dM7@0N7Qh0080N7Qh0180MgMg07IfMP25QHD0VIVI08f=S@25QHD0PX:207inOP23Ph<0NGUi075a
L@1eMGD0Ogmo018B4P1iNGT0Lg=c07EeM@1hN7P207IfMP0:07EeM@1fMWH0MWIf07QhN01fMWH0Ng]k
07UiN@1mOGd0Lg=c07emO@80M7Ad00/0Ng]k07AdM01fMWH0KVi^079bLP1gMgL0M7Ad07alO01eMGD0
NWYj07]kN`0207QhN00707]kN`1nOWh0OGem08N7Q`2EUID0Rh^;0861P@0206][J`0S075aL@1VIVH0
Q8B407]kN`1LG5`0Kfm_07AdM01fMWH0MgMg075aL@2<S8`0H61P07inOP1OGel0IVIV08F5Q@2;Rh/0
FUYJ05aLG01[Jf/0NWYj06MWI`1fMWH0M7Ad07IfMP1dM7@0N7Qh07IfMP1eMGD0MWIf07YjNP1cLg<0
NGUi07EeM@1hN7P0101fMWHN0?ooo`0408N7Q`2<S8`0RXZ:08b<S080RHV900H0RXZ:08^;R`2<S8`0
S8b<08Z:RP29RHT308Z:RP80S8b<01<0Xj>S0::RXP2LW9`0TY:B09bLW02GUiL0Ti>C092@T02EUID0
RXZ:09JFUP1^KVh0Shn?08^;R`2<S8`0RXZ:08N7Q`2<S8`0Rh^;0080S8b<00P0SXj>08f=S@2ATI40
TI6A09JFUP2ATI40UIFE096AT@80Shn?03T0SHf=08Z:RP26QXH0Shn?08^;R`1nOWh0QHF508J6QP2?
Shl0SHf=08Z:RP2>SXh0TY:B096AT@2DU9@0SHf=08n?S`2KVi/0T92@08B4Q01nOWh0PH6107UiN@27
QhL0ZZZZ08n?S`2QXJ40Zj^[0820P01`L700S8b<09VIV@26QXH0PH6107UiN@2<S8`0TY:B09RHV01d
M7@0LG5a08R8R025QHD0PH6108b<S029RHT0S8b<08V9R@2:RXX0S8b<08j>SP2<S8`0SXj>08^;R`2?
Shl0SXj>08Z:RP27QhL00`2<S8`R0?ooo`00803oool0101hN7P0Ng]k07]kN`1kNg/307QhN00307]k
N`1dM7@0N7Qh00<0N7Qh0180M7Ad07QhN01kNg/0O7al08V9R@23Ph<0S8b<07QhN029RHT0OGem08:2
PP27QhL0MgMg07IfMP1hN7P0A4A407QhN01dM7@307QhN00507]kN`1hN7P0MWIf07QhN01iNGT00P1h
N7P0101^KVh0LG5a06=SH`1dM7@206e]K@0507AdM01eMGD0LW9b07=cL`20P8000P1hN7P207UiN@05
07QhN01lO7`0N7Qh07inOP1hN7P00P21PH407020P800UiNG0:6QX@22PX80GEeM06][J`1RHV80JFUY
079bLP1[Jf/0EUIF04e=C@1kNg/0LG5a06m_K`1hN7P0UIFE06ATI01^KVh0JFUY069RHP25QHD0U9BD
05EEE@1lO7`0GUiN07QhN01kNg/407QhN00507AdM01kNg/0N7Qh07QhN01kNg/00P1hN7P00`1dM7@0
N7Qh07QhN00307QhN1h0oooo00D0MWIf07QhN01hN7P0MWIf07AdM00207IfMP0307QhN01eMGD0MWIf
0080MWIf00D0NGUi07MgM`1fMWH0MWIf07alO00208n?S`0=096AT@1oOgl0PH6107]kN`22PX80OGem
06a/K01mOGd0G5aL028R8P1fMWH0LW9b07EeM@0207IfMP0C07EeM@1hN7P0MWIf07IfMP1gMgL0NGUi
0861P@1nOWh0PH61075aL@1oOgl0M7Ad07EeM@1hN7P0MWIf079bLP1eMGD0M7Ad075aL@0207alO00U
07MgM`1hN7P0O7al07IfMP1mOGd0MgMg07YjNP1mOGd0Q8B4092@T02?Shl0Kfm_06EUI@1iNGT0Jf][
07QhN01jNWX0KVi^075aL@1KFe/0Hf=S07MgM`21PH40KVi^08b<S01VIVH0MgMg06YZJP1PH600P820
08^;R`16ATH0O7al065QH@1`L700LG5a07AdM00207IfMP0;07UiN@1eMGD0N7Qh07AdM01fMWH0N7Qh
07IfMP1iNGT0Lg=c07IfMP1iNGT00`1fMWHN0?ooo`0508b<S02:RXX0RXZ:08N7Q`29RHT00P2<S8`0
0`2:RXX0SXj>08b<S00208b<S00D08n?S`2ATI40S8b<08N7Q`2@T900W9bL0:>SX`2LW9`0VIVI08R8
R02<S8`0Ti>C08F5Q@1nOWh0V9RH06MWI`1;Bd/0S8b<08V9R@2;Rh/208b<S00b08N7Q`2>SXh0SHf=
08b<S02;Rh/0T92@09^KV`2QXJ40Xj>S09^KV`2MWId0Ti>C09FEU@2BTY80SXj>08b<S02@T900P820
08B4Q02DU9@0Ti>C08^;R`2>SXh0T92@08b<S02?Shl0S8b<08N7Q`2<S8`0UYJF08j>SP23Ph<0MgMg
08n?S`2LW9`0Ti>C09fMW@2HV9P0SHf=0:VYZ@2CTi<0K6a/09FEU@2UYJD0P82008^;R`2:RXX0UiNG
08V9R@24Q8@208b<S00606e]K@2>SXh0RHV908>3P`21PH40RHV90P2<S8`02`2?Shl0SXj>08Z:RP29
RHT0S8b<08Z:RP2<S8`0Shn?08^;R`2<S8`0Shn?00<0S8b<8P3oool00200oooo0P1dM7@407QhN003
07AdM01hN7P0M7Ad0080N7Qh0140M7Ad07]kN`1kNg/0Lg=c07QhN01nOWh0U9BD07QhN01oOgl0MgMg
06YZJP1mOGd0N7Qh06e]K@1hN7P0Ph>303dm?@0207QhN00707AdM01hN7P0N7Qh07QhN01dM7@0NGUi
07EeM@0207QhN00>07emO@1iNGT0Ng]k08:2PP1/K6`0Lg=c06e]K@1_Kfl0LW9b075aL@1bLW80Lg=c
06m_K`1gMgL20820P00507UiN@1oOgl0OWin07alO01nOWh00P1hN7P03@1mOGd0R8R8096AT@2EUID0
MGEe055AD@1`L700HF5Q07emO@1MGEd0N7Qh08B4Q00a<C400P1XJ6P03@1aLG40N7Qh08N7Q`23Ph<0
KVi^06a/K01KFe/0OWin09:BTP1RHV80Ogmo06IVIP1NGUh0101hN7P00`1kNg/0M7Ad07QhN00307Qh
N080Ng]k0P1hN7P0101kNg/0N7Qh07QhN01hN7PN0?ooo`0307MgM`1eMGD0MWIf0080MWIf01X0NGUi
07EeM@1iNGT0Lg=c07IfMP1iNGT0MGEe07QhN01iNGT0LW9b07UiN@1kNg/0TY:B08b<S02@T900Ph>3
07]kN`25QHD0OGem07=cL`1fMWH0QHF5020P801GEeL0MGEe079bLP<0MWIf00<0MGEe07UiN@1dM7@0
0P1fMWH02@1lO7`0P82007QhN020P800LW9b07UiN@1dM7@0Lg=c07IfMP0207AdM00607EeM@1cLg<0
MgMg07YjNP1iNGT0LW9b0P1iNGT07P1hN7P0OGem07IfMP1gMgL0OWin07moO`2:RXX0Ti>C08Z:RP1S
Hf<0MgMg06=SH`27QhL0Hf=S06i^KP28R8P0=CDe0861P@1nOWh0GemO07IfMP1oOgl0NGUi06e]K@1c
Lg<0GUiN07YjNP1nOWh0EUIF07alO080IfMW101fMWH00`1jNWX0Lg=c07IfMP0307IfMP0507QhN01f
MWH0M7Ad07IfMP1jNWX00`1fMWHN0?ooo`03096AT@2>SXh0S8b<0080S8b<00P0Shn?08j>SP2?Shl0
Rh^;08b<S02?Shl0SXj>08Z:RP80S8b<0100Shn?08b<S02EUID0ZZZZ0:RXZ02OWil0XJ6Q09ZJVP2E
UID0TY:B08^;R`2EUID0Cdm?061PH02;Rh/0RHV90`2<S8`208j>SP<0S8b<01D0Shn?09RHV02;Rh/0
Shn?09:BTP2EUID0Ti>C096AT@2BTY80T92@08n?S`2>SXh0TI6A08f=S@29RHT0R8R808B4Q028R8P0
RHV908Z:RP2?Shl00P2<S8`0702BTY80QhN708f=S@2FUYH0Zj^[09VIV@2EUID0R8R809fMW@2=SHd0
P82009NGU`1kNg/0[:b/0:RXZ01bLW80S8b<08R8R023Ph<0RHV909FEU@28R8P0Rh^;07YjNP1fMWH0
S8b<08V9R@2@T90408b<S00308j>SP2;Rh/0S8b<00<0S8b<00D0RXZ:08N7Q`29RHT0S8b<08j>SP03
08b<S280oooo000P0?ooo`0307]kN`1hN7P0N7Qh0080N7Qh00<0Ng]k07QhN01hN7P01@1hN7P0501l
O7`0N7Qh07]kN`1kNg/0TY:B08:2PP1hN7P0NGUi07QhN01/K6`0Ph>307QhN01fMWH0N7Qh00`<301h
N7P0MGEe079bLP1hN7P0M7Ad0P1lO7`0401jNWX0N7Qh07AdM01kNg/0GUiN08J6QP23Ph<0RHV907]k
N`1=CDd0I6AT06m_K`1EEED0IVIV075aL@1bLW8307QhN0040820P01hN7P0O7al07YjNP<0OWin01`0
N7Qh0861P@20P800R8R809jNWP2PX:00GEeM05mOG`1NGUh0N7Qh065QH@1lO7`0OWin04e=C@1GEeL0
JVYZ069RHP2>SXh0Lg=c0861P@1LG5`0L71`069RHP1iNGT0N7Qh08Z:RP1LG5`0Ph>31@1hN7P00`1k
Ng/0N7Qh07QhN00707QhN00407]kN`1hN7P0N7Qh07AdM1h0oooo00<0MWIf07AdM01fMWH00P1fMWH0
7P1hN7P0MWIf07IfMP1dM7@0NGUi07IfMP1dM7@0MWIf07QhN01cLg<0N7Qh07alO02MWId0TI6A08N7
Q`20P800PH6107EeM@1nOWh0L71`0820P023Ph<02@T907MgM`1fMWH0LW9b07UiN@1bLW80MGEe07Qh
N080MgMg00l0Lg=c08b<S02;Rh/0MWIf07MgM`21PH40TI6A08:2PP1^KVh0QXJ6075aL@1`L700M7Ad
06i^KP1aLG400P1fMWH01@1jNWX0MWIf07]kN`1hN7P0Ng]k0080NGUi00L0MgMg07YjNP24Q8@0QXJ6
09:BTP2EUID0IfMW0080KFe]01@0Ogmo06=SH`21PH40MWIf05iNGP1fMWH0H61P06i^KP24Q8@0MWIf
08j>SP1/K6`0NWYj05aLG01iNGT0I6AT08B4Q01PH600R8R806IVIP@0MWIf00<0N7Qh07AdM01fMWH0
1`1fMWH0101hN7P0MWIf07UiN@1eMGDN0?ooo`0308N7Q`29RHT0S8b<0080S8b<00`0RXZ:08b<S02<
S8`0RHV908n?S`2<S8`0RHV908b<S02:RXX0R8R808Z:RP2@T9020:NWY`0Q0:BTY02HV9P0Vi^K09JF
UP2;Rh/0Ph>309^KV`2MWId0I6AT08f=S@2>SXh0S8b<08n?S`2:RXX0QXJ608Z:RP2;Rh/0SHf=08^;
R`2XZ:P0a/K607emO@22PX80RHV90:j^[P3:b/X0UIFE0:^[Z`2YZJT0UIFE08n?S`26QXH0Q8B40080
Rh^;00D0R8R808b<S02?Shl0Rh^;08f=S@0208V9R@0708b<S028R8P0UYJF096AT@2:RXX0S8b<09:B
TP0209VIV@0D09RHV028R8P0UYJF08F5Q@2GUiL0[jn_07]kN`2HV9P0R8R8092@T02SXj<0Vi^K09VI
V@1nOWh0SXj>079bLP2=SHd0Rh^;09ZJVP1eMGD408b<S00308Z:RP29RHT0S8b<00L0S8b<00@0RXZ:
08b<S02?Shl0SXj>8P3oool00200oooo101kNg/207QhN00507AdM01hN7P0N7Qh07AdM01kNg/00P1h
N7P0:P1cLg<0N7Qh07]kN`28R8P0Xj>S07QhN01cLg<0K6a/07MgM`26QXH0MgMg08J6QP1eMGD0Fe]K
0410@01fMWH0M7Ad071`L01kNg/0Ogmo07QhN01oOgl0NWYj07QhN01`L700OGem07QhN01nOWh0PH61
08F5Q@28R8P0OGem07EeM@1lO7`0SHf=07inOP1]KFd0Kfm_07QhN01jNWX0N7Qh0820P080N7Qh0`1n
OWh07`22PX80P82007inOP1lO7`0PH6108J6QP2h^;P0Lg=c05]KF`1cLg<0LW9b08>3P`2:RXX0LG5a
09fMW@0O7al0NWYj071`L02TY:@0KVi^08n?S`1hN7P0KVi^06MWI`1XJ6P0N7Qh08Z:RP1lO7`0G5aL
07]kN`1dM7@00`1hN7P0101kNg/0N7Qh07QhN01dM7@607QhN00407]kN`1dM7@0N7Qh07QhN1h0oooo
0P1fMWH01@1hN7P0MWIf07AdM01iNGT0MGEe0080MWIf01X0Lg=c07QhN01dM7@0MWIf07EeM@1fMWH0
N7Qh08R8R02ZZZX0PX:208R8R01oOgl0M7Ad07moO`1_Kfl0RXZ:07alO019BDT0;Bd]07EeM@1fMWH0
LW9b07QhN01gMgL0LW9b07YjNP80MgMg00L0LG5a07moO`1cLg<0MGEe07YjNP1lO7`0OGem0080MWIf
00`0O7al07inOP1^KVh0IVIV06a/K01eMGD0MgMg07IfMP1jNWX0MgMg07alO01jNWX207UiN@0G07em
O@20P800Ogmo07inOP23Ph<0PX:20;Bd]01eMGD0Fe]K06YZJP1[Jf/0QXJ608b<S01_Kfl0VIVI028R
8P26QXH0J6QX0:BTY01/K6`0RHV906i^KP1/K6`00P1UIFD01P1fMWH0PH6106YZJP1@D500NWYj07=c
L`<0MWIf00H0N7Qh07AdM01iNGT0MGEe07IfMP1dM7@407IfMP0407QhN01cLg<0MWIf07IfMQh0oooo
0P27QhL01@2:RXX0QhN708V9R@2?Shl0SXj>0080S8b<00`0Rh^;08Z:RP29RHT0S8b<08n?S`2<S8`0
RXZ:09BDU02WYjL0W9bL0:ZZZP2UYJD208Z:RP0F08:2PP2IVIT0UiNG06YZJP1OGel0S8b<092@T02=
SHd0Rh^;08B4Q025QHD0RHV908^;R`2=SHd0S8b<09:BTP28R8P0Ph>308N7Q`26QXH0Ph>308J6QP80
Shn?00/0PH6107UiN@21PH40QhN708Z:RP2;Rh/0S8b<08R8R02<S8`0Ti>C08Z:RP0208V9R@0;08^;
R`2@T900TI6A096AT@2DU9@0SXj>0:2PX02>SXh0Ph>30820P022PX800P2GUiL02P2:RXX0UIFE07=c
L`2PX:00Ogmo09jNWP28R8P0SXj>0820P028R8P208F5Q@0608b<S028R8P0MWIf07AdM02>SXh0Rh^;
0`2<S8`01P2:RXX0RHV908n?S`2>SXh0S8b<08V9R@@0S8b<00@0RXZ:08^;R`2<S8`0S8b<8P3oool0
0200oooo0`1hN7P00`1dM7@0N7Qh07QhN00207QhN00507]kN`1dM7@0N7Qh07QhN01cLg<00P1dM7@0
401hN7P0RHV90:FUY@1fMWH0T92@07moO`1eMGD0OGem07YjNP29RHT0MGEe04I6AP1hN7P0MWIf07]k
N`1iNGT207QhN00707MgM`1iNGT0O7al07QhN01^KVh0PH6107UiN@0207inOP0=07]kN`23Ph<0Ogmo
07IfMP1hN7P0O7al07QhN01bLW80Kfm_07EeM@1kNg/0N7Qh07YjNP020820P00507YjNP1nOWh0NWYj
08:2PP27QhL00P21PH406P22PX80PH610;:b/P1YJFT0FEUI06a/K01=CDd0T92@08Z:RP1VIVH0T92@
04m?C`1XJ6P0Hf=S09FEU@25QHD0OGem0861P@1]KFd0EeMG06MWI`1iNGT0M7Ad07YjNP1dM7@0Ng]k
101hN7P207AdM00307]kN`1hN7P0N7Qh00T0N7Qh7P3oool207IfMP0Q07UiN@1eMGD0NGUi07IfMP1d
M7@0NGUi07QhN01cLg<0MWIf07YjNP1eMGD0M7Ad07EeM@1iNGT0SHf=0;:b/P1iNGT0QHF5079bLP1e
MGD0NGUi075aL@2?Shl0LG5a01`L701CDe<0LG5a07=cL`1bLW80MWIf07MgM`1fMWH0N7Qh0080NWYj
03H0KVi^07YjNP1aLG40NGUi07emO@1iNGT0OWin07alO01hN7P0MgMg07]kN`1bLW80K6a/06i^KP1c
Lg<0NGUi07EeM@1gMgL0NWYj07UiN@1gMgL0Ng]k07MgM`1mOGd0O7al07inOP1oOgl0PH6108>3P`2X
Z:P0LG5a05IFEP21PH40GUiN08R8R02@T900L71`0820P016ATH0Lg=c069RHP2?Shl0O7al07UiN@1j
NWX0Lg=c05mOG`1UIFD0OWin071`L01QHF40Hf=S07QhN01dM7@307IfMP0407MgM`1eMGD0N7Qh07Ad
M0L0MWIf00<0M7Ad07IfMP1fMWH07P3oool208b<S00N08n?S`2>SXh0Shn?08b<S029RHT0Shn?08Z:
RP2;Rh/0S8b<096AT@2?Shl0SHf=08j>SP2?Shl0VYZJ0;2`/02BTY80QhN707inOP2=SHd0RXZ:08:2
PP2LW9`0QhN70451@@1IFET0QXJ608>3P`25QHD0Rh^;102=SHd04`2BTY80Rh^;08N7Q`24Q8@0RHV9
08n?S`2=SHd0S8b<08^;R`2?Shl0S8b<08j>SP26QXH0Q8B408V9R@2:RXX0SHf=08Z:RP2;Rh/00P28
R8P0202;Rh/0S8b<08^;R`2:RXX0Q8B408f=S@2?Shl0T92@0P2EUID0602DU9@0OWin0:RXZ02GUiL0
RXZ:09fMW@2EUID0Ogmo07=cL`2HV9P0QHF5092@T025QHD0RHV908N7Q`2BTY80SXj>08F5Q@2EUID0
R8R806][J`1dM7@0RXZ:08V9R@<0S8b<00@0TI6A08j>SP2:RXX0RHV91`2<S8`00`29RHT0S8b<08b<
S00R0?ooo`00803oool207QhN00307]kN`1hN7P0Ng]k00<0N7Qh00`0Ng]k07AdM01dM7@0O7al07Qh
N01kNg/0N7Qh07]kN`2<S8`0SHf=07emO@1VIVH2079bLP80MWIf0P1aLG4010000000MgMg07AdM01`
L70407QhN00307UiN@1oOgl0PX:20080M7Ad00T0LG5a07QhN01nOWh0OGem07inOP1hN7P0Lg=c07Qh
N01gMgL00P1fMWH0101hN7P0MGEe07alO01kNg/207QhN080P82001h0OGem07QhN01nOWh0P82008J6
QP21PH40PX:208^;R`2XZ:P0J6QX05MGE`22PX80KFe]07QhN02>SXh0LW9b075aL@1GEeL0HV9R065Q
H@23Ph<0YJFU06UYJ@1mOGd0KVi^06QXJ01bLW80Ph>305EEE@1OGel207QhN0<0M7Ad00<0N7Qh07]k
N`1dM7@0201hN7P0101dM7@0N7Qh07QhN01hN7PN0?ooo`80MWIf00@0N7Qh07AdM01hN7P0M7Ad0P1i
NGT0101jNWX0MGEe07EeM@1hN7P207IfMP0507AdM01kNg/0YZJV0:n_[`28R8P00P1lO7`02`1eMGD0
M7Ad07MgM`1oOgl0N7Qh00H61P1dM7@0LW9b075aL@1fMWH0MgMg0080MWIf00H0MgMg07UiN@1hN7P0
LG5a07YjNP1eMGD207]kN`0;07YjNP22PX80PH6107AdM01jNWX0MWIf06m_K`1/K6`0L71`07=cL`1f
MWH00P1hN7P01@1gMgL0NWYj07UiN@1lO7`0MgMg0080NWYj01`0PX:20820P01nOWh0P82009:BTP1W
IfL0GemO075aL@1NGUh0Ng]k08n?S`1^KVh0NGUi061PH01VIVH0JVYZ071`L02JVYX0LG5a08F5Q@1_
Kfl0De=C06UYJ@2>SXh0H61P05eMG@1fMWH0NGUi0P1gMgL0101eMGD0MWIf07QhN01cLg<707IfMP03
07UiN@1eMGD0MWIf0080MWIf7P3oool208b<S00408Z:RP29RHT0RXZ:08V9R@80Shn?0`2>SXh04P2:
RXX0Rh^;08N7Q`29RHT0Shn?0;Zj^P36a/H0X:2P0:JVYP2IVIT0Shn?08^;R`2?Shl0X:2P09JFUP1/
K6`0RHV908Z:RP80S8b<01T0SHf=08b<S02;Rh/0S8b<08R8R024Q8@0RHV909FEU@2ATI40TY:B08b<
S02;Rh/0UYJF09^KV`2>SXh0TY:B08b<S023Ph<0P82008B4Q02:RXX0R8R808Z:RP2>SXh0S8b<0080
R8R80200Shn?08b<S02;Rh/0R8R808b<S02@T900S8b<08F5Q@20P800QhN708j>SP1jNWX0MGEe09:B
TP2GUiL0QXJ609JFUP2?Shl0Rh^;09>CT`1hN7P0SXj>09BDU02KVi/0S8b<06][J`1nOWh0X:2P096A
T@22PX80S8b<08n?S`80TI6A00@0SXj>08b<S02:RXX0Rh^;1`2<S8`00`2?Shl0SXj>08b<S00208b<
S280oooo000P0?ooo`80M7Ad0`1hN7P00`1dM7@0Ng]k07]kN`0207]kN`0307QhN01dM7@0Ng]k0080
N7Qh00L0O7al0;>c/`2@T900QHF5075aL@24Q8@0NWYj0080N7Qh00D0MGEe07YjNP0?3`l0MGEe07Ui
N@0207MgM`0307QhN01gMgL0MgMg0080MgMg0P1lO7`02@1hN7P0Lg=c07UiN@1dM7@0N7Qh07emO@24
Q8@0N7Qh07emO@0307QhN00V07MgM`1dM7@0M7Ad07emO@1hN7P0Ng]k07QhN020P800OGem07inOP1j
NWX0OWin08f=S@29RHT0QXJ60820P02ATI40L71`06m_K`1FEUH0K6a/06YZJP1nOWh0QHF507moO`1Q
HF40K6a/071`L01]KFd0];Bd07QhN01lO7`0JVYZ04m?C`1UIFD0Ti>C07QhN01dM7@407]kN`80N7Qh
00<0Ng]k07QhN01hN7P00P1hN7P01P1dM7@0N7Qh07QhN01hN7P0Ng]k07AdM0<0N7Qh7P3oool207Mg
M`80MWIf00D0NGUi07EeM@1hN7P0MWIf07QhN00207IfMP0=07EeM@1jNWX0MWIf07IfMP1lO7`0^k^k
09NGU`2?Shl0J6QX07IfMP1bLW80MWIf096AT@0207=cL`040000001bLW80LW9b079bLP80MgMg00P0
MWIf07MgM`1gMgL0MWIf07QhN01jNWX0MgMg07EeM@80Ng]k00T0P82007moO`20P800Lg=c07QhN01_
Kfl0K6a/071`L01fMWH00P1dM7@01@1lO7`0MGEe07QhN01fMWH0Ogmo0080NGUi01`0MgMg07emO@22
PX80OWin0820P01oOgl0SHf=06ATI01ZJVX0I6AT07UiN@1bLW80N7Qh07MgM`1iNGT0EeMG06IVIP1]
KFd0IFEU0:^[Z`1fMWH0PH6106e]K@1MGEd0KFe]07moO`1BDU80Hf=S0P1hN7P207IfMP0407AdM01f
MWH0N7Qh07AdM0<0MWIf00H0MGEe07IfMP1fMWH0MWIf07YjNP1eMGD307IfMQh0oooo0P2ATI4208b<
S00708n?S`2>SXh0RXZ:08N7Q`2:RXX0QhN708b<S00208j>SP80S8b<00@0Shn?0:j^[P2PX:00XJ6Q
0P1oOgl02P24Q8@0S8b<0;:b/P2;Rh/0Q8B405ADE028R8P0QHF508N7Q`2>SXh208f=S@80SXj>0100
SHf=08Z:RP2=SHd0SHf=08j>SP2BTY80UYJF09VIV@2CTi<0SHf=08R8R029RHT0PH6107emO@23Ph<0
SHf=0P2<S8`01@2>SXh0RXZ:08^;R`2<S8`0Shn?0080RHV901`0Rh^;08j>SP26QXH0Ph>308Z:RP2?
Shl0TI6A07YjNP24Q8@0UIFE09bLW02DU9@0R8R80820P028R8P0MgMg0820P028R8P0Ogmo09JFUP2<
S8`0UYJF08j>SP2CTi<0TY:B07]kN`1IFET0M7Ad0P2:RXX208N7Q`0408V9R@2<S8`0RXZ:08V9R@<0
S8b<00@0SXj>08b<S02<S8`0S8b<0P2>SXh308b<S280oooo000P0?ooo`80Ng]k2`1hN7P207AdM00>
07UiN@30`<00T92@08>3P`1aLG40O7al07AdM01hN7P0X:2P07EeM@1^KVh0I6AT07IfMP1bLW8407Qh
N080OGem01<0MgMg07QhN01oOgl0OGem07]kN`1oOgl0PH610820P01iNGT0OGem07MgM`1mOGd0N7Qh
075aL@1hN7P0O7al07QhN01dM7@0PH610080NWYj00<0N7Qh0820P01hN7P00P1lO7`207inOP0H08N7
Q`26QXH0OWin08^;R`1_Kfl0HF5Q06YZJP1PH600N7Qh06ATI01oOgl0QHF505]KF`1TI6@0O7al069R
HP2_[jl0MgMg096AT@1RHV80DU9B07=cL`1jNWX0GemO401hN7P207]kN`80N7Qh00<0M7Ad0?ooo`3o
ool0703oool307IfMP0307UiN@1fMWH0M7Ad00<0MWIf00@0NGUi07IfMP1fMWH0MWIf0P1gMgL03P1i
NGT0_kno09>CT`1lO7`0J6QX07emO@1gMgL0MWIf09JFUP1eMGD0<c<c02PX:01cLg<0LW9b0`1fMWH0
7@1cLg<0MGEe07EeM@1eMGD0MWIf07UiN@1fMWH0NWYj07UiN@1lO7`0P82007alO01mOGd0LW9b07Ee
M@1`L700KFe]07AdM01hN7P0MGEe071`L01kNg/0MWIf07UiN@1fMWH0Ogmo07QhN01iNGT0NWYj0080
OGem01T0PX:208J6QP1nOWh0PX:207AdM01[Jf/0LG5a06IVIP1^KVh0Jf][07UiN@1kNg/0GEeM05mO
G`1_Kfl0HF5Q0;>c/`1^KVh0SHf=069RHP1?Cdl0IVIV07EeM@1KFe/0M7Ad00/0MWIf00D0M7Ad07If
MP1fMWH0MWIf07QhN00207IfMP0307UiN@1eMGD0oooo01d0oooo0P27QhL0102<S8`0Shn?08b<S029
RHT308b<S00408n?S`2<S8`0S8b<08b<S080TI6A00D0SXj>0:NWY`2KVi/0R8R807moO`02096AT@06
08b<S02=SHd0SXj>03Lg=`0c<c<0RHV9102<S8`00`27QhL0Q8B408B4Q00208b<S00F08R8R026QXH0
SXj>08R8R02:RXX0T92@09>CT`2?Shl0QhN708B4Q023Ph<0QXJ608R8R029RHT0Rh^;08N7Q`28R8P0
RHV908f=S@2<S8`0T92@08j>SP80S8b<01/0SXj>08n?S`2=SHd0Ti>C092@T027QhL0TY:B09BDU02C
Ti<0SXj>07moO`2@T900RHV908F5Q@27QhL0P82007emO@25QHD0YjNW08:2PP2BTY80QhN707alO01i
NGT0QhN70820P029RHT02`2<S8`02@29RHT0S8b<08b<S02<S8`0RXZ:08N7Q`2<S8`0Shn?08j>SP0R
0?ooo`00803oool207QhN00307AdM01hN7P0N7Qh00@0N7Qh0P1kNg/01@1dM7@0N7Qh07]kN`1hN7P0
UYJF0080N7Qh00/0GemO07YjNP1dM7@0MgMg09>CT`1oOgl061PH07=cL`1fMWH0MgMg07=cL`0207Qh
N00407emO@1hN7P0N7Qh07UiN@<0N7Qh0180MgMg07alO01hN7P0Ogmo08:2PP24Q8@0OWin07QhN01k
Ng/0N7Qh075aL@1eMGD0Lg=c07YjNP1iNGT0OWin07QhN01eMGD207alO00;07YjNP20P800O7al07in
OP22PX80N7Qh08n?S`29RHT0Ph>308b<S01hN7P00P1]KFd03`1/K6`0N7Qh07emO@20P800MgMg061P
H01hN7P0HV9R08j>SP28R8P0S8b<05MGE`1TI6@0GUiN06e]K@0:07QhN080Ng]k00<0N7Qh07]kN`1h
N7P01`1hN7PN0?ooo`0307IfMP1dM7@0Lg=c00L0MWIf01<0N7Qh07=cL`1fMWH0MWIf07AdM02m_Kd0
YjNW08F5Q@1TI6@0O7al07YjNP1fMWH0TI6A075aL@000000Kfm_07=cL`1aLG40MGEe0080Lg=c00@0
O7al07IfMP1fMWH0Lg=c0`1fMWH04P1eMGD0Ng]k07IfMP1iNGT0NWYj08:2PP1mOGd0M7Ad07EeM@1d
M7@0LG5a07=cL`1_Kfl0MgMg07=cL`1hN7P0MWIf07UiN@80N7Qh00<0MgMg07emO@1iNGT00P1mOGd0
1`1gMgL0S8b<08:2PP21PH40PX:2071`L01cLg<00P1]KFd02`1_Kfl0OGem071`L01MGEd0F5QH07Yj
NP1^KVh0UIFE08Z:RP2BTY80F5QH0080FUYJ00<0I6AT079bLP1fMWH01P1fMWH01P1dM7@0MWIf07Qh
N01fMWH0M7Ad07QhN080MWIf00<0M7Ad07IfMP1iNGT00`1fMWHN0?ooo`0308b<S029RHT0Rh^;00H0
S8b<01@0QhN708Z:RP2;Rh/0S8b<08N7Q`29RHT0clo?0=7Ad@2PX:00S8b<096AT@2EUID0SHf=09BD
U01lO7`0BDU908J6QP29RHT0QXJ6092@T080QhN700@0Shn?08b<S02;Rh/0QXJ6102<S8`0102?Shl0
S8b<08R8R027QhL208n?S`0;08R8R026QXH0R8R808b<S02:RXX0QXJ608^;R`26QXH0R8R808b<S02B
TY800P2:RXX07@2;Rh/0S8b<08^;R`2>SXh0Rh^;08b<S02BTY80RXZ:08n?S`27QhL0Ph>309:BTP2;
Rh/0S8b<0861P@2?Shl0Ng]k06UYJ@1jNWX0TI6A09RHV02OWil0UiNG09jNWP23Ph<0N7Qh07moO`1n
OWh0QXJ600L0S8b<00H0RHV908b<S02:RXX0QhN708V9R@2:RXX208b<S00308V9R@2<S8`0Shn?00<0
S8b<8P3oool00200oooo00<0N7Qh07AdM01hN7P01`1hN7P04P1kNg/0M7Ad07QhN01hN7P0M7Ad0=;B
dP2;Rh/0QHF506=SH`25QHD0Ogmo07EeM@2;Rh/0N7Qh04I6AP1iNGT0Lg=c07MgM`@0N7Qh00@0NGUi
07MgM`1cLg<0N7Qh0P1mOGd0301gMgL0O7al07QhN01gMgL0N7Qh08B4Q01nOWh0KVi^07MgM`1hN7P0
NGUi07AdM080LW9b00P0N7Qh07MgM`1hN7P0MGEe07UiN@1kNg/0N7Qh07inOP<0PX:200<0OGem08^;
R`28R8P00P28R8P2071`L00@06EUI@1`L700N7Qh07inOP1_Kfl0FUYJ07MgM`1hN7P0Kfm_08V9R@2S
Xj<0TI6A075aL@1KFe/0FUYJ075aL@/0N7Qh00@0M7Ad07QhN01hN7P0Ng]k0`1hN7P0101kNg/0N7Qh
07QhN01hN7PN0?ooo`0307IfMP1cLg<0M7Ad00D0MWIf01H0M7Ad07IfMP1jNWX0Lg=c07IfMP1iNGT0
MGEe0=7Ad@23Ph<0QHF505YJFP1mOGd0NGUi07QhN027QhL0MWIf01lO7`1dM7@0L71`07IfMP1gMgL0
Lg=c0P1jNWX02@1gMgL0MGEe07EeM@1cLg<0MGEe07UiN@1fMWH0N7Qh07MgM`0207]kN`0B08B4Q01m
OGd0LG5a07IfMP1bLW80Lg=c075aL@1dM7@0LW9b07MgM`1jNWX0Ng]k075aL@1gMgL0NWYj07MgM`1i
NGT0NWYj0P1nOWh0201iNGT0R8R808B4Q027QhL0R8R807QhN01dM7@0JFUY0P1fMWH02@1iNGT0Lg=c
05EEE@1ZJVX0MgMg071`L01mOGd0UIFE07moO`02061PH003051@D01YJFT0MWIf00T0MWIf00H0NGUi
07EeM@1iNGT0MWIf07QhN01dM7@207IfMP0407QhN01fMWH0MWIf07IfMQh0oooo00<0S8b<08^;R`29
RHT01@2<S8`02`29RHT0S8b<08j>SP2;Rh/0S8b<08n?S`2>SXh0[:b/08Z:RP2BTY80NWYj0080QhN7
00@0TI6A08n?S`2<S8`0A4A40P27QhL208f=S@0308N7Q`2BTY80TI6A0080S8b<00d0Shn?08N7Q`24
Q8@0RHV908f=S@2:RXX0SHf=09BDU02CTi<0TI6A08n?S`2>SXh0S8b<0080QXJ600@0R8R808j>SP2;
Rh/0SHf=0P2CTi<01P27QhL0S8b<08j>SP2<S8`0RHV908N7Q`80S8b<01L0RXZ:092@T02>SXh0TY:B
09BDU02GUiL0T92@08b<S02DU9@0S8b<08V9R@2ATI40OGem07alO02=SHd0S8b<08>3P`2:RXX0OWin
07AdM02:RXX0MWIf0820P00:08b<S00608n?S`2>SXh0Shn?08b<S02:RXX0RHV90P2<S8`0102:RXX0
S8b<08b<S02<S8`R0?ooo`00803oool01@1kNg/0N7Qh07AdM01hN7P0M7Ad00D0N7Qh0140Ng]k07Qh
N01hN7P0Ng]k07QhN03;bl/0PH6109FEU@1ZJVX0K6a/07inOP1oOgl0L71`08^;R`1fMWH0NGUi07=c
L`0207QhN003079bLP1hN7P0MgMg0080N7Qh00<0MgMg079bLP1bLW800`1hN7P01`1_Kfl0OWin07in
OP2<S8`0PX:206i^KP1cLg<00`1aLG401`1dM7@0Lg=c07=cL`1nOWh0NWYj07QhN01dM7@00`1hN7P0
6P1lO7`0PX:207inOP1mOGd0QhN7096AT@2?Shl0TI6A08F5Q@1cLg<0KFe]06YZJP1aLG40MgMg075a
L@0l?3`0PH6107QhN01cLg<0KFe]0:FUY@1YJFT0N7Qh05MGE`1>CTh0Lg=c2P1hN7P01@1kNg/0N7Qh
07]kN`1hN7P0M7Ad00L0N7Qh7P3oool01@1fMWH0M7Ad07EeM@1iNGT0MGEe0080MWIf01@0NGUi07If
MP1fMWH0N7Qh07AdM01fMWH0N7Qh07IfMP3@d=00O7al08Z:RP1]KFd0MWIf07alO026QXH0M7Ad079b
LP1BDU80MGEe079bLP80MWIf00<0N7Qh07YjNP1fMWH00P1fMWH0101iNGT0M7Ad07QhN01jNWX207If
MP0607AdM01iNGT0M7Ad08B4Q01mOGd0Kfm_0P1dM7@00`1eMGD0M7Ad07EeM@0207EeM@0307alO01b
LW80MGEe0080NGUi01`0MWIf07QhN01lO7`0NWYj07emO@1kNg/0P82008F5Q@23Ph<0QXJ607YjNP1`
L700Lg=c06a/K01eMGD0OWin07moO`0k>c/0NWYj07]kN`1fMWH0Kfm_0:f][@1^KVh0Lg=c05QHF01;
Bd/0L71`2P1fMWH01@1hN7P0M7Ad07QhN01iNGT0MGEe00L0MWIf7P3oool01@27QhL0RHV908j>SP2?
Shl0SXj>0080S8b<01@0Shn?08b<S02<S8`0RXZ:08V9R@2<S8`0RXZ:08b<S02c/k<0Rh^;08R8R02>
SXh0V9RH08b<S02IVIT0T92@075aL@1JFUX0RHV908^;R`80S8b<00<0UIFE09:BTP2=SHd00P2<S8`0
102BTY80Shn?09FEU@2BTY8208^;R`0:09:BTP29RHT0PX:208V9R@2;Rh/0S8b<08j>SP2@T900TI6A
08n?S`<0SXj>00T0SHf=08B4Q02:RXX0Ti>C092@T02<S8`0SXj>092@T027QhL00P2>SXh05P29RHT0
QhN708F5Q@28R8P0PX:208R8R02BTY80SHf=096AT@2HV9P0WinO07MgM`27QhL0Ti>C096AT@2=SHd0
ZJVY08n?S`28R8P0Q8B407alO029RHT:08b<S00508Z:RP29RHT0RXZ:08n?S`2>SXh01`2<S8`R0?oo
o`00803oool207AdM00607QhN01kNg/0M7Ad07QhN01dM7@0Ng]k1@1hN7P03P1dM7@0Ng]k09nOW`1X
J6P0PX:208V9R@1gMgL0NGUi07moO`1^KVh0K6a/07alO01dM7@0NGUi0`1hN7P01P1mOGd0N7Qh07Mg
M`1iNGT0N7Qh06m_K`80Lg=c0P1hN7P0301eMGD0N7Qh07MgM`28R8P0QXJ6075aL@1]KFd0KVi^079b
LP1WIfL0LW9b07AdM080N7Qh01l0LW9b07QhN01fMWH0N7Qh07MgM`1iNGT0OWin07QhN01oOgl0PX:2
08>3P`27QhL0SXj>08Z:RP26QXH0Jf][07QhN01UIFD0Ogmo07inOP22PX80?Shn07EeM@1hN7P0NWYj
04M7A`2m_Kd0EUIF071`L01WIfL0Bd];00h0N7Qh00<0Ng]k07QhN01hN7P01P1hN7PN0?ooo`0807Mg
M`1eMGD0M7Ad07YjNP1cLg<0NGUi07EeM@1jNWX507IfMP0>07EeM@2IVIT0b<S807QhN029RHT0N7Qh
071`L023Ph<0Q8B406YZJP0e=CD0N7Qh079bLP1dM7@207IfMP0Q07=cL`1iNGT0MWIf07EeM@1jNWX0
O7al07IfMP1hN7P0M7Ad07IfMP1kNg/0L71`07IfMP1eMGD0Ph>30861P@1dM7@0MWIf07=cL`1kNg/0
L71`07=cL`1bLW80MWIf07UiN@1eMGD0OGem07IfMP1gMgL0MWIf07QhN01lO7`0MWIf0080NWYj01H0
PH6108:2PP28R8P0PX:208V9R@1_Kfl0MWIf06UYJ@1iNGT0O7al07MgM`0k>c/0PH6107IfMP2@T900
EEEE0<71`@1RHV80JFUY05eMG@16ATH0Lg=c301fMWH00`1iNGT0N7Qh07AdM00707IfMQh0oooo00H0
TI6A08j>SP29RHT0SXj>08^;R`2?Shl208j>SPD0S8b<00h0SXj>0;Vi^@3EeMD0WinO09^KV`1lO7`0
Q8B409bLW02HV9P0QHF503dm?@2:RXX0Rh^;08R8R080S8b<00D0QhN708V9R@2<S8`0S8b<092@T002
09BDU00509:BTP2>SXh0Rh^;09>CT`26QXH00P2<S8`05P2=SHd0S8b<092@T02GUiL0TY:B09RHV02D
U9@0SHf=08^;R`2<S8`0T92@08n?S`2EUID0SHf=08b<S02=SHd0S8b<08f=S@2<S8`0RHV908N7Q`2?
Shl208f=S@0308Z:RP2FUYH0Shn?0080S8b<00h0RHV908f=S@21PH40MWIf09fMW@2<S8`0[Zj^096A
T@2/[:`0U9BD08:2PP1iNGT0MgMg08R8R0`0S8b<00<0Shn?08Z:RP29RHT01`2<S8`R0?ooo`00803o
ool00`1kNg/0N7Qh07QhN00207QhN00307]kN`1dM7@0Ng]k00D0N7Qh00@0M7Ad0:ZZZP2>SXh0UYJF
0P2:RXX01`1bLW80R8R807AdM01lO7`0820P07UiN@1/K6`00P1hN7P01`1mOGd0LW9b07UiN@1hN7P0
LW9b07QhN01^KVh00P1cLg<03`1^KVh0LW9b07moO`1eMGD0NGUi07MgM`22PX80QXJ607MgM`1aLG40
KVi^07MgM`1bLW80M7Ad07=cL`02075aL@0406e]K@1eMGD0MGEe07IfMP80N7Qh0P1lO7`05`22PX80
OGem08F5Q@27QhL0SXj>08J6QP2CTi<0Jf][06IVIP1]KFd0N7Qh07inOP1hN7P0BDU907emO@1bLW80
WIfM02PX:032`/80KVi^05EEE@1eMGD0FEUI00<0N7Qh00<0M7Ad07QhN01hN7P01`1hN7P00`1kNg/0
N7Qh07QhN00707QhN1h0oooo00P0MWIf07AdM01iNGT0MWIf07AdM01jNWX0Lg=c07QhN0D0MWIf02L0
Lg=c0;no_`2<S8`0Ng]k08V9R@26QXH0MWIf08^;R`1^KVh0Kfm_01TI6@1oOgl0KFe]07MgM`1cLg<0
NGUi07AdM01kNg/0NGUi07MgM`23Ph<0MgMg07EeM@1gMgL0Lg=c07EeM@1mOGd0Lg=c07MgM`1eMGD0
PH6108R8R01jNWX0M7Ad07=cL`1fMWH0Jf][07AdM01fMWH00P1kNg/00`1gMgL0NWYj07IfMP0207If
MP0J07QhN01iNGT0OGem07]kN`1lO7`0Ogmo0820P028R8P0Ph>3092@T01dM7@0L71`06a/K01jNWX0
NGUi07IfMP17AdL0Ng]k07=cL`2[Zj/0>SXj0;jn_P1YJFT0GEeM05mOG`1;Bd/207IfMP0307UiN@1e
MGD0MWIf00P0MWIf00<0NWYj07IfMP1fMWH01`1fMWHN0?ooo`0808N7Q`29RHT0Shn?08b<S029RHT0
SXj>08^;R`2:RXX508b<S00L08^;R`2n_[h0Ti>C079bLP2CTi<0Shn?096AT@2IVIT0QHF507emO@1U
IFD0UYJF08^;R`2=SHd0QhN708V9R@2>SXh0TI6A092@T02CTi<0WIfM09NGU`2?Shl0Ti>C096AT@2?
Shl0SXj>08Z:RP80S8b<00T0T92@09FEU@2ATI40T92@09:BTP2<S8`0PH6108f=S@2ATI400P2JVYX0
2P2HV9P0Ti>C08j>SP2>SXh0S8b<08j>SP2;Rh/0T92@08R8R02?Shl208Z:RP80SXj>0140Ti>C09NG
U`2EUID0R8R8096AT@29RHT0S8b<07YjNP2=SHd0SXj>0:n_[`2;Rh/0Xj>S08B4Q02=SHd0KVi^06m_
K`0208b<S00308n?S`2>SXh0S8b<00P0S8b<00<0SXj>08b<S02<S8`01`2<S8`R0?ooo`00803oool2
07QhN00907]kN`1hN7P0N7Qh07QhN01kNg/0N7Qh07AdM01kNg/0N7Qh0080Ng]k00h0N7Qh0?3`l01L
G5`0SXj>06MWI`1bLW80QhN707AdM01ZJVX0<30`07YjNP1RHV80LW9b07UiN@<0N7Qh0100M7Ad06MW
I`1BDU80CDe=075aL@1IFET0JFUY06MWI`1hN7P0OWin06m_K`1iNGT0N7Qh08Z:RP28R8P0Kfm_0P1`
L700201nOWh0JFUY07QhN01^KVh0K6a/06IVIP1JFUX0GUiN0P1YJFT0701VIVH0MgMg07QhN01_Kfl0
N7Qh07emO@23Ph<0Q8B408R8R01oOgl0Q8B409fMW@22PX80L71`079bLP1VIVH0PX:204m?C`1UIFD0
PH6109^KV`0c<c<0/K6a0820P016ATH0E5AD06=SH`1mOGd507QhN00307]kN`1hN7P0N7Qh00L0N7Qh
00<0Ng]k07QhN01hN7P0101hN7PN0?ooo`80MWIf00T0N7Qh07AdM01fMWH0MWIf07QhN01dM7@0MGEe
07YjNP1dM7@00P1fMWH03P1cLg<0hN7Q05QHF02LW9`0L71`079bLP2GUiL0L71`061PH00/;2`0Q8B4
069RHP1^KVh0N7Qh0P1fMWH0301mOGd0PX:208Z:RP25QHD0MWIf08>3P`1[Jf/0MgMg06a/K01dM7@0
O7al06e]K@80MWIf00`0Q8B408:2PP1fMWH0NGUi06YZJP1fMWH0JFUY07inOP1oOgl0Ph>308F5Q@1n
OWh307IfMP0406YZJP1fMWH0OGem07UiN@80OGem01H0Ogmo0861P@23Ph<0QHF50820P028R8P0KVi^
079bLP1iNGT0KFe]08:2PP1@D500Lg=c08Z:RP2JVYX0:BTY0;Vi^@27QhL0@41005MGE`1MGEd0NGUi
1@1fMWH00`1hN7P0M7Ad07IfMP0707IfMP0307QhN01dM7@0MWIf00@0MWIf7P3oool208b<S00608Z:
RP29RHT0S8b<08b<S02:RXX0RHV90P2>SXh03P29RHT0QhN708N7Q`27QhL0Xj>S07inOP2YZJT0UIFE
08b<S02ZZZX0R8R807YjNP1_Kfl0W9bL0P27QhL03`2=SHd0S8b<08b<S02EUID0XJ6Q0;Vi^@38b<P0
^;Rh0:FUY@2LW9`0WIfM08n?S`28R8P0SHf=08R8R00408^;R`0;09FEU@2IVIT0PX:208F5Q@28R8P0
UiNG0::RXP2ZZZX0];Bd0;Jf]P2VYZH00P2KVi/208f=S@0J09FEU@2JVYX0UIFE08n?S`2=SHd0SXj>
08b<S02HV9P0SHf=07inOP1eMGD0SHf=09FEU@2BTY80TI6A0820P02KVi/0WIfM09VIV@1WIfL0[Jf]
09ZJVP1dM7@0QXJ607inOP29RHT508b<S00308Z:RP29RHT0S8b<00L0S8b<00<0RXZ:08V9R@2<S8`0
102<S8`R0?ooo`00803oool207AdM0<0N7Qh00D0M7Ad07QhN01dM7@0N7Qh07]kN`0307QhN00>079b
LP2JVYX0MgMg08f=S@1ZJVX0J6QX0:>SX`1OGel0PX:206a/K02ATI40GEeM079bLP1cLg<207QhN008
06][J`1HF5P0LW9b09:BTP1hN7P0AdM705IFEP1YJFT204i>CP0E07QhN01/K6`0N7Qh07QhN022PX80
R8R807YjNP1lO7`0FUYJ071`L00W9bL0ATI607YjNP2FUYH0KFe]051@D01PH600GemO05UIF@1@D500
J6QX0080MgMg01L0NGUi07QhN020P800P8200861P@29RHT0QHF508:2PP2ATI40LW9b07QhN01]KFd0
N7Qh06EUI@1bLW80QhN7092@T00_;bl0_Kfm08N7Q`1IFET0G5aL06QXJ00=07QhN00307AdM01hN7P0
N7Qh00L0N7Qh7P3oool02`1gMgL0MGEe07IfMP1fMWH0NGUi07EeM@1iNGT0MGEe07AdM01hN7P0M7Ad
0080MWIf00d0Vi^K0;jn_P1dM7@0UYJF075aL@1/K6`0W9bL059BDP1:BTX0?clo09JFUP1LG5`0M7Ad
0080MWIf00d0O7al09>CT`25QHD0M7Ad07MgM`2:RXX0PX:206IVIP1oOgl0M7Ad06UYJ@1iNGT0K6a/
0080MWIf02/0PH6108>3P`1eMGD0O7al06QXJ02TY:@0MgMg07moO`1^KVh0UiNG09>CT`1/K6`0MWIf
07emO@1eMGD0IfMW07MgM`1mOGd0MWIf07]kN`1jNWX0PH6108:2PP25QHD0OWin0861P@1eMGD0RHV9
07QhN01gMgL0KVi^079bLP1LG5`0KVi^08J6QP2CTi<0;Rh^0;Vi^@1bLW80@41004e=C@1SHf<0NWYj
00/0MWIf00<0NGUi07EeM@1fMWH0201fMWHN0?ooo`0;096AT@2>SXh0S8b<08b<S02?Shl0SXj>08n?
S`2>SXh0RHV908Z:RP29RHT00P2<S8`03037alL0cLg=08V9R@2RXZ80U9BD08f=S@2DU9@0Lg=c0492
@P1:BTX0WIfM08>3P`80Shn?00h0S8b<09BDU033`l<0`/;208n?S`1`L700Z:RX0=7Ad@2HV9P0YjNW
0;Jf]P2VYZH0T92@08Z:RP80S8b<01d0TI6A08f=S@27QhL0Shn?09RHV03EeMD0hn?S0<g=c@1nOWh0
VYZJ0<30`02XZ:P0Y:BT0;2`/02/[:`0X:2P09jNWP2FUYH0SHf=09:BTP2ATI40TY:B09>CT`2GUiL0
QHF508b<S020P800Rh^;09FEU@0208b<S00<08J6QP1kNg/0QXJ609:BTP2JVYX0Lg=c0:6QX@1fMWH0
H61P06m_K`21PH40TY:B2`2<S8`00`2?Shl0SXj>08b<S00808b<S280oooo000P0?ooo`0707]kN`1h
N7P0N7Qh07QhN01kNg/0N7Qh07]kN`0307QhN00507AdM01hN7P0N7Qh0;Bd]020P8000P2EUID06022
PX80L71`09VIV@1KFe/03`l?08>3P`27QhL0Hf=S07QhN01iNGT0Lg=c07EeM@1hN7P0MgMg07moO`2E
UID0OWin07AdM01JFUX0IfMW07inOP1BDU80JFUY06e]K@80N7Qh01d0O7al08:2PP1iNGT0N7Qh061P
H02OWil0VIVI055AD@2<S8`0LG5a08^;R`1VIVH0OWin08n?S`1YJFT0BTY:05YJFP1aLG40L71`07em
O@1hN7P0OWin08J6QP24Q8@0Ph>307moO`1`L700OWin06=SH`0207QhN00:05YJFP1UIFD0KVi^0861
P@2ATI40?Cdm0:f][@1MGEd0IfMW059BDP/0N7Qh00<0M7Ad07QhN01kNg/02P1hN7PN0?ooo`0;07If
MP1dM7@0MWIf07IfMP1hN7P0M7Ad07QhN01dM7@0MWIf07UiN@1eMGD00P1fMWH0>P2n_[h0NWYj08J6
QP29RHT0QXJ606UYJ@2FUYH0L71`01`L701nOWh0PX:205eMG@1cLg<0MgMg07alO024Q8@0RHV905eM
G@1IFET0XZ:R09ZJVP1mOGd0KVi^071`L01iNGT0FUYJ07alO01[Jf/0MWIf07YjNP1oOgl0PH6107em
O@26QXH0LW9b08Z:RP23Ph<0@41009VIV@2LW9`0QhN705YJFP29RHT0Ph>307YjNP1UIFD0K6a/07Qh
N01dM7@0OGem07YjNP1mOGd0Q8B408F5Q@27QhL0PX:207moO`2KVi/207=cL`0<07inOP1TI6@0Hf=S
07=cL`2=SHd0RHV903Lg=`2o_kl0EeMG05ADE019BDT0L71`2@1fMWH0101iNGT0MGEe07IfMP1hN7P:
07IfMQh0oooo00/0QhN708V9R@2<S8`0S8b<08Z:RP29RHT0RXZ:08V9R@2<S8`0Shn?08j>SP0208b<
S0180;:b/P28R8P0PX:208N7Q`2GUiL0PX:209JFUP2QXJ40Ng]k08b<S02=SHd0OWin08N7Q`2<S8`0
V9RH0:>SX`2VYZH0JFUY05]KF`2[Zj/0]kNg09ZJVP2PX:00UIFE08V9R@2;Rh/0Y:BT08N7Q`2<S8`0
TY:B09>CT`2@T900U9BD0::RXP2NWYh0OWin07YjNP1XJ6P0YjNW0<S8b02?Shl0MgMg09nOW`25QHD0
XJ6Q0:FUY@2MWId0UYJF092@T02?Shl0TI6A08j>SP2@T900Ti>C09NGU`2EUID0XJ6Q0;Vi^@2NWYh0
QhN709NGU`2ATI40QHF509:BTP2RXZ80S8b<075aL@2j^[X0Ng]k06i^KP1dM7@0Ph>32@2<S8`0102?
Shl0SXj>08b<S02:RXX:08b<S280oooo000P0?ooo`T0N7Qh0240Ng]k07QhN01hN7P0N7Qh0<W9b@2a
/K40Ph>306e]K@2:RXX0L71`08j>SP2GUiL0:RXZ08V9R@1dM7@0HV9R06e]K@1gMgL0NGUi07IfMP1T
I6@061PH04];B`2ZZZX0QXJ60;Zj^P1]KFd0=cLg05iNGP1GEeL0I6AT075aL@1hN7P00P1mOGd04022
PX80TI6A08:2PP1hN7P0FEUI09nOW`1EEED0/K6a065QH@2a/K4092@T08:2PP2FUYH0Bd];051@D01H
F5P206ATI00F07QhN01lO7`0Kfm_08:2PP26QXH0P82007moO`2=SHd0QXJ6075aL@1BDU80Q8B405iN
GP1]KFd0JFUY08:2PP26QXH0AdM70;bl_015ADD0HF5Q05QHF0X0N7Qh00D0Ng]k07QhN01hN7P0N7Qh
07]kN`0907QhN1h0oooo1`1fMWH0101iNGT0MWIf07QhN01dM7@207IfMP0J09NGU`2>SXh0W9bL08F5
Q@2EUID0M7Ad08B4Q01_Kfl03@d=08b<S01oOgl0I6AT07=cL`1mOGd0QHF508b<S02EUID0Cdm?06YZ
JP2d];@0GEeM0;Jf]P29RHT0I6AT07MgM`1ZJVX206e]K@0[07IfMP1kNg/0Ng]k07moO`2:RXX0OWin
0820P01[Jf/0RHV905mOG`3?cll0CTi>0;Vi^@1EEED0TY:B0;Ng]`1fMWH0GemO06QXJ01hN7P0Kfm_
07YjNP21PH40NGUi08B4Q023Ph<0QHF507alO02BTY80R8R806][J`1XJ6P0Q8B405EEE@1`L700MgMg
0820P023Ph<0ATI60;jn_P16ATH0J6QX04];B`0:07IfMP0507QhN01dM7@0MWIf07IfMP1hN7P02@1f
MWHN0?ooo`L0S8b<00@0Shn?08b<S02:RXX0RHV90P2<S8`07@1TI6@0LG5a0;Jf]P2/[:`0Xj>S092@
T027QhL0H61P04Y:BP2IVIT0W9bL08V9R@2CTi<0UYJF09jNWP2][Jd0c<c<0;Zj^P2ZZZX0[Zj^05UI
F@2PX:00/[:b0;Jf]P2YZJT0WYjN09BDU026QXH0S8b<00@0SHf=01l0S8b<09ZJVP2LW9`0OGem092@
T03=cLd0JVYZ0:j^[P2f][H0Z:RX0<O7a`2k^k/0U9BD09VIV@2SXj<0UiNG09:BTP2GUiL0V9RH09FE
U@2?Shl0V9RH08^;R`2MWId0UiNG08>3P`2PX:00Ti>C07MgM`2>SXh0W9bL0080SXj>00D0O7al0:VY
Z@1mOGd0T92@075aL@0:08b<S00508Z:RP29RHT0S8b<08b<S02:RXX02@2<S8`R0?ooo`00803oool7
07QhN00307]kN`1hN7P0N7Qh00<0N7Qh00D0>3Ph0:JVYP2MWId0Ti>C092@T00307QhN00704A4A024
Q8@0N7Qh06QXJ01dM7@0O7al07emO@0208F5Q@0905=CD`0n?Sh0CTi>01DE5@2DU9@0TY:B06e]K@1`
L700N7Qh00<0M7Ad02X0O7al07emO@1oOgl0TY:B08f=S@2@T900MgMg06=SH`1kNg/0X:2P01dM7@2:
RXX0E5AD06ATI026QXH0O7al05YJFP1[Jf/0KFe]061PH01cLg<0PH6107MgM`1eMGD0OGem07inOP22
PX80UYJF09:BTP1hN7P0IFEU06e]K@1GEeL0M7Ad07EeM@1]KFd0QXJ6059BDP2l_;`0FUYJ06UYJ@1]
KFdB07QhN00307AdM01hN7P0N7Qh00<0N7Qh7P3oool707IfMP0307QhN01fMWH0MWIf00<0MWIf03X0
MgMg0;Jf]P2=SHd0PH610820P01fMWH0LG5a061PH00h>3P0TI6A07]kN`1UIFD0LW9b0861P@28R8P0
SHf=08>3P`1EEED0RHV90:VYZ@1`L700Zj^[08J6QP1HF5P0Hf=S069RHP1QHF40Lg=c07EeM@1kNg/0
O7al07emO@27QhL0OWin0820P01dM7@0O7al07emO@35aLD0J6QX0;Rh^01GEeL0OWin09fMW@1UIFD0
EeMG06e]K@1eMGD0K6a/07QhN023Ph<0OGem0820P02=SHd0NWYj07moO`2;Rh/0P8200P1WIfL02`1h
N7P0FUYJ07EeM@1hN7P0O7al0820P01:BTX0/[:b04i>CP1XJ6P0GUiN0140MWIf00<0NGUi07EeM@1f
MWH0101fMWHN0?ooo`L0S8b<00<0RXZ:08b<S02<S8`00`2<S8`0703AdM40]KFe08B4Q01nOWh0P820
08b<S025QHD0KFe]06YZJP2TY:@0TY:B08F5Q@29RHT0UiNG09nOW`2NWYh0Shn?08>3P`3Ti>@0oooo
0>_[j`2h^;P0QXJ606e]K@1iNGT0Kfm_079bLP2<S8`208j>SP0A08n?S`2=SHd0R8R80861P@1oOgl0
RHV90:ZZZP2BTY80dM7A0=OGe`3Fe]H0QHF50:^[Z`2d];@0L71`07moO`2<S8`00P2FUYH209BDU00D
09JFUP2MWId0YZJV08^;R`2>SXh0RHV907inOP1gMgL0RXZ:09VIV@27QhL0SXj>096AT@2OWil0RXZ:
07IfMP2HV9P0LW9b08N7Q`1dM7@A08b<S00308n?S`2>SXh0S8b<00@0S8b<8P3oool00200oooo0`1h
N7P01@1kNg/0N7Qh07QhN01hN7P0Ng]k00<0N7Qh02D0M7Ad07QhN02YZJT0K6a/08:2PP1hN7P0HF5Q
07QhN01XJ6P0HV9R05iNGP1aLG40MGEe065QH@1hN7P0OGem08:2PP2BTY80/k>c0<71`@36a/H0`L71
0;jn_P30`<00V9RH07=cL`1]KFd0JFUY07MgM`1dM7@0MgMg07]kN`22PX80OGem08>3P`22PX80MgMg
0080PX:20280Zj^[09:BTP2;Rh/0WIfM0;2`/02i^KT0WYjN08^;R`2ATI40Ti>C08V9R@1mOGd0PH61
07QhN01gMgL0RHV908n?S`22PX80N7Qh075aL@25QHD0KVi^08V9R@1hN7P0D51@06YZJP2;Rh/0O7al
07EeM@1WIfL0ZJVY06ATI01ZJVX0OGem5`1hN7P00`1dM7@0oooo0?ooo`0L0?ooo`<0MWIf00D0N7Qh
07AdM01fMWH0MWIf07QhN00207IfMP0Y07UiN@1eMGD0MWIf0861P@29RHT0X:2P08:2PP1^KVh0PX:2
061PH01CDe<0IfMW07alO01kNg/0Hf=S07AdM01eMGD0Lg=c07UiN@1eMGD0Kfm_06][J`1TI6@0HF5Q
05mOG`1/K6`0IfMW06e]K@1[Jf/0L71`07=cL`1gMgL0N7Qh07YjNP1fMWH0PH6108F5Q@1iNGT0P820
075aL@1jNWX00P1eMGD01P1hN7P0LW9b06ATI01IFET0HF5Q06m_K`80L71`01L0LG5a07inOP1kNg/0
Ng]k08>3P`2:RXX0OWin08:2PP20P800R8R806a/K01dM7@0LW9b05ADE01UIFD0QhN707inOP1/K6`0
H61P0:BTY01LG5`0CTi>07AdM00F07IfMP0307UiN@1eMGD0oooo01d0oooo0`2<S8`01@2:RXX0RHV9
08b<S02<S8`0RXZ:0080S8b<0300Shn?08j>SP2<S8`0IfMW0;>c/`2k^k/0WIfM09RHV02MWId0OGem
075aL@2ATI40Vi^K09JFUP2:RXX0RHV908B4Q01lO7`0M7Ad04Y:BP0e=CD0:RXZ02@T900S8b<07QhN
05]KF`1kNg/0RXZ:08^;R`23Ph<0S8b<08j>SP2;Rh/0QhN708J6QP2@T900UiNG096AT@2?Shl0NWYj
05]KF`1^KVh0MWIf06MWI`1:BTX0;Rh^03Xj>P1IFET206IVIP0=071`L01oOgl0SHf=09:BTP2DU9@0
S8b<08j>SP2<S8`0WIfM0:2PX02GUiL0R8R807MgM`0208J6QP0908:2PP2?Shl0TY:B07moO`1nOWh0
VIVI07alO01QHF40Ph>301H0S8b<00<0Shn?08j>SP3oool08@3oool00200oooo0P1hN7P0101dM7@0
N7Qh07QhN01dM7@707QhN00I0<S8b01KFe/0QHF506YZJP1]KFd0UIFE04e=C@1ADE40GUiN075aL@1j
NWX0HV9R07QhN01]KFd0M7Ad07emO@20P800R8R808b<S02>SXh0L71`05=CD`1FEUH0DU9B07alO002
07QhN00=07UiN@1mOGd0MgMg07alO01mOGd0SHf=08n?S`23Ph<0LG5a04e=C@1ADE40LW9b09JFUP02
09ZJVP0909:BTP28R8P0OWin07alO01nOWh0OGem07QhN01[Jf/0P8200080N7Qh00D0RHV907inOP29
RHT0RXZ:07]kN`0206i^KP0:06IVIP1NGUh0EEEE07moO`1lO7`0M7Ad06ATI02^[Zh0IFEU04a<C1L0
N7Qh00<0Ng]k07QhN03oool07@3oool207IfMP0407EeM@1fMWH0NGUi07EeM@<0MWIf0140NGUi07If
MP1dM7@0Lg=c0=kNgP20P800UiNG07QhN01gMgL0SHf=05YJFP1TI6@0JFUY07AdM01oOgl0GEeM07Yj
NP02075aL@0?07QhN01cLg<0MgMg07AdM024Q8@0QXJ608F5Q@2:RXX0GEeM06][J`1WIfL0L71`075a
L@1iNGT0MGEe0080NGUi02L0PX:20861P@24Q8@0SXj>07MgM`1oOgl0JFUY06][J`1/K6`0KFe]06i^
KP1eMGD0LG5a07AdM01jNWX0OGem07moO`1fMWH0Ogmo07alO021PH40QXJ60820P01mOGd0Q8B40820
P01cLg<0QHF506e]K@1MGEd0I6AT08V9R@1lO7`0L71`05aLG02TY:@0Fe]K0492@P1jNWX05P1fMWH0
0`1hN7P0M7Ad0?ooo`0M0?ooo`80S8b<00@0SXj>08b<S02?Shl0SXj>0`2<S8`04P2?Shl0S8b<08V9
R@27QhL0b/[:0;Rh^02[Zj/0WIfM09RHV02=SHd0TI6A09^KV`2DU9@0T92@09JFUP20P800TI6A092@
T080RHV90200Ogmo07]kN`1cLg<0QhN70:^[Z`38b<P0bl_;096AT@1gMgL0MWIf08:2PP23Ph<0RHV9
08b<S02;Rh/0RHV908J6QP23Ph<0U9BD0;Bd]02j^[X0`/;20820P01LG5`0F5QH05YJFP1UIFD0N7Qh
07emO@24Q8@0RXZ:08n?S`80VIVI01D0Shn?09FEU@2KVi/0Shn?09>CT`23Ph<0S8b<09NGU`2BTY80
Zj^[09:BTP23Ph<0V9RH09jNWP2?Shl0QXJ607]kN`2CTi<0NWYj071`L02BTY805P2<S8`00`2:RXX0
RHV90?ooo`0Q0?ooo`00803oool407QhN00307]kN`1hN7P0N7Qh0080N7Qh01@0Ng]k07QhN01hN7P0
LW9b0?Win@1OGel0RXZ:071`L01hN7P0TI6A06m_K`1]KFd0G5aL06IVIP1hN7P0EEEE07inOP1_Kfl0
IfMW06i^KP80MgMg0280LG5a05]KF`1/K6`0L71`09bLW021PH40OWin07AdM01hN7P0Lg=c07emO@1g
MgL0NGUi07alO023Ph<0S8b<0::RXP2[Zj/0Rh^;06QXJ00c<c<0?Shn069RHP1[Jf/0O7al08:2PP1i
NGT0O7al07QhN01iNGT0MgMg07QhN01gMgL0OGem0P1hN7P02@1nOWh0IFEU08:2PP1hN7P0OWin07Qh
N01lO7`0MWIf06m_K`0208:2PP05079bLP1EEED0W9bL075aL@16ATH06@1hN7PN0?ooo`80MWIf00@0
M7Ad07IfMP1hN7P0M7Ad0`1fMWH02`1hN7P0M7Ad07IfMP1kNg/0oooo06YZJP2BTY80Kfm_071`L02=
SHd0FUYJ0080IfMW00D0Lg=c07alO01KFe/0OGem07AdM00207=cL`0807IfMP1kNg/0VIVI09FEU@2?
Shl0OWin05eMG@1@D50206i^KP0407=cL`1bLW80O7al07EeM@80MgMg02H0OGem07]kN`26QXH0RHV9
08B4Q01oOgl0J6QX06][J`1fMWH0Lg=c07MgM`1lO7`0M7Ad07alO01mOGd0Q8B408^;R`1cLg<0OWin
08>3P`1oOgl0O7al08V9R@1kNg/0Shn?07EeM@1iNGT0Jf][05mOG`1VIVH0IFEU07emO@21PH40MGEe
05iNGP2GUiL0I6AT03dm?AT0MWIf7P3oool208b<S00408V9R@2<S8`0RXZ:08V9R@<0S8b<0240RXZ:
08V9R@2<S8`0VIVI0<C4a02DU9@0WinO08V9R@23Ph<0TI6A06i^KP22PX80U9BD09ZJVP2DU9@0RHV9
092@T02BTY80VYZJ096AT@2=SHd0U9BD0<C4a03Fe]H0^k^k0:2PX011@D40Bd];07YjNP25QHD0R8R8
08Z:RP2?Shl00P2<S8`04`29RHT0RXZ:07emO@1fMWH0L71`08^;R`2XZ:P0`<300;Vi^@2SXj<0U9BD
08R8R029RHT0QhN7092@T02FUYH0WYjN0:ZZZP28R8P00P2HV9P0302IVIT0Ti>C09nOW`2VYZH0Y:BT
08Z:RP29RHT0Ng]k06EUI@1gMgL0OGem08Z:RP80TI6A00@0Shn?09BDU01iNGT0L71`6@2<S8`R0?oo
o`00803oool:07QhN00J07AdM01hN7P0QhN70?ooo`1nOWh0QHF508:2PP1hN7P0Ogmo06ATI01[Jf/0
H61P05IFEP1/K6`0FEUI07YjNP23Ph<0DU9B04m?C`1CDe<0D51@06][J`1eMGD0VYZJ0;Vi^@22PX82
0861P@0407alO01hN7P0N7Qh07QhN0<0MgMg0280Ng]k07inOP2<S8`0YjNW0<K6aP30`<00RHV904i>
CP0i>CT0?3`l03Hf=P1FEUH0De=C05UIF@1FEUH0IFEU0820P01mOGd0PH6108N7Q`1oOgl0N7Qh08Z:
RP2KVi/0LG5a08F5Q@2;Rh/0Fe]K055AD@1`L700KFe]07]kN`23Ph<0N7Qh0P1^KVh00`1HF5P0G5aL
07QhN00=07QhN00307AdM01hN7P0N7Qh00P0N7Qh7P3oool907IfMP0;07UiN@1eMGD0Lg=c09fMW@3f
m_H0MGEe07alO01_Kfl0Ng]k07inOP1VIVH00P1eMGD09`1/K6`0MGEe05QHF01dM7@0TI6A07QhN01g
MgL0QhN709BDU02IVIT0JFUY05aLG01PH600HV9R071`L01dM7@0LW9b07=cL`1gMgL0NWYj07IfMP1g
MgL0MWIf07QhN01iNGT0NWYj07emO@20P800L71`07EeM@1bLW80NGUi08:2PP1oOgl0QXJ608:2PP2:
RXX0Ph>30820P00307YjNP0C08B4Q01nOWh0MWIf07IfMP2ATI40L71`06m_K`1iNGT0Jf][061PH01[
Jf/0KFe]07inOP21PH40KVi^07IfMP2?Shl0DU9B04E5A@0=07IfMP0307UiN@1eMGD0MWIf00T0MWIf
7P3oool908b<S01:08n?S`2>SXh0QhN70;:b/P2a/K40Ph>308J6QP1gMgL0Ti>C08j>SP29RHT0UiNG
0:>SX`2PX:00UiNG0861P@27QhL0YJFU0;Jf]P2g]kL0b/[:0>3Ph03:b/X0O7al0492@P0W9bL0I6AT
07UiN@1oOgl0PH6108R8R02=SHd0TY:B08f=S@2>SXh0SHf=08^;R`29RHT0Ng]k069RHP15ADD0=SHf
07QhN02b/[80dm?C0=cLg03Ogml0a/K60<?3``39bLT0`/;20:f][@28R8P0S8b<08N7Q`2>SXh0Shn?
08b<S01hN7P0S8b<08Z:RP1cLg<0Ng]k09ZJVP2FUYH0Q8B408V9R@2DU9@0Shn?0820P02EUID0^[Zj
07]kN`1TI6@=08b<S00308n?S`2>SXh0S8b<00T0S8b<8P3oool00200oooo2@1hN7P06P1kNg/0M7Ad
079bLP2ZZZX0SXj>07alO01hN7P0R8R8096AT@1gMgL0JFUY071`L01fMWH0IVIV06UYJ@1RHV80LW9b
0:2PX02JVYX0Shn?07emO@2>SXh0XJ6Q09bLW021PH40O7al1@1hN7P0101nOWh0N7Qh07QhN01mOGd3
07alO00T07]kN`1nOWh0R8R8096AT@2f][H0aLG50;>c/`2h^;P0SXj>06UYJ@1`L700N7Qh08Z:RP28
R8P0N7Qh0820P01oOgl0QhN707moO`1lO7`0IVIV08b<S01lO7`0LG5a071`L01]KFd0BDU9075aL@1c
Lg<0K6a/08R8R01`L700R8R807EeM@1=CDd0KVi^3@1hN7P00`1kNg/0N7Qh07QhN00907QhN1h0oooo
2@1fMWH02`1jNWX0Lg=c07AdM02a/K40d=3@07emO@1YJFT0N7Qh0820P01kNg/0KFe]0080M7Ad00h0
IfMW075aL@1KFe/0LG5a08J6QP1/K6`0NWYj07inOP1aLG40FUYJ05EEE@1NGUh0LW9b07=cL`@0MWIf
02/0OGem07IfMP1cLg<0MGEe07AdM01gMgL0MWIf07EeM@1iNGT0OGem07UiN@1bLW80K6a/05aLG01j
NWX0N7Qh07UiN@1kNg/0L71`06i^KP1`L700KVi^07QhN01mOGd0QhN707alO01cLg<0O7al08j>SP1[
Jf/0OGem08V9R@1gMgL0B4Q806a/K01lO7`0LG5a07emO@1/K6`0UIFE079bLP0a<C40HF5Q00d0MWIf
00<0N7Qh07AdM01iNGT02@1fMWHN0?ooo`T0S8b<01/0SXj>08^;R`2?Shl0ZJVY0?Cdm02ATI40NGUi
07alO01oOgl0U9BD08j>SP2@T900RXZ:08V9R@2EUID0OGem08^;R`1gMgL0F5QH07UiN@2BTY80KFe]
03Lg=`0f=SH0H61P0861P@28R8P0102<S8`00`2>SXh0S8b<08N7Q`0208B4Q00V08V9R@27QhL0QhN7
08V9R@25QHD0MGEe04A4A00[:b/09bLW04i>CP1fMWH0WinO09^KV`22PX80K6a/079bLP21PH40QHF5
08f=S@2BTY80S8b<08>3P`2VYZH0VIVI07QhN02LW9`0[Zj^09RHV01lO7`0QHF509VIV@2@T900Q8B4
08J6QP2VYZH0RXZ:05QHF01hN7P=08b<S00308Z:RP29RHT0Shn?00T0S8b<8P3oool00200oooo0P1h
N7P00`1dM7@0Ng]k07QhN00707QhN00>09RHV01aLG40O7al065QH@2>SXh0QXJ608B4Q01dM7@0MWIf
075aL@1TI6@0NWYj05aLG01eMGD207QhN007079bLP1iNGT0N7Qh07emO@1hN7P0LW9b07=cL`0207Qh
N00607=cL`1gMgL0N7Qh07emO@1cLg<0LW9b0P1hN7P0101mOGd0N7Qh07UiN@1hN7P307emO@80N7Qh
0100O7al07=cL`1hN7P0OWin07QhN01gMgL0O7al07=cL`1mOGd0R8R808N7Q`1dM7@0N7Qh08F5Q@2K
Vi/0Shn?0`25QHD02P0/;2`0Vi^K08f=S@17AdL0UIFE04Y:BP2VYZH0EEEE055AD@1mOGdI07QhN1h0
oooo0P1fMWH01@1eMGD0N7Qh07AdM01fMWH0NGUi00D0MWIf01l0WinO0861P@1gMgL0DE5A08J6QP25
QHD0NWYj06e]K@1gMgL0M7Ad06ATI01jNWX0Fe]K07=cL`1dM7@0MWIf075aL@1hN7P0Lg=c07EeM@1f
MWH0MgMg07EeM@1fMWH0NWYj07EeM@1fMWH0MgMg07alO01eMGD0M7Ad0080NWYj02H0NGUi07IfMP1f
MWH0MWIf07UiN@1jNWX0O7al07MgM`1hN7P0O7al075aL@1lO7`0OGem07]kN`1jNWX0O7al07EeM@1h
N7P0O7al0861P@1eMGD0N7Qh07alO027QhL0R8R807UiN@1gMgL0MGEe02<S8`2<S8`0PX:204Y:BP2D
U9@0D51@0:JVYP15ADD0?Shn07UiNAT0MWIf7P3oool208b<S00508j>SP2:RXX0RHV908b<S02?Shl0
1@2<S8`06P2TY:@0Xj>S08R8R01_Kfl0RXZ:09:BTP24Q8@0Ph>308n?S`2@T900QhN708j>SP23Ph<0
RXZ:08V9R@2<S8`0RXZ:08f=S@27QhL0Q8B408b<S02DU9@0Shn?08b<S02ATI40Shn?0P2=SHd00`2>
SXh0Shn?08n?S`0209:BTP0=08V9R@2;Rh/0Rh^;08^;R`29RHT0Rh^;08j>SP2<S8`0SXj>092@T029
RHT0U9BD08n?S`0209:BTP80Shn?00<0R8R808>3P`2;Rh/00P2>SXh01`25QHD0OGem08b<S021PH40
Ogmo07emO@1WIfL00P25QHD01`21PH40V9RH08J6QP2NWYh0Jf][06EUI@29RHT06@2<S8`R0?ooo`00
803oool607QhN00307]kN`1hN7P0N7Qh00<0N7Qh01T0Y:BT07]kN`22PX80GEeM07emO@22PX80P820
07QhN01cLg<0LG5a05]KF`1dM7@0Cdm?06e]K@1dM7@0MgMg079bLP1iNGT0Lg=c079bLP1mOGd0O7al
07=cL`1hN7P0O7al00<0N7Qh00<0O7al07emO@1hN7P00P1mOGd00`1hN7P0MgMg07MgM`0207AdM009
07]kN`1mOGd0N7Qh07UiN@1lO7`0N7Qh07]kN`1mOGd0OWin0080OGem00T0O7al07moO`1oOgl0Ogmo
07QhN01mOGd0N7Qh07alO01nOWh00P25QHD02P1^KVh08b<S08^;R`2>SXh0Fe]K09FEU@12@T80UIFE
0410@01^KVhJ07QhN1h0oooo0P1fMWH01P1dM7@0MWIf07IfMP1fMWH0N7Qh07AdM0@0MWIf00L0VIVI
06][J`1bLW80HF5Q08Z:RP1lO7`0NWYj0080N7Qh0140MgMg06ATI01iNGT0FUYJ075aL@1eMGD0MWIf
07AdM01gMgL0MGEe07AdM01iNGT0N7Qh079bLP1fMWH0N7Qh07=cL`0207IfMP0807QhN01fMWH0Lg=c
07UiN@1eMGD0NWYj07IfMP1iNGT207QhN00907YjNP1lO7`0MgMg07QhN01gMgL0MWIf07QhN01lO7`0
NGUi00@0N7Qh01@0Q8B408>3P`1bLW80Ng]k07moO`2DU9@0OGem07QhN024Q8@0Ng]k024Q8@29RHT0
QHF504a<C02>SXh0D51@0:2PX00V9RH0FUYJ07YjNQT0MWIf7P3oool208b<S00608V9R@2<S8`0S8b<
08b<S02:RXX0RHV9102<S8`01@2>SXh0NGUi07YjNP2:RXX0XZ:R0080R8R800/0SXj>09>CT`2DU9@0
TI6A09BDU02?Shl0T92@08j>SP2=SHd0Shn?08b<S00208n?S`80RHV900@0RXZ:08b<S02:RXX0R8R8
0P2<S8`0202:RXX0QHF508N7Q`29RHT0Q8B409:BTP2=SHd0TI6A0P2BTY80202>SXh0Shn?08f=S@2=
SHd0R8R808b<S02;Rh/0Shn?0`29RHT05P2:RXX0QXJ609NGU`2GUiL0QHF508f=S@2IVIT0/K6a08n?
S`20P800TY:B09fMW@1]KFd0TY:B08Z:RP1_Kfl0Shn?08j>SP2XZ:P0EUIF06i^KP2BTY8I08b<S280
oooo000P0?ooo`D0N7Qh00<0M7Ad07QhN01hN7P0101hN7P03@2CTi<0M7Ad06e]K@1RHV80KFe]079b
LP1cLg<0O7al07QhN01lO7`0IVIV07inOP1KFe/00P1]KFd0101gMgL0N7Qh07QhN01iNGT2079bLP04
07alO01hN7P0N7Qh07QhN080Lg=c101hN7P2079bLP80N7Qh00<0M7Ad07QhN01hN7P00`1hN7P0701i
NGT0Kfm_07QhN01lO7`0OWin07QhN01mOGd0NGUi07alO01hN7P0PH6108N7Q`1hN7P0Ng]k07moO`29
RHT0MGEe08F5Q@1nOWh0LG5a02l_;`1aLG40WIfM06EUI@2EUID0GemO079bLP1:BTXA07QhN00307Ad
M01hN7P0N7Qh00L0N7Qh7P3oool407IfMP0307UiN@1eMGD0MWIf00D0MWIf01<0Ph>307EeM@1lO7`0
MGEe07]kN`1dM7@0NGUi07]kN`1dM7@0N7Qh05iNGP1`L700EeMG079bLP1aLG40MWIf07EeM@1fMWH0
N7Qh0080M7Ad00H0N7Qh07=cL`1fMWH0NWYj07QhN01eMGD307IfMP0607YjNP1hN7P0N7Qh07IfMP1k
Ng/0MgMg0P1fMWH01@1hN7P0NWYj07MgM`1lO7`0MWIf0080Ng]k01T0OGem07IfMP1kNg/0N7Qh0861
P@20P800Ogmo07alO01fMWH0PH6108Z:RP26QXH0KFe]08V9R@26QXH0IfMW03@d=01_Kfl0P82005MG
E`2ATI40K6a/06YZJP0X:2P0M7Ad00l0MWIf00<0NGUi07EeM@1fMWH0201fMWHN0?ooo`@0S8b<00<0
Shn?08j>SP2<S8`01@2<S8`02P21PH40SXj>09nOW`2QXJ40WYjN08n?S`2DU9@0SXj>08R8R029RHT2
07alO00707inOP2ATI40Shn?08b<S02;Rh/0S8b<08f=S@0208n?S`0608Z:RP28R8P0S8b<096AT@2C
Ti<0Shn?0`2<S8`01P2BTY80UIFE09FEU@2<S8`0TY:B096AT@80S8b<0200SXj>09:BTP2<S8`0Ti>C
09FEU@2CTi<0SHf=08n?S`2<S8`0SHf=08b<S02FUYH0VYZJ08n?S`24Q8@0S8b<09NGU`2OWil0Shn?
0861P@2HV9P0Vi^K07inOP1lO7`0RHV9079bLP1cLg<0Ti>C09RHV020P800CTi>08V9R@l0S8b<00<0
Shn?08j>SP2<S8`0202<S8`R0?ooo`00803oool407QhN00307]kN`1hN7P0N7Qh00D0N7Qh00P0Ng]k
07IfMP26QXH0N7Qh07UiN@1lO7`0OWin07alO080N7Qh00D0IVIV06i^KP1MGEd0KFe]06i^KP0207Mg
M`0307QhN01iNGT0NGUi0080N7Qh00<0Lg=c07QhN01lO7`01@1hN7P01@1mOGd0N7Qh07QhN01iNGT0
Ogmo0080O7al0200N7Qh07YjNP1hN7P0N7Qh0820P01eMGD0M7Ad07QhN01nOWh0NWYj07alO01hN7P0
QHF50820P01gMgL0O7al08:2PP23Ph<0QHF507]kN`1lO7`0NWYj07inOP1TI6@0@41005EEE@22PX80
EUIF08R8R02=SHd0A4A405iNGQ00N7Qh00<0Ng]k07QhN01hN7P0201hN7PN0?ooo`@0MWIf00<0N7Qh
07AdM01fMWH01@1fMWH04`1dM7@0Lg=c07alO01`L700KVi^07=cL`1fMWH0N7Qh07IfMP1bLW80HV9R
06YZJP1PH600L71`06a/K01eMGD0Lg=c07IfMP1gMgL00P1cLg<0101jNWX0N7Qh07IfMP1kNg/207=c
L`0407YjNP1fMWH0MWIf07alO0<0MWIf00D0NGUi07=cL`1hN7P0MWIf07UiN@0207IfMP0807moO`1g
MgL0N7Qh07UiN@1lO7`0MgMg07alO01hN7P207moO`0B07UiN@1lO7`0O7al0820P027QhL0N7Qh0861
P@29RHT0NGUi06QXJ014A4@0FEUI092@T01RHV80QXJ608F5Q@0b<S80CDe=401fMWH00`1hN7P0M7Ad
07IfMP0807IfMQh0oooo102<S8`00`2:RXX0RHV908b<S00508b<S00A08F5Q@29RHT0QHF508>3P`1n
OWh0Ph>308F5Q@2:RXX0S8b<08J6QP22PX80QHF508V9R@2>SXh0R8R808^;R`28R8P00P2<S8`01P26
QXH0QhN7096AT@2CTi<0S8b<08j>SP80R8R800@0TY:B08b<S02<S8`0Shn?0P2<S8`01P2;Rh/0QhN7
08>3P`2:RXX0S8b<08f=S@80S8b<01`0T92@08n?S`2BTY80T92@08b<S02;Rh/0Shn?08j>SP29RHT0
Shn?096AT@2?Shl0RHV908j>SP2FUYH0Rh^;09NGU`2SXj<0RHV908f=S@20P800R8R80:FUY@2DU9@0
TI6A08Z:RP1RHV80KFe]402<S8`00`2:RXX0RHV908b<S00808b<S280oooo000P0?ooo``0N7Qh0100
LW9b08B4Q01eMGD0Lg=c07UiN@1hN7P0OWin07=cL`1jNWX0OGem06e]K@1TI6@0IFEU06QXJ01]KFd0
Lg=c0P1dM7@00`1hN7P0Lg=c07=cL`0207alO00907=cL`1lO7`0N7Qh079bLP1iNGT0Lg=c079bLP1h
N7P0NGUi00<0N7Qh00P0M7Ad07alO01hN7P0NWYj07emO@1hN7P0P8200861P@80O7al01L0Ng]k07Qh
N01mOGd0N7Qh07alO020P800O7al07QhN01oOgl0N7Qh092@T01hN7P0RHV907YjNP1aLG40IFEU069R
HP1DE5@0OWin069RHP23Ph<0[:b/051@D00L07QhN1h0oooo301fMWH02`1`L700O7al07]kN`1ZJVX0
Lg=c07emO@20P800MWIf06m_K`1bLW80Jf][0080IVIV00H0JFUY06i^KP1dM7@0M7Ad07EeM@1fMWH2
07EeM@0407QhN01iNGT0MGEe07QhN0<0MgMg0P1hN7P09`1jNWX0MgMg07IfMP1fMWH0NGUi07EeM@1k
Ng/0MWIf07]kN`1iNGT0MgMg07YjNP1iNGT0MWIf07QhN01lO7`0N7Qh07alO01gMgL0PH6107moO`1k
Ng/0MWIf08F5Q@1nOWh0R8R807IfMP2?Shl0OWin07emO@1CDe<0DE5A06ATI026QXH0FUYJ07]kN`21
PH409RHV06IVIP0K07IfMQh0oooo302<S8`02`2:RXX0QhN709JFUP20P800QXJ609JFUP2CTi<0T92@
0820P01oOgl0R8R80080RHV900H0Rh^;08b<S02=SHd0SHf=08j>SP2<S8`208n?S`0>08Z:RP2;Rh/0
Shn?08Z:RP2=SHd0U9BD08b<S02DU9@0UIFE096AT@2<S8`0Rh^;08b<S02@T90208j>SP0908b<S02@
T900RHV908f=S@29RHT0QHF508N7Q`2;Rh/0T92@0080SXj>00L0S8b<09JFUP2@T900SXj>08b<S02I
VIT0UYJF0080S8b<00`0W9bL09>CT`2MWId0KVi^06m_K`2IVIT0W9bL07]kN`26QXH0Hf=S04E5A@1e
MGDK08b<S280oooo000P0?ooo`80N7Qh00<0M7Ad07QhN01dM7@01`1hN7P0101bLW80^k^k07QhN01d
M7@206m_K`0@07=cL`1_Kfl0Q8B407QhN01VIVH0JVYZ071`L01XJ6P0LG5a07AdM01fMWH0N7Qh07Mg
M`1cLg<0N7Qh07emO@80Lg=c00@0O7al07=cL`1gMgL0NGUi101hN7P00`1iNGT0N7Qh07MgM`0207Qh
N00807YjNP1kNg/0N7Qh07QhN020P800L71`0861P@1nOWh207QhN080OGem0180QHF508J6QP1hN7P0
OWin07emO@29RHT0NWYj07moO`2;Rh/0Ogmo06e]K@12@T80N7Qh07MgM`22PX80EEEE07QhN01EEEDM
07QhN1h0oooo0P1fMWH00`1eMGD0NGUi07EeM@0707IfMP0607AdM01mOGd0R8R808J6QP1gMgL0NWYj
0P1fMWH01`1lO7`0J6QX06EUI@1ZJVX0IfMW06IVIP1_Kfl00P1bLW803@1gMgL0MWIf079bLP1fMWH0
O7al075aL@1eMGD0Ng]k07EeM@1iNGT0M7Ad07YjNP1gMgL00P1fMWH03@1gMgL0MWIf07IfMP1fMWH0
Ng]k07YjNP1dM7@0NGUi07IfMP1oOgl0KVi^0861P@1mOGd00P1gMgL02@1hN7P0NGUi0820P028R8P0
OWin08>3P`1hN7P0O7al07inOP0208Z:RP0:07UiN@1WIfL0=SHf079bLP1cLg<0OGem059BDP1cLg<0
@d=306][Ja`0MWIf7P3oool208b<S00308j>SP2?Shl0SXj>00L0S8b<0140Shn?04i>CP2TY:@0YZJV
09JFUP2JVYX0T92@09FEU@28R8P0N7Qh08J6QP28R8P0OWin08J6QP2:RXX0Rh^;08R8R00208f=S@0;
08Z:RP2<S8`0SXj>08V9R@2?Shl0SXj>092@T02ATI40QhN709:BTP2=SHd00P2;Rh/208b<S00;08f=
S@2<S8`0Ti>C08n?S`25QHD0Shn?08b<S02@T900RHV9092@T02?Shl00P2=SHd05@29RHT0RXZ:08b<
S02EUID0UiNG09JFUP29RHT0PX:209FEU@2PX:00U9BD08R8R021PH40JFUY08F5Q@28R8P0Rh^;07in
OP27QhL0J6QX07emO@0L08b<S280oooo000P0?ooo`<0N7Qh00<0Ng]k07QhN01hN7P01`1hN7P0103A
dM40P82007QhN01hN7P3071`L00706m_K`1hN7P0KFe]07=cL`1bLW80K6a/075aL@0207AdM00=07Ui
N@1gMgL0Lg=c07=cL`1hN7P0Lg=c07QhN01lO7`0OGem07alO01bLW80OGem07UiN@0307QhN00307Ui
N@1hN7P0N7Qh00@0N7Qh00D0OGem0820P01hN7P0PH6107inOP0207QhN008079bLP1mOGd0Ogmo08:2
PP20P800QXJ607inOP1aLG4207QhN080OWin00P0IFEU03Xj>P22PX80LW9b07QhN01DE5@0N7Qh05aL
G1d0N7Qh7P3oool207IfMP0307AdM01hN7P0M7Ad00P0MWIf0140clo?08^;R`1hN7P0OGem07AdM01h
N7P0MGEe06e]K@1bLW80HV9R06a/K01]KFd0J6QX06m_K`1aLG40MWIf07QhN00207EeM@0907QhN01j
NWX0MGEe07=cL`1hN7P0MWIf07QhN01eMGD0NGUi00@0MWIf00X0MgMg07IfMP1kNg/0NGUi07AdM01f
MWH0Lg=c07UiN@1jNWX0LG5a0P1mOGd05P1gMgL0NWYj07EeM@1lO7`0NGUi08J6QP1iNGT0O7al0820
P01nOWh0R8R808B4Q021PH40OWin06e]K@0a<C40NWYj07MgM`1mOGd0Cdm?06UYJ@1;Bd/M07IfMQh0
oooo0P2<S8`00`29RHT0RXZ:08V9R@0808b<S00;0:^[Z`2PX:00SXj>09FEU@2ATI40UiNG09:BTP27
QhL0QXJ607YjNP23Ph<00P24Q8@03`2:RXX0RHV9092@T02=SHd0S8b<08n?S`2CTi<0TI6A092@T028
R8P0RXZ:08F5Q@2:RXX0T92@08V9R@0208^;R`<0S8b<00d0Rh^;09>CT`2@T900RHV908b<S027QhL0
RHV908R8R025QHD0Rh^;08n?S`2<S8`0TI6A0080Shn?0180R8R809RHV028R8P0Q8B409>CT`2NWYh0
YZJV09nOW`2EUID0T92@09:BTP1[Jf/0QhN709:BTP2EUID0NWYj07UiN@1[Jf/M08b<S280oooo000P
0?ooo`d0N7Qh0140gMgM0;Zj^P20P800Ogmo07QhN01oOgl0MGEe06YZJP1VIVH0IFEU06][J`1/K6`0
Kfm_075aL@1bLW80Ng]k07UiN@0207MgM`0307alO01gMgL0OGem00@0N7Qh00H0OGem07MgM`1lO7`0
MgMg07QhN01gMgL207QhN00507moO`1hN7P0O7al07QhN01eMGD00`1hN7P0101lO7`0OWin07UiN@1m
OGd307QhN00@08B4Q01lO7`0N7Qh08V9R@27QhL0O7al08F5Q@1hN7P0RXZ:079bLP0g=cL0Q8B408n?
S`1bLW80G5aL06=SH`80N7Qh00<0M7Ad07QhN01hN7P06@1hN7PN0?ooo`d0MWIf00d0_;bl096AT@1k
Ng/0NGUi079bLP1gMgL0LW9b07=cL`1[Jf/0J6QX06m_K`1ZJVX0Jf][0080L71`0P1hN7P0101fMWH0
Lg=c07UiN@1cLg<307IfMP0707YjNP1fMWH0N7Qh07IfMP1iNGT0MWIf07MgM`0307IfMP0R07alO01b
LW80N7Qh07UiN@1fMWH0NWYj07MgM`1fMWH0Ogmo07alO01gMgL0N7Qh07MgM`1jNWX0OWin07moO`1m
OGd0O7al0861P@1oOgl0OGem08B4Q01dM7@0PX:206][J`0_;bl0M7Ad08J6QP1/K6`0EEEE05mOG`1U
IFD0NGUi07EeMA/0MWIf7P3oool=08b<S00408>3P`1ZJVX0RXZ:08R8R080QHF500P0RHV909FEU@2?
Shl0S8b<08j>SP28R8P0QHF508V9R@80RXZ:0P2=SHd01028R8P0Rh^;08R8R025QHD208b<S00509:B
TP2<S8`0R8R808f=S@2;Rh/00`2=SHd308b<S00508F5Q@2:RXX0Shn?08j>SP2BTY800P2<S8`0302C
Ti<0SXj>08b<S029RHT0SHf=096AT@2FUYH0Rh^;096AT@2DU9@0RHV908R8R080TI6A00`0R8R808Z:
RP22PX80Jf][07emO@29RHT0Q8B407YjNP22PX80Lg=c08n?S`2>SXhK08b<S280oooo000P0?ooo`d0
N7Qh00<0XZ:R0=_Kf`26QXH00P1`L7002@1eMGD0Ng]k07YjNP1SHf<0K6a/07=cL`1`L700KFe]07Mg
M`02079bLP0407EeM@1iNGT0Lg=c07UiN@<0Lg=c0P1hN7P03P1cLg<0N7Qh07=cL`1hN7P0MgMg07Ui
N@1hN7P0MgMg07QhN01lO7`0M7Ad07QhN01iNGT0NWYj0`1hN7P02@1lO7`0PH6107inOP1hN7P0OGem
07QhN01nOWh0MgMg08B4Q00207QhN080O7al00`0QHF507QhN01oOgl0Ogmo02h^;P1UIFD0UIFE071`
L01_Kfl0J6QX07QhN01kNg/L07QhN1h0oooo00<0MWIf07UiN@1fMWH02P1fMWH05@29RHT0_kno08N7
Q`1iNGT0MWIf07EeM@1fMWH0MgMg06ATI01VIVH0JFUY06][J`1YJFT0LW9b07AdM01fMWH0MGEe07If
MP1dM7@0NWYj07AdM00207EeM@80NWYj00H0M7Ad07YjNP1eMGD0NWYj07EeM@1gMgL307IfMP0907]k
N`1eMGD0Ng]k07MgM`1jNWX0MWIf07MgM`1jNWX0O7al0080NWYj01L0MWIf07alO01iNGT0O7al07]k
N`23Ph<0Ng]k08:2PP26QXH0Ng]k0861P@1fMWH0N7Qh071`L00g=cL0Jf][08j>SP1NGUh0GEeM05QH
F01fMWH0N7Qh07AdM00K07IfMQh0oooo00<0S8b<08n?S`2<S8`02P2<S8`05@1iNGT0RHV909BDU02H
V9P0Ti>C08j>SP29RHT0Rh^;08R8R022PX80OWin08>3P`24Q8@0QhN708n?S`2ATI40SXj>08^;R`2>
SXh0T92@08j>SP0208n?S`0609:BTP2ATI40SXj>09:BTP2?Shl0TY:B0P2<S8`00`2;Rh/0SHf=08b<
S00208j>SP0309:BTP2<S8`0SXj>0080S8b<01/0TI6A08n?S`28R8P0RXZ:08b<S02>SXh0T92@08j>
SP2DU9@0TI6A09:BTP2LW9`0WYjN08j>SP2=SHd0S8b<08J6QP1kNg/0P82008n?S`2>SXh0LW9b075a
L@1bLW80S8b<08Z:RP29RHT06`2<S8`R0?ooo`00803oool00`1hN7P0Ng]k07QhN00:07QhN00@07]k
N`3IfMT0W9bL08j>SP1hN7P0NWYj079bLP1mOGd0Jf][06ATI01OGel0MGEe079bLP1aLG40MgMg07Ui
N@<0N7Qh0P1gMgL01@1hN7P0LW9b07UiN@1hN7P0MgMg0080N7Qh00<0NGUi07QhN01gMgL01@1hN7P0
0`1jNWX0MGEe07QhN00207MgM`0607inOP1hN7P0N7Qh07YjNP1hN7P0OGem0P1nOWh0401gMgL0P820
07]kN`1oOgl0OWin07alO024Q8@0Ogmo075aL@1hN7P0<S8b06ATI01lO7`0HV9R06EUI@1TI6@N07Qh
N1h0oooo00<0MWIf07QhN01fMWH02P1fMWH03`1hN7P0clo?08B4Q01lO7`0Kfm_07MgM`1cLg<0MgMg
06EUI@1/K6`0IVIV06][J`1^KVh0M7Ad079bLP0207AdM00307IfMP1gMgL0MgMg0080Lg=c00<0M7Ad
07YjNP1fMWH00P1gMgL607IfMP80NGUi00P0MWIf07UiN@1fMWH0N7Qh07MgM`1fMWH0OGem07MgM`80
Ng]k01@0MWIf07]kN`1hN7P0OGem07UiN@24Q8@0Ogmo08>3P`25QHD0N7Qh07moO`1lO7`0Kfm_07mo
O`0d=3@0KFe]08B4Q01OGel0GUiN059BDQh0MWIf7P3oool00`2<S8`0RXZ:08b<S00:08b<S00>08Z:
RP2RXZ80NGUi07alO021PH40Rh^;08f=S@28R8P0PH6109:BTP2?Shl0OWin08J6QP2?Shl208N7Q`04
08R8R02<S8`0SHf=08j>SP80R8R800/0Shn?092@T02<S8`0SXj>08f=S@2<S8`0Rh^;08b<S02=SHd0
S8b<08^;R`02092@T00408b<S02=SHd0SXj>08n?S`80SHf=01P0Shn?08f=S@2CTi<0T92@08b<S02=
SHd0R8R808n?S`2@T900UYJF09BDU02GUiL0VYZJ08Z:RP2;Rh/0S8b<08Z:RP2IVIT0NGUi09>CT`2K
Vi/0PX:207emO@1]KFdN08b<S280oooo000P0?ooo`X0N7Qh01@0M7Ad07QhN01hN7P0N7Qh079bLP2X
Z:P0dM7A0<g=c@1hN7P0NWYj0820P01`L700HF5Q06QXJ01TI6@0J6QX07MgM`1hN7P0LW9b07QhN080
NGUi00L0MGEe07QhN01gMgL0NGUi07=cL`1hN7P0NGUi00<0N7Qh00<0O7al07QhN01lO7`00`1hN7P0
0`1kNg/0LW9b07QhN00207QhN00:0820P01iNGT0M7Ad07inOP1hN7P0OGem07=cL`1hN7P0OGem08B4
Q080MGEe00<0N7Qh08R8R01lO7`00P1lO7`02025QHD0O7al06m_K`1nOWh0JFUY06IVIP1TI6@0GUiN
7P1hN7PN0?ooo`0307IfMP1iNGT0MWIf00H0MWIf00<0NGUi07EeM@1fMWH00P1fMWH0201`L700RHV9
08>3P`2LW9`0OWin07]kN`1eMGD0KVi^0`1XJ6P03P1ZJVX0MWIf07IfMP1`L700Lg=c07AdM01iNGT0
MGEe07IfMP1eMGD0MgMg07AdM01jNWX0MgMg0`1fMWH0301hN7P0M7Ad07]kN`1fMWH0M7Ad07IfMP1n
OWh0MWIf07]kN`1gMgL0MWIf07emO@80N7Qh01L0NGUi07MgM`23Ph<0M7Ad0820P021PH40QHF508>3
P`27QhL0Ng]k08B4Q021PH40OWin07alO023Ph<0OWin05=CD`29RHT0Jf][06EUI@1GEeL0CDe=07Ad
M00M07IfMQh0oooo00<0S8b<08n?S`2<S8`01P2<S8`00`2?Shl0SXj>08b<S00208b<S00;08Z:RP1b
LW80?clo06IVIP2GUiL0TI6A08:2PP29RHT0T92@08R8R02=SHd00`2<S8`01@2:RXX0QhN708R8R02?
Shl0SXj>00<0S8b<00<0SXj>096AT@2<S8`00`2<S8`02@2:RXX0R8R808j>SP2<S8`0R8R808b<S02D
U9@0TY:B096AT@0308b<S00?08f=S@2BTY80RHV908f=S@2HV9P0SXj>09RHV02FUYH0U9BD0:2PX02W
YjL0TY:B08n?S`2FUYH0TY:B0080Shn?00P0TY:B06=SH`2OWil0Rh^;08J6QP1eMGD0KFe]08V9RAd0
S8b<8P3oool00200oooo00<0N7Qh07]kN`1hN7P01P1hN7P00`1kNg/0N7Qh07QhN00207QhN080LW9b
00l0PX:20=WIf@1cLg<0MWIf06a/K01hN7P0JFUY06EUI@1]KFd0J6QX075aL@1_Kfl0LW9b07AdM01a
LG400`1eMGD207QhN00807AdM01hN7P0N7Qh07UiN@1hN7P0LW9b07AdM01bLW8207QhN003075aL@1b
LW80N7Qh00<0N7Qh00<0MgMg07alO01iNGT00`1hN7P05023Ph<0N7Qh0861P@25QHD0Ng]k0861P@23
Ph<0NGUi08R8R01dM7@0P82007QhN01lO7`0NGUi07IfMP1mOGd0I6AT07IfMP1WIfL0KVi^0P1dM7@L
07QhN1h0oooo00<0MWIf07QhN01fMWH01P1fMWH00`1hN7P0M7Ad07IfMP0207IfMP0407AdM01hN7P0
NWYj0;bl_080NWYj00X0LW9b07EeM@1VIVH0IFEU06UYJ@1ZJVX0NGUi07=cL`1dM7@0MWIf0P1hN7P2
07EeM@0307IfMP1iNGT0MGEe0080MWIf0P1jNWX0101gMgL0N7Qh07MgM`1iNGT207QhN00307]kN`1j
NWX0MWIf0080MgMg01`0MWIf07inOP1kNg/0MWIf07]kN`1jNWX0OWin07IfMP1jNWX0Ogmo08N7Q`23
Ph<0O7al07AdM01mOGd0N7Qh0820P01mOGd0QXJ603lo?`1lO7`0Q8B405aLG01MGEd0BTY:069RHP1g
MgL0MGEe701fMWHN0?ooo`0308b<S02:RXX0S8b<00H0S8b<00<0RXZ:08V9R@2<S8`00P2<S8`05`2?
Shl0UIFE08N7Q`27QhL0UIFE09BDU02BTY80Rh^;08B4Q028R8P0QHF508^;R`2GUiL0TI6A08n?S`2A
TI40UYJF096AT@2>SXh0SHf=08^;R`2@T900SXj>0080S8b<00<0Shn?09:BTP2CTi<00P2CTi<0302@
T900SXj>09FEU@2IVIT0TY:B08b<S02=SHd0S8b<08f=S@2BTY80T92@08b<S080TI6A01H0Rh^;08b<
S028R8P0RXZ:0:2PX02DU9@0R8R808N7Q`24Q8@0TY:B096AT@2FUYH0WIfM03`l?02GUiL0VIVI07al
O01ZJVX0GemO07YjNP2ATI40SXj>702<S8`R0?ooo`00803oool@07QhN00C079bLP2i^KT0GEeM07mo
O`29RHT0Kfm_07QhN01ZJVX0JFUY06e]K@1iNGT0MWIf07QhN01dM7@0NWYj07QhN01lO7`0M7Ad079b
LP0407QhN00807alO01iNGT0N7Qh07emO@1hN7P0LW9b07AdM01mOGd207QhN00O07MgM`1hN7P0N7Qh
07QhN01iNGT0OGem07MgM`1hN7P0MgMg07YjNP1_Kfl0Lg=c0820P023Ph<0PX:208>3P`1hN7P0K6a/
0:6QX@1aLG40N7Qh08B4Q01EEED0PX:207emO@1XJ6P0HF5Q05iNGP1dM7@0N7Qh07emO@0L07QhN1h0
oooo401fMWH05@1`L700YJFU06YZJP1]KFd0NWYj06QXJ01[Jf/0JFUY06YZJP1]KFd0M7Ad071`L01g
MgL0MGEe07IfMP1bLW80N7Qh07IfMP1eMGD0MWIf07AdM00207IfMP0;07QhN01jNWX0Lg=c07QhN01j
NWX0M7Ad07EeM@1kNg/0MWIf07MgM`1fMWH00P1gMgL06`1kNg/0NWYj07YjNP1gMgL0Ng]k07UiN@24
Q8@0MgMg07UiN@29RHT0Ogmo07YjNP20P800Ogmo07MgM`2?Shl0P82007alO01LG5`0B4Q80820P01d
M7@0FUYJ05MGE`1DE5@0Kfm_071`L00M07IfMQh0oooo402<S8`0202:RXX0R8R809NGU`1gMgL0OWin
0861P@1lO7`0QhN70P2:RXX01`27QhL0QHF508f=S@2>SXh0RHV908J6QP2:RXX00P2?Shl02`2<S8`0
R8R808b<S02<S8`0RXZ:08n?S`27QhL0RHV9096AT@2?Shl0SXj>0080S8b<0P2=SHd03`2<S8`0SHf=
09:BTP2@T900S8b<08f=S@2BTY80T92@09fMW@2FUYH0UIFE09fMW@2=SHd0QhN708f=S@0209VIV@0=
08:2PP2RXZ80U9BD05]KF`1^KVh0Shn?08:2PP1dM7@0MgMg07IfMP25QHD0Q8B408J6QP0L08b<S280
oooo000P0?oooa00N7Qh0180LW9b09VIV@29RHT0G5aL07EeM@1UIFD0N7Qh06YZJP1]KFd0KVi^06UY
J@1aLG40N7Qh079bLP1dM7@0KVi^07alO01fMWH707AdM003071`L01bLW80N7Qh0080LW9b0P1gMgL0
1P1hN7P0MgMg07MgM`1hN7P0OWin079bLP<0N7Qh00@0NWYj08F5Q@1_Kfl0MGEe0P1hN7P0401bLW80
N7Qh08B4Q01kNg/0RHV909fMW@2;Rh/0KVi^06a/K01lO7`0PX:2079bLP1[Jf/0EEEE07QhN01bLW8M
07QhN1h0oooo401fMWH01`1`L700Y:BT075aL@1_Kfl0PX:205iNGP1gMgL00P1YJFT02`1bLW80LG5a
07=cL`1gMgL0Lg=c07UiN@1`L700O7al07IfMP1dM7@0MGEe00<0N7Qh00@0MGEe07MgM`1gMgL0Ng]k
0P1jNWX0101eMGD0NWYj07MgM`1gMgL307IfMP0L0820P01gMgL0NWYj07YjNP1hN7P0Ng]k08J6QP1c
Lg<0PX:208J6QP21PH40P82007moO`1nOWh0LW9b08f=S@1iNGT0IVIV061PH01QHF40Lg=c06][J`1K
Fe/0H61P05=CD`1`L700LW9b07YjNQ`0MWIf7P3oool@08b<S00308Z:RP2XZ:P0LW9b0080WinO00`0
OWin08b<S027QhL0QHF5096AT@2CTi<0SXj>08b<S02=SHd0Ti>C08j>SP2@T90208f=S@0<08j>SP2B
TY80TY:B09:BTP2>SXh0TI6A09JFUP2IVIT0TY:B09NGU`2@T900Ti>C102=SHd00`2<S8`0TY:B09>C
T`02096AT@0H08f=S@2@T900U9BD096AT@2OWil0XZ:R09bLW02OWil0V9RH08Z:RP23Ph<0VIVI06UY
J@1PH600MgMg07]kN`23Ph<0LG5a06a/K01kNg/0OWin08B4Q02<S8`0TY:B702<S8`R0?ooo`00803o
ool@07QhN007079bLP2ZZZX0[:b/06a/K01^KVh0GEeM069RHP0206ATI00;06UYJ@1`L700KFe]079b
LP1]KFd0NWYj071`L01hN7P0MWIf079bLP1dM7@00P1hN7P0201lO7`0KVi^07EeM@1hN7P0MgMg06m_
K`1fMWH0Kfm_0P1hN7P02P1cLg<0L71`079bLP1^KVh0N7Qh079bLP1dM7@0N7Qh079bLP1cLg<207Qh
N00C07alO023Ph<0R8R808F5Q@1`L700MGEe071`L01_Kfl0PH6106IVIP2TY:@0K6a/06EUI@26QXH0
IfMW07YjNP1hN7P0LW9b07AdM00207QhN00307emO@1hN7P0N7Qh00`0N7Qh00<0OGem07QhN01hN7P0
2@1hN7PN0?oooa00MWIf00<0L71`0;2`/02PX:000P1bLW80301^KVh0Lg=c06YZJP1aLG40Kfm_071`
L01cLg<0MGEe075aL@1gMgL0LG5a07]kN`80N7Qh02l0MGEe07IfMP1dM7@0Ng]k07AdM01gMgL0N7Qh
07alO01jNWX0OGem07AdM01fMWH0NGUi07YjNP1fMWH0NWYj07UiN@21PH40MWIf07QhN01nOWh0O7al
0861P@1oOgl0NWYj07inOP22PX80Ogmo08F5Q@1hN7P0OGem07UiN@1]KFd0QHF504e=C@1hN7P0G5aL
05YJFP1eMGD0FEUI05QHF01NGUh0M7Ad07EeM@1fMWH0Lg=c07UiN@0=07IfMP0307=cL`1iNGT0MWIf
00X0MWIf7P3oool@08b<S00<08Z:RP2YZJT0Shn?09>CT`2?Shl0WIfM09jNWP2?Shl0VIVI096AT@2;
Rh/0TY:B0P2@T9005`2;Rh/0S8b<096AT@2@T900U9BD08j>SP2<S8`0R8R808n?S`2CTi<0T92@08n?
S`2EUID0VYZJ09NGU`2ATI40S8b<092@T02FUYH0UIFE09NGU`2JVYX0Vi^K0080Ti>C01/0UiNG09VI
V@2QXJ40VIVI09:BTP2CTi<0TI6A08N7Q`2CTi<0UiNG09VIV@2HV9P0R8R809NGU`1TI6@0GUiN07Ad
M01gMgL0NWYj07EeM@1OGel0JFUY08n?S`2>SXh0S8b<08N7Q`29RHT03@2<S8`00`27QhL0RHV908b<
S00:08b<S280oooo000P0?oooa40N7Qh0180R8R80<_;b`2OWil0J6QX07alO01bLW80HF5Q05MGE`1T
I6@0LG5a07]kN`1`L700KVi^06e]K@1iNGT0N7Qh07AdM01hN7P3075aL@05079bLP1]KFd0K6a/079b
LP1fMWH00P1_Kfl02@1UIFD0Jf][06][J`1]KFd0Jf][075aL@1RHV80KFe]06MWI`0206e]K@0D06UY
J@1hN7P0O7al07QhN01cLg<0KFe]08J6QP24Q8@0MgMg08^;R`1iNGT0RXZ:07YjNP1UIFD0NGUi06e]
K@1OGel0KVi^07YjNP1fMWH207QhN003079bLP1hN7P0N7Qh00T0N7Qh00<0Ng]k07QhN01hN7P03`1h
N7PN0?oooa40MWIf00D0OGem0;Vi^@1cLg<0IVIV07UiN@0206i^KP0806MWI`1_Kfl0KVi^07QhN01f
MWH0M7Ad079bLP1gMgL207EeM@0^07YjNP1hN7P0N7Qh07UiN@1kNg/0O7al07emO@1lO7`0OWin07Qh
N01lO7`0NWYj07inOP1hN7P0Ng]k07YjNP1lO7`0NGUi07moO`1gMgL0OGem07moO`1eMGD0P82007in
OP1jNWX0PH6108>3P`1oOgl0OWin06i^KP1eMGD0NWYj07=cL`1WIfL0Jf][08>3P`1UIFD0GEeM06QX
J01SHf<0GEeM07AdM01fMWH0M7Ad07YjNPX0MWIf00<0N7Qh07AdM01fMWH03`1fMWHN0?oooa40S8b<
00H0Q8B409:BTP1NGUh0QXJ608^;R`25QHD209RHV00309NGU`27QhL0RXZ:0080Ti>C00H0TI6A08^;
R`2;Rh/0SXj>09:BTP2EUID209JFUP0909VIV@2PX:00XZ:R09ZJVP2IVIT0V9RH09fMW@2UYJD0Y:BT
0080WIfM00L0WinO09bLW02XZ:P0Y:BT09nOW`2RXZ80Y:BT0080VIVI01H0Ti>C096AT@2PX:00ZJVY
08V9R@2:RXX0PX:207EeM@2@T900M7Ad07=cL`2@T900WIfM07moO`22PX80Ph>306i^KP1ZJVX0RHV9
08b<S02?Shl0TY:B2P2<S8`00`2:RXX0RHV908b<S00?08b<S280oooo000P0?oooa80N7Qh00h0c<c<
0;>c/`28R8P0Jf][07QhN01bLW80KVi^05QHF01DE5@0Hf=S07EeM@1lO7`0MgMg07IfMP80LG5a0140
Lg=c06e]K@1]KFd0IfMW079bLP21PH40Lg=c075aL@1hN7P0JVYZ07EeM@1aLG40JVYZ07IfMP1RHV80
LW9b061PH00206IVIP06071`L01[Jf/0Lg=c06i^KP1[Jf/0O7al0P27QhL03P2BTY80Q8B40861P@1b
LW80O7al09bLW01DE5@0IVIV0861P@2:RXX0KVi^07AdM01aLG40EUIF1P1hN7P00`1dM7@0N7Qh07Qh
N00<07QhN00307emO@1hN7P0N7Qh00T0N7Qh7P3ooolB07IfMP0>09BDU02ATI40Ng]k06i^KP1fMWH0
JFUY079bLP1^KVh0LW9b07EeM@1dM7@0LW9b075aL@1jNWX207QhN080NGUi00@0OWin07MgM`1eMGD0
PX:20P1hN7P08P24Q8@0MWIf08:2PP1mOGd0LG5a08>3P`1dM7@0Q8B407MgM`1jNWX0MGEe07alO01j
NWX0OGem07]kN`1fMWH0M7Ad07inOP1hN7P0NWYj0861P@1nOWh0J6QX071`L02<S8`0L71`06MWI`1^
KVh0MgMg06=SH`1OGel0Kfm_05=CD`1cLg<407IfMP0307UiN@1eMGD0MWIf00`0MWIf00<0Lg=c07Ui
N@1fMWH02P1fMWHN0?oooa80S8b<00h0G5aL07=cL`22PX80SHf=08b<S01oOgl0TI6A0::RXP2/[:`0
X:2P08b<S021PH40QHF509>CT`<0UIFE00h0Vi^K0:6QX@2OWil0T92@09:BTP2DU9@0UIFE09jNWP2J
VYX0X:2P09fMW@2DU9@0X:2P09nOW`80YZJV01T0Y:BT09fMW@2LW9`0WinO09ZJVP2MWId0V9RH08F5
Q@27QhL0Ogmo07EeM@2?Shl0SHf=07inOP1oOgl0Q8B40:VYZ@29RHT0MWIf07YjNP1lO7`0Kfm_08V9
R@1mOGd0R8R800@0S8b<00<0Shn?08j>SP2<S8`0302<S8`00`27QhL0RHV908b<S00:08b<S280oooo
000P0?oooa80N7Qh00`0ZZZZ0=?Cd`3IfMT0Ti>C07alO01NGUh0MWIf05YJFP1bLW80JVYZ07alO01g
MgL307QhN006071`L01_Kfl0M7Ad07QhN01bLW80J6QX0P1hN7P04P1ZJVX0N7Qh06a/K01hN7P0MgMg
06EUI@1_Kfl0Jf][07alO01UIFD0OGem06ATI01hN7P0JFUY06e]K@1gMgL0Jf][05ADE080IfMW00d0
MGEe08>3P`22PX80NGUi05]KF`1hN7P0RHV906i^KP1`L700M7Ad07inOP1hN7P0Hf=S00H0N7Qh00<0
Ng]k07QhN01hN7P02P1hN7P00`1dM7@0N7Qh079bLP0<07QhN1h0oooo4P1fMWH04`29RHT0OWin092@
T01fMWH0OGem06YZJP27QhL0I6AT06a/K01PH600KVi^07=cL`1jNWX0NGUi07]kN`1jNWX0OWin07Ui
N@1kNg/00P1dM7@05P21PH40P82007YjNP24Q8@0MWIf0861P@1nOWh0NWYj0820P01aLG40RXZ:07Qh
N01oOgl0K6a/08>3P`1hN7P0MgMg07]kN`1nOWh0NGUi0861P@1eMGD20820P00<07=cL`1nOWh0MWIf
07moO`1SHf<0HF5Q07IfMP1^KVh0H61P07emO@1CDe<0GUiN0P1fMWH01@1iNGT0MWIf07IfMP1hN7P0
M7Ad00X0MWIf00D0NGUi07EeM@1fMWH0M7Ad07YjNP0;07IfMQh0oooo4P2<S8`07`1aLG40=SHf04U9
B@1_Kfl0TY:B09FEU@2UYJD0TY:B08B4Q01kNg/0O7al08R8R02ATI40T92@09>CT`2IVIT0X:2P09>C
T`2ATI40Shn?09ZJVP2KVi/0VYZJ09nOW`2NWYh0V9RH09^KV`2HV9P0YJFU0::RXP2ATI400P2SXj<2
09:BTP0F09jNWP2MWId0VIVI09BDU02SXj<0][Jf0:f][@2LW9`0WIfM08j>SP1mOGd0UIFE0:ZZZP2I
VIT0GUiN07QhN02DU9@0Q8B406IVIP2FUYH0L71`06UYJ@80S8b<00D0Shn?08b<S02<S8`0RXZ:08V9
R@0:08b<S00508n?S`2>SXh0S8b<08n?S`2BTY802`2<S8`R0?ooo`00803oool707QhN080M7Ad2P1h
N7P02@22PX80`/;208V9R@2BTY80OWin09:BTP29RHT0Ogmo065QH@0206UYJ@<0MGEe00P0MgMg07Qh
N01hN7P0JFUY071`L01gMgL0L71`07emO@80MgMg01l0Lg=c07QhN022PX80Ng]k08:2PP1hN7P0OWin
08n?S`1dM7@0PX:207inOP23Ph<0N7Qh07alO02BTY80L71`07AdM01jNWX0OWin07QhN01nOWh0Ph>3
08F5Q@1eMGD0KVi^079bLP20P800R8R807IfMP23Ph<0GUiN00<0N7Qh00<0Ng]k07QhN01hN7P0301h
N7P00`1kNg/0N7Qh07QhN00=07QhN1h0oooo1P1fMWH00`1iNGT0MGEe07EeM@0:07IfMP0<07YjNP2l
_;`0Ph>307]kN`1/K6`0KFe]05eMG@1bLW80IFEU07YjNP1fMWH0Ng]k0`1lO7`0:01kNg/0PH6107If
MP1dM7@0Ng]k07alO021PH40Ng]k07inOP1gMgL0Ph>308:2PP1aLG40Lg=c07alO01fMWH0Ng]k06i^
KP1fMWH0N7Qh07IfMP1eMGD0LW9b08f=S@1`L700KVi^07=cL`20P800LW9b07moO`1mOGd0M7Ad06e]
K@1`L700Jf][069RHP1SHf<0Jf][071`L016ATH307IfMP0307AdM01fMWH0MWIf00`0MWIf00<0N7Qh
07AdM01fMWH03@1fMWHN0?ooo`H0S8b<00<0Shn?08j>SP2>SXh02P2<S8`03027QhL0X:2P08^;R`1g
MgL0MWIf06=SH`1FEUH0Ogmo08^;R`2QXJ40W9bL09FEU@80UiNG02T0UIFE09:BTP2KVi/0Vi^K096A
T@2CTi<0WIfM09JFUP2CTi<0UiNG09>CT`2NWYh0TY:B0861P@1mOGd0U9BD08B4Q01jNWX0QHF50861
P@28R8P0P82008Z:RP21PH40T92@08^;R`24Q8@0QXJ609>CT`26QXH0TI6A08Z:RP1kNg/0PX:208j>
SP22PX80IfMW05mOG`1oOgl0MWIf06=SH`0308b<S00308F5Q@2<S8`0S8b<00`0S8b<00<0RXZ:08V9
R@2<S8`03@2<S8`R0?ooo`00803oool207QhN00507AdM01hN7P0N7Qh07QhN01kNg/03@1hN7P0=@32
`/80d=3@071`L022PX80CTi>05eMG@1]KFd0GEeM06m_K`1dM7@0L71`07=cL`1bLW80Ng]k071`L01n
OWh0K6a/06YZJP1/K6`0MgMg07QhN01dM7@0PX:206m_K`1hN7P0IfMW06YZJP1`L700Q8B406ATI01h
N7P0IVIV08^;R`1NGUh0LG5a079bLP1^KVh0Ogmo07QhN01PH600GemO065QH@1VIVH0K6a/06IVIP1^
KVh0J6QX07alO023Ph<0N7Qh08F5Q@1/K6`0ADE500@0N7Qh00<0LW9b07QhN01hN7P0701hN7PN0?oo
o`80MWIf00D0MGEe07IfMP1fMWH0MWIf07QhN00207AdM0/0MWIf03H0Shn?0:>SX`1aLG40OWin06YZ
JP1hN7P0Ogmo06a/K01cLg<0MGEe07]kN`1mOGd0MWIf0861P@1iNGT0QXJ6079bLP1iNGT0Ng]k07in
OP21PH40MGEe08>3P`1lO7`0Ng]k07UiN@1bLW80MgMg08B4Q01_Kfl0Ogmo05aLG02EUID0LG5a07in
OP1_Kfl0OWin08N7Q`1iNGT0MgMg08B4Q021PH40OGem08F5Q@1fMWH0OGem075aL@1QHF40H61P05UI
F@23Ph<0M7Ad04A4A01VIVH307IfMP0307AdM01fMWH0MWIf01`0MWIf7P3oool208b<S00508j>SP2<
S8`0S8b<08b<S02:RXX00P29RHT;08b<S00:05mOG`1]KFd0S8b<08b<S02VYZH0ZZZZ0:>SX`2JVYX0
TI6A08n?S`80VYZJ02X0TY:B09NGU`2HV9P0Vi^K09>CT`2NWYh0WinO09RHV02KVi/0SXj>09:BTP2N
WYh0Ti>C0::RXP2DU9@0UYJF09>CT`2GUiL0V9RH07]kN`2SXj<0X:2P09jNWP28R8P0X:2P09^KV`2@
T900YZJV0;Zj^P2c/k<0ZJVY0:b/[02NWYh0WinO09BDU01YJFT0H61P069RHP2@T900UYJF07]kN`1e
MGD308b<S00308n?S`2<S8`0S8b<01`0S8b<8P3oool00200oooo501hN7P03@1bLW80dm?C0<c<c02=
SHd0Lg=c08>3P`24Q8@0OWin07YjNP1kNg/0OWin071`L01/K6`00P1hN7P06`24Q8@0N7Qh07emO@1^
KVh0M7Ad07MgM`1UIFD0N7Qh06i^KP1lO7`0HF5Q05ADE01[Jf/0IVIV07moO`1hN7P0IFEU07=cL`1d
M7@0OWin04M7A`1dM7@0KFe]07QhN01kNg/0S8b<08J6QP0208>3P`0:07EeM@22PX80OGem07MgM`1h
N7P0L71`04m?C`1[Jf/0GEeM07emO@H0N7Qh00<0M7Ad07QhN01hN7P06@1hN7PN0?ooo`80MWIf00<0
M7Ad07IfMP1fMWH03`1fMWH04P1dM7@0VIVI08J6QP22PX80GUiN06i^KP1`L700IVIV06][J`1hN7P0
PX:207YjNP1gMgL0OWin07YjNP1oOgl0Lg=c07moO`80MGEe0280PX:207EeM@2=SHd0Kfm_075aL@1k
Ng/0K6a/0861P@1cLg<0MGEe07IfMP1nOWh0R8R806YZJP2?Shl0MgMg08>3P`1jNWX0OGem079bLP1h
N7P0K6a/07YjNP1kNg/0KFe]071`L01ADE40GUiN06EUI@2FUYH0Ng]k07inOP0g=cL0NGUi1@1fMWH0
0`1iNGT0MGEe07IfMP0J07IfMQh0oooo0P2<S8`00`29RHT0S8b<08b<S00?08b<S00;08n?S`1LG5`0
BDU908F5Q@1^KVh0M7Ad07IfMP1^KVh0NWYj08^;R`2FUYH00P2JVYX01`2GUiL0TY:B08b<S027QhL0
TY:B09FEU@2>SXh00P2NWYh0802/[:`0SHf=0820P02ZZZX0Xj>S0:RXZ02JVYX0Ph>308b<S02[Zj/0
ZZZZ07moO`2XZ:P0`L710::RXP2MWId0UYJF08:2PP1iNGT0KFe]08F5Q@26QXH0PX:207UiN@1ADE40
JVYZ07=cL`31`L40_Kfm0:BTY01?Cdl0RHV91@2<S8`00`2?Shl0SXj>08b<S00J08b<S280oooo000P
0?oooaH0N7Qh0200[Jf]0<c<c01lO7`0VIVI07AdM01NGUh0HF5Q07IfMP1jNWX0Ph>306IVIP1dM7@0
JVYZ07emO@1kNg/0JVYZ07AdM01oOgl0O7al08V9R@1/K6`0H61P08>3P`1hN7P0Shn?05mOG`1hN7P0
NGUi06][J`1fMWH0MGEe08B4Q080N7Qh00L0K6a/07EeM@1^KVh0LW9b07MgM`1kNg/0OWin0080L71`
00L0GemO07inOP1=CDd0LG5a07emO@1nOWh0QHF50080M7Ad1`1hN7P01@1mOGd0N7Qh07QhN01hN7P0
OGem00D0N7Qh00<0Ng]k07QhN01hN7P03P1hN7PN0?oooaH0MWIf0180QhN70;^k^`1LG5`0Ogmo06][
J`1UIFD0K6a/07YjNP1oOgl0SXj>07IfMP1nOWh0KVi^07moO`23Ph<0Kfm_07IfMP21PH4207emO@03
07IfMP1nOWh0Ogmo0080Ph>300X0JFUY0861P@1kNg/0Lg=c07YjNP1iNGT0Ng]k06m_K`1lO7`0NWYj
0P1dM7@05`1lO7`0NWYj075aL@1[Jf/0Kfm_07UiN@1RHV80Kfm_08N7Q`2<S8`0J6QX06e]K@1KFe/0
MgMg07EeM@1fMWH0NGUi07IfMP1dM7@0MWIf07AdM01cLg<0NGUi0080MWIf00<0Lg=c07UiN@1fMWH0
101fMWH0101hN7P0M7Ad07IfMP1jNWX=07IfMQh0oooo5P2<S8`03`1ZJVX0U9BD06=SH`1eMGD0P820
08n?S`2EUID0Ti>C09JFUP2QXJ40WinO09^KV`2>SXh0TY:B09^KV`02092@T00;09>CT`2ATI40Ph>3
09RHV02`/;00SHf=09fMW@26QXH0Ti>C09bLW02ATI400P2DU9@07P2CTi<0QHF50861P@2CTi<0WYjN
08^;R`2CTi<0Vi^K09>CT`21PH40MGEe08^;R`2HV9P0RXZ:07]kN`3AdM40/K6a07=cL`1hN7P0EUIF
096AT@2>SXh0S8b<08n?S`2<S8`0RHV908b<S029RHT0QhN708V9R@80S8b<00<0QhN708V9R@2<S8`0
102<S8`0102:RXX0RHV908b<S02BTY8=08b<S280oooo000P0?oooaH0N7Qh01l0LW9b0>KViP1OGel0
De=C08>3P`1lO7`0KFe]0861P@23Ph<0VIVI06m_K`1oOgl0IVIV07MgM`1lO7`0J6QX07EeM@1lO7`0
N7Qh06QXJ02@T900IVIV07moO`1/K6`0L71`06EUI@28R8P0L71`075aL@1mOGd0MgMg0080L71`01D0
KFe]06a/K01YJFT0K6a/07QhN02:RXX0LG5a07emO@2ATI40RXZ:092@T01hN7P0PX:206MWI`1bLW80
FUYJ07QhN021PH40M7Ad07QhN01kNg/0101hN7P01@1bLW80N7Qh07QhN01hN7P0LW9b01L0N7Qh7P3o
oolF07IfMP0N07AdM02TY:@0Q8B406e]K@1^KVh0K6a/079bLP1iNGT0NWYj09NGU`1[Jf/0Ogmo07=c
L`22PX80Ph>306YZJP1hN7P0PX:208B4Q01aLG40U9BD065QH@1lO7`0Ng]k08^;R`1PH600QHF507Yj
NP1dM7@0O7al0P1iNGT0701oOgl0P820079bLP1iNGT0M7Ad06][J`1jNWX0KFe]06QXJ01dM7@0GUiN
06EUI@1gMgL0PH6105mOG`1oOgl0CTi>04Q8B01jNWX0Lg=c07IfMP1hN7P0M7Ad07IfMP1dM7@0MWIf
07AdM01jNWX207IfMP0307AdM01jNWX0MWIf01D0MWIf7P3ooolF08b<S00l08n?S`1GEeL0^KVi0:JV
YP1cLg<0NGUi09:BTP26QXH0QHF509JFUP26QXH0T92@09ZJVP2NWYh0V9RH08b<S02ATI40V9RH09nO
W`2DU9@0W9bL0820P02<S8`0WinO0;6a/@20P800T92@09VIV@2@T900SXj>096AT@2HV9P0XJ6Q0:FU
Y@2CTi<0WinO09FEU@1lO7`0OWin08F5Q@1cLg<0KVi^05EEE@1KFe/0SHf=092@T01mOGd0WYjN07Ad
M01;Bd/0QhN708^;R`2<S8`0RXZ:08V9R@2<S8`0RHV908b<S02?Shl0TY:B0P2<S8`00`2?Shl0TY:B
08b<S00E08b<S280oooo000P0?oooaL0N7Qh0380M7Ad0?Gem@1XJ6P0>SXj05YJFP1]KFd0MWIf08>3
P`2JVYX0Jf][06a/K028R8P0Q8B4092@T01jNWX0IfMW08B4Q01^KVh0N7Qh092@T01VIVH0O7al08n?
S`2>SXh0@d=307=cL`1hN7P0Shn?07QhN01]KFd0Ogmo07inOP1kNg/0KVi^06YZJP1OGel0GUiN07Ui
N@2>SXh0J6QX07QhN01_Kfl0HF5Q04e=C@2;Rh/0I6AT07UiN@1<C4`0LW9b07]kN`<0N7Qh00<0M7Ad
07QhN01hN7P02@1hN7P00`1dM7@0N7Qh07QhN00507QhN00307emO@1hN7P0N7Qh00T0N7Qh7P3ooolF
07IfMP0>07UiN@1eMGD0Y:BT07=cL`1_Kfl0MWIf07MgM`1cLg<0P82009VIV@1iNGT0Kfm_07emO@1f
MWH207YjNP0A071`L01oOgl0Lg=c075aL@2;Rh/0IFEU07QhN020P800SHf=06=SH`25QHD0Hf=S0861
P@24Q8@0LW9b07alO020P8000P1lO7`05@1jNWX0JVYZ06UYJ@1]KFd0Hf=S06QXJ01]KFd0M7Ad09ZJ
VP22PX80P82006i^KP1cLg<0:2PX06i^KP1lO7`0M7Ad07IfMP1iNGT0MGEe07=cL`0907IfMP0307Ui
N@1eMGD0MWIf00D0MWIf00<0Lg=c07UiN@1fMWH02P1fMWHN0?oooaH0S8b<03P0Shn?08j>SP18B4P0
V9RH0<;2`P2[Zj/0V9RH08V9R@2=SHd0VYZJ09fMW@2?Shl0Q8B407emO@1hN7P0SXj>09FEU@2:RXX0
TY:B08F5Q@2@T900QHF508Z:RP21PH40UIFE0:RXZ02VYZH0L71`08:2PP2OWil0TI6A08b<S02BTY80
TI6A09jNWP2PX:00UYJF09BDU01mOGd0FUYJ08R8R01nOWh0Ti>C0=OGe`3:b/X0QXJ609JFUP26QXH0
C4a<08J6QP2@T900RHV908b<S02?Shl0SXj>08N7Q`T0S8b<00<0Shn?08j>SP2<S8`01@2<S8`00`27
QhL0RHV908b<S00:08b<S280oooo000P0?ooo`D0N7Qh00<0M7Ad07QhN01hN7P03P1hN7P07`1kNg/0
N7Qh0<[:bP3IfMT0KVi^05QHF01DE5@0HF5Q07QhN02QXJ40R8R805]KF`1gMgL0GemO06QXJ024Q8@0
IFEU06IVIP1`L700JVYZ07emO@1nOWh0L71`08F5Q@2WYjL0SXj>0820P01DE5@0L71`08Z:RP1hN7P0
0P29RHT03`2RXZ80T92@09NGU`2ATI40Rh^;07=cL`1bLW80VIVI065QH@1nOWh0RXZ:05MGE`1hN7P0
Ti>C06YZJP0507QhN0030861P@1hN7P0KVi^00@0N7Qh00<0OGem07QhN01hN7P00P1hN7P00`1kNg/0
N7Qh07emO@0507QhN003079bLP1hN7P0N7Qh00X0N7Qh7P3oool407IfMP0307UiN@1eMGD0MWIf00l0
MWIf01<0N7Qh07AdM02[Zj/0YZJV06YZJP1cLg<0IfMW079bLP1iNGT0VIVI08B4Q01UIFD0NGUi07Yj
NP1kNg/0RHV907=cL`1gMgL0LG5a0080NGUi01`0Lg=c07]kN`1kNg/0R8R806QXJ01jNWX0L71`0820
P01mOGd0IfMW07inOP1ZJVX0Ng]k06i^KP1WIfL0GemO06IVIP1NGUh0J6QX07inOP1[Jf/0Ti>C09nO
W`1RHV80LG5a07UiN@0d=3@0E5AD0`1fMWH0101cLg<0NWYj07IfMP1cLg<307IfMP0307=cL`1iNGT0
MWIf00<0MWIf00<0N7Qh07AdM01iNGT01@1fMWH00`1dM7@0NWYj07IfMP0:07IfMQh0oooo102<S8`0
0`2?Shl0SXj>08b<S00?08b<S00a08Z:RP29RHT0OWin06UYJ@24Q8@0Z:RX09bLW02NWYh0T92@096A
T@2>SXh0TI6A092@T02/[:`0Xj>S09VIV@2KVi/0WinO08f=S@2OWil0RHV907moO`2JVYX0Q8B407=c
L`1OGel0R8R80:RXZ02RXZ80Ph>307IfMP23Ph<0J6QX06EUI@1VIVH0E5AD051@D01QHF40KVi^07em
O@1cLg<0U9BD0:j^[P2c/k<0Ti>C08B4Q01cLg<0?Cdm05]KF`0308b<S080QhN700<0S8b<096AT@2<
S8`00P2<S8`00`27QhL0RHV908b<S00308b<S00308Z:RP29RHT0RHV900D0S8b<00<0Shn?09:BTP2<
S8`02P2<S8`R0?ooo`00803oool407QhN00307]kN`1hN7P0N7Qh0140N7Qh01<0TY:B0=cLg030`<00
R8R806EUI@13@d<0E5AD07emO@2][Jd0IVIV05iNGP27QhL0L71`07UiN@1aLG40Hf=S07AdM01bLW80
K6a/0080N7Qh01<0OWin08Z:RP23Ph<0U9BD08:2PP2;Rh/0MgMg08J6QP29RHT0LG5a08B4Q02=SHd0
RXZ:09>CT`24Q8@0OGem08V9R@1lO7`0JFUY0080PX:200/0NWYj06a/K01XJ6P0OGem07QhN01mOGd0
N7Qh07AdM01hN7P0M7Ad0861P@0207QhN00307emO@1hN7P0LW9b01X0N7Qh7P3oool407IfMP0307Qh
N01dM7@0MWIf0140MWIf03/0P8200:>SX`29RHT0LW9b06m_K`1^KVh0N7Qh07UiN@2IVIT0LG5a06i^
KP1lO7`0MWIf08N7Q`1lO7`0M7Ad07]kN`1cLg<0Kfm_08:2PP1mOGd0MGEe07emO@1gMgL0QXJ606=S
H`1hN7P0JFUY075aL@1jNWX0K6a/07]kN`1WIfL0GemO079bLP1]KFd0GUiN07IfMP2DU9@0MWIf09ZJ
VP1mOGd0FUYJ07EeM@11@D40CDe=07=cL`1eMGD0NGUi075aL@1iNGT0MGEe07YjNP1fMWH0Lg=c07Ui
N@1fMWH0M7Ad07YjNP0607IfMP0507YjNP1fMWH0MWIf07IfMP1cLg<03P1fMWHN0?ooo`@0S8b<00<0
RXZ:08V9R@2<S8`04@2<S8`0>`1nOWh0HF5Q05UIF@1dM7@0UIFE0;Vi^@2e]KD0RHV908F5Q@2GUiL0
Vi^K08B4Q02DU9@0XZ:R09^KV`2OWil0V9RH08j>SP2?Shl0WIfM09FEU@24Q8@0Ph>30861P@25QHD0
IVIV07]kN`1jNWX0MWIf07moO`25QHD0QXJ605mOG`1HF5P0JFUY079bLP1TI6@0NWYj0;6a/@2KVi/0
];Bd08^;R`1RHV80UYJF055AD@1;Bd/0QhN708B4Q02?Shl0RHV908n?S`2>SXh0QhN708b<S027QhL0
RHV908b<S02?Shl0TY:B00H0S8b<00D0TY:B08b<S02<S8`0S8b<08N7Q`0>08b<S280oooo000P0?oo
oaH0N7Qh0180LW9b07AdM01hN7P0M7Ad0:ZZZP3Cdm<0YjNW06a/K01gMgL0L71`075aL@2SXj<0YjNW
07QhN01bLW80N7Qh08b<S02@T90206IVIP0;05YJFP22PX80GEeM06EUI@2:RXX0O7al09^KV`2i^KT0
]kNg0:FUY@2OWil00P2@T900302PX:00OWin07moO`1SHf<0JVYZ07MgM`1]KFd0QXJ608:2PP1oOgl0
Ph>307YjNP<0N7Qh00D0OGem079bLP1hN7P0N7Qh079bLP0207QhN00407AdM01hN7P0OGem07emOA/0
N7Qh7P3ooolF07IfMP0;07MgM`1iNGT0NGUi07EeM@29RHT0U9BD092@T01YJFT0Kfm_06][J`1aLG40
0P24Q8@05025QHD0M7Ad07AdM021PH40MGEe07=cL`20P800Kfm_08N7Q`1NGUh0GemO07emO@1FEUH0
IVIV07moO`1gMgL0I6AT06a/K01VIVH0HV9R0P1XJ6P06028R8P0S8b<08J6QP1nOWh0PH6107UiN@1K
Fe/0G5aL07]kN`1jNWX0C4a<07YjNP1cLg<0NGUi07AdM01jNWX0MWIf07AdM01jNWX0NGUi07EeM@1c
Lg<0MGEe07UiNA/0MWIf7P3ooolF08b<S080Ti>C03T0Shn?08j>SP1aLG40E5AD07emO@26QXH0PX:2
08B4Q02;Rh/0LW9b06i^KP2QXJ40Shn?08R8R026QXH0L71`09^KV`2][Jd0XJ6Q09RHV025QHD0Ogmo
08>3P`1KFe/0D51@05=CD`19BDT0@T9205ADE01KFe/0EEEE04e=C@1`L700WIfM0<71`@2`/;00V9RH
0:NWY`21PH40Fe]K05mOG`26QXH0Shn?051@D02BTY80QhN708V9R@2?Shl0TY:B08b<S02?Shl0TY:B
08n?S`2>SXh0QhN708B4Q029RHT06`2<S8`R0?ooo`00803ooolF07QhN00]07]kN`1hN7P0Ng]k07Qh
N01mOGd0XZ:R0=kNgP1cLg<0H61P04Y:BP1SHf<0OWin0:NWY`2?Shl0Ogmo08F5Q@21PH40Q8B40;>c
/`2JVYX0K6a/08B4Q01OGel0MWIf08V9R@1KFe/0Bd];07alO02=SHd0Rh^;09FEU@2BTY80L71`05]K
F`1QHF40M7Ad07inOP1bLW80N7Qh071`L022PX80KVi^07UiN@1hN7P0QhN70080N7Qh00@0KVi^07Qh
N01hN7P0M7Ad1@1hN7P2079bLP80N7Qh00<0M7Ad07QhN01hN7P05`1hN7PN0?oooaH0MWIf0240N7Qh
07AdM01hN7P0L71`07UiN@27QhL0Q8B407EeM@22PX80JVYZ06ATI01bLW80QhN707YjNP1ZJVX0NGUi
07AdM01`L700Ng]k08B4Q01SHf<0Ph>3069RHP1NGUh0NWYj06i^KP1ZJVX0OGem07alO01_Kfl0LG5a
07QhN01iNGT00P23Ph<0402CTi<0Q8B407=cL`2:RXX0OWin06YZJP1LG5`0O7al07IfMP16ATH0NWYj
07UiN@1cLg<0NWYj07UiN@1eMGD207IfMP0807UiN@1fMWH0M7Ad07AdM01hN7P0NWYj07UiN@1eMGDI
07IfMQh0oooo5P2<S8`0<`2:RXX0RHV908Z:RP24Q8@0RHV907EeM@0c<c<0Shn?0;Jf]P2[Zj/0R8R8
0820P01bLW80NGUi07=cL`22PX80Ogmo07EeM@1DE5@0NWYj07inOP2@T900R8R806a/K01oOgl0WYjN
0:ZZZP2ATI40OGem06e]K@1UIFD0LW9b09RHV02m_Kd0]kNg0;Vi^@2HV9P0SXj>0:NWY`2OWil0LG5a
071`L02BTY80S8b<03Lg=`2BTY80Shn?096AT@2BTY80Shn?08j>SP0208b<S00808n?S`2<S8`0RHV9
08n?S`2EUID0TY:B08n?S`2>SXhI08b<S280oooo000P0?oooaT0N7Qh02/0LW9b07emO@1hN7P0OGem
0=SHf02=SHd0G5aL05=CD`1JFUX0MgMg08f=S@2DU9@0W9bL09RHV02MWId0UiNG0=3@d035aLD0i>CT
0<S8b02EUID0VYZJ09bLW022PX80OGem07inOP1cLg<0IFEU05=CD`1mOGd0L71`075aL@1mOGd0KVi^
07IfMP1lO7`0U9BD07inOP1ZJVX0N7Qh0<71`@1hN7P0OGem00<0N7Qh0100Ng]k07AdM01hN7P0N7Qh
07]kN`1hN7P0M7Ad07QhN01mOGd0N7Qh07]kN`1dM7@0N7Qh07AdM01hN7P0OGem5@1hN7PN0?oooaT0
MWIf0300L71`07alO01fMWH0N7Qh09jNWP26QXH0Fe]K06QXJ01_Kfl0KFe]06a/K01[Jf/0LW9b06AT
I01WIfL0Kfm_06e]K@1=CDd0IfMW05QHF01VIVH0NGUi06m_K`1OGel0M7Ad07EeM@1mOGd0TY:B07al
O02@T900QHF507moO`28R8P0MgMg08:2PP1`L700IfMW075aL@1`L700B4Q805aLG01;Bd/0Ng]k07If
MP1dM7@0MWIf07QhN01cLg<207IfMP0<07QhN01fMWH0MGEe07=cL`1iNGT0MWIf07YjNP1cLg<0NGUi
07EeM@1cLg<0NGUi5@1fMWHN0?oooaT0S8b<02X0RXZ:08n?S`2<S8`0RHV905iNGP2<S8`0Ph>309nO
W`2RXZ80P82006MWI`1NGUh0GemO055AD@1?Cdl0HF5Q028R8P0000000`<300`<301GEeL0Jf][05]K
F`1PH600Ph>308B4Q02JVYX0alO70;Zj^P2[Zj/0Z:RX0:2PX02NWYh0V9RH09nOW`1oOgl0F5QH07em
O@2BTY80Bd];01TI6@1>CTh208b<S00408V9R@2<S8`0RXZ:08^;R`80S8b<00`0RXZ:08b<S02>SXh0
QhN708V9R@2<S8`0SXj>08^;R`2?Shl0SXj>08N7Q`29RHTE08b<S280oooo000P0?oooaT0N7Qh02X0
LW9b07emO@1hN7P0N7Qh0<c<c03Ng]h0^;Rh05]KF`1=CDd0De=C08B4Q021PH40UIFE07QhN021PH40
MGEe07MgM`1LG5`0I6AT079bLP1nOWh0SXj>07inOP1lO7`0OWin06][J`1mOGd0QXJ606m_K`26QXH0
L71`06MWI`1lO7`0Q8B409RHV02>SXh0QhN707QhN02FUYH0LW9b07QhN01dM7@707QhN00507AdM01h
N7P0Ng]k07QhN01bLW800P1hN7P01@1kNg/0N7Qh07]kN`1hN7P0LW9b00X0N7Qh00<0OGem07QhN01d
M7@02@1hN7PN0?oooa40MWIf00<0Lg=c07IfMP1fMWH01@1fMWH07`1`L700O7al07IfMP1fMWH0VYZJ
071`L02>SXh0M7Ad069RHP1/K6`0KFe]06MWI`1kNg/0J6QX07YjNP1PH600NWYj07=cL`1mOGd0PH61
07=cL`1lO7`0LW9b07IfMP21PH40Q8B408n?S`28R8P0JVYZ09FEU@1jNWX00P1hN7P02`1/K6`0Jf][
05iNGP1dM7@0IVIV04i>CP0n?Sh0OGem07EeM@1jNWX0M7Ad00<0MWIf00D0M7Ad07UiN@1eMGD0MWIf
07QhN00207AdM00507YjNP1fMWH0N7Qh07AdM01hN7P00P1dM7@00`1jNWX0MWIf07IfMP0407IfMP03
07=cL`1fMWH0Lg=c0080NGUi00<0MGEe07IfMP1fMWH01`1fMWHN0?oooa40S8b<00<0QhN708b<S02<
S8`01@2<S8`0;02:RXX0Shn?08b<S02<S8`0IFEU01LG5`1ZJVX0YZJV09bLW02UYJD0LG5a06a/K01c
Lg<0MgMg08N7Q`1`L700Ti>C0:BTY02ZZZX0XJ6Q0861P@1lO7`0Ogmo08R8R02DU9@0[:b/0:VYZ@2F
UYH0Ph>30:RXZ02IVIT0X:2P08Z:RP1`L700FEUI055AD@1iNGT0MGEe03@d=013@d<0UIFE08j>SP2B
TY80RHV90`2<S8`03`29RHT0Shn?08j>SP2<S8`0RXZ:08V9R@2?Shl0TY:B08b<S02:RXX0RHV908Z:
RP29RHT0Shn?09:BTP0608b<S00608N7Q`2<S8`0QhN708V9R@2?Shl0SXj>2@2<S8`R0?ooo`00803o
oolA07QhN003079bLP1hN7P0N7Qh00@0N7Qh00@0OGem079bLP1mOGd0OGem0P1hN7P02@28R8P0i>CT
0<[:bP1]KFd0GemO06MWI`1QHF40KFe]079bLP0207QhN00C08>3P`21PH40QhN708F5Q@1bLW80OGem
07YjNP1eMGD0OWin096AT@1[Jf/0NWYj05iNGP20P800L71`079bLP22PX80RHV907UiN@0207EeM@05
09fMW@1hN7P0N7Qh07]kN`1dM7@00P1hN7P00`1mOGd0N7Qh07emO@0:07QhN00307emO@1hN7P0N7Qh
00X0N7Qh00<0LW9b07QhN021PH402P1hN7PN0?oooa40MWIf00<0M7Ad07IfMP1fMWH0101fMWH03`1i
NGT0L71`07UiN@1iNGT0Lg=c07IfMP1iNGT0Vi^K08J6QP1ZJVX0LG5a07EeM@1dM7@0Ng]k07EeM@02
079bLP0607]kN`1/K6`0M7Ad07QhN01bLW80OWin0P1lO7`01`1oOgl0S8b<0820P027QhL0Ng]k08j>
SP1XJ6P00P1SHf<206e]K@0;07inOP1eMGD0DE5A05ADE01fMWH0NWYj07=cL`1dM7@0Lg=c07UiN@1c
Lg<00P1iNGT00`1fMWH0M7Ad07IfMP0507IfMP0307=cL`1iNGT0MWIf00@0MWIf00D0Lg=c07IfMP1f
MWH0MWIf07=cL`0207IfMP0407AdM01fMWH0NWYj07AdM0T0MWIf7P3ooolA08b<S00308n?S`2<S8`0
S8b<00@0S8b<00l0RHV908Z:RP29RHT0RHV908N7Q`2<S8`0OWin04e=C@1:BTX0QhN709nOW`2KVi/0
XJ6Q09fMW@2@T9000`26QXH08@1dM7@0N7Qh0820P02;Rh/0TY:B096AT@2GUiL0TY:B092@T02WYjL0
XZ:R0:j^[P2UYJD0Ogmo07IfMP1UIFD0Jf][07emO@2JVYX0SXj>030`<01KFe/0S8b<08j>SP2;Rh/0
RHV908N7Q`29RHT0QhN708V9R@2?Shl0S8b<08V9R@0608b<S00308N7Q`29RHT0S8b<00@0S8b<00D0
QhN708b<S02<S8`0S8b<08N7Q`0208b<S00408n?S`2<S8`0QhN708V9R@T0S8b<8P3oool00200oooo
4@1hN7P00`1mOGd0N7Qh07QhN00907QhN00Q0861P@1hN7P0LW9b07emO@1hN7P0^KVi0<K6aP2RXZ80
FUYJ04];B`1PH600Jf][08:2PP1hN7P0OWin08:2PP2EUID0Shn?09FEU@1hN7P0LW9b07AdM02o_kl0
SXj>092@T02SXj<0Q8B4065QH@23Ph<0]kNg0;2`/021PH40OGem0080N7Qh00<0OGem07QhN01bLW80
0P1hN7P01`1mOGd0Ng]k07QhN01bLW80N7Qh079bLP1dM7@00`1hN7P00`1bLW80N7Qh07QhN00207em
O@0407QhN01mOGd0OGem07emO@@0N7Qh00<0OGem07QhN01bLW800P1hN7P00`1kNg/0OGem07QhN003
07QhN003079bLP1hN7P0N7Qh0080N7Qh7P3oool@07IfMP0307=cL`1iNGT0MWIf00T0MWIf0240NGUi
07YjNP1dM7@0L71`07alO01fMWH0Shn?05eMG@1kNg/0NWYj06m_K`1lO7`0LG5a07MgM`1`L700NGUi
07IfMP21PH40MgMg07emO@1_Kfl0O7al075aL@28R8P0EeMG05iNGP1gMgL0LW9b06IVIP1UIFD0JVYZ
05QHF01FEUH00P1fMWH0201cLg<0NGUi07IfMP1dM7@0MWIf07=cL`1iNGT0N7Qh0P1dM7@00`1jNWX0
MgMg07UiN@0207IfMP80M7Ad00P0NWYj07=cL`1iNGT0MGEe07=cL`1iNGT0MGEe07UiN@<0MWIf00L0
Lg=c07UiN@1fMWH0L71`07IfMP1jNWX0N7Qh00D0MWIf00<0M7Ad07YjNP1fMWH00P1fMWHN0?oooa00
S8b<00<0QhN708V9R@2<S8`02@2<S8`02@2?Shl0QhN708V9R@2:RXX0Shn?08b<S01YJFT05ADE06EU
I@020;6a/@0S0:f][@2BTY80PX:208>3P`29RHT0PH6107emO@1eMGD0MWIf0861P@2JVYX0RHV905UI
F@18B4P0Cdm?05iNGP1iNGT0SXj>06MWI`0g=cL09RHV05ADE026QXH0S8b<08N7Q`29RHT0S8b<08n?
S`2<S8`0QhN708V9R@2:RXX0RHV908n?S`2BTY800P2CTi<208b<S00:08V9R@2?Shl0TY:B08N7Q`29
RHT0Q8B408N7Q`29RHT0Q8B408V9R@<0S8b<00P0QhN708V9R@2<S8`0RXZ:08b<S02BTY80RXZ:08J6
QP@0S8b<00<0Shn?09:BTP2<S8`00P2<S8`R0?ooo`00803oool@07QhN00306i^KP1hN7P0N7Qh00T0
N7Qh00@0Ng]k07QhN01hN7P0LW9b101hN7P20;Vi^@050:BTY01`L700IVIV05MGE`1VIVH00P1aLG40
0`29RHT0Ti>C0:RXZ0020:BTY00308R8R02HV9P0PH610080HF5Q00@0R8R809BDU022PX80LW9b0P1h
N7P00`1dM7@0N7Qh079bLP0307QhN00407AdM01bLW80N7Qh07AdM080N7Qh00<0M7Ad07]kN`1hN7P0
101hN7P00`1dM7@0LW9b07QhN004079bLP0507AdM01hN7P0M7Ad07QhN01bLW800P1hN7P0101^KVh0
LW9b07QhN01bLW8:07QhN1h0oooo3`1fMWH00`1iNGT0Lg=c07YjNP0:07IfMP0607QhN01jNWX0MWIf
07AdM01jNWX0MWIf0P1cLg<07@2?Shl0J6QX07emO@1kNg/0NWYj07IfMP1dM7@0N7Qh079bLP1fMWH0
Jf][07MgM`1bLW80MGEe05mOG`23Ph<0MWIf07emO@1gMgL0MWIf05EEE@1QHF40JVYZ07IfMP1mOGd0
NGUi07IfMP1dM7@0NWYj0080MWIf00T0MGEe07AdM01mOGd0MGEe07IfMP1iNGT0MGEe07QhN01dM7@0
0`1fMWH0101iNGT0MGEe07AdM01jNWX307QhN00=07YjNP1iNGT0Lg=c07EeM@1fMWH0M7Ad07YjNP1f
MWH0Lg=c07QhN01jNWX0M7Ad07emO@0907IfMQh0oooo3`2<S8`00`2?Shl0TI6A09:BTP0:08b<S006
08Z:RP2BTY80S8b<08n?S`2BTY80S8b<0P27QhL07@1YJFT0<S8b06MWI`2JVYX0Y:BT0:j^[P2LW9`0
UIFE08f=S@1jNWX0H61P05YJFP1GEeL0Fe]K05YJFP1kNg/0PH610:j^[P2UYJD0Ng]k03lo?`1TI6@0
PH6108b<S02EUID0Ti>C08b<S02?Shl0TY:B0080S8b<00T0SXj>08n?S`2EUID0SXj>08b<S02?Shl0
SXj>08Z:RP29RHT00`2<S8`0102?Shl0SXj>08n?S`2BTY8309FEU@0=09RHV02CTi<0QhN708j>SP2<
S8`0Shn?09:BTP2<S8`0TI6A09FEU@2BTY80Shn?09FEU@0908b<S280oooo000P0?ooo`l0N7Qh00<0
Ng]k07QhN01mOGd03P1hN7P02P1dM7@0N7Qh079bLP1^KVh0M7Ad07QhN02ZZZX0[jn_0:ZZZP2JVYX2
08V9R@80N7Qh00X0HF5Q05eMG@1WIfL0N7Qh079bLP1eMGD0Ti>C0:ZZZP2PX:00Ti>C0P1hN7P0101b
LW80N7Qh0861P@1hN7P207emO@@0N7Qh00D0M7Ad07QhN01hN7P0N7Qh07]kN`0207QhN00707AdM01h
N7P0OGem07QhN01kNg/0N7Qh07emO@0407QhN00607]kN`1hN7P0LW9b07emO@1hN7P0OGem1P1hN7P0
0`1kNg/0N7Qh07QhN00407QhN00307emO@1hN7P0N7Qh01h0oooo3`1fMWH00`1hN7P0L71`07UiN@0=
07IfMP0D07UiN@1eMGD0MWIf071`L01eMGD0NGUi07IfMP29RHT0KFe]07=cL`1WIfL0Jf][07IfMP1X
J6P0Ng]k07moO`22PX80Ng]k07YjNP1fMWH207EeM@0;06UYJ@1NGUh0I6AT071`L01fMWH0L71`07If
MP1nOWh0L71`07EeM@1iNGT0101fMWH03P1gMgL0MWIf07AdM01fMWH0N7Qh07AdM01iNGT0MGEe07=c
L`1kNg/0MWIf07QhN01`L700NGUi101fMWH01P1hN7P0M7Ad07AdM01fMWH0Lg=c07UiN@80MWIf00D0
M7Ad07IfMP1fMWH0MWIf07AdM00607IfMP0307UiN@1fMWH0MWIf01h0oooo3`2<S8`00`2:RXX0Q8B4
08V9R@0=08b<S00908n?S`2>SXh0S8b<08Z:RP2DU9@0Ti>C08b<S01aLG40@d=30080DU9B00L0JFUY
07UiN@1gMgL0Ti>C0;6a/@2i^KT0YJFU0080TY:B00X0SHf=06e]K@13@d<0?clo05EEE@23Ph<0S8b<
08Z:RP2<S8`0SHf=0P24Q8@00`29RHT0S8b<08b<S00208b<S009096AT@2<S8`0RHV908b<S02:RXX0
RHV908n?S`2>SXh0QhN70080S8b<00<0RXZ:08B4Q029RHT0102<S8`01P2:RXX0RHV908n?S`26QXH0
QhN708V9R@80S8b<00D0RHV908b<S02<S8`0S8b<08F5Q@0608b<S00308V9R@2<S8`0S8b<0280oooo
000P0?oooa00N7Qh00<0LW9b07QhN01hN7P02@1hN7P0201mOGd0N7Qh07QhN01kNg/0N7Qh07AdM01b
LW80Ng]k0`1hN7P207]kN`0508N7Q`22PX80R8R807alO02CTi<00P2JVYX01P2@T900Shn?09bLW02B
TY80PX:207]kN`80N7Qh00D0OGem07QhN01bLW80LW9b07emO@02079bLP0607QhN01dM7@0N7Qh07em
O@1kNg/0PH61101hN7P0101mOGd0Ng]k07emO@1bLW8207QhN00307AdM01bLW80N7Qh00L0N7Qh00@0
M7Ad079bLP1hN7P0OGem0`1hN7P00`1mOGd0N7Qh079bLP0907QhN1h0oooo401fMWH00`1dM7@0OGem
07IfMP0807IfMP0:07=cL`1kNg/0MWIf07IfMP1hN7P0MWIf07EeM@1dM7@0MWIf07AdM080MWIf00T0
N7Qh079bLP1jNWX0M7Ad07IfMP1^KVh0O7al07=cL`1]KFd00P1YJFT0201bLW80KFe]06UYJ@1aLG40
M7Ad07=cL`1iNGT0MWIf0P1dM7@02`1lO7`0M7Ad07QhN01mOGd0MGEe07=cL`1iNGT0M7Ad07QhN01d
M7@0MWIf0080Lg=c00T0NGUi07AdM01fMWH0MgMg07YjNP1iNGT0MGEe07AdM01jNWX01`1fMWH0101i
NGT0M7Ad07IfMP1iNGT207IfMP0407=cL`1iNGT0MWIf07AdM0H0MWIf00<0NWYj07IfMP1fMWH07P3o
ool@08b<S00308n?S`2EUID0S8b<00P0S8b<00X0QhN708b<S02<S8`0S8b<08Z:RP2<S8`0SXj>08n?
S`27QhL0RHV90P2<S8`04`2:RXX0PX:20861P@1nOWh0NWYj07]kN`1gMgL0I6AT05]KF`1PH600HF5Q
061PH01RHV80Kfm_0861P@29RHT0QhN708V9R@2<S8`0102?Shl209FEU@0708j>SP27QhL0RHV908F5
Q@24Q8@0RHV908b<S00208N7Q`0908V9R@25QHD0QXJ609>CT`2BTY80Shn?08j>SP2?Shl0TY:B00L0
S8b<00@0Ti>C08n?S`2<S8`0RHV90P2<S8`01027QhL0RHV908b<S02?Shl608b<S00309:BTP2<S8`0
S8b<0280oooo000P0?oooa40N7Qh00<0Ng]k07QhN01hN7P01`1hN7P00`1bLW80Ng]k07QhN00507Qh
N00607emO@1hN7P0N7Qh07QhN01dM7@0KVi^0P1hN7P00`1mOGd0M7Ad07]kN`0307]kN`04079bLP1m
OGd0N7Qh07AdM080N7Qh00H0LW9b07QhN01hN7P0OGem079bLP1mOGd307QhN00407emO@1bLW80OGem
079bLP<0N7Qh0P1bLW801@1hN7P0LW9b07emO@1hN7P0M7Ad00P0N7Qh00<0OGem07QhN01hN7P00P1h
N7P01P1bLW80OGem07QhN01hN7P0KVi^07QhN080OGem1P1hN7P00`1mOGd0N7Qh07AdM00N0?oooa40
MWIf00<0N7Qh07IfMP1fMWH01`1fMWH01`1dM7@0O7al07IfMP1fMWH0NGUi07IfMP1dM7@00P1iNGT2
07IfMP0807UiN@1eMGD0Lg=c07YjNP1cLg<0Ng]k07EeM@1hN7P307IfMP0406i^KP1lO7`0NGUi07Ee
M@80MWIf00h0M7Ad07YjNP1cLg<0NGUi071`L01lO7`0MWIf07UiN@1cLg<0MWIf071`L01iNGT0M7Ad
07YjNP80MWIf0P1dM7@01`1jNWX0L71`07moO`1iNGT0Lg=c07IfMP1dM7@01@1fMWH03P1cLg<0NGUi
07IfMP1fMWH0M7Ad07IfMP1`L700O7al07IfMP1iNGT0Lg=c07IfMP1eMGD0NGUi1P1fMWH207UiN@03
07EeM@3oool0oooo01`0oooo4@2<S8`00`2:RXX0S8b<08b<S00708b<S00908n?S`2@T900S8b<08b<
S02?Shl0S8b<08V9R@2?Shl0RHV90080S8b<00P0Shn?08j>SP2ATI40TY:B08N7Q`2<S8`0SXj>08Z:
RP@0QhN70P2?Shl04@2>SXh0S8b<08b<S02?Shl0TY:B08N7Q`29RHT0RXZ:08n?S`2<S8`0Shn?08N7
Q`26QXH0RXZ:08V9R@2?Shl0TY:B0080S8b<0P2?Shl01`2BTY80RXZ:09:BTP2?Shl0Rh^;08b<S029
RHT01@2<S8`03P27QhL0RHV908b<S02<S8`0RHV908b<S02:RXX0Shn?08b<S02?Shl0TI6A08b<S024
Q8@0RHV91P2<S8`00`29RHT0Shn?08j>SP0R0?ooo`00803oool?07QhN00307emO@1hN7P0N7Qh0080
N7Qh00<0M7Ad07QhN01hN7P01`1hN7P00`1dM7@0OGem07QhN002079bLP80N7Qh00@0Ng]k07QhN01d
M7@0M7Ad0P1hN7P01@1bLW80OGem079bLP1hN7P0OGem00<0N7Qh00H0M7Ad07QhN01hN7P0N7Qh07]k
N`1bLW8207QhN080LW9b00P0OGem07QhN01hN7P0N7Qh07emO@1kNg/0LW9b07AdM080OGem00<0N7Qh
07AdM01mOGd01P1hN7P02`1bLW80PH6107QhN01hN7P0OGem079bLP1hN7P0OGem079bLP1mOGd0PH61
0080N7Qh00D0OGem07QhN01hN7P0N7Qh079bLP0607QhN00407emO@1hN7P0LW9b07QhN1h0oooo3P1f
MWH01`1cLg<0NGUi07IfMP1iNGT0NWYj07UiN@1eMGD0201fMWH01P1iNGT0LG5a07UiN@1fMWH0M7Ad
07YjNP80MWIf00@0N7Qh07IfMP1aLG40NGUi0P1fMWH0101`L700O7al07AdM01fMWH207UiN@0307If
MP1dM7@0MGEe00<0MWIf00@0N7Qh07AdM01jNWX0MWIf0P1dM7@01`1lO7`0NGUi07IfMP1`L700NGUi
07QhN01gMgL00P1eMGD0101iNGT0MWIf07EeM@1iNGT307IfMP0F07=cL`1fMWH0MWIf071`L01nOWh0
M7Ad07=cL`1iNGT0M7Ad07IfMP1iNGT0M7Ad07EeM@1jNWX0M7Ad07=cL`1iNGT0MWIf07UiN@1fMWH0
LW9b07YjNP@0MWIf00D0Lg=c07UiN@1fMWH0M7Ad07YjNP0N0?ooo`h0S8b<00L0QhN708V9R@2<S8`0
Shn?09:BTP2?Shl0SXj>00P0S8b<00H0Shn?08V9R@29RHT0S8b<08n?S`2HV9P208b<S00408Z:RP2<
S8`0RHV909>CT`80S8b<00T0RXZ:08n?S`2?Shl0S8b<08V9R@2?Shl0S8b<08V9R@2>SXh00`2<S8`0
102:RXX0Shn?09:BTP2<S8`408n?S`0;08b<S024Q8@0RHV908Z:RP2CTi<0SXj>08B4Q029RHT0S8b<
08j>SP29RHT00`2<S8`04`27QhL0S8b<08b<S02:RXX0SHf=08V9R@27QhL0RHV908n?S`2<S8`0RHV9
08n?S`24Q8@0QhN708V9R@27QhL0RHV908b<S02?Shl00P2<S8`00`2BTY80S8b<08b<S00208b<S005
08N7Q`29RHT0S8b<08n?S`2BTY808P3oool00200oooo3P1hN7P01P1bLW80N7Qh07QhN01kNg/0N7Qh
0861P@T0N7Qh00<0Ng]k079bLP1hN7P00P1hN7P01P1kNg/0N7Qh07QhN01hN7P0Ng]k06i^KP80N7Qh
00P0OGem06i^KP1hN7P0N7Qh079bLP1hN7P0Ng]k07emO@H0N7Qh00T0M7Ad07QhN01mOGd0N7Qh079b
LP1hN7P0Ng]k07QhN01bLW800P1hN7P01P1kNg/0LW9b079bLP1dM7@0N7Qh079bLP<0N7Qh00P0M7Ad
07QhN01mOGd0N7Qh079bLP1mOGd0N7Qh06i^KP80N7Qh00@0LW9b07QhN01hN7P0LW9b0P1hN7P0101b
LW80N7Qh07AdM01kNg/707QhN00306i^KP1mOGd0N7Qh0080N7Qh7P3oool>07IfMP0707AdM01jNWX0
MWIf07QhN01cLg<0NWYj07AdM00807IfMP0307QhN01bLW80NWYj0080MWIf00X0N7Qh07IfMP1fMWH0
MWIf07YjNP1aLG40M7Ad07=cL`1kNg/0Lg=c0P1fMWH01P1dM7@0NWYj07AdM01fMWH0Lg=c07AdM0@0
MWIf00L0MGEe07=cL`1iNGT0MWIf07AdM01jNWX0N7Qh0080M7Ad00`0NWYj07IfMP1hN7P0LW9b07Yj
NP1iNGT0MWIf079bLP1jNWX0MWIf07UiN@1aLG4207UiN@0B07IfMP1`L700O7al07IfMP1cLg<0NWYj
07IfMP1dM7@0NWYj07IfMP1hN7P0NWYj07IfMP1dM7@0NWYj07EeM@1hN7P0M7Ad1@1fMWH00`1iNGT0
Kfm_07alO00307IfMQh0oooo3P2<S8`0102?Shl0TY:B08b<S02:RXX208N7Q`0308V9R@2<S8`0S8b<
00H0S8b<00<0RXZ:08b<S02BTY800P2<S8`0102:RXX0S8b<08b<S02<S8`208j>SP0408V9R@27QhL0
S8b<096AT@80S8b<00H0Shn?09:BTP25QHD0QXJ608N7Q`29RHT408b<S00?08j>SP27QhL0RHV908b<
S02?Shl0TY:B08Z:RP29RHT0Shn?09:BTP2<S8`0RXZ:08b<S02HV9P0Ti>C0080S8b<01P0TY:B08b<
S02?Shl0RHV908n?S`29RHT0S8b<08Z:RP2?Shl0S8b<096AT@2BTY80S8b<08n?S`2BTY80S8b<09FE
U@2BTY80S8b<08n?S`2BTY80SXj>08Z:RP29RHT508b<S00308n?S`2<S8`0Shn?00<0S8b<8P3oool0
0200oooo4P1hN7P00`1bLW80N7Qh07QhN00807QhN00307AdM01hN7P0N7Qh00H0N7Qh00P0Ng]k07Ad
M01hN7P0LW9b07]kN`1hN7P0KVi^07emO@<0N7Qh00<0M7Ad079bLP1hN7P00P1hN7P01`1mOGd0N7Qh
07AdM01bLW80N7Qh07emO@1dM7@00P1hN7P00`1mOGd0N7Qh07QhN00207emO@0507QhN01kNg/0N7Qh
07QhN01mOGd00P1hN7P01P1kNg/0LW9b07]kN`1hN7P0OGem079bLPD0N7Qh00H0OGem07QhN01mOGd0
N7Qh07emO@1dM7@407QhN00307emO@1hN7P0N7Qh00<0N7Qh00<0Ng]k079bLP1hN7P00P1hN7P00`1d
M7@0oooo0?ooo`0L0?oooa40MWIf00<0Lg=c07AdM01jNWX02@1fMWH00`1eMGD0MWIf07IfMP0607If
MP0:07YjNP1eMGD0MWIf07AdM01lO7`0MWIf06m_K`1iNGT0MWIf07=cL`80NGUi00@0M7Ad07IfMP1f
MWH0Lg=c0P1iNGT01@1cLg<0M7Ad07IfMP1kNg/0MGEe0080Lg=c00<0NGUi07IfMP1cLg<00P1iNGT0
1@1fMWH0N7Qh07AdM01fMWH0NGUi0080MWIf0140N7Qh079bLP1nOWh0MWIf07UiN@1dM7@0NWYj07=c
L`1dM7@0MWIf07=cL`1iNGT0Lg=c07UiN@1cLg<0Ng]k07EeM@0207IfMP0507AdM01cLg<0NGUi07If
MP1cLg<00`1fMWH01P1hN7P0LW9b07YjNP1fMWH0NGUi07MgMah0oooo4@2<S8`00`27QhL0Shn?09:B
TP0908b<S00308j>SP2<S8`0S8b<00H0S8b<0P2>SXh00`2<S8`0Shn?092@T00208b<S00608V9R@2<
S8`0QhN708n?S`2CTi<0Shn?0P2<S8`01@27QhL0RHV908n?S`2;Rh/0Shn?0080S8b<00H0SXj>08N7
Q`27QhL0RHV908b<S027QhL208V9R@0508b<S02:RXX0RHV908b<S029RHT00P2<S8`04@2:RXX0S8b<
09>CT`2<S8`0RHV908n?S`2BTY80QhN708V9R@2<S8`0QhN708V9R@27QhL0RHV908N7Q`2<S8`0SXj>
0080S8b<00D0RHV908N7Q`29RHT0S8b<08N7Q`0308b<S00608Z:RP2<S8`0TY:B08b<S02?Shl0TI6A
8P3oool00200oooo4@1hN7P00`1bLW80N7Qh07emO@0:07QhN00407emO@1hN7P0N7Qh07AdM0@0N7Qh
0P1kNg/01@1mOGd0N7Qh07QhN01kNg/0LW9b0080N7Qh00<0KVi^0861P@1hN7P00`1hN7P00`1bLW80
N7Qh07]kN`0207QhN00306i^KP1kNg/0OGem0080LW9b0P1hN7P00`1^KVh0OGem07emO@0307QhN003
07AdM01hN7P0N7Qh00<0N7Qh00h0Ng]k07QhN01dM7@0M7Ad07QhN01bLW80M7Ad07QhN01bLW80N7Qh
079bLP1mOGd0LW9b07]kN`<0N7Qh00D0OGem079bLP1hN7P0N7Qh079bLP0607QhN00307AdM01kNg/0
PH6101h0oooo4@1fMWH00`1dM7@0Lg=c07UiN@0907IfMP06071`L01iNGT0MWIf07UiN@1eMGD0NGUi
0`1fMWH00`1hN7P0MWIf07UiN@0207IfMP0707QhN01bLW80NWYj07UiN@1_Kfl0OWin07AdM00307If
MP0?07AdM01jNWX0N7Qh07AdM01iNGT0Lg=c07QhN01fMWH0L71`07AdM01jNWX0NGUi06m_K`1oOgl0
O7al0080MWIf00<0NGUi07EeM@1jNWX0101fMWH03`1hN7P0NGUi07]kN`1eMGD0MWIf07AdM01eMGD0
MWIf07AdM01jNWX0L71`07alO01dM7@0O7al07AdM00207IfMP0507UiN@1dM7@0NWYj07IfMP1dM7@0
1P1fMWH00`1eMGD0M7Ad07QhN00N0?oooa40S8b<00<0Shn?08N7Q`29RHT02@2<S8`01P24Q8@0RHV9
08b<S02?Shl0SXj>08n?S`<0S8b<00<0RXZ:08N7Q`29RHT00P2<S8`01`2:RXX0S8b<09:BTP2?Shl0
S8b<08f=S@29RHT00`2<S8`03`2?Shl0TY:B08Z:RP29RHT0Shn?096AT@2:RXX0QXJ608Z:RP2?Shl0
TY:B08n?S`2<S8`0TY:B08n?S`0208b<S00308n?S`2>SXh0TY:B00@0S8b<00/0RXZ:08n?S`2GUiL0
SXj>08b<S02?Shl0SXj>08b<S02?Shl0TY:B08Z:RP0208n?S`09092@T029RHT0S8b<08b<S029RHT0
Shn?09:BTP2<S8`0Shn?00H0S8b<00<0SXj>08F5Q@24Q8@08P3oool00200oooo4P1hN7P00`1bLW80
N7Qh07AdM00707QhN00507AdM01bLW80N7Qh07AdM01kNg/01@1hN7P207emO@80N7Qh00<0M7Ad07Qh
N01hN7P00P1hN7P01@1bLW80N7Qh07emO@1hN7P0OGem00@0N7Qh00L0OGem07]kN`1mOGd0LW9b07Ad
M01hN7P0M7Ad0080N7Qh00l0LW9b07]kN`1hN7P0N7Qh07AdM01kNg/0N7Qh07AdM01mOGd0N7Qh07Ad
M01hN7P0M7Ad07]kN`21PH401`1hN7P00`1bLW80N7Qh07QhN00607QhN00307AdM01hN7P0N7Qh00L0
N7Qh00<0LW9b07QhN03oool07@3ooolB07IfMP0307AdM01mOGd0MGEe00H0MWIf00P0NGUi075aL@1d
M7@0OGem07EeM@1hN7P0MWIf07UiN@80MWIf00H0Lg=c07EeM@1iNGT0NWYj07UiN@1eMGD207IfMP04
07UiN@1fMWH0LW9b07IfMP<0NGUi101fMWH04@1iNGT0M7Ad07IfMP1gMgL0MGEe07IfMP1eMGD0NGUi
07IfMP1bLW80N7Qh07YjNP1iNGT0MGEe07QhN01`L700LG5a0080NGUi00<0MGEe07UiN@1aLG400P1h
N7P0101dM7@0MWIf07UiN@1dM7@307IfMP0307AdM01jNWX0MWIf00@0MWIf00<0NWYj07UiN@1eMGD0
201fMWH207AdM00307YjNP3oool0oooo01`0oooo4P2<S8`00`2?Shl0UIFE08j>SP0608b<S00808n?
S`29RHT0Shn?09FEU@2>SXh0RXZ:08b<S02?Shl208b<S00608N7Q`24Q8@0RHV909:BTP2?Shl0SXj>
0P2<S8`01`2?Shl0S8b<08b<S02<S8`0RHV908n?S`29RHT0102<S8`02029RHT0QHF508J6QP2CTi<0
SXj>08b<S02>SXh0Shn?0P2<S8`01P2:RXX0TY:B08n?S`2>SXh0RXZ:08B4Q080RHV900X0Shn?08j>
SP2?Shl0RHV908Z:RP24Q8@0RHV908b<S02?Shl0RHV90`2<S8`00`2?Shl0TY:B08b<S00408b<S003
09:BTP2?Shl0SXj>00P0S8b<00<0RHV908n?S`2BTY808P3oool00200oooo401hN7P01`1mOGd0N7Qh
07QhN01hN7P0M7Ad07QhN01dM7@0101hN7P0301mOGd0N7Qh07QhN01bLW80N7Qh079bLP1dM7@0Ng]k
079bLP1dM7@0Ng]k079bLP@0N7Qh00@0M7Ad07QhN01bLW80LW9b0P1hN7P01P1mOGd0N7Qh07QhN01h
N7P0OGem07AdM0L0N7Qh0`1bLW8307QhN00307]kN`1hN7P0LW9b0080N7Qh101bLW8207QhN00507em
O@1hN7P0N7Qh06i^KP1mOGd00`1hN7P00`21PH40N7Qh07QhN00307QhN005079bLP1dM7@0N7Qh07Ad
M01bLW800`1hN7P01@1bLW80N7Qh079bLP1hN7P0LW9b0080N7Qh7P3oool?07IfMP0807=cL`1iNGT0
Lg=c07IfMP1iNGT0MGEe07UiN@1eMGD307IfMP0807=cL`1iNGT0MWIf07IfMP1dM7@0NWYj07MgM`1i
NGT207YjNP0407UiN@1hN7P0LW9b07YjNP80MWIf0100NGUi07EeM@1fMWH0M7Ad07QhN01jNWX0Lg=c
07UiN@1fMWH0NWYj07=cL`1kNg/0MGEe07=cL`1fMWH0NWYj101fMWH307QhN00407YjNP1cLg<0MWIf
07QhN080M7Ad00<0OGem07IfMP1dM7@00`1hN7P01`1fMWH0Lg=c07UiN@1fMWH0NGUi07=cL`1lO7`0
0P1fMWH00`1cLg<0NWYj07AdM00407IfMP0607AdM01eMGD0NGUi07EeM@1dM7@0NWYj0P1fMWH01`1d
M7@0NWYj07AdM01jNWX0M7Ad07YjNP1fMWH07P3oool?08b<S00808N7Q`29RHT0QhN708b<S02?Shl0
SXj>08n?S`2>SXh308b<S00608N7Q`29RHT0S8b<08b<S02?Shl0TY:B0P2CTi<01P2>SXh0V9RH09>C
T`2:RXX0S8b<09:BTP80S8b<0100Shn?08j>SP2<S8`0Shn?09FEU@2BTY80QhN708V9R@2<S8`0TY:B
08N7Q`2<S8`0SXj>08N7Q`2<S8`0TY:B102<S8`309FEU@0909:BTP27QhL0S8b<08Z:RP29RHT0Shn?
09FEU@2<S8`0Shn?00<0UIFE00L0S8b<08N7Q`29RHT0S8b<08n?S`2ATI40Shn?0080S8b<0P27QhL0
0`29RHT0S8b<08b<S00208b<S00608n?S`2>SXh0Shn?08j>SP2?Shl0TY:B0P2<S8`01`2?Shl0TY:B
08n?S`2BTY80Shn?09:BTP2<S8`08P3oool00200oooo3`1hN7P01`1bLW80OGem079bLP1mOGd0Ng]k
07QhN01kNg/0101hN7P00`1bLW80N7Qh07QhN00207QhN00307AdM01kNg/0N7Qh0080Ng]k00@0N7Qh
07emO@1hN7P0OGem0P1hN7P00`1kNg/0N7Qh07QhN00407QhN00507emO@1hN7P0N7Qh06i^KP1kNg/0
3@1hN7P01@1mOGd0N7Qh07QhN01hN7P0Ng]k00D0N7Qh00D0LW9b07QhN01mOGd0N7Qh07]kN`0407Qh
N003079bLP1hN7P0N7Qh00@0N7Qh00@0OGem07AdM01kNg/0M7Ad101hN7P00`1mOGd0M7Ad07QhN004
07QhN1h0oooo3`1fMWH0201`L700O7al07AdM01iNGT0N7Qh07AdM01hN7P0M7Ad0`1fMWH0201dM7@0
NWYj07IfMP1fMWH0NGUi07EeM@1hN7P0M7Ad0P1hN7P0101`L700NGUi07=cL`1iNGT207IfMP0307Qh
N01dM7@0MWIf0080MWIf0P1cLg<0201lO7`0MWIf07UiN@1cLg<0O7al071`L01cLg<0NWYj201fMWH2
07=cL`0507UiN@1fMWH0MWIf07IfMP1hN7P01@1fMWH01`1`L700Lg=c07alO01fMWH0N7Qh07AdM01j
NWX00P1fMWH00`1dM7@0NWYj07IfMP0307IfMP0;07=cL`1iNGT0Lg=c07YjNP1cLg<0MWIf07=cL`1f
MWH0Lg=c07]kN`1eMGD01@1fMWHN0?ooo`l0S8b<00P0RXZ:08n?S`2?Shl0RHV908Z:RP29RHT0RXZ:
08V9R@<0S8b<00P0Shn?09:BTP2<S8`0S8b<08n?S`2>SXh0RXZ:08V9R@80RXZ:00@0Q8B408V9R@27
QhL0RHV90P2<S8`00`2:RXX0RHV908b<S00208b<S080QhN700P0Shn?08b<S02?Shl0TI6A092@T024
Q8@0QhN709:BTPP0S8b<0P27QhL01@29RHT0S8b<08b<S02<S8`0RXZ:00D0S8b<00L0RXZ:08N7Q`2?
Shl0S8b<08Z:RP29RHT0TY:B0080S8b<00<0Shn?09:BTP2<S8`00`2<S8`02`27QhL0RHV908^;R`2>
SXh0Rh^;08b<S027QhL0S8b<08N7Q`2<S8`0SXj>00D0S8b<8P3oool00?l0oooo``3oool00?l0oooo
``3oool00?l0oooo``3oool00?l0oooo``3oool00?l0oooo``3oool005T0oooo0T00002;0?ooo`90
0000R`3oool2@00004d0oooo001K0?ooo`03@000003oool0oooo08X0oooo00=000000?ooo`3oool0
RP3oool00d000000oooo0?ooo`1:0?ooo`00B@3oool00d000000oooo0?ooo`030?ooo`=000000P3o
ool2@00000<0oooo0d0000050?ooo`03@000003oool0oooo06/0oooo0T0000040?ooo`03@000003o
ool0oooo00@0oooo0d0000020?ooo`9000000`3oool3@00000D0oooo00=000000?ooo`3oool0I03o
ool5@00000040?oood0000100000@00000<0oooo00=000000?ooo`3oool01@3oool3@0000080oooo
0T0000030?ooo`=000001@3oool00d000000oooo0?ooo`140?ooo`00B03oool00d000000oooo@000
00030?ooo`06@000003oool0oooo@000003ooom00000103oool014000000oooo0?oood00001c0?oo
o`03@000003ooom000000080oooo00=000000?oood000000103oool01T000000oooo0?oood000000
oooo@00000@0oooo00A000000?ooo`3ooom00000KP3oool01D000000oooo0?ooo`3ooom0000000@0
oooo00=000000?oood0000001@3oool01T000000oooo0?oood000000oooo@00000@0oooo00A00000
0?ooo`3ooom00000C03oool004P0oooo00=000000?oood0000000`3oool01D000000oooo0?oood00
0000oooo00=000000P3oool014000000oooo0?oood00001c0?ooo`03@000003ooom000000080oooo
00=000000?oood000000103oool01D000000oooo0?oood000000oooo00=000000P3oool014000000
oooo0?oood00001^0?ooo`03@000003oool0oooo0080oooo00M000000?ooo`3oool0oooo@000003o
oom0000000D0oooo00E000000?ooo`3ooom000000?ooo`03@0000080oooo00A000000?ooo`3ooom0
0000C03oool004P0oooo00=000000?oood000000103oool3@00000040?oood0000100000@00000<0
oooo0d00001c0?ooo`9000000`3oool00d000000oooo@00000050?ooo`=0000000@0oooo@0000400
001000000`3oool3@00006h0oooo00=000000?ooo`3oool00P3oool01d000000oooo0?ooo`3ooom0
00000?oood0000001P3oool3@00000040?oood0000100000@00000<0oooo0d00001<0?ooo`00B03o
ool00d000000oooo@00000060?ooo`03@000003oool0oooo07/0oooo00=000000?ooo`3oool00P3o
ool00d000000oooo@00000070?ooo`03@000003oool0oooo07H0oooo00M000000?ooo`3oool0oooo
@000003ooom000000080oooo00=000000?oood000000203oool00d000000oooo0?ooo`1D0?ooo`00
B@3oool00d000000oooo0?ooo`040?ooo`900000OP3oool2@00000<0oooo00=000000?ooo`3oool0
1@3oool2@00007L0oooo0T0000040?ooo`03@000003oool0oooo0080oooo00=000000?ooo`3oool0
1P3oool2@00005H0oooo003o0?oool<0oooo003o0?oool<0oooo003o0?oool<0oooo003o0?oool<0
oooo003o0?oool<0oooo003o0?oool<0oooo003o0?oool<0oooo003o0?oool<0oooo003o0?oool<0
oooo003o0?oool<0oooo003o0?oool<0oooo003o0?oool<0oooo003o0?oool<0oooo003o0?oool<0
oooo003o0?oool<0oooo003o0?oool<0oooo003o0?oool<0oooo003M0?ooo`900000h`3oool00=l0
oooo00=000000?ooo`3oool0h03oool00=40oooo0T0000000`3ooom00000@0000002@0000080oooo
00=000000?ooo`3oool00d000000103ooom00000@000040000030?ooo`900000f@3oool00=40oooo
00M000000?ooo`3oool0oooo@000003ooom000000080oooo00=000000?oood0000000P3oool01400
0000oooo0?oood0000030?ooo`03@000003oool0oooo0=T0oooo003B0?ooo`=000000P3oool01T00
0000oooo0?oood000000oooo@0000080oooo00A000000?ooo`3ooom000000`3oool3@0000=T0oooo
003B0?ooo`04@000003ooom000000?ooo`A000000`3oool3@0000080oooo00A000000?ooo`3oool0
oooo0d00003I0?ooo`00d`3oool00d000000oooo0?ooo`0<0?ooo`03@000003oool0oooo0=d0oooo
003B0?ooo`9000003@3oool2@0000=l0oooo003o0?oool<0oooo003o0?oool<0oooo0000\
\>"],
  ImageRangeCache->{{{0, 449}, {294.313, 0}} -> {-0.178538, -0.0492293, 
  0.00747679, 0.00747679}, {{23.875, 149.25}, {287.688, 
  162.313}} -> {-39.4226, -10.476, 1.19477, 1.19477}, {{161.75, 287.188}, {
  287.688, 162.313}} -> {-204.189, -10.476, 1.19477, 1.19477}, {{299.688, 
  425.063}, {287.688, 162.313}} -> {-368.956, -10.476, 1.19477, 1.19477}, {{
  23.875, 149.25}, {149.75, 24.375}} -> {-39.4226, -175.28, 1.19477, 
  1.19477}, {{161.75, 287.188}, {149.75, 24.375}} -> {-204.189, -175.28, 
  1.19477, 1.19477}, {{299.688, 425.063}, {149.75, 
  24.375}} -> {-368.956, -175.28, 1.19477, 1.19477}}]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
  StyleBox["\t",
    FontFamily->"Century",
    FontSize->10.5],
  StyleBox[
  "Further, we compute the more realistic three-dimensional image by \
convoluting the relief images in Fig.5 with the original monochrome image in \
Fig.1. The obtained images are shown in Fig.6.",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell["\<\
cAngle=Table[monoSample*(1-imageNormalize[angle[[i]]]),{i,rotation}];\t\
\>", "Input",
  CellLabel->"In[36]:="],

Cell["\<\
cAngleG=Table[Table[ListDensityPlot[cAngle[[i]],
\tPlotRange->All,Mesh->False,Frame->False,
\tPlotLabel->StringForm[\"`1`deg.\",(i-1)360/rotation],
\tDisplayFunction->Identity]],
\t{i,rotation}];\
\>", "Input",
  CellLabel->"In[37]:="],

Cell[CellGroupData[{

Cell["\<\
Show[convertRGB[Table[cAngle[[i]],{i,1,rotation,rotation/3}]],
\tAspectRatio->1,PlotLabel->\"Fig.6.Convoluted images\"];
Show[GraphicsArray[
\tTable[Table[cAngleG[[i+j]],{j,0,2}],{i,1,rotation,3}]],
\tImageSize->{450,300},PlotLabel->\"Angle\"];\
\>", "Input",
  CellLabel->"In[38]:="],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00744048 0.0238095 0.00744048 [
[.5 1.0125 -71 0 ]
[.5 1.0125 71 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -132 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Fig) show
81.000000 12.812500 moveto
(.6) show
93.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(.) show
99.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Convoluted) show
165.000000 12.812500 moveto
(images) show
201.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
384 string
128 128 8 [128 0 0 128 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
7F6C6F806C6F88716E836F737A6A74806C6F7D6A707E6B6F89726C786975816D6E605974716063\
7160637260637864626E5F6772606372606372606372606392735D7968712A356B
8E693D77625E685A656D5C5F665860725F5B6E5D60645761735F5B6F5E606D5D606F5E60655861\
6A595C725F5B6E5D6074615F715F636B5C636E5D606D5D606E5D606E5D606F5E60
6155627560596E5D606E5D6077635F7261647261647261647261647261647261646F5F65746262\
695B656E5D60726060756261695B656E5D606E5D606E5D606E5D606D5D606E5D60
6E5D606E5D606F5E606E5D606B5C61705E5F6E5D606D5D606F5E606E5D606D5D60876C5C887067\
706372363C6A7F62466A595C725F5B6E5D606558616A595C6A595C705E5B6D5C5F
6D5C5F6D5C5F6D5C5F6D5C5F76625E705F636C5D637360607B66616F6068796563756367756367\
6D5F687A65626C5E68695B646C5C6061556067585A6C5A5A6A595C68595C65575C
8B6D547765694C4A6B8166518A6F5D876F6A86706F7A6A74
7F6C6F816E6F846C6E82647181677283746F7D7772797071846A6D8270737B70706C7477626969\
716163726163755E62725D66726063726063715F63725F6382565D8B5E6A324C76
7F744375625E695B646C5D5F695E616A595C6E535E69565F6F595A725B5E6E5D606E5D60696062\
69645F6A5B5C725C5F74625F6E5B626E5B626E5C606E5C6068525F71535D725B5E
6760636A5B5B735A5E6F5D60725A5E735661755B62725B63715762735662775E626C5A64735860\
726164696062705C607359606E59636E5D607061616C5E616E5D606D5D606E5D60
6E5E606E5E606E5E606E5D606D5E616D5C5F6B545F735B5F6E5E606E5C606E5D607A575B8F5B61\
806C703751735B41478654546E615D6E5D606558616A595C6A595C6D585B6D545D
715C5E6D5F606D5F606D5F6074625E6E5A627260626E5D61795C5F735B66765D62765A65765A65\
756367726063715D66685A646D5D6066606267655E665E5C6A595C6C605D748160
77835D644D68614E69725D54936A5A876F6A83696F806873
80696F81696E81676F806B707F6D6F84696E8465718068737F6C7084696E846F737D77726A7C77\
60696A715F63725F63725F63705D63735E63715F636F5B63745E6288695E5A7C7A
3F374F9844506F5B626B5E6069565F66515E6D585B6E615D6A635E6E605D6F5E606D5D606F5E60\
6D5D606657616D535B7B5C5D6E60646B5F616D5D606A575F685860695A5B6E555B
6B4D5D6A4E5D6E505972525C715A5F6F5E60715C5F735E626B5D636E5D60735B5F6E59636E5C60\
735B5E6E59637163616F67626D68636C65626F61617065636960626E5E616E5E60
6E5E606E5D606E5D606E5D606E5D606C5D616961616E625D6E5D606E5E616E5E606E5E617A575B\
864D6169787842A06A45444A8B44536E535E6A555F6E615D68625F665B5E6A595C
725F5B6A555F6E525E735B5E7461606D61647263616D6164726361716063726063756664726A65\
7566646E5E68705E636B5D646B5D606E5E606B5D60695E616D685F706F5F7C645D
8663685E64735D5F606A5A5B8D68558B67688472707B6F71
7E6F6F7E6E6F7F706F82766F7A6E7283746F7E76717A6C7184736F7E7671806D6F846571816772\
6C72776D836A6571696A5E64735F626E5C627158616F5A62715B5F7B545E8F6463
397A835B6E497A555A6E5B60695F61625D5F6A5C5A6E575B6E535E6E535E735A5E6E5D606E5E60\
6D5D60655861685A5D765F597159616E5B626E5E616659616E605D645A5F66545B
69595C665D5B64585B6A545872545A735A5E6E5C60715C5F6E5B626E5C606F5D606E5C606E5C60\
6E5D60716260766B616F6464726164706265726A646F65636D64666C65626F6762
6D68636960626E5D606F5E606E5E616E5F616E5E606F5E606E5E616E5E616E5D606E5D606E5E61\
725C5F86555C89676C3C878046514B87555469655F6E625D6D5F616961616B6A5F
6B645E69616269665F6E625D74605F6E5A62755F616E5B63745F62726163756863746764756266\
725C667563666A5D656F5C626B5C6172645F695E627B7B606671657365637B7166
694F638359675E5E6A655B5D8D75577F6D6785616B856571
806B70816E707F6C6F866A6F817073816F6F8468717C697488726D836F737F72747E76727B6F71\
817470797071737573616E6E6C65636F64646960627162616B5F617265618A745C
726F7148516C7A63546E60606F6361625A626A595C6A595C6E615D655C5E6E575B735A5E6E5C60\
6E5D6069606269645F6E625D6E5D606B565F6E545E6A5660715E5C686062666660
68675D68645E635F5F62595B6C5A596E575A725A5E68525F6E4E5D6E4E5D75595D6E5D606E5E60\
6E5E60715C5F76565F775B646E59637356627E62617265686B5C65756063705E62
755F636B5F666C5E617263616E64626C5F626E5E617163616E64626E64626B5F627163616B5F62\
6E5D60725B5F86555C89676C365575715E4879575C7162616E64626E64626E5D60
6E5B626E5D607162606E64627062616E62647265616D6265716361736263796662746267756366\
7165677260636E5F676E6562695E6279685F758067797C62716D7071776A7E7865
58607481755A5C536A69555F94725483786C7676707E6E6C
7F6C6F826E6F7D6971836D6E83696F816772826C708173717E6A6F876770846871826471856E72\
8373707C6D758274706F787665726E6B63656F63656F64616E62647362607F585F
8B62685B78795F715D726361706361655E6569625E665B5E6E575B6E5D6068625F6F625D6E5E60\
6A555F6E535E725A5E6A555F6B4D5D6E555E6A5A5D69585D735E5C6E5D606E5D60
6E5E606D5D606A6061666661625C5C68535B6E50596C565F64575C6F625B6A5B5B735A5E6F5D60\
6E5D606E5D606E5D60735B5F705C64706762766460715464725C66726261705F64
7360617162656C64647265617061636F62646E64626F5E61745E626F5B636E5B63715D5F6E5B63\
7162616B5F61725B5F86555C6B77774C71626952567C565B745F627161636D6164
6C6061706261716261736363706364716463726263705F64726263726163765D62786065756366\
7563666E5F676D58637153616B506181625B896961806D6E684F6C855165794765
76516B86715F55556F736E5D8B845984716B7F6B737C6B71
7F6C6F85736F7D76738077707A6B7285736F7B6B71876A6E7E6C7483756F7B6A7283727183756F\
7F6773856E72837271807174747A76688272656F69706766716A65706965726A65
7E6360876C6A6066736B6062745F626D63656B656266616269625E6A595C6D545E6E535D6E515D\
6A555F66535C6A48586E4B5B66535B6A54586E555B66525C765D596E5E60706361
6E64616D64626E64616F676262636566675F5F5B5C6E5C59655A5E6F5B5866505F7154596F525D\
6D4F5D75595E6E5C606F5D60705C60755E607058636E5963725B5F715862715861
725961725861715762765D61715E646F5B627159626F5B63715B606F5A626F5D606F5D606E5D61\
70595F705A626E5D6071595F8B5A5B717475578A6A616C5D735B5F715861715961
6E5A62746060705E62756162726164715E64746063705F647767636D6266756664756664756366\
6D556572526363456069405974525A8978587668668A69685A5474785F5D6D5F66
71625F7D575E61496B8A7758877963806B70847270796E73
7F6C6F856A6E8568718468717E6C7486736D7A6D7583756F7C6C7284686F7D6673856A6C846571\
836F73816F6F866D71836F73836F737C6C747074766C736B746E68746D69756E68
736A688163637B6F71606E6D513359944E566D5B636D5C6268565F6A565F6A595C695A5D68595C\
634C5A664A59665659665A5766565966565969555866545B725957735A5E715C5F
735E61715F63715F63746262695C656E5E6060576269555969515B6A515A67535C6C5B5966545B\
67525B6E51576E4C5C72515C6E525E71515D7357606A555F6E525E6F545E6E535E
73595E6A5460735A5E71595F6E5060725560705B606F5B606A54606E525E6E525E6E525E6E525E\
6D535E6E545D735A5E69556075505A8E545C82636D5C5A6F6E5C5F6F5C606F5D60
6E5E61715C5F705A61765F60746063705F64735F627567647568636D5F68755E62755B64705364\
6A4E645D3A596841595F4E56786451856457704B6973365C763E6675595D6C4F5F
7D6060695C63645563937254876F6A7D697186696D7F6873
7F6C6F84746F7C6D718571708074728372717C697485686F806A737F6F708075717C72717E6D70\
83676E866E72816D71866D71836F737C69748372717373747B806D737D6F767C6E
77826E74856F7C7A6B71767645987C587352755360705C60685E62665B5E6A595C6A595C66545C\
645B5E5D5B596B5F56665E5B67605B69675C65695E62635D65575A725659725B5E
74605F715F63715F63735E626F62656C6562646264605B5D695F5B69675C605E5C6C5D5A665D5E\
655F5C665F5B63585A6A5458654A596A48586D4556663F596D46576A4757694758
6E4556663F597044556D42596A455A6D47576E43586E425969455A69485869485871545967545C\
6C575B6A585C6E565A67505E69515A78505776385A7E4C676C66625D485D5F2C53
7D3A54764E5B6E525E77595D735861715762755E62765E61765A657562676E62656D586354315A\
6C3253624B5A615D515E56566D4F508152586C55645D5D63695F576E565A766F61
6D695E665065746A6084795A866D6A7F6E717D6C6F80696F
7E7671816F6F817073806D6F886D71836F737E72757C7171816E707E697086686E8167727F6A70\
7E6D7088726D7C697483666F896C707A6A7488716E7C6D7586726E7D6C747F6A70
88706F816A73816A73806B708372715B7F7D5565625F3A58895C595F5C63634D5B71555A665B5E\
685C5A5F535D695256674A596F4F5871535A6F545D6A575F62555E6E5958735E5C
715B5F7661616F6163726363715F636E59636E5B62635B626A5D5B6E585C6858606E635C675C5E\
6D615E69645F65666062635D646A5E5E695C61675B5D675B5F62576463595F6059
615E585E60596466575F6059625E5865655960645A63665A61655A62655A656D5B686C595F585E\
70635A68645E68645E625E5F6A665C65605C625E5F725E54765860606769508363
5A785336183F9C38486A4958764E5B72585E72585E73566064405E5E1F5065134C65154A5B2B53\
695A4A6967516464595A5659695F576E5E556E545D7063606464605E4E5B8E6254
6E6169574B638E6A557B65648B6B68826E6F807472797071
84627082667288706F7B6A74866C6E826471856470826972816D718074727A6D70826D6F817570\
7F7671816E707F6B737E707186736D7C6D7586726E7D6C7486706F7C6974816D71
846D6E7F67738571707B6D72866C6E7F6B735050754C465D7C4D47673B5D664B5A705B556A585C\
69585C645C5E64615B5D595B6859566C5A596C5B5C6A5A5D62555E6C5959735F5A
6E5E60725A5E715762755D61715E646E61646E6462676063675C5E6A5A5D6E605D6E605D6A5F61\
6E605D6E5D606E5D606A5F616A5A5D68525F705F5C68635F66666068675D625E5F
665D5B685F5B695F5B69645E66685E67605C695B5D6A5B5C69595D6E615D6E615D6E5D60666163\
6E645B6A575F715B5F665961715F5C695F6269645F69635F6B585C76595E715961
6C61642E86766AAB3A4F555F5B374E692A4D7535525C275057204D55384E443F454E45425D5744\
614E47785751634D5A5F495A8680535563636A585B74595A5F3F5D76635E7B7C56
6450666E6D696E68578B6D647D6E6884666D84656E846E72
7D78717A7070856A6E836F737C6E718273717E78717B6C71836A6F84696F8170737D717086706F\
7F6773856E727C6C72826C70846B6F836F737F6A70856E728372717E7275807671
7C6C727F6A7083676E806572836D6E7E6970565676576C654B49506A4A516250535D394F7E4E54\
6A5A5C66555C6C575B5E505D6C5B57695C5A67535B6F585B64595E695B5A735F5A
6E5D606E5C606F5E60715C5F735E616E5A62745E616A5C636A5F61675C5E6E585C715B5F6E5D60\
6E5D606E5D606E5D606E5D606A5F6167646068585B71535D6E555E715B5F695F62
68645F655B5D6C595C6D575B6C505D6D555E6E605D6A625F63585E745E5A6E5D606E5D606E5D60\
6A575F6A575F715E5C665761725E5C69545F735A5E6E5C60695F626E615D6A5560
71525C6F505F7D5A5D5F666C4F8363487B58372A414C1E40563D424D3D404E3F46555044594B45\
59434B653B476C4254655756936F4B4D3667704454795A58504B6083614D7F5D5F
5E506A917B56667970827D5F7B6D707F706D7E6E6F88726D
846571836F737F76717F6C707F677388716E8068738170737F77707F76717F6C70856E72837271\
7C6D75836B6E836F738076718074728372717B6B74856C6E866D71836F73816A73
7E68737F6C6F7F6F707C6F70816C6E7E6B715C5C75695F6148536554484A6B4B5042334E551F39\
8C384B6D565B66575A62575D6B5E5766555B68595C69585967525C6C585B735F5A
6E5D606E5D606E5D606E5C6074605F6A5C63715B5F6E5A626E5D606A5F616A625F6E605D6E5D60\
6E5D606E5E606D5D606E5D606E5D606E5D60645A626A5D5B6A5A5D715E5C6A575F
6E555E6C5E60655B5D68555C6A5B5C6A5D5B6E585C6D535E68566072615A6E5E606D5D606E5D60\
645460705F5C6E605D6659616E595B69576071605B6E5D606A555F6E535E6A555F
69585C634C5A6B3D546C30555B1B4D551147472D51424B3D4B413A4B3B42584E43524845574649\
56484A615D4E605E4E6553538458504C446964584F755952574D6082714F6D5C60
6B5F668D75567E6B6F81736C79676F88726D7E7671816F6F
7E7671816F6F836671816A737E6E7088716E7B6A7488716E7E6673896C707A6A7488716E806873\
846E727B6D7288716E836F73836F737F6773816A728373708372717F6773856E72
7B6E727E6A70826A6E8372717B6F717F6C706666756E7C6854796C38485961414641344E3B363F\
451C2B9E3D42634E5A6D5959624F59674B596D53576A595C655B5C695C5A735F5B
6E5D606E5D606E5D606E5D60715C5F6D5A626E5D606E5D606E5D606E5D606A575F6E555E6E555E\
6E555E725B5E6A5660715B5F6E5D606E5D606759616A5A5D6A5A5D6E585C6A575F
69585D6E555B69545F695C5D6A5D5B6A5A5D6A5A5D68585D6B5B5C6E595B725B5E69545F6F545D\
68586071615A6E5D6067596169585D6C595C6E585C6E555E65505F6D565B634C5A
6848585A3F57583C514929464527434A3F4152513F4B4F464C5347464A444F3C3F5C4448554A48\
5E574C655C4C615355696056655154563D5B695150684E526D615C7464546D5664
77675E8B7B5F7C706D836C6E7A6E7385716A8468717E6673
8465718269728173717D70717D697189706D7E727583746F7A6B7588726D7C6D75836A6E846F73\
7F6C70836F7383746F806873846571816A737F6C6F88706F7E6673846E72816F6F
7E69738174707C7271846D6E7D6673816C6F6A5B728971655F556F3B38624C384449374639313D\
2E28343B111D982B426C4C52634C5A696057645C586C5A5966545B6C575A6F575A
725A5E6E5D606E5D606E5D606B565F715A5F6E5D606E5D606E5D606E5D606A5F616A625F675C5E\
6E605D6A5A5D6A575F6E585C715B5F6E5D606A5F616A625F64575E6A535B6D585C
695B5D695C5D695C5D68575C6D595C69585D69545C6A565C6B585B69555C745D5B6559616E625D\
675C5E6D565B735A5E6A5F61655D5F6A5B5C69585D67525C66525C654D57624B5A
5A44535A455347364A3D2C424F483F4F53404A3F415842455C524948494C48454757484160564B\
55484A6C4D4E5B44536F474F604558646258616B546164597D7C55574E617A565B
867C5D817764816D717B686F83696E80696F86716F7A7073
7F6D70816B6F84686F8167727E6B7188726D7E66738665707E667389706D8071747E7572806D6F\
836F73806D6F846671836F737A6E7285736F7C7072836A6E8270737F6D6F816772
837271806C70846E727D6F727D6D727E6B6F6B6374856C625D52734A626934444D4E4542373841\
2C2A33211F273D15199D373D6254556D5654634C5A705857655A5D66565972605B
6E615D6E5D606E5D606E5D606A5F616A5A5D6E555E715B5F6E5D606A575F6E555E6E555E6A575F\
6B535B6C535E6C595C6E605D6E605D6E5D606A575F6E555E675861665C5C69575A
6C555B68515B6F585B685C5E6A5D5B66555D69595C63505A6F565967595C705A596A575F6E585C\
6A575F695B5D6E595B6C525E63465C6A4557664157613B55653B51613D53604150
4E344E421D3D3B1537543A3D5D5F3E4E51493A304260433E5C47465C58514D635152634C524547\
543B4D6141465E445068574E5B5054745D5069595B7B7E5D655C5D65566A757757
88735C7E636D82636C816B707F706D7E6D7088726D7D6C74
80696F84736F7C71717E6D708373707F6C6F7E6873816F6E80757181706F846871866D717C6C74\
86726E7C6C748274708373707C6D7586726E7D6C747E6C71846A6E836F737C7171
836A6E7F6572876B6D806873816D717C6B7177727272676B6B6670514D623C39584A3F41382D3E\
2E273427262B242223361017A2303E6B59555B4D59735A5366545B69595B705B58
715B5F6A575F6E555E6E555E6E555E6E5D60675C5E6E585C715B5F6759616A5A5D6E605D675C5E\
675C5E66585B6C565B70575B6E555E6D535E6F5C5F675C5E67555C68515B69555B
67555A66545B6A54586A505A6D545B65535D69545960505C695154694B586F52586D585C634D5B\
72565A614A5B72525966525C5E515C5C4E555E4D54554A5355454D5138494D2943
3817383F24393937365850335F4B4055444D404B4F5A603F56544B64534A5947525D464F565355\
484A4B57494763564B61524E615255705F516A5A5C7C4F546D4D6A736D5D7D785F
7D7166765F6C82666A86706B7F6F707E6C7088716E807174
7E6F6F83696D866E727E757283746F7A687484736F8076718372717C6A74816A7088706F7C6A74\
856B6F7E6673876A6E83667181677288706F8071747F75727C7171846C6E836F73
7A6D727E6D70816D6E816D71806C707A647180636D6B52707F62653E33634B374F473D44332D3C\
302932302D2E2729291E1D2020070EAC2137654F586852526A52596955586E585A
6D555B6C565F6A5A5D6A5A5D6A5A5D715E5C6759616E605D6A5A5D6A575F6A5A5D6E585C69545F\
6C595C675C5E65595B6A555A6C555B68545C71585A6A575F66595E655B5C66595A
65565B675959625259644C576A4D566A555A625259635159675C575F56586D5C56685459604F5C\
684D5366525C645254664A58634D585B4D565A4951523D4F472C4546273F40293B
352F3A403F334D553B545C3E51484653404855484A5E514855444D5536475732495F3F49593B49\
5E4F52565F4E5E584D5E4F526C61536A62566A5A5C6C605D7B7E5D717F64786A65
81676A7A766F7A7A6B84776C8074727E757283746F836F73
80696F83737081706F866D71836F737D7275806E6F856871866D717F72747C7172836A6E7F6572\
836D6F8074728077707E75727E7671816F6F836671866771816A73816D7186706F
7C6D757F6F707F6F707F6C70806B707C7172756D6F6660707C6961353D6A494248473E4433323E\
2E2B31332B2D29252A1A161E1A191B20090CB12E356253566D5E5563595B6C5A59
69585C6C5B5C6A5A5D6A5A5D6A5A5D6E585C6E5D606E605D6759616A5A5D6A5A5D6A5A5D695B5D\
6A5B5C6A5A5D65595E675A5B6A5D5B64585C6C595969545C6A555C67535B67535A
66555A67565960525B615557635655675255614D59604A556A4C53654F59674E546E575A584C59\
655055655053624E585A4653654A525946534B314B3F1E3D47283D2B1A2D4C3134
41423A474B3B59553D5247465141495449485244476653495150514F554F4F5B4B595F4A525D51\
5E5B4B6155535D54546664556964546A5A5B6A595C75675C80655C805D697B696C
7F7369836F6B837271816E70866D71816A73836671886C71
7D787183756F7B6774896F6E816A73866D717F7274807571816D718468717E6673826C70807571\
7C6F7083666F876770846871866D718071747B6E72826E6F8372717C6C7284686F
8269728372717D6F727E6B71806C6F80696F7864716D6470715D653D3A6649404A3F32403A2E3C\
3534372F2E2E241D261A161E181316201E1DA2790B6253566D565469595C695B5A
6A5A5C6A595C6F605D675C5E6E605D675C5E6E585C6E555E6A575F6A5A5D67555C6D585C6A5A5D\
69575D6C595C65565D6A595B69565B66525C695459644E5A6B535866555A665659
665659635159635159615156604B55624954614A545E4D546453526B60565955596142505D3D56\
61454E614451614451523B505D3A484F2D494B3448282135442C2F32343944412E
3E2D35563C3A5B46404E3D48503E4556424559504B5D51486053525B5D5352505162514E696354\
5659566254536761576961556A5A5B69595C72685D756F5D7566648477657A796B
817A6D7F7770816E70816A7386706F7C697483727183746F
836F73816A737D6A74846B6D82697283696F886C71806873846E727C6D727E6B7185746E837271\
7C6D758075717C6F70847270816D718468717F6B738373707F6A707F677383746F
807671816D71836F737B6E72816F6F7C6B71796A706C5D6E5D3E634B375D49404A3D3944363038\
423A372C2C32292A2D1B1E211E1F1D2A2A20471D1A9838426C5D56695C5A6E625D
655B5D69585C735F5B6759616E585C6A575F6A5A5D6A5A5D6A5A5D69585D685B5E695B5B67525C\
6A545C6D5A5B65595E68575A67565C675B5B60535A695B5A5F52576B5457695B5A
63585A60535A6354575D4D565F4E5455415062444E6653516864546253555234545C3B4F5D494D\
56454D5F494D56434D48344A5035423E293F442938404445364635464C3B434D3C
435542505F3D5352454B47494F4946504745614F46523F4C613E4865414E59455362524E63434D\
5F3C55715D5269605669595B6A595B70665D766F5D7B746473756A867864827470
7F6C70836371866E72807472816D717F6B7386726E816A73
836F738071747B6D728473707C6D71816D71846D6E8270738373707B6A7483747083746F836F73\
8071747F6A70816A7286726E7C6974826C707E697085676E836F737A6F71866C6E
866D717C6A74856B6F7E697380696F7B62707D656E65556F514866453A514E3D483C3441403D3E\
3E3B3629243230272B212026292A242C2B241D151CA75F19705C556A5A5C725F5B
64576169595C6F595A67515F6C555B6C595C67555C6C555B6C595C695B5D69585C68545C67595C\
66595A6A555A6C595C63565C67555A695459655A5D61515667565B6053556A4D56
654B59634D58604B555B4755583F4F594851594F4C71634E6960574C3757553E5259524A594F4C\
4F424D4E32434C26413F213C55383D3A36403A34374934344A3E414B453C42333D
593F3E5B494555484A4F444B4E4046473141745443494B51605E4B504B4D6D654F5051525E5052\
646A5369675169595B69595B6D605C715F5B84705F7C71667B6A6C87706A86706F
7A687483746F83756F836F737C6974857170837271807174
836F737F6773836F73806D6F836F73807671807472837271836F737C6C7486726E836F73836F73\
836F737C6D75806D6F88706F7E72757D70717E6F727D6C6F89706D7C6D7583746F
7F6A7080677285726F7F75727A6F727668707C686C56426B5E455E403D534535403F303F3D2D35\
3E2B3627202F3127292F302D2F342A242024110D15BD7708665A576D585B6D565B
6A575F685A5C6C5B5C64565E69575A6D5A5B64565E69575A6A555A6A535B69545C67565B6A595A\
67595C66585B69545969575D63585A665659644D57614C5A674F53635059615255
625156615356584A545948514F414E58404768554D69574D5831524E2F52543D455A3D46553748\
4B30464431423525364434385045373C353F3F393A413A38473637462E3A43323D
57463A5B4A4455494A4D41494E42474C524A64593E514252634B48524252663F446244575E534F\
694A4E745457685A5C695B5C786E5B768863767C637D696C7E6E6C86766B837271
7A6D7586736D836F737F6773816A73836A6E886C71836F73
836F737E727583746F7B6A7488716E836F73816A73866D71816A73836F73816D71866D71836F73\
836F738071747C6F72846C6E846871816A73816D7180747283756F7D6C7486706F
7A6A7483746F83746F836F737B6A74766671745A6B4F426C594553463C52413E453D393D3C393A\
2D252E2A1F2B362E2A36312D2E272B211C251C1E21B6860363565D716359655C5E
67535B6D585C69595C67595D685E5C67585A68555C685A5B66585B6350596C555967585A644F59\
694C58674D59664E586D5657604C5A684F576050596153556356555E4D54624B54
614C535D44525B44534F3A4B553F4B554A49654C465D3B4E4C354F4F3F464E4244504044493743\
3B273B442C3939343B423C335A4E3B3E464543483F3C3A3B403539504D3E404B40
51493D55424356404752474B5C624B4F5A4C5A504B50444E5A464955454D55484B614B496D6152\
5E6B586D6D55655D5E756F5D78755E856B637E6A70786A6D826C6B866A6C836371
866E72837271816A738170738076717E757283746F836F73
836F73816A73866D717E727583746F816A73816A7386706F807174816D71836F73837271836F73\
836F73816A73836F737D6F72816D71837271807472816D71866D717D6C74846B6F
7F6B73846D6E8468718366717F68737667716A5E6E4D4A684F4353493C4C4136433F333D403539\
2D2E372E302E40432F2E2E2F2016222217201D171BBB750B63565D71575763485D
6D565B6C5E59695B5D624F5B6A4B586C525B66555A664E59674D59635059654E55694D57635059\
615156635055655356634A54664F585F4E54614B54614C54634C535E4C565F4F52
5948515A485155444D4C424E4F42456050485142494C3046472B4153383F4833404F363F3A263A\
45383E3D3E383E3838413838573F375245474848453C3C4247473E4C413A4C3A43
5346424535405C40425648476B56485A54565A5A524B4A5156494A605B4D4C4C4E5E4D4A785F4B\
6A595B725D5B716C627B7D5D7B7C6876706B826D6B786770846F6B806E6F817470
83756F836F737D6C7483696F866771836671866771866D71
836F73807174837271816A73866D718071747D6F7286706F836F73807174816D71866D71836F73\
836F73807174837271807174807472837271836F737D6C7486706F7D6C74816D71
8372717C6D72816A708472707E7672726973614C6C513B6156485446444C3D39433E363B403739\
2B24313D3331362A2C2B1C2C1A141F261F1F1B191BBA7809665A5D695B5A625D5F
69605767535B6F585B615B605D57596C595662515A614E586553566151565F4C56655053604B55\
644F555F4E54634C535F4C566653525E52575C51545C4A525D4750624D515A4951
5A4951594C4E52474E4B3E49564B4856474447324843304145383E44343843303C3B2433412E3A\
433533352232432A33463737594F3C524B434F47494A544B42474149404145383E
4C333C5043465552414E40466E4E456250535A4752504052615A4C625E4D4E4D56615E4D70634E\
69585B7A6D5B7974607E6F657C5D6A81616D826D6B7D72707F746D7F6F7086726E
816A73866D718071747E75727D70717F6E7183746F816D71
836F73836F73836F73807174816D71846871836F73816D71836671886C71807174837271836F73\
816A73866D71836F73836F73836F73836F73816A73836F738372717D6C747E6970
876A6E7D667384736F816F6F8366717A6B754A436D54415A513E4B4D3A4B35293E422F38382833\
2F263240362D2F2930272128201F232A28211D1E20B67C0A624E5B70555966545B
6C575B63555C674F576E545A5D525C6752556350595F5257604D54614B555F4E545D48515F4652\
644C515C48535E4951624E52614E52614B535945535C4951594B505E494D5A4851
5A4B4E52404C553F4B4A3F495C4B444C3E494134443F333C4130374030393C2D353E38393D3A34\
362A32352B333E3530463935563D385842454E3F4658424548404A4C49443D3B41
453A3C4932385C394059504B5D55465F464F615254545E555F5C4C573F505D435269554D715D53\
6D625C8071597866668168687A756E79776A7B696C876C6C8372717D6F7286706F
807174837271836F73836F737D6C748372718372717D6C74
836F73816A73846871866D717D6C74816D7186706F8071747E7572816F6F836671886C71836F73\
7D6C7486706F836F73816A7384687183667181677288706F816A73816A73807472
8077707A707386736D7B6774816A7073546E4D406F534A54473D4D4837433833424342382C2A34\
3A35323B3630322E331B17211F141B26191C241D21B3780F5C505D6E5754624D5A
6D535766545B60535A695155634F5A5F4C56654E555E4B555C4853614E515C4A525B4B525B4D4F\
58424D5A3E4E5A414C62464C5E45505F49505849525B4B4E55444E59434C59434C
563E4B52404C4E40474F424749323F47273F432D3D3B2C374032374138373C3B393B32333D2E35\
3831363A3934403F35423C374F413A5848415A5C4C4F5B4C56664F424F4B383142
433239463A3C584C3C553E4264464A605650605750605154553F51553F5059454976604C6D6857\
6E615C83695C7B6D697866688969687B646F83756F7D756D86706F807174837271
836F73816A73866D71836F738071747F6A70886C717D6C74
846871836F73807472816D71816A73806B7084686F846571866771836F737E757283746F7F6773\
856E72816D71866D717D6C748372717B6D7283747083746F807174807472837271
816A737F6773866A6F7D6A74806E6F5C4B715745644F40524B3F4D403742382C3A453035302A37\
433C322D252E2E1D2918121E1C1518241C1B221C1DB574105B505D6B585562595B
665A576351596351595F4C566249545F4B55614E525E4D54584C525D4A4E5B47515C4C4F594A4F\
564D51524A4C55484B59464959434C5F494C594A4F55454D55454D55484B4E3D48
513C47513D45493644543F423C33423A2D38392732443537393334443636413739271C2C311927\
381F2A4732324C463944473F4A443D5442406243435E464F5C414A5C5256365050
3A433E4E4C3D50473F554C48514043724E49605254554051543F5155494A54484A7D6146725E5A\
7C7960717263816B66776B6E806C677F6D6F88766A7B677486686E886D71836F73
816A73836F73837271836F73816A7381707383746F807174
807472837271836F738071747D6F728273717E76727E7671807671837271836F73836F737E7275\
806D6F82697286706F7C6A7488706F7C6C7486726E816A73866D71816A73836671
8269728173717B6C71826C70765B6F57426F5C4B5C463C524835453E2F403B333B362C31362A32\
4131302A2431251E251D1B2122231E23231E252321A46B13624D5A665054664C56
674E57624F58604C556251565B52545E51535949515F48505B4A5155444E59424C5A424B52384A\
5B3B49553F4B513D475B454955484B523C475E404A55454D55484B4E3D484E3D48
4F42444E42454137425948403634422D22304335344039333930373A2A30301A2A291B2B1D151C\
4939294B50333E3537523A3D42333D533A3D5E484362554B525151675A4B413F53
4748495355424A48475A4B454E494C6C5B44563F51553F514E3D48584047645B4C75704B75705D\
806D5D77626C7B6266846C6A7C736D7F716D88716E7A6D757F706F86726E836F73
8071747F6A70886C71816A73836F73816D71866D71836F73
836F73836F73816A73866D717D6C74846B6F836671866771846871866D71816A73866D71836F73\
7F72748075718372717B6A74856A6E82697283696F856E728372717D6C74827371
8075717F6A707F6B737E6B6F654D7157426658415442314D4838433A323D3E3337363237342F30\
392D2F221826251B22201B1F261F1F241F20251E209F6918625256625356696257
5D5A586256575C54576459545C54575F56545B59565858525B56525150524E454B503B47534349\
4B3D44543C444F3E46543E42543A46534349554745503B47543A464E3C48483942
4D3740472F3E46344058433C332A3F28202F45332B4337372D232F2D1B28271B252E26262B342D\
403E26554136414344453F3947404140353967473E624C4860535256444D4F3F53
4A434657434450424953424464584C605C4C4C44545A4F4C4B4D4E5D634A615D4A7A5F518B7D5C\
6B686A7A62677E73697C6F6888726D7F76718373708071747D6F7286706F836F73
836F737E727583746F8071748372717D6C7486706F816A73
846871866D718071747E697081647186716F7C707283746F807472816D71816A7386706F836F73\
7F6773886C71816A738170737B6F71826D6F7E6C7188716E836F737D6C74846B6F
8366717F6773816B6F7A63715C5171554B614D415340374A45383E3C343D393135453F392B2B32\
382D2F14101B2E222122202124201F211B1E332F2693721C6C675862715C696C59
626861626E5D606F5E5D645A61605B6162595E5B585E59585F5B56585A57505C554B5B50454145\
4B3B454C3D414E3C424D3C424A384150363F503341523D454B3E434A38414A3C43
44393E3F333C433438543D3B281F362F242E41362C392A30281D2D211821261C20423E2A272628\
44312D554435493F4142394043323945373E5F4C39614D4967564E565B59536252
454F4F514D47463944472C3E7D503F6051544A43545A46485F5750605B4D696256828D547D7A5F\
7368737673698272677C6F7085706B866D71816A73866D71807174837271836F73
816A73866D71836F73836F73836F73807174816D717F6773
807472816D718468718071747D787183756F7D6C7486706F836F73807174807472837271836F73\
7C6D7586726E807174816D718270738075717A6B7289706D816A73836F737C6D72
7F6B71816F6F7F6F706A5370604269553F5B4C3C5142394742383E3428353E2D353C292F392E38\
2923291715212F281E272425232020201C1E585828878F2B6D6B58756D60686564
6E62616C5F616E5E6069656365695F67685E5D5E5F635E5A625C595F57595D5557575456495856\
47584A42434446373E4D393F4A3E414941404A424145343C4E36404A3E41483D3F
4338403E363B3A2E355037362A2A3B373A3045483325222D261B26201A202D29234D4328222430\
44362A4C3733503C3F3E343E3F343A483C3958433C5C404470514B6253555E5156
4F4C564F4A4B3D35464D4A4368583B5F435054495456534C6F684C524B557A594F9A765274606F\
7857698766687E686B88726D7D707186706F7C6974866A6F836671866771846871
836F73837271816A73866D71836F73836F738071747E7572
846871836F737C6D7288706F816A73836671846E727F6A70886C71836F73836F73836F73816A73\
80687388706F816A73816A7386706F816A737E6C7486736D7D6C7483696F806772
806C70826E6F816D715E58755448624F3D544D3D4C3F344341323C3A383D373633342D323E3331\
181321241D222F2B22231E22241D214D64306BAF2A728A47716E63726561726568
6A6264736B636865647265616B61646C5E6167606368675E605C5E635C5C5D58595E5858575456\
555754475953435B4B3C3F4049363C49353D49353D493F42443C3C4C3B3E45373F
3E2F3B403039302431341A274D3639313132594A36191D2F21191F181117231418583627353F3E\
30312C4C3733594E3C353640504E3E3D413D55453D5D5446695C4869605660665A
515A5A3A2E47523F47504B405E4844543C4A61484B60585068534D584A5B8A894B7B745C72536D\
7E6C68817A657C746F86766B807174806B70836F738076717E75728076717D6F72
846B6F866D71807174837271836F73816A73866D71836F73
807472816D718270738373708071747F75728373707A6A74866C6E836671886D71836F73807174\
7B6D72856C6E836F737D6F72846B6F816A73816D7186706F8071747E75727E7671
7B6E717D646F79506D694A6F4C3D605140514537463C2C3F382634412B333B2F36342D3230232A\
181321302B212D2925211E236DA72B4FC7366C854B746460796563726568756564
7066697568626A5C68735D61705C647065636960626E5D6067606367665E5E605F5C55595E5358\
5F5A55555656515152435251383D4042333A4333394C373A41313D48353942313B
3D323A3B3035271F2D2A202763502A2120316F4C2E2135451B2324262D251416163D211B5B3D36\
22223150392E563E383B31435946394745484E49405F484365464A7958506A5A5B
574D5D38465847423D55404359484551474B655C486158505F51546762568E744C75596B74656A\
847762806E6B86726F806B70886D717C6C7486726E836F73816A73846871836F73
7D6F72846B6F866D71836F73836F73807174837271836F73
836F73807174837271836F737F6773886C71836F737E72758076717F7572837370836F737F6773\
816A72806C7088706F8071747D6F72837271807472837271836F73836F73816A73
7D667379677065566E654D63463A5C503D4A4338473A363E3432373B3432362C31362C31211A25\
1F1A212F261F261B214A52329A9B1A7466606C5A64776061765F63796265746467
7564667464676E6668706C656A6264735D616C5A646E5E616E5E6069565F66505F645B5E5E5E59\
6057575E55585754565151523C484F495D45313A3C42313642333A403337403138
3A2E353325302B242E2723256646272F3F48534C2D3B3746161A271B10162A23253C4526564E2D\
36514B4158364A453D4748454136395C41414D46465849445F4D4A6F4F4A735358
5F5D603C415540354458443F4D39425C4346705E486463575A5B58664F528653538469657A7E68\
7E78697F716F86736D7C6C7486726E7D6C7486706F816A73816A73837271837271
807174807472816D71866D71836F73836F73816A73866D71
846571886C71816A73866D717E727583746F806873886D71816A73846871866D71816A737F6B73\
816F6F7E6C7188716E816A73816A7383696F886D71836F737E6673896C707C6974
7D6971745E6F66556E584760493D584C42494036433C303C3024313B292F30232D3A2C2E16121E\
271E1F2B242134352C849D237282457760616D6466726561726164796563705966
7C60647059667556647C61646A5C68705F626C5D626E5C606F5D6069606265666062595B66555C\
62585B5E54585E54575754564C5454514F493C484F3135394233353E3337372B33
3D2F342A242E2D23291C141D5B32235F574327243368493C1B3C432A56341A231E4D362836202B\
683B3A3A2C3E53393D4D3D404849484D473C57484748384371534655444D7F574D
70695D343F5D3D374458473D4D48485B5444654B476E4551634958695E587C7B5481765E81676A\
856A6E80696F876A6E836F73816D71836F738372717D6C74816D7186706F816A73
846871866D717D6C74846B6F866D71816A73836F73837271
7F6F7086726E7D6C7486706F836F73836F737C6C74846C6E836F738074728372718071747D6F72\
816D71827371816E70836F738074727F7572837370836F737D727581706F7A6173
7F636E6A536F6D57674A3F5F4D3C50433043453341362D38322C3436302E2E292E261A221E1723\
302F2232362970A52D6E9738716260746460726164726164705C64775A616D5666
76575F705565705A6176575F7054656A4F5F6E4D5E70525D735A5E69545F6F545E63526066575A\
614E596351586154565E55575754565150524C4D4E3C544E2F383834242F3E2F34
30252C2F242D231C23221D233F2D20703F30313E5147392D544F4D22262F40473F303C2A3A3737\
4E3D2D473D45403837523B3E54454139283C643B3C4A434A68523F5549546F5247
734254555A6933535042363B5C3D415F4C4655434B6B514B69615574775682835B736769856B6A\
81706C7D6A7086736E816D71816A7386706F816A73836F73807472816D71836F73
7D6F7286706F807174807472816D71836F73837271836F73
8074728372717D6C7486706F836F73836F737D6C74837271816D71846871846871846871836F73\
807472816D71836F73816D71836671846571866771846871866D71807174736874
74596B6C556C6248604A365C4734474133423B2C37362735362C31362E2F1E1421261922201C1E\
261A1C84952A6F99377265616F6361705A61735662755A626E59636D53606A4B5F
6B465B6E455A6C42596E41596E415965405A6B48566949566E455669445A6F4F5866525C665659\
62595B625D585E53586252565C4F56574D5454505052534E3953522D493F323230
2E272F2E272A2523272320203225224F2B286246433D53494C3D374359563D5A373A454527232B\
4F303256473B3F44454B463C442E3B453B444E4437615246544B475F494C66544E
6B62556C6958373E5C48514B566342524C48513F4B6E5447735D528E805775696681706F7C7669\
816D6E7D6A7089726C8071747D6F7286706F7C6974866A6F866D717D6C74846B6F
836F73837271836F73836F73807174837271836F73816A73
836F73816A73836F73837271836F73816A73836F738372718071748074727D6F72837271837271\
836F738071748372717D6C747F6E717F6F7083746F807472816D71846871766475
6A5E6F6B5B665549634941563D354644383E37353B2C262F3A2C2E31272D1B192426201E2D2C26\
5FB22E73B3276E64627464616F5F656B5C636E5D60705B606A5361644A5E664C5A
5F49586044535D3E51603D4F603D4F5E3F5060404D6848515E4653654A52694F536347566E5256\
66565966575A5D525A6153565C4F565A5054574D5155454D53464E40474C292E39
2A222A2E2328231C231B131A2B1B1D4631286D51324031453721387F52373C3C4E5351452A4E4B\
363D2F4D30345944434442433E3B41524D3C43404169523E4F454F65594A594C4E
6F494E7C58574354674F5A4C584E4A544B4F53544D665C48735E52976F537667728673667D6971\
826F6E80757181706F866D718071747F6A70836F738076718372717D6C74837271
837271816A73866D71836F73836F73836F73836F73807174
836F737D6C7486706F836F73816A73836F73837271836F73836F73836F737D6C7486706F836F73\
836F73836F73836F738071747D6F72806B7084696F886D717D6C747E6970715670
70536B6E5B654A3F5F452F4C4231443B2C374030382B2832302528261824231B23262220302823\
B77A17715E5F7159617358617157626E5B626E5C6068525F4E2953581D48662948
5C2F4C5D394B573E4C57414A57414A57414A4B3045582940562544582641723C48665054665352\
6B545866565962585B5E55575E55575A5254564C52564F50514A4C49414A3A4C4C
1D2A30241C22211920161217261C1A3E2A235D332D5A504C3054495D4E335B56544B55484E5650\
3A5E4D3C513F4A3A38523D45484B4540333A4B303F60403C5E4A4D553D466B4E50
5F5850765A50605B624A4C576057504D484E5F4A4B70634E706C56826558856568836C6A7C656F\
84686C86686E846E727F6A70866771817073816F6F866D71836F73807174816D71
866D71807174816D71866D71836F73816A73866D71836F73
836F737D6C7486706F816A73836F73816D71866D71836F73836F73836F737D6C7486706F836F73\
816A73836671886D71836F737D6C748273717F7671806C70846E727667726D6172
6C65685C45604D355B3E34493D303B392E38382B302B202D322A2B2324272320202E292472B02B\
6BA3326E5D616E5D616E5C607162606B5F6157385A612B524E39564951496B8845
478057455A4F54504C5D614E59745242504F494C4D464F45484C4445444253363A723F46694F53\
6651546A54586657595E525A6153565F5456565255574E5051474F4E484C4A4446
30474B1C2E2D18161A1A16191A13143F2B21200E1A99452C506357302F3E844E3C40324E6E4F46\
565C543E494E4649455554413A2C3D50404442463E55483E5C464451474E654F44
674E52725E536D615C413F5C5532455B3A4D5F4E496E4F4A8F7455727C657F77657E6E6C786770\
87766B7F77707F6C70816A73816F6F86706F7D6C7486706F816A73846871836F73
837271816A73836F73837271816A73816A7386706F816A73
846871836F73816D71836F73816D71836F73816D71866D71816A73846871836F73816D71846871\
816A737F6E71846C6E84687180687388706F836F737B6A7488716E6C5774724F69
643A61552E5B4C324D4234452E23343B273130242D352F301C151D291821241D2150552C9F901F\
6E61646E64626B5F626D5D60715B5F6E5A623E375D56424A53474950414865303D
621E4D55294E5C3E48512C425F1F42481A4650273D4C293E634B444041474840424A2C377E4244\
68545469595666565962585B615D585D5557594E56574B52564F504F4B4D4F4D4C
4447482D434615242721241F0F0E112D191732322F6A531E6736483636526348335954574D4742\
734C4C5D7C5E33525049333F48404A4E4E3C3D314053383B5F47435447495F4D4A
60484C7B594F6E575B4443614A4D4D5855465546496B504B9E76487C6A6C83706B7A676F7B666F\
8D7468836F737E7275807671807472837271807174816D71836F73807472837271
836F73807174837271836F73807174807472837271807174
8074728372718071748372717D6C74846B6F836F73816D71816A73816D7186706F7D6C74816D71\
816D718372718074727D6F727F6E7186726E816A737F6B73846D6E655976655466
4F3F5F4F41523E33453B27392C21323A2E2D2B252C24161F281F29201F1D38362888A621718B46\
7160636E5A626E5A626D5D6058385966285042204F3A19334715334B1C37502C3C
4126394623374F26383E213A3A1D312F152B3C1B2A40212F3510244510323B162E33152C541B29\
792A41794F50665659665659624F58624F585D5557534D535A4C4F554E5056524D
45434C413E4522313C100F14110B112B221934252046232869393A575B4E2F293985463A3D334F\
714A3F81544D536F6D2F61564F59443D32404D424444453D5A433E5540474F3242
714E4A73624D6B595C555F634856545E5D4D4D50516C614A93704B856B6A7D676C7F696F7D746E\
826C6B896C70836F73816A73866D71816A73866D71807174837271836F73836F73
836F73836F73836F73816A73866D71816A73866D71836F73
846871846871846871866D718071747D6F72846B6F836F737D6F72837271816D71836F737D6F72\
837271816D71846871816A73816D71846B6F806873826C707C64706A59735E5167
483B5A49324738253E302030362C3130282A2C222A28282A2B2B242729287EAF23729F376F5B63\
745E626F64646960626D5D60515F675780593362582E524938523A3A4537484438
3A3C3E42473B4A563D33423F38443A324B3A364F343A4935304B3B4B7E363689462F91473B9841\
53813F6B664B665659635159625259605356635556565258564E505A4C4F594C4E
4C4A51444848313C42121F280E1010150D0E2C171B3F2C2753362D73473F36505A44363163444D\
493D3F8C55447155595A6C6B31394B4C3E494E4B3E443C43554640514345433A45
775A3C684D517455586A615E43415A6B514B524A5580794B8082577F6D677B656F7F676A876C6C\
7E6F72846E6D846871836F73837271807174837271816A73866D71836F73816A73
866D71836F73816A73836F738372717D6C7486706F836F73
8074727D6F72816D7186706F816A73836F738074728372717D6C7486706F7D6C7486706F807174\
8372718071748074727C6D728472707D6F727D6971836B6F77657267566E584464
4232543C2A403C303C2E303430282A2E242B2821262F25272B2426312C2ABB82136F5963725F63\
716261705962715E646A5E626A66636F6E5D53766C469D623EAE5A36A45942A151
42B1563BA5544C965140A05D3CB95536A9563DA4533B99533E8F515C87465A6A565D6457616155\
625E58665B5666575962585B6056586052576352555C4E575A5354564E50594C4F
52474E4F4B4D3A41481E2C38131B1D0A0A0B41381D2C292440272A5A2A305F3445312A41664033\
3D2A456E3535864A51725459384A694B5B454A48474037424C343B583F424F504A
6355415B3D4E7F574D705E5B4245615F4A4852394EA06F41826E637C686C7C696C7B696C8A7569\
8074728074727D6F7286706F836F73836F73836F73807174837271816A73836F73
816D71866D71807174837271816A73836F73837271836F73
846871836F73807472837271807174837271816A73866D718071748372717D6C7486706F816A73\
846871866D71836F737C6C74836A6E8269727E6F727B676F6B486D6D4567503B5D
3C2C4B37293B33222F34222E2E252B2118203023262D28262923266C862F809B2E6E6264716361\
6F5E637064636C5E617263636C5F61776061726164796563715E677167686A6964
796A606659696E5D60735B5E7655606748646E4B5C6A4E5E66545C6C5A5964555D685C5A6A665C\
5F5B5C66565A695C5A63595B60545A6255586054565C4F565F5053564B5353414D
57444C55484B3F3A492A2D3C11121B1313153A2B1831282C4C51313C423665563B29304241262D\
5942424D503F7B583F7055595C6B6348645941444D4745484A5243443B3D54323E
552E41603F497F6246705E5B4646615F5A4F474B51A782397C6F6876606C82656A80716D88766A\
836F73836F737D6C7486706F836F73816A73846871846871866D71807174837271
807174837271836F73836F73807174837271836F73816A73
816D7186706F816A73846871846871846871836F73806B70886D71836F738071748372717D6C74\
837271816D71866D717D6C747F6E71806C70826C707A7073585E73523D5B48274F
3823403E323928252E302629241A232B26282D2B242D26272B2728B18916716D596F5B63745E62\
716364705F626E5D647564606C6166746560726164765F63725E66765F63725E66
755D636A58676E5D606E5C606E5C605F5462695B5A685F5B63595B6C5B5963565D70635A66545B\
6E5D605F5B5D695658634F5B6352596659585D53585C4F565B4A525D51534F5152
524C4B55484B44434C30374019262E1B241E130D0F3F22233F23264324354D252F442D45333637\
5941314B31406E403E7D544F6E555A4E395B534A554547485243443D3745524A3F
403B4068523F6F5247775257504D6255424C5A47529B703E856368766B6F735E68947066816E70\
866D71836F737D6C7486706F816A73836F73807472807472837271816A73866D71
836F73836F73816A73846871866D71836F73836F73807174
807472816D71836F737D6F72816D718372718372717F7274816E70866D71836F73836F73807174\
8372718071748372718071747D6F727F6E71806C70704C6E6B446D44395E3D3248
38323D2E222C362A32221D232D2528211B1E3223252E2828241C22C9790F6F5B636F5B63746160\
7462636F62656F6563705F62746064726263726164726164715E64746063726164
6C59646E596266505F76595D66505E634A5E6C53576E575A64555D6B5759695C5D716259605662\
6E56586D5F6165695E5C5C5E635B596355576152595A50565B52545A4B4F594851
50444E513D484E3E483A3A451F243115121919161A352B1B3D342D3E3B31403D374E4B3934373D\
3C282F4425356A4539623843743A506467604C65543D3B4D554544372F41634B3C
434A4A63593F5F494C7B5A4F564D5E463C517970497B794F866D627B6A6C716F708A7862836F73\
837271836F73807174837271807174816D71866D71836F73836F737D6C7486706F
816A73866D71807174807472837271836F73836F73836F73
836F73807174837271807174807472837271836F73836F73807174816D71866D71836F73836F73\
836F73816A73846871846871836F738074727866725E4F725B3D5D4C3858352D43
3B2C373333372A252829242B2D29252728292D2B24251C224C553397911B705A626F5E61756360\
7262637261647261647268656F6563715E647460637261647162656E5A62735662
664C6269445A63405A73495365475C604957694D546B4E5669525A6856596E5A5A6D575B6C5E61\
68675E6E645C67525F66535F65585A60535A6151575C4E575F5053564B535A4C4F
534F514C4F4D4640463F3441292D39181F2422251E29231D3F2B2736242C4C3434402A3348343E\
2A28324032303E202A7F4D4166714C5E464F643F5A414255544F44373C48533F37
553D46614C455B4B4E7A5F4B5B555F42475695803E66586099705C766C6F83786C807A6E837271\
836F73836F73836F73816A73866D71807174837271836F73836F73807174816D71
816A7386706F836F73816A73866D71836F73836F73836F73
846871866D71836F73836F73836F73836F73816A73866D71816A73816A7386706F836F73816A73\
866D718071748074727C6D7288706F816A737A6D75535271483A5B442B4637253E
30222E35212C2B212C241C22281A213024262D26271F1A219C8E196F82476F5F60706061756360\
726164726164726164765F63725E666F5E64746162726164726164695B6568525F
634C5F64575A544C56674C50624A555A4554654A50684F53664F556B54576B54586E585C6B545B\
75595D6E5C60676063625B5D6C645C5D5E5E5E57595D55575C5254564B535A4C4F
594C4F4B3D4C4B3F494040442D2E381B1A250C070C200F1539212034272B49372D302431523A32\
2F333C3B373029222D8E5B2457304A643A5376754F394E5951454748474C424240
554540553D425E3F487F5C4962585D5365608071476E626A8365587A4A6B9B6B63836F73836F73\
836F73836F73836F737D6C7486706F836F73836F73836F73836F73836F73807174
807472837271836F737D6C7486706F836F73836F73836F73
807472837271836F73836F73836F73836F73807174816D71836F73807472837271816A73836F73\
837271836F73836F737F72748373708071747965714E3E7042315536263E312131
2F242D241B233123272623262B2B252C28242218201F161EC67F076D5C60705C60705C60776160\
705C647865637269666F6365726164706265705E62786463593B5F5F2252894F56
636A605F605B55545D3E264454183D642C4569474A4D2D4870394A6E4C516C5557726259676460\
6E645C6E5E606E5E6067616368585B66505F60525B6155585A50565A5354564E50
594C4F4C4A504945473F344137333D1D232C0C0E131B17132519183421233B252835283249372D\
3C323A2F262F3C3836472926632F466B5F456844495C476141444C52414537283E
57353A4C374164504379644766575C7C815C53515D956B585C4B6594795F838663836F73836F73\
836F73836F73836F73807174837271836F73836F73836F73836F73836F73836F73
836F73836F73836F73807174837271836F73816A73866D71
846871846871866D71816A73846871866D71836F73807174837271816A73846871836F73816D71\
866D71836F73836F73836F73836F73816A73725B744032673E2B4A342B3C363535
28272A29272A241F202C21252E2726241C221E171E323226B38B0D6C5E617164606F6762756B61\
6C6466735D617C60646C5B67755F63715E64716164786861536C714985616F804A
6E6261656264585C603B686340854C507F475E714D42625B4E50446845497355517661586E5E60\
6E5E606E5D606E5D6067525F6E5D6066675F5D5E5E5F56595D54585C5254564B53
55454D55454D49404A424247393B3D29313707090E130D0E1C13142D1F1D352726392E2D36262B\
4A35352928323E2D2B1B0E1E935B265347465B3B4F76614C343753554243313243
4B3C355347415C4C40734C48745A597D5755533D6A824A4983786C839558816A73866D71836F73\
836F73836F73836F73816A73866D71836F73836F73836F73816A73866D71836F73
836F73836F73836F73816A73846871866D71807174837271
807472807472837271807174807472837271816A73866D71836F737D6C74816D7186706F807174\
837271836F73806873886D71836F73807174665C7436346433273F372835261725
301D292F28282524272D29252F2A271A161E1E161B554E26998124715F60716060735C627B6262\
7365686F6A677569626E6569706563706265705E627C63626A59677567636F6C63
6F6B646863656362645A5D5E6059576357576451565E505A5058585A5D4D70614E7561586E5D60\
7061616C5E616E5D6067616367585B6E4F5C67535F61585C5F56585D5557544E54
4E444E5544494B404A463B433C333F343138060810171411120E0F35281D342F273D362E252029\
4E342C2B2633392F2D1618238B57154E384F655B4973684A303458554640383945
48443B51433C5A46446C56487861516C5B5E595A636B70569E874E836F737D6C7486706F836F73\
836F73836F73836F73807174837271816A73866D71836F73807174837271836F73
836F73836F73836F738071747D6F7286706F836F73836F73
836F73836F73836F73816A73866D71816A73836F73837271816A73836F737D6F7286706F836F73\
806873886D717C6C74846C6E866D71816A736254762D285A31243A372C31282C30
2A2B262E26272C28292F2C2829232617141C231E1C9599176E884474665F6F6563726B64746A63\
7564667562677663667462677366676C5E656E59637E655F6D686A746A62796C66
6F66686A5D676C5D63615A625E555B614F576351576153565C4F566359546C5E537560596E5D60\
7361606B5D637061616C5E6167606367665E625B5D66595B5F555A615557575257
5153544E4E4C494349443C443C353E332B350F152206050618111232271A1D111A4E2D29282A31\
473D2B241E2C3826292C33335946235A3D456C554469494F46495F4141424C4547
3F3C3D4E3A3D51373E774F437A6251634E5D74635E7E8D5C868660836F73807174837271836F73\
836F73836F73816A73846871866D71807174837271836F73836F73836F73836F73
836F73836F73836F73836F73807174837271836F73836F73
836F73836F73836F73807174837271807174837271816A73816A7386706F7D6C74846B6F866D71\
7F7274816E70836F738074728372717C6A74472B6731184B382D38231A252E1B25
2B1F262F25272F28282D2527150D171F141B171113D07704706160746260715C637C6362756367\
7562677563677564667464677564666F67696A68657664607357657A5F647A6064
755E6A6D6168695E635F4D605E4559624A556551545E4C55635355685E547067586F655C6E5E61\
7362606F65646B5F616E5C626D5D606E5E60676163625B5D5F535B6354575D5458
595355514F5346434C443B443F3A4035383B1C292F06090C130F0D2B1C182F322B363322362B31\
3F332E25232F332C282E222751362E5A433A6344436A51506169582E394E50393C
3F30404E3D3B545043757241716854503D5C8B5A4F9B795A816D71866D71816A73846871846871\
866D71836F738071747D6F7286706F836F73836F73836F73836F73836F73836F73
836F73836F73816A73866D71836F73836F73836F73836F73
846871846871866D71836F73836F73816A73866D71807174807472837271807174807472816D71\
866D717D6C7486706F836F73836F737B6A742B2E692F29412E222C211927342F26
2B2C292E2B272D2627110A121C111A181414211F1DC38B00746460746A636E6A66756862756266\
7562677562667562667562667562667663667265686C5E65725F64735D617B6164
6F5A66715664674E62625260564F596256536256545E5657665F546E6A586E655B6F5D606F5D61\
735F607561626A5C656F61616C5F616E5D606E5D60615661635A5C5F5759615557
594E565B5254484C524448493D3B403B343A27273207090E1D1B141D181533201E302027362729\
36252B3834342C2E2B2F2B2C51462D564A3C5A4B446E57497A6A5428385B453A3C
3C303C4D3A38573D3C7C4C427A5757586C68819E4E868660807174837271807174807472807472\
837271836F73836F73807174837271836F73836F73836F73816A73866D71836F73
836F73836F737D6C74846B6F866D71836F73836F73836F73
807472807472837271836F73816A73836F73837271836F73836F73836F73836F73816A73836F73\
816D71836F73816D718468718468717F6B7324326C2C283B29222D292729342F26
2B24292E24272F282913171E1613121B1617678D2482AA227362607A6462746267756366756366\
756366796B66746E68746E687066687664667563676F67696E66646C5C647D655F
6F6769676064615562614F5A5E515A615653665A56625D586A61577362597163616B6062706161\
7060617868616A64676E61626D5D626D5E616E5E6061556266565B63575C5F5458
5A4F575A4951554A5346424B3C35423C333A3233380B131B0B08092519191E15163A2A2536332C\
2B25293E2C2B3834352C2C2D4F3A2D65533E57564969594A826651282C5A524B42
2C2C3858433744393C86653D746F546D625F9B7B58837271836F73836F73836F73836F73836F73\
836F73836F73836F73836F73836F73836F73836F73836F73807174837271836F73
836F73836F73807174807472837271836F73816A73866D71
846871846871846871866D71807174837271836F73836F73836F73836F73816A73816A73846B6F\
836F738372717D6C74816D718372716A4A6E2C1C5D302639252029332B29312C2A
2C282B2C27271B121B160D17110D1072A21F68C1266F7056776763796F64706568756366796B66\
7066687A60647A5B677A5B67755E697562667562667562667365686A6567796960
756367685D696562645A5C5F5E5557665A57665B566757596D5B5974605B715D5F756763706E64\
6A62647B65606C5B677568646A66656E66636B606266616364665F615D5C60595C
5A5658565255564E504F515238424838363B38313619242E14201B252719282D242F2B2140332D\
2B2B2F3E382D362E2F2E252E4D3B2E735C38564F4F67534D7B5850313B62463A3C
2A1F38593B2F473C41815D36856456797F6589855F836F73836F73836F73836F73836F73836F73\
836F73836F73816A73866D71836F73816A73846871866D71836F73816A73866D71
816A73866D71836F73836F73836F73836F73807174837271
816D718372717D6F7286706F836F73836F73836F73836F73836F73816A73836F738074727D6F72\
86706F836F7380717480747283727133175B3612433122301D15213D2B262B2428
2D22282F272915151D23231E1B251EBC940072635A766563766962796065755E69796B66796B66\
70616B756366756466786C677066687563667563667563667664666E5E677A6463
7563676F67696863655D55625E515A6B5955685C5A675E5B6A5C5A725D5B7361607A6960725D66\
736567746863706768705F62745B657260636E62656B60626C5E61635A6163585C
5D525A5D5557534D53594C4F3E3C4E3A3A40332E3526232D1F202324211E271D1F362B28352A28\
3B32333A362F342D323D3F354D54346A593A5949515F494C6F494E443959383142
27213257402D5650416E60408E704F8D7D6183756F836F73836F73836F73836F73836F73836F73\
836F73836F73807174837271836F73807174807472837271836F73807174816D71
836F73837271836F73816A73866D71836F73836F73836F73
816D7186706F807174837271836F73836F73836F73836F73836F73807174837271836F737D6C74\
86706F836F73836F73816A73866D71172A6933333928232B201D253E35242D2C2E
2A28282A21241F1E241B171750562C999A19706561786760756266756267796B66796B66755E69\
7560697463667664667A6165745F6A796B66746E68706668756266726568756864
7562677159667059665D53645E515A6651547058576A5A5C6E625D6D635E75635F765E61725C66\
7964627562677159657059667768626E64657060646C5C646E5D61696062615E5F
5B535B615356564F57564D5043404F3B3841312C372A282E1C191F21181C261E1F322522312529\
41322D3B32343733343A2C2E6D56385A5746594B4F594C4E634F4D5458582C3847
353E3D484630583E3B7554459A804B897B66836F73836F73836F73836F73836F73836F73836F73\
836F73836F73836F73836F73836F73816A73866D71816A73866D71836F73807174
837271836F73836F73807174837271836F73836F73836F73
807472837271816A73866D71816A73866D71836F73836F73816A73866D71836F73836F73807174\
837271836F73836F73807174816D711925653D383C272C332628292D222136262B
2C272B1D171F2B22232B342A8AA619748B457163627864627563667563667A60647A5B67755E69\
756266756367756366725C667860657A60647A5B67755E697564667564666F5766
7C5E646F6668706C655A5C675C565C6154566E57546D585B6E575A72585E745B5E755E62726063\
755E627861656C6068736B637262626F56657158626E5A626F5E616C5B60665761
625E5F5A5759594E56564B524B4A513B404734383D2A2B302124291E1F1E26201E271D1F372A28\
3B2F2B3C2F3132262E30212B8B612A534F5154434D5F4A4D5B484D695250242345
4B3837443C3A4F3F3C77573FA77C4788726D836F73836F73836F73836F73836F73836F73836F73\
836F73836F73836F73836F73836F73807174837271807174837271816A73866D71
836F73836F73836F73836F73836F73836F73836F73836F73
846871866D718071748372717D6C7486706F816A73866D717D6C7486706F836F73836F73836F73\
836F73836F73816A73866D715C316A2611504029332D243233312F2B302C302C28
241B23201A212C2520769C2B77AC316B5F62796563746764756366756366756366796B66706668\
756366766466715D676F5765755760785963755B64796265756466705966715F67
776860756366766466615D6B59545F6052576751546A4C56705559664B597B565A755E5F705A62\
786462726063725D66765E626F57666D5863705D606E5D616F5D606D5E61655960
6A595C5B515E5C55585653544C454F46424B34343F2F2E3526262A18151B281E1E241F20322522\
45392F332F30342D3132322F7E5927553D50594C4E5A504B3D25428E5542151A3E
4E312D54493E4F56436B5E41AE8444837370836F73836F73836F73836F73836F73836F73836F73\
836F73836F73836F73836F73836F73836F73836F73816A73866D71807174837271
836F73836F73836F73836F73836F73836F73836F73836F73
807472837271836F73816A73836F738372717D6C7486706F807174837271836F73836F73836F73\
836F73836F737D6C7486706F2C2264423F5231413826232D45392F26242C32272A
1C17202D28242B2B25B47C147A5D5C6B54667F645E756267796B667066687563667A6264745F6A\
725D66765B64684B64745360705C60725B5F725961795C607A61656B5F68746362
786563746366766466665A69574C616251565E4C54675154694F536A5A5C716556725D5F726262\
70595F7252636F4F6076535F6F56626D5A606F5B5F705C606F5E606C5B60695D61
61525C67595D5A5659594E56504E5446444A3939442F2E352A272D15151D1A1214291C1E2F2723\
402D283B3035332F30362E2F76562E52484D5947485D4A4D221C3B9A542919254E
3A312A6040346557466F744CA18B49836F73836F73816A73866D71836F73836F73836F73836F73\
836F73836F73836F73836F73836F73836F73836F737D6C7486706F836F73836F73
836F73836F73836F73836F73836F73836F73836F73836F73
836F73836F73836F737D6C7486706F836F73807174816D71866D71836F73836F73816A73846871\
846871846871836F7383727112124F6D40382B273C37373935312B312C34292727
17131D453C25558E38799B2D654B5D79575E7D695D7463667A6064755E69756366725D65745865\
705765725962665E66614F5A6E4358764E5B72585E745B5F795C606C5466755860
7D6161756267766466604F675B4C605B4953634F545F4F51644C546E5252775A596F5C5F6E525E\
6D5061684B5C694A5B6A47576D4358683D577242576E4459764E5B6D535F6D545D
635861695E595B515D594E56524450493E4D3C354236363C2A2C301F26290E0E112317162A1C1E\
402E28392C2E3E37352D2A2E744C2D5C4D4D4536475D38431F1D3C9E741F1F3151
2C282E6C5230695E4483714E987F58836F73836F73807174837271836F73836F73836F73816A73\
866D71836F73836F73836F73836F73836F73836F73807174837271836F73836F73
816A73866D71836F73836F73836F73836F73836F73836F73
836F73836F73836F73807174837271836F73836F73807174837271816A73866D717D6C74837271\
807472807472837271877873072A6854432E291F393D2A2D3125303A2F2F150F1B
332B29332E21AB7724543E536C3B578364527A6860746267756366756366725D666D556566445F\
5E2B5565204E7B3151613E5A58395079484E6D48577F5E5B726361695D656F605F
7D675F7465667564665F5E6B56545E5449565E454D5F44506F61525E5956796055644C5D68475B\
633F565E3754562A4B602B4A683A4C5D405161414D6745517658526A595C634D5B
694A58694A58614C5A594D56514A5348424B403E46322C372F263128252A1A23251D2019211A1A\
3D2A2333262C412E2E322C3463472D5B3B4343344A4E3B3D28293E9E751F1F214A
2D2430785A2A614D4892684B9C815D7D7275836F73836F73836F73836F73836F73836F73807174\
837271836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73
807174837271836F73836F73836F73836F73836F73836F73
846871866D71836F73836F73836F73816A73866D71816A73866D71807174837271807174837271\
836F73836F73836F735B2464341A62423938251E3137272A2C21293E2E2C151924
4038215F9038718A30473F6164534A87684D765E617860657563666F576567446153225262234E\
6651554C635339253B52143A5C28446E43425C364E6D2D489149566F5B636D5A60
7F655E7563677563676659695A56634F4C585B535051454D72474835103D660D386C1D4A70404F\
6B685835334C3617375B2D39532F3D5229415329415E2F427942476E4756634C5A
6353566353565D4C555D4C555044514A3F4C3E334137333D2F313228252A2E2F2B16171B1C1518\
3D2D21312A2C3A2E2C3E3834564A33574B443D38444B3C3E2A2638A26D231C2951
3A423776702D5A5C51958347927A60836A76836F73836F73836F73836F73836F73836F73836F73\
836F73836F73836F73836F73836F73836F73816A73866D71836F73836F73836F73
836F73836F73836F73836F73836F73836F73836F73836F73
807472837271836F73836F73836F73807174837271807174837271836F73836F73816A73866D71\
836F73836F73836F732A2B6B514C4E333C412D333A1D181F3827293A332B191A25
211316C76D175B545C56525D5F5E50836C4E7568637161647053646644624C28544F3450687347\
6E8D4C30274A371E4132242D53323157313A6345494F494A7F56426D425A7A565C
7F685D756367715B666A58675F546153505C52424D4C344B5D38423F545A2632318C7A3369A74F\
362948441A4A32303A554B3233253666503D363B3F432A3666333972444A624953
6750546252565A4D565A4951554B52443E4A3E36433B343A2D26312A222A21161D0B060D191012\
402D1F36302E291F264C332E574538513D403A2B414D383A32353F8C66281C1741
6451356C673C605254A8874683786C836F73836F73836F73836F73836F73836F73836F73836F73\
836F73836F73836F73816A73866D71836F73807174816D71866D71836F73836F73
836F73836F73836F73836F73836F73836F73836F73836F73
836F73836F73836F73836F73836F73836F73836F73836F73816A73866D71836F73807174837271\
836F73836F738778733393902A4D4D2D1A39311B2C1B15223B2E2235292A292C30
2A412DB0950B5247625A40526C4F517E5F517A5A606F56656146605532573C2449270D268E2B30\
833E4D2B295B567642070913612C242C17295F23305B3043683C41765152796A55
7B695F7563676D6068695D646158625B5C5E44465549434A41313E613A3E3B50554F332CAC3446\
1C124A746E390808136220262D1F347A542C160B263F18295B3731623B3D5F394A
6B484C624A535D4B5451405059404B483E4D3D3842342A362F26312C282B1210180F0D11171411\
2314143F232628232B51442B4736364D333D413A4248443B38343C825D32171D41
6E4C29694A45736354A28949836F73836F73836F73836F73836F73836F73836F73836F73836F73\
836F73836F73836F73807174837271836F73836F73807174837271836F73836F73
836F73836F73836F73836F73836F73836F73836F73836F73
836F73836F73836F73836F73836F73836F73836F73836F73807174837271836F73836F73836F73\
836F73836F73561E619E245F322A672F3B43272E2F24292A353124322A2B37322E
4A50358F722B4F3B5E5A48516A584C7C645374625F634E6259425D473852261834332F37483423\
36072621001F3B051C271A3F45491F2D32384C4C2E58533D636A486D6F4C7A6A58
7661617962656F6068695B6565596262575D4C535E464E4E404A4B443B3A4B293B4C3E48644134\
180B322D08151E0A2F2B1F16321B2937131D2D1C3B2F342456422D53403D523B42
64424462454E5D47504E42514D3B464A354435243A362734342E312925291C202511151522221A\
22251D29201C2F21274E372946393B3F33373F2936523A3A3D3B407B61341D2C4C
61532E634F459283488D865B836F73836F73836F73836F73836F73836F73836F73836F73836F73\
836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73
816A73866D71836F73836F73836F73836F73836F73836F73
836F73836F73836F73836F73816A73866D71836F73836F73816A73866D71836F73836F73836F73\
836F73836F732224657A3C3C4C3C5B2A283C2A1E2D39352F2E2F2B2C2328362528
6348317A593D51455A5A4E4D69564E7D6352705A5F655C6559656148665C266358315137333434\
272B3125352C2A3826323126483C3048543E55743E5C7B486B7A4E6A6A5A77675C
7567647567646F6068695B656A6062656561565E5F4D5A594C595041544D3E4E44392B34562F3B\
2F4B4D246339244A2E212C262721202C252646462C42603B485E384C4B42535146
5A58475A504C53424D55444D48444A3E3540312939352D3032282D2F2A2E23252716171B25201A\
20191C21181C2E2221503D2B4A433A3B393D3732365241354C4B4370623C262E4D
5D4C35675646A5824189756A836F73836F73836F73836F73836F73836F73836F73836F73836F73\
836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73
807174837271836F73836F73836F73836F73836F73836F73
836F73836F73836F73836F73807174837271836F73836F73807174837271836F73836F73816A73\
866D71836F732C899031574943223E291634291E273321242F1E29241A23463C2C
5B52306545415C415155414C6B4C4B805F507163616C66626C72635B75664C7C643E945F309E57\
2BA1512DA14A31A74931AF4A3CA046446D48625C486B5650795E56766B616F6762
7863637562667365686A65676C65626B5F625E54625345585C4A524D454F565B4E3A7254477B43\
435A484854483D5E4A3272482F8B4332974043883D5477465170514E6F5152634D
5A584E574E5050474F4F4047503F483F3D462E2E383932322E2A2E241A2326192218151B251E1B\
2B2A2424292324211F513827584A3B35343E392F37594A36554F426E5E452A314F
5F5139848C4591A34D7D7871836F73836F73836F73836F73836F73836F73836F73836F73836F73\
836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73
836F73836F73836F73836F73836F73836F73816A73866D71
836F73836F73816A73866D71836F73816A73866D71836F73836F73836F73836F73816A73836F73\
837271877873778179111044411C331C1323281A20271C203F372C181A21432921
5631316342405946494E3D4A6B5046836A4E6A565F7B5E607966627166686C6B676E6F64677267\
63786451565F53314E591C455713435419448354466A6E56757759756C61726568
786E657066687664667164686E6366706B655A5F66535B5F483F4D412241562139561E3F642D45\
6E63525483565288585185575578565C70565A6658616255635D585E5558594D56
543F4F5031495D404A4A424A48394244324136333E332F312F272F2B2E2E19191C1A15191D1617\
281A1C1A0F173224234031255634323B2D3F383035614D35564B457866472A3855
64573BA4833C927563836A76836F73836F73836F73836F73836F73836F73836F73836F73836F73\
836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73
836F73836F73836F73836F73836F73836F73807174837271
836F73836F73807174837271836F73807174837271836F73836F73836F73836F73807174837271\
836F73815E70976A710110453523231B162226201E2C2824392C2424242E3F3F27
453B305739375A3B444F3E48654B438A604A67596470555A7C525E7D5F64746267756266715966\
50215655154D462044472F3E5C6444509A4B6A98436D715D796A5F796A67716668
7D686570616B76646674646772666772616469636A5D69644465633154512F303638202E48202E\
651F3387314A74445777565C6A616169655F605A5F685D5B5F515A5F4958523C51
462C485A47484F46434C3A474134423E2F3B3E3239312C34231A2529182119121C1F1B1B1A1718\
1A1315302E25333C253E3E2E4A43343C383C322C346548325340457950433D425D
5C5741B38B3B83786C836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73\
836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73
836F73836F73836F73836F73836F73836F73836F73836F73
836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73816A73866D71\
87787353356EC06357001C5A272523282728292C241F191C3B28262A252A3E2F29
3C2A30412630583138533B42624C448665477065614C385970304E7931526F2A576A2153560F49\
4B1A4D5C574655A04E3DBB5359AA4A6F8B57717764717268757066796A6775696B
756267755E697562667562667663667164687062656D6466616F674982682B8D612B8B4D316941\
384138471E2E60153A5A103C6A11436E1C4A63214E602149561C48572044572E48
4E4A4B55514150474B4A47483C39423B333A3E35372D2631363E361013172B2322252A221F2321\
1719191E1214482B28423931493B373D313A353037614D32595448513B42452144
896C439E9643836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73\
836F73836F73836F73836F73836F73816A73866D71836F73836F73836F73836F73
836F73836F73836F73836F73836F73836F73836F73836F73
836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F737D6C7486706F\
896C71393B785E163B2503442B242938372B2C302C242A2A2F29222C2328372A28
392C2E3A31314A39324E373A6E55417F694A76615E4F71705288584D5C5454465150434E526A52\
51AC4D58B34C718E54757066756D69796A6779666A79666A79666A79666A79676A
6F616B756366796B66746E68756E687066697266677167667368656D64666265675970634C8161\
3B985D2FAA573DAD4A2E734F3A473E4A343B4E323F4A3440534D454C5F47495745
554F4558524B504D4C4B43493C37443E383C423E3A28293329182125212E23241D21171D120A11\
130A101810134D371E443A343828324C393A3738396354365D4F46372945514543
A3992D8D835E836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73\
836F73836F73836F73836F73836F73807174837271816A73866D71836F73836F73
836F73836F73836F73836F73836F73836F73836F73836F73
836F73836F73836F73836F73816A73866D71836F73836F73816A73866D71836F73807174837271\
836F73415A7F24324D2A2A352927284E472E303C382B31302E2F2B29272739312A
36302E3B31304A3E35453B3A71513A84634C725D5F745E626E62645E786A5191624C995E5F9354\
7577587E686479666A79666A79666A79666A79666A79666A79676A78676A79666A
70606C796B66796B6679666A755E69755E697562667562677562667365686B62666E63636F6762\
6960626D5E616D5F6052636846865F409B543E8D51427E50537349555D4F515351
595A4D50474B513B4A493445413442443D3D433C3B33383D20292D241F20181018120B11110C11\
110E0F1713126C5E1C3135353429346862342D3A40583C346F5447293149675738
B3953483786C836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73\
836F73836F73836F73836F73836F73836F73836F73807174837271836F73836F73
836F73836F73836F73836F73836F73836F73836F73836F73
836F73836F73816A73866D71807174837271836F73816A73836F73837271836F73836F73836F73\
836F734B43751D164232202D332E2E5A512E33353D2D2831352D2E2F2F2E36302B
352C2E392C2E503E3440363B7053398364497362607163617261637A6662756367746267796B66\
746E687563667A5D677D646879666A79666A7560697D646879666A79666A79666A
70626B7961647E6468755E69755E69796B667066687564667465667564667066696B6065756162\
6A5C656E5E616D5B6066576172605C65515E66515E5E515A5D4B555E4B54574B52
5D4B4E4E425150494B4649493B394046393B44393C3328353838391E272916171B181918141513\
1E1F19161715825E15333F482D3134724E2D36344B413336815639292D4C827134
AE9A3E7D7275836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73\
836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73
836F73836F73836F73836F73836F73836F73836F73836F73
836F73836F73807174837271836F73836F73836F73807174837271836F73836F73836F73836F73\
836F734B5D7E1125483B3C303538304E382F37273A383537353731322E2F32292C
33272C34272B4B332E43343A634237895745785B5C745E62726063765E627A6165746467796164\
7E646874696C7167687D686579666A79666A75696B796A6779666A79666A79666A
75696B746D69796B6674696C746E68756366755E69756266735D66765C65765C656F5F67726462\
6A5B656E5C616C5B606A61616A595C66566163575B5E515A5D55575A52535A5153
574E50544F51504C4B44384640344248413D3F373B37353C2C21291E1222231E221C1D1C0F0E11\
140C0F171014895A143C384734363E6D5F32363949362D3875463131284AB6A024
8C8C57836A76836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73\
836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73
836F73836F73836F73836F73836F73836F73836F73836F73
836F73836F73836F73836F73836F73816A73866D71836F73836F73836F73836F73836F73836F73\
836F7367787C0B2C5833292B36232E3A222B3C28333C2F3132252F362A2F302A2D
352E2D302B2C4F443045463C5A533D7C6241725559795D5E726063726263796662756367746267\
7A60647E646875696B796A6779666A79666A7560697A5D687D646879666A79666A
79666A79666A755E697A5B677A5B67755E69756366705A65755D65726164726164715E64705863\
6E59636E5E6166535F70535C69545F6A595C63565D5D515A6253565A50565C4F52
5141505A424B4F3B4B4A424B404242443A3C3D303B322331291F2D1E1C222A2621141116100D11\
110E0F211E18653F195E4E49374F47675D3A393A4D373B3E452C2F64594AAFAC27
837271836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73\
836F73836F73836F73836F73836F73836F73816A73866D71836F73836F73836F73
836F73836F73836F73836F73836F73836F73836F73836F73
836F73836F73836F73836F73836F73807174837271836F73836F73836F73836F73836F73836F73\
836F73847A740A19533D34332C2D2D39352F3C3A313C3834323435322F2E332E2F
322A2B3933304A3D2F55483E574D4174554572585779645A726162766763756764756367746467\
786C67796B667560697A5D687D646879666A71626B796A67796A67755E697E6468
79666A79666A70616B7563667563667564667465666F6869726B646F63657261646F5F656B5C63\
6E5D606E5D6061556268555A69535B6A535A66545C5F545B6053565B4D565D4E53
514E54514C4B4A414A4C3E44493F45413D4139343B2F2D35211C242B2627171217150F16151313\
100F0F1C15135B3D20694A373C2B4669423D46414F3F45443132399C822A9B8E4B
836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73\
836F73836F73836F73836F73836F73836F73807174837271836F73836F73836F73
836F73836F73836F73836F73836F73836F73836F73836F73
836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73\
836F738D75700830722B2A2C372A31403A303D37343529313C2D332F282F352A2D
3D3A333736304739345742395A47456B5247765B52775E5A766062766062765C65796265756367\
7A61657D646875696B7064687A61657D646875696B7562677A5D6778676A756466
795C687A5B67756069746366756466756466756367725E667962656F60687261646C5A64726363\
6960626E5C60676063625F5E665D5B675E5B63585B60505A6151575A4E565D4F52
51415057444D4A414A493F454C40423B2F3D3E303A312C3424252C241F20151119110E100C080B\
0C080B37341E433D2258353441324466563B4D4B4C56664D336150A9B425838663
836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73\
836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73
836F73836F73836F73836F73836F73836F73836F73836F73
836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73\
836F738D7570101454453D3E3A50373230313E2C32352E34372E2F322C313A3730
2A1E264329304C4135544B3C5343426B5047765D4F745F5B76605F746063756764756764756367\
796A67796A67755E6979666A756E68796A6775606978676A7167687960657A6669
7066697463667562667563677563667562667663667265687567647265686B5B65705C64736160\
6B5A646E5E6167535F705C5F62565E6A535A624D5B624F586153565A4E565D4F52
4B43525B504A47434C4A404541313E3C2D3C3528312D1D2C32282D1B1920100C120C080B191714\
0A0B0B4D3C183E3B304435333E29366D463754444C63484672805894A044836F73
836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73\
836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73
836F73836F73836F73836F73836F73836F73836F73836F73
836F73836F73816A73866D71816A73866D71836F73836F73836F73836F73836F73836F73836F73\
836F73896C7115879A235C4133223335223335262C35252D33252C372B2E35272B
34323539392C4F3E3457453E585148635A47755E4F74605A75615F776763756764756267766366\
7D686579666A70626B7D69657560697D646871626B796065765F69786B67756466
755E69756267756466756466746467746566756366766366756367705966705F676F67626C5D62\
6E5B626E5D60615562745F595F546166575A5E515A6252566252565E5557595153
4F4B535B514A443C4C4636423E333F3F393A363A392A3031241D221E16200F0D11100F0F1B1713\
0F0E115644183E3734423937373237695033584E4B5E584CA49241837E68836F73
836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73\
836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73
836F73836F73836F73836F73836F73836F73836F73836F73
836F73836F73807174837271807174837271836F73836F73836F73836F73836F73836F73836F73\
836F73836F7377817913235830243532292C2C222934282A30272A2E222736292C
3D332E3E3834514A3752493F62514564574E725F5174605A766460735C617C6064746267766466\
7A61657A5D687560697960657A6669796A6775696B746D697065687A5F657A6669
706669746566756466756367756367756367746467756466705966725E66726462726164695B65\
7265616960626760636E635C635B6263595B5E515A6153565E4C54655154594E56
58525451454D473A4C4843443F4040362E363927322316271F141F160F151511150B090B171010\
110D10644B193937383D2F343A2D366F563363624D697A529D8F49836F73836F73
836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73\
836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73
836F73836F73836F73836F73836F73836F73836F73836F73
836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73\
836F73836F73896C71195B8B1C3E3C2F2B2D2F2C2D312C29312B2C2F2D2C302928
37272A463431503C36564241624D446B574D705F5373605B77635F6F6265796861746267756266\
7A6A677064687A6A67746D69796B6679666A79666A755E6979666A706768796164
7A66697064687663667562677663667563677563677563676C61697569626F6365705C646F5F65\
705C606E59636D5D606E5D6063526066535C5E525A6153565E55575D4F525E4C54
55424F54435048444A44394146374039393E302F331C1A251E191D1412151916150E0E10171411\
151313684D184549422D2F36473E3665523579614A8C9254838762816A73866D71
836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73\
836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73
836F73836F73836F73836F73836F73836F73836F73836F73
836F73816A73866D71836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73\
836F73836F73836F7358808210345527232C2F222732262931272A332A2B322D2D
2F292A47362E524639564F41625947675A4D7664556F625D735C5F755C62775E62786266746566\
7A626574606A7A62657D64687560697D6468755E697560697A6265755E69756367
796164755E697664667464677564667562677663667563676F6068765F63715A667161646E6063\
6C5C636E5D606E5E6169565F665760665D5B5F5A5C5D54586253555A4E565A4951
564B534B414A503F4840394441353B392A373024311D19241E1A1C161518161213191818191A16\
100E10603B19563E3C3134415251366362407D75489D8152836F73807174837271
836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73\
836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73
836F73836F73836F73836F73836F73836F73836F73836F73
836F73807174837271836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73\
836F73836F73836F7380717414306C2C3C3B282E2B35312B312F2D2F292A352B2C
332E2E43392E4B353463453F6958496B64536E5E55735B5E736561716662756863756764756367\
7562677562667A6A67796A6770606B7A616574606A756366756266756267756266
756367746566756366766366756367746467756466725E66725E667261646F5F65735E626D5964\
6E5B626E5C606F5D6065586169585C66535C634F5B6050596253555B4F565A5354
51474F4A3E4D4C3E444035423D313B3329342A212B1F1A23211D1E1817191512141C1716110D10\
0C080B5E3D184B34343D2E3D5C49386F5D4491884C898360836F73836F73836F73
836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73\
836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73
836F73836F73836F73836F73836F73836F73836F73836F73
836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73\
836F73836F73836F73836F7334A492189961215647334234373D35353F352E302E
342B2D4436304C453957493B6A494577544F715F5C6F625D735B5F775E62755D63775B64786065\
7562677563667A60647A5D6774606A7563667A6A67706669746366756466746566
756466756367715E67796265725E66765C65765C65725E667567646C5E657360646C5B636E5A62\
6E5C606E5D6068525F6B545F68595C63555C605159665958594E565F4B545F4D52
493B504F3F48443742443841352D38302530271F282927281C1B1D1E1A1C141315120D0F0A070A\
23221A61631A3A3E3A433E3B5E563A6B5945AC824681706F866D71836F73836F73
836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73\
836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73
836F73836F73836F73836F73836F73836F73836F73836F73
836F73816A73866D71836F73836F73836F73836F73836F73836F73836F73836F73816A73866D71\
836F73836F73836F73836F738D7570578D892AB07818494A3C3537352831382F34
3534313D322F4F38345D49405E4F4671534B7B5D566F5E606E5D6077635F716265756863746765\
715F667761657563667664667563677464677A6265756069746467756366766366
7563677563677265687567646F60687261647261647567647261646B57677359606E59646E5E60\
6D5D606E5E60635A6266565B69535B66555C61595B625256564457614E51533F4F
5041504C45473E3643382736332032352A30242228231A1F211A211814171A16190C0B0D0A080A\
57591B4B512B37293B503E395C483C8173489C8D4A807174837271836F73836F73
836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73\
836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73
836F73836F73836F73836F73836F73836F73836F73836F73
836F73807174837271836F73836F73836F73836F73836F73836F73836F73836F73807174837271\
836F73836F73836F73836F73896C718967747D787A194E79252A353A2C3230262B
3E2E303931324D3F345B463B624E486B594C755A536D505D755A5E735B5F775E62745C63765864\
745D66756063786365756466756367725E66796265756367756367715E67796265
715B66775B64755A65775B65725E66726164715E647356617353646E59636E5D606E5C606F5D60\
6D5D606E5D6064546065545D66575A66575A624F596250595650575A4C4F575254
47444A4733443D2C3E362E38313031342F2D2E3031191B2020191C191619110D100B080B4B6E24\
4063233F3039382C395B4D36666E458B93448D815F816A73846871866D71836F73
836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73\
836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73
836F73836F73836F73836F73836F73836F73836F73836F73
836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73\
836F73836F73836F73836F73836F73836F738D75703961870E19353F2929424638
2D312E4A413646433757463E614C456D554D715B546B605D70635B6E5C60735B5E755F63706463\
7569636F6365755E637A6165725E66756367756764756367756367726568726164
715F677568636E63666E5A63775E626E5963755F63695D646E5D606E5C606F5D606E5E616E5D60\
6E5C6069545F69576062575C665659635059614E59604E55523C5260464F58434C
48374D4238433C373D3A3738302C322C212934242A333F360F1417120C101410132F3E233E351A\
53303B3A343B413F3A5E56377B6A4499824F86766B7D6C74877B707D7573836F73
836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73\
836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73
836F73836F73836F73836F73836F73836F73836F73836F73
836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73\
836F73836F73836F73836F73836F73836F738D75704A3F7818325D2B34293C2329
392836504331453B3D57463E6251466A584C695053755458735C5D6D5D606F5E60755E5F715762\
7E62616D5C67736064766062725E66765F63765C65765C65765C657962656C5B67
735B637456617353646E59636C4F5D755561725A5E6E58636E5C606E5C606E5D606F5D606D5D60\
6E5D606152606A515A66535C625059634F586152565B4C554B42535944474E3649
442F4343303D3A2B383725323528322D2B2E312D2A26161F26212E19261F2634212C291D4D4532\
41413349464049533F65694171654AA57D50877B707A7476896F6E836A76836F73
836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73\
836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73
836F73836F73836F73836F73836F73836F73836F73836F73
836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73\
836F73836F73836F73836F73836F73836F738D75703A3A77404E5C19223136272A
372A2B41272C4C2F37573F3B6043426542496F51526C5855725559725A5F68525F795C5D6E6063\
77605E715C66705B62725762755A62755F637261647567646B5C65795A616D5766
705A616E5B6268525F6D4C5C684F5E6F535875595E6E5D606A575F6B505D71535D6B4F5D6D4C5C\
6E4C5C61485D685057654E575E4857624A535D4452563A50533F4E4F40474A3D47
3F3841443D3D37373B2B262F32252A2D21292F2227221E262C24211D181F53552A29493647432C\
3E303A665A3C4B5248766B45819B5583915B896C71816576866D71836F73877873
7D7275836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73\
836F73836F73836F73836F738778737D7275836F73836F73836F73836F73836F73
836F73836F73836F73836F73836F73836F73836F73836F73
836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73\
836F73836F73836F73836F73836F73836F73896C71486C874A806009152F311F21
45392F2D2C2E4C393051403957414066544969594D6750566E53576F525968525F775E58715A61\
7057607358617260636B5F62705C607359607357627655616E5565725B5F6E5A62
6A56606A4E5D64495D674E596750586A54586F535769475B6A465B684B5A6A4C57634459694956\
684F575C4858684F535E49555E4B545845505B47504E444F4C3B464E39454C3E44
403A4241363A342736312A33312F2D2C2A2B3A3D2F28352F272A26344230575B28373640474139\
49514167653B5F6D55676A4DA5764F866D71836F73807174877B707D7275896C71
836A76836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73816A73866D71\
836F73836F73836F73836F73896C71836A76836F73836F73836F73836F73836F73
836F73836F73836F73836F73836F73836F73836F73836F73
836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73\
836F73836F73836F73836F73836F73836F73836F737378794741691B385F243D2C
3B2F283C35373C332E4C323550343B673F3F6C484D6E5D556055576A50576A54596E525877595D\
6D5E616E5F5F715C5F6D58626B545F6E525E6F525D6E525E6B4D5D6A455B6D4159
6B435A6649595E4757634753604152653E50663C51623C53644251614151623F515E41525A3A4D\
63374C5C3950603C4B5C3B4F55354A56354A5C3F484F3B4B4A3D47483B41412C3B
3E243846313937363A2E2C2F3E3932353F352B24283E2D323640353D402F4B36343E2D3C564B3B\
4C4440745B437061517D885D84915A837271836F73836F73896C71836A76836F73
836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73807174837271\
836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73
836F73836F73836F73836F73836F73836F73836F73836F73
836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73\
836F73836F73836F73836F73836F73836F73836F73836F734F8B86237267244345
2E31303F302E3E34364942364D483D4C3A3C6236416933467145556755566C5D586A665C6D625A\
6B545F6E525E6E525E6D525E63495D6948586441576E46566E565A584B5A624B54
614A53624953533C5161414D51374C5F3F4A533A4A63474B4B3448633C494C30475D34454C3046\
5231415A3A455037455336444F39464F3D434C3340563C45514B48414145444944
38473F434639342F37353035433E3144423A273037261B213F2029523F37464C3E3F4740554D3A\
5C614B676B466C5A55A47E50837370836F73836F73836F73836F73836F73816A73
866D71836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73\
836F73836F73836F73836F738778737D7275836F73836F73836F73836F73836F73
836F73836F73836F73836F73836F73836F73836F73836F73
836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73\
836F73836F73836F73836F73836F73836F73836F73836F73836F7352898528B874
1568523445383229304E33334E373A3A263961403A5C50467265496A6A5969685B6E605D69565F\
6A565F64505B684A59634157644658604A545D4C55614D506946515D45595F4E51
543F4F5C3B4B4F384D563C454C3849563F424C3A474E2D3D513448533D3F3F2C43472A37543A41\
3F343D573D3C412F3F4B313C4C353E4A353E4738403F27354E213749273E4C323B
422F3D45333A3B363D3D3F3831272E40212E3C2D392F4338394E304B46324A373D564C44607247\
5F6B4C584451988A5083915B836F73836F73816A73866D71836F73836F73807174
837271836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73\
816A73866D71836F73836F73896C71836A76836F73836F73836F73836F73836F73
836F73836F73836F73836F73836F73836F73836F73836F73
836F73836F73836F73836F73836F73836F73836F73816A73866D71816A73866D71836F73836F73\
836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73797476
23366B3E3D443847403F43354F483C4A6A4A517440525249735549674054734157734C5A6A505E\
654C5A644B5A5E4A565D4B55604F51533D5061414D624C50584650593D4D60424D
5041504F3F484C3A464F3D43412F3F5F4641413944524D464649414638404C48453A4540423335\
564B4440413D49434441423D463C3C4A413F4A47412D2E3A413533483F38443E3B
3A3039443537463F3B372F3639363A343932403A323A30344637364F463C5A6C46577548615B4C\
654C5567725D9B9744836F73836F73836F73847A747D7573836F73836F73836F73
836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73\
807174837271836F73836F73836F73836F73836F73836F73836F73836F73836F73
836F73836F73836F73836F73836F73836F73836F73836F73
836F73836F73816A73866D71836F73836F73836F73807174837271807174837271836F73836F73\
836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73
3DA08F16464E4E3F3E3D393E442E356030395F324655364A684146695054645C53655155654757\
614657644D545643545D434F5D434E4C3A4E5B43465738475B3B4C503C4A5B4246
4C3849564548403843462F3C4738404229335333424D373B543D463C344050363A453542413F3F\
5F523931273F4E2E36452F3D50433E443C3E422B393A2D3D352B2F3C222D34162B
371A2D432A3038202E361E313A252D37242F412E30453F39515D3C5871446D7E474E4754694B53\
4C324CB48042838663836F73836F73836F73896C71836A76836F73836F73836F73
836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73\
836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73
836F73836F73836F73836F73836F73836F73836F73836F73
836F73836F73807174837271836F73836F73836F73836F73836F73836F73836F73836F73836F73\
836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73
896C712CA3991F6E523B404440423E5A5E3C515A47545D4C5F6B4C626250645757625659544454\
5D424F5F424E58445253434B5C484B4C474E534A47493D48523B425645484C3E44
46324350333D3A243D4F3E3D48453D302E3B331C285930383A223255394042403C463C3E463C3D\
3E223241273F484236271A2B3C14274A2034382534392630362A32393632313A34
3843323739303534342D2C2D3C36303A3E345B7B393D6643616A43676A4D3D1A40712A4F513144\
726E55A2B0377D7275836F73836F73836F73836F73836F73836F73816A73866D71
836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73\
836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73
836F73836F73836F73836F73836F73836F73836F73836F73
836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73\
836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73
836F73896C712E417C3A424B362937582B344C1F3C60293F7541476B4E54645157665457504C5A\
50454D57414A533B4857414A5745484F3D4A4D36444F3B464F454449363F503845
474344362C385551423E473A3C2738534E44223D3B3C2D28463C3E3C312F412336462B36392133\
37253535252B3216263221322F302A40372C2F272F35292D3C3330362E2F34252E
351F2A3C2630443A3540533E3F5A3A4C69415A543B6962555B69504C2E4B3A2B51665A35403B4B\
B69B2E898460836A76836F73836F73816A73866D71836F73816A73836F73837271
836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73816A73\
866D71836F738778737D7275836F73836F73836F73836F73836F73836F73836F73
836F73836F73836F73836F73836F73836F73836F73836F73
836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73\
836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73
836F73836F7352958713284649363D54643B3548434C453A62443D6F4A4B6752555F4B555A4756\
40314A5636424C36445C4644534749493D48413140543E3E4E3E4242384354473F
44394142454639282E4D263D3B363D442B2E4632432C2F33442E2D3A2B38342B303D2C30332932\
30262B33282D2D2D2D322E292C23282F1C2436232D342C2C35282B33242D31272D
383530434B334347374A3C394A353E684C405E6151492F415B17444D2A4C585F474F5343709A53\
8AAA3E846871866D71836F73816A73836F73837271816A73836F73837271877873
7D7275836F73836F73836F738778737D7275836F73836F73836F73836F73836F73836F73807174\
837271836F73896C71836A76836F73836F73836F73836F73836F73836F73836F73
836F73836F73836F73836F73836F73836F73836F73836F73
836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73\
836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73
836F73836F73896C7118A39F1A5E4434172B6936424E584554564659424575514E5E5A59565555\
35364E54473F423A4250343C5635424632433E313E523F3A4B3C413E313E51363A
412E3F4E373B2B263A4F42323B35393A343834222B2E192D4F41322A272F36272E372B2D33292E\
2F292D2C24272F22272719222517202C20242D21222D1D2536262A3E3C312E3230
3C332E534535555B44445A475B844951784A57494D3F385439333B63543E402C3A97804887B448\
7E867078727486706F836F73807174837271836F73807174837271836F73896C71
836A76836F73836F73836F73896C71836A76836F73836F73836F73836F73836F73836F73836F73\
836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73
836F73836F73836F73836F73836F73836F73836F73836F73
836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73\
836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73
836F73836F73816A73866D7133A5920560562E1F235F1D355B2E40593E48755A45695A58565059\
34344F432C375944443E404154473F4A4F473E4C443C3338533A3D3F3C413A2D35
4C393C463F3B2F2F3B4A3B31443C3E3B3B3A3238391A18213D1C20352232464A33292E2F33282C\
241A2436282A272326231D221F191D261B1D21161D22161C342223402B2A49473B
46663D45523C5D4940635E4F5842474210405A1B415235453F42464731335B524EADAE2789756A\
896774806C78837271836F73816A73866D718778737D7275836F73836F73836F73
836F73836F73836F73836F73836F73836F73836F73816A73866D71836F73836F73836F73836F73\
836F73836F73836F73836F738778737D7275836F73836F73836F73836F73836F73
836F73836F73836F73836F73836F73836F73836F73836F73
836F73836F73836F73836F73836F73816A73866D71836F73836F73836F73836F73836F73836F73\
836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73
836F73836F73807174837271896C712B6B8D104147372E2845242F61383A6B43426E445064525A\
333C5336333C54393450414741333B4C283A4E3040372D3D412A314B2F3A3B373D
403332442C37433D3F3D3D373C2B344B383B3B3B3B273E3D30442C292727381C243B27352F2C2D\
2B2E2E3637292B2D2E36463122382D2A36282C3E2C304F2F3758303C5235525537
5B54435F7B523E554C66454442294C26193450332F523E3B524B4442554990BC32839F51836F73\
836F73836F73836F738778737A7476816D718C6A6F836A76836F73836F73836F73
8778737D7275836F73836F73836F73836F73836F738071748372718778737D7275836F73836F73\
836F73836F73836F73836F73896C71836A76836F73836F73836F73836F73836F73
836F73836F73836F73836F73836F73836F73836F73836F73
836F73836F73836F73836F73836F73807174837271836F73836F73836F73836F73836F73836F73\
836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73
836F73836F73836F73836F73836F73697D7C1B797D205345384135402C2E491B3267263C622A45\
605759233441442E32523338483F45393B3B41313634243536262F3B242C412833
3B2C34403334463535392A37392D354F3F34464340393C3D3B3C39292E33414F332B302C31272D\
414032373F343236343D352E3938393C4E374059394C6C3E3F58424C5743607345
4C564C683D454A2C54553943301C3A3D393D4B593347463D4D373D97AE417DAE4B877873827B75\
7D7275816A738B7671816A738B71757A7476816D71866D718778737D7275836F73
896C71836A76836F73836F73836F73836F73836F73836F73836F73896C71836A76836F73836F73\
836F738778737D7275836F73836F73836F73836F73836F73836F73836F73836F73
836F73836F73836F73836F73836F73836F73836F73836F73
836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73\
836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73
836F73836F738778737D7275836F73836F735F828022686F2C3F423C3B3A3C42384F4736504241\
6D483F3F5560293F3B423033553C3A43414436363A434A3D262F31362D2D372C2D
4136333D37344339372E25324C4236413D3656473E3C3F43484B3F3D5E46363E352F293733312F\
483E303F393A464D3D3E543E45593E4854405A66445861494F58534039445B263B
5220463F1838330C2C44142E473740474F37473B3A574A4476CA4683B93F836A76896C718D7074\
8276797A7476896F6E847578837271836A76807174837271896C71836A76836F73
836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73\
836F73896C71836A76836F73836F73836F73836F73836F73836F73836F73836F73
836F73836F73836F73836F73836F73836F73836F73836F73
836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73\
836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73
836F73836F73866771866875836F73816A73866D71528985207E6D24363C48343653453B534C43\
5C4F44604F4C40635C2A453F5044373928384D3D3F4039373C3F433341352D2B2E
37242A321B2A46282F2F2733503C2E41343C5F4F3B454949698345518E5234805E2F764D418E46\
3E834543774B4D724759884F4C8F544574555E684C48374D461C3E4C28443E2F39
392232342233333633465C334E6138403F40463B4099BE3583AA49836A768778737D7275896C71\
896774836A76836F73896C71836A76816A73866D71836F73877873827B757D7275
836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73\
836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73
836F73836F73836F73836F73836F73836F73836F73836F73
836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73\
836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73
836F73836F73807174837271836F73807174877B707D72755A85821FC07D1B62494336383F1D34\
662F3C7257495F5D533E63603A4E42424E47464C3A46474542433D4C55453C784A
27583F24302F423A2C2C282F4C392E53513F5D64404C524E5D373E89415165546057635F677252\
637D5E58815E536B5B5D434E6428505F2A515727484322473D313F403334301F30
34232E423D3340483659583845394052464874C24489B63C836A76816A738C6A6F836A76816A73\
846871866D71836F73836F73816A73836F73837271836F73896C71896774836A76
816A73866D71836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73\
836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73
836F73836F73836F73836F73836F73836F73836F73836F73
836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73\
836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73
836F73836F73836F73836F73836F73836F738D75707D6D79836F737E727538A78D145351303038\
58433162373B74414E6E66583D6160506A4C527B52456F4F548F524B874F515C50
57845D29BE5E37F14919E65E2FD24C49A74E588C554D715C51865B647F4C67625D67625D70695C\
664A5B571F53752E544A2F52492C434F2D3F493141372939412E3533243144423A
3D5E3A41543846473D4D393A87B4483CDF5983AB488778737B6D75836F73837271836F73807174\
7D6F7286706F836F73836F73807174816D71866D71836F738778737D7275836F73
7D6C7486706F836F73816A73866D718778737D7275836F73836F73836F73836F73836F73836F73\
836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73
836F73836F73836F73836F73836F73836F73836F73836F73
836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73\
836F73836F73836F73836F73836F73836F73836F738778737D7275836F73836F73
836F73836F73836F73836F73836F73836F738D75707D6D79836F73836F73896C713196951DCD63\
1E3E3C4D2A376C3C3B733C496C515D6574596B7D585773656E6F556762645A7064
767A526D566283495D804668724C6879616472706561706A69695E6D63635E4E5E5F3555814554\
53375C4D43565D50443828464A353F392A37442A36433C3D434E3B426A4549713D
464E44453F435C5E4566C54C89B73C816576866D71866771836A76837271836F73836F73836F73\
807174837271816A73866D71836F73807174837271836F73896C71836A76836F73
807174837271836F73807174837271896C71836A76836F73836F73836F73836F73836F73836F73\
836F738778737D7275836F738778737D7275816A73866D71836F73836F73836F73
836F73836F73836F73836F73836F73836F73836F73836F73
836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73\
836F73836F73836F73836F73836F73836F73836F73896C71836A76836F73836F73
836F73836F73836F73836F738778737D72758D75708276797D72758778737D7275836F73778179\
19A38E1D63494F40395C37417D4E476F4955794859734D61745B607467626E6B64
7467626A6769737F62697665696D677469607C66656C5B696D5A656A505F6555634646585C3344\
603953442F4552293F3D2B4451483B2D2F3B504E3850633F4C60465552454F3948
5A4A4C669B4F5FC94F839F51836F737D6C7486706F8071748372718778737D72758778737D7275\
836F73816A73836F73837271836F73836F73836F73836F73836F73836F73836F73
8778737D7275836F73836F73836F73836F73836F73836F738778737D7275836F73836F73836F73\
877873836F73836A76836F73896C718773767A7476837271836F73836F73836F73
836F73836F73836F73836F73836F73836F73836F73836F73
836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73\
836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73
836F73836F73836F73836F73896C71836A76896C71896774836A76896C71836A76816A738C6A6F\
7D787A32A38B35DE5F266754512F3C60224582464C745E59766B5D746762736165
715C65705363855A5F725069724F646F48616E355A6727596623517033546C41534E3D59473E4A\
4124394E2D435457423D50465E6B403A745551854153664C483E4B66524C6AAD55
4DCE5873AC53837E68836F73836F73807174877B707D7275836F73896C71836A76866771866875\
836F73847A747D75738778737D7275836F73836F73816A73866D718778737D7275
896C71836A76836F73836F738778737D7275836F73836F73896C71836A76836F73836F73836F73\
896C71836A76836F73877873827B758778737B6878866D71836F73836F73836F73
836F73836F738778737D7275836F73836F73836F73836F73
836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73\
836F73836F73836F73836F73836F73836F738778737D7275836F73836F73836F73
836F73836F73836F73836F73836F73836F73836F73836F73836F73816A738B76717A7476837271\
8D75707D6D79836F7343918B31D56837E35A3C644F65304B833951753D5B78445D
7F5E616C6B66746A606F65686C6C65657166526463566A5B485D555A544A573E4C665753568558\
296B58568D43598E4B467B5B4F574A58394C79564E718B5C48C86A4FD9587EAB56
7D7573836F73836F738778737D7275836F73896C71836A76836F738778737D7275807174837271\
836F73896C71836A76866771866875836F73836F73807174837271896C71836A76
8778737D7275877873827B75877873827679827B757D7275836F73836F73836F73836F73877873\
7D7275836F73836F738D7570877376836A768475787D7573836F73836F73836F73
836F73836F73896C71836A76836F73836F73836F73836F73
836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73\
836F73836F73836F73836F73836F73816A738C6A6F836A76836F73836F73836F73
836F73836F73836F73836F73836F73836F73836F73836F73836F73807174896F6E836A76836F73\
896C71836A76836F738778737D727587787343918B43C7653F6A57604352755453
683E53813E5A7E52607557637D64647164676C7A6C6696654F976D4D90624A8660668D526A6E5A\
546C6B565650663450744257626C6158A65C68BA5379965E8D7E6A877376816576
866875836F73836F73896C71836A76836F73836F73816A73866D71896C71816576866D71836F73\
836F73816A73866D71807174837271836F73836F73836F73836F73816A73866D71
896C71836A76896C718967748967748967748662748668758778737B6D75866D71836F73896C71\
836A76836F73816A738C6A6F896774836A76896C71816576866D71836F73836F73
836F73836F73836F73836F73836F73836F73836F73836F73
836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73\
836F73836F73836F73836F73836F73807174877B707D7275836F73836F73836F73
836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73\
816A73866D71836F738D75707B687889656F866875836F735289854CB26760AC5D
51A46D5C9F5E6C89616876687F80626D756E6F5865793B627C36637C4A656F5A6572585F705463\
725E6163856B50B2645CBA5B68A561798D6583786C836F738D75708773767A6F7A
877B70827B75827B757D7275836F73836F73836F73807174816D71846871836F73837271836F73\
836F73807174837271816A73866D718778737B6D75866D71836F73807174877B70
7D7275836F73836F73836F73836F73836F73807174837271896C718475787D75738778737D7275\
836F73836F73807174837271836F73836F73836F73847A747D7573836F73836F73
836F73836F73836F73836F738778737D7275836F73836F73
836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73\
836F73836F73836F73836F73836F73836F73896C71816576866D71836F73836F73
836F73836F73836F73836F73836F73836F73836F73836F738778737B6D75866D71836F73836F73\
807174816D71866D71896C71806C78807472837271836F73836F73807174807472
847D72747A76797D707380727F806A79797466817660946E609C68699764709E69609A6F659A6B\
699869798C66807A6E837271877873827B757D7275836F73896C718D70747D6D79
896C71896774896774816576866D718778737D7275836F73847A747A7774837271836F73877873\
7D72758778737D7275847A747D7573866771836A76837271816A73866D71896C71
836A76836F73836F73836F73836F73836F73836F73836F73836F73866771866875896C71877376\
7D7275836F73836F73836F738778737D7275836F73896C71836A76836F73836F73
836F73836F73836F73836F73896C71836A76836F73836F73
836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73\
836F73836F73836F73836F73836F73836F73836F73807174837271836F73836F73
836F73836F73836F73836F73836F73836F73836F73836F73896C71806C78837271836F73836F73\
816A73836F73837271816A738B76717D7275836F73836F73816A73866D71816A73
8C6A6F836A768778737B6D75866D71836F738071748074728074728074728D786E7D6D79836F73\
816A73866D71836F73836F73896C71896774836A768778737D72758D75707D6D79
836F73836F73816A738778737D75738D75708276797D7275896C71836A76836F73836F73896C71\
836A76896C71836A768D75707B6878816A7386706F816A73836F73837271836F73
836F73836F73836F73836F73836F738778737D7275836F73836F73807174837271836F738D7570\
7D6D79836F73836F73816A738C6A6F877376827B757D7275836F73836F73836F73
836F73836F73836F73836F738778737D7275816A73866D71
836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73\
836F73836F73836F73836F73836F73836F73836F73836F738778737D7275836F73
836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73\
8071748372718778737E7D76837271836A76836F73816A73836F73837271847A74
7D7573836F73896C718475787D7573836F738778737D7275836F73836F73866771866875836F73\
807174837271836F73836F73816A73866D71877873836F73836A768D7570827679
7D7275836F73807174866A6E866875896C718662748668758778737D7275836F73836F73836F73\
8778737D7275836F73896C71806C78807472837271807174837271836F73877873
7B6D75866D71836F73836F73836F738D75707D6D79836F738778737D7275836F73816A738C6A6F\
836A76836F73836F73807174837271866771916E737D6D79836F73836F73836F73
836F73836F73836F73836F73896C71836A76847A747D7573
836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73\
836F73836F73836F73836F738778737D7275836F73816A738C6A6F836A76816A73
866D71836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73816A738B7671\
7D7275836F73896C71866274866875836F73836F73807174816D718B7671816A73
866875836F73836F738D75707D6D79836F73896C718773767D7275816A73836F73837271816A73\
866D71836F73836F73836F73807174837271896C71836A76836F73896C718D7074
7D6D79836F73816A73836F73877B707D72758071748372718667718B7175827B757D7275836F73\
8667718B71757D7275836F73836F73836F738778737D7275836F73836F738D7570
7A6F7A837271836F738778737D7275896C718773767D7275896C71877376827B757A7476837271\
8778737D7275836F73836F73816A73836F73896F6E836A76836F73836F73836F73
836F73836F738778737D7275836F73836F73896C71836A76
836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73\
836F73836F73836F73836F73896C71836A76836F738071748372718778737A7476
837271836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73807174896F6E\
836A76836F73836F73807174837271836F73836F73836F737D6C748C6D6D806C78
8372718778737B6D758C6A6F8773767D7275836F73896C71836A76847A747D75738778737A7476\
837271836F73836F73836F73836F73816A73866D718778737D7275836F73896C71
836A76836F73807174837271896C71836A76836F73836F73807174896F6E866274866875836F73\
807174896F6E836A76836F73816A738B7671816A738B71757D7275836F738D7570
7D6D79836F73816A738C6A6F836A76836F73896C71836A76836F73896C71896774836A76836F73\
896C71836A76816A73866D71807174837271836F73836F73836F73836F73836F73
836F73816A7391736F7D6D79836F73836F73836F73836F73
836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73\
836F73836F73836F73836F73836F73836F73836F738778737D7275896C71836A76
836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73816A73866D71836F73\
836F73836F73836F73836F73836F73836F73836F73836F737D6C74846B6F866D71
836F73896C71806C78816D7191736F8276797D7275836F73877873816A73866875896C71836A76\
836F73836F738778737D7275816A73816A7386706F896C718773767B6D75866D71
8778737D72758778737D7275836F738778737D72758778737D7275836F73807174837271836F73\
8778737D7275836F73836F73807174896F6E7D67788C6D6D8773767D7275896C71
836A768778737A7476837271836F738778737D72758778737D7275836F738778737B6D75866D71\
836F73836F738071748372718778737D7275836F738778737D7275836F73836F73
836F73807174896F6E836A76836F73836F73816A73846871
836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73\
836F73836F73836F73836F73836F73836F73836F73896C71836A768778737D7275
836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73807174877B707D7275\
836F73816A73866D71816A73866D71836F73836F73836F73807174807472877B70
7D7275836F73836F73807174896F6E896774836A76816A7391736F7A6F7A837271836F73836F73\
836F73836F73896C71836A76807174807472837271816A738C6A6F8475787D7573
8D75707D6D79896C71836A76816A7391736F7B687891736F7D6D79836F73836F73816A73866D71\
896C71836A76836F73836F73836F73836F73807174877B70816A73846375866D71
836F73896C71816576866D71836F73896C71836A768D75707D6D79836F73896C71806C78837271\
836F73836F738778737D7275896C71836A76836F73896C71836A76836F73836F73
836F73836F73836F73836F73816A73866D71847A747A7774
836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73\
836F73836F73836F73836F73836F73836F73836F73836F73836F73896C71816576
866D71836F73836F73836F73836F73836F73836F73836F73816A738B76717D7275896C71816576\
866D71807174816D71816A7386706F836F73836F73877873827B757D7275896C71
836A76816A73866D71836F73836F73836F73816A73836F73896F6E8773767D7275816A738B7671\
7D7275836F73836F73836F73836F738778737D7275847A747D75738667718B7175
836F73816576866D71816A73836F73896F6E847578837271836A76816A73866D71807174877B70\
7B6D758B76717D7275816A73866D71816A738B7671836F738475787A7774837271
836F73816A73836F73837271836F73836F73836F73896C71836A76836F73836F73836F73836F73\
836F73836F73896C71836A76816A73866D71836F73836F73836F73836F73836F73
836F73836F73836F73836F73807174837271896C71836A76
836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73\
836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73807174
837271836F73836F73836F73836F73836F73836F73836F73807174896F6E836A76836F73847A74\
7D75738778737A74767D6F728B796F827B757D7275866771916E737D6D79836F73
836F73807174837271836F73836F73836F73847A74827E737D7275896C71836A768071748D786E\
7D6D79836F73836F73836F73836F73896C71877376836F73836A76807174896F6E
836A76847A74827E737E7D76827E737D7275896C71836A76836F737D6C7486706F877873836F73\
806C78896F6E8773767E7D76827E737E7D76837271836A76896C71836A76836F73
836F73847A74827E737D7275836F73836F73836F73816A73866D71836F73836F73836F73836F73\
836F738778737D7275836F738071748372718778737D7275836F73836F73836F73
8778737D72758778737D7275836F738778737D7275836F73
836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73\
836F73836F73836F73836F73836F738778737D72758778737D7275836F73816A73
866D71816A73866D71836F73836F73836F73836F738778737D7275836F73836F73836F73896C71\
836A768667718668757D6C748C6D6D866274866875807174896F6E836A76836F73
836F73836F73816A73866D71836F73836F73896C71896774836A768778737D7275836F73896C71\
836A768778737B6D75866D71877873827B75836F73836A76836F73836F73836F73
836F73896C71896774896774896774836A768778737D7275836F73807174837271896C71816576\
866D71836F73896C718967748967748967748773767D72758778737D7275836F73
816A738C6A6F8D70747D6D79836F73836F738778737A7476837271836F73836F73836F73836F73\
836F73896C71816576866D71816A73866D71896C71836A76836F73836F73836F73
896C71836A76896C71836A76836F73896C71836A76836F73
836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73836F73\
836F73836F73836F73836F73836F738D75707D6D79896C718773767D7275807174
837271807174837271836F73836F73836F73836F73896C71836A76836F73836F73836F73816A73\
866D71807174837271807174837271807174877B707D72758778737D7275836F73
836F73836F73807174837271836F73836F73836F73836F738778738778737D6D79836F73836F73\
816A738C6A6F806C78877B70877873836A76836A76836F73836F73836F73836F73
836F73836F73836F73836F73836F738778738778738276797D7275836F73836F73836F73807174\
837271836F73836F73836F73836F73836F738D75708276798778737D6D79836F73
807174837271896C71836A76836F73836F73896C71836A76836F73836F73836F73836F73836F73\
8778737D72757D6C7486706F7D6C7486706F836F738778737D7275836F73877873
7B6D75866D71836F73836F73836F73836F73836F73836F73
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[38]:=",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`003P3oool207m/K`80P6a_0P28LFh208=_L`80NVYd
0P20K6l207eZL080OV]_0P29LV`207QYM@80PFe^0P1PFG@4075PH`80LV1S0P1hI68206iOI`P0LV1S
0P2BLed207UXL@80:SE[0P2>JCd207MRGP80J5YU0P1]G5l206IHH080LUmK0P1^GF0306AGH@80LemK
0P1_GV0206eMH080KeiP0P1UF64206YIG080LUmK0P1^GF0207AQG`80LEmS0P1[G6<206iMH080KEeP
101^GF0206mNH080HEER0P1eH5T406iMH080Mf=O301bHF@206mOI@80M69R0P1YFfD206iMH080LV1P
0P1eHV4206UKI@P0KUeP0P1]GF0606iMH080KeiP0P1^GF0206]LH@80L5iO0P1^GF0206eMH080KeiP
0P1^GF0206eMH080QfaL0P28L6L2071SLP80=SaZ0P1oHTH206YIG080LUmK0P1^GF0206EHH@@0JUUL
0P1`GU/;06eLG`80MV9N0P1`Gf<206aMH`80Lf1P0P1kIV4206mPJ080NFES101eHfL206eOJ080NVER
0P1/GVP206UKI080K5aP0P1QEF0206MHFP80K5YJ0P1ZFE`206QIG080IEML0P2;KE@207MUJ@80C4Y[
0P21IU4208Y_G@80QfmZ0P26L6l207YZM100oooo000>0?ooo`80Ofa_0P20K6l208QaKP80Pfmc0P1j
JW@2081/K`80OFY`0P1nJfl208UbK080N6Ue0P21KFh2061IM0@0LF1S0P1bH6<207QTHP80KUmW201b
H6<2099cG@80NFQa0P0Z=F/208iY?@80Mf9N0P1XFVD206eLG`80IUQP0P1bGe/206iMH0<0I5MQ0P1c
Ge/206mNH080KEeP0P1_GV0206EHH@80JUUL0P1bGe/206iMH080M65O0P1aGf<206]LH`80KUeP0P1]
GF0406iMH080KeiP0P1QEF8207EPF@@0KUeP0P1gHel<079QI080KemU0P1dHV8206UKI@80KUeP0P1b
H60207ERH@80JE]U201^GF0206eMH0H0KUeP0P1_GV0206iMH080JeaQ0P1`GUl206iMH080KEeP0P1_
GV0206iMH080KEeP0P27K5`208Q`I`80L6=b0P0f?6X207mRAP80JUUL0P1bGe/206iMH080IEQQ101Z
FE`2071NF`/0KEaO0P1fHUh2071OH`80K5eS0P1cH60207]VH@80Kf1X0P1iIF<407ESI`80KEmX0P1j
IF8206aNJ080JE]T0P1/G602065EH080IeQJ0P1/FUX206YIG080J5UL0P1UEe`208]]E080MfEY0P1<
BV/2085VD@80RVmM0P27KfX208I`K`80NVYd403oool000h0oooo0P1oK6l2085^K`80Q6a^0P22I742
085WLP80PgA_0P1mMg8207U`L@80Q6Y]0P22L7<207]`L080K7Ag0P1RJFT2075QH`80LV5S0P1eGV82
079MIP@0LV1S0P1aGf<2079OH`80PUIM0P2;GVX2039<MP80OgA30P1eHUh206UKI080K5eO0P1YGV42
06YIG080KU=N0`1YEUl206mIFP80LU]N101^GF0206UPHP80JFAO0P1ZFe`2079LG`80M69O101^Ff84
06iLH080J59O0P1aDed2079KGP80If1S0P1ZFe/207=JGP80KeeP0P1bFUh207=FH@80ME]R0P1bFf<2
075GHP80LeIR0P1gGV8206aJI080LeQP0P1bHF@206UPHP80L5aP0P1cFF0206iIH`80KUeP0P1`HF42
06aNH@80KUeP0P1]GF0206iMH0H0KUiP0P1^GF0206eNH@80KEaO0P1[E5l207=KG`80KUiP0P1^G602
06iMH080NUMK0P2?Ff42081/L080=e5c0P1K@DL208IDE080KV5M0P1^GF0206EHH@@0JUUL0P1]F5/3
06eDG@80LEaN1P1]Gf0207ARGP80KUYR0P1bH68206iMH@80NEaO0P1cFfH207IMHP@0MUYU0P1eHfL2
079PH`80LEeV0P1XFV@206eMH080IV1R0P1WIEh206ING080JUUL0P1/H5d207B1H080Mh=M0P1TCFP2
065>J@80LUeD0P2CJUX208M_JP80PfU_0P20J7<@0?ooo`003P3oool207m/K`80PFi_0P24K6h2089T
L@80PFMb0P23M6l207egLP80NG1a0P24JVd2089`L`80Ng1`0P1/M7L2069YJ@80LF5S0P1bHF<207EN
HP80LUeV101bH6<2075OH`80LUmS0P22EUd208]NJP80<Taf0P1oM4<207ERGP80JE]T0P1/GEl206UN
H@80JUUL0P1^Deh306UFG`80KeUJ0P1bFeh406iMH080JF1R0P1YI5l206YKG080LUaO0P1dHUl406iK
HP@0KUaP0P1XDUl2075CG@80LU]N0P1WH6<206YKF`80LeYN0P1_GF02079JGP80LeIQ0P1eFf82079K
H`80LEMR0P1cEV8207MNHP80K5YT0P1cF602079QI080JF1R0P1`G60207=IH080KUUS0P1^GF02071Q
H@80K5iQ0P1^GF0206eMH080KUeP1P1^GV0206iMH080KEiQ0P1]G5l206]DG`80Le]O0P1^GV0206iL
H080KUeP0P1jEe/208mKH@80P6a`0P0gDG<205]1A`80QUAD0P1^HEd206iMH080IEQQ101ZFE`206eH
F`<0KEAM0P1aG5h606eOH080M69N0P1^FV82079PHP80KUeQ0P1iG5l207=KIP80MUeR101fFVD207ES
I`80LV1S0P1aGFH206QJI080KEeP0P1VH68206MUGP80IUiL0P1ZFE`206aPG@80M85P0P1gPed206A=
J080HDiY0P1bGE@209=ZFP80QfmZ0P23JFl2081XLa00oooo000>0?ooo`80P6U_0P21JFh2085WK`80
P6]`0P1oKFl208AYKP80Q6Ea0P20J7<207m/L080Q6U^0P24Kg<207egLP80JWag0P1PJFX2075OH`@0
LUmS0P1`GF<207=NH`80LEmS0P1_Ff<207ANHP80R6UN0P1JO7X203lgC`80V4A@0P1_Ff8206]NH080
JEIO0P1VDEh206eHF`<0KV5M0P1ZHeh206iPG@80KeiP0P1]GF0206mNH080KEeP0P1VEf4206eCF`80
NeaM0P1^H6@206]OH@80KEeP0P1ZEel206QHH080JEYK0P1^EE/206]=G@80JTiM0P1^D5T2079BG080
LEYO0P1_GV02075LG`80LeiR0P1[GF<206iMH080Le]O0P1^FF<206iLH080Le]N0P1^FF<2075SH@80
KfMR0P1]J6<206aUHP80Kf5Q0P1`IF<206UPHP80KUiQ101^GV0806iMH080K5eQ0P1YHF4206iRG@80
KUeP0P1^GV4206iNH080KUiQ0P1jEe/208I=H@80JGQh0P12X6X204E4BP80RdAC0P1^Deh206YEG`80
KV5M0P1XHUl206IKGP<0JUUL0P1bGe/206YEG`80KU9N0P1cFeh207AQH080KF5T0P1bHf4206eQI080
LV=Q0P1aH6<2079PH`80MFIT0P1bJVD207EVI080KUiX0P1`GV<206]MI080JeeP0P1^GV0206]MH080
JEiQ0P1]J5l2071_G`80O6AM0P26HfP205iTL`80GEmP0P1ZFU/208eXE@80RfMX0P24LW0207]_LA00
oooo000>0?ooo`80P6U_0P21JFh2085WK`80P6]`0P1oKFl208AYKP80Q6Ea0P20J7<207m/L080Q6U^
0P24Kg<207egLP80JWag0P1PJFX2075OH`@0LUmS0P1`GF<207=NH`80LEmS0P1_Ff<207ANHP80R6UN
0P1JO7X203lgC`80V4A@0P1_Ff8206]NH080JEIO0P1VDEh206eHF`<0KV5M0P1ZHeh206iPG@80KeiP
0P1]GF0206mNH080KEeP0P1VEf4206eCF`80NeaM0P1^H6@206]OH@80KEeP0P1ZEel206QHH080JEYK
0P1^EE/206]=G@80JTiM0P1^D5T2079BG080LEYO0P1_GV02075LG`80LeiR0P1[GF<206iMH080Le]O
0P1^FF<206iLH080Le]N0P1^FF<2075SH@80KfMR0P1]J6<206aUHP80Kf5Q0P1`IF<206UPHP80KUiQ
101^GV0806iMH080K5eQ0P1YHF4206iRG@80KUeP0P1^GV4206iNH080KUiQ0P1jEe/208I=H@80JGQh
0P12X6X204E4BP80RdAC0P1^Deh206YEG`80KV5M0P1XHUl206IKGP<0JUUL0P1bGe/206YEG`80KU9N
0P1cFeh207AQH080KF5T0P1bHf4206eQI080LV=Q0P1aH6<2079PH`80MFIT0P1bJVD207EVI080KUiX
0P1`GV<206]MI080JeeP0P1^GV0206]MH080JEiQ0P1]J5l2071_G`80O6AM0P26HfP205iTL`80GEmP
0P1ZFU/208eXE@80RfMX0P24LW0207]_LA00oooo000>0?ooo`80OVm_0P1nKVl207m`K`80PWI_0P1j
KW8208=dK`80OWIa0P1jK74208AcK`80OWIa0P20KFl208AUL@80PFMb0P1/LWL206f3JP80IG5Y0P1Z
GV@207=OHP80KUaR0P1aF64206mJHP80LE]O0P1kE5h208mTH`80>GZ30P1KKTT207YEFP80KU]P0P1Y
Gf42069MG`80JUaJ0`1^Ee/406iCGP80LeYN0P1^GF0206iNH080KEeP0P1UF64206QJG@80MUmI0P1a
FF4206iKHP80KUiQ0P1VFF4206iPG@80I5YO0P1VE5/206UIG080IUeK0P1TF5/206YDF080LUAJ0P1c
FUh206iLH080LEaO0P1^Ff8206iLH080KeeP101^G60206iMH080LF9P0P1fJf4206mTI080LV5T0P1`
HVD2079ZI080KfES0P1]I6H206aUHP80KfMR0P1]J6<206UPHP80KUeP0P1_GV0206iNH@80KUmQ0P1^
GV0206mNH0@0KUiQ101^GF0206iNH@80LUaO0P26EE`208UWK080?8N00P16DD/208MEE080JFEO0P1^
HUd206eOH@80JF5Q0`1[JUl206]TGP80JF5R0P1YIUl206iRG@80M61O0P1^FV8207EOH@80KU]S0P1d
Gf82079QH`80MFQS0P1dIf@207ERIP80LUaV0P1eHfH206YMI@80KeaR0P1[G642079TG`80JEiR0P1k
Nf0206IaI@80LfES0P1kLFH206U?H`80PeUW0P1NGVX206EKG@80SGEG0P1oKFL208EQJ`80QFEa403o
ool000h0oooo0P1nKfl207i^K`80Og1_0P22MVl207Y^LP80PgA_0P1nMW4207Y/L@80Q7=_0P1nMW42
081]K`80Q6Ea0P21Ig8206abM`80KH=Z0P1ULFT206YNI080LemR0P1^G682075HH@80KeYR0P1aFel2
07]DGP80SfAS0P0iNX<205]^B@80NUEJ0P1^Ff0206UOH@80HUeO0P1ZG5X306iGF`@0KU=N0P1cFUh2
06iMH080KUiP0P1]GF0206EHH@80J5YM0P1fGeT2075IH@80KU]R0P1^GV4206IIH@80KV1M0P1TFUl2
06IDF`80JEUL0P1VGE/206AHF`80JUAH0P1bE5X207=JGP80KUaP0P1aG5l206iKHP80KUaP0P1_GF04
06iLH080KUeP0P1aHV0207I[H@80KfAT0P1bHF@2071RI@80LVYT0P1_IF<206eTIP80K6ER0P1_If82
06eXH`80JF1R0P1^GF0206mNH080KUiQ0P1^Gf4206iNH080KeiP101^GV4406iMH080KUiQ0P1bG5l2
08IEG080RFM/0P0lQh0204IAB`80QeED0P1YIEl206iRG@80KEmQ0P1YHF4306]ZG`80JfAN0P1YHF82
06UVG`80KV9M0P1dH5l206iJHP80MEmQ0P1^Ff<207AOHP80LV5S0P1eJ6<207AWI080MF9V0P1bG6H2
07ESIP80JUeU0P1_G68206]LH@80LVAO0P1YGV8207]kH080IW5U0P1cIF<207]aIP80JDmS0P23FFL2
05iNJP80IE]M0P2=MEL207m]I`80QF5[0P25IG4@0?ooo`003P3oool2081[L080PFi`0P1oK6l208IZ
K`80PG1c0P21Kfl208AXL@80O6Ud0P28LVd208=_L`80Og9d0P1nMW8207]_L@80PGA`0P1iL74207=e
L`80HFi^0P1/IF<206mTI080JF1R0P1aHV4206]OH@80LVEQ0P2:M5`2079_L@80B55/0P1jHe@206iP
H080Kf=Q0P1RFV8506YIG080KV5M0P1UG5h206iGF`80LeYN0P1^G60206iMH080JF1R0P1YI5l206iR
G@80KUeP0P1[EUl206iDGP80JUIP0P1aGU`206QPHP80IVIP0P1XIed206QTGP80HemO0P1RFE/206aJ
F@80KUMJ0P1bFUh206QBG`@0KTiM0P1eFEd206iMH0@0KUiP0P1aG5l207IFG`80Me]T0P1^FF<207=F
HP80OV9Q0P1bIFP206]LI@80MF1S0P1`GV8207EOH`80JemV0P1/GV42079SH@80KVAR0P1/Gf8206iN
H@80LF=Q101^I68206]OHP80LF=Q0P1[Gf8206iMH080LU]O0P26EE`208UWK080=UEe0P1aGTP207UG
G080LF9Q101^I68306iMH080KU]R0P1^GF02075RH080KVAR0P1`HV4206iRI080LVEQ0P1]HVD2075S
H@80Lf9S0P1iIV8207ARI`80MF=V0P1aIFL2079PH`80KUmW0P1^IF8206UNHP80NFQO0P1eP6L207Ul
HP80LFe`0P1aMfX207ihI@80F61d0P21MEX205aCJP80JEEO0P2DLU@208=hK080MWI`0P1nKV`@0?oo
o`003P3oool2081[L080PFi`0P1oK6l208IZK`80PG1c0P21Kfl208AXL@80O6Ud0P28LVd208=_L`80
Og9d0P1nMW8207]_L@80PGA`0P1iL74207=eL`80HFi^0P1/IF<206mTI080JF1R0P1aHV4206]OH@80
LVEQ0P2:M5`2079_L@80B55/0P1jHe@206iPH080Kf=Q0P1RFV8506YIG080KV5M0P1UG5h206iGF`80
LeYN0P1^G60206iMH080JF1R0P1YI5l206iRG@80KUeP0P1[EUl206iDGP80JUIP0P1aGU`206QPHP80
IVIP0P1XIed206QTGP80HemO0P1RFE/206aJF@80KUMJ0P1bFUh206QBG`@0KTiM0P1eFEd206iMH0@0
KUiP0P1aG5l207IFG`80Me]T0P1^FF<207=FHP80OV9Q0P1bIFP206]LI@80MF1S0P1`GV8207EOH`80
JemV0P1/GV42079SH@80KVAR0P1/Gf8206iNH@80LF=Q101^I68206]OHP80LF=Q0P1[Gf8206iMH080
LU]O0P26EE`208UWK080=UEe0P1aGTP207UGG080LF9Q101^I68306iMH080KU]R0P1^GF02075RH080
KVAR0P1`HV4206iRI080LVEQ0P1]HVD2075SH@80Lf9S0P1iIV8207ARI`80MF=V0P1aIFL2079PH`80
KUmW0P1^IF8206UNHP80NFQO0P1eP6L207UlHP80LFe`0P1aMfX207ihI@80F61d0P21MEX205aCJP80
JEEO0P2DLU@208=hK080MWI`0P1nKV`@0?ooo`003P3oool207m/K`80PVi_0P1mJG4208=]KP80PfU_
0P21Ig82089/L080PG=a0P1nJVl208MWL080Q6Qa0P22I74208E^LP80Pg=`0P1lKGD2089dL080KgQf
0P1ULVh206]SI@80Kf=U0P1_I64206iRI080Lf9P0P1oF5l208]RJ080FgQi0P1OLEd2079SH@80L6=Q
0P1UGVD206URGP<0IU]N0P1^Ee/206iMH080J69O0P1_HUd206iNH080JUEO0P1^Deh2079JGP80JUEO
0P1[CEd206iEGP80JUYM0P1YF5d207=NG0@0KUeP0P1^GV0206eMH080JV1Q0P1VIV42069LG080J5=K
0P1^D5T206aFG`80I5ML0P1_HU/206YKF`80LeYN0P1_GF0606iMH080Le]O0P1`G6@2071WHP80MVAP
0P1aE6@2079LIP80LV9Q0P1`Gf@207=PH@80LF9U0P1/I6@2079UH@80L65S0P1_HV@206iTHP80KeiQ
0P1dGV8206mKH`80KU]S0P1aGEl206iKH`80LF9Q0P1[Gf42079KG`80QUEL0P1[MgL204aaHP80JE9F
0P1lEU/207AOHP80LF5S0`1]HF@206aPH@80L69Q0P1aHV4207=SH`80L6=T0P1aI6<2079RH`80L5mT
0P1bHV<2079QH`80MUeR0P1hH6D407ESIP80KUmW0P1]F6<2075CH@80Je1Q0P21HU/208UYH@80P6e^
0P1XCf`208EAI@80NDMU0P1fDF/208IaG`80EEE_0P1cKUd208^4F@80Q75[0P1oJg<207a[LA00oooo
000>0?ooo`80Ofa_0P22KVl207eYL@80Pfe^0P23JFl2085WLP80PVa`0P21Lg4207iZK`80QfM`0P24
J742089TL@80QFib0P23Lg0207a]M@80PWA`0P1_N7H206EbKP80Jf=U0P1_HfD206mTH@80KV9T0P1c
HV0207mHG`80Rf9X0P1KN7T205maG@80LV=Q0P1`Hf4206ENI@80JF9N0`1VFeh206iGF`80KUeP0P1X
HUl206mRG@80KUiP0P1ZEEl206iCGP80LUYN0P1ZEEl206]=G@80KUEN0P1ZFUd206UHG@80LeiL101^
GF0206iNH080KEeP0P1ZH64206IVH@80HUaL0P1XDe/206i@F@80K5IO0P1TEe`206mRF`80JU]K0P1c
FUh206mMH0H0KUeP0P1cFel2071LI080L6MR0P1fI602075DI080LUaV0P1bHV42071OI080Lf1Q0P1a
HVD206aTI080LVEQ0P1`HF<206mRI080KVAR0P1_GV4207ANHP80Ke]S0P1^Ff<2075MG`80KU]S0P1a
HV4206]OH@80LU]O0P26EE`206]gM`80C75R0P1YDUH207aFF`80M5mR0P1aHF<306eQI080K61Q0P1`
HV42075RH@80Lf=S0P1`Hf@2075TH`80LV9S0P1`Gf@2079RH`80LV5S0P1fGF8207QPI@@0MF=V0P1^
GfL206eHH`80LE=Q0P1[D642085RF`80RFUQ0P20KFh206Q?K080QE5U0P1iAfD207IAJ`80QW5O0P1E
EFl207=^G@80RhAI0P24LF/207m[L`80O6]a403oool000h0oooo0P1oK6l208EcK`80OGIc0P20Mg02
07Y[LP80QG=_0P1kJg4208MZKP80OVad0P23MFl207]ZLP80Pg9a0P23MFl207mWL`80QFib0P23LW42
081aM080M7Yf0P1XPW8206E_J@80L6MV0P1aJVD2071YI@80LVYU0P1nHf0208M/JP80H6Ic0P1[H682
07AOHP80KF=U0P1[IF8306IQHP80JF9N0P1ZFE`206eDGP80KU=M0P1^DEd206YEG`80IU=L0P1ZB5P2
06i;F`80IU=K0P1ZE5P206iEF`80IU9L0P1fGET206iNH080L6=Q0P1^I64206eTHP80KVAQ0P1_If82
069SI@80IVMO0P1OFe`206iLF@80IEYN0P1_FeP206I@G`80LEAI0P1_DUd206e?G@80MEUN0P1^G602
06mMH080L5aP0P1eGV02071HH`80KUUS0P1bFel2075HHP80LEQQ0P1bFF42079HH@80LEMR0P1fGF42
075NI080Ke]R0P1aFF8206mKH`80LE]P0P1_FV8406mMH080KUeQ0P1`FEl2071JHP80KUeP0P1aFEl2
08]JF`80LGAe0P1GRVX2065/G@80Le]O0P1aF643075IH@80KUYR0P1dH602071NHP80MF5R0P1bHF@2
075NI080M61S0P1`Gf@207MWH`80KF9V101eIV@207ESIP80KEEU0P1bDV<206=5H080JD1I0P1dDUX2
08UhF080MVQV0P2:JFP205YDM080N5mM0P1]GfH2075RG`80OEMN0P1QBF/208YgF080QgUS0P20Jg02
08AbL080NFic403oool000h0oooo0P1oK6l208EcK`80OGIc0P20Mg0207Y[LP80QG=_0P1kJg4208MZ
KP80OVad0P23MFl207]ZLP80Pg9a0P23MFl207mWL`80QFib0P23LW42081aM080M7Yf0P1XPW8206E_
J@80L6MV0P1aJVD2071YI@80LVYU0P1nHf0208M/JP80H6Ic0P1[H68207AOHP80KF=U0P1[IF8306IQ
HP80JF9N0P1ZFE`206eDGP80KU=M0P1^DEd206YEG`80IU=L0P1ZB5P206i;F`80IU=K0P1ZE5P206iE
F`80IU9L0P1fGET206iNH080L6=Q0P1^I64206eTHP80KVAQ0P1_If82069SI@80IVMO0P1OFe`206iL
F@80IEYN0P1_FeP206I@G`80LEAI0P1_DUd206e?G@80MEUN0P1^G60206mMH080L5aP0P1eGV02071H
H`80KUUS0P1bFel2075HHP80LEQQ0P1bFF42079HH@80LEMR0P1fGF42075NI080Ke]R0P1aFF8206mK
H`80LE]P0P1_FV8406mMH080KUeQ0P1`FEl2071JHP80KUeP0P1aFEl208]JF`80LGAe0P1GRVX2065/
G@80Le]O0P1aF643075IH@80KUYR0P1dH602071NHP80MF5R0P1bHF@2075NI080M61S0P1`Gf@207MW
H`80KF9V101eIV@207ESIP80KEEU0P1bDV<206=5H080JD1I0P1dDUX208UhF080MVQV0P2:JFP205YD
M080N5mM0P1]GfH2075RG`80OEMN0P1QBF/208YgF080QgUS0P20Jg0208AbL080NFic403oool000h0
oooo0P1oK6l208EZKP80QFQa0P24J74207i/M080QW=]0P1jKGD208=eK`80O6ab0P24J6l207eVL`80
QFY/0P24IG4208=_L`80PFm_0P26KG4408=_L`80O6ad0P1`M7H206acJ`80M6iX0P1dKFT207E^J080
LfYX0P21Hf<207]_L@80H6i]0P1A<eT209A>EP80KE]S0`1]G68206QFG`80JUIO0P1ZFE`206UJG@80
J5UL0P1SC5X206I:F@80IUII0P1VFUL406IFF@80JEEH0P1VE5/2079IE`80LeYN0P1aG5l207=NH@@0
LEmS0P1dHV8206ULI@80KUiP0P1PEf8206UEF@80JE5K0P1ZDEX206MCG080K5]I0P1VE5/206MBF`80
KU5G0P1^C5`2079AG080KU9N0P1aDEd207=GH080JUEO0P1^DUh206mDGP80KU=N0P1cFEh206YDH080
LeYN0P1aFEl206i@H080LUEP0P1`Ff0206mKH080JUAP201^DUh206eCGP80KUAM0P1cFUh206UEH080
ME1J0P2>E5`2089SK@80G5Y_0P1^G5l206mLH0<0KeeP0P1^GV42075LG`80L5YQ0P1fGf0207APH`80
L5mT0P1cGf8207EWI080MFQS0P1]GfP207ENHP80ME]T0P1`Df@206Y>I080GCYI0P1X@ET205m>EP80
N6AA0P25I5L2071;J@80LcIL0P1f?VH207EIG@80K4mO0P1mH60206ULH`80I5ES0P2CLU@208M_JP80
OFUa0P26JFd207mXLa00oooo000>0?ooo`80Ofa_0P25JVh208EXL@80Q6Qa0P1nK7@208IcK@80NVee
0P23MFl207a/LP80Q6Q_0P1mIW<208EZK080Q6Ea0P23Kg<2085_K`80QVea1023Kg<207a/M080L7Af
0P1/Lf/207A^J080M6eY0P1eKVP207=ZJ080PF=S0P1kKg42061^K@80DC=I0P2DCUH206eKH`<0KEaR
0P1XEUl206YFG`80JUUL0P1YFUd206QIG080HdaJ0P1VBUT206IFF@80IUYG101VEUT206UEF080IUAK
0P1bFEL207=JGP80LEaO0P1cGV44075OH`80M69R0P1YG6D206iNH080H5MR0P1YEET206UAF`80JU5J
0P1WDe`206aKF@80IUAK0P1WDU/206iAE`80KTaL0P1bDE`206iBGP80LE5M0P1cEf0206YEG`80KU9N
0P1_E5h206iCGP80LeUN0P1ZE60207=JGP80LEUO0P1^D602079EH080L5]P0P1_Ff0206YDH0P0KU9N
0P1]Deh206iDG@80LeYN0P1YEF0207E@FP80SUAL0P22Hfd205aJK`80KUaO0P1_G60306mMH080KUiQ
0P1aG5l2071JH@80MUmP0P1dH6<2071OI080LemR0P1eIf@207EXH`80KEmX0P1eGV8207EKI080L5=T
0P1ZCV@205djF@80J45I0P1OCUH207QTD@80QFAG0P1`BfT207<fG080MSiV0P1eFEd206a?G`80OF1P
0P1YG6<206AEH`80Tg9D0P27KfX207eYL@80QVU]0P1oJ7<@0?ooo`003P3oool207m/K`80Q7A_0P1l
KG4208EaL080P7Ab0P23LW4207aYM080QFQ_0P20JW<207m_L080P7Ea0P1lLW4207i]L080PfM^0P26
KW82085]L@80QVea0P23Kg<207aYM080Pg9a0P1cLg@207^0K@80Lge_0P1fO6h207N2KP80M8E_0P1l
NV/2075fMP80AIQl0P1HLe8207ECH0<0L5aP0P1XGV8206IKGP@0JUUL0P1VE5`206AKGP80GE]I0P1[
GeH206INF`80If1K0P1YIe`206EYGP80HV=M0P1UEeX2079FF@80LU]N0P1dH5l4075OH`80LeiR0P1_
HVD206aUHP80I69T0P1PFed206UOF`80JFML0P1PGU`206aMFP80IUeN0P1UGe`206IOF`80HeQJ0P1Z
E5P206E:F@80JTQH0P1]AEH206HoF@80KDIG0P1ZAeL206U7F080KTEF0P1V?eT20714E@80KD9I0P1Z
AEX206e7E`80KT=H0P1^@UT206U5FP@0JDQH0P1aE5T206MDG080K5MK0P1ZF5`206iFFP80Ie1N0P1Y
DEX207Q@E`80MSQJ0P1nC6L206aVHP80GDQM0`1O;5<207djE080MTiK0P1^DUh207MIG@80LeQQ0P1a
Ef8207ENHP80MUiQ0P1fFVD207ERI`80KV9U0P1]F6<205@aFP80K39C0P1RBeX2065MD@80GUIF0P1]
Ce02085BF080K5ET0P1MGF<206UOE`80KUIJ0P1fKf4206eYGP80IU1U0P1dJV0208AiFP80QVeZ0P1o
KW4207e/K`80P6U_403oool000h0oooo0P1oK6l208AdK`80O6ea0P25LG02081dLP80Pg9a0P1lJG@2
08EXK`80P6Yc0P1oKg02081eL@80O79a0P1nKG0208=WKP80QVib0P21KG4208I]L@80Pfmc0P1lJG@2
08=bL@80Lg=d0P1kP6d207=mK`80MWa^0P1gPVh207B5K`80O7Y[0P1aMWH204FHO080F7=B0P1eDf03
071LH080J5iR0P1VFeh406YIG080IUAL0P1TFeh205eKF@80JemF0P1VGU/206MPF`80JFML0P1UJEh2
069SG@80IEMJ0P1bEUT2079KGP80M61O101aGf<207=NHP80Kf9U0P1/IF8206ARI080H5]M0P1YGe/2
06UWG080H5iL0P1/GEX206IMGP80IEmL0P1VGe/206=HFP80JUAH0P1UBUT206Y8F080KDEF0P1V?eT2
06e6E`80JTMG0P1YAeP206i5EP80ISmI0P1`A5D206e2F@80JTEJ0P1]AeL206i3F080KT9I0P1YAEX4
06U8F080LEAI0P1WE5`206aGF`80JUQL0P1^EUX206M@GP80JE5J0P1hD5L207HhFP80OTaW0P1/IV82
05e8G@<0GbaC0P1m>U@207I>F`80KU9N0P1gFEd207=HH@80LEMR0P1eGV8207INH@80MUYU0P1eHVL2
06iRI@80KEQS0P1D<EX206`bD`80HT]J0P1QGE4205iFEP80KDm@0P21DUP206aEI080GEeS0P1YGeL2
06iFFP80MVmQ0P1]JEh206I@I@80M6YP0P24NEX208I]JP80Ofia0P1mK6l2081YKa00oooo000>0?oo
o`80OWIa0P21Kfl2085`L`80P6e_0P28KG4208=_L`80OW9e0P1lLG42085^L080OVU`0P26J6h2085W
LP80OfY`0P1nKG0208QbK@80O6Ud0P23IVl208U/L080NVYd0P28LFh207a]M@80QW9^0P1mK7@207mZ
L080R71_1021JW<2081[L080Pg9a0P1KOgd205EUHP<0GcYH0P29G5T205mLH`80HdeK0P1aEEX206IK
GP80J5aJ0P1ODed206UBEP80IdYI0P1_CeP2075CFP80KeAM0P1ZEel2069EGP80KUUH0P1cGU`2075K
G`80MV5Q0P1_HF<2079SH`80LEmS0P1^FF<206iKHP80He]R0P1ZGE/206iHG080J5QP0P1^He`206ML
GP80KF5N0P1YI5l206EVH080HV=M0P1TJUh205iYG080HFMK0P1MIe/205mRE`80I6=I0P1OH5T2065N
F080GV1I0P1TIUL205mPF@80HUiH0P1UIET2061TFP80HfIJ0P1QIEX2069UFP80IFeK0P1XK5T205mH
GP80L6=J101XI5h2069NG`80JVIL0P1UH5`2069NG`80LUiD0P1fF602061WJ@<0D8=S0P1JN5<203HH
?`80W3Q80P1ZBEP207I>F`@0LUQN0P1cEV0206A0GP80GQm@0P1U4d`206DEBP80Fb]C0P1YFTX206UW
D@80I6AI0P1JEUT206UOE`80KUiE0P1^E5d2071SH080I6AP0P1NCU/208iRE080KV5Y0P1GBf<208iZ
E@80NfET0P2;JfP2089^K`80P7Ab0P1iL74@0?ooo`003P3oool207ifL@80PFm_0P21L7<2081]K`80
R6ea0P23Kg<207ibM@80O75a0P21KW0207iYL080QVQ^0P21Ig8207mZL080OVe`0P28LVd207aYM080
PfI_0P29K70207YZM080R75^0P1lKGD208IbKP80OFad0P1oJW0208Q`K`@0PFYc0P20Jg0208=bL@80
Fgmm0P1EIF8305ljF080REaI0P1OG6<206==F`80LEEJ0P1VFeh206QLFP80Ge=M0P1YDUH206M:F@80
KdmH0P1aDeX206mDG@80JUMO0P1REEh206iIF080LeiL0P1aFel207IQH@80Kf5S0P1bHf<2075OH`80
KUUS0P1^Ff8206=KHP80JUeK0P1^F5`206QHH080KV=L0P1WG5h206eQGP80JFAO0P1UIV02069SG@80
I6YN0P1NJE`2065WF`80GFMK0P1OHUL206ASF@80Gf1I0P1QGUP205iPF@80I6IG0P1OH5T2069NF080
IFEI0P1PI5X206=VFP80HFEJ0P1RIEX206E]F`80J6aI0P1OF5h2071SFP@0J6AN0P1RGUl206YVG080
IF1L0P1RGUl2079NE080MUQP0P1PIfT30523H`80FWQC0P0f63l209`hB080JTUH0P1fCU/4079HGP80
LeIP0P1T@5h205hOD080IA=<0P1U5DX205/[D`80JEY:0P1YIe4206ATF@80FUII0P1YGeL206iNE@80
KUAM0P1`Hf0206ATH080GTiK0P2>HU@206iQJ@80Ed]S0P2>JUD207]UI080Rf]X0P22KVl2081dLP80
NG1a403oool000h0oooo0P24HW02089VLP80R71_0P1kJW@208I/KP80PVAa0P25I702089YLP80PFea
0P20M78207Y]L080PVe_0P21MG0207mfL@80PFi`0P1oJg<207i`L@80QW=]0P1lKGD208IbKP80OFad
0P26L6l207aYM080PFea0P24KFh207mWL`80QG5`0P1kKG8208I/KP80Of]c0P1@D7D304a6G@80O4e7
0P1W>ed206I;FP80L5]E0P1ZF5`206UHG080I5aN0P1THE/205eIF`80J5UF0P1/FUT206aKG080JUYM
0P1REEh206aIF@80LemJ0P1^GV02079JGP80LEMR0P1eGF42075NI080KV5T0P1^I68206MPH`80IeaN
0P1ZFUd406iPG@80JUmQ0P1^H5d406iMH080JUmQ0P1ZFUd206QBG`80L5mL0P1XHel206IVH080J6MM
0P1RGUl206IMF`80J5mK0P1YGe/206UTGP80IVQN0P1WH5`206UKG@80JU]L0P1YFEd406iQG@80KUeP
0P1VHF<206iTF`80JUMO0P1aFel206IIH@80LEmL0P1YGf8206UTG`80JF=O0P1[F5`207IIGP<0LEUQ
0P1/HF@202j6MP80JZ/j0P1?EEl205/gCP80JBY=0P1e=E8205`WD080Eb1=0P1E>4h204@oA@80CTE2
0P1MEd@2065>A`80N5MA0P1SCEX205m9FP80QX1C0P1EHf<206YHF`80M5UJ0P1O?ed207ISGP80NgaF
0P1TD6H206i]J@80KVQG0P2;KF@207e^J080Q6I]0P24IFh208A^LQ00oooo000>0?ooo`80Q69`0P22
IW8208Q`K`80NfYd0P26K6h2089TL@80QFA`0P22JG82085]L@80P7Ab0P1jKG02089]K`80PGE`0P1o
MW42085^L080Of]c0P1nL74208IcK@80O6ee0P26LVh207e/M080QW1_0P1lJG@2085]L@80Q6e^0P1o
Ig<208EaL080Nfeb0P26K6h207m[L`80D51e0`1<AUd207a=A`80Ic]M0P1VBeX2071KE@80JUQL0P1Y
F5`206ALGP80I65K0P1MFE/206QIEP80K5YI0P1/Fe`206YJG@80HUEN0P1/FET207=OFP80KUiP0P1b
FUh2075GHP80MEeQ0P1aGV@206iQI080KVAR0P1WH6<206MLGP80JUYM101^H5d206YOH@80KV1M101^
GF0206YOH@80JUYM0P1XDUl2071OG080J6=O0P1VIV0206QWG@80HUiO0P1VGE/206QOF`80JEmK0P1Y
I5h206IXGP80If1L0P1YFed206YKG080JEUM101^HEd206iMH080IV5S0P1^I5/206YGG`80LE]O0P1V
FF42075OG080JEmR0P1YI5l206USG`80JeQL0P1fFEh3075IH@80K65T0P0^QWH206Z[>P80CeEO0P1K
=dh206TZC@80MCEB0P1L9e0205LPC@80ECQ>0P14?dD204i5@P80GEM40P1QCTL207QGD@80HdeJ0P1O
BEX208J0D`80EF=S0P1ZF5/207AIFP80GcmM0P1fHeh207]lEP80I51V0P1^KFT206iXE`80RfeT0P1m
KVP208AVK@80Q6E^0P24KW8@0?ooo`003P3oool207ehL@80NW1`0P25JVh208=_L`80O6ia0P22Lg42
07ihL@80Nfaa0P23JVl208AYK`80PG1c0P1mLG0208I`K`80OfMc0P25KW8207a/LP80PVa`0P24Jfl2
08=_L`80OfY`0P25KW8208=bL@80OW9e0P20MW4207a/LP80OfY`0P23Ifh2081ULP80Pfe^0P1nJG02
05IFMP<0EfaU0P1;BE0206Y:D@80HU1C0P1M>Dl207i>E080JUYL0P1VEE`206aGF`80GU1M0P1/FeL2
06ULFP80Ie=K0P1_F5/206AIGP80JE]J0P1cGeX206iMH080KUaP0P1_GV02075LG`80LeiQ0P1^FV82
07ANH@80JUaS0P1ZGf4206MLGP80KUQL0P1aFel:06iMH080JUmQ0P1WI60206QHF`80LE=M0P1^EEh2
075KG`80JEmR0P1XI5l206EKG@80K5UL0P1]Ee/206a@G@80KEEN0P1^H5d206YRG`80HeQN0P1dGUX6
06iMH0@0JUMO0P1aGU`206IGH@80LUiL0P1YE5l207=JGP80KUaP0P1YGf8206iQG@<0JUEP0P1aDU`2
06m@G`80OEYM0P1OIV`204n3H`80B7]H0P0g:T4204`N@080ESe20P1=?D0204hoAP80EE140P1IBdD2
05U3B`80IC]70P1/@U@206EGEP80Tfm;0P1==VL20714E080NEYH0P1@Bf0208=QC@80OeeO0P1ND6X2
095kEP80IWU`0P22OEl207]]L080Og1]0P1nKVl208QbKA00oooo000>0?ooo`80OGQa0P1jL70208EZ
KP80Pfmc0P1lKW42089cL@80OWQa0P1kK74208=ZK`80Q6U_0P21L7<207eaL080QW1_0P1oIg<208E^
LP80O6ab0P22K70208A[K`80Pfmc0P1oJW0208E^LP80Pg9a0P1nLWD2081fL@80O6ab0P1oJW0208=W
KP80P6Eb0P23KFh207iYL080EUIf0`1GK6D204]9D080JTYA0P1RD5<205diC`80OTiD0P1ZFU`206IE
G080K5MK0P1ND5d206aKE`80JEaJ0P1WDe/206mHF`80I5UN0P1YFeX207=OFP80KUeP0P1^G60206mN
H080LEaO0P1cGV4206iJHP80M5iQ0P1ZG6<206YOH@80IeaN0P1^F5`2075KG`X0KUeP0P1ZGf4206MT
H080J5QK0P1aDed206iEGP80LE]O0P1YGf8206QTG`80IE]M0P1/FE`206eGF`80K51M0P1]EEh206iP
G@80JV9O0P1SF5h207ANFPH0KUeP101ZEel2075NG080IUMQ0P1bGU`206UDG`80LeYN0P1^G60206UO
HP80KV5M0`1ZEF02075BG080Ke1O0P1mFUd205mVK080Ch=S0P18NeP203LZ@@80C1i00P1F?D8204dm
@080CSm60P1ED4@205U;A@80FD=;0P1U>dL206a2E080IEMF0P2CKd/204dfI`80L4AD0P1iFUP2051;
H080Pf5=0P1oGEl205i@JP80TG]F0P1VNG02089mG`80Nfe`0P1oL6d207i^K`80R79]403oool000h0
oooo0P24IG4208=_L`80OgIa0P1oK70207mWL`80R75^0P20J7<2085`L`80OgM`0P1oMW4207m/L080
QFib0P23LW4207a]M@80Pf]^0P23Kg<2081fL@80P7Ab0P23LW4207][M080QFa^0P26KG4208=_L`80
PFYc0P1nJ7<207m/K`80Ofm`0P1lKg02085/KP80OV]a0P1LG7D306UOH@80B5=U0P1DB4X206];D080
@S=>0P1E7cT208`hB`80KEIK0P1VEeX2069GG@80JeiG0P1VEE/206QIG080JEQI0P1WDU`206aHF`80
LemJ1P1^GF0206iLH080M61O0P1ZG6<2075KG`80KUYR0P1^GF0206YOH@80JV9O0P1^H5d406iMH080
KUiP0P1]GF0606iMH080I5YR0P1ZGE/206YJG@80LEiL0P1ZEel206iEGP80K5iP0P1UFed206QEG080
JU]L0P1ZGE/206iHG080KE=N0P1XEV02079QFP80KUiP0P1]GF0206iMH080I5AP0P1`Ge`206iPG@80
IUUQ0P1^FE/206UGH080LF1K0P1^GF0206YEG`80KU=N0`1ZEEl206UHG080HdaJ0P1[?E@206``E@80
Fa]=0P1E4DL204L]D@80@T/m0P1;@CX204/k@P80F4i30P1BB4D205M6B@80ETQ:0P1QGDh2061NCP80
IE=C0P24F50204a4J@80I5Q?0P1eFE8205M=H080PW5?0P1]G60206]OIP80SGEF0P1nJfl2085cK080
NFM_0P28LVd207ifL@80PFm_403oool000h0oooo0P24IG4208=_L`80OgIa0P1oK70207mWL`80R75^
0P20J7<2085`L`80OgM`0P1oMW4207m/L080QFib0P23LW4207a]M@80Pf]^0P23Kg<2081fL@80P7Ab
0P23LW4207][M080QFa^0P26KG4208=_L`80PFYc0P1nJ7<207m/K`80Ofm`0P1lKg02085/KP80OV]a
0P1LG7D306UOH@80B5=U0P1DB4X206];D080@S=>0P1E7cT208`hB`80KEIK0P1VEeX2069GG@80JeiG
0P1VEE/206QIG080JEQI0P1WDU`206aHF`80LemJ1P1^GF0206iLH080M61O0P1ZG6<2075KG`80KUYR
0P1^GF0206YOH@80JV9O0P1^H5d406iMH080KUiP0P1]GF0606iMH080I5YR0P1ZGE/206YJG@80LEiL
0P1ZEel206iEGP80K5iP0P1UFed206QEG080JU]L0P1ZGE/206iHG080KE=N0P1XEV02079QFP80KUiP
0P1]GF0206iMH080I5AP0P1`Ge`206iPG@80IUUQ0P1^FE/206UGH080LF1K0P1^GF0206YEG`80KU=N
0`1ZEEl206UHG080HdaJ0P1[?E@206``E@80Fa]=0P1E4DL204L]D@80@T/m0P1;@CX204/k@P80F4i3
0P1BB4D205M6B@80ETQ:0P1QGDh2061NCP80IE=C0P24F50204a4J@80I5Q?0P1eFE8205M=H080PW5?
0P1]G60206]OIP80SGEF0P1nJfl2085cK080NFM_0P28LVd207ifL@80PFm_403oool000h0oooo0P1n
MW42085_K`80PfIa0P21JW<207i^L080R75^0P1kJW@208QaKP80OVIc0P29K70207YZM080R75^0P20
J7<208A^LP80Nfeb0P28LFh408=_L`80OfMc0P21JW8208=cL080Pg9a0P1oIg<208E^LP80Nfib0P1n
JW02089ZKP80Pg9a0P1kKg4207m/L080IVIe0`1^O6P205AiK080>4QI0P1Q@DH2044dCP80>cHo0P15
72/209hm@P80HdiJ0P1]FET2069?F@80Id]I0P1]DeL206YIG080IE]L0P1YG5X207=OF`P0KUeP0P1a
G5l206eJHPP0KUeP0P1ZEel606iEGP80LU]N0P1ZEV02075KG`@0KUeP0P1WFF4406YJG@80KUQL0P1Z
Eel206UHG@80KUEK0P1YE5l206ULG@80JUeK101ZFUd206QHG@80Je]L0P1^FE/2079KGP80JEAO0P1_
E5d206QHH080LF5J0P1^GF0206MIH@80JEQM0P1/FE`206iHG080KUEN0P1UD5l206eFF`<0HdaJ0P1X
B5P205XoE`80F3aA0P19:DH204DW@`80BSm10P1BDCl204]?AP80C5=70P16BT@204ll?`80G4A80P1E
BTP205iGC080IEa<0P1QDeD206UPEP80IE5D0P1F?E/206UAD080J4iB0P1]HE`207ATE080KEIT0P1g
Ieh208]kG`80O71]0P23K6h207Y^L`80QG5Z0P24J74207iVLa00oooo000>0?ooo`80OWIa0P21Kfl2
08=VL@80PFYc0P1nKW0208QaKP80NfYd0P28LFh207iVL`80RFa`0P1jJW@208QaKP80P6Qc0P24KW82
07]]LP80R75^1023Kg<207mWL`80PFYb0P23Lg0208=bL@80OfMc0P25KW8207]^LP80OVY`0P22JVh2
08=bL@80Nfma0P1oK70206IVM@<0KWaX0P1DNF`203Q8F@80HD560P11=4h203/f?`80AA`[0P2N?D82
06=>FP80KEUI0P1RCeT206M;F@80KE=G0P1ZFE`206EKG080JEaJ0P1cGe/806iMH080LEaO0P1]FV88
06iMH080JUMO1P1^EEh2079KGP80JUIP0P1aFel406iMH080IeUQ101ZFUd206iHG080JUMO0P1YF5d2
06iEF`80JEAO0P1YG5d206YMF`@0JUYM0P1XF5d206]KG080KUUK0P1bFeh206UDG`80KeAM0P1XF602
075QFP80KUeP0P1WFF4206UHG@80K5UL0P1^F5`206iEGP80IE1O0P1]EU/306=<FP80J4QH0P1J?eL2
05PlD@80BBU60P159d<204Xo@@80DU4o0P1;CdH204aCA`80ATY40P1??3l205a4B080EDY80P1NEd`2
06ELC080HE=E0P1YH5H206EAE080ESeK0P1YDE0206Q>DP80KF5L0P1dI5@206eFI080MfMN0P2;Nel2
07a`K@80Pfa^0P1jKW<208EaJP80Q6Qa0P1nIW<@0?ooo`003P3oool208AUL@80PVUb0P21Lg4207e`
L@80OFUa0P29L6d207ibM@80PgA_0P1jJgD208QbK@80O6ee0P23JVh208A_L`80Ofa`0P23Kg<208=d
K`80P6Qc0P24IG42085ZL`80Ofa_0P28L6l207iVL`80Q6ib0P21Kfl207iYL`80PGA`0P1lLW4208A]
KP80OFIc0P21K6l206YKLP<0RG5U0P1OEFl203/hHP80C3Q40P19=dH203Ta?@80;RPd0P0k4Ad209P[
@P80K4aB0P1SC5X206UPE`80I5aH0P1/FUT206IDF`80K5MJ0P1_EeX2079JGPH0KUeP0P1[EUl2075J
G`P0KUeP0P1ZGf4206YRG`80IeaN0P1^H5d206YJG@80JUMO0P1^F5`2075KG`80KUeP0P1ZGf4206YR
G`80I5MN0P1ZDe/206eHG080JE]M101YG5d206QGG080KEUL0P1YF5d206UDG080JUIL0P1[F5/206UE
G080M5eK0P1UFF4206iRG@80IeaN0P1]EU/207=JGP80JUmQ0P1UGEl206YKG080JEQM0P1WDU`206IB
G080IDeG0`1RBeX205Y4D`80FTEC0P17=TX203d/@P80CdPo0P1?Dd0204Xo@@80F4950P1LDTT204Q9
C080B4E70P1GB442061FB`80EDQ:0P1/CDh205]4D`80KdM?0P1PAEP206ARF080HF]D0P1QI5T207el
E@80EdiQ0P1jEU/208IlG@80PGMT0P21KG4207]XK`80PfU^0P20JFl208IaK`80NW1c403oool000h0
oooo0P24IG42089YLP80PG=a0P1mL74207eYL@80RG1]0P1nLWD208=dK`80NV]e0P28LVd207a]M@80
PfY^0P24Kg<207m/L080Pfmc0P23M6l2081XL`80Q6Ea0P21JW<207m/K`80R71_0P1nIW<208A^LP80
PFm_0P1nJG<2085dL080O79a0P24KFh207eVL`80PFa_0P1ZFg8308UaI@80GeE_0P0k>68204`hA080
BCM60P0i<Cd202hX=080>a4M0P2H:d8206a<DP80HdaJ0P1YH5L206ALF080K5YI0P1VE5/206aGFP80
KeMJ0P1bFUh606iMH080JeIO0P1aFUl806iMH080JUmQ0P1ZHUl206MLGP80KV1M0P1ZFUd206YGG`80
KUQL0P1aFel206iMH080JUmQ0P1ZHUl206AGGP80JU=K0P1]F5`206UKG@@0JEaM0P1XEe`206eIG080
JEQM0P1YE5`206YFG080JeQK0P1YEE`207AMF`80IEUQ0P1^HUd206MLGP80KEIK0P1cFUh206YOH@80
IEeO0P1ZFe`206UHG@80Ie9L0P1VDU`206E=E`<0HT]J0P1JA5<205Y5D`80AcI:0P0m;48204m8?`80
Ce=00P1:?d4205Q2A@80G5990P18BD`204Q5A`80EdQ10P1PET/205E8BP80K4e>0P1KA5<206m7C`80
H4EH0P1THUP2065[E080HFAI0P1mO5D205M>H@80NUIK0P26O5d2085gI080PFea0P1kJ6l208=YKP80
P6U_0P26LFl207Y`La00oooo000>0?ooo`80Ofe`0P21Jfl208AXK`80PFMb0P1nJg4208QbK@80OVIc
0P26IG0207iVL`80RG1]0P20LG@207ieLP80P6e_0P23Kg<2081]K`80Q6Ia0P23Kg<207Y^LP80QG=_
0P1lL78208=ZKP80PW1c0P1oKFl2085WLP80Pg9a0P20K70208A^LP80OFmb0P1mKG8207i[K`80Jf=d
0`25K68205eBL`80BV9Y0P0dA4d204i5@P80=cQ10P0/:S<2024O9`80?ADI0P2M=cd2069DE@80KEID
0P1SC5X2071HE`80IEYM0P1VEUT2079PF`80KV5M1P1^GF0206YOH@80JUYM0P1^EEh2075KG`80KUeP
0P1ZEel406iEGP80JUMO0P1[De/206aCGP80K5UL101^H5d206iMH080JUMO0P1^EEh206MHH@80IUaL
0P1YEeX206aEF`80J55K0P1_F5/206QLGP80JUeK0P1VEEd206UIG080He1J0P1_EUT206MIG080L5YI
0P1ZEel206iHG080JUMO0P1YFed206iIF`80K59N0P1SAU`206Y5E`80IT5G0P1Q>eD206DkD@80HCeC
0`1P@E0204hdCP80@Qdm0P0k5CL205@j?@80GEln0P1>DDT203X`@P80H4<n0P1LAdH205aHD@80CF=A
0P1BHd`20595A`80E3]=0P1Q@DH205i4D080J5M>0P1KD5@207AMD080JEUK0P1kOUd206ELG@80IEIZ
0P1eMeL208QcG080OV=]0P22Hf`2085[L080Og1]0P1nKG0208QbK@80OFad403oool000h0oooo0P1o
KG02085[K`80Q6Q_0P21Ig8207i[L@80R79]0P1nIW<208IUL080OVIc0P29L6d2081aM080OWEb0P20
KFl208=_L`80P6e_0P24IW4208=_L`80NVib0P25Lfl207a`LP80PfY^0P22L7<207m]K`80PFMb0P23
LW42081/L080Q6ib0P1mKg8207e]LP80OV]_0P1[Hg@308E/HP80GE9c0P1:HVT203A4C@80CTE20P0g
>44202`Z<`808AlW0P0m5AT209dg?@80HUAE0P1]EU@206=<FP80L5QG0P1UFUd206IFF@80LV1K0P1^
HEd606iMH080JUmQ0P1ZFUd206iEGP80LE]O0P1^GF0206YGG`@0KUEN0P1ZEel206]CF`80K5=N0P1/
FE`406iPG@80KUeP0P1ZEel206iEGP80IeQQ0P1VG5`206UGFP80K5EK0P1XDE/206mHF`80J5aN0P1Z
GE/206IEG@80JEUL0P1SD5X206mFF@80IeUL0P1`FUT206YGG`80KUQL0P1ZEel206UKG@80KUUK0P1/
DUh206=6G080JTEG0P1V@EL2064kE@80IC]A0P1Q?E<30611D080CSA>0P127Cd203/E=`80E3Xm0P1M
Gch204iAB@80>S120P1P@ch205a7AP80G5QA0P1=He42059SC080DTE70P1D>dd20651AP80GTA@0P1X
Edh205]@E080M5e@0P1YFE/207]nG@80IEaM0P1UEVX207EgE`80R7=L0P1nHfd2089SK080PF]`0P1o
L6d207i]L080R79]0P1mK7@@0?ooo`003P3oool2081YK`80Q7=_0P1lLG4207i]L080Pg=`0P1oK6l2
07iXL`80PFm^0P20MG42085`K`80Q6Qa0P26KG4207a/M080QW9^0P1lK7@2089dL080Pg=`0P1lKGD2
08IbKP80OFad0P1nK74208AZKP80Pfmc0P1lLG4208=ZKP80OfEb0P27Jfd2081XL`80PFea0P1lJg42
07MbLP<0LVM[0P1[IW02055=HP80?3UH0P1:?d4203P]?P80;RLd0P0W9R/202@R8`80=Q0G0P2R<3h2
06]IE@80FdeI0P1cFU<206IDF`80JEUK0P1`FeP2075KG`80JUMO1P1^EEh206iMH080IeaN0P1^F5`2
075KG`80IeUQ0P1ZFUd206iPG@@0IeaN0P1VF5/206aFF`80L5MK0P1^EEh206eCGP80KeaO0P1WG5h2
06MEG080J55K0P1YEE/206MEFP80IUAK0P1ZE5P206Y@FP80KEAK0P1UDed206UDF@80H51L0P1YDE@2
06U;F080Ke9H0P1]F5`206==F`80LUIJ0P1QBU/2079BF@80IU9L0P1NDE`205a>E@80GTeD0P1EBU<2
05E5C@80DCQ90`1=:D<203PG>080?b@i0P0i=cH205Q@<`80Gd]00P1EA4d2041;C`80FV0o0P1FE4/2
06ACBP80FDMB0P1MATl205ICE@80B4Y;0P1GBDL206=FB`80HE9>0P1QDUD2071OD@80JUYL0P1lCe@2
06e=JP80LfeM0P1mN5l207eaIP80MUm/0P22IVX208I`J`80Ofm`0P1nK70208QaKP80P75d403oool0
00h0oooo0P20JFl208AcK`80O75a0P1nKG0208=cL080Ofa_0P1nJ7<2085_KP80P7Ea0P21L6l208AX
L@80QVea0P1lK7@208IbKP80O6ad0P22M70208=cL080O6ee0P26LVh207e/M080OVaa0P24JVh208=_
L`80O75a0P23JVh207mULP80Qf]]0P20J7<2085]L@80O6]a0P1gLW83079WJ`80JfI`0P1ACF8203`i
F080BSm10P0h;Ch202hW=0809bH[0P0T8R<203H@5`80XS0n0P1[FED205]=F@80LeYC0P1VE5/206UI
F`80L5]H0P1aFel206YGG`H0KUEN0P1^GF0206MLGP80KUQL0P1aFel206MIH@80JUYM0P1^H5d406ML
GP80IUQK0P1/EU/2071GF`80KUEN0P1]Deh206mLG`80IeaN0P1WEE`206QAF`80JEEK0P1WEEX206ID
F`80JUAH0P1ZD5X206eDF`80IE=M0P1YE5T2061@G080JE5D0P1YBeP206mBF080KEQL0P1SCE/2079F
FP80HDYK0P1bDUT206IBG080GU5L0P1LCUD205i=E080EDYC0P1EADd2054hB@<0CBU30P0h5cP203lT
>@80>CLf0P1HD3<205m;@080EDA=0P10Bdl205YP?`80EUA;0P1TDdX205U7DP80GDI?0P1FDeD204Q:
B`80EdU70P1SET/2065BCP80HE9E0P1`Ge4206YJG080O4mD0P1]CFX207=]G@80OGQO0P1mLFH207IO
K080PVIZ0P26L6/207m_L080OVa`0P28LFh2081aM100oooo000>0?ooo`80OVm_0P23JFd208I^LP80
OWEb0P23M6l207YXM080Q7=_0P20MW4208=bL@80O6Yd0P21JW0208Q`K`80O6Yd0P25Jfl207iVL`80
QfY^0P23IW42085WLP80R71_0P20LG@207meLP80O75a0P24K6h208=_L`80NVeb0P1nKG02085]KP80
PFea0P20K70207YTL@80P6=]0`1[DW0207mRI@80?S=S0P1;=dl204LmA080<bdl0P0`:C82030];P80
9bTY0P0N7B0202073P80[24g0P1UCeP206QBDP80JU9I0P1YEEP206iHFP80KEEK0P1/EUl606YJG@80
LEiL0P1WFF4206iPG@80JUYM0P1ZEel206YJG@80KUQL0P1YE5l206aIG080IeaN0P1UFE/206YEFP80
K5EK0P1XE5`2075HFP80JUMO0P1VFEh206EKG080IUUJ0P1UEU/206MIF@80HU9I0P1TC5L206Y=EP80
JUEJ0P1RDUT206=AF@80IeaG0P1OEUP206eLEP80J5AI0P1PCe`206Q=D`80IU9L0P1TDU@206I:F080
HdeH0P1KCEH205Y9D@80DSe?0P17;4D204HW?`<0@2Tk0P0e;cX2040o<`80CEDk0P1DG3h20558AP80
Dd180P1EB4X205iAB080EDA=0P1E=TL205LbB@80Gcm90P1I>dT205i?DP80EUm>0P1NF4d205i?DP80
K65C0P1ZHUH206YJG080K61M0P1kOUd2075oI080N6YU0P21IfX207YfK`80NWY[0P24Mf`2081dLP80
OWEb0P23M6l208=_La00oooo000>0?ooo`80OVm_0P23JFd208I^LP80OWEb0P23M6l207YXM080Q7=_
0P20MW4208=bL@80O6Yd0P21JW0208Q`K`80O6Yd0P25Jfl207iVL`80QfY^0P23IW42085WLP80R71_
0P20LG@207meLP80O75a0P24K6h208=_L`80NVeb0P1nKG02085]KP80PFea0P20K70207YTL@80P6=]
0`1[DW0207mRI@80?S=S0P1;=dl204LmA080<bdl0P0`:C82030];P809bTY0P0N7B0202073P80[24g
0P1UCeP206QBDP80JU9I0P1YEEP206iHFP80KEEK0P1/EUl606YJG@80LEiL0P1WFF4206iPG@80JUYM
0P1ZEel206YJG@80KUQL0P1YE5l206aIG080IeaN0P1UFE/206YEFP80K5EK0P1XE5`2075HFP80JUMO
0P1VFEh206EKG080IUUJ0P1UEU/206MIF@80HU9I0P1TC5L206Y=EP80JUEJ0P1RDUT206=AF@80IeaG
0P1OEUP206eLEP80J5AI0P1PCe`206Q=D`80IU9L0P1TDU@206I:F080HdeH0P1KCEH205Y9D@80DSe?
0P17;4D204HW?`<0@2Tk0P0e;cX2040o<`80CEDk0P1DG3h20558AP80Dd180P1EB4X205iAB080EDA=
0P1E=TL205LbB@80Gcm90P1I>dT205i?DP80EUm>0P1NF4d205i?DP80K65C0P1ZHUH206YJG080K61M
0P1kOUd2075oI080N6YU0P21IfX207YfK`80NWY[0P24Mf`2081dLP80OWEb0P23M6l208=_La00oooo
000>0?ooo`80P6U_0P23Lg02085`K`80QVea0P23Kg<207ebM@80P6i_0P25J74208I]L@80Og9d0P1l
LG8208=ZKP80OfEb0P23KFl2081dLP80P7M`0P1nMG8207ifL@80PFm_0P23IW4208IWL@80PFYc0P21
KG4208I`K`80O6ee101oKg0207m/L080P6]`0P1lLG8207E]K`<0IV1`0P1lJF4203DmJP80BD980P17
?T@203<b?P80;R/a0P0c:bd202TU:P806QHN0P0J6A/202093080/Bhe0P1RDeH206eNE@80HeUK0P1/
FUT206UHG080K5]L1P1ZFUd206iHG080KUeP0P1^H5d206MIH@H0JUYM0P1YFed206YKG080JUYM0P1U
FEh206MJF`80JUeK0P1TF5`206aIF@80JEAL0P1ZEE`206MCF`80Ie=J0P1VEEX206MFF@80H59K0P1Q
EEL206=FE@80Ie9E0P1QCET2061:E@80JTaC0P1UCeT206M>E080KUMJ0P1HC5T206E@E@80IE1C0P1R
CUP205Y6D`80IDYB0P1IAU<204/aB`80?ahm0P17:3d202/J;@<0C34d0P11@SX204M;>`80FEDm0P1B
AdH20551B@80E4U80P1BA4L206ICB@80DE1A0P1?EDl204mKB`80FEm:0P1BGE4205iKB`80HEEC0P1M
E5@206ITE@80JFAD0P1ZFU/206YIG080MFML0P20IE`2081MJ@80NfU/0P1oLfT208=_J`80Pg9a0P21
KW0208I]L@80PFYc0P23IW4208Q/LA00oooo000>0?ooo`80P6U_0P23Lg02085`K`80QVea0P23Kg<2
07ebM@80P6i_0P25J74208I]L@80Og9d0P1lLG8208=ZKP80OfEb0P23KFl2081dLP80P7M`0P1nMG82
07ifL@80PFm_0P23IW4208IWL@80PFYc0P21KG4208I`K`80O6ee101oKg0207m/L080P6]`0P1lLG82
07E]K`<0IV1`0P1lJF4203DmJP80BD980P17?T@203<b?P80;R/a0P0c:bd202TU:P806QHN0P0J6A/2
02093080/Bhe0P1RDeH206eNE@80HeUK0P1/FUT206UHG080K5]L1P1ZFUd206iHG080KUeP0P1^H5d2
06MIH@H0JUYM0P1YFed206YKG080JUYM0P1UFEh206MJF`80JUeK0P1TF5`206aIF@80JEAL0P1ZEE`2
06MCF`80Ie=J0P1VEEX206MFF@80H59K0P1QEEL206=FE@80Ie9E0P1QCET2061:E@80JTaC0P1UCeT2
06M>E080KUMJ0P1HC5T206E@E@80IE1C0P1RCUP205Y6D`80IDYB0P1IAU<204/aB`80?ahm0P17:3d2
02/J;@<0C34d0P11@SX204M;>`80FEDm0P1BAdH20551B@80E4U80P1BA4L206ICB@80DE1A0P1?EDl2
04mKB`80FEm:0P1BGE4205iKB`80HEEC0P1ME5@206ITE@80JFAD0P1ZFU/206YIG080MFML0P20IE`2
081MJ@80NfU/0P1oLfT208=_J`80Pg9a0P21KW0208I]L@80PFYc0P23IW4208Q/LA00oooo000>0?oo
o`80OGQa0P23MFl207]WM080RFm^0P21JW<208I]L@80Og9d0P20MG42085]L@80Q6Qa0P1nIW<2089/
L080P7Ea0P1lKg0208=VK`80QfM`0P24J74208I]L@80P75d0P1kKW82089^K`80Pg9a0P1lK78208AX
K`80PVUb0P23LW4207e_LP80OV]a0P20K6l2081YK`80N6Aa0`1]I702075MI@80?CYV0P19@4X203lb
@080>Rhl0P0e=3L202l^;P8091dV0P0J5Qh201PC5P8081hM0P2RN@/2069CEP80KEID0P1YFE`206UK
FP80JUYL0P1ZFE`206mPG@80IeaN0P1^H5d206MLGP80KUQL0P1^EEh206YGG`80JUYM0P1WEE`206eH
G080JUYM0P1YEed206aIG080IEIM0P1ZFE/206UFF`80IU9L0P1YE5T206A>FP80Je=H0P1VEEX406IF
F@@0He5I0P1QDEH2061;E@80HTUD0P1QBU@205i=E080I5=B0P1[H5H205UEF@80HD9@0P1M?EH20655
CP@0HDAA0P1B>e0205djB080Cbe90P1;=4P202PQ=@80A2`_0P0b=3T304A1;P80?Rde0P1F?3X205]6
@080CSe80P1@?TD205I2A@80FE1;0P1MDDP2061CDP80FeeC0P1BD542069ACP80JF=D0P1FFEH2069D
D`80If5G0P1YHED206YJF`80JEUL0P1bJ5d207E_G@80MFIT0P24MfD207YiJ`80PGY]0P1oMg02085^
L080PFYc0P26L6l207aYM080Pg9a0P23M6l@0?ooo`003P3oool207ehL@80PgE_0P1kIg@208U_KP80
PFYc0P26KG4207mbM080P7Ea0P21KG4208AXL@80OVIc0P22K702081eL@80O6m`0P23IVl208MWL080
Q6Qa0P26KG42081aM080Nfib0P22KVl208=bL@80O6ab0P24J6l2089YLP80Pg9a0P1mKg8207i[L@80
P6a_0P20JFl207QTL@<0KFA`0P1aGFD203djIP80BD1:0P0o<T0203X^?080=C@g0P0_;Rh202@M9P80
6QHN0P0H4aH2020N7@80XWT;0P1RDeH206eFE080JEUL0P1YFeX206YJG080JUUL0P1_H5d206MLGP80
KV1M0P1WG5h206iHG080KUEN0P1ZEel206YJG@80IeEL0P1]F5`206YJG@80JEMM0P1/FE`206EFG@80
JUUK0P1YEU/206IBG080JEAI0P1TCUX206]CF080IUEJ101VEUT406=AF@80HE5F0P1PBeD20699E080
HDYD0P1NCE@206ACDP80Jf1F0P1IEET20652D080GCeF0P1QADh40654D@80DS]@0P1M>TP204l]B@80
BcA80P0X8CD204@/;`80<S@i0`14@Bh203h]=@80ES`j0P1KAT0204hmB080D3i50P1F@TD205U@B`80
GE580P1PDe8205]MD`80DU1A0P1RDDh206USE080EUUF0P1RE5<206MQE`80JF5E0P1ZFU/206UIG080
LVQM0P1eKed207EVI080Q7MU0P1jNF/2085jK@80OgM`0P21KW02085ZL`80QW1_0P1lJG@208=bL@80
PgA_403oool000h0oooo0P23Kg<2085ZL`80OFYd0P24Jfd2089YLP80PfU_0P28K742081XL`80Q6ib
0P1lKG8207i[L@80QGA^0P23LW4207a]M@80P7Ea0P1lKg0208AbL080PFea0P24J74207m[L`80Pg=`
0P1oJW0207mWL`80PgA_0P20MW42085]L@80Pfmc0P1kKW82085_K`80O6]a0P1iJW0306aMKP80GCiS
0P1;=ed204U0BP80?CU40P0f<3P2048j=`80;2`b0P0Y:Rd201/N8@807QlM0P0Z:R0204LM6P80V3Q2
0P1/GEH206ULFP80KV9M0P1UFed206UHG080LemK0P1WFF4206iHG080JUMO1P1ZFUd206UHG@80J5]N
0P1YFe/206MBG080JUAL0P1]FU/206EIGP80J5MJ0P1WEU`206MKF`80H5=J0P1YFeX205mBE`80JeAG
0P1YFeX206=HFP80H5=J0P1SE5L205e=EP80GdiD0P1E@E020694CP80IU=A0P1XI5@2069CE@80DSAD
0P1L>dl205e9C@80ETE=0P1OBDd205I3C@80B3A:0P1@=D8203hY?`80A2Th0P10A4D203I6=@80AT`k
0`13CC`204=E@P80D5lm0P1CDTD204]7B@80CdU60P1@AdD2065?AP80DSm<0P1Q?TP206E1CP80FDEC
0P1RDTh206=3C@80GcaE0P1aGE8206UPEP80JEUK0P1ZFE/2071VG@80MVmM0P1kM6@207=eJP80QWQT
0P22M70207m/L080Pf=a0P26KW82081dLP80PFea0P1oJg<208IbKP80PFYc403oool000h0oooo0P23
Kg<2085ZL`80OFYd0P24Jfd2089YLP80PfU_0P28K742081XL`80Q6ib0P1lKG8207i[L@80QGA^0P23
LW4207a]M@80P7Ea0P1lKg0208AbL080PFea0P24J74207m[L`80Pg=`0P1oJW0207mWL`80PgA_0P20
MW42085]L@80Pfmc0P1kKW82085_K`80O6]a0P1iJW0306aMKP80GCiS0P1;=ed204U0BP80?CU40P0f
<3P2048j=`80;2`b0P0Y:Rd201/N8@807QlM0P0Z:R0204LM6P80V3Q20P1/GEH206ULFP80KV9M0P1U
Fed206UHG080LemK0P1WFF4206iHG080JUMO1P1ZFUd206UHG@80J5]N0P1YFe/206MBG080JUAL0P1]
FU/206EIGP80J5MJ0P1WEU`206MKF`80H5=J0P1YFeX205mBE`80JeAG0P1YFeX206=HFP80H5=J0P1S
E5L205e=EP80GdiD0P1E@E020694CP80IU=A0P1XI5@2069CE@80DSAD0P1L>dl205e9C@80ETE=0P1O
BDd205I3C@80B3A:0P1@=D8203hY?`80A2Th0P10A4D203I6=@80AT`k0`13CC`204=E@P80D5lm0P1C
DTD204]7B@80CdU60P1@AdD2065?AP80DSm<0P1Q?TP206E1CP80FDEC0P1RDTh206=3C@80GcaE0P1a
GE8206UPEP80JEUK0P1ZFE/2071VG@80MVmM0P1kM6@207=eJP80QWQT0P22M70207m/L080Pf=a0P26
KW82081dLP80PFea0P1oJg<208IbKP80PFYc403oool000h0oooo0P23Kg<2081aM080Nfeb0P24Lg02
07a]L@80PFea0P24KFh2089`L`80Pg=`0P1kJW@208=dL080PgA_0P23Kg<2081aM080OfY`0P21JW82
08IbKP80O6Ud0P22K70207iYL080QFM^0P23Kg<207Y_L@80QVa^0P26KG4207aZM080QF]_0P1nJG<2
081YK`80Nf9`0P1mIFh306EEK`80DDQV0P15>U4204hmB080?3A10P10?Ch203hk=P80:B@b0P0`9b/2
024P9P80:BXT0P0/:b@201dE7080YelI0P1`G5D206YJG080LUmK0P1TEf4206UIG080KeUJ0P1WDEl2
06aEF`80K5UL0P1WEE`206aEF`80K5UL0P1YFed206UHG080J5AL0P1WFE`206IIFP80JUEJ0P1/FE`2
06=FG080IeEJ0P1YE5T206EJG@80HE5F0P1WEU/2061CE@80JTeF0P1UBeT206==F080H4]E0P1KAeD2
05PoC`80FDQA0P1ICd`2075SCP80JF1G0P1<=eL205DnDP80FE9:0P1ICd`204m2C@80CS930P1<9T42
03lQ?080ECPm0P0j=T0203Xd=`80BC@d0P1:?T4204]5?0<0@S<m0P1I?ch205]9A@80EDQ:0P1?A4/2
04i0AP80Ac510P1dE4<204U;D@80H5i;0P1@Bdd206eUC`80D55B0P1ND58206AZD`80JFMA101YFE/2
06ePG080LEmK0P24L5l207aaIP80NfY/0P27L6X208I`K`80NVQd0P23M6l208=eK`80Pfmc0P1lJG@2
08EaL080Pg9a0P20LG@@0?ooo`003P3oool208=_L`80P75d0P1kKG8208AcL080O6ea0P21KG4208A]
KP80PW1c0P23Lg0207]ZM080PgA`0P23M6l208=_L`80P75d0P1oJW02085ZLP80QW9^0P1lJG@2089/
L080OVU`0P25Ifh208=_L`80NVma0P26K6h208I]L@80O6Yd0P25Jfl207iYL`80P6U_0P1kHW0207eU
KP<0IEE_0P1AB6H204DjD@80CSe80P0l=442040m?P80?S/f0P0Y9382030W:`808B0V0P0Y:R@202`[
90807ADL0P2WGaT2071LE@80JUYL0P1bGe/206AGH@80JEUL0P1_FEX206MAG`80K5EK0P1/FE`206ME
G080K5EK0P1/FE`206UKG@80JEQL0P1XE5`206MIG080IUUJ0P1ZEEX206aIG080HeIL0P1WEEX206UD
F@80IEYM0P1QDEH206MFF`80H5=E0P1ZCEH206E;F@80HdeH0P1PBeD205]7E@80F3m?0P1IB54205U?
C080LF=>0P1YH5L204`gE`80ECiB0P1IDTX205U?C080Cd9=0P1><T<204`V@@80?b4l0P1E>3d203Xf
@080>S@g0P19=3@204Xn@@80BdDl0`12<cd205To?P80FdU50P1EB4X204m4B`80CT160P17<D4207AD
@`80BD]A0P1PGT/2051;C@80KFE?0P1@DE8205i@DP80I6YC0P1YIe4406UIF`80KF1L0P1aGe/208A`
G`80O75V0P1kJV`208M`JP80QW1_0P1jJ7@208=dK`80PgE_0P23Kg<207aYM080QG5`0P23LW42081a
M100oooo000>0?ooo`80Pfmc0P1oIg<208=_L`80P6e_0P23Kg<2081fL@80P7Ab0P23LW4208=_L`80
O6ad0P26LVh608=_L`80O6ee0P20KFl208Q`K`80OW9e0P1mL74207i_LP80OFa_0P29L6d207a]M@80
PgA_0P1oJW02081WLP80QG9_0P1oMG8207Y_LP80MVQ`0P1lJ6`305I2J`80GTEN0P10?E<204De@080
?c0o0P0m;CD203h[=P809b0_0P0a9bT202l`;@80;c@Z0P0T82@2014=5@80_GL80P1VFUL206eHF`80
KEIK0P1ZEel206QJG080K5]L0P1TEUh206UGFP80KEYK0P1TEUh206UGFP80JUEJ0P1ZDe/206UDG080
IeIK0P1ZFEX206MIG080IUQK0P1YE5T206UGG@80HeQJ0P1VEUT206A=E`80HDaJ0P1WCe<206=@F@80
HE9E0P1RDEH2065CEP80F4YD0P1IB54204m1CP80F4170P1XEDd206UGC@80F35B0P1>;e8205@mA@80
FSe60P1E=dP204/`AP80A3520P0e9CH204@d>080D4Dg0P0l=Cl203li>P80@CXh0P17=SL204H^>P<0
@c8m0P1GASX205]:A080EDU:0P1=@DT204i2A`80C59:0P1TFCh20552DP80Hd]80P1B@U8206HoA080
HTAG0P1NDdl206U:CP80M5AG0P1XFU`206UKG080N6iK0P1fR6<207IlH`80OFU/0P1nKV`208IfJ`80
Pg9a0P1jKGD208IcK@80Pfmc0P1oIg<2085ZL`80PfY^0P28K74208=_La00oooo000>0?ooo`80Pfmc
0P1oIg<208=_L`80P6e_0P23Kg<2081fL@80P7Ab0P23LW4208=_L`80O6ad0P26LVh608=_L`80O6ee
0P20KFl208Q`K`80OW9e0P1mL74207i_LP80OFa_0P29L6d207a]M@80PgA_0P1oJW02081WLP80QG9_
0P1oMG8207Y_LP80MVQ`0P1lJ6`305I2J`80GTEN0P10?E<204De@080?c0o0P0m;CD203h[=P809b0_
0P0a9bT202l`;@80;c@Z0P0T82@2014=5@80_GL80P1VFUL206eHF`80KEIK0P1ZEel206QJG080K5]L
0P1TEUh206UGFP80KEYK0P1TEUh206UGFP80JUEJ0P1ZDe/206UDG080IeIK0P1ZFEX206MIG080IUQK
0P1YE5T206UGG@80HeQJ0P1VEUT206A=E`80HDaJ0P1WCe<206=@F@80HE9E0P1RDEH2065CEP80F4YD
0P1IB54204m1CP80F4170P1XEDd206UGC@80F35B0P1>;e8205@mA@80FSe60P1E=dP204/`AP80A352
0P0e9CH204@d>080D4Dg0P0l=Cl203li>P80@CXh0P17=SL204H^>P<0@c8m0P1GASX205]:A080EDU:
0P1=@DT204i2A`80C59:0P1TFCh20552DP80Hd]80P1B@U8206HoA080HTAG0P1NDdl206U:CP80M5AG
0P1XFU`206UKG080N6iK0P1fR6<207IlH`80OFU/0P1nKV`208IfJ`80Pg9a0P1jKGD208IcK@80Pfmc
0P1oIg<2085ZL`80PfY^0P28K74208=_La00oooo000>0?ooo`80Pfmc0P1nLWD208=dK`80NfYd0P28
LFh208=_L`80PFYc0P26KG42085ZL`80Pfmc0P21KG4208I]L@@0Pfmc0P20LG@207a_LP80Q6a^0P24
J742085ZL`80PFea0P20M78208=eK`80OFad0P26L6l207YZM0@0PgA_0P23Kg<207]ZM080MVIa0P1d
FV/304m2K080FDEC0P16?582044nA@80?CTm0P0l>CX202dU;P80:Ql[0P0f;RX203Ha;@80;RL[0P0Q
72D201`N8@80]XH30P1SEUd2075SF@80IEaN0P1WDe/206eHG080JEUL0P1WFEd206QNG080IeQJ0P1X
EE`206QJF`80IUQK0P1SD5T206aEF@80IeQJ0P1TCeT206U<F080IdeI0P1VCUP206eFE`80H4aJ0P1X
CeL2061@F@80HE=E0P1SEUD205i=E080HT]D0P1QC5<205e4DP80FdAC0P1?>T/205DoB`80EDY90P1U
C4H205dkCP80C3E?0P1??dH204i2A080D4140P19=d<203/W>`80A2`i0P0i=3/2048l<`80FThk0P0n
ATD204=8?`80?3Xk0P10=CT2051=?P<0@4]00P1ABCd205E2@`80ET170P1BAd/205aRB`80CeY<0P1J
D4/20514CP80FTI90P1EADd205E8B`80HD]90P1]HE8205i[F080KFeE0P1UGEh207E_G@80N7EN0P25
Jf<207iZL080N6Y]0P22K6/208IZK080Pf=a0P26KW8208=bL@80PFYc0P21L7<2081fL@80OWEb0P23
M6l208=_La00oooo000>0?ooo`80Pfmc0P1nLWD208=dK`80NfYd0P28LFh208=_L`80PFYc0P26KG42
085ZL`80Pfmc0P21KG4208I]L@@0Pfmc0P20LG@207a_LP80Q6a^0P24J742085ZL`80PFea0P20M782
08=eK`80OFad0P26L6l207YZM0@0PgA_0P23Kg<207]ZM080MVIa0P1dFV/304m2K080FDEC0P16?582
044nA@80?CTm0P0l>CX202dU;P80:Ql[0P0f;RX203Ha;@80;RL[0P0Q72D201`N8@80]XH30P1SEUd2
075SF@80IEaN0P1WDe/206eHG080JEUL0P1WFEd206QNG080IeQJ0P1XEE`206QJF`80IUQK0P1SD5T2
06aEF@80IeQJ0P1TCeT206U<F080IdeI0P1VCUP206eFE`80H4aJ0P1XCeL2061@F@80HE=E0P1SEUD2
05i=E080HT]D0P1QC5<205e4DP80FdAC0P1?>T/205DoB`80EDY90P1UC4H205dkCP80C3E?0P1??dH2
04i2A080D4140P19=d<203/W>`80A2`i0P0i=3/2048l<`80FThk0P0nATD204=8?`80?3Xk0P10=CT2
051=?P<0@4]00P1ABCd205E2@`80ET170P1BAd/205aRB`80CeY<0P1JD4/20514CP80FTI90P1EADd2
05E8B`80HD]90P1]HE8205i[F080KFeE0P1UGEh207E_G@80N7EN0P25Jf<207iZL080N6Y]0P22K6/2
08IZK080Pf=a0P26KW8208=bL@80PFYc0P21L7<2081fL@80OWEb0P23M6l208=_La00oooo000>0?oo
o`80Pfmc0P21JW<208I]L@80OW9e0P23M6l4085ZL`80QW1_0P20LG@2085]L@80Pfmc0P23LW4408=_
L`80PFYc0P23Kg<207e_LP80PFea0P23LW42081dLP80PFea0P26KG4207e/M080Q6]_0P1oJg<208A]
KP80Q6Qa0P23IW4207mXL`80MVMa0P1ZGVh304e:J080Cd=C0P19?4`2044f@`80?c<m0P10=CT202d^
=`80;S0^0P10@bl202h^;`8081HR0P0R5b0201dG6`80^gD;0P1SEUd2075GE`80HdQM0P1]EU/206aN
F@80JE]M0P1RCe/206Y;F080K59K0P1VEEX206I>F@80IdeI0P1SD5T206E>E@80JDeG0P1SD5T2065A
EP80He1E0P1UDeH206=:E080ITmH0P1OCU@2065;E080HDaD0P1SC5<205i<EP80GdmB0P1IB54205Y8
D@80EDA=0P1<@Th204m2A@80H5180P1A@TT204``AP80Ab]10P1C>3l204Pc@080CcHo0P0j9SX204Dh
?P80?Chh0P0n>3P2044h>080Eclg0P1BADL204Q8A@80?3a20P17Ach204a1>P<0C3Y30P1CAT8204De
@080G4120P1FB4L206]FB080FUAF0P1JFU8204]:D@80ETU:0P1PFdd204a<CP80GTe:0P1hGd/206YI
F`80LUeK0P1aK68207]mG@80NgaX0P1fL6/2089]J`80N6M`0P24Kf/2081^K`80PGA`0P23MFl208=_
L`80OFad0P23JFl208IWL@80PfIa0P26Ig4208I]LA00oooo000>0?ooo`80Pfmc0P21JW<208I]L@80
OW9e0P23M6l4085ZL`80QW1_0P20LG@2085]L@80Pfmc0P23LW4408=_L`80PFYc0P23Kg<207e_LP80
PFea0P23LW42081dLP80PFea0P26KG4207e/M080Q6]_0P1oJg<208A]KP80Q6Qa0P23IW4207mXL`80
MVMa0P1ZGVh304e:J080Cd=C0P19?4`2044f@`80?c<m0P10=CT202d^=`80;S0^0P10@bl202h^;`80
81HR0P0R5b0201dG6`80^gD;0P1SEUd2075GE`80HdQM0P1]EU/206aNF@80JE]M0P1RCe/206Y;F080
K59K0P1VEEX206I>F@80IdeI0P1SD5T206E>E@80JDeG0P1SD5T2065AEP80He1E0P1UDeH206=:E080
ITmH0P1OCU@2065;E080HDaD0P1SC5<205i<EP80GdmB0P1IB54205Y8D@80EDA=0P1<@Th204m2A@80
H5180P1A@TT204``AP80Ab]10P1C>3l204Pc@080CcHo0P0j9SX204Dh?P80?Chh0P0n>3P2044h>080
Eclg0P1BADL204Q8A@80?3a20P17Ach204a1>P<0C3Y30P1CAT8204De@080G4120P1FB4L206]FB080
FUAF0P1JFU8204]:D@80ETU:0P1PFdd204a<CP80GTe:0P1hGd/206YIF`80LUeK0P1aK68207]mG@80
NgaX0P1fL6/2089]J`80N6M`0P24Kf/2081^K`80PGA`0P23MFl208=_L`80OFad0P23JFl208IWL@80
PfIa0P26Ig4208I]LA00oooo000>0?ooo`80Pfmc0P20LG@208=bL@80PFYc0P26KG42081aM080OFmb
0P26L6l208=_L`80P75d0P21KG4208I]L@@0Pfmc0P20LG@208=bL@80P75d0P20M78208=bL@80Pfmc
0P1mK7@208I`K`80OFad0P21KG4208=bL@80O6eb0P21JW0208AbL080OWIb0P1bJG<2065<K0<0DC]Q
0P1FB5@204I4C080?CU30P0n=S/2040g>@80:b@a0P0m<c4203HZ;080:a`/0P0J51l202HO7`806aTK
0P2jN0T206IJG@80JE]J0P1RGEl206UPE`80Ie=K0P1_F5/2065KH080GEMI0P1/FEH2069AFP80HDiH
0P1UDeH2065AEP80GdaF0P1UD5<2061;E@80I4mE0P1OCU@206=<D`80GdaF0P1VDe8205iBE`80G55D
0P1LBU8205e7D080HTeA101JBE4205U<CP80DTM>0P1;?TT205I;B080ETM40P17<TP204<`@@80ACPn
0P14=3P204<`?080>b@c0P11;SX204<e<`80=B8b0P13:S<204Hg=`80FDll0P1BBd<204m7B@80BUA;
0P12Ad4204U0@@<0ACPn0P1<<c`20513AP80EE910P1>@4H206i>A@80HU1C0P1JAe820510DP80HEY<
0P1RGTd204i=EP80HEi=0P1`Hdh206UHF`80NVeK0P1iM60207i_I@80O5eZ0P21HFd2089]J`80OG9`
0P1oM6d207m_L080QW9^0P21JW<208I]L@80P75d0P1nMG8207e`L@80Ofia0P23M6l2085]LA00oooo
000>0?ooo`80Pfmc0P20LG@208=bL@80PFYc0P26KG42081aM080OFmb0P26L6l208=_L`80P75d0P21
KG4208I]L@@0Pfmc0P20LG@208=bL@80P75d0P20M78208=bL@80Pfmc0P1mK7@208I`K`80OFad0P21
KG4208=bL@80O6eb0P21JW0208AbL080OWIb0P1bJG<2065<K0<0DC]Q0P1FB5@204I4C080?CU30P0n
=S/2040g>@80:b@a0P0m<c4203HZ;080:a`/0P0J51l202HO7`806aTK0P2jN0T206IJG@80JE]J0P1R
GEl206UPE`80Ie=K0P1_F5/2065KH080GEMI0P1/FEH2069AFP80HDiH0P1UDeH2065AEP80GdaF0P1U
D5<2061;E@80I4mE0P1OCU@206=<D`80GdaF0P1VDe8205iBE`80G55D0P1LBU8205e7D080HTeA101J
BE4205U<CP80DTM>0P1;?TT205I;B080ETM40P17<TP204<`@@80ACPn0P14=3P204<`?080>b@c0P11
;SX204<e<`80=B8b0P13:S<204Hg=`80FDll0P1BBd<204m7B@80BUA;0P12Ad4204U0@@<0ACPn0P1<
<c`20513AP80EE910P1>@4H206i>A@80HU1C0P1JAe820510DP80HEY<0P1RGTd204i=EP80HEi=0P1`
Hdh206UHF`80NVeK0P1iM60207i_I@80O5eZ0P21HFd2089]J`80OG9`0P1oM6d207m_L080QW9^0P21
JW<208I]L@80P75d0P1nMG8207e`L@80Ofia0P23M6l2085]LA00oooo000>0?ooo`H0Pfmc0P20LG@2
085]L@80Q6Qa0P23Kg<2085]L@80PfIa0P28K742081aM080Pg9a0P23Kg<2085ZL`80QVea2023Kg<2
085ZL`80Pfmc0P23LW4207e/M080OVU`0P27JVh207eVL`80Q7=_0P21Kfl208=VL@80NV]e0P1:@fd3
05A1FP80DCi;0P1=>T/203DY?P80@Rlh0P0h:3<202lV<P80@3H]0P0_:C0202LQ:08081lS0P0Z:242
01dN8080]W`:0P1RCU/2071EF@80IUAK0P1/Ee/206=EG080IdmG0P1^E5X205eBG080Ie9E0P1SD5T2
05mBE`80H4eD0P1QBeD205m>E080GDQA0P1OAU8206A<D@80G4QC0P1NBE42069>DP80HDiB0P1QBe<2
05U5D`80G4UA0P1IBe0205i9C@80FTQA0P1JBdh20590C080ECm;0P1:?dT205a;A080C3i90P11=4@2
03lc?080@C0g0P10<3T203`]=@80?SPi0P0m>S@203HZ<P80=B/c0P0n=C0204Hi=@80ESdh0P1H@TD2
04hoAP80F4950P18@4X204a9A0<0?C]10P15>S`204Tb>080G3U00P1ID4/205eEAP80GdI?0P1QDU@2
05ANE@80Gea<0P1G?e0205e3DP80JEE=0P1aGE<206eRG080P75I0P1hIVH2085XJ080NWE^0P1iMfX2
07]YK080Qfa/0P23LW4207e_LP80QW1_0P20LG@208=bL@@0Pfmc0P1mK7@408=bL@80OFad403oool0
00h0oooo1P23Kg<2081aM080PFea0P24J74208=_L`80PFea0P23IW4208Q/L@80P75d0P23LW4208=_
L`80PFYc0P26KG4808=_L`80PFYc0P23Kg<208=bL@80OFad0P1nJG0208MZKP80OFIc0P24Lfl2085_
K`80PfIa0P1jJgD204Y3K@<0E45J0P1A?T/204djB`80=BTn0P12;cP203PX<`80;bHb0P10=Rd202lY
<0809b4X0P0P7b<202XX8@807AhP0P2fO0X2069>F`80L5EI0P1VE5/206aGF`80HeEL0P1WCeL206iD
FP80GE9L0P1WDUD206=@F@80Ge9G0P1PCE@2065;E@80GdiD0P1MB54205m6DP80I4aA0P1LB5<205i9
D@80HTiB0P1QCU82065;D`80FDEC0P1LBE4205U;D080GTU=0P1JB54205Y;CP80DT1<0P1E?d/204Xo
B@80G4]40P1<?TT2044dA080?c<l0P11<3L2040`>@80?2de0P0n>3T203dj=080=RXb0P0e:c<203he
<080ASTe0P1F?CP205Q2A@80CSm60P1H@TD204Q0BP80C4U40`0m>d4204Dj?080BC8h0P1L>D0205U@
B`80GEE60P1OATl2065BE080E5iE0P1OG4`205LoD080GD=B0P1YEDd2075MD`80KF9L0P20LET207QV
IP80PFQX0P1jMFh207UgJP80NfU/0P27K6`208=bL@80OFmb0P26L6l2081aM080Pg9a1023Kg<207e/
M0@0Pg9a0P1mK7@@0?ooo`003P3oool208=_L`80PFYc0P24J74208I]L@80OFad0P21KG4208I`K`80
P75d0P1nMG82085_K`80PfIa0P28K74208=_L`80OFad0P26L6l208=_L`80PFYc0P24J74208=VL@80
PFMb0P28L6l4085ZL`80P7Ab0P20Mg0207Y`L`80QW=]0P1kIg@2085ZL080LeA^0P1=@6l305=:E080
Ace=0P18=d<203Pc@P80@d8h0P0/:S@203Xe<P80>cH`0P0b;S<201/G8@807a@K0P0V6A`202@M8@80
/gP?0P1LD5d206iGE080HTeJ0P1]DeL206IDF`80H5=J0P1YDED206=?FP80GdaF0P1UCUD205i;E@80
G4QC0P1QCU4205a:DP80Fd]B0P1KCDl205Q2C@80FSi>0P1J@D`20696C080GTE@0P1OBE0205Q9DP80
Fd]>0P1EA4h405U3C080ESi;0P1B@4`204i0A`80Cd970P19<Sl204LW?`80@bdm0P0k;3L2040b=`80
@CPg0P0l>cT203/b<`80?Bhe0P0h<CH203Xi=080@3le0P12?3L204m1>P80F4Q10P1JG4`204mKC080
EVI?0P12Cd/303Pa@P80@c8i0P16>S`205Q<?080ECi20P1TATX2061FD080H5M@0P1PDE@205DoD@80
ECm@0P1IADT207IPC080KFQG0P1^HE`208=YG080NfeY0P1hIVP208UYJ080NfA_0P23MFl207eeK@80
QW1_0P20LG@208=bL@80Pfmc0P21JW<208I]L@80Pfmc0P20LG@207mZL080R6aa0P1mK7@@0?ooo`00
3P3oool208=_L`80PFYc0P24J74208I]L@80OFad0P21KG4208I`K`80P75d0P1nMG82085_K`80PfIa
0P28K74208=_L`80OFad0P26L6l208=_L`80PFYc0P24J74208=VL@80PFMb0P28L6l4085ZL`80P7Ab
0P20Mg0207Y`L`80QW=]0P1kIg@2085ZL080LeA^0P1=@6l305=:E080Ace=0P18=d<203Pc@P80@d8h
0P0/:S@203Xe<P80>cH`0P0b;S<201/G8@807a@K0P0V6A`202@M8@80/gP?0P1LD5d206iGE080HTeJ
0P1]DeL206IDF`80H5=J0P1YDED206=?FP80GdaF0P1UCUD205i;E@80G4QC0P1QCU4205a:DP80Fd]B
0P1KCDl205Q2C@80FSi>0P1J@D`20696C080GTE@0P1OBE0205Q9DP80Fd]>0P1EA4h405U3C080ESi;
0P1B@4`204i0A`80Cd970P19<Sl204LW?`80@bdm0P0k;3L2040b=`80@CPg0P0l>cT203/b<`80?Bhe
0P0h<CH203Xi=080@3le0P12?3L204m1>P80F4Q10P1JG4`204mKC080EVI?0P12Cd/303Pa@P80@c8i
0P16>S`205Q<?080ECi20P1TATX2061FD080H5M@0P1PDE@205DoD@80ECm@0P1IADT207IPC080KFQG
0P1^HE`208=YG080NfeY0P1hIVP208UYJ080NfA_0P23MFl207eeK@80QW1_0P20LG@208=bL@80Pfmc
0P21JW<208I]L@80Pfmc0P20LG@207mZL080R6aa0P1mK7@@0?ooo`003P3oool208AXL@80Pfmc0P20
M782085]L@80PFYc0P20Jg0208AXK`80Q6Ea0P26Ig4208=_L`80OWEb0P23M6l207mWL`80QFib0P21
KG4208I]L@80OFad0P23LW4207]]LP80PgA`0P23M6l2081aM080P7Ab0P23LW42085ZL`80OfMc0P26
JVl207eZM080P6i_0P1LBg4205M5I0<0Cd1B0P1;?dd2040g@P80>2`j0P15<3D2030Z=`80@c`b0P0]
9Bh202hM:@80618N0P0L5AP202@L6`808Q`M0P2eM10205]@G@80JeQE0P1RFE/206IJE`@0He5I0P1O
C5H20699E080Gd]E0P1QCU8205i=E080F4aB0P1MBTh205]7D@80G4a?0P1IBTl205I=D@80DTY<0P1E
B4/205U6B@80FD=<0P1OBD`205U:C`@0EDE=0P1EB4/204hmB080DCa70P1A?DD204TfA080E3m20P0l
<d8203X]>080>BLb0P14=CL203Tc=080A3Hf0P11=cT202LL;080<ATW0P0h7bX204Lb<P80C4Hi0P14
Acl204Y4?@80E4900P1R@d<205i6C`80G45:0P1LDUH303I@D080>T<n0P1>C3d20517?`80EDa80P1A
@4<2079>B@80H59D0P1E@54205@oD@80EDU:0P1DB4X207eQAP80LUiJ0P1lNF02075bH`80PF]V0P1g
Jfh2081/I`80Ofe_0P28MVX207]WM080QVQ^0P28KG4208=_L`80PFYc0P23Kg<208=bL@80Pfmc0P21
JW<2085`L`80PgA_0P20LG@@0?ooo`003P3oool208AXL@80Pfmc0P20M782085]L@80PFYc0P20Jg02
08AXK`80Q6Ea0P26Ig4208=_L`80OWEb0P23M6l207mWL`80QFib0P21KG4208I]L@80OFad0P23LW42
07]]LP80PgA`0P23M6l2081aM080P7Ab0P23LW42085ZL`80OfMc0P26JVl207eZM080P6i_0P1LBg42
05M5I0<0Cd1B0P1;?dd2040g@P80>2`j0P15<3D2030Z=`80@c`b0P0]9Bh202hM:@80618N0P0L5AP2
02@L6`808Q`M0P2eM10205]@G@80JeQE0P1RFE/206IJE`@0He5I0P1OC5H20699E080Gd]E0P1QCU82
05i=E080F4aB0P1MBTh205]7D@80G4a?0P1IBTl205I=D@80DTY<0P1EB4/205U6B@80FD=<0P1OBD`2
05U:C`@0EDE=0P1EB4/204hmB080DCa70P1A?DD204TfA080E3m20P0l<d8203X]>080>BLb0P14=CL2
03Tc=080A3Hf0P11=cT202LL;080<ATW0P0h7bX204Lb<P80C4Hi0P14Acl204Y4?@80E4900P1R@d<2
05i6C`80G45:0P1LDUH303I@D080>T<n0P1>C3d20517?`80EDa80P1A@4<2079>B@80H59D0P1E@542
05@oD@80EDU:0P1DB4X207eQAP80LUiJ0P1lNF02075bH`80PF]V0P1gJfh2081/I`80Ofe_0P28MVX2
07]WM080QVQ^0P28KG4208=_L`80PFYc0P23Kg<208=bL@80Pfmc0P21JW<2085`L`80PgA_0P20LG@@
0?ooo`003P3oool2081dLP80Pg9a0P23Kg<2081aM080OFmb0P22Lg4207ifLP80OWIa0P20MW4208=b
L@@0Pfmc0P1nLWD2081]K`80PVUb0P26L6l207aZM080R71_0P1lK7@208IbKP80PFYc0P26KG42085Z
L`80PfIa0P22JG82085cL@80Nfaa0P22K70207IKK`80Ed9_0P1LBe`304HlDP80B3E50P0n;d0203/c
>`80=R`a0P0f:S82044a<080:R@a0P0U7RD201dK8@808R<N0P0S8ah202DS8@80Y6/C0P1RCEX206I@
E080ITaF0P1WCUL2069?F080H4aE0P1RDEH205]BE080GU5C0P1IBE4205m8D080FdYA0P1EA4h205U2
C080FT9;0P1B>4X205/kB@80ECm;0P1A?DL205]5B@80EDQ;0P1B?4L205i0BP80EDE=0P1EB4/404hm
B080Cd940P1>@TD2044g@P80FDQ00P0f=48202dR<080@cDd0P10>C<203T`=`80>RX`0P0`6RX202TK
:`807ADL0P19>BT204]@<`80?SDg0P1B>Sd2048c?@80DcXm0P1NB4<2069EB`80DU5A0P1WFT/3044o
D`80AdQ90P1CED8204Y8A`80FT]50P1>BD`206aKA080ESmA0P1E?e4204hmB080F4170P1TFd`207E`
B`80MG1M0P20KEd207MRK080Nf9V0P24K6X207acK@80Og5]0P28LFh207Y]M@80Og1_0P26LVh208=_
L`80P75d0P1oJW0208Q/L@80PFYc0P23Kg<2085]L@80QVea0P23Kg<@0?ooo`003P3oool2081dLP80
Pg9a0P23Kg<2081aM080OFmb0P22Lg4207ifLP80OWIa0P20MW4208=bL@@0Pfmc0P1nLWD2081]K`80
PVUb0P26L6l207aZM080R71_0P1lK7@208IbKP80PFYc0P26KG42085ZL`80PfIa0P22JG82085cL@80
Nfaa0P22K70207IKK`80Ed9_0P1LBe`304HlDP80B3E50P0n;d0203/c>`80=R`a0P0f:S82044a<080
:R@a0P0U7RD201dK8@808R<N0P0S8ah202DS8@80Y6/C0P1RCEX206I@E080ITaF0P1WCUL2069?F080
H4aE0P1RDEH205]BE080GU5C0P1IBE4205m8D080FdYA0P1EA4h205U2C080FT9;0P1B>4X205/kB@80
ECm;0P1A?DL205]5B@80EDQ;0P1B?4L205i0BP80EDE=0P1EB4/404hmB080Cd940P1>@TD2044g@P80
FDQ00P0f=48202dR<080@cDd0P10>C<203T`=`80>RX`0P0`6RX202TK:`807ADL0P19>BT204]@<`80
?SDg0P1B>Sd2048c?@80DcXm0P1NB4<2069EB`80DU5A0P1WFT/3044oD`80AdQ90P1CED8204Y8A`80
FT]50P1>BD`206aKA080ESmA0P1E?e4204hmB080F4170P1TFd`207E`B`80MG1M0P20KEd207MRK080
Nf9V0P24K6X207acK@80Og5]0P28LFh207Y]M@80Og1_0P26LVh208=_L`80P75d0P1oJW0208Q/L@80
PFYc0P23Kg<2085]L@80QVea0P23Kg<@0?ooo`003P3oool408=_L`80PFYc0P26KG4207e/M080Q6]_
0P23IW4208IWL@80Q6Qa0P26KG42085ZL`80QVea0P23Kg<207mbM080P7Ea0P23LW4207]ZM080QFY^
0P22JG8208=YK`80QFib0P23LW4207e/M080PW=a0P20MG4207mZL080Of]c0P1nJfl206E=L@80Ed9V
0P1H@E@3048aC@80B3Q30P0j<Sd203hc=`80=S8g0P0d;c0203T];`808QPV0P0U6b82020K7`809QlO
0P0T7b0202DN8080WfTH0P1RDUH2069CEP80JF9G0P1MFUP2069FE`80G5AG0P1TFE@205aDE`80GeID
0P1KFEH205QHDP80FeIB0P1AD58204i5B`80D3]70P1C@dT204/mA080E3a40P1??TH205@n@P80E3Y6
0P1C@dT205E7A@80D3]70P1D>TH204hlB080B3U20P1==d0204L_?P80ASA00P1H@c`203<Z?`80:20_
0P15<b/204<g=`80;B<_0P0]6bP202LK9@80;RHV0P0[=2d2040n9P80ED4f0P11@d@204Do>@80Ad11
0P10=CT206M7?P80HTa80P1PDe8205I4C@<0CcmC0P1:@dH205M3A080D4990P1C@T@206AHC080H5a<
0P1<A5@205Y?C080Bde>0P1MHdX2065MBP80NUmA0P2;OE`206]XJP80NV9W0P1nLfT207a_J080R79]
0P1oMW4208=cL080P75d0P1mKg8208I`K`@0Pfmc0P1nLWD208=dK`80P75d0P23LW4207e/M080QW1_
0P21JW<@0?ooo`003P3oool408=_L`80PFYc0P26KG4207e/M080Q6]_0P23IW4208IWL@80Q6Qa0P26
KG42085ZL`80QVea0P23Kg<207mbM080P7Ea0P23LW4207]ZM080QFY^0P22JG8208=YK`80QFib0P23
LW4207e/M080PW=a0P20MG4207mZL080Of]c0P1nJfl206E=L@80Ed9V0P1H@E@3048aC@80B3Q30P0j
<Sd203hc=`80=S8g0P0d;c0203T];`808QPV0P0U6b82020K7`809QlO0P0T7b0202DN8080WfTH0P1R
DUH2069CEP80JF9G0P1MFUP2069FE`80G5AG0P1TFE@205aDE`80GeID0P1KFEH205QHDP80FeIB0P1A
D58204i5B`80D3]70P1C@dT204/mA080E3a40P1??TH205@n@P80E3Y60P1C@dT205E7A@80D3]70P1D
>TH204hlB080B3U20P1==d0204L_?P80ASA00P1H@c`203<Z?`80:20_0P15<b/204<g=`80;B<_0P0]
6bP202LK9@80;RHV0P0[=2d2040n9P80ED4f0P11@d@204Do>@80Ad110P10=CT206M7?P80HTa80P1P
De8205I4C@<0CcmC0P1:@dH205M3A080D4990P1C@T@206AHC080H5a<0P1<A5@205Y?C080Bde>0P1M
HdX2065MBP80NUmA0P2;OE`206]XJP80NV9W0P1nLfT207a_J080R79]0P1oMW4208=cL080P75d0P1m
Kg8208I`K`@0Pfmc0P1nLWD208=dK`80P75d0P23LW4207e/M080QW1_0P21JW<@0?ooo`003P3oool2
08AXL@80QVea0P20LG@207iYL080PFAa0P26LFl207a`LP80PgA_0P20M782085]L@80PFYc0P26L6l2
08=_L`80OfMc0P28K742085ZL`80PG1c0P1kKg42089]K`80OVaa0P28LFh208=_L`80OFad0P24Jfl2
08=VL@80OfMc0P21Jfl207YSL@80G55a0P1EBf4204e1D`<0@3M:0P15>3h203`d?@80>C4e0P15?cT2
02/[<P80>2d_0P0D41/202hR8@808R0Q0P0T81l2024K7P80<blV0P2CLQ`206aWF080HW5L0P1YK5T2
069XH@80HViM0P1PKeh205eTFP80HF1K0P1QHUT205iKF080GUUH0P1OFeH205QJE`80D5aE0P1;Fe02
04E1A@80Bc]50P1<?D4204hl@P80CCa20P1:>442050f?`80D3=10P1B?DD204/n@`80BSQ10P1:?4<2
04@i?P80?c<l0P13=3P205@m>`80:1lf0P0_92h2044f;080>BX`0P0X7Bd2024H8@809Q`P0P12?RX2
02LV:080A34]0P1EA3D204To@@80@SU00P13<ST204Dg?P80Gd`i0P1QCDT206MFCP80EU]I0`1CHU82
04E?C`80DDe70P16>D@204L/?P80OE0o0P1PDE@204Y3E080FTI80P1OEe02061KC@80JF9F0P22SE@2
07ejG`80LfQc0P1fLfT2089bI`80O6m`0P25L6/208I]L@80PFYc0P26KG42081aM080Pg9a0P23Kg<2
085ZL`80QVea1P23Kg<2081aM080PFea0P1oIg<@0?ooo`003P3oool208AXL@80QVea0P20LG@207iY
L080PFAa0P26LFl207a`LP80PgA_0P20M782085]L@80PFYc0P26L6l208=_L`80OfMc0P28K742085Z
L`80PG1c0P1kKg42089]K`80OVaa0P28LFh208=_L`80OFad0P24Jfl208=VL@80OfMc0P21Jfl207YS
L@80G55a0P1EBf4204e1D`<0@3M:0P15>3h203`d?@80>C4e0P15?cT202/[<P80>2d_0P0D41/202hR
8@808R0Q0P0T81l2024K7P80<blV0P2CLQ`206aWF080HW5L0P1YK5T2069XH@80HViM0P1PKeh205eT
FP80HF1K0P1QHUT205iKF080GUUH0P1OFeH205QJE`80D5aE0P1;Fe0204E1A@80Bc]50P1<?D4204hl
@P80CCa20P1:>442050f?`80D3=10P1B?DD204/n@`80BSQ10P1:?4<204@i?P80?c<l0P13=3P205@m
>`80:1lf0P0_92h2044f;080>BX`0P0X7Bd2024H8@809Q`P0P12?RX202LV:080A34]0P1EA3D204To
@@80@SU00P13<ST204Dg?P80Gd`i0P1QCDT206MFCP80EU]I0`1CHU8204E?C`80DDe70P16>D@204L/
?P80OE0o0P1PDE@204Y3E080FTI80P1OEe02061KC@80JF9F0P22SE@207ejG`80LfQc0P1fLfT2089b
I`80O6m`0P25L6/208I]L@80PFYc0P26KG42081aM080Pg9a0P23Kg<2085ZL`80QVea1P23Kg<2081a
M080PFea0P1oIg<@0?ooo`003P3oool208AXL@80QVea0P20LG@207iYL080PFAa0P26LFl207a`LP80
PgA_0P20M782085]L@80PFYc0P26L6l208=_L`80OfMc0P28K742085ZL`80PG1c0P1kKg42089]K`80
OVaa0P28LFh208=_L`80OFad0P24Jfl208=VL@80OfMc0P21Jfl207YSL@80G55a0P1EBf4204e1D`<0
@3M:0P15>3h203`d?@80>C4e0P15?cT202/[<P80>2d_0P0D41/202hR8@808R0Q0P0T81l2024K7P80
<blV0P2CLQ`206aWF080HW5L0P1YK5T2069XH@80HViM0P1PKeh205eTFP80HF1K0P1QHUT205iKF080
GUUH0P1OFeH205QJE`80D5aE0P1;Fe0204E1A@80Bc]50P1<?D4204hl@P80CCa20P1:>442050f?`80
D3=10P1B?DD204/n@`80BSQ10P1:?4<204@i?P80?c<l0P13=3P205@m>`80:1lf0P0_92h2044f;080
>BX`0P0X7Bd2024H8@809Q`P0P12?RX202LV:080A34]0P1EA3D204To@@80@SU00P13<ST204Dg?P80
Gd`i0P1QCDT206MFCP80EU]I0`1CHU8204E?C`80DDe70P16>D@204L/?P80OE0o0P1PDE@204Y3E080
FTI80P1OEe02061KC@80JF9F0P22SE@207ejG`80LfQc0P1fLfT2089bI`80O6m`0P25L6/208I]L@80
PFYc0P26KG42081aM080Pg9a0P23Kg<2085ZL`80QVea1P23Kg<2081aM080PFea0P1oIg<@0?ooo`00
3P3oool2081dLP80PFea0P24J742081aM080OGQa0P23MFl207e/M080QW1_0P23Kg<2081aM080P7Ab
0P23LW4208=_L`80O6ee0P26LVh2081aM080PFea0P22L7<2081eL@80NV]b0P29L6d2085ZL`80Pfmc
0P1lKG8207m[L@80PFm_0P1oKg0206YCL080H49Y0P1E?e/204`lD@<0@SU70P12>3h203@X=@80?Rde
0P0l:Bl203T^>080:B<Y0P0G5B4202lX7P809b@U0P0S8202020L7P80F5PX0P27Sb/206e[F080MFeP
0P1XIF@206iRH@80K5mQ0P1^GV0206UUH`80IFUO0P1WJ5h205eNG`80HeiJ0P1RG5T205mGF@80GEEG
0P1GE5H204UHEP80AeQ:0P12@d@204Hg?P80CCTo0P1:?T4204U1@080BT910P15=3`204hf@080BSi1
0P18?Cl204<h@080?SHk0P0j;SD2050g=P80:RXk0P0g>S0204E8<`809B8]0P0V6bH2020J8080;BTS
0P1=@bP2028T<080A3HZ0P1<=c<2050l?`80?S@n0P0o=3X204Pl>@80F4<l0P1L@4@2071AB`80HU=E
0`1NDEH204m<EP80CdY;0P0m=DH204e:@`80J5Pk0P1O@e0205A9E080EU=<0P1_J4`2059;E@80NUU?
0P2JMU8207APK`80N5MY0P27IVP207iXJ`80R79]0P1mL74208I`K`80O6Ud0P26JVl208=VL@80QVMa
0P24J74208=_L`80Pg9a0P21JW<208I]L@@0Pfmc0P20LG@207ieLQ00oooo000>0?ooo`80P7Ab0P21
KG4208AXL@80P75d0P1mN74208=eK`80OFad0P26L6l208=_L`80P75d0P20M78208=bL@80Pfmc0P1l
KGD208IbKP80P75d0P21KG42089`L`80P7Ea0P1jJg8208U`K@80PFYc0P23Kg<207a]LP80Of]a0P21
Kfl207m_L080JU=`0P1P@VT205DoF`80C3aA0`12>DL2048h?P80=2Pe0P0n;CD203`Y;`80>Bhh0P0Y
8bT201LE8@80;bPN0P0W92D202<P808081`N0P1HF2P208N?:`80KF]H0P1eKF0206QUI080KV9Q0P1/
Gf4206iNH080JFES0P1UJEl206MXGP80GEiO0P1SGUX2069LF@80GeMI0P1MEEL205MDEP80BEQF0P17
F4X20493A080ASLn0P1=>Cl204Xn@@80BD500P1:@T4204Dd?080CSI00P1:?T4204Pm?`80@cQ00P0n
=S/203X^=@80D3Lf0P0Z:S/203Lj<080ADPc0P0U8Rd202HK9P8081XP0P0]:B<204e3:0808R@`0P14
=RX204`g<`80D3`o0P0n=3h203ld>P80B3`i0P1H@c`205a0A080L55;0P1RDeD305iAEP80CdaF0P1?
BT/203deAP80CDY30P1XF3/205m3D080E4UD0P1FDd`206mXC080DT]E0P1jFDl209YfDP80M61_0P1h
EfT208MVJ080OVQ[0P28LVd207e`L@80QW1_0P1lJG@208IZK`80PfIa0P26Ig4208AXL@80Pfmc0P23
LW42085ZL`80QVea1023Kg<2081aM080OWEb403oool000h0oooo0P24J74208=_L`80O6eb0P28L6l2
085ZL`80PfIa0P24KW8207mZL080R6aa1P23Kg<2085ZL`80P6Qc0P28L6l4085ZL`80QW1_0P21JW<2
07i/M080QW=]0P1mK7@208=YK`80P6Mb0P20K702089^K`80PFea0P1NF7D205A8HP80CceD0P1=?D`3
03ld@`80@C8l0P0j>3d203Lf<`80=2db0P0n<c4201PC8@8091dR0P0_:b8202<N8P8091dQ0P1=I302
06^_:P80LXY70P1aKV<2079UH@80LVEX0P1ZHV@207=[H`80J6ET0P1bIF4206]QI080K5iQ0P1WH6<2
06QWGP80H5aN0P1SG5`205eHF@80GUQH0P1GE5H205EGE080AeUC0P13Fd/203`o@080BCHl1019=Cd2
04To@P80A3`l0P1<>ch204Dg?`80?Rlk0P10<3T2030T<@80=1XW0P1==ST2034a<P80FDXf0P0I7Bl2
024I7`80614G0P0S51P205Pf9`80=Cln0P0`<B`204`g<`80FDhl0P0e=T02051>?P80?D4m0P1EACd2
05eDAP80JEa80P1YH5H3061VFP80DEYJ0P0j;TL2058oA`80D4]00P1NB4@205@lBP80HDQ;0P1PF502
06QCC@80F4YK0P2:RD/207]dG080LU=]0P1nK6P2085jI@80O7A_0P26MV/2081aM080P6]`0P23Kg<2
081fL@80OWEb0P20MW4207e_LP80Q6]_0P26KG42081aM080Pg9a0P23Kg<2085ZL`80QVea0P23Kg<@
0?ooo`003P3oool208AXL@80Pfmc0P1lKG8208Q`K`80PFYc0P23IW4208A^LP80OfY`0P28K74608=_
L`80PFYc0P20J7<208Q`K`@0PFYc0P26L6l2085ZL`80OVad0P26Lfd207e/M080PfU_0P20Ig82081/
L080PVi_0P21KG4205iHM@80E4QR0P1??E@204dmC0<0?cA30P11<S`203Xh?@80=cHc0P0d;C8203hc
<@8061<Q0P0T7B8202l[8P808ahR0P0T7B4204eT<080JjlZ0P1bRTL2075^H`80LVEQ0P1bIFP206YR
I080Lf]S0P1XIF@2079UH@80Jf5T0P1/GV4206MPH`80J6MN0P1PG5h206=LG080GEQI0P1NF5P205MD
EP80EEMD0P17FE<204=KB`80?3m00P19=S`404Te?@80BCm20P14?3`204`k?P80ACLo0P0n;c/2040`
>@80<2@a0P0d6RL204df>@80<C4b0P1IBSH201TM;`808ATO0P0H4AL202<D6080F3HW0P0e?ch2030a
;080C3Lc0P1ICS`203Df@080D4hn0P0m@Cd205E5?@80GEA60P1YG4P206UPEP<0H6IJ0P1AFUX203X^
A`80DSm70P1@Bd0205i8A080E3a:0P1QB4/2061HD080J5==0P1HBU/208Z9B`80NgAL0P1bDfd207i/
J080PGYU0P1lM6l208IfJ`80P75d0P20Jg0208=_L`80P7Ia0P1nMG82081fL@80OFmb0P24Jfl208I]
L@80P75d0P23LW4208=_L`80PFYc0P26KG4208=_La00oooo000>0?ooo`80P7Ab0P21KG42089`L`80
Pg=`0P20LG@207meLP80Pg=`0P1jJW@208I/KP80PfIa0P28KG4208=_L`80P75d0P1kKG8208E/KP80
Pfmc0P1mKg8208A[K`80PFYc0P21KG4208I`K`80P75d0P1nMG8207ifL@80Nfia0P1mI6l207U@K@80
JDY_0P1<?F020550D@80ACM60`0l;3l203PV=080@B/c0P0k;cH203@]<P80<2<Z0P0H4b42030[8@80
;BTU0P0Q7R<206fW:`80ClLf0P1/QD/207ATH080NFES0P1bIFP207EUI080L6IY0P1eJ68206YLJ080
LeeQ0P1`G6@2071UH`80JF1R0P1^GF0206MPH`80IfIN0P1NH5l205aEF@80GU=H0P1OFUD205EFEP80
DE5B0P13DU4203Pm@080@S<j0P13<cT204`g>P80@C4m0P18=CT2048a>`80?C8j0P0k<3D202LO;@80
:R0W0P1SD2X2024P<@80Kd`^0P0Q=DD201/S90809RdU0P0D5QH203dQ6`80Fcdf0P0R8S42050i;P80
EShh0P0k<D<205U6>@80AdE80P1>BD0205m8@`80IDI:0P1iF50306YJF`80EdeM0P0hAUP204M2?@80
ED130P1IB4D20557B`80IEa80P1QF50205mAE080If9F0P2>M4`207EIJ`80M6EZ0P24Mf82081^J`80
QW9_0P20Jg0208Q]L@80O6ad0P26LVh208=_L`80PFYc0P24J74208=_L`80OFmb0P24Jfl208I]L@@0
Pfmc0P20LG@208=bL@80Pfmc403oool000h0oooo0P20M782085]L@80PW1c0P23Lg02081aM080OgEb
0P23Lg0207YZM080QVa^0P23IW4208Q]L@80Pfmc0P20LG@207]]LP80QFa^0P23Kg<207e_LP80Q6]_
0P21JW<2085]L@80QW1_0P20LG@207ieLP80OWIa0P1kKW4207eTK`80NE1]0P1YBVl204`mH080DD1A
0P15=dH303`/?`80>2Hd0P11:c<203/_=P80=2db0P0`8bX201PC8@80<2/Q0P0]:BD2024N8`80KJL[
0P1?acH206b5B`80M6AP0P1iIF<2079UJ080MFET0P1`IVT207EXHP80JUaX0P1cGF42071LI080L6ES
0P1YH68206iMH080If1S0P1WIUh205iPG`80G5EI0P1NDeP205mJE@80EEIF0P1ADE8204=BD@80>3e0
0P12<cX204<c>@80C3Lj0P11<Cd204Pe>@80@S4k0P0m<SX203/`=@809al]0P0Z82L206=@:P808B0a
0P1_C2h2024eA@806b<T0P0V;BD201@F5P80?B4K0P1K?CH2028R<@80D3T^0P1F?SP203/a@`80FDHi
0P17ADP204i9@080GdQ30P1UATX207UHD0<0JUYK0P1GCEd203Q6F080Ad8m0P1E@4<205U8A@80DDM;
0P1UG4P2065HD080Ge5D0P1WHUH208idC080MEU[0P1dIFX208AgHP80P6i[0P26LVl2081[L080R6ea
0P1lK7@208IbKP80Pfmc0P21JW<208AXL@80Pfmc0P1mKg8208A[K`80QVea1023Kg<2081aM080Pg9a
0P23Kg<@0?ooo`003P3oool208=_L`80P75d0P23LW4208=_L`80OfMc0P28K74208=_L`80OW9e0P20
MW4207meLP80Pg=`0P23Kg<207mWL`80PFYb0P20K70208Q`K`80P75d0P1mKg8208=bL@80P7Ab0P23
LW4408=_L`80PFYc0P1mIW<207UWL080IEI^0P1UCF<204HjG080D3e:0P13>4L303Xf?P80=38g0P0k
=38403H/<@808AXU0P0O6R4202lV7`809Q/Q0P1:DS8209ZK6P80M6IP0P1/FV@207MPH@80MUmS0P1i
HVD207ATI`80MFAV0P1dI6L206iVJ080L6aU0P1ZHV@207=MH@80K5YT0P1^GV4206iNH080JEIO0P1V
D5l206AKGP80GUiI0P1PEeL205iEF080EeAF0P1ADE8203a8C`80BEe50P0a>S`2048a=P80@S<j0P10
<cL2040a>080>Rhe0P0c9C0202/T;P809b<U0P1VARL202loB080Dd`]0P0k=dH201HJ9`806a0F0P0Z
8bD203a59P80ETh]0P0fDD/2045H=P80BTDm0P17B4D2044f>@80G4510P1=ATH205Q9A080Gde:0P1_
CdX307=CF080GeeP0P0l@ED2040eA080F4@o0P1=>D8205a3AP80L5i80P1THeL205YKF080ITmB0P26
De<208AYI@80NWiX0P1nN6T207maK`80QW=]0P1lK7@208IbKP80OFad0P26L6l4085ZL`@0Pg9a0P20
LG@2081dLP80PFea0P26KG4408=_L`80PFYc0P26KG4@0?ooo`003P3oool208=_L`80P75d0P23LW42
08=_L`80OfMc0P28K74208=_L`80OW9e0P20MW4207meLP80Pg=`0P23Kg<207mWL`80PFYb0P20K702
08Q`K`80P75d0P1mKg8208=bL@80P7Ab0P23LW4408=_L`80PFYc0P1mIW<207UWL080IEI^0P1UCF<2
04HjG080D3e:0P13>4L303Xf?P80=38g0P0k=38403H/<@808AXU0P0O6R4202lV7`809Q/Q0P1:DS82
09ZK6P80M6IP0P1/FV@207MPH@80MUmS0P1iHVD207ATI`80MFAV0P1dI6L206iVJ080L6aU0P1ZHV@2
07=MH@80K5YT0P1^GV4206iNH080JEIO0P1VD5l206AKGP80GUiI0P1PEeL205iEF080EeAF0P1ADE82
03a8C`80BEe50P0a>S`2048a=P80@S<j0P10<cL2040a>080>Rhe0P0c9C0202/T;P809b<U0P1VARL2
02loB080Dd`]0P0k=dH201HJ9`806a0F0P0Z8bD203a59P80ETh]0P0fDD/2045H=P80BTDm0P17B4D2
044f>@80G4510P1=ATH205Q9A080Gde:0P1_CdX307=CF080GeeP0P0l@ED2040eA080F4@o0P1=>D82
05a3AP80L5i80P1THeL205YKF080ITmB0P26De<208AYI@80NWiX0P1nN6T207maK`80QW=]0P1lK7@2
08IbKP80OFad0P26L6l4085ZL`@0Pg9a0P20LG@2081dLP80PFea0P26KG4408=_L`80PFYc0P26KG4@
0?ooo`003P3oool208AUL@80R6aa0P21JW<208I]L@80OW9e0P23M6l2081XL`80R6ea0P21JW<208AX
L@80QVea0P21JW<207m[L`80PFm_0P1nK74208QaKP@0PFYc0P23JFl208Q]L@80Pfmc0P1nIW<208U/
L080O6Ud0P1mJG4207ANK`80IUE^0P1HAf0204TmF080C4990P10=T<303``?080<2@a0P0k:Bl2030S
;@80>R`^0P0F4Qh202LN7`80:b@Q0P0d=B`208BM8`80LX950P1gH64206eTIP80LVEQ0P1bHF@207UU
H`80L5UV0P1lH6@2071IIP80MEIT0P1lHF@206YLJ080L5mR0P1/GF8206iLH080KeeP0P1YH68206EV
H080HUUK0P1VEE`2069HF`80GUAH0P1NE5L205MDEP80C5AD0P1ACdT203a8C`80<CDi0P12<cD203hc
=`80=b/c0P0m;c@202XT;P80;B<Y0P0L51d205/b8`80GeM30P0W93<206Q9?0806ca30P0ZES@201XS
7P80CCHX0P0f82/206Pk>P80>R`n0P1C>Cd204dm@080B4U80P1=Ac`205M8A`80B3Q30P1aDdH205E4
C@<0OeM=0P1`JEd203@oG@80?CM40P1HAcd204e8B080FeA40P1UBdL206i5D@80HdUH0P1YGUP207ak
E080PGIN0P21IfX208EZKP80P6U_0P27JVh208=_L`80PFea0P23Kg<208=bL@80OFad0P21KG4208I`
K`80PFYc0P24J74208I]L@80OFad0P24Jfl208I]L@80PFYc0P23Kg<208=bLA00oooo000>0?ooo`80
Q6Ea0P28K742085ZL`80QVea0P1nLWD208=dK`80P6Qc0P28KG42085ZL`80Q6Qa0P26KG42085ZL`80
Of]c0P21Kfl207i/L@80R75^1021JW<208=YK`80R6ea0P23Kg<207iVL`80RFa`0P1lJG@207eYL@80
M5i_0P1VEFh205Q7H080BCeH0P1<@TT2040f@`<0?30l0P0`934203/Y;`80<2<]0P0j;2h201HB7P80
9ahO0P0[924203@e;080Q9dS0P1bPTD207MPH@80KFAV0P1bIF42079QI080NFES0P1`FFH207aPI080
L5UV0P1eEV@207aQI080JUaX0P1`Gf8206aMHP80KUaP0P1_GF0206UPHP80IFIP0P1RFE/206IEG080
HUQK0P1NE5P205iDE`80EeAF0P1<E5@2055?B@80?4Q?0P0a=CT2048c=@80?S<g0P0g:c<203d_=080
:R@^0P0]8bT201`D7@80Fc8S0P1OEd<202LT<`80J4Tl0P0K?4<202YF=0806R<N0P1==RP203HP:`80
J3/j0P0j;3h205<i?@80CCe00P18BDP204e7?080EdQ70P18>4<2075CAP80EDA=0`1oEdd2071YG@80
=3mM0P0m=d@205Q7?@80CDQ80P1KE4@206E;A`80KTEA0P1SBEP206UNF080O7]D0P21MUh2085WJP80
QFY^0P20JFl208MZKP80Pfmc0P21KG4208=_L`80Pg9a0P1mK7@2085]L@80QW1_0P21JW<208AXL@80
QVea0P1mK7@208A[K`80QVea0P21JW<208=_L`80Pg9a403oool000h0oooo0P1oKg0208IbKP80OFad
0P26L6l408=_L`80O6ad0P24K6h208=_L`80P7Ab0P23LW42081aM080OFmb0P21KG42089cL@80PFi`
0P23Kg<2081dLP80OgEb0P23Lg0208=_L`80OG9e0P21L6l207YQL`80Of=^0P1ZDfl206eGI`80BSmO
0P1=?50204<`@`80AC=10`0f;CP2038/=080=S0^0P0^:Bh202HJ8P807QLS0P0`;b82038f:@80L:D]
0P1^UcP2075RH080M6AP101bHF@2071LI080MeYQ0P1]EVH207IGG`80L5EU0P1`FV4207IGG`80L5AU
0P1ZCel206i=GP80L59M0P1cFUh206UDG`80KeAN0P1SDV0206IGFP80HDiI0P1SDEP2065DEP80GUEG
0P1GE5H2055@DP80C4e>0P0lE4h202lh>080=2@_0P0n;c@2030U;080;b@]0P0S72<2028M8`80?bdP
0P1`?c02034nD@80AcT]0P1DCdd2028V;`80@4Lo0P0`?2X203Xg=`80CSd]0P17?DD2040h=`80DS/n
0P1DAD4203TX?080I3/l0P1:@dX206QB?`80EDUD0`1_DTL207=2E080EEYY0P0cDe02048f>`80G3e1
0P1OC4H205E3B`80Je5;0P1YHED207AgEP80PX=K0P1cIfT208E[JP80PG1/0P1mJW0208IcKP80PFea
0P21JW<208I`K`80PFYc0P23Kg<2081dLP80PFea0P23Kg<207e_LP80QW1_0P20LG@2081dLP80PFea
0P23Kg<208=bL@80Pfmc403oool000h0oooo0P1oKg0208IbKP80OFad0P26L6l408=_L`80O6ad0P24
K6h208=_L`80P7Ab0P23LW42081aM080OFmb0P21KG42089cL@80PFi`0P23Kg<2081dLP80OgEb0P23
Lg0208=_L`80OG9e0P21L6l207YQL`80Of=^0P1ZDfl206eGI`80BSmO0P1=?50204<`@`80AC=10`0f
;CP2038/=080=S0^0P0^:Bh202HJ8P807QLS0P0`;b82038f:@80L:D]0P1^UcP2075RH080M6AP101b
HF@2071LI080MeYQ0P1]EVH207IGG`80L5EU0P1`FV4207IGG`80L5AU0P1ZCel206i=GP80L59M0P1c
FUh206UDG`80KeAN0P1SDV0206IGFP80HDiI0P1SDEP2065DEP80GUEG0P1GE5H2055@DP80C4e>0P0l
E4h202lh>080=2@_0P0n;c@2030U;080;b@]0P0S72<2028M8`80?bdP0P1`?c02034nD@80AcT]0P1D
Cdd2028V;`80@4Lo0P0`?2X203Xg=`80CSd]0P17?DD2040h=`80DS/n0P1DAD4203TX?080I3/l0P1:
@dX206QB?`80EDUD0`1_DTL207=2E080EEYY0P0cDe02048f>`80G3e10P1OC4H205E3B`80Je5;0P1Y
HED207AgEP80PX=K0P1cIfT208E[JP80PG1/0P1mJW0208IcKP80PFea0P21JW<208I`K`80PFYc0P23
Kg<2081dLP80PFea0P23Kg<207e_LP80QW1_0P20LG@2081dLP80PFea0P23Kg<208=bL@80Pfmc403o
ool000h0oooo0P20M78208=bL@80OFad0P26L6l408=_L`80OFad0P23LW42085]L@H0Q6Qa0P23Kg<2
081dLP80PFea0P23Kg<2085]L@80PfIa0P24IG4208IWL@80Q6Qa0P26KG42081aM080LfQd0P1dFF/2
06aEK080HTQP0P1:=U`204LdA`80@C=20P0k;3L303HW=@80=R`a0P0f;Rl201hD8@809QTR0P0P71h2
02HJ7080Q9DZ0P1_VCL2079UH@80Kf=Q0P1`FV4207=FHP80MEYR0P1^FF<206eCH080JT]O0P1[AU/2
06i5FP80K49I101^@ET206E0FP80JdQF0P1YBEH206i5EP80JDAJ0P1_CeP206IBG080IUII0P1RFE/2
069MF080GU=H0P1RDUH205a?EP80EdeD0P1DD502059CCP80>E=B0P0]BCl2038b<080;RL_0P0^9bX2
02DS9`808b0P0P0b9B8204l[:080HTI30P0mDdT204`m=`80@eUF0P0mFSL203Y5A@809b<[0P1?<382
05I7>`80?dA50P1;AS`204@^>`80AC]40P1>A3L2065BAP80E4]70P1OBD`306IDCP80Jf9E0P1/JEP2
03LnG080B55;0P1FHd82059<B080DCm;0P1^E4L207=MDP80SX1G0P1eJFH2085`K`80O7IY0P21KFh2
07eZL080RG9/0P20LG@207e_LP80QW1_0P1lJG@208IZK`80QVea0P1mK7@208A[K`80Pfmc0P23LW44
08=_L`80P75d0P23LW4208=_L`80PFYc403oool000h0oooo0P20M78208=bL@80OFad0P26L6l408=_
L`80OFad0P23LW42085]L@H0Q6Qa0P23Kg<2081dLP80PFea0P23Kg<2085]L@80PfIa0P24IG4208IW
L@80Q6Qa0P26KG42081aM080LfQd0P1dFF/206aEK080HTQP0P1:=U`204LdA`80@C=20P0k;3L303HW
=@80=R`a0P0f;Rl201hD8@809QTR0P0P71h202HJ7080Q9DZ0P1_VCL2079UH@80Kf=Q0P1`FV4207=F
HP80MEYR0P1^FF<206eCH080JT]O0P1[AU/206i5FP80K49I101^@ET206E0FP80JdQF0P1YBEH206i5
EP80JDAJ0P1_CeP206IBG080IUII0P1RFE/2069MF080GU=H0P1RDUH205a?EP80EdeD0P1DD502059C
CP80>E=B0P0]BCl2038b<080;RL_0P0^9bX202DS9`808b0P0P0b9B8204l[:080HTI30P0mDdT204`m
=`80@eUF0P0mFSL203Y5A@809b<[0P1?<38205I7>`80?dA50P1;AS`204@^>`80AC]40P1>A3L2065B
AP80E4]70P1OBD`306IDCP80Jf9E0P1/JEP203LnG080B55;0P1FHd82059<B080DCm;0P1^E4L207=M
DP80SX1G0P1eJFH2085`K`80O7IY0P21KFh207eZL080RG9/0P20LG@207e_LP80QW1_0P1lJG@208IZ
K`80QVea0P1mK7@208A[K`80Pfmc0P23LW4408=_L`80P75d0P23LW4208=_L`80PFYc403oool000h0
oooo0P23Kg<2085ZL`80Pfmc0P23LW4208=_L`80PFYc0P23Kg<208=bL@80P75d0P20M78207e_LP@0
Pg9a0P23Kg<2081aM080Pg9a0P1mK7@207m^L@80Ofm`0P23M6l2081dLP80PFea0P24J74207ITM@80
JUi_0P1[FfH205E9H`80BD5F0P0m=DH204@h?P80=cDk0`0/9Rl203X/;P80<BL]0P0K6B@202HP7P80
;B`V0P1O/Rh207>c9`80KVAR0P1dI64206mOI@80JeaS0P1^GF02071KH080JU=Q0P1TBUh206I<FP80
GdUH0P1PA5<205dnD@@0H3e?0P1N?e020610C@80J4QA0P1NAU<206E:DP80JDmC0P1SAeH206iBEP80
IUII0P1VEeX205eBFP80HE=F0P1LCeH205Y@E080EdeA0P1EADd205=6CP80@4M<0P0Y;ST202XR:P80
;R<X0P0S72<201/C6P80:a/M0P16<BP206eA<P80@3550P0g8CP207mB=`80?3a>0P1CDDD202Y>B`80
=Sd_0P1=<3@205U4@`80A4930P0n>d42059=?080@d110P1YDSh204m5C`80IEU:0`1IC4h206m9CP80
O5QG0P13E6L204mJC080F4i:0P1DBdl205=DC@80IUa80P1cGU8209M_D`80MVMb0P26LfH207eYL@80
PVm^0P20MG42085`K`80QVea0P20LG@207mZL080Pfmc0P20MW4208=bL@80OFad1023LW42085ZL`80
QVea2023Kg<2081aM100oooo000>0?ooo`80Pfmc0P21JW<208=_L`80Pg9a0P23Kg<2085ZL`80Pfmc
0P23LW42081aM080P7Ab0P1mKg8408=bL@80Pfmc0P20LG@208=bL@80OFad0P1oKW4207m_L080PgA_
0P20M782085]L@80Q6Qa0P1fI7D206YNK`80Je]V0P1EBF<204U1EP80?CE60P14>3h203Le>`<0;2H_
0P0j;2h2034W;@806aTT0P0V81h202d/9P80Gk8^0P1c/bL206iTHP80M6AQ0P1_GfD206]LH`80KUeP
0P1`Ff0206YCH@80I4YN0P1VC5X205m9F080H4AC0P1M?U44060mC`80GSm@0P1P@4d206Q8D@80GTIC
0P1UBU8206U?D`80HdMF0P1^DUH206IFF@80IUMJ0P1MDUX2065CEP80G4mF0P1JD5@205M=D@80EDE=
0P1CATh20417C080:Bhi0P0Z8RX202hS:0808a`S0P0K4aX202/K7@80AS4X0P1]DC82040aA@80=b4h
0P1oDSL203`lCP80De550P0ZCT/203Hm;`80CC0d0P1IA4<204A2@`80?S]10P1BCC`204=0@@80JE8n
0P1?ADl206EIBP<0FDa>0P1_BDh207aHE`80@eAW0P1?FT`205Q>BP80E4]?0P1CE4d206ILB080LeiB
0P2GKe<207IWLP80QW=V0P1mJG42089_KP80P7Ea0P21L6l208I]L@80P75d0P1oJW0208=_L`80P7Ia
0P23LW4207e/M0@0Pg9a0P21JW<208I]L@P0Pfmc0P20LG@@0?ooo`003P3oool208=_L`80OFad0P26
L6l208=_L`80PFYc0P23Kg<208=bL@H0Pfmc0P1mK7@208I`K`P0Pfmc0P20LG@207e_LP80P6]`0P24
JFl208Q]L@80OFad0P1nJG02075FL080L5=[0P1^FfD204XoG`80ABm<0P12<D@203//=`80@30h0`0[
:382030U:0809QPT0P0S6b<202HR8080<2PS0P2gNQL2075NG`80LEUQ0P1cF642075GHP80KU]R0P1^
G60206QBG`80CRUC0P1H7DP206HYB080G2m<0P1M>D/205LnC0H0Ed5:0P1;<4D205PY@080ERE40P1H
9T42078lB080IU1D0P1VDe8206]DF080IUII0P1RF5/405iEE`80FU9D0P1FC58205I?D080DDY<0P19
@DX203Y<C0807BX`0P0T7282024I80805Q8G0P0V71X203hZ8`80GC<]0P1JD4`2031DB@80GDhc0P1K
EU@204]EB080CUI@0P0jGTd203aA?`80BSXh0P1B?DD204Q;A@80@3<j0P1;<3l20610?080GTY=0P1E
?DH306]>D080GeQ@0P1fFU02061KHP80BTaG0P1PEe0204e8CP80GdY;0P1`Hdh2071/EP80PVEH0P25
IFP208=/JP80O6E_0P24J6`208IXKP80Q6ib0P1oJW0208IWL@80PG1c0P21Kfl208I]L@80Pfmc0P20
LG@2085]L@80QVea0P20LG@2085]L@80QVea0P23Kg<2085ZL`80QVea0P23Kg<@0?ooo`003P3oool2
08=_L`80OFad0P26L6l208=_L`80PFYc0P23Kg<208=bL@H0Pfmc0P1mK7@208I`K`P0Pfmc0P20LG@2
07e_LP80P6]`0P24JFl208Q]L@80OFad0P1nJG02075FL080L5=[0P1^FfD204XoG`80ABm<0P12<D@2
03//=`80@30h0`0[:382030U:0809QPT0P0S6b<202HR8080<2PS0P2gNQL2075NG`80LEUQ0P1cF642
075GHP80KU]R0P1^G60206QBG`80CRUC0P1H7DP206HYB080G2m<0P1M>D/205LnC0H0Ed5:0P1;<4D2
05PY@080ERE40P1H9T42078lB080IU1D0P1VDe8206]DF080IUII0P1RF5/405iEE`80FU9D0P1FC582
05I?D080DDY<0P19@DX203Y<C0807BX`0P0T7282024I80805Q8G0P0V71X203hZ8`80GC<]0P1JD4`2
031DB@80GDhc0P1KEU@204]EB080CUI@0P0jGTd203aA?`80BSXh0P1B?DD204Q;A@80@3<j0P1;<3l2
0610?080GTY=0P1E?DH306]>D080GeQ@0P1fFU02061KHP80BTaG0P1PEe0204e8CP80GdY;0P1`Hdh2
071/EP80PVEH0P25IFP208=/JP80O6E_0P24J6`208IXKP80Q6ib0P1oJW0208IWL@80PG1c0P21Kfl2
08I]L@80Pfmc0P20LG@2085]L@80QVea0P20LG@2085]L@80QVea0P23Kg<2085ZL`80QVea0P23Kg<@
0?ooo`003P3oool208=_L`80OFad0P26L6l2085ZL`80Pfmc0P21KG4208I]L@H0Pfmc0P1mK7@208I`
K`80Pfmc0P21JW<208=VL@80R6ea0P23Kg<207e/M080PW=a0P1oMW42081/L080Q6ib0P1fIg8206eQ
LP80K6EX0P1LAF0204deF`80?SA90P0m<3/203T^>080>2/`0`0[82d2038Z:`808b@W0P0S820202hY
9080L[0[0P1[Xc8406iMH@80KUaP0P1aHV0206]OH@80EcQJ0P1Q:e8204hiEP80BE590P1[R4D204N0
E`80AEY?0P1DD4`205eQCP80FGAB0P12D4l204U<C@80ATm50P18C4@204E4@P80DcHj0P1b?dH206U?
D`80IU5D0P1ZE5P206IGF@80GU9J0P1QDeH205mDEP80EU9E0P1GCU020557C`80CTQ<0P1:A4H20317
B`8072h]0P0H5QX201XF6@806Q<D0P0o:b42020>6P80VDD/0P1@HeL2030_?P80Q4hl0P10<Th206i?
AP80EUaD0P0nBDh204I9A@80EEA10P0j;3d20510A080@THn0P1EB3h205a6A080DDM>0`1UCd@206M>
DP80LUiC0P1]HE`2044oG080EC950P1K>Td205m>B@80KTm:0P2?M5D2079lI@80OgMU0P1nKV`207QW
L080QgI[0P1oMg0207m/L080PFYc0P21Kfl208I`K`80OFad0P26L6l2085ZL`80Q6Qa0P23Kg<208=b
L@80PFYc0P23Kg<208=bL@@0PFYc0P26L6l2085ZLa00oooo000>0?ooo`80Pfmc0P1mK7@208I`K`80
PFYc0P23Kg<2085]L@80QVea1P23Kg<207e/M080QW1_0P23Kg<2085ZL`80PfIa0P28KG4208=_L`80
OFad0P22Lg4207mfL@80P6a`0P24KW8207IWLP80KF5b0P1/IFP205a5H080CCEK0P0n=4T203d`>`80
>Bhh0P0h:c0302/P;@80<RX[0P0S92L202<P8080;RTT0P1b/2/206^S<P@0KUeQ0P1^G602075RH080
JemQ0P1G>5X2064[DP80CSUF0P19DDT206^8A@80Ah1G0P15FTl205A@C080GF5>0P1IM582049@C`80
BDa=0P16CdD204Q<A080ADA20P1C=SX2078oAP80JDmC0P1VDE@206YDF080IUMI0P1NDUX2065CEP80
GeAF0P1FDUD205M>D080DDM?0P1>B4`204Y4AP80<4M;0P0L;Rd201PF6P806QHI0P0J4a@203l[8@80
80hJ0P2IAB`2051SE`80<2ln0P24CS`2040bCP80KTm60P1FG5@203i9CP80ATU50P1EE44203X/?@80
D4140P12ASh205E8?P80G4I40P1AAdh306E?A080IdiB0P1bGU<206eQG080@CmL0P1E<TD205/jC@80
Gdi90P1^CdX208mdE@80LWaU0P1oMfD207i^K080N6M`0P27MV/207mgL080Ofa`0P21JW<2085_K`80
QW1_0P1mK7@208I`K`80PFYc0P24J74208=_L`80Pg9a0P21JW<208=_L`80Pg9a1021JW<208I`K`80
PFYc403oool000h0oooo0P24J74208=_L`80PFea0P23Kg<2085]L@80Pfmc0P21KG4208I]L@80PFYc
0P24J74208=_L`80PFea0P24J742085ZL`80Ofia0P24K6h208AXL@80P6Qc0P28L6l208=_L`80NfYd
0P28LFh206aGM080LTmY0P1T>V4205D^F`80C39=0P12=4D202hS=080>bLa0P0`92d303D_<08071DM
0P0Y624202@M8@80D5D/0P2OT1l206iQI080KVAR0P1[Gf8206eMH080LE]O0P1^FV8203hgG@80ET9:
0P1CAdT20511B080IC0m0P1R7Td205DYCP80G3i80P1A;48205lO@P80B1Y60P1@9cd204`Y?P80Hd]4
0P10@DL204Q0@P80BR`g0P1n@T@206QDE080JEUF0P1VEUT2069HF`80HEeH0P1MEEL205U>EP80Ed]B
0P1FCe0204m;C@80Cde<0P14AdP202e3AP805B@W0P0Q91l200l>4@80;ATG0P0b<Rl206YC7P80IcI8
0P0f=U8206=8<`80FEAG0P1=Ad8207=<C080GGaN0P0cDU0204Tc?`80B41:0P1>CS`203da@080DcPk
0P1OAd<205A7B@<0Gde:0P1PB4`207]IC`80KUMK0P14@f4204Y=C@80F5E60P1EATT206]@B`80WWI8
0P1lJV`208=`J`80NVM_0P1kIVl208edJ080Pfmc0P1nLWD2081fL@80P7Ab0P23LW42081aM080PFea
0P23Kg<2081dLP80Pg9a0P23Kg<2081aM080Pg9a0P23Kg<2081aM080P7Ab0P23LW42081aM100oooo
000>0?ooo`80Q6Qa0P23Kg<2085]L@80Pfmc0P21KG4208=_L`80PFea0P26KG42085ZL`80Q6Qa0P23
Kg<2085]L@80Q6Qa0P21JW<207m^L@80Q6a^0P24J742081XL`80R71_0P23Kg<207]ZM080R75^0P1/
Eg@2079?J@80I3YQ0P1E;U/204`bC@80@SA50P0^8c@203/W<@80<2@]0`0e;c0201`E7@80:APQ0P0T
7B42051E;080Wi0O0P1^HF@206iTHP80JemR0P1]GF02075KG`80KUYR0P0n=ed205I2BP80DdM90P1@
@DP206D`?@80HQi=0P1E:Dh205`nB080DBa20P1O7d8204PJAP80D2Lm0P1<:Ch206=;A080@4570P18
@48204X/=`80OT940P1XE5@206UIEP80IUII0P1RF5/2065MF080GEEG0P1ICUH205M;DP80ETm@0P1?
Bdd204m=C080A4M80P0]@dH201DT9`808B@O0P0?3Q4202dI5`80<S8_0P1ZDah206LfB080=SIB0P1S
B3<205UDE`80CDM20P1cC4`205elGP80<e9@0P19<cl204Q0BP80CThl0P0m<D0205<h>`80GdM30P1D
AdT305m=BP80H4Q<0P1kFDl206iGF`80A4=Q0P1:CDd205QEAP80EDI90P1[D4/209ifB080O6Y/0P23
L6/207YWK`80NfI_0P2=M6P208=_L`80OW9e0P20MW42081dLP80Pg9a0P20LG@2085]L@80Pfmc0P20
M78208=bL@80Pfmc0P20LG@208=bL@80Pfmc0P20LG@2081dLP80Pg9a0P20LG@@0?ooo`003P3oool2
081dLP80Pg9a0P20LG@208=bL@80OFad0P24Jfl208=_L`80PFea0P21JW<2085]L@80QW1_0P1mK7@4
085]L@80Pg9a0P20M78207e_LP80Ofia0P26LVh2085ZL`80Of]c0P24KFh206EIMP80IEAV0P1??el2
04m1DP80?S=50P0k9cT202`Q<P80>Rh]0P0[9B`302@F7`80:1lY0P0P7ad203Pf:080R:HQ0P1aRdH2
075PH`@0KUYR0P1]GF0205PhF@80IRQ@0P1284l203XI<`80AaDc0P1;73L2050/?080@BHi0P168cL2
04lV>080?R4j0P0j7C4202lE:`80?1/Z0P108Bl203D@9080AA0b0P0k5Rh203<E;080E1/Y0P1i:T42
07U?D0@0IUII101RCeP205eEE`80DdeC0P1JC4l205E>D080EU9=0P15@d`2044nA@808S4l0P0@3a@2
014;4@80:b8I0P0d9B0204HS:080JCTj0P1GFdh202lY>@80QDHj0P0m<dl2075:?`80PEA=0P1CKfd2
02mQEP80CeU40P0m<T0204e2A080A4Dm0P1J@ch205E0A`<0Cc920P1aCTX207=RC@80JeUL0P1EGf<2
04QFE080GUe=0P1=D54206aQBP80Tg1;0P25JfX207eWK080OfU_0P1mM6h2089/J`80RFa`0P23Kg<2
085ZL`80QVea0P21JW<208I]L@80P75d0P23LW4:08=_L`80PFYc0P26KG42085ZL`80QVea0P23Kg<@
0?ooo`003P3oool2081dLP80Pg9a0P20LG@208=bL@80OFad0P24Jfl208=_L`80PFea0P21JW<2085]
L@80QW1_0P1mK7@4085]L@80Pg9a0P20M78207e_LP80Ofia0P26LVh2085ZL`80Of]c0P24KFh206EI
MP80IEAV0P1??el204m1DP80?S=50P0k9cT202`Q<P80>Rh]0P0[9B`302@F7`80:1lY0P0P7ad203Pf
:080R:HQ0P1aRdH2075PH`@0KUYR0P1]GF0205PhF@80IRQ@0P1284l203XI<`80AaDc0P1;73L2050/
?080@BHi0P168cL204lV>080?R4j0P0j7C4202lE:`80?1/Z0P108Bl203D@9080AA0b0P0k5Rh203<E
;080E1/Y0P1i:T4207U?D0@0IUII101RCeP205eEE`80DdeC0P1JC4l205E>D080EU9=0P15@d`2044n
A@808S4l0P0@3a@2014;4@80:b8I0P0d9B0204HS:080JCTj0P1GFdh202lY>@80QDHj0P0m<dl2075:
?`80PEA=0P1CKfd202mQEP80CeU40P0m<T0204e2A080A4Dm0P1J@ch205E0A`<0Cc920P1aCTX207=R
C@80JeUL0P1EGf<204QFE080GUe=0P1=D54206aQBP80Tg1;0P25JfX207eWK080OfU_0P1mM6h2089/
J`80RFa`0P23Kg<2085ZL`80QVea0P21JW<208I]L@80P75d0P23LW4:08=_L`80PFYc0P26KG42085Z
L`80QVea0P23Kg<@0?ooo`003P3oool608AXL@80QVea0P20LG@207e_LP80Q6]_0P23Kg<207e_LP80
Pg9a0P21KG4208=_L`80OFmb0P23LW42085]L@80Q6Qa0P21JW<2085]L@80Q6]_0P20J7<2089/L080
O6A`0P1ZFG<205iAI`80B3]J0P19<TL203PU?P80<20`0P0f;342030X:P80;28Z0`0X:2X202/[9080
9bTX0P1n[b<207:O=`80Ke]S0P1dGV8206mTI080JF1R0P1]GF02055OI`80Eh1I0P0cHUP202iBB@80
>58j0P0jACL204Q4>080>S`n0P12Ac/204YF?@80<d8o0P0hA3X2039;>P80=Tld0P0jBCD2031;>`80
Bghf0P0fRDH202nAA`80>iQ10P1CPCl206]VB`80IUII0P1SDET2069BF@80H5=F0P1SEEH205IBF080
ETi@0P1JC4l205U<CP80C4YA0P14B4P2034l@P804QlX0P0>410201D=3P80;1LK0P0o;2L205<f;@80
LdLo0P0fD5X204@f<@80HdA=0P19?Cl208aEA080LEEI0P1JK6/2034iB`80C3i90P1>Bch204@l@`80
EDI00P1A@dD304<jA@80MeXl0P1XCE4207AEF080JV5N0P13@EX206]AB`80DTYE0P20ND/20822E`80
OfeW0P1kIFl207mWJP80Qfa/0P1nKg8208A^K@80Q6Qa0P23Kg<208=bL@80P75d0P23LW42085ZL`80
QVea0P23Kg<2085ZL`80QVea0P23Kg<2085ZL`80Pfmc0P23LW4207e/M080QW1_0P23Kg<@0?ooo`00
3P3oool608AXL@80QVea0P20LG@207e_LP80Q6]_0P23Kg<207e_LP80Pg9a0P21KG4208=_L`80OFmb
0P23LW42085]L@80Q6Qa0P21JW<2085]L@80Q6]_0P20J7<2089/L080O6A`0P1ZFG<205iAI`80B3]J
0P19<TL203PU?P80<20`0P0f;342030X:P80;28Z0`0X:2X202/[90809bTX0P1n[b<207:O=`80Ke]S
0P1dGV8206mTI080JF1R0P1]GF02055OI`80Eh1I0P0cHUP202iBB@80>58j0P0jACL204Q4>080>S`n
0P12Ac/204YF?@80<d8o0P0hA3X2039;>P80=Tld0P0jBCD2031;>`80Bghf0P0fRDH202nAA`80>iQ1
0P1CPCl206]VB`80IUII0P1SDET2069BF@80H5=F0P1SEEH205IBF080ETi@0P1JC4l205U<CP80C4YA
0P14B4P2034l@P804QlX0P0>410201D=3P80;1LK0P0o;2L205<f;@80LdLo0P0fD5X204@f<@80HdA=
0P19?Cl208aEA080LEEI0P1JK6/2034iB`80C3i90P1>Bch204@l@`80EDI00P1A@dD304<jA@80MeXl
0P1XCE4207AEF080JV5N0P13@EX206]AB`80DTYE0P20ND/20822E`80OfeW0P1kIFl207mWJP80Qfa/
0P1nKg8208A^K@80Q6Qa0P23Kg<208=bL@80P75d0P23LW42085ZL`80QVea0P23Kg<2085ZL`80QVea
0P23Kg<2085ZL`80Pfmc0P23LW4207e/M080QW1_0P23Kg<@0?ooo`003P3oool2081dLP80OFmb0P21
KG4208I`K`80PFYc0P23Kg<2081dLP80Pg9a0P1mK7@208I`K`80OFad0P26L6l2081aM080Pg9a0P20
LG@2081dLP80O6eb0P24LW0207e_LP80OFUa0P23Jfl207MULP80IeI^0P1HA6@2048bE080?2Y00P0l
<3`202h`=080<2PZ0P0^92/202PQ9P<0;bDW0P0[92H2034/:P80^h8C0P1_FF<2079OH`80LF9Q0P1`
FF82075NI080JUiR0P1ZIV<206m^G@80DgI/0P16WF8203j^FP80=ZAI0P12XE4204:aEP80>jED0P1<
UU42042PG@80?;UE0P0fZEH203fTD`80>iUC0P0nSe4205b7AP80FVYF0P1MI5L2065QE@80HUiH0P1V
FeH206IGF@80HUQK0P1PEUP2061BE`80He9E0P1LCUL205YCE080ETi@0P1IC4l20597CP80Cd]=0P0j
@DP201h/>0804a/M0P0:2P/2044h7@80;2TT0P109bX205XZ<080GcA50P0a:T4206I0<`80?BY50P1^
=CD208I:D@80LUAI0P0hBVT204]KA@80BTQ70P10=d8204`d>`80F3m20`1?D4X206=E@@80Fce>0P1o
Edd2071NF`80@TEQ0P1OBTP2058iCP80X6m10P22KV<207aXK080O6U/0P1kJF`208YeJ@@0P7Ab0P1m
Kg8208I`K`H0Pfmc0P20LG@208=bL@80PFYc0P23Kg<2085]L@80QVea0P20LG@208=bL@80PFYc0P23
Kg<208=bL@80Pfmc403oool000h0oooo0P20M78207e_LP80PFea0P26L6l2085ZL`80Pfmc0P20M782
08=bL@80OFad0P26L6l207e/M080QW1_0P20LG@208=bL@80P75d0P20M78207a]LP80Q79`0P1mKg82
07eYL@80Pf]_0P1gIG8206MFKP80F4AT0P12<U@203`Z@080?30l0P0^<3@2030X:P80;R@[0P0X8BH3
02lU9`80:b@V0P0a;2X20;^24`80KeUS0P1bGf<2075RH@80L5UR0P1aGV@206YNHP80JVIS0P1_KUd2
05=fK080AYeR0P0n[UX203JTF@80@Z5A0P12/EH203^UE080C9IA0P10X5d203biE@80=ZUF0P0mY5<2
03^ID`80?XmA0P1LQdH205YZEP80GFAG0P1QHED2069NF080IU]F0P1VEeT2069HF`80H5IH0P1PDUL2
06=BE@80G4iG0P1JDe@205I>D080FDa?0P1BAdh204m;C@80>T580P0N;3P201<K7@802PX;0P11>1d2
02`Y9080@2LZ0P1J:S0205ldA@80<BY10P1V@3<203dZA@80KSDe0P26BU42079DF@80>4YY0P1;FdD2
04Y8A`80@3M20P1<=3/205Po@P<0Ce1:0P1SED4205/mCP80OeM=0P1`GU/20495H@80GdY80P1B>Dh2
0:1_@@80PViS0P1lJ6`207aYK080NfU/0P2:MFT4081dLP80OFmb0P26L6l608=_L`80P75d0P23LW42
085ZL`80Pfmc0P21KG4208I]L@80P75d0P23LW42085ZL`80Pfmc0P23LW4208=_La00oooo000>0?oo
o`80Q6Qa0P23Kg<2081dLP80Pg9a0P20LG@208=bL@80PFYc0P26KG42081aM080Pg9a0P1mK7@208I`
K`80PFYc0P24J74208I]L@80Pfmc0P1lK7@208=ZKP80PVUb0P1nKg8207]WK`80JdQ]0P1]AFL2050k
G@80?2a;0P0g:C/203<R;`80=28^0P0^9B/2024H8080<2<V0`0]:2H202TS9P80K8H_0P20Vbh206iR
I080LF=Q0P1_GV<2071TH`80K5iQ0P1bHf<206aOH@80Mf1Q0P1bHF@207UUH`80LEiW0P1aIfP206YY
I080NFYP0P1VFFT206iMH080Le]N0P1fEF0206M8I080KT]L0P1ZCUh206IDG080K5YI0P1TEEd206QL
FP80JVIL0P1OFe`206IFFP80JEaJ0P1SFE/2061DFP80HUEH0P1PE5H205a?EP80Ge1C0P1FBe<205=1
C@80EdA<0P1EB4/203ljB@80:Rdl0P0A4Q/201<C5@80>R/H0P0a:2`204aA<@80?48f0P1UES/202T`
@P80@BH]0P1I@T8204e@?`80NePo0P1`EET205a[H`80B6AI0P11A4d204M5B080BU930P14>cd305@b
?P80EBi10P1P?dT207mRAP80L5iK0P16AV4205mJC`80Ad]A0P2WPST207a_J080MV1/0P22IFX2081a
K@80R7IZ1023Kg<207e/M080QW1_0P23Kg<2085ZL`@0Q6Qa0P26KG42081aM080Pg9a0P20LG@208=b
L@@0Pfmc0P20LG@208=bL@80Pfmc0P21JW<@0?ooo`003P3oool208AXL@80Pfmc0P20M78208=bL@80
P75d0P23LW42085ZL`80QVea0P20LG@208=bL@80OFad0P26L6l2085ZL`80Q6Qa0P26KG4208=_L`80
O6ad0P23JVh2089YLP80OVmb0P1kIfl206]8K@80KDEW0P1@>ed203`/B`80=bTk0P0c8Rl203@R;P80
;RD[0P0Q6202030S9P<0;BPV0P0Y8bH206b6;`80P9/^0P1^HV@2075SH@80KeiS0P1`I6<206aNH@80
LV=S0P1/Gf4207MPH@80LV5T0P1iIF<2075NI`80LFMX0P1ZJF@207UZH080IUUY0P1^GF0207=KGP80
MUEP0P1WB6@206i;G080JTiN0P1VE5`206aJF@80I5EM0P1XG5X206YVG080Ge]L0P1VEUX206ULFP80
HeUK0P1PE5X2069EF080H5AF0P1LCeH205m@D`80ET]C0P1C@Dd205M4C080EDQ;0P0o>TT202X]?080
4A8K0P0C4aD203X[6080<BP/0P1<DC4203a2=P80IEHk0P0Y<482044V;@80FD920P1=D3l207]H?`80
L5EI0P1LJf<204QTF@80@DA=0P17ADP204YB@`80A3/m0`1D<Sh205D^@@80H3m90P1oHTH2071NF`80
ATIQ0P1OFTl204M;D@80Yh8i0P1lKfP207IPK080PVEZ0P20LFd208QfJP@0Pfmc0P1mK7@208I`K`80
Pfmc0P21JW<408AXL@80QVea0P20LG@208=bL@80P75d0P23LW4408=_L`80P75d0P23LW4208=_L`80
PFYc403oool000h0oooo0P21KG4208I`K`80PFYc1P24J74208=_L`80P6]`0P28KG4208=_L`80P75d
0P23LW4207e/M080Pg9a0P21KG4208I]L@80OFad0P1oKW42081/L080PVa`0P1jL7<205QNL`80DSeK
0P189dl203PS@080?S8i0P0X9Bh2030V:@8091XS0P0[9RP202d[90<0;BHW0P0[9bP20;695P80LFeI
0P1_Ff<207ANHP80LF=T0P1`Gf8206iMI080MFAP0P1/HFH207AUH080LV5T0P1fGf<2079NIP80MUmS
0P1bGVH207EMH`80JUQW0P1^GF0406iLH080GeAR0P1YFeX206QOF`80HeUK0P1/FeT206=FG@80L6=J
0P1VE5/206iMH080Ge]M0P1YEUP206=?F`80He9I0P1VFEP205eCF080G4mF0P1KBU8205eAD`80Ce5B
0P1BC4/205E8B`80A4=<0P0`=d0201TV;P806b@N0P0C3@l203lR8`80?b<V0P1393D204dU;`80A2e5
0P0c=SL205U1<@80Bc500P1^@3h207eDC`80KUEJ0P1>>E/205=:E@80ADM80P1B@d@203dgA@<0DTXo
0P10>d0206QB?`80Ke970P1gDUL2051=HP80ED9<0P1JAe8209]`?P80QF=X0P1fJfl207=NJ080U71V
0P21KW0208I]L@80Pfmc0P1mK7@208I`K`80PFYc0P23Kg<4081dLP80Pg9a0P21JW<208I]L@@0Pfmc
0P21JW<208AXL@80QVea1023Kg<2081aM100oooo000>0?ooo`80PFea0P26L6l2085ZL`H0Q6Qa0P23
Kg<2081[L080R6ea0P23Kg<2081aM080Pg9a0P1mK7@208=bL@80PFea0P26KG4207e/M080Ofia0P20
K702089/L080NW1c0P1HGW<2058mF`80B2M?0P0h8d0203hb>@80:2D^0P0`9RT202@J8`80:bHX0P0]
:b@302dV9`80:bLX0P2aRAH2075]F@80Ke]S0P1dGV82075SI080L5mR0P1^GF@207ETH080K65V0P1d
IF02079QI080MUmS0P1bGVH207IOH`80LUiV0P1eGF<206YHI`80KUeP101^G60205mDHP80JE]J0P1X
Ge/206=IF`80K5]I0P1SEUd2071SFP80IUAK0P1^GF0205mKG@80JEIH0P1SCe/206=BF@80IUUH0P1M
DeP205a?EP80FdYB0P1MDE<204mADP80DTa;0P1EB4/204A3C080<3M00P0I9Rh201/T7P804`d?0P0o
8R<203lS9P80@b@e0P1=9Bl204@]A@80<cHg0P1I@C4204/a@080KT0n0P1mE4l206iEFP80CSUK0P1C
BUD204E7B080DT=40P0m=dD3059:?`80@3]00P1XDSl206mBA`80Me9G0P1@CF8205E2C080FTMB0P2K
L3h208ESJ080MV]_0P1cGVP209A`IP80PFi`0P26KG4208=_L`80OFad0P26L6l2085ZL`80Pfmc1020
M78208=bL@80PFYc0P26KG4408=_L`80PFYc0P24J74208I]L@@0Pfmc0P20LG@@0?ooo`003P3oool2
081dLP80PFea0P23Kg<207e_LP80PFea1023LW4207mbM080PFi`0P26KG4408=_L`80P75d0P23LW42
081aM080Pg9a0P20LG@207e_LP80Ofia0P20K702071<KP80JdA]0P14>Eh203dbB080>38m0P0^8R`2
03HZ<P808QdS0P0]9BP2024K7P80<R<U0`0^:2P202@L8P80bGT?101_Ff<207AQH080M69S0P1_HVD2
06mUH`80L5mR0P1dH6@2079RH`@0LV5T0P1aGV@207APH`80LV5T0P1/FF@206iIHP80IU1O0P1fFEd2
06I@GP80HdYN0P1/DeL206iGFP80I5EM0P1[EeT206ULG@80LF9I0P1PEV8206iFF080KEmQ0P1UJEh2
05aLGP80He]I0P1SEEL2065BF@80FU1F0P1KDU@205Y;C`80FDQA0P1@A4h2054mB080CSi80P0j>TD2
01lT<@805A8I0P0I5QX203D[6`80?C@]0P0n>c42040m=`80CT/i0P0d=cd203`X;`80A2De0P1ZACT2
068h@`80M3Y@0P1TIf0204aUE080?C]=0P1EAD@203L_@@<0Hd/l0P13BTX206=I?`80GdU<0P1kFTl2
05I=GP80ASaA0P1iL4T207]iC`80QVeR0P1kJV`2075_L080RWQR0P23Kg<208=bL@80Pfmc0P20LG@2
08=bL@80P75d0P21KG4208I]L@@0Pfmc0P1mK7@208I`K`80PFYc0P26KG42081aM080P7Ab0P23LW46
08=_La00oooo000>0?ooo`80P7Ab0P21KG4208=_L`80OFmb0P21KG4408=bL@80Og9d0P21KW0208I]
L@@0Pfmc0P20LG@208=bL@80P75d0P23LW42081aM080OFmb0P1oKW42081/L080L4a^0P1[A6d204@i
GP80?C980P0h<Sd202hR;080=RXb0P0R7B<202dU:0808A/N0P0b8bD302hX:08091`R0P39N@l406mK
H`80M65P0P1dHV<206mRI@80KfES0P1`Gf8207API080LV9S101bHF@2075NI080M61S0P1bHF@206aI
I080KUUR0P1VD5l207IIG@80IU1N0P1SBUh206aCE`80KUMJ0P1TEEd206]GF@80JEaM0P1aHUT2061F
HP80KUIH0P1]Gf4206EYGP80G5aN0P1SFeT206=EE`80HE9I0P1JD5H205]BE080FT]?0P1IB5420514
CP80DCe80P1>?TP203XjA@807b@a0P0E4QT201TF6P80=B/K0P0m=2d203hk<@80@3dg0P1>BcT203@g
?@80?2P_0P149CD206Y5>@80HSQ30P1d>U0206AWH080C6ED0P0m>dd205E5A080=bm10`1SBc`204=:
BP80HeTo0P1OBD`207]JC`80ETeN0P16?54207U`B@80NgU?0P26KF8207]ZK080LFm`0P2:N68208=_
L`80Pg9a0P23Kg<2081aM080Pg9a0P20LG@2085]L@80QVea1023Kg<207e/M080QW1_0P21JW<208I]
L@80P75d0P20M78208=bL@H0Pfmc403oool000h0oooo0P23Kg<2081aM080Pg9a0P20LG@2081dLP80
Pg9a1023Kg<2081aM080PFea0P26KG4608=_L`80PFYc1024J74208=_L`80P7Ab0P1hIW8205i?LP80
FceM0P1<>5P203D]@`80>b`g0P0c<cL202XU:080:B@[0P0]:BD202LX:@80;B/T0`0U728204aE<`80
Ui4K0P1`FV8206mNH@80MF=P0P1bHV<4079QI080LVQU0P1_IF<2075NI080M61S0P1bHF@2075RI@80
KUYR0P1cEV8206I<HP80JDAJ0P1S@5X207=9D`80IDML0P1PBEL206U=E080JdiF0P1YDUX206QFF@80
KUYJ0P1]Ee/206aNH@80J6MN0P1^I5`206MBG`80IU=O0P1UF5X2061CFP80HE5G0P1LCUL205m@D`80
ET]C0P1JC4l205=?D@80C4m=0P16@4H203ld@@80:Bdi0P0H7b@2028U7P80:B<M0P0o:bL203HT;080
C3@d0P10:S<204Pd?P80:RPb0P10<S0203hP:P80Ode10P1VLD`205i6C`80I3mJ0P11@UD205A?A080
=ca80`1C?cL205DmAP80HDa50P1KBdh207YOB`80FeEO0P12AeH209F0?P80IUQP0P2IL5`207I/K`80
PgQ/0P20NVh208=bL@H0Pfmc0P21JW<208I]L@80P75d0P23LW4408=_L`80P75d0P21KG42085ZL`80
QW1_0P23Kg<2085ZL`80QVea1P23Kg<@0?ooo`003P3oool208=_L`80P75d0P23LW42081aM080P7Ab
0P23LW4408=_L`80P75d0P21KG4208I]L@H0Pfmc0P21JW<408AXL@80Pfmc0P20M78207QVLP80GTmb
0P1K?Ed204`hF080=Be30P0k;3L203<c=`80:RDX0P0Y92/202dY9@809bPY0P0]:b@302DL8P80C5Dc
0P2GTA/2071JHP80KeiQ0P1eHf02079RH`@0LV5T0P1bJ6D206mUH`80LEiT0P1dH6<2079QI080LF9U
0P1^FV8207=FHP80ITaR0P1YA5X206=0FP80LdUC0P1UAe`20619E`80JDeD0P1[CUH206UBFP80J5II
0P1^FUX206eGF`80K5iQ0P1XIeh206iTG080Ie9O0P1VDel206EHFP80H5=J0P1QDEL205a>E`80Ge1C
0P1FBe<205Y<C`80DdmA0P1<Cdd204I0AP80?cA10P0Y;CT201PO90808RDN0P0Y8ad203l[9`80=R@/
0P1<=3@2040Z<`80B3@n0P0Z:382040b<080?R0Z0P1oCD4206IaC080GTI?0P1T?eX20452E@80E4m4
0P0g?4P305<o=`80ECe60P1QC4D205];CP80NUm;0P1KEEl20497EP80UH0n0P1VF60209U`G080MVa_
0P23N6`2081jKP80Pg9a1P23Kg<2085ZL`80QVea0P20LG@208=bL@@0Pfmc0P20LG@2085]L@80PFYc
0P26L6l208=_L`80PFYc0P26KG4608=_La00oooo000>0?ooo`80Q6Qa0P26KG4808=_L`80PFYc0P26
KG44085ZL`80QW1_0P23Kg<2085ZL`80QVea0P20LG@2081dLP80O6eb0P28L6l2085ZL`80NVee0P1C
DW4204PjF`80A2]60P0g9Ch2030R;P80=B4/0P0[8B`202@L8P80:1XQ0P0`92H202dV9`<07aXQ0P2L
SQT206n2A`80KemP0P1`H64207ESH0H0LV5T0P1fGf<2079NIP80KeiT0P1dHF84079QI080JE]U0P1X
DUl206=<G`80I5MJ0P1DC5H206M<D080HTYE0P1JAE@206E:D080J4mC0P1VCeD206]DE`80JeAH0P1^
F5`206]DF`80MEUM0P1^G60206MPH`80HU]M0P1/I5`205eNGP80GUMI0P1MEEL205aBE080ET]C0P1J
C4l205U<C`80Bce<0P1;?dT20410A080;Bhh0P0K6RD200`7308080lE0P0i8B0203@W:`80BCL]0P0`
9342058j<P80;c<l0P0k=c0202TR;@80SU/T0P1G<4X206@jD`80MWE?0P0iCUT20555A`80B4M<0`12
@T0205E5@080ECe20P1N?dP207mLB@80HUQM0P1CIF02081aA`80KV9Z0P23IEP207Y:J`80Vf]S2P23
Kg<207e/M080QW1_2P23Kg<2081aM080P7Ab0P23LW4208=_L`80OFad0P26L6l608=_La00oooo000>
0?ooo`80Q6Qa0P26KG4808=_L`80PFYc0P26KG44085ZL`80QW1_0P23Kg<2085ZL`80QVea0P20LG@2
081dLP80O6eb0P28L6l2085ZL`80NVee0P1CDW4204PjF`80A2]60P0g9Ch2030R;P80=B4/0P0[8B`2
02@L8P80:1XQ0P0`92H202dV9`<07aXQ0P2LSQT206n2A`80KemP0P1`H64207ESH0H0LV5T0P1fGf<2
079NIP80KeiT0P1dHF84079QI080JE]U0P1XDUl206=<G`80I5MJ0P1DC5H206M<D080HTYE0P1JAE@2
06E:D080J4mC0P1VCeD206]DE`80JeAH0P1^F5`206]DF`80MEUM0P1^G60206MPH`80HU]M0P1/I5`2
05eNGP80GUMI0P1MEEL205aBE080ET]C0P1JC4l205U<C`80Bce<0P1;?dT20410A080;Bhh0P0K6RD2
00`7308080lE0P0i8B0203@W:`80BCL]0P0`9342058j<P80;c<l0P0k=c0202TR;@80SU/T0P1G<4X2
06@jD`80MWE?0P0iCUT20555A`80B4M<0`12@T0205E5@080ECe20P1N?dP207mLB@80HUQM0P1CIF02
081aA`80KV9Z0P23IEP207Y:J`80Vf]S2P23Kg<207e/M080QW1_2P23Kg<2081aM080P7Ab0P23LW42
08=_L`80OFad0P26L6l608=_La00oooo000>0?ooo`80P7Ab0P23LW4808=_L`80P75d0P21KG4208=_
L`80P7Ab0P23LW42085ZL`80Pfmc0P23LW4408=_L`80Og9d0P23Lg02081aM080NFEa0P1>?W02048a
E@80=RHn0P0a8C4202lT;@8091/S0P0a8bL202HS9P80:b/U0P0/:2@2028H80<07aHN0P36O`L206eL
H0@0L5aP0P1gHF02071LI080N6ES0P1bJFH206mSI@80LV5T0P1`HVD2071NHP80N6AS0P1I>el205lR
DP80RDmF0P1SJV0205mPF`80EEAM0P0n9T@205@H?@80I2a50P1YAdX204d]B080L3U:0P1^C54206aE
E`80LV9I0P1WI60206iTG0@0KUiP0P1WHF<206QHF`80IU1O0P1PDU/2065EF080FU1F0P1JDe@205I>
D080FDa?0P1<BU0204U5A`80?cA10P0g<cd201dS;08030hC0P0K5a<202DI6080=24S0P0k9BP203DX
<P80BCL]0P0l<SX202lV;`80?3Pf0P17:BH206<_AP80Jem50P1XA4T205a7H@80@DA<0P1B@DD303LX
?P80EcDj0P1<=d4206A@@`80NFA70P1VEe`207b1G080De5M0P2EJeP205a;I@80U7UO0P23QV<:08=_
L`80P75d0P23LW4B08=_L`80P75d0P23LW4208=_L`80PFYc0P26KG4@0?ooo`003P3oool2081dLP80
Pg9a2023Kg<2081aM080PFea0P23Kg<2081dLP80Pg9a0P21JW<208=_L`80Pg9a1023Kg<207mbM080
Pg=`0P20LG@207UUL@80CSi`0P12<ED203HV?P80<B4a0P0_92d202@K8`80<B<W0P0V8bH202/[9@80
;2PT0P0R620301lF7P80aWl70P1]G604071LH080Mf5P0P1`G6@207QUH`80LVUV0P1_HfD2079QI080
L69U0P1`GV8207QTH`80FC]O0P1O8U8208U?EP80HfYP0P1OH5/205EDG@80?RI40P1D63d206@/A@80
JDM:0P1=;DP2070iBP80KTaA0P1/EEL2079RF@80IfAP0P1^I5`406iNH080If5S0P1XF5/206I@G`80
H59K0P1QEEP205Y@EP80FU=D0P1FCU0205U<C`80C4Y@0P19ADL203ld@@80=c<m0P0M8b`200`>4`80
6aLC0P0U6AP203@Q8`80>bDX0P0e:38204Tg;@80?38j0P0_9Rl203`h=P80AbTV0P1S;dH206]OA@80
J4A90P1LAf420454C080DT550`0g:3h205Le>P80C3M10P1TD4<207UTA`80IUML0P1lPE`205=AG@80
UF]H0P1LBfD209AiG`80PhIS2P23Kg<2081aM080Pg9a4P23Kg<2081aM080Pg9a0P23Kg<2085ZL`80
QVea403oool000h0oooo1024J74208I]L@80PFYc0P24J74208I]L@80Pfmc0P20LG@208=bL@80PFYc
0P24J74208=_L`80PFea0P26KG4808=_L`80PFYc0P1bFg@2040bI`80?R]:0P0d:c`203He=@80:2LZ
0P0Y9bX202@O8080;24U0P0^9bH202@L8P807QLN0`0b<RH20;>;3@80K5iQ0P1aI60206mWHP80MF]Q
0P1/I6H207=MH@80O61T0P1/FfL207EOH`80LEiT0P1aHF@207QXH@80Dfaa0P19QF4206n0BP80KV9Q
0P1UHV@205QLH080>fQS0P10QD`2051oA`80GW5=0P12HU/204i@A080J4E90P1cEE4207IQF0@0KUiP
101^GF0206MBG`80KUeP0P1VIel205eNGP80GeII0P1ME5P205aBE080ET]C101EADd204U0BP80@T97
0P0i>cd202Ta=`801`T>0P0C3@h201`C5080;AlM0P0e9bH203T^;@80=RH[0P1:=CD202TX<P80?Rd[
0P0K3Qh209=K9P80DdM60P1K>dl207IQC080=3MC0P1E@T<3034b@`80Bc`e0P1CAd4205a<@080Lda8
0P1dFUT207eGE@80DceZ0P22BTT208=hK080PiEH0P21JW<208I]L@P0Pfmc0P21JW<208I]L@H0Pfmc
0P21JW<208I]L@P0Pfmc0P21JW<208AXL@80QVea0P20LG@208=bLA00oooo000>0?ooo`@0Q6Qa0P26
KG42085ZL`80Q6Qa0P26KG4208=_L`80P75d0P23LW42085ZL`80Q6Qa0P23Kg<2085]L@80QVea2023
Kg<2085ZL`80LU]d0P10<VL203h[BP80=2/l0P0f=CD202PW:P80:BLZ0P0T7b0202`Q9@80;RLV0P0T
728201hG7P<0<S8V0P2cR`d206aNH@80LFAP0P1_If8207E[H@80K6AV0P1cGF4207aPI080K5]W0P1e
Gf<2075NI080LF5T0P1hJ64205=/L@80BHEQ0P1_P4X206iRH@80IF9T0P1HG60203]XH`80@8E<0P1@
OdL205iaC@80@V9K0P1>D4@206Q5B@80LeEA0P1fHEP406iNH0@0KUeP0P1WDUl206iMH080IVMO0P1M
GUh205mFF@80GEAH0P1LDU@205I;D`@0EDE=0P19@4X20492A`80>C/m0P0Y<CL200L93P804`d>0P0L
4a@202dO7@80=BLV0P0i;Rd203HV:`80BSDe0P0Y:38203h]:`806`hN0P2CFbH205=7AP80Fc]?0P1f
HD`203@gD`80ED930`0a<T<204/l=@80DdM10P1LC40207=<B080M5YI0P1mEeD205<mJP80PTY90P23
N6`208>EF080PFYc0P26KG4808=_L`80PFYc0P26KG4608=_L`80PFYc0P26KG4808=_L`80PFYc0P24
J74208I]L@80P75d0P23LW4@0?ooo`003P3oool4081dLP80Pg9a0P20LG@2081dLP80Pg9a0P21JW<2
08I]L@80Pfmc0P1mK7@2085]L@80QW1_0P20LG@208=bL@80Pfmc0P20J7<208Q]L@80Pfmc0P20LG@2
06ILM080=SAT0P0c9cl203LX=@809QLU0P0`7BT202lX:0809B@W0P0]:BD202lZ9`806QHN0P0N5Q/3
05E>9P80VH4T0P1aGf02075PH080LeaR0P1kHV8207=UJ080KfYW0P1eJF8206iUJ@80L6ES0P1`HVD2
071NHP80O6=R0P1ZFFL207EWH`80KfaS0P1_Jf@206QSI@80Hf9T0P1JGEh2061IE`80HeMG0P1TDEH2
05i@FP80D5QH0P1JGDd2071QCP80MF5H0P1^GF02071QH@80K5iQ0P1^GF0206MQH`80IeQK0P1^Ce`2
06MCG`80HEQL0P1OEUP205eEE`80E4iD0P1>A4h205E4B@80Bd1:0P16>d<203`c?`80=34h0P062102
01LD4@804Ph?0P0e:1d203@_9`80?CH^0P0U82T204hd;080:bHc0P0i;bd201HH8`80ReLE0P1>>4l2
06EKB@80LfQ:0P0`=5P205E6@0<0>3U50P18A3/20553?080FTI40P1/ETP207QQD@80K5]N0P1IFV<2
06]`EP80WXM>0P23Kg<207e/M080QW1_2023Kg<2081aM080Pg9a0P21JW<208I]L@80Pfmc0P20LG@2
08=bL@P0Pfmc0P20LG@207e_LP80QW1_1023Kg<@0?ooo`003P3oool4081dLP80Pg9a0P20LG@2081d
LP80Pg9a0P21JW<208I]L@80Pfmc0P1mK7@2085]L@80QW1_0P20LG@208=bL@80Pfmc0P20J7<208Q]
L@80Pfmc0P20LG@206ILM080=SAT0P0c9cl203LX=@809QLU0P0`7BT202lX:0809B@W0P0]:BD202lZ
9`806QHN0P0N5Q/305E>9P80VH4T0P1aGf02075PH080LeaR0P1kHV8207=UJ080KfYW0P1eJF8206iU
J@80L6ES0P1`HVD2071NHP80O6=R0P1ZFFL207EWH`80KfaS0P1_Jf@206QSI@80Hf9T0P1JGEh2061I
E`80HeMG0P1TDEH205i@FP80D5QH0P1JGDd2071QCP80MF5H0P1^GF02071QH@80K5iQ0P1^GF0206MQ
H`80IeQK0P1^Ce`206MCG`80HEQL0P1OEUP205eEE`80E4iD0P1>A4h205E4B@80Bd1:0P16>d<203`c
?`80=34h0P06210201LD4@804Ph?0P0e:1d203@_9`80?CH^0P0U82T204hd;080:bHc0P0i;bd201HH
8`80ReLE0P1>>4l206EKB@80LfQ:0P0`=5P205E6@0<0>3U50P18A3/20553?080FTI40P1/ETP207QQ
D@80K5]N0P1IFV<206]`EP80WXM>0P23Kg<207e/M080QW1_2023Kg<2081aM080Pg9a0P21JW<208I]
L@80Pfmc0P20LG@208=bL@P0Pfmc0P20LG@207e_LP80QW1_1023Kg<@0?ooo`003P3oool608=_L`80
PFYc0P26KG42085ZL`80Pfmc0P23LW42085ZL`80Pfmc0P1mKg8208I`K`80Pfmc0P20J7<208Q]L@80
O6ad0P24K6h208I]L@80PFYc0P1RE7H202dXFP80<B@j0P0g;34202P/<080:R/V0P0^9RL202`X:@80
;b`X0P0Y8bH201LD70808ahL0`2EVAL206j8A080M6IO0P1_IF<2079[I080M6YS0P1eI6H207ERI`80
MV=V0P1dHVL207=VI`80K5iU0P1^FF<207iUG`80KFQZ0P1dJV8207U/IP80KfIX0P1ZGFL206aMH`80
HEYR0P1NEE/2065?E`80He5G0P1QDeH205a?EP80HeUD0P1/GU<207EPF@80KUeP0P1cHF0206]MH`80
L65Q0P1/GV4206MPH`80IfIN0P1RFed206IIF`80GeEJ0P1QEEL205MBE`80DE=D0P1>CT`204U3B@80
A3a40P0l=Ch203<[=@803aDR0P061@H201PA4P80<RLJ0P0M4AX204h]:@80:2Xa0P17?B/202@N;080
>2HY0P0/<c<205U68`80FSe50P1/ED@206U9C`80ATUO0P11@D8304a5A`80?c`m0P1>>Sd2054g?P80
Mdm30P1jHU4206=>G@80M6=N0P1nSE`208J6H080Pfmc0P20LG@208=bL@H0Pfmc0P21JW<208AXL@80
QVea0P20LG@208=bLA00Pfmc0P20LG@208=bL@@0Pfmc403oool000h0oooo1P23Kg<2085ZL`80QVea
0P21JW<208=_L`80Pg9a0P21JW<208=_L`80OFmb0P26L6l208=_L`80P6Qc0P28KG4207a/M080Q6a^
0P26KG42085ZL`80HUAf0P0]:5X2034T>P80=b`a0P0X;30202X[9P80;RHW0P0/:2T202l/:080:B<V
0P0G51`202<N70<0UITG0P1^R4@207AVG`80KfES0P1bJf@207AZH`80MFAV0P1eHVL207ISIP80M69W
0P1cIVL206aNI@80KUUS0P1nIEl206eXJP80M6YR0P1iK6H206mVJ080JUeW0P1/GF<2065JHP80GUEK
0P1QCeL206=AE`80HE=F0P1LCeH206=IE080K5iC0P1eH5T206iMH080Lf5P0P1[GF<2071QH@80K5iQ
0P1WH6<206MVGP80HU]M0P1VFE/205mEFP80HEEG0P1GDUL2055CE080CTi<0P19@dT204@lA080?3Dn
0P0c:cD200lE8P801PD60P0H4A82038W6P807A4J0P1>;BT202PZ<@80Acd[0P0T7R`203PV:@80;3<c
0P1IAR<205XmA@80K5E40P1YBDl204I9G`80@D520`1<ADL203ll?@80CSXm0P1A=ch207M?@`80NV9A
0P1SCUd207ASGP80OXeL0P26QV0208=_L`80P75d0P23LW4608=_L`80PFYc0P24J74208I]L@80P75d
0P23LW4@08=_L`80P75d0P23LW4408=_La00oooo000>0?ooo`H0Pfmc0P20LG@208=bL@80P75d0P23
LW44085ZL`80QW1_0P1mK7@208A[K`80QVea0P1oLW@2085^L080Pfmc0P20M78208=bL@80O6Yd0P17
:fL2034HB`80>2dh0P0S6RD202hK9@80:alV0P0_9BL202lX:080;BDW0P0E3AL201lD6`805a4C0`3@
M`@2071QH080M69P0P1aG6<207aSHP80MF=W0P1eHVL207ESI`80MFAV0P1dI6L207ETIP80KfMY0P1Z
J6D207ITH080LeMU0P1jGf@207YPI080MEiZ0P1]HFP206UNH`80GdeP0P1NAET2069:E@80IE5D0P1N
C5D206=CE@80J5iD0P1`IeP206mUG080KUiQ0P1cHV0206mUI080JemQ0P1^G68206eMH080KUiP0P1W
HF<2069KG@80Ge=K0P1SE5L205eDF080FE=E0P1ACe<204I3C080A3]40P0o>T0203Dh>`8072T_0P06
2@`201<?3@80:a`H0P0_<R/203Hc8P80=R/a0P0o<bh202DS;`80<b`X0P0^8RL2054f;P80FT<j0P1S
A4<206YAD080HFUH0P0^>Dh3050i?080?c100P1>?C/205A@@`80MG910P1aJ5@2050mG080ReY?0P2K
NEX2085]L@80QVea0P21JW<408AXL@80QVea0P23Kg<2081aM080OFmb0P26L6l@08=_L`80PFYc0P26
KG4808=_La00oooo000>0?ooo`H0Pfmc0P20LG@208=bL@80P75d0P23LW44085ZL`80QW1_0P1mK7@2
08A[K`80QVea0P1oLW@2085^L080Pfmc0P20M78208=bL@80O6Yd0P17:fL2034HB`80>2dh0P0S6RD2
02hK9@80:alV0P0_9BL202lX:080;BDW0P0E3AL201lD6`805a4C0`3@M`@2071QH080M69P0P1aG6<2
07aSHP80MF=W0P1eHVL207ESI`80MFAV0P1dI6L207ETIP80KfMY0P1ZJ6D207ITH080LeMU0P1jGf@2
07YPI080MEiZ0P1]HFP206UNH`80GdeP0P1NAET2069:E@80IE5D0P1NC5D206=CE@80J5iD0P1`IeP2
06mUG080KUiQ0P1cHV0206mUI080JemQ0P1^G68206eMH080KUiP0P1WHF<2069KG@80Ge=K0P1SE5L2
05eDF080FE=E0P1ACe<204I3C080A3]40P0o>T0203Dh>`8072T_0P062@`201<?3@80:a`H0P0_<R/2
03Hc8P80=R/a0P0o<bh202DS;`80<b`X0P0^8RL2054f;P80FT<j0P1SA4<206YAD080HFUH0P0^>Dh3
050i?080?c100P1>?C/205A@@`80MG910P1aJ5@2050mG080ReY?0P2KNEX2085]L@80QVea0P21JW<4
08AXL@80QVea0P23Kg<2081aM080OFmb0P26L6l@08=_L`80PFYc0P26KG4808=_La00oooo000>0?oo
o`@0Q6Qa0P26KG4408=_L`80PFYc0P26KG42081aM080P7Ab0P23LW42081aM080P7Ab0P21KG4208I]
L@80OFad0P26L6l408=_L`80NfYd0P0[;VT202lY@@80;R8/0P0Q6BL203@_9P80:b`Y0P0^:bL202dV
9`804@XB0P0L4AX201PD50808AlM0`33R`0207ATH080M6YS0P1^JVH207EXHP80MF9V0P1eHVL807ER
IP80MV=V0P1bIFP206aNI@80LUmT0P1cGF4207]QI080KeYV0P1aEV@206M>HP80HU9P0P1FCeT2069F
D`80HUID0P1NEUL206IOE080KVYH0P1^IE/206mMH080KeeQ0P1cGf0207EQHP80JUaU0P1_HF4206aO
H@@0KUeP0P1QEV4206=JG080GeMI0P1QEEL205U>EP80Fe9D0P18C58204A8B@80?C]00P0k=3X202LW
<P801`T>0P0M6a@201dH5@80<b0N0P0`82L203HW:@80=RD[0P0h=3@202`^:`80;b//0P1AARd205I:
?080FT]40P1^EdT207YZE080:3QK0`15>S`203``?080CCXh0P1G?C`207a<@P80NUMG0P1HK6P2086N
CP80QXIP0P20LG@208=bL@80P75d1020M78208=bL@@0Pfmc0P20LG@208=bL@H0Pfmc0P21JW<208I]
L@H0Pfmc0P1mK7@208A[K`80QVea1P23Kg<@0?ooo`003P3oool408AXL@80QVea1023Kg<2085ZL`80
QVea0P20LG@2081dLP80Pg9a0P20LG@2081dLP80PFea0P26KG4207e/M080QW1_1023Kg<207]ZM080
:biY0P0_:D4202hR;0808ATW0P0d;bH202//:@80;R/W0P0]9RL2014:4P80714J0P0H51@2024O7@<0
`h/00P1dI60207AZH`80KVYV0P1eJ68207ERIP80MF9W201eHVH207ISIP80LVEX0P1/GVD2079OI080
LeeQ0P1kHF@206mJIP80LEIT0P1WCV82069BH080ETmI0P1REU<2069FE080GUIG0P1VGe@206iZF080
KVEK0P1_GF0206mMH@80LemP0P1eHF8206YLI@80Kf5Q0P1/Gf4406iMH080HEIQ0P1SFU`205mGF@80
HEEG0P1ICUH205]BE080B4aB0P14B4T203dk@080>c@j0P0W9c8200L93P807A/D0P0M61D203<P7P80
<20W0P0f9bT203HU:`80>3@d0P0/;R/202l[;080DDH]0P1FBS`205Y;A080KUM90P1jJU@202PhF`<0
ACXl0P0l<3`204dj>080Ecdl0P1lC48207YGE`80F6aX0P21WTh208J6H080P75d0P23LW42081aM0@0
P7Ab0P23LW4408=_L`80P75d0P23LW4608=_L`80PFYc0P26KG4608=_L`80OFad0P24Jfl208I]L@H0
Pfmc403oool000h0oooo1020M78208=bL@80Pfmc0P21JW<208=_L`80Pg9a2023Kg<2085ZL`80Pfmc
0P21KG4208=_L`80PFea1024J74207m[L`80939/0P0/:3/202TR;@80:BLY0P0d;bH202/T:@80;R@W
0P0_:2T201<G7P805Q<B0P0K5QL206N=90<0PZXR0P1cHV0207YTHP80M69W1P1eHfH207U[IP@0M6iX
0P1`IVP207ITIP80MF=W0P1_IfT206iVI080K5aT0P1mIEl206mWJ@80If1T0P1QEF82065?FP80GU5J
0P1QEU<206IJEP80HUeH0P1ZHEL207=RF@80LF=Q0P1[H682071QH@80L61Q0P1hJ64206YTI`80KV5R
0P1]GF8206eNH@80KUiP0P1QEF8206IFF`80HeML0P1OE5P205Y?E`80FTUA0P1EBU<204I2B`80?3E2
0P0l<cX2038c>0802a<K0P0;20T202DI6@807QDF0P0j:RD203Hc;080:bDY0P0n;2/203Pd=@80;2`]
0P1?>Rd206EC?P80EeI90P1YFDX2089VD@80:2aJ0`1BBd8202`/>080F4<g0P14>C`208IU?@80M6mD
0P1]HUl209]kF080Pg9a6P23Kg<2081aM080Pg9a1P23Kg<2081aM080P7Ab0P23LW4208=_L`80PFYc
0P26KG4@0?ooo`003P3oool4081dLP80Pg9a0P23Kg<2085ZL`80Pfmc0P23LW4808=_L`80PFYc0P23
Kg<2085]L@80Pfmc0P21KG4408AXL@80Of]c0P0T<V`202`X>`80:B8]0P0Y9bT203@_9P80:b@Y0P0^
92L202lX:@804aLN0P0F4a8201/F5`80IhdT0`22ZR8207=RH080NVAR0P1dHVL607ESIP80NF]V101d
KVP2071VJ080MVAV0P1eHfL206mWJ@80KVIT0P1/G6@207eUG`80KfMY0P1WH6@2065EHP80HDmJ0P1N
DEX2065FD`80IUYF0P1RGEP206YQE`80Lf9I0P1aHf4206]PHP80L65Q0P1`H64207QXH@80JVAW0P1^
HF8206eMHP80KEiQ0P1^GV02065EHP80IUIK0P1SEe`205mDF080FTmG0P1JBE4205E:D`80AT9;0P0l
=D8203`c>P80<S<h0P0;4a/200/82@809ATI0P0N5AH203XZ9@80=S</0P0[9BT203h/:`80>3@e0P0/
;2d204lj;@80IE<n0P1GETT206UIBP80PVIA0P0X;5X3059;@P80;2`h0P1H@cL204@i?080QVDm0P1d
Ke@206eRG`80Vg]H0P23LW4J08=_L`80P75d0P23LW4608=_L`80P75d0P20M78208=bL@80Pfmc0P21
JW<208I]LA00oooo000>0?ooo`H0Q6Qa0P26KG42081aM080Pg9a2023Kg<4085ZL`80Q6]_0P23Kg<2
08=bL@80OFad0P21KG4208=bL@80JTY^0P0/75d2030V>@809B0Y0P0c:bT2034/:P80;2P[0P0/9bL2
01/B6`805PdG0P0A3A0207:R7`80J<4V0`1_L5H207MWH`80NFmT0P1`IFP207ESIP80NF]V0P1`IVP2
07YPI0@0NU]W0P1eGVT607ERIP80LfEX0P1ZIFL207UYH080MF=W0P1XGFT206ERI080FUaO0P1NEEL2
06IJE`80IU]F0P1WEeT206eKF@80M61K0P1aGEl207EWH`80L6iT0P1ZHV@207]UH080K5]W0P1eJ6@2
06YVI@80KVIS0P1[H68206IQH`80I6IO0P1QGE`2061IG080FUIH0P1FDUD205I>D080Ce5B0P0h@TP2
03Pf>`80>34f0P0I92h201@P6`809BLI0P0X;B@202l[8@80@3<]0P0[:bl203hh;@80=Rh_0P0^9Bh2
04dk;P80Le`h0P1FCdl206MCC@80NeQ@0P0a>f8304Hj?080:Qlh0P1I>bl204Ll@@80PEdf0P25I5H2
07UoI@80RHEO4023Kg<2085ZL`80QVea0P23Kg<2085ZL`80Q6Qa0P26KG4208=_L`80PFYc0P26KG42
085ZL`80QVea2023Kg<2081aM080Pg9a403oool000h0oooo1P24J74208I]L@80P75d0P23LW4808=_
L`@0PFYc0P24Jfl208=_L`80Pg9a0P1mK7@2085]L@80Pg9a0P1ZBVh202`LG@80<2Hi0P0U82T203<[
:@80<B`Z0P0/:2/202`W9`806a8K0P0F3AL2014=4080LZ8O0P1X`BH306m`EP80MfMS0P1iKf@2071U
J080MF=V0P1iJfH2071VJ080NV1T101jFfL207ENJ@H0MF9V0P1cIFP206YUI`80NFUP0P1eHfL206QM
J@80IF9T0P1JG5l205iEE`80IUYG0P1VFeH206MGF@80KE]I0P1dH5/2075MG`80MFMS0P1`KV@206YR
I080NfEP0P1/FfL207EXI080JVIU0P1^IV<206]PHP80IV5S0P1TIUl2065MG080H5UL0P1JEUP205IB
E@80ETi@0P1?DE8203Q2B080>3Hk0P0h<CH201TT;P80520K0P0U9aT202P]9080;b/Q0P10<bd202/[
;`80?SP]0P0f;Rl202hU;P80CC/^0P1cG3P205I?C`80Ie==0P1kF502034kHP<0ASXl0P0Z7cP205Tk
;`80Aca10P21GCH208ETEP80NGmU0P29QEl@08=_L`80PFYc0P26KG4208=_L`80PFYc0P24J74208I]
L@80Pfmc0P21JW<208I]L@80PFYc0P26KG4808=_L`80P75d0P23LW4@0?ooo`003P3oool2085]L@80
Pg9a0P1mKg8208I`K`X0Pfmc0P21JW<208=_L`80P7Ab0P1mKg8208I`K`80Pfmc0P20LG@2081dLP80
Pg9a0P0c5e/203HB@`80<B8`0P0M5B4203d[9P80:b@X0P0]8RP202lW:@805ADM0P0S8ah201/U7P80
_9@00P1bHeX307IUH`80MVUR0P1iH6D207ENJ@@0NF]V0P1`HF/207ESIP80MFAV0P1hK6L2071VJ0H0
MF=V0P1fI6H206iNI`80NVAS0P1eHfL206mWJ@80J6=U0P1MEF8205iAFP80JeUE0P1XG5X206MNF`80
JUaJ0P1bGE/207=QH080NVUP0P1bGFH207=UI`80M6QS0P1`IfP2071OHP80M5]U0P1bH6<206iRI@80
Jf1R0P1/GV4206=JH@80HeQL0P1MDUX205eEE`80DdeC0P1IC4l203hlCP80>SY00P0c;SD202HS;@80
7b0S0P0T8Ah202LM7`80=R/X0P0e:RP203/b<`80>SH_0P0d;C8203do=@80CE@d0P1ZFCX205U9D@80
GdU<0P1_BDh204@iF@<0>3520P0W8C8205M0;@80EU110P1^H40208i`C`80SGeQ0P23MFl@08=_L`80
P75d0P23LW4208=_L`80P75d0P20M78208=bL@80Pfmc0P20LG@2085]L@80Pfmc0P23LW4208=_L`80
PFYc0P26KG4608=_La00oooo000>0?ooo`80PFea0P23LW4207e_LP80QW1_2P23Kg<2085ZL`80Pfmc
0P20M78207e_LP80QW1_0P23Kg<2081aM080P7Ab0P23LW4203<GF`80=Q930P0a8S0201dE8@80?B/V
0P0[92P202dR:080;bLY0P0E5Ad202<S7P806bDN0P2lU002079SFP<0MVES0P1fJF8207UPI@80MEiY
101iJfH2071QJ`80MF=V0P1eI6H207Q/I`80L6IX1P1eHfH207ITIP80KUiW0P1jI6<207ESI`80KfMY
0P1XHfD205eEHP80GU5J0P1[FED206QLFP80IeiK0P1ZG5X2079MF`80Lf5P0P1jJF02079MIP80LfEW
0P1dJ6<2071WJ080L5mR0P1dFfD2079PH`80KV9U0P1[H68206aNH@80HeYQ0P1SF5`205eBFP80GEEG
0P1CCE<205U<C`80?Sa>0P0j>T0203<^=@809R<]0P0O82<202@Q7P809adO0P0f:bP203DZ:080>c8c
0P0j=Rl203@]<P80?Cle0P1=E3@206YI>P80FDUA0P1OBD`206m9CP80A3UI0`0h<D8202LQ<P80Ed0]
0P1FD44206iP@080SW1?0P2=OF4208=eKa00Pfmc0P20LG@208=bL@80Pfmc0P20LG@2081dLP80Pg9a
0P23Kg<2081aM080PFea0P23Kg<208=bL@80Pfmc0P21JW<208I]L@H0Pfmc403oool000h0oooo0P21
KG4208I`K`80P75d0P23LW4:08=_L`80P75d0P23LW4208=_L`80OFad0P26L6l408=_L`80PFYc0P26
KG4201LZJ@80<c<i0P0X8b/2020M9@80?SDT0P0];2h202XX:080:R4T0P0O7R@201/G5`80D5H/0P2I
VQT2071UH@<0N6MP0P1eHVH207ERI`@0NF]V0P1eGVT207EPJ@80M6=V0P1fI6H207YQI@80M5mZ0P1i
JfH207A^J080L6IX0P1eHVH2079UJ080MFQT0P1eHVL2075IIP80L5UV0P1MDf@205iAFP80IU5D0P1`
F5L206YJG080KV9M0P1]Heh207ESG`80MUiQ0P1bG6H207UTHP80MF9W0P1aFFD2071IIP80MfQR0P1^
I6D2071PI080K5aT0P1^GF4206UPHP80HEiO0P1KDe/2065CEP80ETmG0P1FCE0204=0C`80>cQ10P0a
;3L202XX;P8071TO0P0Q61`202HN7`80<RDR0P0a9BT2044b;@80>c8d0P0g<c@203X/;P80KEHh0P1J
EdH205U;C`80FDa>0P1SCdd205AHF0<0;3Q70P0e?Sd204Q6<080F3hk0P1eE4D209Z0B`80RG]V6023
Kg<2085ZL`80QVea0P21JW<208I]L@80Pfmc0P20LG@208=bL@@0Pfmc0P20LG@208=bL@H0Pfmc403o
ool000h0oooo0P21KG4208I`K`80P75d0P23LW4:08=_L`80P75d0P23LW4208=_L`80OFad0P26L6l4
08=_L`80PFYc0P26KG4201LZJ@80<c<i0P0X8b/2020M9@80?SDT0P0];2h202XX:080:R4T0P0O7R@2
01/G5`80D5H/0P2IVQT2071UH@<0N6MP0P1eHVH207ERI`@0NF]V0P1eGVT207EPJ@80M6=V0P1fI6H2
07YQI@80M5mZ0P1iJfH207A^J080L6IX0P1eHVH2079UJ080MFQT0P1eHVL2075IIP80L5UV0P1MDf@2
05iAFP80IU5D0P1`F5L206YJG080KV9M0P1]Heh207ESG`80MUiQ0P1bG6H207UTHP80MF9W0P1aFFD2
071IIP80MfQR0P1^I6D2071PI080K5aT0P1^GF4206UPHP80HEiO0P1KDe/2065CEP80ETmG0P1FCE02
04=0C`80>cQ10P0a;3L202XX;P8071TO0P0Q61`202HN7`80<RDR0P0a9BT2044b;@80>c8d0P0g<c@2
03X/;P80KEHh0P1JEdH205U;C`80FDa>0P1SCdd205AHF0<0;3Q70P0e?Sd204Q6<080F3hk0P1eE4D2
09Z0B`80RG]V6023Kg<2085ZL`80QVea0P21JW<208I]L@80Pfmc0P20LG@208=bL@@0Pfmc0P20LG@2
08=bL@H0Pfmc403oool000h0oooo0P20M78208=bL@80PFYc0P26KG42085ZL`80QVea1023Kg<2085Z
L`80QVea1023Kg<2081aM080Pg9a1023Kg<2081aM080PFea0P0I9FD203dh?0809b`c0P0V:2T202dR
8@80=RH[0P0/9b/201dG7`80:b8S0P0[=2X208ZV6@80M8]50P1aHf8307QTHP@0MF=V0P1jH6@207YK
I`80MEiY0P1eHVH207ESI`80MF=V0P1bG6H207QPI@80NV1T0P1jFfL207ENJ@@0MFAV0P1_EfH207aN
I080KfIX0P1`K6D205YLI`80G5IL0P1QE5H206iGE080KEQK0P1^EeX2079HGP80M5]N0P1eGV82079P
H`80MEiR0P1hHFD206aPJ080Lf]S0P1bHV8206mFI@80LEQR0P1^FV8206mNH@80K5]P0P1VEf42069N
G`80FUMI0P1ICUH205I;DP80BdYA0P0k@4L203@h?@80:R/`0P0Q92T201hO7P809R0N0P0W7Al203LZ
:080>bl[0P0l;c42038V;P80<24[0P2;HBX205=?D@80E4==0P1OBTd205]8C@80JE9@0`0T8dD204/h
=`80A3`j0P1??c`207MG?`80Yga70P28LVdH08=_L`80P75d0P23LW42081aM080Pg9a0P21JW<208I]
LA00Pfmc403oool000h0oooo0P20M78208=bL@80PFYc0P26KG42085ZL`80QVea1023Kg<2085ZL`80
QVea1023Kg<2081aM080Pg9a1023Kg<2081aM080PFea0P0I9FD203dh?0809b`c0P0V:2T202dR8@80
=RH[0P0/9b/201dG7`80:b8S0P0[=2X208ZV6@80M8]50P1aHf8307QTHP@0MF=V0P1jH6@207YKI`80
MEiY0P1eHVH207ESI`80MF=V0P1bG6H207QPI@80NV1T0P1jFfL207ENJ@@0MFAV0P1_EfH207aNI080
KfIX0P1`K6D205YLI`80G5IL0P1QE5H206iGE080KEQK0P1^EeX2079HGP80M5]N0P1eGV82079PH`80
MEiR0P1hHFD206aPJ080Lf]S0P1bHV8206mFI@80LEQR0P1^FV8206mNH@80K5]P0P1VEf42069NG`80
FUMI0P1ICUH205I;DP80BdYA0P0k@4L203@h?@80:R/`0P0Q92T201hO7P809R0N0P0W7Al203LZ:080
>bl[0P0l;c42038V;P80<24[0P2;HBX205=?D@80E4==0P1OBTd205]8C@80JE9@0`0T8dD204/h=`80
A3`j0P1??c`207MG?`80Yga70P28LVdH08=_L`80P75d0P23LW42081aM080Pg9a0P21JW<208I]LA00
Pfmc403oool000h0oooo0P24J74208I]L@80P75d0P23LW4207e/M080QW1_0P21JW<208I]L@80OFad
0P26L6l:08=_L`80PFYc0P26KG4205`aJP809Q5@0P10:C<202dT<P80<c4_0P0[<2`2030/:08091/S
0P0P6R4202`U8080MY`[0P1g[34206]OHP80NFES0`1dIf@607ESIP80NF]V0P1`IVP207ESIP80MVAV
0P1aGFL206mGI@80MEMP0P1hFF<207EKI080NF9U0P1eI6H2071IIP80LEmW0P1gJ60207ESIP80MVAV
0P1QGF/205UDG`80H59G0P1WDE@206Y<EP80L5EI0P1VBeT207]FFP80MEiO0P1`FV8207QTHP80LV1S
0P1bGFH207INHP80KeMV0P1]F6<2071MH080KUeQ0P1_GF0206eNH@80IEUP0P1ZFE`205]AGP80G5EH
0P1FDe@204a5C`80AT9;0P0d=3l202l^=@809RHZ0P0H5A/202PN7P8091lP0P0b9B8204Di;`80<bl`
0P0d;C42038b;`80OUTW0P1E?E0205U<CP80FU1;0P0m9D8208iE@P<05AXn0P1><Bd205A9?P80CeI3
0P1[GT420:j4A080Pg=`7023Kg<2085ZL`80QVea0P20LG@208=bLA00Pfmc403oool000h0oooo0P24
J74208I]L@80P75d0P23LW4207e/M080QW1_0P21JW<208I]L@80OFad0P26L6l:08=_L`80PFYc0P26
KG4205`aJP809Q5@0P10:C<202dT<P80<c4_0P0[<2`2030/:08091/S0P0P6R4202`U8080MY`[0P1g
[34206]OHP80NFES0`1dIf@607ESIP80NF]V0P1`IVP207ESIP80MVAV0P1aGFL206mGI@80MEMP0P1h
FF<207EKI080NF9U0P1eI6H2071IIP80LEmW0P1gJ60207ESIP80MVAV0P1QGF/205UDG`80H59G0P1W
DE@206Y<EP80L5EI0P1VBeT207]FFP80MEiO0P1`FV8207QTHP80LV1S0P1bGFH207INHP80KeMV0P1]
F6<2071MH080KUeQ0P1_GF0206eNH@80IEUP0P1ZFE`205]AGP80G5EH0P1FDe@204a5C`80AT9;0P0d
=3l202l^=@809RHZ0P0H5A/202PN7P8091lP0P0b9B8204Di;`80<bl`0P0d;C42038b;`80OUTW0P1E
?E0205U<CP80FU1;0P0m9D8208iE@P<05AXn0P1><Bd205A9?P80CeI30P1[GT420:j4A080Pg=`7023
Kg<2085ZL`80QVea0P20LG@208=bLA00Pfmc403oool000h0oooo0P20M78208=bL@80Pfmc0P21JW<2
08=_L`80Pg9a0P1mK7@208I`K`80P75d0P23LW4:08=_L`80OFad0P26L6l202`RI080@SmB0P0a@CP2
02HS;@80ACT_0P0V92`2038W:P8071LP0P0]:2@202/[9@80]7`D0P1jGE`206]DIP80OfAN0`1eHVL2
07U[IP80L6IX0P1eHfH207YRI080M5mZ0P1bGFH207IKI080J4]T0P1dDf02071LH080LU]O0P1bFF42
07ULH080NV5U0P1[GfP207ASHP80N6ES0P1dHfH207ITIP80IUYY0P1GC642069AEP80GTaD0P1WDE@2
06U?D`80JUYL0P1aIEH2079MG`80LV9R0P1`FEl2079BH`80KdmP0P1fDel206mFHP80KEYP0P1_Fel2
071LH080KeiP0P1/Ff0206UMH@80HE9L0P1WFEd205YFF@80FDiF0P1@CU@204I4BP80>CU40P0_;SD2
02XW;@805ADM0P0J4Q@202TL7P80;bLS0P10;BP203/`=@80<bl`0P0f;Rl207IF;P80DTQ=0P1IAdP2
05e:C@808Q`k0P2JE2T301TUCP80>S4Z0P1P@3@206EGAP80KgA<0P2QRdT408=_L`80PFYc0P26KG4F
08=_L`80OFad0P26L6lD08=_La00oooo000>0?ooo`80P7Ab0P23LW4208=_L`80PFYc0P23Kg<208=b
L@80OFad0P26L6l2081aM080Pg9a2P23Kg<207e/M080QW1_0P0/8V@2048oDP80<D4h0P0V8bd204Di
;`809R@/0P0b9bX201`G8080;BPT0P0[:bD20;Al5080NUeL0P1[E6H207mTGP<0MF9W0P1iJfH2071V
J080MF=V0P1jHV@207AOJP80LUeV0P1fFf@206Q;I080M5=P0P1`G602079KG`80LUUQ0P1iG60207YQ
I@80JemX0P1dHf8207QUH`80M6=V0P1fI6H206IJJ@80EdaQ0P1RDEH205i<E080Ie5D0P1YCe<206YJ
G080LFEF0P1bGEl2079RHP80L5UO0P1bDV<206m?H080MU=O0P1_EV8206eJH080Ke]O0P1`G60206mN
H080K5]P0P1YGF42065BG080IeUM0P1JEUT205U>EP80D4iD0P16A4X203TiA080;bhe0P0Z9bd201DE
7@806Q8D0P0Y71h202lW8`80@2dX0P0k<3D203<_<080=Rh_0P1fERh20598C@80FDM80P1MBTd2028L
>`80VU@Y0`0I9Dh203Xa:P80H40d0P1UEdH206mdC080XH]91023Kg<2085ZL`80QVea5P23Kg<207e/
M080QW1_5023Kg<@0?ooo`003P3oool608=_L`80OFad0P26L6l208=_L`80P75d0P21KG4208I]L@@0
Pfmc0P21JW<608AXL@80Pfmc0P23LW42018BC`80KD0h0P0[9c`203Lg>@80=C4[0P0a;3@202TW9`80
5a<M0P15?2D205F>>080NI/]0P1UBed207UGGP80OFUM0`1dHfH207YPI080MEiY0P1eHfH2079MI@80
M5QU0P1`EfD2079IHP80IUiV0P1QCeX206i3F080MTiK0P1bF5h207AKG`80NEaP0P1/E6H207EHH080
OF5Q0P1eHVL207ITIP80H4mW0P1KC60205]9D`80HdmD0P1OCe4206A<E080KU9B0P1gFUT206mLG`80
KU9N0P1]D64206Q;G080JDYK0P1ZAeL206e3F080J3eG0P1b@UL206i4F@80MTiK0P1]Del206eDG@80
HeQQ0P1YGUT205]AG@80FDiF0P1BA50204TnC@80?3E20P0f=S`202X/<0807bHY0P0>3Q4202<G5P80
:Q`N0P10;RP203T/;P80?SLe0P0]:Rh207A<;@80G4e=0P15=TL205dh@`807adl0P2NM1l301laD@80
;2P^0P1/DS0206UNA080Pg5>0P2HOeP408=_L`80P75d0P23LW4608=_L`80PFYc0P26KG4<08=_L`80
P75d0P23LW4408=_L`80PFYc0P26KG4<08=_La00oooo000>0?ooo`H0Pfmc0P1mK7@208I`K`80Pfmc
0P20LG@2085]L@80QVea1023Kg<2085ZL`H0Q6Qa0P23Kg<208=bL@804Q9?0P1]@3P202/W?080=cLi
0P0e<B/2034/=080:BLW0P0G4ad204Dl9@80EHhh0P1iVbd206E;G@80NEMN0P1mJEd307ASIP80NV1T
0P1eGVT207ESIP80LUeU0P1dF6D2071GI@80LUUR0P1VGVH2065?FP80KT=H0P1fCU/2079HGP80M5]O
0P1iG60206aDIP80MEQP0P1mHF4207ERI`80MVAV0P1PCfL205]<H080FdUC0P1SCe@205m?D@80I4aD
0P1^DU8207MJF@80KeaO0P1^DUh206e@H@80J4]L0P1YBU/206Y7E`80KD=H0P1X?EL20792E`80KTAI
0P1fCU/206eCG`80KEAM0P1SF64206UNF@80Fe5M0P1ICUH20594D080BCi=0P0l=D8203Hf?080:R``
0P0O9RT200h>4@808aLF0P0Z71h2040^:080>B`^0P0n=cD202dZ;P80M4`]0P1LCDd204DfA`80GCQ3
0P0O7C`209id7`<07c5A0P0/:2h206aB<080JEi40P23LDh209QoF0@0Pfmc0P20LG@208=bL@H0Pfmc
0P21JW<208I]L@`0Pfmc0P20LG@208=bL@@0Pfmc0P21JW<208I]L@`0Pfmc403oool000h0oooo1P23
Kg<2081aM080Pg9a1023Kg<2081aM080Pg9a0P21JW<208I]L@80OFad0P23LW44081dLP80Pg9a0P27
N7<200LZJ080E4<^0P0Y7cT203dZ;@80<BD`0P0j;bl201D?6`80<b/Y0P0c;R420:]g9080E3iC0P1/
>eL208=TDP80NVQP0`1dHVL407ESIP80LUeV0P1]EFD206I4G`80GR]E0P1U84h207/aD@80HCiJ0P1H
>E0207U8CP80KDQG0P1oGU/2079SH@80JEeU0P1_H5l207eWG`80M6EV0P1eI6H205mNJ`80EUAN0P1D
BEH205i5C@80GdA@0P1_HE8205iIEP80NF1E0P1TC5d206Q7F`80HcmF0P1N=e@205HZB`80H2]:0P1X
>T`205e0D@80HD5=0P1WAE4207IHDP80JUUL0P1SCE/406U:F080HDaJ0P1ICEH2055:D`80B49;0P10
?TH2038/=`80;bHa0P0X9BX201XS9@807B0I0P0Q6QX203dZ8`80<bH/0P11;Rh2038/=080HdL]0P1K
>d<204<dBP80CS/m0P0X:Ch209ie7`<07b5:0P0]930207QJ:P80HDe80P2BJ4/209b1G@80OG9e3023
Kg<2081aM080Pg9a5023Kg<2081aM080Pg9a3023Kg<@0?ooo`003P3oool608=_L`80P75d0P23LW44
08=_L`80P75d0P23LW42085ZL`80QVea0P1mK7@208=bL@@0P7Ab0P23LW4208MhL`801bYX0P1D@bh2
02TO>@80?BX]0P0a9C0203X_;`805@lK0P0c:bT203<^8@80ZgLT0P1D?U<206`kE`80PfAB0P1jJ603
07ARI`@0MF=V0P1bGFH206eEI@80ITAO0P1N:eD206DPCP80Nc5A0P1Q?UX205PiD080NDQ>0P1]B5L2
07mNF`80LV=Q0P1YGFD206mPG`80OFMO0P1dIFH207ETIP80Gei[0P1FE5h205A9EP80GTE=0P1OA502
06mQDP80GUUF0P1iH5D206A<G@80J4MK0P1S?eH205hgE080ERY;0P1P:dX206PjC080GD1A0P1Q@Dd2
06M5D@80MUQB0P1ZFE`206==F`@0JDYH0P1QC5X205U=EP80DDYC0P18@T/2040nAP80<R`g0P0_9S42
02PU:P806R<U0P0M81T2024J6P80?BXS0P0c9R`2044^;P80<R`d0P1SAbd205/k@`80@cA:0P1>>cd2
02PY?P80WWDO0`0O8DX202dT<080N5XZ0P1QCDP2099XB`80W85M0P1mLWD<08=_L`80P75d0P23LW4D
08=_L`80P75d0P23LW4<08=_La00oooo000>0?ooo`80Q6Qa0P26KG4608=_L`80PFYc0P26KG42085Z
L`80QVea0P20LG@208=bL@80P75d0P23LW4608=_L`80FbAT0P0d6V82048i>0809Aha0P0g9bX202`Q
:@80?Rh/0P0E6B@2040h8@80Gi0h0P1aRS0204LoH@80I5=:0P27J4d207INH@<0N61U0P1eHfH206mG
I@80IdAQ0P1C8U82068SCP80IU5E0P1<He<203TU>`80DQ@j0P1L:4@206i3@P80G3I>0P1];DP20959
EP80Ke]S0P1]FV0207mUGP@0MF=W0P1VFFT205YFH`80CdaH0P1KDe020555C@80LTM80P0e43d206H=
>080K1e:0P1`@4l206]XF080=C=<0P0f5cL205/]>@80Dblm0P1B:D4205<Y@@80GRm20P1i@TL206i7
EP80HdaJ101SDeH405e<E@80D4AA0P1:?d`203hc@@80=c<m0P0_<C8202PU:P80;Rl[0P0F5a/201`E
6080?BdQ0P0a:R`203X^;080?SPd0P1FBS<205M;A080?CQ40P1;?3h202XV>080XVdS0`0L:E4203Y2
=`80MW0]0P1JG54209F3A`80TWYP0P23JWHJ08=_L`80PFYc0P26KG4F08=_La00oooo000>0?ooo`80
Q6Qa0P26KG4608=_L`80PFYc0P26KG42085ZL`80QVea0P20LG@208=bL@80P75d0P23LW4608=_L`80
FbAT0P0d6V82048i>0809Aha0P0g9bX202`Q:@80?Rh/0P0E6B@2040h8@80Gi0h0P1aRS0204LoH@80
I5=:0P27J4d207INH@<0N61U0P1eHfH206mGI@80IdAQ0P1C8U82068SCP80IU5E0P1<He<203TU>`80
DQ@j0P1L:4@206i3@P80G3I>0P1];DP20959EP80Ke]S0P1]FV0207mUGP@0MF=W0P1VFFT205YFH`80
CdaH0P1KDe020555C@80LTM80P0e43d206H=>080K1e:0P1`@4l206]XF080=C=<0P0f5cL205/]>@80
Dblm0P1B:D4205<Y@@80GRm20P1i@TL206i7EP80HdaJ101SDeH405e<E@80D4AA0P1:?d`203hc@@80
=c<m0P0_<C8202PU:P80;Rl[0P0F5a/201`E6080?BdQ0P0a:R`203X^;080?SPd0P1FBS<205M;A080
?CQ40P1;?3h202XV>080XVdS0`0L:E4203Y2=`80MW0]0P1JG54209F3A`80TWYP0P23JWHJ08=_L`80
PFYc0P26KG4F08=_La00oooo000>0?ooo`80P7Ab0P23LW4608=_L`80P75d0P23LW42081aM080Pg9a
1023Kg<2085ZL`80QVea1P23Kg<202X[J`80DDa>0P0c?44202dc>P807APO0P0h9bT203Xc:`806AXU
0P0Q4aH20<M]5`80FeAL0P1FDUd205mND080Pfa>0P1eJ6<3075QI080L5=T0P1VA68204`XE080CcA@
0P1XLdL206j=C080<2M:0P0g7T42038T;@80Dc8a0P1G<CX206=5B@80CdU:0P1oET8206e2FP80NUIL
0P1oJ5d207ESI`80LE]V0P1ZF6L205mDH@80De1L0P1B@Td204`dB`80GCQ20P0oE5X202Hb<@80S7Xc
0P1YYdl203HYB080A1Y:0P0b<3X205E;<P80<bDf0P1VD3d203Hk?`80@bXf0P1V<cT20794BP80HTUC
0P1WD5@2069BEP80FTeF0P1JBE4205E;DP80A3i:0P0n=T<203/d>P80;BHa0P0Z8RX2024F7@802`H=
0P0I4182040]7`80=S0^0P0Y7bH204`c;P80EdDh0P1A?D0203X[@@80CCPj0P0b=Cl208aV:0<071M1
0P1TDCD206aW?080H59D0P2XQdH208=hK1H0Pfmc0P21JW<208I]L@80Pfmc0P20LG@2085]L@80QVea
5023Kg<@0?ooo`003P3oool2081dLP80Pg9a1P23Kg<2081aM080Pg9a0P20LG@208=bL@@0Pfmc0P21
JW<208I]L@H0Pfmc0P0Z:f/2055<CP80<ca10P0]<cX201dH7`80>2LY0P0j<b/201TJ9@808A<F0P37
KAL205]DG080EU9M0P1OGU0208=/CP80MFQS0`1aHF@2071CI080ITAR0P1<:5@204ldD080J7=70P1^
SD`2030WBP80=ai10P0b92d205<b<@80Ec4j0P1SADT204m9BP80OeI20P1]@UX207YFG080OfQM0P1e
HfL2075KIP80JUQW0P1OE64205=@G080DT9=0P1<=4/205dh@P80?eAJ0P0V<S4208aj<`80JJM?0P0f
:DP204@JBP80<S0j0P1EBc8203<U=P80IU0m0P0f>cl204<Z=P80IS<i0P1bA4X20699D`80Ie1D0P1R
DUH205Y=EP80FTUA0P1EBe8204@nBP80?SI30P0k=3X202dV<@80:R8Z0P0Q5Qd200/63@806A0B0P10
;Al203H`;P80:AlV0P1<<bh205M5>080DCe00P0j:d4204dh>P80<SDo0P2<IRP301`G@@80I54e0P1/
Ic`2061BE080Z8M60P23N6`F08=_L`80PFYc0P26KG4208=_L`80P75d0P21KG4208I]LA@0Pfmc403o
ool000h0oooo4023Kg<2085ZL`80QVea0P23Kg<2081aM080Pg9a1023Kg<208MhL`80<i>@0P0ZCDd2
02dJ>@80<A//0P0K5B8203/^8P80=BTZ0P0Y;30202Y1;@80/9D;0P1BAf8205Y0DP80K4mA0P1nGe42
07YJH0<0KeIU0P1QAV0205DbE`80?2A90P0W3BH208h[<080Pci=0P0[:E/205If@P801`TC0P1Q;2@2
02`G:@80Gb<`0P1K<4<206Pl@@80MU5B0P1iJUD207]YG`80MF=W0P1]H6P206UMI080HEQR0P1KG5h2
04A6E@80BD=:0P11<Ch2064j?P80>e1E0P1?<b`20:`dAP80719:0P1dKST200P84`80HR0V0P0]7c@2
07YD;0805P/V0P0o62T205/g<@80HS/m0P1O>DX206]8C080HTYC0P1MBe@20550D080FD1;0P18?Td2
03dh@P80=2Xf0P0_9S4202`X:`804Q0H0P0?3A4201LD4@808a@D0P0o8bH202PS:`80DD@[0P17=SH2
04dc?@80@CY20P18A3/203Pd?080PUdb0`0G7D4206i<:@80JDY50P1cHe@20::9BAP0Pfmc0P20LG@2
08=bL@@0Pfmc0P20LG@208=bLA@0Pfmc403oool000h0oooo4023Kg<2085ZL`80QVea0P23Kg<2081a
M080Pg9a1023Kg<208MhL`80<i>@0P0ZCDd202dJ>@80<A//0P0K5B8203/^8P80=BTZ0P0Y;30202Y1
;@80/9D;0P1BAf8205Y0DP80K4mA0P1nGe4207YJH0<0KeIU0P1QAV0205DbE`80?2A90P0W3BH208h[
<080Pci=0P0[:E/205If@P801`TC0P1Q;2@202`G:@80Gb<`0P1K<4<206Pl@@80MU5B0P1iJUD207]Y
G`80MF=W0P1]H6P206UMI080HEQR0P1KG5h204A6E@80BD=:0P11<Ch2064j?P80>e1E0P1?<b`20:`d
AP80719:0P1dKST200P84`80HR0V0P0]7c@207YD;0805P/V0P0o62T205/g<@80HS/m0P1O>DX206]8
C080HTYC0P1MBe@20550D080FD1;0P18?Td203dh@P80=2Xf0P0_9S4202`X:`804Q0H0P0?3A4201LD
4@808a@D0P0o8bH202PS:`80DD@[0P17=SH204dc?@80@CY20P18A3/203Pd?080PUdb0`0G7D4206i<
:@80JDY50P1cHe@20::9BAP0Pfmc0P20LG@208=bL@@0Pfmc0P20LG@208=bLA@0Pfmc403oool000h0
oooo4023Kg<2081aM080Pg9a2P23Kg<205HNH@80WRAO0P0b:VL202lk@`809bh_0P0T:BX203Da9080
<RX[0P0g<Rh204Y@=@80Sg8[0P1?>eh205Y8D@80JUQ<0P1lI5<207ARG`<0HdiR0P1I@Ud204LhDP80
9QPd0P0c;cL204Pd8`80=PLV0P0Q01l203/570809aXo0P15BAl202db>080C4`^0P1HDcd206=ZB080
KFm<0P1jJUP207IQH@80NF9U0P1_H6P206UKI@80IEUR0P1REed204aCGP80ATi>0P10BT/204@k>P80
BbTk0P1<?TP206A1=08060/b0P0]21D201h:;`80:alF0P0b6bT203LC7@80;A`k0P0_=2@205I2;@80
Dd0m0P1B>d8206A2A080HTE>0P1MAe0204i2D@80CC]60P1:=D@203DT>P80=RLd0P0d;S4202TU:@80
720U0P0A5AD2028R6P808RDM0P0Y81`202lQ9`80CSLY0P16>C/203lc=`80?bTf0P1B>SX203dk@080
Nf4d0`0M;4`2065C;P80Hdm50P2BPdP208f6FbP0Pfmc0P21JW<208I]L@`0Pfmc403oool000h0oooo
4023Kg<2081aM080Pg9a2P23Kg<205HNH@80WRAO0P0b:VL202lk@`809bh_0P0T:BX203Da9080<RX[
0P0g<Rh204Y@=@80Sg8[0P1?>eh205Y8D@80JUQ<0P1lI5<207ARG`<0HdiR0P1I@Ud204LhDP809QPd
0P0c;cL204Pd8`80=PLV0P0Q01l203/570809aXo0P15BAl202db>080C4`^0P1HDcd206=ZB080KFm<
0P1jJUP207IQH@80NF9U0P1_H6P206UKI@80IEUR0P1REed204aCGP80ATi>0P10BT/204@k>P80BbTk
0P1<?TP206A1=08060/b0P0]21D201h:;`80:alF0P0b6bT203LC7@80;A`k0P0_=2@205I2;@80Dd0m
0P1B>d8206A2A080HTE>0P1MAe0204i2D@80CC]60P1:=D@203DT>P80=RLd0P0d;S4202TU:@80720U
0P0A5AD2028R6P808RDM0P0Y81`202lQ9`80CSLY0P16>C/203lc=`80?bTf0P1B>SX203dk@080Nf4d
0`0M;4`2065C;P80Hdm50P2BPdP208f6FbP0Pfmc0P21JW<208I]L@`0Pfmc403oool000h0oooo2023
Kg<2085ZL`80QVea1023Kg<2085ZL`80QVea2P23Kg<2028TI@80NS`l0P1<?5/202XX?080:Qh]0P0i
=Bl202h_:`80;2<X0P0f9BP206=8<@80NUTm0P1AAEX205Y>C@80JEI>0P1mHe82071JG`<0IEaU0P1I
IF4204QVG0809V=H0P0aDCL203<d=0809b/a0P0U=B`202Xh9P80<S4V0P18?30204QD?P80EG@n0P1L
NdP206]jCP80JVYJ0P1gIe`407EWI080Kf1X0P1YFfD206YPHP80IFEQ0P1FGUl204eJF@80C5U@0P11
E4d203i>A080>B/d0P1F;c/202m;C@8096<i0P0TBRh2024/9P809b4P0P0/9BH204I6;080@V0k0P18
GSP204a;@P80De560P1JF4L205Y@C080Dd9=0P1EA4d204Q4BP80?SE00P0a:CT203D]<080<RP]0P0_
:Rh202<U9`805QLK0P0U81X2020I70808APL0P0^8R42050m:`80BT<j0P0k>Cd203Lb=P80DT4e0P1<
Bd<2071R?0<09Ri=0P1MC3D206MFAP80YH910P29MFXX08=_L`80P75d0P23LW4<08=_La00oooo000>
0?ooo`P0Pfmc0P21JW<208I]L@@0Pfmc0P21JW<208I]L@X0Pfmc0P0R96D207Xl?080C3aK0P0Z:3`2
02XN;@80>CD_0P0^;b/202`S:080=RDX0P1SB34207YI?@80DDEJ0P1JCTd206UFCP80OF=B0P1`FUl3
06ELI@80FFEQ0P18IU`202ISF080<E4g0P0c=3@202L[<@809CD/0P0Z>2H2038a9P80B3``0P18E3h2
05Ed?P80G7]80P1[NTh206YZFP80MfML101eIf@206mPJ080JE]U0P1ZH68206EUH@80EUiO0P1=FUT2
04aID080@EA=0P0nCT@203T[=080ERlk0P0_Bdd202AS>@8094X^0P0Q;2H202LQ8080;2DV0P16AR`2
049P>`80B5hh0P1<Bd8205=AAP80FUQ70P1JD4`205=2C@80EDA=0P18A4X203he@080<BTi0P0e;C02
038X;@80;bX^0P0S9BL201HG6`809B0J0P0P6A`2024H7080;R8Q0P1@?B/204Y3>P80>cTm0P0g<SH2
0591=@80C4]30P1`HS`302H^C@80GD`e0P1WETH20:F2@@80RGEZ:023Kg<2081aM080Pg9a3023Kg<@
0?ooo`003P3oool808=_L`80P75d0P23LW4408=_L`80P75d0P23LW4408=_L`80PFYc0P26KG4208=_
L`80;8V@0P0aEdT204<R?P80:AHd0P0Y7RL203<Q9080;ahY0P0T6R<204Hl;080Fe8`0P1UAD4205a1
D@80ED5<0P1[C4/2081OD080LF=Q0`1/IV8206abH`80FgEV0P1<O6@203jDG`80<9iG0P0[XE4202fQ
BP80<JM90P0a[dX203bPAP80A6e80P1RG4P206]FD080NEiF0P1fJf4206mWHP80N6=S0P1eHVH207=U
J080JVEW0P1/IF8206]OHP80GUAR0P1CAEP205a:DP80CDE?0P1FFdh203YbE080Ag]30P13FTP204QD
B080?Ei:0P0bLTP202n;@`80<YM00P13R3d205AgAP80DG1A0P1>Ke42059SC@80FUQ>0P1GCU020517
C`80Cd170P1@?dP203lmAP80;Rhh0P0i<S8202hZ;P8091XS0P0V6B8201PE6`809AhK0P0[:R@202@Y
8`80924O0P1A>2L205Q:>`80=C@n0P0i;cL205U:=P80EDm20P1^GTD302XaC`80Ge4i0P24S4D2096S
C@80OGQa=023Kg<2085ZL`80QVea403oool000h0oooo2023Kg<2081aM080Pg9a1023Kg<2081aM080
Pg9a1023Kg<2085ZL`80QVea0P23Kg<202b9T080<EM90P138Sh202TF=080:AhW0P0c8B@202lN:@80
91XS0P16?2`205]B<080IDE10P1L@E4205E1C080Jda;0P20Ge02075SH@<0K6IR0P1/LV<205]eIP80
C7aT0P0nU5l2032NE`80:j5A0P0]XDX2036WB@80<Jm:0P0lX4H204A]B080HUa80P1[EU0207UNEP80
MV]Q0P1_If8207QSH`80MF9V0P1cIFP206YUI`80K6ER0P1[Gf8205iDHP80DdEH0P1LBU8204e5C`80
EU]>0P0jLU@204Mk@`80@eY80P18E4P203eNBP80<W980P0_Rd<203:G@080@hPm0P1DMdH2055`D@80
CVmA0P1BHdd205YHCP80Edi@0P1@Adl204m0A`80D3m80P0o?DH202h^>080>C8b0P0^:Rh202@J8`80
9QTR0P0H5A/202DN6`80:bXT0P0T:B<202@Q7`80DCPW0P1HBS/203Dd?P80>Blg0P1IBSH205E?@P80
KUi50`0Z<Dl205mA>@80Q8a50P2AXdd207ehLC@0Pfmc0P21JW<208I]LA00oooo000>0?ooo`@0Pfmc
0P21JW<208I]L@80Pfmc0P21JW<208I]L@P0Pfmc0P21JW<208=_L`80Pg9a0P27N7<207N1N@804A14
0P1173<201`C8`80:1XP0P0W720203lg;08061XQ0P13:B4205Ha<@80Hd900P1IATT204hmBP80Je16
0P23JTh206YFG`<0NeiP0P1iIV82075VJ080K6]W0P1^Kf@206MbI`80HgQT0P1AEUl205<aCP80FAa5
0P1G4d<205@IA080PeA60P1ZKUH207EgF@80MFaQ0P1bIFP207Q^I@80L6IX0P1fI6H2075TJ080KV=V
0P1`JfD205YOIP80De]O0P18?dd2044R@@80ER4i0P1F7Sl206@]A@80KV=B0P1DPeH205:8F080DHEG
0P1EN5H205a`EP80FVIH0P1QHUD206=MF080GUEH0P1ICEH205@oC`80D3590P1M@4X204Y2BP80B3U2
0P14<T4203Hc?P80<bla0P0_9bl202/^;P806ATL0P0J5AT201dF5`80:1XL0P0J3aL2038T8`80@34U
0P1F=38203/]?`80>30e0P1QCCD205I;A@80N6I70`0Z>5D206AG>`80Y8<l0P2BMF<208=ZMS@0Pfmc
0P20LG@208=bLA00oooo000>0?ooo`@0Pfmc0P21JW<208I]L@80Pfmc0P21JW<208I]L@P0Pfmc0P21
JW<208=_L`80Pg9a0P27N7<207N1N@804A140P1173<201`C8`80:1XP0P0W720203lg;08061XQ0P13
:B4205Ha<@80Hd900P1IATT204hmBP80Je160P23JTh206YFG`<0NeiP0P1iIV82075VJ080K6]W0P1^
Kf@206MbI`80HgQT0P1AEUl205<aCP80FAa50P1G4d<205@IA080PeA60P1ZKUH207EgF@80MFaQ0P1b
IFP207Q^I@80L6IX0P1fI6H2075TJ080KV=V0P1`JfD205YOIP80De]O0P18?dd2044R@@80ER4i0P1F
7Sl206@]A@80KV=B0P1DPeH205:8F080DHEG0P1EN5H205a`EP80FVIH0P1QHUD206=MF080GUEH0P1I
CEH205@oC`80D3590P1M@4X204Y2BP80B3U20P14<T4203Hc?P80<bla0P0_9bl202/^;P806ATL0P0J
5AT201dF5`80:1XL0P0J3aL2038T8`80@34U0P1F=38203/]?`80>30e0P1QCCD205I;A@80N6I70`0Z
>5D206AG>`80Y8<l0P2BMF<208=ZMS@0Pfmc0P20LG@208=bLA00oooo000>0?ooo`@0Pfmc0P20LG@2
08=bL@80Pfmc0P20LG@208=bL@P0Pfmc0P20LG@208=bL@80Pfmc0P21GW0209MZL@800A150P0e8b<2
01/F8P809R0N0P0/:2@203T/908092@^0P0o?bL204Dk<080EcTg0P1J>d@204lnB080ID]30P2:H4X2
06MII0<0L5EJ0P1lDUh207eOI080M69W0P1eHVH2075IIP80D25F0P1E5Dd204HPA080Abln0P1LI4@2
052JB`80JYQ30P1]LEd207UZG`80NFYW0P1aIVP207eXI@80L65[0P1fI6H207ATI`80LVIW0P1bHF@2
06USJP80GFUT0P14IF<2035DD@80;c0f0P0h82h204PP;P80IAlc0P27<DX207A4E`80MeIL0P1ZHF42
06UUG`80H5YO0P1XGE/205mAFP80GdUH0P1B?54204H/B080FTM80P1?AT<204`jA`80@CA20P0n;c/2
03hb>@80<B`d0P0S6RD202TH8@806A8L0P0O6a/201XG60806Q<E0P0`;RD203<l9@80?Sh^0P1:@c@2
03`h?080<R`d0P1UB38205=0A@80NE130`0m@Ud205aG@@80/h/k0P23N6`j08=_La00oooo000>0?oo
o`@0Pfmc0P20LG@208=bL@80Pfmc0P20LG@208=bL@P0Pfmc0P20LG@208=bL@80Pfmc0P21GW0209MZ
L@800A150P0e8b<201/F8P809R0N0P0/:2@203T/908092@^0P0o?bL204Dk<080EcTg0P1J>d@204ln
B080ID]30P2:H4X206MII0<0L5EJ0P1lDUh207eOI080M69W0P1eHVH2075IIP80D25F0P1E5Dd204HP
A080Abln0P1LI4@2052JB`80JYQ30P1]LEd207UZG`80NFYW0P1aIVP207eXI@80L65[0P1fI6H207AT
I`80LVIW0P1bHF@206USJP80GFUT0P14IF<2035DD@80;c0f0P0h82h204PP;P80IAlc0P27<DX207A4
E`80MeIL0P1ZHF4206UUG`80H5YO0P1XGE/205mAFP80GdUH0P1B?54204H/B080FTM80P1?AT<204`j
A`80@CA20P0n;c/203hb>@80<B`d0P0S6RD202TH8@806A8L0P0O6a/201XG60806Q<E0P0`;RD203<l
9@80?Sh^0P1:@c@203`h?080<R`d0P1UB38205=0A@80NE130`0m@Ud205aG@@80/h/k0P23N6`j08=_
La00oooo000>0?oooaH0Pfmc0P21JW<208I]L@80QgQc0P1C=Fh20<1SE`8001aJ0P0W9B<202PW:080
:B`T0P0O6A`203/X9P80:RDZ0P0n;bT203`Z<080@BH`0P1H<CP205<k@P80HTa40P26IDL2071UH@<0
C3QI0P1`<4h207TaDP80KbYG0P1Z8E<205H?B@80BaY=0P1LEdH205FPCP80?K]C0P1IZTX206n;E`80
LGMT0P1aLVP207E`IP80NFYW0P1eJF/207ERI`80MEiY101eHVH207ISIP80LFAX0P1`HVD206eTIP80
HFmW0P19PVP202^=H@80:h]=0P0aJD4203Q1>080Aah^0P1P5CX205X@?080JQ530P1^74X206<QCP80
H2590P1F74P205LPA080Ebi80P1>BT/205EA@@80D4M;0P1:AdP203`i@P80>c<j0P0n=CL202dV<@80
=Shf0P0@4aL202/S8P809BXR0P0O8b4201LI6@807Q8D0P18:bP2048i<@80BC/g0P0m<CX203D`=`80
HDdb0P1IE4P2054k@P<0AB540P29K4<209jF@b00Pfmc0P21JW<208I]LAP0Pfmc403oool000h0oooo
5P23Kg<2085ZL`80QVea0P27N7<205<eKP80`6=G0P0075X202LU8`80:2LX0P0Y;2@201lI7080>bPV
0P0Z9BX203h_:@80?2X`0P119S0205Pa>080Dc]20P1RC4@208IUA`80L6EQ0`1<>5T2070`CP80NC5B
0P1_:UL206XQD`80EPm90P1;6Td205aGAP80EJ1>0P0m^e<205VZBP80Kh]G0P1aMf@2075bJ080MG1V
0P1iJVL207EYJ`80MF9W0P1eGVT407ERIP80MV=V0P1aI6P2071RI@80KFAV0P1QKfL204V2J080:heQ
0P0[Rdd2035Y@@80>44h0P177Rh2060E>P80FQ0l0P1Z4D<206hLBP80Hb5>0P1P8DT205HLB080Eb14
0P1G;TP204i:B`80EE510P1@Ad/204Y7B080?3U20P0k<cX203he=`80;BHa0P0f?SH2010C5`80:b<R
0P0U:R8201lS8@805aTI0P0N4Q@204P[:080@STa0P19>cL203da>P80=C0g0P1QCC8205UDB080DC]2
0`158D@208U/@`80WYI38023Kg<2085ZL`80QVea6023Kg<@0?ooo`003P3ooolF08=_L`80OFad0P26
L6l208U/L@80>C]h0P1N5S/202D3A080:b@Y0P0h=b/202``;08092XZ0P0_:B8202`S:080=bXX0P0i
;2h203Xa<@80BSTb0P1>=cX206iE@@80OfU:0P1fHEh304maL080DXQH0P1=G5@205A6D@80D4=>0P1B
JU82056/C@80F;=<0P1aSU@207E`IP80MFeY0P1iJVL807UVJP80NFMZ0P1_HF/207ESIP80NF]V0P1d
KVP207E^J080L6IY0P1bIVL2075WIP80LfQU0P1]I6H2069UI`80FG1S0P1<PF4203^HG@80;jYG0P0m
[DX202icC`80>TLn0P1:=3/204hb?`80BSA00P1CCDD204aOA`80BEM50P1ECdD205QBB`80D4e<0P1;
@dT203`gA080?SPl0P12?SX202PY<`80:APQ0P0U8Bh202<T7@808ALM0P0B2Q4201<:4080610C0P1=
=ah204@j=080>2Pb0P1<>CX203Lh>@80He@f0P1MCdH203LYA@<0DDE30P2SVBd208f3GR00Pfmc0P20
LG@208=bL@80PFYc0P26KG4D08=_La00oooo000>0?oooaH0Pfmc0P1mK7@208I`K`80RFaa0P0i>gP2
05hF>`809@=40P0[92T203Pg:`80;30/0P0T:RX202lY8P80;2<X0P0g:RP203T/;P80>S4a0P1:>C82
04hg>P80KUE10P1oJDX207IQGP<0Cg5`0P1BR5P204eLE080E4IA0P1@@dh2059ZDP80DJa=0P1H/d`2
076>E080MG1V0P1eKFT207UZI`P0NFIZ0P1iIfX206mQJ`80MF=V0P1iJfH207A^J080MFiX0P1`IVT2
079VI`80LFMV0P1cJ6D206eTIP80HVEW0P1IL6<204b1H@80>iQM0P0_ZUL203f]BP80;W=?0P0jAch2
04Xd>`80CS8o0P1:=40205==A@80C5m70P19EdD205E?A@80F59;0P1@CD`204]3B@80?3M40P0n>3`2
048n>P80:2Tc0P0Y624202DQ;P808b@M0P0Q5ad2018:4@804`X@0P0H41<204dg7P80A3Xd0P0h:382
04`i>P80=cPi0P1SE3H205e?AP80=bU50`1AAD<20:>I;@80SH=N8023Kg<2081aM080Pg9a0P21JW<2
08I]LA@0Pfmc403oool000h0oooo2023Kg<2085ZL`80QVea1023Kg<2085ZL`80QVea0P23Kg<2081a
M080Pg9a0P23Kg<2045JO`80939=0P0Z:SD202TW:080CTL^0P0`?3P202/a<080;Rl[0P0Y9bL203Ta
:P80=S0^0P0k<C0204Xn=@80AC/j0P1aDCX208ASC080LUeO0`1dGV8206iRI080GWQZ0P1ATF8204bI
GP80Gi=D0P1eMeP207iXI0`0NFIZ0P1iIfX207QWJP80NFIZ0P1`H6`407U[IP80NFIZ101eGVT207ER
IP80MF9W0P1eHVH207=UJ080Jf9V0P1^Hf<206mWHP80JF1R0P1]GV4206eOH080DV=X0P16QUl2042K
E080?XeA0P12OU0205=cB@80EEe?0P1ADe4205UJC@80D4M;0P1A>dX204TdA@80@CA20P14?Cd204<l
>`80<cPm0P0P:Bd202@O8080610H0P0B2a42014<4@804@h?0P0G4a8206aN7080<CDe0P0d:C@206QR
=080;CY00P1H?3@206mDA`80:C590`1WEcP20;>E=080PgQ/9023Kg<2081aM080Pg9a5023Kg<@0?oo
o`003P3oool808=_L`80PFYc0P26KG4408=_L`80PFYc0P26KG4208=_L`80P75d0P23LW4208=_L`80
@EYo0P0T<Td202XZ=@80:BLX0P1>Abh2030l>080:c4`0P0^;b/202TW9`80>C4Z0P0f<2h203/a<080
BShe0P15>cX2075A>P80Q6=<0P1bGEl307ANHP80KV9T0P1NN6X2056AHP80C9UN0P1OTe@207EgF080
OVQT301iIVX207UWJP80N6MZ0P1iIVX2071PK0@0NF]V0P1iIVX407ENJ@80MF9V0P1eHVL207ERIP80
LfEX0P1[HVH206iSH`80KfMR0P1YH68206eNH@80KEmP0P1BHfP204J6G`80@9]D0P0nSE42049nD080
Dg=90P1EGDl2055CD@80FEY=0P1@Ad/2054kBP80BCA50P11=48204@m?@80@c`k0P0c>3d2020Y;@80
91lP0P0H41P2018;4@804@`A0P0A3Pl201LC4P80K5hL0P0a=CD203@Y=080J68d0P0]>T0205Pl=080
KeA70P0Y<DT306MG>080/iDd0P23N6`T08=_L`80P75d0P23LW4D08=_La00oooo000>0?ooo`@0Pfmc
0P21JW<208I]L@80P75d0P23LW4208=_L`80PFYc0P23Kg<208=bL@P0Pfmc0P1;@gD201dF@P80<R0]
0P0c;Rh205YA;P80<cDm0P0]:34203D];P80;bl^0P0f<2/203D/;P80>B`^0P1@?S@2040f>`80L5<i
0P23I4T207=RH0<0LF=Q0P1bHF<207YVHP80MF=W0P1dHVL207U[IP80M6iX0P1eHfH207YMI`80OFAX
101iIVX207EPJ@80OFAX1P1iIVX2071RJ`80NF5T0P1nI6P407ENJ@80NF]V0P1`IVP207ETIP80M6EV
0P1eI6H2071VJ@80Jf1U0P1eHF8206YLI@80KUiQ0P1]Ff0206IGH@80LV1L0P1UDEh206IAGP80GU5J
0P1MBeD205i;E080Ed]B0P1MBdh204i2D@80D4U;0P16BDT203/i@080ASTk0P14>C`203<X=@80>3Pi
0P0N9bT201HG6`8061TH0P0D5A<201hO6@805QLE0P22GQD203<oB080;C4d0P1bCRd203HdB`80@C<f
0P21EST202T]C0<0PW4d0P2^VSh207ebMC`0Pfmc403oool000h0oooo1023Kg<2085ZL`80QVea0P20
LG@208=bL@80Pfmc0P21JW<208=_L`80Pg9a2023Kg<204]3M@807AI20P0b82d203<^;P80FU4^0P0c
=Cd202dX<@80=Bd^0P0_;bh203H`:`80=B`^0P0i;2h2050n=080@3Hk0P1`DcT208=TB@80Lf9P0`1a
Hf42079QH`80NVIR0P1eHfL207ARI`80NF]V0P1dKVP207ESIP80NUeW0P1mI6P407UVJP80MF1Y0P1m
I6P607UVJP80L69[0P1iHF@207iTJ0@0MEiY0P1iJfH2071VJ080MFAV0P1dIFH207ETIP80L6IY0P1[
H6D207EQHP80JUaU0P1^GV4206eKH080IUMQ0P1bH5`206EAGP80IU5N0P1NDEX205e;E@80GT]D0P1G
Be8205e;CP80CT9A0P1@BD/204I9B@80>cU00P16>C/204@i?080<bPe0P0h>3T201hW:@805QLK0P0H
6AP201@E4`807QlI0P0F5aD2089N5@80<cm80P0]<C@2079>;@80=SA;0P11<cH2085F>@80:Be<0`22
LC@20:jJ?P80OG9e?023Kg<@0?ooo`003P3oool408=_L`80P75d0P23LW4608=_L`80P75d0P23LW4:
08=_L`80Been0P0A9DP203/l<080=CP`0P1>>2l203LW>P80>3Dg0P0e=c42038^;`80<RT/0P0c9b`2
03@W:`80Bc<^0P13=3X206=2=`80REM50P1hFe`307ANHP80LV1S0P1fGV8207YQI@80M6AW0P1iHF@2
07iTJ080M6U/0P1aIfP207eXI@@0NFIZ0P1eJF/207UZI`H0NFIZ0P1eJF/207A]J@80NF]V0P1dJF`2
07A^J080MF=V0P1eGVT207ERIP80LeeV101fG6D206mOI`80LVAR0P1ZFfD206iLH@80K5]P0P1ZHF42
06YIG080IUIQ0P1SEe/205iAFP80GEEG0P1JDU<205YAD`80Edi@0P1DCe42051<B`80A3Q60P10=482
04Q1?@80?cLk0P0g=C`202`Q:@807Q8R0P0S7R8201`M70803`hA0P0D30l201L@5080REXD0P0l>4L2
03@f?P80KElb0P0f>DT203H]>080MDHa0P0a:4X30;JP9080S8aG0P23JWHl08=_La00oooo000>0?oo
o`@0Pfmc0P20LG@208=bL@H0Pfmc0P20LG@208=bL@X0Pfmc0P1;GGh2014UB080>c``0P0e>30204hh
;`80=bLj0P0h=CL203Dg<@80<Rh_0P0b:B`203<W;080=2L[0P1;<bh204<d>P80Hd8g0P29EdD207QK
G0<0M5iR0P1bH6<207INHP80NV5U0P1dI6L207UQI080OVAX0P1dJF`2075WJ080OFQU101iIVX207EY
J`80NFYW1P1iIVX207EYJ`80M6eY0P1iJfH207AYK080M6iX0P1eHfH207ENJ@80MF9V0P1cGFH407IL
I@80KemW0P1bI68206YKI@80KUaQ0P1/Ff0206YQH@80JUUL0P1VEV4206=GF`80GU5J0P1MEEL205YB
D`80FU5C0P1GCU0205A?D@80D4a;0P14>4H2040d@P80B44m0P0o=c/203Le?080;24Y0P0N4R8202<N
8P8071dL0P0?3Q4201@<3`805a0D0P29FQ@203`hA`80=3Hn0P1]Gc8203HiB@80=Rdh0P1eAS42034X
BP<0]Z0T0P2<S5L208=ZMS`0Pfmc403oool000h0oooo2P23Kg<2085ZL`80QVea3P23Kg<206MhO080
2baH0P0c:B/203HS;P80>R8[0P0l:3<203`_<@80<RD_0P0f:Rl2030Z;@80=Bh]0P0`:b`204m4<080
ADHl0P1JDcd207aR@@80LUEI0`1iGEh2079PH`80LV9S0P1iIV8207ESI`80M69W0P1jH6@207iTJ080
MFU[0P1iJVL407UVJP80MF1Y0P1jGFP207eTJ0P0NFIZ0P1eGVT407YKI`80MEiY0P1eHfH2071JI@80
MEeU101bHF@2075NI080L5QS0P1^FF<206iNH@80IU=O0P1`De`206UDG`80JUUL0P1SEUd205eAFP80
HU=F0P1JD5H205a?DP80DD5@0P1J@T/204lkB`80BT9;0P10@T8204@j?080?C0k0P0b8c4202TO;@80
7Q`R0P0Z9R4201@A5P8040dA0P0A3Pl2024N6080IClI0P1NCTT203M?A`80Iedj0P0i>Td203Lk?P80
AB`_0P1TFDX30:n/9`80Pg9a9023Kg<2085ZL`80QVea5P23Kg<@0?ooo`003P3oool:08=_L`80PFYc
0P26KG4>08=_L`80IgQl0P0;;5P203<Y:`80=R<^0P0j8R/203`X<`80?2la0P0b9Bl203HZ;`80<2X]
0P0e;Rd2030[;080Cd@`0P15AS`205YC?@80O6910P1bEET307UMGP80LV1S0P1bHV<207UVHP80MF=W
0P1dHVL207YPI080OVAX0P1eJF/207UZI`@0NFIZ0P1eH6T207YMJ080OFAX201iIVX207ENJ@@0NU]W
0P1eGVT207ESIP80L5YU0P1eGFD4079QI080LEiT0P1`F6<206iIH`80KUiQ0P1VDel2071CG080JEAO
0P1ZFE`206=FG@80GE5J0P1RDeH205Y@EP80G4mB0P1A@E0205Y2B`80Cc];0P1:@T/20412@P80A3Xl
0P0m<3/2038S<@80:Al]0P0N728202XV8@80514F0P0@3A42014>3`808AhH0P1U?aT205i>B@80=dm7
0P1WGCX203TjC@80=c/n0P15;2l206AIBP<0[j`W0P23LW4T08=_L`80PFYc0P26KG4F08=_La00oooo
000>0?ooo`X0Pfmc0P20LG@208=bL@h0Pfmc0P24NW@200XID`80?C@c0P0/;Bd203Te;`80?3Xa0P0l
>3@2038d=@80<Rl^0P0c;Rl2038Z:`80>C<`0P1:?Bl205E8?P80Ede10P1dEDD2079HE`<0NFAJ0P1b
HF8207IWH`80MFMT0P1eHfL207ATI`80N6aW0P1iJfH207EPJ@80NUeX0P1mI6P207UVJP80LF9[101i
JVL207ENJ@80OVAX101iIVX2071QJ`@0MF=V0P1eI6H207AUIP80KfQY0P1bJf@206mSI@80LV5T0P1_
GfD206]LH`@0KUeP0P1QEF8206QEFP80JE=K0P1ZDeX206IDG080GeAK0P1PDeH205]=EP80GDiC0P1A
CU@2055<B`80BT5:0P1<?T@204ToA@80@Ce10P0i=3/202l]=@808A`T0P0[9RL201LB5`805@lF0P0E
4a<2010?3`8071DC0P1K?B0206U:=`80?2]60P1Y@Sd204I1C`80?dE40P0a<ST209b2:P<0Vhi;9P23
Kg<2081aM080Pg9a5P23Kg<@0?ooo`003P3oool:08=_L`80P75d0P23LW4>08=_L`80Q7Yd0P0:6E<2
03dd<`80;2d]0P0i=Bl203`j<@80?3Pd0P0b=3D2038_;P80<bh_0P0b:R/203Tc<080BSd_0P1EB3h2
05M=@@80M5E50P1bF5L307UTFP80LV5R0P1fIf<207EWI080MF=W0P1dI6L207Q/I`80NF]V0P1eH6T2
07YMJ080OFAX0P1iIVX2075RJ`@0NFYW0P1eGVT207iTJ0@0NFIZ0P1`HF/407ESIP80MFAV0P1dIFH2
06mXJ@80LV]T0P1_HfD2079QI080KemU0P1[G6<406iMH080HEER0P1XEEX206UCF`80JU=J0P1VE5`2
05mDF`80H5=F0P1KCEH205e>D`80DDiD0P1AC4/204Y1BP80C3i40P19?dD2044m@@80>C@k0P0_;CD2
024L9080:bHW0P0G4QL201D?5P805A<C0P0@3`l201`E4`80FcdP0P1YBSL203`[AP80JD8m0P16@Dl2
03m5A080<C8i0P2LPRX309^>BbH0Pfmc0P20LG@208=bLAH0Pfmc403oool000h0oooo7023Kg<208ee
L080231b0P0[:R`203LZ<@80@3X`0P0m=c@203DY<@80?2dc0P0_:2l203DZ;@80?CXc0P0g=S0204Li
=080Ed8i0P1JAdD206]BA`80MU]B0`1gGUX407IPHP80MUaU0P1iHVD207ESI`80NV5U0P1mI6P207EY
J`80L6AX0P1jHFD207eTJ080MFU[0P1eHVL207YMI`80N6MZ0P1eI6H207ULJ080NU]W0P1eH6T207AS
IP@0MFAV0P1eHfL2079NIP80NF9U0P1_H6P2079QI080K5YT0P1bHf<206UPHP80KUaP0P1WH6<2069O
GP80IUeK0P1WGU/206=HF`80H51J0P1QDEL205Y>EP80GDmB0P1A@E0205M4C@80BT5:0P19?dD204a0
@P80>blm0P0n<3X2034/=08092D/0P0T7b0201DA6@804@h@100<20/203Ld7P80@cdR0P1H=C@2044b
A080IUHk0P1=Bd`205IVC@80<f5@0P2Y]2D308>6Hd00Pfmc403oool000h0oooo7023Kg<208eeL080
231b0P0[:R`203LZ<@80@3X`0P0m=c@203DY<@80?2dc0P0_:2l203DZ;@80?CXc0P0g=S0204Li=080
Ed8i0P1JAdD206]BA`80MU]B0`1gGUX407IPHP80MUaU0P1iHVD207ESI`80NV5U0P1mI6P207EYJ`80
L6AX0P1jHFD207eTJ080MFU[0P1eHVL207YMI`80N6MZ0P1eI6H207ULJ080NU]W0P1eH6T207ASIP@0
MFAV0P1eHfL2079NIP80NF9U0P1_H6P2079QI080K5YT0P1bHf<206UPHP80KUaP0P1WH6<2069OGP80
IUeK0P1WGU/206=HF`80H51J0P1QDEL205Y>EP80GDmB0P1A@E0205M4C@80BT5:0P19?dD204a0@P80
>blm0P0n<3X2034/=08092D/0P0T7b0201DA6@804@h@100<20/203Ld7P80@cdR0P1H=C@2044bA080
IUHk0P1=Bd`205IVC@80<f5@0P2Y]2D308>6Hd00Pfmc403oool000h0oooo7023Kg<208eeL08041AD
0P15?Ch203Y@=`80<S0a0P0n;38203D^=080=bh_0P0b;34203Xg<080:QhV0P13:C0204a1=@80E4/l
0P1C@d8206]@A`80MUe?0`1dGe/207IPG`80M61S101eIf@207ESI`@0NFYW0P1eGVT207UVJP80MFiX
0P1iJVL207EPJ@80N6MZ0P1aIfP207UPI@80NVIY0P1`IVT207ASIP80MF9V0P1eHfL207ESIP80MF9V
0P1fHfH2079UJ080MFMT0P1bIFP206]KI@80L5aT0P1cHF0206]JI080KUiQ0P1WDel2071LG`80HUIN
0P1ZDeX2069=F`80HTmH0P1QDeH205Y>EP80GDmB0P1;@e8205]@BP80Ad=<0P1:@4D2044a?P80?2dl
0P0e:34202dM;080<RP]0P0K6B02010<4P8030P;0P0I5a@200X;2`80CC`H0P0n>c0204@e<`80?RTf
0P1]ASL205A4C080HdQ60P1bP5P209BPA4<0Pfmc403oool000h0oooo7023Kg<208eeL08041AD0P15
?Ch203Y@=`80<S0a0P0n;38203D^=080=bh_0P0b;34203Xg<080:QhV0P13:C0204a1=@80E4/l0P1C
@d8206]@A`80MUe?0`1dGe/207IPG`80M61S101eIf@207ESI`@0NFYW0P1eGVT207UVJP80MFiX0P1i
JVL207EPJ@80N6MZ0P1aIfP207UPI@80NVIY0P1`IVT207ASIP80MF9V0P1eHfL207ESIP80MF9V0P1f
HfH2079UJ080MFMT0P1bIFP206]KI@80L5aT0P1cHF0206]JI080KUiQ0P1WDel2071LG`80HUIN0P1Z
DeX2069=F`80HTmH0P1QDeH205Y>EP80GDmB0P1;@e8205]@BP80Ad=<0P1:@4D2044a?P80?2dl0P0e
:34202dM;080<RP]0P0K6B02010<4P8030P;0P0I5a@200X;2`80CC`H0P0n>c0204@e<`80?RTf0P1]
ASL205A4C080HdQ60P1bP5P209BPA4<0Pfmc403oool000h0oooo1023Kg<2085ZL`80QVea0P21JW<2
08I]LA00Pfmc0P29K74201F7VP808ea10P0c8S<203DR<`80=BH/0P0e9Bd203<U;080=b/^0P0e9b/2
03@b=@80>CT/0P1??S@205M5?P80F5580P1SFTL207ENC`<0M61J0P1eHEl207MWH`80MFMT0P1eHVL2
07ISIP80OFQU0P1iIVX2071RJ`80OFUU0P1eH6T207eTJ080LF9[0P1iH6D207IOJ@80N6]W0P1eI6H2
07ENJ@80MF9W101eI6H207ATI`80M6EV0P1eHfH207ISIP80MF=W0P1`FFH2071OI`80KfMR0P1/GF82
06iKHP80KUeP0P1QEF8207AOF@80GeAQ0P1VEeX205iAFP@0HU9F0P1NEEL205UAD`80Cd]C0P1KDDX2
04@lC080ASI20P0n<cl203li>P80=SXi0P0Z<34202@M8P807QHP0P0?3A42010?3`806aLC0P0?3Q42
05I46080?SLd0P12>CL203Lb=`80JE0c0P1HCT/205iHC080Y9910P23OVQ308=_La00oooo000>0?oo
o`@0Pfmc0P21JW<208I]L@80PFYc0P26KG4@08=_L`80RFaa0P0EQiX202=L@@80<b8c0P0e8S<203DV
;080=BD]0P0c9B`203L[;P80=BL[0P0d<SD203Ti;080Cchd0P1GACh205QAB080HeY70P1eGTl307AP
FP80MF5O0P1gIf<207EWI080MF9W0P1fHfH207eXI@80NFIZ0P1`HV/207eYI@80MF1Y0P1mI6P2075R
J`80NF1U0P1fGfT207Q[I`80MFAV0P1eGVT207ERI`@0MFAV0P1dI6L207AUIP80MF=V0P1fHfH207ES
I`80L5UV0P1`GfL206mWHP80K5eR0P1^Ff8206iMH080HEER0P1dGeT205mDH@80IUMJ0P1NDEX4069B
EP80GUEG0P1IDE<204m;D`80Fe5:0P14?4`204Hf@P80?S<o0P0o>CX203Hj>@80:S0a0P0T7B8201hF
80803`dA0P0@3`l201/G4`803`hA0P1FA1P203hg=080@STg0P0g<SL206U@<`80F4i;0P1NF4`20:BB
@@80PgiX@`23Kg<@0?ooo`003P3oool408=_L`80P75d0P23LW42081aM080Pg9a4P23Kg<207N1N@80
4b=H0P0`93D2038Y;080;28Y0P0d:2X2030W:P80;R8W0P0f:B`203dc;P80?SPd0P1ABSL20599?`80
HU550P1TEdh2079OD@<0M61J0P1fI60207=LH@80O61T0P1dHVL207ITIP80NV5U0P1jGFP207EPJ@80
NF1U0P1jIVT207UZI`80MFU[0P1dKFT2071UJ080NUmU0P1jIVT2071VJ@80M6EV0P1eI6H607ESI`80
M6AW0P1eI6H2071IIP80LUiV0P1bI682079QI080JE]U0P1bIF4206UPHP80If1S0P1^He`206=KHP80
HeUK0P1NDEX2065CEP80GTaD0P1UDE@205U>EP80F59D0P1AADd204LjC080B4=40P0o@40203H^=P80
>BLb0P0S5RL201lD7`805PlE0P0E4AD200/92`805a0@0P0A3A0206A;6@80>CLh0P0m;c@203X]=P80
KeHc0P1SHTd206UjDP80WHm9A@23Kg<@0?ooo`003P3oool408=_L`80P75d0P23LW42081aM080Pg9a
4P23Kg<207N1N@804b=H0P0`93D2038Y;080;28Y0P0d:2X2030W:P80;R8W0P0f:B`203dc;P80?SPd
0P1ABSL20599?`80HU550P1TEdh2079OD@<0M61J0P1fI60207=LH@80O61T0P1dHVL207ITIP80NV5U
0P1jGFP207EPJ@80NF1U0P1jIVT207UZI`80MFU[0P1dKFT2071UJ080NUmU0P1jIVT2071VJ@80M6EV
0P1eI6H607ESI`80M6AW0P1eI6H2071IIP80LUiV0P1bI682079QI080JE]U0P1bIF4206UPHP80If1S
0P1^He`206=KHP80HeUK0P1NDEX2065CEP80GTaD0P1UDE@205U>EP80F59D0P1AADd204LjC080B4=4
0P0o@40203H^=P80>BLb0P0S5RL201lD7`805PlE0P0E4AD200/92`805a0@0P0A3A0206A;6@80>CLh
0P0m;c@203X]=P80KeHc0P1SHTd206UjDP80WHm9A@23Kg<@0?ooo`003P3ooolN08=_L`80RFaa0P0I
Fh/201`n?080;b/]0P0_;2d2034/:@80<B//0P0_;B`2030Y:080=bLZ0P16=342050l=P80ET910P1R
CD@206]GC@80L5mC0`1cH5/207MSG`80Kf9U0P1iJ64207ARI`80MF9V0P1jJVL2071TJ080NVYW0P1d
KFT207U[IP@0NFIZ0P1eGVT207UVJP80L6MX0P1iHF@207YVJ@80L6AX0P1fHfH207ERI`80MV=V1P1e
HfL206aQJ@80MFUR0P1_HfD2071LI080KemU0P1`G60206iIH`80KEeP0P1^GF0206=BH080IU=L0P1N
DUX2065CEP80GUEG0P1MCe8205i<E080ED9?0P1D@e0204Q4BP80A3U10P16=d0203Ti?P80<2lc0P0L
6RD201hI7@80518E0P0I5QD200h>40805a@A0P0E4a<206Q=6080ADU20P0];cH204Ln=P80IE8e0P1i
HDX208bBE080PhMR0P21JW<308I]LD00Pfmc403oool000h0oooo7P23Kg<208U/L@806E^;0P0L?S`2
02l[;@80;b`]0P0a;2T2034[;080;bd/0P0`:BP203LW:P80AS@a0P1@?3H205I2@@80HTe40P1[Edd2
071OD`<0Lf1K0P1gHel206mRI@80NFQQ0P1dHVL207ERIP80NVYW0P1`I6P207YZI`80M6eY0P1iJfH4
07UVJP80MEiY0P1iIVX2071WJ080NF5T0P1jIVT2071TJ080MV=V0P1eHVL207ISIPH0MF=W0P1/HFT2
07EYHP80Kf=U0P1`G6@206mOI@80L5aP0P1^FF<206eMH080KUeP0P1SDV0206ICG080GU9J0P1QDeH2
05iEE`80GDmB0P1NC5@205E2C`80E4=@0P18A4X204@i@@80ASM00P0i>Ch2030_<`8071XU0P0N6Ad2
01@B5@806AHE0P0>3Q0201LD4@805A<C0P1XCAP204E9@P80;Blf0P17?SH206EB=@80NF5:0P2<TU@2
08>7HP80PFYc0`26KG5008=_La00oooo000>0?ooo`80Pfmc0P21JW<208I]LAX0Pfmc0P1HP882010d
E@809b</0P0_8RL2038V:@80<BLZ0P0c:R/2038];@80;bTZ0P17=Rh20596>@80ETm10P1RFDL206MJ
C@80MVAE0`1_HUd207=LG`80MEaR0P1gGV8207QRIP80M6EV0P1jHVD207APJP80NV9U0P1mI6P207EP
J@80OFAX0P1eGVT207EPJ@80NV9U0P1eGVT207ESI`80NF5T0P1eGVT207ITIP80M6AW0P1eI6H207ER
I`80MV=V0P1eHfL206mPJ080MUmS0P1aFVH2075QI080KV1S0P1/G6<206iMH080KUiQ0P1YEUl206IG
H080IUeK0P1OFU`205eDF080HU=E0P1JCUH205Y9D@80ET]C0P1;@DX2050oB080@3U40P11=C/203TZ
=`80<2@a0P0M6B@201hJ70805QDH0P0F4Q<201TH60806AXF0P0@3Q02060k6@80EShl0P0a=442059A
=P80Hf900P1mMDP209f1DP80Pfmc0P20LG@308=bLD00Pfmc403oool000h0oooo0P23Kg<2085ZL`80
QVea6P23Kg<205R0PP8043AE0P0W8b`202lR9`80<RHY0P0a9bX203<Z:`80<Rd]0P0_:BX204Lf;P80
DTHi0P1FCd42069IA`80IeY=0P1fI5D306mRG@80LeaO0P1eG68207MNHP80N69V0P1dIFH207YRI@80
M61Z0P1jHVD207eTJ080MF1Y0P1mI6P207ENJ@80MF1Y0P1jHVD207ENJ@80MF=W0P1iHF@207ENJ@80
MVAV0P1dI6L207ETIP80MF9W0P1fHfH207ESI`80Kf1X0P1fGf<2075JIP80LF5T0P1^H6<206aLH`80
KUeP0P1^GV4206UFG`80IUMP0P1VGE/205mJG080GEAH0P1RDeD205Y>EP80FTUA0P1FBe<204]1BP80
D3m80P10>D@2044e>`80>BXg0P0`934201dI90807QXL0P0F5AP201HB4`806APH0P0I6QH2010>4080
H3/I0P1F?S`2034d@@80DU4f0P1SHT0207eeB080WH5B0P23Kg<2081aM0<0Pg9a@023Kg<@0?ooo`00
3P3oool208=_L`80P75d0P23LW4J08=_L`80P75d0P0D<6`202`l>`80:2h[0P0e<B/2034_;@80;bTZ
0P0e:b`203<^;P80@cT^0P1;=C@206=5?`80JEQ90P1[I5<206iNE@<0Le]N0P1cIF42075VHP80MFQS
0P1eIf@207ESI`80MF9W0P1eHVH207YZI`80NFYW0P1`H6/207YQI@80M61Z0P1eHfH207ERIP80MF9W
0P1eHVH207ESI`80M6EV0P1eHfH207ISIP80MF=W0P1dI6L207ETIP@0LUiV0P1bHF@206mOI@80LeiR
0P1]FF@206iKHP80KUaP0P1_GF0206EHH@80JEQL0P1VDe`206=?F`80H51I0P1RDeD205]?EP80FU=D
0P1AAdl204XnC@80C3i40P10=D8203da>`80<bTd0P0Z8B/201lJ8`808AdN0P0H5aT201DB508071LF
0P0A3A0200`82`80GSdH0P1;=3@203d^?@80G4Th0P1_GD@20968C080RH=PA`23Kg<@0?ooo`003P3o
ool208=_L`80P75d0P23LW4J08=_L`80P75d0P0D<6`202`l>`80:2h[0P0e<B/2034_;@80;bTZ0P0e
:b`203<^;P80@cT^0P1;=C@206=5?`80JEQ90P1[I5<206iNE@<0Le]N0P1cIF42075VHP80MFQS0P1e
If@207ESI`80MF9W0P1eHVH207YZI`80NFYW0P1`H6/207YQI@80M61Z0P1eHfH207ERIP80MF9W0P1e
HVH207ESI`80M6EV0P1eHfH207ISIP80MF=W0P1dI6L207ETIP@0LUiV0P1bHF@206mOI@80LeiR0P1]
FF@206iKHP80KUaP0P1_GF0206EHH@80JEQL0P1VDe`206=?F`80H51I0P1RDeD205]?EP80FU=D0P1A
Adl204XnC@80C3i40P10=D8203da>`80<bTd0P0Z8B/201lJ8`808AdN0P0H5aT201DB508071LF0P0A
3A0200`82`80GSdH0P1;=3@203d^?@80G4Th0P1_GD@20968C080RH=PA`23Kg<@0?ooo`003P3ooolR
08=_L`80=:BB0P0HVF42025FA`80<d8d0P0g?CD203Do=@80;S0^0P0d:bd204@f<080C4Di0P1GBC/2
06Y9A@80MeA?0P1aGe`306mRG@80Le]O0P1gGV8207EMH`80Me]T0P1hH6D207ERI`80MF=V0P1jH6@2
07YMI`80M61Z0P1eHfH207YZI`80L6IY0P1dHfH207ETIP80M6EV0P1eI6H207ESI`80LEiW0P1iHVD2
079NIP@0MUaU0P1bGVH207EWI080K5iU0P1cH6@206aKH`80KUYR0P1^G60206iMH080J59O0P1[E5l2
06QIG080HeEL0P1PDET206IIF080FDiF0P1OBe@205m=DP80BC]@0P1??dP204@g@P80A3Q10P0e;CP2
030U<0809alX0P0Y9bP201`K7@807QXL0P0D4aD2018=3`802PL:0P0S8QX2065S6P80>Shj0P13?S/2
05iF>P80JeU50P2/PTH2085`K`80QVeaA@23Kg<@0?ooo`003P3ooolR08=_L`80=:BB0P0HVF42025F
A`80<d8d0P0g?CD203Do=@80;S0^0P0d:bd204@f<080C4Di0P1GBC/206Y9A@80MeA?0P1aGe`306mR
G@80Le]O0P1gGV8207EMH`80Me]T0P1hH6D207ERI`80MF=V0P1jH6@207YMI`80M61Z0P1eHfH207YZ
I`80L6IY0P1dHfH207ETIP80M6EV0P1eI6H207ESI`80LEiW0P1iHVD2079NIP@0MUaU0P1bGVH207EW
I080K5iU0P1cH6@206aKH`80KUYR0P1^G60206iMH080J59O0P1[E5l206QIG080HeEL0P1PDET206II
F080FDiF0P1OBe@205m=DP80BC]@0P1??dP204@g@P80A3Q10P0e;CP2030U<0809alX0P0Y9bP201`K
7@807QXL0P0D4aD2018=3`802PL:0P0S8QX2065S6P80>Shj0P13?S/205iF>P80JeU50P2/PTH2085`
K`80QVeaA@23Kg<@0?ooo`003P3oool208=_L`80PFYc0P26KG4@08=_L`80PFYc0P26KG4808=_L`80
SGE`0P1GSHT202Z`N08064U:0P0l=CL203DX<@80>2ld0P0e=34203db;`80CcPd0P1MBD0205i?AP80
LE=;0P1kGEH306mNH080KUeP0P1gHel2075RI@80MFQS0P1dIfD2075OIP80Mf5U0P1eHfH207ITIP80
MF=W0P1dI6L207YRI@80MF1Y0P1dI6L207ESIP80MV=V101eHfL2079UJ080MFMT0P1_H6P4079QI080
MFMT0P1bHF@206]GI`80LeUP0P1^FF@206iNH080KEeP0P1^GV0206=JHP80IUIK0P1YDe/206IEG080
HEUK0P1RDUH205I4E`80HDiA0P1C?dl20511D080C4E70P0n=T<203PW=P80<b0b0P0e:S0202@R:080
8aXO0P0Q6R4201PD5`806QHI0P0<2`d200X82P80EeTK0P1;DB/203LY>`80D3hi0P1LB3`2085cB080
W8e:0P20LG@208=bLDD0Pfmc403oool000h0oooo0P23Kg<2085ZL`80QVea4023Kg<2085ZL`80QVea
2023Kg<208eeL080Ehf90P0Z/7P201Q9BP80?3Dg0P0e:34203P_=080=C@a0P0m<Rl204lh=080GDU0
0P1NCdH2075CB`80NeeF0`1_GV0206iMH080Mf=O0P1aHVD207EXH`80M6MU0P1aGfH207MQI@80MF=V
0P1fI6H207ESI`80M6AW0P1jHVD207EPJ@80M6AW0P1eHfH207ISIP@0MF=W0P1bIFP207EWI080Kf1X
101bHF@207EWI080LV5T0P1[EfL207=IH080KUUT0P1^GV0206eMH080KUiP0P1SFV8206IFF`80JE=K
0P1VEE`2065IF`80HU9F0P1FA5L2065>D@80Dcm?0P1@@E0204a5A`80?SI30P0h9cH203<P<P80=BX`
0P0T8RP202<J7`808AXQ0P0H51L201XF6@8030/=0P0:20X205MI6`80Be4[0P0g:C/2050n>@80G4Pl
0P21LdP209b=BP80P75d0P23LW5508=_La00oooo000>0?ooo`80Pfmc0P20LG@208=bLA00Pfmc0P20
LG@208=bL@P0Pfmc0P29K74208UWM080OGQj0P0ICWT202DZ=@80>R`b0P0`9R/203h^<080>C4b0P1=
?c@205]6>`80HTi80P1[FD`207EJD`<0KE1M0P1eFUh207=KG`80MeiR0P1dG6<207IHI080M5eV0P1e
H6<207QSI@80MFAV0P1eHfL2079NIP80NF9U101eHfL2075NI`80NF9U0P1aFfH207MKI080MEYU0P1g
FfD2079NIP80LV5T0P1aGV@207=FH@80Le=T0P1^FF<206iMH080KUaP0P1_GF0206eMH080KUeP0P1T
E60206EDG@@0IUMJ0P1RCeT2069@F@80EU1G0P1JC4l205MBE080AdA:0P17<d@203d/?P80=Rhh0P0a
<34203@_;@80;S0a0P0I6b02020I70806AHI0P0A3A0200/82`80BfhT0P10Hb<203l`>@80>2`i0P1K
CCH206I^A@80Ri=40P2=PEl2085ZL`80Q6Qa0P26KG5308=_La00oooo000>0?ooo`80Pfmc0P20LG@2
08=bLA00Pfmc0P20LG@208=bL@P0Pfmc0P29K74208UWM080OGQj0P0ICWT202DZ=@80>R`b0P0`9R/2
03h^<080>C4b0P1=?c@205]6>`80HTi80P1[FD`207EJD`<0KE1M0P1eFUh207=KG`80MeiR0P1dG6<2
07IHI080M5eV0P1eH6<207QSI@80MFAV0P1eHfL2079NIP80NF9U101eHfL2075NI`80NF9U0P1aFfH2
07MKI080MEYU0P1gFfD2079NIP80LV5T0P1aGV@207=FH@80Le=T0P1^FF<206iMH080KUaP0P1_GF02
06eMH080KUeP0P1TE60206EDG@@0IUMJ0P1RCeT2069@F@80EU1G0P1JC4l205MBE080AdA:0P17<d@2
03d/?P80=Rhh0P0a<34203@_;@80;S0a0P0I6b02020I70806AHI0P0A3A0200/82`80BfhT0P10Hb<2
03l`>@80>2`i0P1KCCH206I^A@80Ri=40P2=PEl2085ZL`80Q6Qa0P26KG5308=_La00oooo000>0?oo
obH0Pfmc0P2=MG0203UQQ`803QTe0P0o:BT20496>080;C4^0P1:@CH204I3=`80EdHn0P1QC4D206eE
C@80LE]D0`1[H5d2071SF`80KUaP0P1cFeh207EOH`80L6AS0P1eJF<206mSI@80MEiS0P1jHFD2079N
IP80MF=W0P1eIf@407ESI`80LVEX0P1bHF@2075OI`80MFQS0P1^HfH206iJH`80MeiR0P1^FF<207EO
H`80JEeT0P1^GF0206iLH080KeeP0P1^GV4206iMH080KUaP0P1YE5l206UGH080HUML0P1VEUT206=@
F@80HDiI0P1PCUD2058lDP80H4I?0P1H@d`204PgC@80@SQ30P0l=cd203Xg>080<2`b0P0/8BT203@T
:P80<clf0P0?51L2018<4080510C0P0_?R<203he6P80Dc0k0P0j=3/2044o>P80GUHg0P1kJT@209V2
C`80QWI[0P1mK7@208MkL080OGEc@`23Kg<@0?ooo`003P3ooolV08=_L`80SGE`0P0iHHL200hI=@80
?bTY0P12ASP202da;P80BT4f0P16@cL205M6?P80HDa50P1]EDd2075KE0<0Jf1M0P1`He/206iLH080
Le]N0P1eGf<2071TH`80MFUS0P1_HfD207ENH`80NV5U0P1bGVH207ESI`80MFMT101eHfL2079UJ080
LV5T0P1aGfL207EXH`80KV=V0P1^FV<207MNHP80KUUS0P1eGf<206UMI080KUeP0P1^G60206mMH080
KUiQ0P1^GF0206iLH080JEAO0P1YEf02069GG080IUII0P1SD5T2065>F@80H4iE0P1B?5820616C`80
F4=<0P18=dd2048h@`80?3Lm0P0j=cP2030/<P80;24Y0P0d92X203<o=P803a@G0P0B310201@@4`80
;chS0P0n=AX205<`>`80>S@k0P11?cX205iF=`80NfY40P2IPTl208IfJ`80OFad0P27Ng0207eeLd<0
Pfmc403oool000h0oooo9P23Kg<208eeL080BSmh0P0H<Ud202/d:@80?2<Y0P0i:3H20513<@80AC/m
0P1GASh2069AAP80JUQ<0P1YD5<307EDF080LeaM0P1]GF0206mNH080MEiO0P1aEf8207iRH@80KEaW
0P1cH6@207IPHP80LUiV0P1fGf<607ILI@80NF9U0P1/FfL207=KH`80M5IQ0P1cDf@206iIH`80K4mM
0P1eEF42079JGP80KUQS101^G60206iMH080KeeP0P1]GF0206iMH080HE9P0P1ZDEX206ICG080HU1I
0P1SCeP2065BEP80FdaE0P1;@U<205U4A`80CSI90P14;d<204<`?@80>R/h0P0g9C8203DX<P80;B/^
0P0a;BX202HF7`809R4^0P0I9Ql202Hd8@80;2TM0P1=AC820451<`80BDI00P19Dcl206EY@@80LFE:
0P2UOE0208MkL080NWAf0P29Kfh208=ZMT<0Pfmc403oool000h0oooo9P23Kg<208eeL080BSmh0P0H
<Ud202/d:@80?2<Y0P0i:3H20513<@80AC/m0P1GASh2069AAP80JUQ<0P1YD5<307EDF080LeaM0P1]
GF0206mNH080MEiO0P1aEf8207iRH@80KEaW0P1cH6@207IPHP80LUiV0P1fGf<607ILI@80NF9U0P1/
FfL207=KH`80M5IQ0P1cDf@206iIH`80K4mM0P1eEF42079JGP80KUQS101^G60206iMH080KeeP0P1]
GF0206iMH080HE9P0P1ZDEX206ICG080HU1I0P1SCeP2065BEP80FdaE0P1;@U<205U4A`80CSI90P14
;d<204<`?@80>R/h0P0g9C8203DX<P80;B/^0P0a;BX202HF7`809R4^0P0I9Ql202Hd8@80;2TM0P1=
AC820451<`80BDI00P19Dcl206EY@@80LFE:0P2UOE0208MkL080NWAf0P29Kfh208=ZMT<0Pfmc403o
ool000h0oooo9P23Kg<208eeL080>SYg0P10CU`201TR<@80=RLZ0P0g:R/2044W;080C2lg0P1G?c/2
0613@P80ID990P1_DE8306aHE@80LUEI0P1bFUl206QBG`80NEaM0P1^H6<207MPGP80LEaV0P1`Ff82
079GHP80MEYR0P1eGf<2079QI080MFMT0P1[G6D207UJH@80KEMV0P1`FV4206iKHP80J59O0P1]C5`2
06Q?GP80Ke=H0P1eFEh206iMH080JUMO0P1[D5d2075CG@80JdmM0P1]C5`206i<G080HDQM0P1XD5L2
06E>E`80GTQG0P1RBU<205e4DP80ESY@0P1C?dh204m0A`80BSe70P0o>44204@m?@80=cLk0P0[9Rl2
038U:P80;B4Y0P0_8RL2028N9P80;2@Q0P0M61l205=E:P80:DTf0P17@b`203h`>P80IUXl0P1;DTP2
07I[A@80PI]E0P23TE/208U/L@80PFEf0P26KG4208=_L`<0QgQc0P1mLWDP08=_L`80QgQc0P1mLWDJ
08=_La00oooo000>0?ooobH0Pfmc0P2=MG0203XjM`80@4iL0P0I8S4203HW:P80=bX[0P119b`204`_
=`80Eclk0P1P@d8206E2B@80Ke5B0`1/F5D2079EF@80LUYO0P1XDUl207ULG@80KV1S0P1gH5h2075L
IP80L5]R0P1bEf8207EJHP80MEmS0P1bHF@207EWI080JeaU0P1iFV4206eGIP80L5YQ0P1^Ff8206QB
G`80KDaL0P1XCeh206mCF080MEUN0P1^GF0206YGG`80Je1M0P1aDed206]?G@80KDaL0P1^C5`20658
G@80J51G0P1UCUL205i8E`80HTYC0P1MA58205HjD080Dcm>0P1?@4L204XmA`80?cQ10P14?Cd203Lg
>`80:bH_0P0b9BX202dQ:@80;b8W0P0R7RH202`T8@807APO0P1CEBX202U9=P80Ad</0P0n<3X206IJ
?080Be980P1fJdD2086KE@80Pi5K0P29K742085UMP80QVea0P23Kg<308MhL`80OG9e8023Kg<208Mh
L`80OG9e6P23Kg<@0?ooo`003P3ooolV08=_L`80RFaa0P18K8L204Z0H0802AD_0P0a7b4204Di;`80
;B`^0P1<>C020550>@80Ed500P1VE4T206UIC@<0Ie1F0P1^DeL206mBF@80J59O0P1gGUP2075JH@80
L5MP0P1cF642079PH`80JemR0P1`G60207=IH080LeMR0P1fEF4206iEI@80LU]O0P1^FV8206YFH080
JTiM0P1TBEd206M>F@80Ie1H0P1ZE5P206mCE`80JDMK0P1ZAU/206Q;FP80JTaG0P1SA5T206U9EP80
J4mG0P1LB5P206Q?D`80GTUE0P1NBe@205Q5D080FdM@0P1>A4l204`kAP80CSU50P1<?T@2040j@P80
@CHj0P0d9cH2034Z<`80<Bl]0P0/:R/203Xm;`80:3D_0P0W:RH203A2<080Ee/X0P0g=T0204M1>@80
BE510P1WIC/205m]E@80IfY=0P2UMTl208I]L@80Pfmc0P20LG@208MkL080OG9e0`29K74208=ZMQ@0
Pfmc0P21JW<208I]L@P0Pfmc0P29K74208=ZMQX0Pfmc403oool000h0oooo9P23Kg<208U/L@80B6b7
0P1:P60200TE;`80<AlQ0P15>Bl202d/;P80C3T`0P1A@3T205M1@080IUA90P1YFDd306M@EP80KU=G
0P1_DUT206QBG`80MeiH0P1aFV42071GH080LeQQ0P1bH6<206]OHP80L5aP0P1cFF0207=GHP80MUEQ
0P1^EFD2079KG`80KUYR0P1ZEV0206Y>G@80I4UM0P1WCUT206M@F080JUAH0P1_DeL206U7F`80JTIK
0P1XBeX206Y<E`80HdAI0P1YBEH206Q?E`80G4QH0P1XCe<205i9E@80GT]D0P1HAE0205]7D080CTA?
0P1<>dH204hiA@80C3i40P10>T82044f>P80=2Lf0P0a:S<2034_;@80;2X[0P0j?Bl202Pe;`809bXV
0P0d@S0205MK:080=cI00P17@CT204UA@@80IfDk0P1OKED206MZC@80YGI?0P26KG4208=_L`80P75d
0P27Ng0207ebM@<0RFaa0P23JWHD08=_L`80PFYc0P26KG4808=_L`80RFaa0P23JWHJ08=_La00oooo
000>0?ooobP0Pfmc0P1cN7T204M1J@806cQO0P0T?B`203/_:080?3Dg0P0l<bh204`b=@80D3@k0P1W
?cl206a8C@<0KUeE0P1PEEL206Y@E`80JUAI0P1^DUP207MIG@80KEiQ0P1^Gel2075LG`80KEQR0P1[
E5l206iBGP80Ke9M0P1^DUh206]=G@80JTEK0P1]@ET206]3FP80ITUI0P1NAeL206=7D`80H45B0P1U
?U0206HlD@80HSaC0P1T@U420651D@80HSmA0P1N@E8205XjC@80HcM<0P1L>E02060lB`80G3]?0P1E
=DX205HeBP80G3m80P1?>d/204XmA`80B3]10P11;3/203hT>080AS4i0P0g=SX202h/;`80?STb0P0e
?cD202/T:080?Rdb0P0f@3D203e0;`80BcHd0P0n;C`205I;>`80C4A00P1dFd<2071QD@80OHQM0P24
TEX208=bL@@0Pfmc0P29K74208=ZMQT0Pfmc0P20LG@208=bLBH0Pfmc403oool000h0oooo:023Kg<2
07=hN@80Ad5Y0P0K>5l202@m;080>blX0P0l=CL203`c;P80C38e0P1@=3/206Lo?`80K4Q=0`1^GED2
061EE`80JU1G0P1ZE5T206iBF080MeUM0P1]GV4206iOG`80LEaO0P1]F68206]DG`80KU9N0P1_DUd2
06iBGP80JdeM0P1ZAE/206e1F@80Jd=J0P1VBET205i7E`80HdMC0P1P@E8206DnD080ISaA0P1R?5<2
06A2D@80HD5A0P1R?e4205i1DP80FSY=0P1S=d`205`iD080H3a;0P1L>dl205DeBP80ESE:0P1L?dP2
04lkB`80BSe70P18>d42044/>`80?R@h0P16<CT203Lf>P80;R`_0P0n>C8203Do=@80:b@X0P0n;C82
03I0=@80?D0_0P1;=S@203h]?080ET/k0P1<A40207AK@`80L65A0P1mR5d208BAFP80Pg9a1023Kg<2
08U/L@80PfYf6@23Kg<2081aM080Pg9a9P23Kg<@0?ooo`003P3ooolX08=_L`80LgQi0P17@FT201/h
G`8093d/0P0k;bP203`e=`80?3<^0P1<<SD2050d>`80Iclo0P1/B4d306iME@80H5EG0P1ZD5L206YD
F@80KU9H0P1gFEd206eNH@80KUmO0P1aG5l206eHHP80JeAO0P1^DUh206mBG@80KU9N0P1[CEd206Y5
F`80KD5I0P1[@eX206I9F@80GTMG0P1SAe<20611DP80ICi@0P1V?542068lD`80I49A0P1Q@E42068o
D@80GT5B0P1J>Td206<gC080G3U@0P1P?4/205`kC`80ECE:0P1F=DX205`oB080Cc];0P1:?DL204Pk
@@80@B`k0P0n93P204Ha>@80=cHj0P0^;2l203hi<P80=Cle0P0[92P203h]<P80=T0e0P0m@2l204/f
=080?Rdl0P1FBc/204a4@080M5]30P1`HE4207f8G@80Q95J0P23LW4408=_L`80RFaa0P23JWHI08=_
L`80P75d0P23LW4V08=_La00oooo000>0?ooobX0Pfmc0P1?RhH202=bI`8094=50P0^<C0203l`;P80
?S@f0P19@SH204e8?@80C3Xl0P1R=T4306TcAP80LDEE0P1WEEH206aMF080JVIL0P1]HUX206]DG`@0
KU9N0P1]DUh206=9G@80JDQH0P1T@EL206i6EP80KUIJ0P1HBeX2069;E080HDYC0P1RBE<205<lD@80
HD5=0P1A=d`205loBP80DcY:0P1SAd/204/dB080Hca90P1<<4L205ddA@80C3160P1B<D4205XjA@80
D3M50P1C=T@204liAP80Cce30P1<<d0205HlA@80DD]80P11@DD204A9A080>4Lo0P13AST203@_=`80
=C0e0P13?S4204A2>P809c0g0P0V6b4203lP:@80DSlg0P16C3h203m7@080EDdj0P1LHD/206M[AP80
K5YE0P2TOU0208=cL0X0Pfmc0`21JW<208I]LB00Pfmc0P27N7<207ebMAX0Pfmc403oool000h0oooo
:P23Kg<204n;QP808g9W0P0T@dD202ha<080?c0^0P0n=3H204U2=P80CDPm0P1<>S`2068f@@<0JC=6
0P1aAED206MEEP80K5eH0P1ZIU`206eRFP80JeAO101^DUh206eBGP80HdUM0P1YB5P206A1E`80KTIF
0P1^EUX205Q;FP80HT]D0P1QBU<20699D`80DcaA0P1Q@Dd2054gC080Gcm:0P1C>TX206=7B`80BcA8
0P1S?4T204``A`80GCA50P1<<4H2058a@@80FSY50P1@=dD205<fA080CcU60P1??D<204`c@080ESa5
0P1ABdP20451A@80A4U40P0hAcl204=6>@80=2lg0P0e<3D204<n<@80A48j0P0W<3L202HK8@80?b0Y
0P1B?cL204I<?P80?dM00P1ECCX205aQB`80If]60P1/FUD20:AnD080Pg=`2P23Kg<3085ZL`80QVea
8023Kg<208MhL`80OG9e6P23Kg<@0?ooo`003P3oool/08=_L`80DXV50P0X^7@201EXDP80=4Dh0P0b
:C0204hc<`80CSLj0P0j9ST20650>P<0G5160P1bIDT206YZF@80JFQK0P1^H5d206UFG`80JUIO0P1T
D5/206Q:F@80Hd5G0P1TAUP2061:E080GDaE0P1QCE0206U6D@80GDEI0P1OCU4205@oC`80G3];0P1?
>4d205HlA@80C3Q90P1F?d8204`jA`80CRdm0P1A=4P205<m?`80?ba30P17:SL205@j@@80?c@m0P1G
?C`2044_?`80Bc4l0P1<=Ch204Xe?P80AcQ00P0o9cD204hQ=`80BBLn0P1<<S/2048_?@80AC<j0P0k
=Sd203do>080<BL^0P108Bh203`]>@80;d<h0P0iCS0204]6<P80BSLm0P1FC4@2061bA`80Gf]<0P1H
A54209R:D080Pi5K1023Kg<2085ZL`80QVea1023Kg<3081aM080Pg9a6023Kg<2085ZL`80QVea1023
Kg<208U/L@80PfYf6P23Kg<@0?ooo`003P3oool/08=_L`80DXV50P0X^7@201EXDP80=4Dh0P0b:C02
04hc<`80CSLj0P0j9ST20650>P<0G5160P1bIDT206YZF@80JFQK0P1^H5d206UFG`80JUIO0P1TD5/2
06Q:F@80Hd5G0P1TAUP2061:E080GDaE0P1QCE0206U6D@80GDEI0P1OCU4205@oC`80G3];0P1?>4d2
05HlA@80C3Q90P1F?d8204`jA`80CRdm0P1A=4P205<m?`80?ba30P17:SL205@j@@80?c@m0P1G?C`2
044_?`80Bc4l0P1<=Ch204Xe?P80AcQ00P0o9cD204hQ=`80BBLn0P1<<S/2048_?@80AC<j0P0k=Sd2
03do>080<BL^0P108Bh203`]>@80;d<h0P0iCS0204]6<P80BSLm0P1FC4@2061bA`80Gf]<0P1HA542
09R:D080Pi5K1023Kg<2085ZL`80QVea1023Kg<3081aM080Pg9a6023Kg<2085ZL`80QVea1023Kg<2
08U/L@80PfYf6P23Kg<@0?ooo`003P3oool>08=_L`80PFYc0P26KG42085ZL`80QVea6023Kg<207Ud
MP808cI[0P0n?D@203Q7@080?d<e0P1?B3`204YZBP80DGA00`1BDTT207=EB@80Id1D0P1c@EL207=<
FP80JU1N0P1UC5X206A;FP80GTYF0P1MBeD2061?D@80Dce@0P1Q@Dd2069<D080F4I@0P1I?Dd20612
C@80D45@0P1??dP204`jAP80Cce30P11;cl205m6@@80@CU40P1BCDH204I9@@80ASQ00P1<B4D203Y5
@080@S<e0P1FBd@20411?@80BD=40P11@Sd204Hl?080BT4o0P1:Ad4202d^>P80@CDc0P18?cP204@n
>`80>S0i0P14=CL204Ho>`80=blf0P0i=SX203@i<P80@3Xb0P0j<3@204Hg=P80CdHl0P1JK4H205Me
B080HE]<0P1UC5D206MbG@80ViM41P23Kg<208AjM080OGEc8@23Kg<2081aM080Pg9a8P23Kg<@0?oo
o`003P3oool>08=_L`80PFYc0P26KG42085ZL`80QVea6023Kg<207UdMP808cI[0P0n?D@203Q7@080
?d<e0P1?B3`204YZBP80DGA00`1BDTT207=EB@80Id1D0P1c@EL207=<FP80JU1N0P1UC5X206A;FP80
GTYF0P1MBeD2061?D@80Dce@0P1Q@Dd2069<D080F4I@0P1I?Dd20612C@80D45@0P1??dP204`jAP80
Cce30P11;cl205m6@@80@CU40P1BCDH204I9@@80ASQ00P1<B4D203Y5@080@S<e0P1FBd@20411?@80
BD=40P11@Sd204Hl?080BT4o0P1:Ad4202d^>P80@CDc0P18?cP204@n>`80>S0i0P14=CL204Ho>`80
=blf0P0i=SX203@i<P80@3Xb0P0j<3@204Hg=P80CdHl0P1JK4H205MeB080HE]<0P1UC5D206MbG@80
ViM41P23Kg<208AjM080OGEc8@23Kg<2081aM080Pg9a8P23Kg<@0?ooo`003P3oool408=_L`80PFYc
0P26KG4608=_L`80P75d0P23LW42081aM080Pg9a6P23Kg<203fPS`805TI>0P1>?ch203di?P80A2he
0P1P<3T205lbAP<0ECI:0P1X@DH206U@E080I5aC0P1UDED206E7E`80HDIG0P1TCE@205I3E080GD=?
0P1M@dh204`jCP80Fd=60P1G>4L205/kC080D3a:0P1K@TH204`hB@80ETE80P10>4<204H_?080AcQ0
0P12:C<205<c@P80CCLk0P1D?DH203`d@080D3Hj0P15=D82044o?`80Ge8i0P0a9cl204h^=P80ABlm
0P1@@ch204@l?P80@R/i0P0j;Cd203D[;`80?28]0P0d5R/203LJ;@80@bX`0P0h82h203HN<@80>RD]
0P0g92l2044^<080ACli0P1AGC`205QaA080KGi70P1>Ae@206U;D`80C39<0P2dP48208>6H`H0Pfmc
0P29K74208=ZMTL0Pfmc403oool000h0oooo1023Kg<2085ZL`80QVea1P23Kg<2081aM080Pg9a0P20
LG@208=bLAX0Pfmc0P0mX8l201I6CP80CSln0P0m>Ch204@^=@80H30i0P1O<TH305DfBP80J4560P1Y
D5@206ALD`80IE5E0P1UAeL20656E`80I4eD0P1F@e@205e3C`80GD=>0P1<>Th205]3AP80EcQ70P1K
>d`2050lBP80Fd960P1<>4T205I5B080@3Q30P16;c`204Lh@080@RTc0P1C<d8204dg>`80E3e60P0l
=402050f>P80ACE20P11?cl205mB>@80<BLo0P1>;SH204D_?@80D4<n0P14?3h2048[>@80>Rdm0P0e
:bl203`R;@80=1H[0P0g6Rd204<Z<080>20^0P0f7S4203XU;@80=b@_0P11;S0204Do>@80DEdl0P1H
LD@206enA`80CTMD0P1YBe<204`bC080]8120P23QV<608=_L`80RFaa0P23JWI708=_La00oooo000>
0?ooo`@0Pfmc0P20LG@208=bLBP0Pfmc0P29K74202bSV@807fiB0P0k@4@20412?P80FUhl0P1AFTL3
05AMC080Gf]<0P1RHU0206AGE`80HUII0P1DA5@205e2C`80Gd9>0P1HA58205=3B`80G4Q;0P1<Adh2
05=:A`80BCe80P1B>d8205I5B080C3i40P16<T<2050c?@80>R@m0P1??Sd204Q5?@80<2hk0P0c72P2
05T`>080>R8b0P1E>D020490?080AS`n0P16?3d203hR<P80@BLo0P18@SH202LJ:`80?1@W0P1:83@2
03PU=080>BH`0P0f:S8203Tf<P80<CXd0P0h@c8203Li<080=C@d0P0];2d203`f<080>Shd0P1KNcT2
03eV@`80HFY30P1WJTd203dJ@080LBY?0P1A<D@2079^E@80X[0g0P1mLWD<08=_L`80PFYc0`26KG50
08=_La00oooo000>0?ooo`@0Pfmc0P20LG@208=bLBP0Pfmc0P29K74202bSV@807fiB0P0k@4@20412
?P80FUhl0P1AFTL305AMC080Gf]<0P1RHU0206AGE`80HUII0P1DA5@205e2C`80Gd9>0P1HA58205=3
B`80G4Q;0P1<Adh205=:A`80BCe80P1B>d8205I5B080C3i40P16<T<2050c?@80>R@m0P1??Sd204Q5
?@80<2hk0P0c72P205T`>080>R8b0P1E>D020490?080AS`n0P16?3d203hR<P80@BLo0P18@SH202LJ
:`80?1@W0P1:83@203PU=080>BH`0P0f:S8203Tf<P80<CXd0P0h@c8203Li<080=C@d0P0];2d203`f
<080>Shd0P1KNcT203eV@`80HFY30P1WJTd203dJ@080LBY?0P1A<D@2079^E@80X[0g0P1mLWD<08=_
L`80PFYc0`26KG5008=_La00oooo000>0?oooc80Pfmc0P29K74202i1O080>T9;0P0f:CL205P[=080
C1ll0`1P:Cl207E1A`80JdiD0P1TDEL206IDE`80D4aJ0P1@ADd205M1BP80Dc]80P1G@DX205M5B080
Cce:0P1==T@204lkAP80CdE40P19=Sl2050hA@80Ad=40P0f;3P205EA@P80?TLj0P0l9cP205=>A080
8Sdk0P0l;BP204Hl?P80?34_0P118cH204H[=P80>B4c0P0g9CD203DU:`80<QHV0P0b8C8202l`:P80
@3L/0P0_9bl203DY;@80?3<`0P0f;Rl203@U;P80=AlZ0P0l9S0204@j=@80@5<n0P0oFSX204aY@@80
FU@k0P1YHUD205]YD080C2i;0P0j:e4206IJ=@80@3];0P2fVbh208V4H080PfYf1023Kg<2085ZL`80
QVea0P23Kg<2085ZL`80Pfmc0`23LW4H08=_L`80PFYc0P26KG4208=_L`80QgQc0P1mLWDN08=_La00
oooo000>0?oooc80Pfmc0P29K74202i1O080>T9;0P0f:CL205P[=080C1ll0`1P:Cl207E1A`80JdiD
0P1TDEL206IDE`80D4aJ0P1@ADd205M1BP80Dc]80P1G@DX205M5B080Cce:0P1==T@204lkAP80CdE4
0P19=Sl2050hA@80Ad=40P0f;3P205EA@P80?TLj0P0l9cP205=>A0808Sdk0P0l;BP204Hl?P80?34_
0P118cH204H[=P80>B4c0P0g9CD203DU:`80<QHV0P0b8C8202l`:P80@3L/0P0_9bl203DY;@80?3<`
0P0f;Rl203@U;P80=AlZ0P0l9S0204@j=@80@5<n0P0oFSX204aY@@80FU@k0P1YHUD205]YD080C2i;
0P0j:e4206IJ=@80@3];0P2fVbh208V4H080PfYf1023Kg<2085ZL`80QVea0P23Kg<2085ZL`80Pfmc
0`23LW4H08=_L`80PFYc0P26KG4208=_L`80QgQc0P1mLWDN08=_La00oooo000>0?oooc@0Pfmc0P1B
UHL201<XAP80BCHm0P1DI3/203E8@`<0C4Dj0P1RA3d206m:B`80Ie9E0P1OBeD205Y7EP80@35:0P1F
=T8204`fA080G4I40P1CAdT204TmB080@C500P1D?Sh204hn@P80@SQ30P1DAcl204@i@@80@TE60P0i
:2h204dV?@80>cHm0P14:bh204Hb@`80;2lc0P14;Rd203X[>080=2/`0P0m;30203<Y<P80<2H[0P0c
:2d202d];@80<RhY0P0/8bP202lL9080=R<]0P0d;2`203DX:`80<b@]0P0a9bd203Pe<080@d/c0P13
AcL204Xl>@80BSDn0P1XC40205iQD@80BBm10P1K5d@204dZC080F5m70P1?Dd<2072JD`80RZXn0P24
J74208I]L@80Pfmc0P21JW<208=_L`80Pg9a0P21JW<208=_L`80Pg9a0`27N7<207ebM@H0Pfmc0P27
N7<207ebM@`0Pfmc0P20LG@208=bL@80Pfmc0P29K74208=ZMQh0Pfmc403oool000h0oooo=023Kg<2
05:EQ`804bQ60P19=Sd205AT>`80=DQ30`1<ACX20694?@80KdY;0P1WDUD205m;E@80FTMF0P10<DX2
05Hf@P80C3I40P1LAT@205=7B@80BCe80P11<D0205@n?P80CSi20P12>4<205A7?`80A3U10P12ADH2
03TX;P80CBHm0P0k=Sd204@[;P80AS930P0/;c<204@^;@80>R/h0P0d:c0203d/<080<bTb0P0`9R/2
03<X;@80;Bd]0P0b;RT202`S:080;a`T0P0f8bd203@/;080=BP[0P0c92d2034W;@80>3D`0P13Bc<2
04=7=`80BS`i0P1:=Ch206Q<@080GV5A0P19;d4205/GA080CBY<0P1HGdL204mC@`80L9YC0P2:ZSh2
08AXL@80QVea0P23Kg<2085ZL`80Pfmc0P23LW42085ZL`80Pfmc0P23LW4308MhL`80OG9e1P23Kg<2
08MhL`80OG9e3023Kg<2081aM080Pg9a0P23Kg<208U/L@80PfYf7P23Kg<@0?ooo`003P3ooold08=_
L`80RFaa0P0HXil201YNA080=1L[0P1Y=T8304iHA@80E5I60P1I@TD207EACP80GUYI0P1FEED203Df
CP80E4Lo0P12>T82050d?080ESE20P16<T<203ha?P80DSlj0P1;?44203ha?P80DCHj0P11;Sl204hg
>`80:bHj0P1?@S8203/e>@80>S@h0P0d8R/202hI;@80Cd4b0P0Z9bl203HW;P80=b/]0P0c:Bh202lY
;@80;2@W0P0_8RL202LI8P809ALP0P0/82@202dQ8P80;AdU0P0f9RX203hl<@80;S8`0P0l<bh205=5
=@80EE]40P14FTL205^4B@80DGQ:0P1GBDd203lhE080>C<k0P1SE3h2040/>P80Uh180P27]4P207j6
L080N79d0P26L6l208=_L`80P75d0P23LW4208=_L`80P75d0P23LW4208=_L`<0RFaa0P23JWH608=_
L`80RFaa0P23JWHd08=_La00oooo000>0?oooc@0Pfmc0P29K74201RSW`806Ui40P0d5b/206Tf@P<0
CUQ50P1DETH205U2A@80ME5>0P1NFUT205IEE@80=CI>0P1DAcl2048j@P80D3@l0P1F=D8204Hb@`80
?S4n0P1B?cX204/l@@80?S4n0P1A=SX2044^?`80CSLk0P0[9SX204m2<P80>cDi0P0j=3P203@R:`80
;QT]0P1?@C8202XW;`80=RL^0P0g:bd203<Y;P80;bT]0P0/92L202lR9`809aTR0P0U5b0202`P9080
;B4R0P0]7BD203HV:P80?S`a0P0^<S0203`c;P80DdDe0P1EFd@204AJA`80FhA90P1AN4X205M9C@80
?cQD0P0i<c/206=D?P80@2`j0P2GP4P208NdB080OXI`0P1hLW@208I`K`80Pfmc0P20LG@208=bL@80
Pfmc0P20LG@208=bL@80Pfmc0`29K74208=ZMPH0Pfmc0P29K74208=ZMS@0Pfmc403oool000h0oooo
=023Kg<2085ZL`80QVea0P0cYI8200EPEP80;QlS0`1O7CD205/^@080FCi80P1eFTD206UJF080EU1I
0P0d=4l204</=`80FDA40P0n@44205A7?`80BTm70P0nC4@203`c>080DcXm0P0o?44203X]=@80C3Tl
0P16?c/202l_>`80BS/a0P14?3h203/k>P80<SPi0P0J624203dL8080=B8b0P16BS<202T^;`80<bP/
0P0T6R@203HX:P809b<V0P0S7B8201lI7@809Q/M0P0Q5Qd2028F7080=28S0P10:bX204U7>`80AVHm
0P15DS`205e9@080Hei?0P1H@TL2048@@080FQ]10P1B=DD203m2AP80Ac4c0P1KDTh20:f^9`80RGEZ
0P29Ig@2081/N080Pg9a0P23Kg<2085ZL`80QVea0P27N7<207ebMAD0Pfmc0P21JW<208I]LA00Pfmc
0P27N7<207ebMAX0Pfmc403oool000h0oooo=023Kg<2085ZL`80QVea0P0cYI8200EPEP80;QlS0`1O
7CD205/^@080FCi80P1eFTD206UJF080EU1I0P0d=4l204</=`80FDA40P0n@44205A7?`80BTm70P0n
C4@203`c>080DcXm0P0o?44203X]=@80C3Tl0P16?c/202l_>`80BS/a0P14?3h203/k>P80<SPi0P0J
624203dL8080=B8b0P16BS<202T^;`80<bP/0P0T6R@203HX:P809b<V0P0S7B8201lI7@809Q/M0P0Q
5Qd2028F7080=28S0P10:bX204U7>`80AVHm0P15DS`205e9@080Hei?0P1H@TL2048@@080FQ]10P1B
=DD203m2AP80Ac4c0P1KDTh20:f^9`80RGEZ0P29Ig@2081/N080Pg9a0P23Kg<2085ZL`80QVea0P27
N7<207ebMAD0Pfmc0P21JW<208I]LA00Pfmc0P27N7<207ebMAX0Pfmc403oool000h0oooo2P23Kg<2
085ZL`80QVea9P23Kg<2081aM080Pg9a0P29K74202][S@8044570`0g;RP204DT;`80HCPj0P1[@d82
06i4D080I59J0P0c?5<203Hc?080E3Td0P1@@DL2044c>`80C2Pj0P1><40203L]?@80@BXa0P1;;cX2
03/g?@80@3<b0P14;3L204<m?`80?Cdg0P0l:c@204/h>`80>c/k0P0W?Sd20314;080:BLW0P0h72@2
03/W=@80;b`]0P0[;Rh203Hg:@80:bd^0P0fAS42028h;@80:SHX0P0/?R`2031?;`80=eP`0P0lDSD2
059E=`80FeA30P1ONe8203iEC080ITE40P12:D`202HI=080D3<_0P1B?S/2059;A080@UE90P2@_382
08>OD@P0Pfmc0P27N7<207YdMP80PFea0P2<JVl208=ZMPL0Pfmc0P27N7<207ebM@X0Pfmc0P20LG@2
08=bL@80QgQc0P1mLWD<08=_L`80RFaa0P23JWHJ08=_La00oooo000>0?ooo`X0Pfmc0P21JW<208I]
LBH0Pfmc0P20LG@208=bL@80RFaa0P0[Jhd20111A`<0=bhX0P1592l2064h>P80Jd=20P1^A50206AB
FP80<caC0P0f<c`205@i=080D4570P11<c/204`X>P80CS100P0g;Cd2044Z<@80Bblj0P0k=cd2040c
<P80A2`g0P13?Cl203dm=`80?2/d0P1;>3/203/k>`809chm0P0`A2`202TW9`80>1`T0P0k9cD202l/
;@80:bh^0P0f=bT202/];P80=THa0P0R>2d202Xf:080;3h/0P0`Cbl203MH<080?58e0P1BECL205]D
@`80Gg]B0P0nED`206I5A080@RU<0P0V6C@2050c;`80DShk0P1BBd@2049EB@80T;`b0P23We4808=_
L`80QgQc0P1jM7H2085]L@80S6Y_0P23JWH708=_L`80QgQc0P1mLWD:08=_L`80P75d0P23LW4208Mh
L`80OG9e3023Kg<208U/L@80PfYf6P23Kg<@0?ooo`003P3oool:08=_L`80P75d0P23LW4/08=_L`80
JGel0P0KNGd3021CA@80>44e0P10;2h204TK<P80IbHl0P1R:TD2061GF@808cA10P14;S82058c>080
B3m50P0i>c/2044a=P80=2@e0P0f9Rl203/T;080@BPc0P0k;3@2040c=080ASDe0P0i:SL203T]=@80
Ccld0P16@d0203Tl?@80>c`i0P0Y;S<2045?<`80:c0/0P0a9bd20450<P80=cld0P0b=S@203de;P80
>CPi0P0lCSL2041I>@80C6`n0P0oF48204aG@`80H7=50P1<ET`206PmA@80BRaD0P1E>D<2030L>P80
?CTm0P1;FC<204M6?@80CCLm0P2G[T4207f^B`80QgQc0P22NgD207ebM@80PFYc0P2;MW42085ZL`80
Rg5e0P1jM7H2085]L@80QVea0P27N7<207ebM@<0Pfmc0P29K74208=ZMPh0Pfmc0P29K74208=ZMPH0
Pfmc0P27N7<207ebMB00Pfmc403oool000h0oooo2P23Kg<2081aM080Pg9a;023Kg<206UmO0806gUm
0`0PDdD203Q1=@80@2`^0P196c8206LV?080HRY50P1PEeT202<d@@80A2hb0P1B<cP204PoA@80>C/k
0P11<CH203@T=@80=RH_0P0k92`2044X<`80>b`d0P10<c@204He=@80>BXg0P0i;CD204lo=080AT=0
0P0i?3d203/l>@80:Bhc0P11Cc<202/`;080<BL]0P11@38203Lo=080<SHd0P0m=Bh203Th>@80?4hg
0P10FCT204a/?P80?eQ20P1<Ed<2061cA@80C5I<0P1X?DD204X/E080ECU30P0`73X203di?@80BeTc
0P17ASd204dg?@80Uji10P1m[T/208MhL`80PW]e0P1mLWD2085ZL`80RgIa0P21JW<208]aM@80NWAf
0P21KG4208I]L@80QgQc0P1mLWD308=_L`80RFaa0P23JWH>08=_L`80RFaa0P23JWH608=_L`80QgQc
0P1mLWDP08=_La00oooo000>0?oooc@0Pfmc0P27N7<207ebM@@0Pfmc0P1OPX03029XK`80;3m20P0l
>cX203a2>080CdLf0P1@@T4206e8?`80?eEP0P0Y?c/2048`<`80EC`j0P13@D@203Hf>P80@dXm0P0V
;c4203H];@80=b`]0P11=S<203dg=080@cTg0P0^9C8204a2=P80@Cdf0P1FAch203`o@`80B4/o0P0m
GTH203Hn=@80;bTg0P0c<Bl204Pn<080?cTj0P16CCd203iD?P80AETn0P18E40205YVA080F6590P1?
F5<2040iA080FbHk0P1B84H203lH>080<``/0P1452h204Lg@080Adlg0P17>cX205M:A080M/Y60P23
^Cl208=ZMP80RFaa0P2=L7@2089fN@80NWAf0P29Kfh208AeN080Pg9a0P23JWH2081aM080Pg9a0P29
K74208=ZMQl0Pfmc0P29K74208=ZMR00Pfmc403oool000h0oooo=023Kg<208MhL`80OG9e1023Kg<2
05n2P0<08VQ_0P0/?d8203`k>P80?48h0P1?AcH20512@@80KDPo0P0oEF0202To>`80@S0c0P1E?3X2
04=1A080=SHj0P13BSd202H_<@80=Rd]0P0g;2d2044f<`80?CLd0P13>CL202hU<P80C48f0P11?CH2
05I7?P80?3m30P18Bcl203eNAP80=She0P0_:CL203<a;`80B3h`0P0o>CX204I=?@80?U@n0P15FCh2
04QD@080FVI40P1HHDT204mHD`80@3U40P1K9S/2058PAP80?aPh0P0c32`204@D;P80AcM00P17CcL2
04Lk>P80EdY40P1fbTH208>i?`80PfYf0P29K74208e`M080PWIi0P1jM7H208U_KP80Q7Eh0P23LW42
08=ZMP80P75d0P23LW4208U/L@80PfYf7`23Kg<208U/L@80PfYf8023Kg<@0?ooo`003P3ooold08=_
L`80QVMa0P26J7D208=_L`80PFYc0P26KG4305:9Q@8087i]0P0T=S`204Pd=P80DdDk0P1CC4<205a?
A080H4m<0P10He`202Y5?`80D4@g0P0i:3P204dm?`80@3Tg0P0l?d<203=1=@80;B/^0P0g92X2038K
:P80ARP_0P0_9c<2050l;P80@C@l0P1OCc/204E9B@80JH=50P1ASU8203B0GP80;gI=0P11STH203j3
A@80@gM;0P1=LTL205V8C`80C8mD0P15M5D205iXC080B3M=0P1673h204`XA080?Rli0P0i8S8203@R
<`80<cHc0P16G3<204iQ>080@3m00P16>d0209Vn=@80PjY90P23JWH208MhL`80OG9e0P29K74208UW
M080PfYf0P23Kg<208U/L@80PfYf0P21JW<208I]L@80Pfmc0P27N7<2089kM@<0OG9e@023Kg<@0?oo
o`003P3ooold08=_L`80QVMa0P26J7D208=_L`80PFYc0P26KG4305:9Q@8087i]0P0T=S`204Pd=P80
DdDk0P1CC4<205a?A080H4m<0P10He`202Y5?`80D4@g0P0i:3P204dm?`80@3Tg0P0l?d<203=1=@80
;B/^0P0g92X2038K:P80ARP_0P0_9c<2050l;P80@C@l0P1OCc/204E9B@80JH=50P1ASU8203B0GP80
;gI=0P11STH203j3A@80@gM;0P1=LTL205V8C`80C8mD0P15M5D205iXC080B3M=0P1673h204`XA080
?Rli0P0i8S8203@R<`80<cHc0P16G3<204iQ>080@3m00P16>d0209Vn=@80PjY90P23JWH208MhL`80
OG9e0P29K74208UWM080PfYf0P23Kg<208U/L@80PfYf0P21JW<208I]L@80Pfmc0P27N7<2089kM@<0
OG9e@023Kg<@0?ooo`003P3ooold08=_L`80P75d0P23LW4208=_L`80P75d0P27Ng0307ebM@80FXF2
0P0O`7d201]RB@80@cHh0P0o7C@206H_?080LUM90P1OGE<203iSH080>Ti20P12CTL204I<>P80ATM5
0P12@cd204aEA@80?7Q:0P0WF3l202@`;`80@SX/0P0/:2l204`i;P80De4o0P1MI40204aBCP80GCLn
0P29@E4206EDH080Ef=O0P1WLU8206=mGP80F85N0P1CJe/205e3CP80I2Q@0P1O:U4205LWB080@b97
0P0m<Cl2040c=080<1l`0P0d8bh2048m<`80@4Pf0P1IF3P204Di@080DTI80P1d`T@208Vf?080PfYf
0P21JW<208aZK`80PfYf0P21JW<208AXL@80QVea1023Kg<2085ZL`80Pfmc0P23LW4208=_L`80RFaa
0P29Ig@308=ZMP80PFYc0P26KG4l08=_La00oooo000>0?oooc@0Pfmc0P20LG@208=bL@80Pfmc0P20
LG@208MkL0<0OG9e0P1JQH8201o0O@806f990P13=SP203lM=080IRll0P1bEdT205mMD`80?V=P0P0j
CT82049>A`80AT`j0P16AdD20493?@80C5E50P0lN4X202MH?`80930_0P12>R`202`X;`80C3T^0P1C
DCl205eT@080C59>0P1M=ch208U1D@80IEAP0P1GHel206MbDP80HgeN0P1HPEh205=[F`80GD=>0P1T
:50205lZD@80EbM80P138TL203da?`80@3<d0P0`7c0203@S;P80@Sdc0P10B3H205UH>080ACU00P1B
ATP207C2A080RKHl0P23JWH2085ZL`80S6Y_0P23JWH2085ZL`80Q6Qa0P26KG4408=_L`80PFYc0P23
Kg<208=bL@80Pfmc0P29K74208UWM0<0PfYf0P21JW<208I]LC`0Pfmc403oool000h0oooo?023Kg<2
08eeL0<0OFei0P23Kg<207ibM@80>:N=0P0DDe42030`>080F4<a0P1R=c/207A1CP80KVIH0P0mHF02
051ZC080DW]B0P15Kdl205B?DP80BhM?0P1AG50205N4G@80:KiN0P0glDT201WVGP80;m9<0P19Ydh2
05R<E@80CG5L0P1AQU/206AoC0@0If9M0P1`JE`206I:F`80EamC0P1e;U@204X_DP80BBa30P1?;Cl2
04Ta@@80=bTi0P11;SD203<T<@80A48j0P0mGSX2045D>080ATLm0P1=>CX208NdB080?=mI0P23ZdP2
08MhL`80Nfee0P23Kg<208=bL@80Pfmc0P20LG@207e_LP80QW1_1023Kg<2081aM080PFea0P26KG42
08=_L`80QgQc0P1mLWD308=_L`80OFad0P26L6l208=_L`80PFYc0P26KG4208MhL`80OG9e<P23Kg<@
0?ooo`003P3oooll08=_L`80SGE`0`1mKGT208=_L`80OW9e0P0hYhd201ACD@80<30h0P1H@c42068g
>`80M45>0P1^IUP203eQH080D6Y<0P1BNe8204E_C`80E8mB0P1;Qdl2055LD080EhAM0P0Y_Uh203Oa
B@806NIN0P0_dT`204VWCP80F8aE0P1=LE`20566F`80I7m<101WHUd2071YG080ITYK0P1G7e<207D^
E080BRmB0P19;4<204l]?`80BC510P0g:CT2044^=@80<b@a0P14@SX203eN>P80@E@h0P16Acd204di
>P80QkA80P0lgeT208>[B080QgQc0P1kKGD208=_L`80Pg9a0P23Kg<2081aM080OFmb0P26L6l408=_
L`80P75d0P21KG4208I]L@80Pfmc0P27N7<207ebM@<0Pfmc0P1mK7@208I`K`80Pfmc0P21JW<208I]
L@80QgQc0P1mLWDb08=_La00oooo000>0?ooobP0Pfmc0P27N7<207ebMA00Pfmc0P2=MG0307e]N@@0
Pfmc0P29K742036FU@807LeS0P0N?S`204dZ=`80K3`k0P1c?4T206aAG@80IGAI0P1[OEP205McI@80
KVmE0P1WHV@205Y`I080MWYB0P1]EV8208=9G@80P4IX0P1bC6P207UQI080LW1U0P1QL6X206UYGP80
KF=S0P1NCUh205leE@80PDED0P1C=e`204e3EP80GE140P0h:4H204Xe?`80>BXg0P14:SH204<l?@80
@dhk0P12JTD204Ua?@80ATi40P15?d<205aNA@80I/E<0P29]c`2085UMP80QVea0P26Ig4208=ZMP80
Pg9a1P23Kg<2081aM080Pg9a0P21JW<208I]L@80Pfmc0P20LG@208=bL@80Pfmc0P29K74208=ZMP<0
Pfmc0P20LG@208=bL@80Pfmc0P20LG@208=bL@80RFaa0P23JWH>08=_L`80QgQc0P1mLWD208=_L`80
QgQc0P1mLWD2085ZL`80QVea5P23Kg<@0?ooo`003P3ooolX08=_L`80QgQc0P1mLWD@08=_L`80SGE`
0`1mKGT408=_L`80RFaa0P0aUYD201g=H`807Shl0P1=:SL206`l>`80Lca90P1/DEd206EdF@80JgeH
0P1GLfD206i_E@80If9T0P1JL6@207IjDP80KEIR0P23BEd20816J080LTaX0P1iHF@2079`I@80HG1Z
0P1YJEh206eSH`80GTiN0P1O=ED20855E080DcML0P1=@eH205e@A080>2Q60P1:=Cl203TZ=`80A2Xf
0P13?3d204=>>`80@VY50P19LCd204I>A080ACm30P1LGTD206K5C080RKLl0P21IGH208I]L@80QVMa
0P23JWH208=bL@H0Pfmc0P20LG@208=bL@80PFYc0P26KG4208=_L`80P75d0P23LW4208=_L`80RFaa
0P23JWH308=_L`80P75d0P23LW4208=_L`80P75d0P23LW4208U/L@80PfYf3P23Kg<208MhL`80OG9e
0P23Kg<208MhL`80OG9e0P21JW<208I]LAH0Pfmc403oool000h0oooo:023Kg<208U/L@80PfYf3023
Kg<208MhL`80OG9e0P2=MG03089fN@80OG9e0P27N7<207ebM@80Pfmc0P1gPGT201VSSP807F=90P1?
@3T205`g@@80ODi70P1_BED207U8F@80LdeQ0P1dFf0207AWHP80KV]T0P1dIf8206YWJ@80LgmR0P1Y
MVD206U]I`80M6UP0P1lIVD206aKJ@80KEYU0P1ZD5l206EEH`80ATIH0P1L<d@2060iD`80A2m50P1B
:Cl203d[A080DDPk0P0];c/2051>>080D6<o0P1<H4H205EBA@80CcU80P1JBT`206JKC`80GlU?0P23
We4208=_L`80OFad0P26L6l2081aM080Pg9a0P27N7<207ebM@80QgQc0P1mLWD208=_L`80PFYc0P23
Kg<208=bL@l0Pfmc0P27N7<207ebM@`0Pfmc0P27N7<207ebM@H0Pfmc0P27N7<208=_L`80PfYf0P23
Kg<208U/L@80Qg=f0P1jM7H208=bLAH0Pfmc403oool000h0oooo:023Kg<208U/L@80PfYf3023Kg<2
08MhL`80OG9e0P2=MG03089fN@80OG9e0P27N7<207ebM@80Pfmc0P1gPGT201VSSP807F=90P1?@3T2
05`g@@80ODi70P1_BED207U8F@80LdeQ0P1dFf0207AWHP80KV]T0P1dIf8206YWJ@80LgmR0P1YMVD2
06U]I`80M6UP0P1lIVD206aKJ@80KEYU0P1ZD5l206EEH`80ATIH0P1L<d@2060iD`80A2m50P1B:Cl2
03d[A080DDPk0P0];c/2051>>080D6<o0P1<H4H205EBA@80CcU80P1JBT`206JKC`80GlU?0P23We42
08=_L`80OFad0P26L6l2081aM080Pg9a0P27N7<207ebM@80QgQc0P1mLWD208=_L`80PFYc0P23Kg<2
08=bL@l0Pfmc0P27N7<207ebM@`0Pfmc0P27N7<207ebM@H0Pfmc0P27N7<208=_L`80PfYf0P23Kg<2
08U/L@80Qg=f0P1jM7H208=bLAH0Pfmc403oool000h0oooo>023Kg<208U/L@80PfYf0P29K74308UW
M080PfYf0P29K74208=ZMP80PFYc0P2<JVl207ehNP80<Z>;0P0egUl202IWE080DBll0P1P8TD20896
C080M5iI0P1fJed207AWHP80Lf5U0P1aG6D2071CH`80QEYO0P1bD6T2079?I080KdQQ0P1^=EX206LW
F@80IR=A0P1`<e@206a1D`80CSeI0P17?TX2044T>@80CRe30P1DEd8203e@AP80GV]00P0jM5D20565
@@80DfI<0P18?T/206IBC080JZeE0P1=cUP207>/D`80PgiX1023Kg<2081aM080Qg]`0P1mLWD208=_
L`80RFaa0P23JWH208IWL@80QVQe0P23Kg<208AjM080OGEc0P27N7<207ebM@@0Pfmc0P21JW<208I]
L@80QgQc0`1mLWD208U/L@80PfYf1023Kg<208MhL`80OG9e1023Kg<208U/L@80PfYf1P23Kg<208U/
L@80PfYf0P23Kg<208MhL`80PW]e0P27N7<207]XN080QVea2P23Kg<208MhL`80OG9e2023Kg<@0?oo
o`003P3ooolh08=_L`80RFaa0P23JWH208U/L@<0RFMd0P23JWH208U/L@80PfYf0P21JW<208aZK`80
OGQj0P0bXh/203GNG`809VMD0P1A;c`2060RA@80PTI<0P1dGUT207I[G@80M6MR0P1cHFD2075LI@80
L5=S0P25FUl2079@J@80LTmT0P1_B64206heFP80IbMI0P1V8e42070cE080K45C0P1>?ET204LnBP80
@B@i0P1>;D<205AG@P80?E160P1NJd0203YdE@80DHE10P1CIT`204PnB`80IU9<0P1Z[ED204g>F080
LjaC0P23OVP408=_L`80P75d0P27Ng0207ebM@80Pfmc0P29K74208=ZMP80QVMa0P26J7D208=_L`80
Q7Yd0P1mMG<208MhL`80OG9e1023Kg<2085ZL`80QVea0P27N7<307ebM@80RFaa0P23JWH408=_L`80
QgQc0P1mLWD408=_L`80RFaa0P23JWH608=_L`80RFaa0P23JWH208=_L`80QgQc0P22NgD208MhL`80
NfQh0P26KG4:08=_L`80QgQc0P1mLWD808=_La00oooo000>0?ooobH0Pfmc0P27N7<207ebMAT0Pfmc
0P21JW<208]fL@80NWAf0P23LW4208eeL080OFei0P23Kg<204>AR`80<MEX0P0gheX203aTC`80IC1;
0P23>E4207DmF`80N4AM0P1oGV4206a[IP80M6YP0P1_IFP206a/I@80IG5V0P1BI6<205IZF`80B5eE
0P1JE4X205LnC080IUMC0P1FQEP202U[F080EXe30P1IST/204IkF`80CeM:0P1H>D`207UFCP80LH]L
0P18b6X204oIF080OZ]F0P1mMG<408=_L`80QgQc0P1mLWD208=_L`80RFaa0P23JWH208=_L`80QgQc
0P1mLWD2081aM080Pg9a0P23Kg<208U/L@80PfYf0P26Ig4208IXM@@0Pfmc0P20LG@208=bL@80RFaa
0`23JWH208MhL`80OG9e0P27N7<2089kM@80QgQc0P22MWT2089kM@80OG9e2023Kg<208MhL`80OG9e
1023Kg<208eeL080Qg=f0P23JWH208AeN080OGEc2P23Kg<208U/L@80PfYf2023Kg<@0?ooo`003P3o
oolV08=_L`80QgQc0P1mLWDI08=_L`80PFYc0P2;MW4207YdMP80Pg9a0P2=MG0207e]N@80Pfmc0P13
TH/2037EJ080=n=J0P0lI4l206D`B`80PcUA0P1e?E/207Q4G@80OeiQ0P1/JfH207AZH080KfEX0P1/
K6D206EaIP80DVAS0P1FJU/204QME@80FUA:0P1G?T`206IGD`80EXEH0P0YJeP205J=@`80FHi;0P16
Ne/204mGBP80F3U<0P1iETh2076;G080B<QZ0P1?fEP207j[EP80OGEc1023Kg<208MhL`80OG9e0P23
Kg<208U/L@80PfYf0P23Kg<208MhL`80OG9e0P20LG@208=bL@80Pfmc0P29K74208=ZMP80QVMa0P26
J7D408=_L`80P75d0P23LW4208U/L@<0PfYf0P27N7<207ebM@80QgQc0P22NgD208MhL`80PWIi0P22
NgD207ebM@P0Pfmc0P27N7<207ebM@@0Pfmc0P2=MG0208McMP80PfYf0P24MGP207eeL`X0Pfmc0P29
K74208=ZMPP0Pfmc403oool000h0oooo9023Kg<2085ZL`80S6Y_0P23JWHI08=_L`80P75d0P29Kfh2
08=ZMP80Pfmc0P29K74208=ZMP80Pfmc0P27N7<207ebM@80QgQc0P13TH/204?7I@80?fYG0P1P@e82
07EDD`80J3iC0P21?UX207iBH080MEMS0P1mI6@2075TI`80K7Y/0P1VUVD204nGK@80CI1R0P1:QV02
06J=DP80JViJ0P1DK6/205IFD080ISA@0P1d@UL2069/H@80F:IL0P1X^U<207VFGP80SGiZ0P27LgH2
085UMP80QVQe1023Kg<208U/L@80PfYf1023Kg<2085ZL`80QVea0P29K742085UMP80QVea1023Kg<2
085ZL`80QVea0P20LG@208=bL@P0Pfmc0P21JW<308I]L@80RFaa0P23JWH208U/L@H0RFMd0P26HW@2
08IXM@80QgQc0P1kKGD208I]L@80Pfmc0P29K74208=ZMP80Pfmc0P21JW<208aZK`80RFMd0P23JWH2
08U/L@80PFEf0P26KG4D08=_La00oooo000>0?ooob@0Pfmc0P21JW<208aZK`80PfYf6@23Kg<2081a
M080RFm^0P23JWH208=_L`80RFaa0P23JWH208=_L`80QgQc0P1mLWD208MhL`80@i6;0P13afD203mZ
E`80H4=B0P1eE5<206PnD`80PCiJ0P1nDV0207EGH`80OFAT0P1aI6L206ajK080IYIU0P1?Ufd204f@
HP80BXIP0P1VSE8206Y^FP80E6a[0P1FEU0206HdD080M49G0P1RK64205RVG080J;YC0P1iUUh208en
JP80Qg=f0P21IGH208IXM@@0Pfmc0P29K74208=ZMP@0Pfmc0P21JW<208I]L@80RFaa0P21IGH208I]
L@@0Pfmc0P21JW<208I]L@80P75d0P23LW4808=_L`80PFYc0`26KG4208U/L@80PfYf0P29K74608UW
M080QV9d0P26J7D208MhL`80Nfee0P26KG4208=_L`80RFaa0P23JWH208=_L`80PFYc0P2<JVl208UW
M080PfYf0P29K742085UMP80QVea5023Kg<@0?ooo`003P3ooolT08=_L`80P75d0P27Ng0207ebMB40
Pfmc0P21JW<208I]L@80Pfmc0P2=MG0207]XN080RFE_0P26J7D208=_L`80DXV50P1</VL2062/G@80
DJA]0P1LWeh206b9H@80J7IX0P1oP68206eeKP80KeQU0P1i>f8207`fH`80O4YU0P1_FVD2079HG`80
L5AS0P1bGV4206>5J`80D;9T0P1L^U/206RUH@80NHeU0P23N6`208=_L`80SGE`0P27LgH207Y_NP80
Qg]`1022NgD207ebM@H0Pfmc0P20LG@2085]L@80Q6Qa0P23Kg<208=bL@@0Pfmc0P20LG@208=bL@80
PFYc0P26KG4208MhL`80Nfee0P26KG4208=_L`80P75d0`27Ng0207ebM@X0Pfmc0P20LG@208=bL@80
RFaa0P24MGP207eeL`80QgQc0P1mLWD408=_L`80P75d0P23LW4608=_L`80Q7Yd0P1mMG<<08=_L`80
QgQc0P1mLWD408=_La00oooo000>0?ooob@0Pfmc0P20LG@208MkL080OG9e8@23Kg<2085ZL`80QVea
0P23Kg<208eeL080NfQh0P29IFl208IXM@80Pfmc0P1BRHD204bbI`80H:aM0P1AY6d205bOGP80K8UQ
0P1XMVP207n0HP80KGE^0P1_F6D207TkHP80O3IS0P1lBVD206mJI@80LUQO0P1`E6<2079NH@80HhE[
0P1@/V@205bjF`80J:EQ0P1iSFD208=hK080Pfmc0P2=MG0208McMP80NVmj0P27Ng04089kM@80OG9e
1P23Kg<2081aM080PFea0P24J74208=_L`80Pg9a1023Kg<2081aM080Pg9a0P21JW<208I]L@80QgQc
0P1kKGD208I]L@80Pfmc0P20LG@308MkL080OG9e2P23Kg<2081aM080Pg9a0P29K74208AeN080OGEc
0P27N7<207ebM@@0Pfmc0P20LG@208=bL@H0Pfmc0P24NW@207eeL``0Pfmc0P27N7<207ebM@@0Pfmc
403oool000h0oooo9P23Kg<208U/L@80PFEf0P26KG4E08=_L`80QgQc0P1kKGD208I]L@@0Pfmc0P20
LG@2085]L@80QVea0P29K742081/N080P7Ab0P23LW4408=_L`80P75d0P20M78208AmLP80M7Yf0P1i
OG0207>0LP80Oh1Z0P1iNG@206J1MP80H9A^0P1PW6P206VGI080L9iY0P1PVVl206FJJ`80JIQY0P1i
S6H2081jKP80Pg9a0P27N7<2089kM@80OG9e0P23Kg<208U/L@80SG1d0P1mKGT208U/L@@0RFMd0P21
IGH208I]L@80QgQc0P1mLWD208=_L`80Q7Yd0P1jMg@208=bL@80Pfmc0P27N7<207ebM@80QgQc0P1m
LWD208AjM080OGEc0P26Ig4208=ZMP80Pg9a0P21JW<208I]L@<0RFaa0P23JWH@08=_L`80QVMa0P26
J7D208U/L@80Qg=f0P1mLWD608=_L`80QgQc0P1mLWD208=_L`80RFaa0P23JWH<08=_L`80RFaa0P23
JWH408=_La00oooo000>0?ooobH0Pfmc0P29K742085UMP80QVea5@23Kg<208MhL`80Nfee0P26KG44
08=_L`80P75d0P21KG4208I]L@80RFaa0P20K7P2081dLP80Pg9a1023Kg<2081aM080P7Ab0P24OG82
07AjMP80NGe`0P1cP78207n0JP80NGUd0P1VPGH2062DKP80H9aX0P1YUf@2072NJ@80H9Y_0P1UVV/2
06VHJ@80NHaV0P20NVh208=bL@80QgQc0P22NgD207ebM@80Pfmc0P29K74208e`M080OFei0P29K744
08UWM080PFEf0P26KG4208MhL`80OG9e0P23Kg<208AjM080NWMd0P23LW4208=_L`80QgQc0P1mLWD2
08MhL`80OG9e0P24NW@207eeL`80QVMa0P23JWH208=bL@80PFYc0P26KG4308U/L@80PfYf4023Kg<2
08IWL@80QVQe0P29K74208McMP80OG9e1P23Kg<208MhL`80OG9e0P23Kg<208U/L@80PfYf3023Kg<2
08U/L@80PfYf1023Kg<@0?ooo`003P3ooolX08=_L`80P75d0P23LW4E08=_L`80RFaa0P20K7P208=b
L@@0Pfmc0P21JW<208=_L`80Pg9a0P21JW<208]fL@80OG9e1023Kg<2085ZL`80QVea0P21JW<208aZ
K`80PfYf0P27N7<207]]M@80QVea0P23Kg<2081aM0H0P7Ab0P2=N6h207e]N@80Pfmc0P21JW<208I]
L@@0Pfmc0P29K74208UWM080PfYf0P27N7<207ebM@80SGE`0P1mKGT408=_L`80PFYc0P27N7<207ee
L`80SGE`0P22MWT207ebM@80RFaa0P23JWH408=_L`80RFaa0P23JWH208U/L@80PfYf0P2=MG0207]X
N080PFYc0P26L6l2085ZL`80Pfmc0P23LW4=08=_L`80QgQc0P1mLWD408=_L`80P75d0P23LW4208=_
L`80SGE`0P1mKGT408=_L`80PFYc0P2<JVl208McMP80PW]e0P1mLWD>08=_L`80QgQc0P1mLWD2085Z
L`80QVea403oool000h0oooo:023Kg<2081aM080Pg9a5@23Kg<208U/L@80P6ah0P23LW4408=_L`80
PFYc0P23Kg<208=bL@80PFYc0P2;MW4207ebM@@0Pfmc0P21JW<208I]L@80PFYc0P2<JVl208=ZMP80
QgQc0P1kKGD208I]L@80Pfmc0P20LG@6081dLP80SGQ^0P1mKGT208=_L`80PFYc0P26KG4408=_L`80
RFaa0P29Ig@208=ZMP80QgQc0P1mLWD208eeL080OFei1023Kg<2085ZL`80QgQc0P1mMG<208eeL080
PWIi0P1mLWD208U/L@80PfYf1023Kg<208U/L@80PfYf0P29K74208=ZMP80SGE`0P1kJ7P2085ZL`80
QW1_0P21JW<208=_L`80Pg9a3@23Kg<208MhL`80OG9e1023Kg<2081aM080Pg9a0P23Kg<208eeL080
OFei1023Kg<2085ZL`80S6Y_0P27LgH2089kM@80OG9e3P23Kg<208MhL`80OG9e0P21JW<208I]LA00
oooo000>0?ooobX0Pfmc0P27N7<207ebMAd0Pfmc0P20LG@208=bL@80QgQc0P1nOGH208=bL@80PfYf
0P23Kg<2085ZL`80Pfmc0P23LW4208AjM080OGEc0P23Kg<208U/L@80Q7Eh0P1mMG<208=_L`80QgQc
0P1mLWD408=_L`80QVMa0P26J7D208=_L`80P75d0P23LW4408=_L`80PFYc0P26KG4208MhL`80Pfmc
0P23JWH208eeL080PWIi0P1mLWD208=_L`80P75d0P26JVh208IXM@80RFaa0P26HW@208IXM@80QgQc
0P1mLWD608=_L`80QgQc0P1mLWD208=_L`80RFaa0P20K7P2081dLP80Pg9a0P20LG@208=bL@80Pfmc
0`27N7<207]]M@80QVea1P23Kg<208eeL080OFei0P23Kg<208MhL`80OG9e0P23Kg<2085ZL`80S6Y_
0P23JWH408=_L`80P75d0P23LW4208IWL@80TFic0P1mKGT>08=_L`80RFaa0P23JWH208AjM080OGEc
403oool000h0oooo:P23Kg<208MhL`80OG9e7@23Kg<2081aM080Pg9a0P27N7<207imMP80Pg9a0P23
JWH208=_L`80PFYc0P23Kg<208=bL@80Q7Yd0P1mMG<208=_L`80RFaa0P24MGP207eeL`80Pfmc0P27
N7<207ebM@@0Pfmc0P26Ig4208IXM@80Pfmc0P20LG@208=bL@@0Pfmc0P21JW<208I]L@80QgQc0P23
Kg<208=ZMP80SGE`0P22MWT207ebM@80Pfmc0P20LG@208IZKP80QVQe0P29K74208IRM080QVQe0P27
N7<207ebM@H0Pfmc0P27N7<207ebM@80Pfmc0P29K742081/N080P7Ab0P23LW42081aM080Pg9a0P23
Kg<308MhL`80Nfee0P26KG4608=_L`80SGE`0P1mKGT208=_L`80QgQc0P1mLWD208=_L`80PFYc0P2<
JVl208=ZMP@0Pfmc0P20LG@208=bL@80QVMa0P2AKW<207e]N@h0Pfmc0P29K74208=ZMP80Q7Yd0P1m
MG<@0?ooo`003P3ooolR08=_L`80QgQc0P1mLWD208=_L`80PFYc0P2<JVl208=ZMP80PFYc0P26KG4E
08=_L`80PFYc0P2;MW4207ebM@80Pfmc0P29K74208IRM080QVQe1023Kg<2081aM080PFea0P2;MW42
085ZL`80QVQe1023Kg<208eeL080OFei0P23Kg<208U/L@80Qg=f0P1mLWD2085ZL`80Pfmc0P23LW42
085ZL`80QVea1P23Kg<2081aM080Pg9a0P29K74208=ZMP80Pfmc0P29K74208e`M080OFei0P23Kg<2
085ZL`80Pfmc0P27Ng0207ebM@80P75d0P23LW4208IWL@80Rg5e0P22NgD207ebM@80Pfmc0P26Ig42
08]aM@80OG9e1P23Kg<208MhL`80OG9e1023Kg<308eeL080NVmj0P23LW4208=_L`80QgQc0P1mLWD2
08U/L@80Qg=f0P1mLWD208U/L@80Qg=f0P22NgD207YdMP80Pg9a0P27N7<207ebM@@0Pfmc0P21JW<2
08=_L`80RFm^0P23JWH:08=_L`80QgQc0P1mLWD408=_L`80RFaa0P23JWH@0?ooo`003P3ooolR08=_
L`80QgQc0P1mLWD208=_L`80PFYc0P2<JVl208=ZMP80PFYc0P26KG4E08=_L`80PFYc0P2;MW4207eb
M@80Pfmc0P29K74208IRM080QVQe1023Kg<2081aM080PFea0P2;MW42085ZL`80QVQe1023Kg<208ee
L080OFei0P23Kg<208U/L@80Qg=f0P1mLWD2085ZL`80Pfmc0P23LW42085ZL`80QVea1P23Kg<2081a
M080Pg9a0P29K74208=ZMP80Pfmc0P29K74208e`M080OFei0P23Kg<2085ZL`80Pfmc0P27Ng0207eb
M@80P75d0P23LW4208IWL@80Rg5e0P22NgD207ebM@80Pfmc0P26Ig4208]aM@80OG9e1P23Kg<208Mh
L`80OG9e1023Kg<308eeL080NVmj0P23LW4208=_L`80QgQc0P1mLWD208U/L@80Qg=f0P1mLWD208U/
L@80Qg=f0P22NgD207YdMP80Pg9a0P27N7<207ebM@@0Pfmc0P21JW<208=_L`80RFm^0P23JWH:08=_
L`80QgQc0P1mLWD408=_L`80RFaa0P23JWH@0?ooo`003P3ooolR08=_L`80RFaa0P23JWH208=_L`80
P75d0P23LW4208MhL`80NWAf0P23LW4E08=_L`80P75d0P29Kfh208=ZMP@0Pfmc0P20LG@208=bL@H0
Pfmc0P1mK7@208a]K@80P6ah0P23LW4208MhL`80Nfee0P2<JVl208McMP80OG9e0P23Kg<208U/L@80
PfYf0P24NW@207eeL`80QgQc0P1jM7H208=bL@P0Pfmc0P21JW<208I]L@80QgQc0P1mLWD208=_L`80
RFaa0P23JWH208=_L`80P75d0P23LW4208U/L@80PfYf1023Kg<2081aM080RFm^0P26HW@208IXM@80
Pfmc0P20LG@208U_KP80PfYf0P23Kg<2085ZL`80RgIa0P21JW<208]aM@80OG9e0P23Kg<308eeL080
OFei0P23Kg<2085ZL`80S6Y_0P23JWH208=_L`80RFaa0P23JWH208=_L`80RFaa0P29Ig@208=ZMP80
Pfmc0P29K74208=ZMP80PFYc0P26KG42081aM080Pg9a3023Kg<2085ZL`80TG=_0P1mKGT808=_La00
oooo000>0?ooob80Pfmc0P29K74208=ZMP80Pfmc0P20LG@208=bL@80QgQc0P1jM7H208=bLAD0Pfmc
0P20LG@208U_KP80PfYf1023Kg<2081aM080Pg9a1P23Kg<207e/M080S6e]0P20K7P208=bL@80QgQc
0P1kKGD208aZK`80Qg=f0P1mLWD208=_L`80RFaa0P23JWH208AjM080OGEc0P27N7<207YdMP80Pg9a
2023Kg<2085ZL`80QVea0P27N7<207ebM@80Pfmc0P29K74208=ZMP80Pfmc0P20LG@208=bL@80RFaa
0P23JWH408=_L`80P75d0P29Kfh208IRM080QVQe0P23Kg<2081aM080RFm^0P23JWH208=_L`80PFYc
0P2;MW42085ZL`80Rg5e0P1mLWD208=_L`<0SGE`0P1mKGT208=_L`80PFYc0P2<JVl208=ZMP80Pfmc
0P29K74208=ZMP80Pfmc0P29K74208UWM080PfYf0P23Kg<208U/L@80PfYf0P21JW<208I]L@80P75d
0P23LW4<08=_L`80PFYc0P2ALfl207e]N@P0Pfmc403oool000h0oooo:023Kg<208MhL`80OG9e0P29
K74208=ZMQD0Pfmc0P21JW<208I]LA80Pfmc0P1mK7@208A[K`80QVea0P23Kg<208U/L@80P6ah0P21
KG42095cK`80PWIi0P1mLWD208=_L`80QgQc0P21JW<208IXM@80RFaa0P23JWH408=_L`80QgQc0P1m
LWD4085ZL`80QW1_0P29K74208McMP80Nfee0P26KG4208MhL`80OG9e0P27N7<207ebM@80Pfmc0P27
N7<207ebM@80QgQc0P1mLWD208=_L`80P75d0P23LW4208=_L`80QgQc0P1mLWD408=_L`80P75d0P29
Kfh207eWN080S6e]0P27LgH207ebM@<0RFaa0P23JWH208MhL`80NWAf0P23LW4208=_L`80QgQc0P1m
LWD208MhL`80OG9e0P23Kg<208MhL`80Nfee0P26KG4408=_L`80P75d0P23LW4208MhL`80OG9e0P23
Kg<208MhL`80OG9e1P23Kg<2081aM080RFm^0P23JWH408=_L`80PFYc0P24J74@0?ooo`003P3ooolX
08=_L`80QgQc0P1mLWD208U/L@80PfYf5@23Kg<2085ZL`80QVea4P23Kg<207e/M080Q6]_0P26KG42
08=_L`80RFaa0P20K7P2085]L@80TG=_0P22MWT207ebM@80Pfmc0P27N7<2085ZL`80QVQe0P29K742
08=ZMP@0Pfmc0P27N7<207ebM@@0PFYc0P26L6l208U/L@80Qg=f0P1kKGD208I]L@80QgQc0P1mLWD2
08MhL`80OG9e0P23Kg<208MhL`80OG9e0P27N7<207ebM@80Pfmc0P20LG@208=bL@80Pfmc0P27N7<2
07ebM@@0Pfmc0P20LG@208U_KP80OFMh0P2<KFd208McMP80OG9e0`29K74208=ZMP80QgQc0P1jM7H2
08=bL@80Pfmc0P27N7<207ebM@80QgQc0P1mLWD208=_L`80QgQc0P1kKGD208I]L@@0Pfmc0P20LG@2
08=bL@80QgQc0P1mLWD208=_L`80QgQc0P1mLWD608=_L`80P75d0P29Kfh208=ZMP@0Pfmc0P21JW<2
08AXLA00oooo000>0?ooobP0Pfmc0P29K74208=ZMP80QgQc0P1mLWDE08=_L`80P75d0P27Ng0207eb
M@80Pfmc0P21JW<208I]L@80PFYc0P26KG4608=_L`80P75d0P20M78208MkL080OG9e1023Kg<2081a
M080RFm^0P29Ig@208=ZMP80PFYc0P2ALfl207Y_NP80Pg9a2023Kg<208U/L@80PfYf0P20LG@2081d
LP80Pg9a0P21JW<208aZK`80Q7Eh0P1mMG<208eeL080OFei0P29K74208=ZMP80PFYc0P2ALfl207]X
N080TG=_0P1mKGT408=_L`80PFYc0P26KG4208U/L@80PfYf2023Kg<2081aM080Qg]`0P21JW<208AS
M@<0QVea0P23Kg<208U/L@80PFEf0P26KG4208=_L`80RFaa0P23JWH208eeL080OFei0P23Kg<208U/
L@80P6ah0P23LW4408=_L`80QgQc0P1mLWD208U/L@80PfYf0P23Kg<208U/L@80PfYf3023Kg<2085Z
L`80QVea0P24NW@207YgM100oooo000>0?ooobP0Pfmc0P29K74208=ZMP80QgQc0P1mLWDE08=_L`80
P75d0P27Ng0207ebM@80Pfmc0P21JW<208I]L@80PFYc0P26KG4608=_L`80P75d0P20M78208MkL080
OG9e1023Kg<2081aM080RFm^0P29Ig@208=ZMP80PFYc0P2ALfl207Y_NP80Pg9a2023Kg<208U/L@80
PfYf0P20LG@2081dLP80Pg9a0P21JW<208aZK`80Q7Eh0P1mMG<208eeL080OFei0P29K74208=ZMP80
PFYc0P2ALfl207]XN080TG=_0P1mKGT408=_L`80PFYc0P26KG4208U/L@80PfYf2023Kg<2081aM080
Qg]`0P21JW<208ASM@<0QVea0P23Kg<208U/L@80PFEf0P26KG4208=_L`80RFaa0P23JWH208eeL080
OFei0P23Kg<208U/L@80P6ah0P23LW4408=_L`80QgQc0P1mLWD208U/L@80PfYf0P23Kg<208U/L@80
PfYf3023Kg<2085ZL`80QVea0P24NW@207YgM100oooo000>0?ooob`0Pfmc0P29K742085UMP80QVea
3`23Kg<2085ZL`80RgIa0P1mLWD208U/L@80PFEf0P26KG42081aM080PFea0P21JW<208I`K`@0Pfmc
0P27N7<2089kM@80OG9e0P29K74208=ZMP80PFYc0P26KG4608=_L`80PFYc0P23Kg<208U_KP80Qg=f
0P1mLWD2085ZL`80RgIa0P1mLWD808=_L`80QgQc0P1mLWD208AjM080OGEc0P26Ig4208]aM@80Pfmc
0P21IGH208I]L@80PFYc0P23Kg<208U_KP80Q7Eh0P23LW4208=ZMP80PFYc0P26KG42081aM080Qg]`
0P1kKGD208]fL@80OG9e0P21JW<208I]L@80PFYc0P2;MW4208=_L`80Q7Eh0P1jMg@308=bL@80Pfmc
0P21JW<208=_L`80Pg9a1P23Kg<208U/L@80PfYf3023Kg<208U/L@80PfYf0P21JW<208I]LA80Pfmc
0P20LG@208=bL@80RFaa0P23JWH@0?ooo`003P3oool/08=_L`80RFaa0P21IGH208I]L@l0Pfmc0P21
JW<208]fL@80OG9e0P29K742085UMP80QVea0P20LG@2085]L@80PFYc0P26L6l408=_L`80QgQc0P22
NgD207ebM@80RFaa0P23JWH2085ZL`80QVea1P23Kg<2085ZL`80Pfmc0P29Kfh208McMP80OG9e0P21
JW<208]fL@80OG9e2023Kg<208MhL`80OG9e0P24NW@207eeL`80QVMa0P2;LGD208=_L`80PFEf0P26
KG42085ZL`80Pfmc0P29Kfh208AeN080Pg9a0P23JWH2085ZL`80QVea0P20LG@208MkL080Nfee0P2;
MW4207ebM@80PFYc0P26KG42085ZL`80RgIa0P23Kg<208AeN080NWMd0`23LW4208=_L`80PFYc0P23
Kg<208=bL@H0Pfmc0P29K74208=ZMP`0Pfmc0P29K74208=ZMP80PFYc0P26KG4B08=_L`80P75d0P23
LW4208U/L@80PfYf403oool000h0oooo;P23Kg<2081aM080Pg9a3`23Kg<2081aM080RFm^0P23JWH2
08=_L`80Q7Yd0P1mMG<208MhL`80NWAf0P1mKg8208]iK`80PW]e0P1mLWD208IWL@80TFic0P1mKGT4
08=_L`80P75d0P23LW4608=_L`80Q7Yd0P22OW<207ebM@80RFaa0P23JWH2081aM080SGQ^0P1mKGT8
08=_L`80RFaa0P27LgH208=_L`80PfYf0P20LG@208U_KP80PfYf0P24NW@2089nL`80OWef0P22OW<2
07ebM@80RFaa0P23JWH208=_L`80OFad0P26L6l208MhL`80Pfmc0P20K7P208U_KP80Qg=f0P1nOGH2
089nL`80OWef0P23LW4208=ZMP80RFaa0P23JWH508=_L`80Q7Yd0P22OW<207ebM@H0Pfmc0P21JW<2
08I]L@X0Pfmc0P27N7<207ebM@80Pfmc0P20LG@208=bL@80QgQc0P1mLWD608=_L`80QgQc0P1mLWD2
08MhL`80OG9e0P23Kg<208MhL`80OG9e0P23Kg<@0?ooo`003P3oool^08=_L`80P75d0P23LW4?08=_
L`80P75d0P29Kfh208=ZMP80Pfmc0P24NW@207eeL`80QgQc0P1jM7H207e_LP80RgU_0P22NgD207eb
M@80QVMa0P2AKW<207e]N@@0Pfmc0P20LG@208=bL@H0Pfmc0P24NW@2089nL`80OG9e0P29K74208=Z
MP80P75d0P2=N6h207e]N@P0Pfmc0P29K74208McMP80Pfmc0P23JWH2081aM080RFm^0P23JWH208Aj
M080PWic0P1nOGH2089nL`80OG9e0P29K74208=ZMP80Pfmc0P1mK7@208I`K`80QgQc0P23Kg<2081/
N080RFm^0P27LgH207imMP80PWic0P1nOGH208=bL@80PfYf0P29K74208=ZMPD0Pfmc0P24NW@2089n
L`80OG9e1P23Kg<2085ZL`80QVea2P23Kg<208MhL`80OG9e0P23Kg<2081aM080Pg9a0P27N7<207eb
M@H0Pfmc0P27N7<207ebM@80QgQc0P1mLWD208=_L`80QgQc0P1mLWD208=_La00oooo000>0?ooob@0
Pfmc0P27N7<207ebM@80QgQc0P1mLWD208=_L`80PFYc0P26KG42085ZL`80QVea2023Kg<308MhL`80
OG9e1P23Kg<208U/L@80PfYf0P26Ig4208IXM@80OFad0P2<KFd208IRM080QVQe0P20LG@208U_KP80
PfYf1P23Kg<2085ZL`80QVea1023Kg<208U/L@80RFMd0P23JWH208MhL`80OG9e0P23Kg<208U/L@80
PfYf0P27N7<207]]M@80QVea0P27N7<2089kM@80Pfmc0P23JWH808=_L`80RFaa1P29Ig@208=ZMP80
QgQc0P1mLWD208=_L`80P75d0P23LW4208U/L@80PFEf0P26KG4208=_L`80RFaa1P29Ig@208McMP80
OG9e0P27N7<207ebM@<0Pfmc0P21JW<208aZK`80SG1d0P1mKGT408=_L`80QgQc0P1jM7H208=bL@X0
Pfmc0P29K742085UMP80QVea0P21JW<208I]L@80RFaa0P23JWH608=_L`80RFaa0P23JWH208U/L@80
PfYf0P23Kg<208U/L@80PfYf0P23Kg<@0?ooo`003P3ooolT08=_L`80QgQc0P1mLWD208MhL`80OG9e
0P23Kg<2085ZL`80QVea0P21JW<208I]L@P0Pfmc0`27N7<207ebM@H0Pfmc0P29K74208=ZMP80QVMa
0P26J7D207e/M080S6e]0P26HW@208IXM@80P75d0P29Kfh208=ZMPH0Pfmc0P21JW<208I]L@@0Pfmc
0P29K74208UWM080PfYf0P27N7<207ebM@80Pfmc0P29K74208=ZMP80QgQc0P1kKGD208I]L@80QgQc
0P22NgD208=_L`80PfYf2023Kg<208U/L@H0RFMd0P23JWH208MhL`80OG9e0P23Kg<2081aM080Pg9a
0P29K742085UMP80QVea0P23Kg<208U/L@H0RFMd0P27LgH207ebM@80QgQc0P1mLWD308=_L`80PFYc
0P2<JVl208e`M080OFei1023Kg<208MhL`80NWAf0P23LW4:08=_L`80RFaa0P21IGH208I]L@80PFYc
0P26KG4208U/L@80PfYf1P23Kg<208U/L@80PfYf0P29K74208=ZMP80Pfmc0P29K74208=ZMP80Pfmc
403oool000h0oooo9023Kg<208eeL080OFei0P29K74208McMP80OG9e0P20LG@208=bL@80P75d0P23
LW4808=_L`<0RFaa0P23JWH608=_L`80PFYc0P26KG42081aM080Pg9a0P20LG@208=bL@80P75d0P27
Ng0207ebM@80QgQc0P1mLWD608=_L`80P75d0P23LW4808=_L`@0QgQc0P1mKGT408=_L`80PFYc0P2<
JVl2081/N080Qg]`0P27N7<408=ZMQ80Pfmc1027N7<2089fN@80OG9e1P23Kg<2081aM080Pg9a2P23
Kg<208eeL080PWIi0P27N7<207e]N@<0Pfmc0P20LG@208=bL@80RFaa0P23JWH408=_L`80RFaa0P23
JWH:08=_L`80QgQc0P1mLWD207e/M080QW1_0P1mK7@208I`K`80Pfmc0P27N7<207ebM@80Pfmc0P27
N7<207]]M@80QVea3023Kg<@0?ooo`003P3ooolT08=_L`80SGE`0P1mKGT208U/L@80Qg=f0P1mLWD2
081aM080Pg9a0P20LG@208=bL@P0Pfmc0`29K74208=ZMPH0Pfmc0P21JW<208I]L@80P75d0P23LW42
081aM080Pg9a0P20LG@208MkL080OG9e0P27N7<207ebM@H0Pfmc0P20LG@208=bL@P0Pfmc1027N7<2
07e]N@@0Pfmc0P21JW<208aZK`80P6ah0P27Ng0208MhL`@0PfYf4P23Kg<408MhL`80PWIi0P1mLWD6
08=_L`80P75d0P23LW4:08=_L`80SGE`0P22MWT208MhL`80OFei0`23Kg<2081aM080Pg9a0P29K742
08=ZMP@0Pfmc0P29K74208=ZMPX0Pfmc0P27N7<207ebM@80OFad0P26L6l207e/M080QW1_0P23Kg<2
08MhL`80OG9e0P23Kg<208MhL`80Nfee0P26KG4<08=_La00oooo003o0?ooob40oooo003o0?ooob40
oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40
oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40
oooo001F0?ooo`900000J@3oool2@00005d0oooo001H0?ooo`03@000003oool0oooo06P0oooo00=0
00000?ooo`3oool0FP3oool004X0oooo0d0000030?ooo`=000000`3oool3@00000D0oooo00A00000
0?ooo`3oool0oooo0T0000060?ooo`03@000003oool0oooo00<0oooo0T0000030?ooo`90000000<0
oooo@000040000000P3oool00d000000oooo0?ooo`02@00000<0oooo0T0000020?ooo`=000000`3o
ool3@0000080oooo0T0000030?ooo`9000000`3oool3@0000140oooo0d0000001`3ooom000000?oo
od000000oooo@000003oool0140000020?ooo`=000000P3oool2@0000080oooo0T00001D0?ooo`00
B`3oool00d000000oooo0?ooo`030?ooo`05@000003oool0oooo0?oood0000000P3oool00d000000
oooo0?ooo`070?ooo`03@000003ooom0000000X0oooo00=000000?ooo`3oool00P3oool01T000000
oooo0?oood000000oooo@0000080oooo00=000000?ooo`3oool00T0000020?ooo`04@000003oool0
oooo@0000080oooo00E000000?ooo`3oool0oooo@00000020?ooo`03@000003ooom000000080oooo
00=000000?oood000000103oool014000000oooo0?oood00000B0?ooo`09@000003oool0oooo@000
003ooom000000?oood000000oooo00=000000P3oool01T000000oooo0?oood000000oooo@00000H0
oooo00=000000?ooo`3oool0D@3oool004/0oooo00=000000?ooo`3oool00`3oool01D000000oooo
0?ooo`3ooom000000080oooo00=000000?ooo`3oool01`3oool00d000000oooo@000000:0?ooo`03
@000003oool0oooo0080oooo00I000000?ooo`3ooom000000?oood0000020?ooo`03@000003ooom0
00000080oooo00=000000?oood0000000P3oool014000000oooo0?oood0000030?ooo`06@000003o
ool0oooo@000003ooom00000103oool3@0000080oooo00A000000?ooo`3ooom000004P3oool02400
0000oooo0?oood000000oooo@000003ooom000000`3oool014000000oooo0?oood0000020?ooo`03
@000003ooom00000009000000`3oool00d000000oooo0?ooo`1B0?ooo`00B`3oool2@00000<0oooo
0T0000040?ooo`=000002@3oool2@00000/0oooo00=000000?ooo`3oool00`3oool2@00000030?oo
od00001000000090000000<0oooo@000040000000P3oool00d000000oooo0?ooo`02@00000<0oooo
00=000000?ooo`3oool00T0000000`3ooom00000@0000004@0000080oooo0d0000030?ooo`=00000
4@3oool2@0000080oooo0T0000000`3ooom000000?ooo`020?ooo`9000000`3oool3@00000040?oo
od0000100000@00000<0oooo0T00001C0?ooo`00B`3oool014000000oooo0?oood00000C0?ooo`03
@000003oool0oooo00X0oooo00=000000?oood0000005`3oool00d000000oooo0?ooo`060?ooo`03
@000003oool0oooo00X0oooo00=000000?ooo`3oool0OP3oool004X0oooo1D0000020?ooo`03@000
003oool0oooo00l0oooo0T00000:0?ooo`=000005P3oool2@00001@0oooo0T00000B0?ooo`03@000
003oool0oooo06/0oooo003o0?ooob40oooo003o0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-7.15527, -3.20068, 0.495855, 
  0.495855}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .65625 
%%ImageSize: 450 300 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.31746 0.015625 0.31746 [
[.5 .66875 -17 0 ]
[.5 .66875 17 12.5625 ]
[ 0 0 0 0 ]
[ 1 .65625 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .66875 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Angle) show
93.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
0 0 m
1 0 L
1 .65625 L
0 .65625 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.015625 0.321429 0.313244 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00751202 0.0192308 0.00751202 [
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(180) show
81.000000 12.812500 moveto
(deg) show
99.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(.) show
105.000000 12.812500 moveto
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
128 string
128 128 8 [128 0 0 128 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
81817F85868182807E877F867272727277737373736C837A
486D746E6F6A6F70696F706F706B6A6F6E72736F706F6F6F
71676F6F6E7474747474747471756F6F70756F6F6F6F706F
6F6F6F6F706E6F706F6F706B77847A526B6A6F706B6B6A6E
6E6E6E6E6D73736F7078737777787278736F6F69686B6B6B
62797B5E6D7B8186
81827E7C80858C887B8686958574736F73737372725F6D91
5C6E746F726A666B666A6F6F75756C6B6F706F6F6F69646A
766A696F6A696C6F6C6A6E726A74756D6A6F6F71726F706F
6F706F6F716E696A6F6F6F616181904B536F6F706B6B6767
6B7071716E6F727069716D6E6E777374746F76756F6B6F85
83707361637B7D81
7F7D7D81817B7B81817B848C9C87727272717072706F6BA6
583D6F716B68676F736F6F706F706F64667573706C6F6A65
62645F626B6F6C70736F6A6F6F696F727879787276757070
6F6F6F6F6F71756F6F706F70615B9BB95A45666B6F736F6B
6A6A656A6F767276727272767B76777274706F7072767A6B
718D776A5F718386
8383848686858A85838A817C7F95938975716F6C6F6C6169
BA6D5F6E73736B666666696F6F70706D666C6F70706F7068
6A6D6B6361696E6C6F6F6F6F6F6E71767874767A78797877
79756F707171707071706F6F706B5C76BF63537570717578
737576706E6F6F716F73777775737675707171747E85757D
6A6A806E6A7A737C
8082817D87827E847F858A8A868788908E7878757273746F
8A82627173736B6B6F7066696E6F75746F6F6B676C6B7578
7575746D67656A686162676F70706C666E6F6A6D7B747171
707772727673717276767372736F6B5C769557627275756F
6F6F71767376747772737377767A73777774718B81888880
8E727A6A62858C80
8180827F7D7F8187807B7E7C83858886978F797875767164
6EA280727478736F666F736E706B666A6A63676C6A696F6F
6F7074796F665F6A6B6D6B696F6F6F6F6A7176706C727174
71757874747676706F70716D7072736B5C998D605F6F7376
737372737675747474736E727676776F6869666E80746261
6E728276767E8483
81838C898683847B858584858581838589969C887B7C7C7B
6D788D7470797877736A6765646A675B5E67626567656F73
757675777C7870676F6669626564676E6F6D6C6D6F6B6C6C
6C6B6C6D726F6D706C6F6F6F6F6B6E6F6A5C92A17C6A6C6C
6E6E71707472727475787676766F6963565F6F7973856977
7163726D7B818388
817C7D7E85818985857B817A7B858281858587938A80807F
7E6E868D574B72716C6B6B6B6B635F67676767646761696C
6F727271757072656462676868665E5F616562696A656666
696A696A66686D6E6A656565656765696C5D5877836D6D6F
706C6D6D7274717777786F6F6A6A58576161616A4F5C6666
6B7370627A817A81
818485838985857C83848888837A8182818585858F8F928E
92968794C479656E746F6B6B68706E686E6F74797568626A
6E72727077787A716D74726970706F6B635F5A565757595A
555752565A5756565B5B5B6167676A656764594D63776547
455C65666A6C6F6D6E76776F564562666756576F796A6479
766E76737984817F
8A8287817F858A8782807A7F81837F857A7E867F88818681
7F82828185AA81565B7764626F6B6B605E5E61666C6C6569
6B707474726F70746C676F6F70707479757A7A7679707071
6E7170716D71747475747875706C75757473707463688498
7D372B5B5D6869695D3C2C2D495A6A726C6A646672786759
7B6E5F7375818888
797E7F867D7C7A8082888581878A82848581888186818582
7E8183867D84876A465860626A6A70716E65676A6C6C6668
6F6A6C6C72757577706C6F6F736F6F6F736C696C75787574
6E6F6D7478706D6C6C6F6F6F786F6C6B716B7475746A676C
77BB81754C3C43423D4F524F5752586262708069635E6E75
6F826E727C797983
8C867C8585868A847E7C878681818385807E858183858A89
85817A7F7F808A8760555E4D526B686769666A66666F6A68
6E6F6F6C6F6F6E737370676B6F6F6F6F6F73766964676B74
756E6A6764686F736E676F6F6F6C6C6B6F6A6A686F746E6B
63646487998C453346484F565152435265586951616F5667
766B957B8481827F
7B858A81817F81878A8A818385887D85898985877D818582
838184847F828A747D5655542A3465686C68686B67666769
6F6F6E6E6E736B6F6F73736F6F6F6F706F6F6F736C6C6B6C
67716E686C6C67666C6A6F706F6D6C6F71676D6B6F6B666B
6A634F47372C4F5346495253535663645F53745F5C6E646E
77698082807F8A82
8A827D82837F867F807E867F8183867F8585818285858183
87807E8587818D8C997048544A20286465635F60696D6A69
6F6F6F6F6C706F6F6F6F6C6767676A6C6B6F6F706C6C676C
6A656A6D6C6C6C6C6B676A6A666F6B6F706A6A6767686663
5B5B52423F4B535A5E58454E565E5F636A5E5E5A5A6E666E
7076837E887D7E80
7B808786817E8A85887F887D84818585817C82817F808382
8387887E818080767E6D484B453B101E57636A6B67686665
6A6F6F6F6B6B6F6F6F6F7373706F6C6C676B6F73736D6568
6D6D6D69686A6768686767716F70666973716C6A66675F62
5A5A4F454D564B4C595E564C5B5653594F5D6F7373736F60
777D82807C7E8189
827F7B7F837F807A807E898A8185817C858683887D86817F
8581838685808871818A644F4E3C2D0E20635F63626D676A
6F6F6F6F736C676B6F6C67676C65676A6F6F6F6C676F6E67
6665666F6C6A6A65636B656C676C6D6766605857524E5253
4F342B40575D49424E65726C535048565C635D6A7D6F7875
6F79768082837F86
7E8388828581828288827E818781878685888186837C8587
7D7F7B8182838B7E8572634B443A342A0A1962665E676A65
6B6C6767676F70676B706C6F706F6A666567666D70696567
66676262656964685D5E60686463625F676A615F5F564B3C
2F3643434A56655A5F585B56675E535A5B62616B556E757B
7D79767D84837F89
837B818A8586838985857F7F857D807B7D7F7F898A877E85
86827F82817F77787069524E44383834260504615C636466
656A6C6C6C6B706F6C6C6C676A6A6F6B656668646C6E6D6A
6969665F5C65666469696565685A67605E61635B54433A3A
42425458534F56565647444A4A5F695F5F666B6B6F7D8879
778A8883898A8585
7E858281858C817D818A887D7F7F88898A8A827D7D828281
8884848181888584727A554F493A34312121050963656B67
6A6A6C6C6C676F6F706C6C6C6D6C6C6D6B6C6C6767676666
67666866645F625D58625C64665F5D625B585B4B36392C34
4A4F515252555155646767646C5F62646D6A6A6B6F69707D
7F7E858281827D7F
8C85847E82818A89827E808188857A7B7E8189878185857B
80858683817F8083727155464142392A2118241A635F6A6A
6B696D706F7067676C6C69686C6A696B6967676463626767
676464625E5A5C5F5F686B53565354555447444B3A30463D
383E494F4C4C5B56616A635A6A6D616B6A6A6A7276767D88
878A828281858585
8582857C817D7F81838583838588888583827E8485818185
898285878283837D6461554F40423C3729262A1027666A6F
6F6A6970676C6C6C6C6A6E6A6666686D68696B676A65616A
6A6864626057515E6B63544F565655554E443F36564D5054
5F5B595956535253484E5B5B5054616A6A6972747D877C86
817A818982848182
8589868485827E868586858585898182818580807A85867D
81857D837F7D7C7B72594F4A4C4437302D2E2E1D14626B6A
706A666966696966696D6A686B69656A6B66646D6269645C
5F615E5C535B5B606A5A565B5B57433A373E4B41374A4B43
434F55564F434A64605D65655F6F6A6A6A6E6A727D7E7B81
8685858585838589
858185818589898585878185858588817F8A8685827E8885
8180838A88837C72635F46443938332E39392A160A676765
6C6C6A6C67686C6765656769686B6A646A6A675F625B6462
6263605B574C5A5B4D4F4948484645373E434945433C3B42
444F565452604F5B505B435A5E535E6B6B728C837D808185
89818581827D7F85
858A85867F85828182858281858589877E7E828288858681
86858585868375755B5B524947332D3137322929136C6B70
66686A6C6E69696A6A646369635E5F6162645F6563645F5C
5C57595050564E4E524F4F4C493C38453F4A595249415057
4B4A4D5766665A59515656526578707076797180807B7A7B
81858287898A8585
8582818A858282818982858585858285868285898281867E
847E7E7D81837F775D544A4441423B413A23211E0D6B6263
656A6D665C6367615F645D5D646260625B61605C5D5B605F
5B5A56594F5452463F4143423B454743413C5356504F454A
4D46465254686862566160565869687A7D87837B817D8187
8585867D7D7D7D81
858985828189868185898281858589858989858586818682
85857F848A8875645F5B4E45423639312C2123200D6D6A73
6A6666736B6366626262605D5E5F605B605E66625C585B5B
5C5B5B52564F4A44463E3E323C3A32333E4B535663554D46
3D51544F4B5E5B5A606368626169707A7972767B87848481
8281898A86848582
85858589827E85827D7F8985858281858585858285858680
7B8183827D8879615250423B363736382E2A2A2713646267
676B5F636B5F64645E5D605958595C595C5C5C5B5A5B565A
5A5350534F524A433C3D3944413739383D3D4B4F4C56544E
463B3F5B5754616F6255565A616F6F767688867D7A858681
8985858586858586
85827E81868281898A827D7F85868185827E7D7F7F828288
898981847F75786257494C483D3C3C3C241C1D25166B5F64
5F67685E64605D5F5C5C5C5D5C5350505156575C59565252
4F534F51413B3E3B3D41463C393F414443444B63676F634A
3D4449474E6160605655515B6E6E6A7D79747D8586818985
8582818589817F86
7E85898282817C7B7D858A85818382818685868585898985
82817D85817A6B5B564C3F383E3D33281F1B1F21136B626C
686464605A5F5C5F5F58595A5B5F5B565252545B5656564F
4C4B49484A3D343E3D3D412D22273548514B4846564F666E
524F4C564B4D625756565652697C7F768279827F847A7F85
8285858582878589
8985858986868A8A898585858A818181857F87818281827D
818784807A75665C49444337373536292628262817635E5D
5F635E6364605C585C5752514C49504D50564C4C56564F4F
4F4F4A4A4D333A3E3E33272B1E31493F4143414B5A645C61
5A5757515C5356564F4C5F6576707A737985827F89848185
89817F8285828185
85858281867E7D7D7E818281858A8985867C817D83858686
89818480786C595049453F413A342824232425241D63636B
6C67686468656B676465584C524C484E484852504C484E49
443F44434533303F3327262C3D343D54464D41415160555B
534C534D5C61605A6164605D748174807D7F8A8589868185
858A858985868182
7E8189807D8188858982828185817F82878681837F85867E
7D817F7E7F6E5D5346463D463C351D24282522302C6F7D75
7D7C7F7571716C6B6A6E716D534C49494A4741414A4C474B
47433E40393234332F22233831313E4B4A3D4644535C7070
66584C3D4061605162616A7C7B87837B857D818281898585
8281858585898281
89827E888C8586818589898585888189828689857E828585
818284796B5F5751483938313E2E24252C27233F5372777B
737270797A78756E6D6A686871665545444B4D4E41424B49
49453B394540463327242B35393237444642424347516263
675A4F534A54605F626457617D70737B7F8681857D7D7D7E
858582818585898A
7E85857F827D83817F85858582817F828281828581867D80
818182876E5B534B4149403A3823252B27255374747C747A
78797B7477727777726E6C6A68696F6B504242414D474546
3F3D35223D3D4237221817265238384B4D514E47575A6975
734C4E514C4E526158666E76737A7F8881898185898A8986
7E81898585828185
89828685898A85867D7D7F8589867D85867E828281898A8A
867C6E7267594D4236353C3A2C232A2D286F9C7771737B76
7D76776E7176756F7676776A67686A656B50403E3E413E40
413B302A3638325A30331C173739323D4A42574F4A4E586A
6B6E4A4A4F585B61626C5E747B797E81817F878185827E85
867E818585898585
85898585817F858A898A85858182817F8986858985858582
82817B6B63504F49423B3737282525244B4472726E707378
77787D7D786E7270706B6870706868696565644E3A403E3D
3B33332C2B5D3D512F152A3B3E6A554B574145535055505E
75664C47474B586F6E5B5273888384818781868182828585
8989828185858281
7B7F82818A85817F827E81828482837F82827D7F85807E85
817C7A6960544C42353130332122273A566C6F7974747371
6F716B6F7871726F6F75796D686B6867686B5B65473B3F38
3A332D1F1E553A415E5B2B2C2935423F47594B51494E5652
74704E4757564E505E6A7276777C7F7B8582858586828182
7E81867E81828585
848186818585877E858985898682868285898A85858C827F
7A7872695646453F3C373623262D396E7071717474716B70
666D6D666D666164696A666C68636465676864616C493138
31312628232B64365D39533E43354F41424C3E39574A604F
4F8071434350535469757C7C787F82818282818285898285
8681898982858585
8985868185858685827E7E7E85898285827D7C7D7E818988
7576665F4B483A3737372123231D577074746D6A6C6F6863
5C5857555559585A555A5D67676D6B676363626163715C3C
35302E272623486640755A5A313046564B3D4E435455555A
69706C62605752505F717A82837F827E898681857D81867E
8585858589858582
858285858582858589898685858589858684848589827E84
80746F624F46473533322924307F71767274736F6D6A6461
5F57524F4F524F5559595A5B5E6768696363625F57596046
2F2C271B1E2C3B4936385C586C41334A524E4D4F485A5B5B
4F5D8267595D625B605D8379828088828189818589858685
8582818585858589
858681858285858585858681858585858986817C7F868079
7273684D483B3D3B2C242627291D6D6C6A6C6F6F694C3537
43495050505045353835405E5E62676C68676460605B5665
3F25221A1D24295B6C40666167735C404A59413F3D564B57
635B7569615D55626F64737A7D797A83817D878281858982
8189828185828185
85868182858281858585868185827D7F8586868A81838483
7D665D50403E35303130272C73746F6F6F717359455A6074
8E6E5D677A68605C58523B405A5E6368686366675F5B5A54
663F1F1C1623151A774838534C6C655956424C514A4B5B4F
5A616F69424D555067887F8080808A818282818681827E85
8582858582828182
7E85828582858281827E85827E82847E7E817F85867F7F6D
5C544D4B373131391F2025433E767673706B6E6551545132
36444A3D2D3834394C574E353A6064676C6D68635F605D5D
5B60372914153B2A405E3A69504E897142564F463D4A5554
5357667061595353557D7D7F7E7A858A8989858982858985
8589858589898589
89858985867E8582828281868282858986848182847E8672
665A4B3A3533321F2C24355974736F6F70593F482A222A37
36302F352B24222A181F23241829516767636368635B6060
5A524D18121E24223466403156414F93825E48504E454E42
4E5E6A7E6F63665D58787B7F867C7E858281828189858585
8585858281828185
7E7E7E8189867E85868582858685827E82827E81817D8074
62493E3137302E332F326573706F7875708489836B5A4D47
4D4E58555057524E596B8C958E736267646664646A605C5B
615B5535150D182A2E3E7838504942618C5B514F4E4A4F4F
47575F7168546366787A7E787A857E7E8585898582818582
8185828585868185
89868281828589858681868189858989858386817E827B6B
58424240302F2A2B2C321E6F72726D72737A7897ADB4B0A2
B2AA95ADB8B1A8A0967B76726D6D68686B6865616365605B
5B5D5A48270D272D28263F4733462A49608162574C3D475D
5050526A72515049767C7D7E7D8989868185858589858285
8281898582858585
7E8589858985828189858681827E8185877D81857F6E6662
4F3F2F2F3022292D2B5D62767272767274726E7473757C7D
73786F6A66675F6468676B6B7370686A6B68676563606055
5456544720191D3248484B502B48534662837C5E575A473C
3B4A526A7063644B7D7976817F8585868185827E7E818985
8985858589858582
8281827E7E7E85817F8589858685828186848181898C6049
3F40362E252F2D2D2F2A72706F7571737078727470747074
6F746F6E6E706A6F6C686B6C686F716565656768635C6166
5B565B503C2A0F1E233027454537413A52645F62594E4E4D
4C4A4F5B72545B4871837572828185868182858989858281
8585827E81858589
898285868285858A828185858985898589868481706C674F
462F37282D22272F260E70706F7277777172747474727274
716E6866686460656B656D6B72627179746B656665635B5B
584E50533B1B1D22363E444A4B30303A3E457A775B4D4844
5E5154576C5B616C727E8A77858585898589828185858681
8281898985858585
8589858989858585898281858585827E7E8589827D5E5C4A
3C432E312D322D244D3F6E70707474747A78727274756F6A
685B5A53605F5A5C6466676771776F6A6B6968636360605C
62615249452F2823292D3634423A36243E6D55586555583D
4A4E59577169556F67848589858585858281898585858982
8281858281858585
7E818585858582818282818582818989857F82898461453F
302B302521292D2539707071707474747074747174747569
676A64575C5B565C5E61636865676E767071756B6863605B
5B545353442B0B111E2F333536493C3227454F6C74525C51
4A474A516E805C7C64686985858585858681858585858589
8985858681858585
898585858585898285898582858585858A85898177584032
3125292E302C21200C6E6D6D6E71737B78747671735F3F51
7C73704229374D444055626A766F70707769686866656560
5B615648473717171923283533423442233A574A695E4E41
38454F576A7D6F606F728585858585858985858585858585
8585858985858281
7E7E81827E81858985827E85828185858585827F6B4B4242
333225282C25213222727278777B6D6F7570727574959B72
737A778F8A7A7080584B5966706F6F6F6A6F787569686360
575656564C46110F151E2A332D393B2F1B26524F5B604A4E
3D4D4B4A63596D4385858281858585858281858585828185
858585827E818985
898985898985828185868281898585817F8589856E433823
282F2E2D2F211D363B70706E6F7A7E777D7776716F75767C
7C7A7C766A666167716560676F71726F786A626A6D696864
5A52544C47421215112230382E2D39342A16525B5F654A53
49464C545F6D787466858681858585858985828185898585
8585858986818585
85858582818285858285868185817F877E8182835F3D363C
302C31312B1F22417172777A78777676777A756F6D80777B
7C7772756B626263636564676F707371727776706B6A6668
685E564F473B2907131F18263C36312B422D474F53715254
4B4340465F676E8581858985858585827E81898585858585
8585858589858585
85858589858985828281867E818A828589858564463E2723
282B2F2D171C15007170706F7776777778777E7D706D7070
767A756A5F5C5F5F62666E70717078736F706F77706A6568
67645A4F4B493F0F0F19382E3735362F2A30414659756040
4543555C6962506A8281827E7E8185898681858585858585
8585828185858585
7E7E818585828189898589898281868185858674472F2930
34302D111A18230E71787D75757675757575767B75736D70
726D6A6D68626368686F6F6F6F6E707572726F6F716E6A66
6364665B4D443B111A191E282C2D3F37353A495054686E46
423F40405C8A828189858989898585858985858585828185
8585867E81858585
898985858285858585858582858285827E7E847C4232322F
2E2C2F25161B595F7171777676767A80807C76777E79736E
7E7871656863676C6B6A72747171737C7372716F71686B67
655B605A4C4245220A1A182837302E3F37334B5E595E6551
423F45496D726A8585858585858585858585858585898585
8585898985858281
7E7E7E8189858585858582827E8585868285715B3E2E3032
322E1B16115D7E72757A7C767A7C707070767575757A7D73
777B7A7668686767676A6D767D786F75777C77747878716E
6B675F675C463F3B2824312A343A38373335465F59567345
3A314B3E61877E8585858585858585828185827E81858281
8281858585858985
82858681858585858582858986818589898553373223292E
2B2F22272A166B747671767A7A7C76777B7C767676767772
777E7B7368636B6E6B6870727379777D717173777472736C
6968635B5B4E3D342B25222E2D3C3B39464C495B544F614A
373452525E79858585858585858585898585898985858982
8585858281858585
8281898585858585858985858681858582817945322A2D38
30292B1B4542757275767A7A7677777672777A807C757B77
76707173685E626A6F716F6E737176707174797473707574
6C63675F5D4D3F37241E23262C333C3E33445A5B5B586F59
4F413F4B607E858585858585858585858585828182818589
8585858985858585
89858281828185858281858589858585898270473F33252D
3222273B5172747276767070767577767272707076777770
6E7C7D7D6D655F6765686A6F736F727979736F6D6F706F6F
746C645F62594C3B322624222C3237322C31625555565A4C
3D454447547F858585858585858585858585898589858281
8585858585858585
7E81898586818281868185858585858281624933363A3930
25252663747473777676767A7C76767470686B6F73777175
7376767F71645E5B625F5F6C6E7273736E706F6E706F7170
6B6C69675C594B3F331F212526383A393C2E535B5A403F45
2D4B5B535485858585858585858585858585858582818985
8585858585858585
8985858285858681898585858585858681665F4F3338332E
242B2F1D66706A767A7C767177736E69666D6B6B6A727A72
747776796E625E5E5B6A6A6C736A6865646C6E6C6E706F72
696C6B63655A524035221620292B3C3A37365A52563E215B
3237566B6385858281858585858585858585858586818585
8585858585858585
8585858681858982818585827E7E7E858552354346353C30
1F30746363646F77707676726E6E6C7865565C686A6A6F69
6D7676726B5D5F5D5C5A636C6667625F59565353565C6767
716A6C645A564C483B3515171F2C343F372F594D41412C63
353957636D85858985858585828185858585858589858585
8281858585858585
85858589858585898582818685898985897F373C2F33351B
302A2D58505D71777676736F6049373D59504A5863737670
6F78778171625355646962655D5650423C46534E535B6A64
5C5C63636158533E363130221E252F313C33444F43482D52
34345252718B858585858585898585858585858585858585
8985858585858585
7E818585858281828189858985858585545B42352D2D312B
2C725F6C57596D72767062443B5F753A2437404A3749706E
6B777778766861584730152F4A70572F3039383839405663
6364605F5C5649483F3237211A2533323F40514F463F295E
4B4868617385858585858585858585858585858281858585
8585858585858585
89858585858985898585858281858585745E5348222B342B
150E6E6F675F77746A634D50687C4E3D2F2F364C59465761
6C777274716E564D4076424B934C3E444138474F352F4759
5D62635B60574C43372F1E0C1222372A304146443F4C3244
4254625B8585858585858585858585858281858982818585
8585858585858585
85858585858585858281858985858589DB6E372925282F3C
47286E56575B686F6553471D113E626E1619261E3C3D5669
7077797574746757423B702D1F495215123531231E303B47
4F5A5E584F564D3C36321A1315122331363C3E4D4946394A
2E4A65618585858585858585858585858985858589858585
8585858585858585
8585858585858585898585858585854F336C563D362F3238
4B3C625B5A616F6B62593440281410063E3446414F65686B
70737875726D756360453651352E06281825133933364546
4552585B4D473B3739302E1B23281F292E433E373E4D425D
3D5063798585858585858585858585858585858585858585
8281858585858585
8585858582818585828185858585856C3062442F3A372D2A
3746655B5A5F6B777E828959413C3F3A323957687373746E
77777875747979746B6A5E38366A6C5036262D3D60595359
5B5B545659493F3832363021201F1E2332474A403E544F5B
4154547E8585858585858585858585858585858585858585
8985858585858585
858585858985858589858585828185D76E38302A242A2537
4144545350597278818C96A7ACABA4A5AC99745C5C617678
72757A7D787371625C5C66887867626F7F8D907D72797A6D
635F5D505054433B3725231E202E30252A47493E4353555D
476B7E8B8585858585858585858585858585858585858585
8585858585858281
8585828185828185858585828585899C462A232122362821
2E4252524F5D6B6A737C807F878A754B312A31477377777B
7B7C767A797D7F78573C2A2E38668A908E827A766E6C6863
55474D564945483A343A221C191C16262B31433D3F535967
4B5073858585858585858585858585858585858585858585
8585858585858985
858589858589858585858589858577774D2425232D2A3637
3A3945504A4F7362606E77757049363B3F60917D7A737A7C
757C76787B747F828873412C251D3253637475726C676056
4650504D483F3F3C271F1E201D1630383D41483C384C456E
544E85858585858585858585858585858585858585858585
8585858585858585
85858585858585858585858281896C486B2C32302028302E
322D33464D52755D3D3F433A2D3E5995B8988583837F7A7F
76767575767A777A88A0AC98734B241F1F202C3935353341
5B5358574E433F37491D272E2B1F13263B3F41403D5B473C
526685858585858585858585858585858585828185858585
8585858585858585
858585858585858585858586817E8421352E3939362A2C2C
3339383E4B5A6D9990715B58769FA0837F7F7A7A7A7A7A7B
7C767A807F7D7B7A7A7A818797AAB5A589553E3E43546760
565C5C564E47473D1F34261E100F14233E3440474453484E
507A85858585858585858585858585858585898582818585
8585858585858585
85858585828185858281858985859E5E3F303C4B3E373033
37383F4441576C6F7692A0A48F76747A7A7A7A7A7A7B7B7A
7C7A7A7A76757576757A7A7678757171869BA29688736966
64584F494849464D3A2518101111152F44394A5337505847
4E8585858585858585858585858585858585858589858585
8585858585858585
85858281898585828585858585857F432D383F4A38353934
35343B4441557072737277777A807671757A7A77757A7A7A
7D717476767A7C7778777D777075706E6F6B6968685F5E5F
585B595B4D43453A4636211E19211B1F5C4132563C3C584A
5D8B85858585858585858585858585858585858585858585
8585858585858585
85858985858585898585858585859A583F3F333D423F3932
302F30403946666F726D72787174807C757A7A7F7A7A7A7A
7F807A80807676757370707774746F6F746B6E6A68686463
5F615C4E494945472D212723130E1419534B45573E2F4E45
7A8585858585858585858585858585858585858585858585
8585858585858585
8585858585828185858585858585A06F312E293437323434
36343C4D4F4F6168727473777770747F7A7A7A7772757A7A
7A7A767070767671707474726D6F706B636A6B6C68636460
58505057534541323028281912111E1A55654D5B4E2F5C52
858585858585858585858585858585858585858281858585
8585858585858585
85858585858985858585858585858D5E3C383A3E41423837
323A394A504D616972767777787B7A7772757A7C7A7A7674
7A7A7C767677787E7B787474736F6F71666564686A64625F
655B564C504D453F292E1917171215233C483D5B57454169
858585858585858585858585858585858585858985858585
8585858585858585
8585858585858585858585858585828C35353C3F35373532
403D3C414E505C666F7070737772757F7B71757F76717B77
71707777777777747378747274756F76746E6E6B6663635F
5855554F4D433F3C36251C120B0B2A2F3148495D6D7A5985
858585858585858585858585858585858585858585858585
8585858585858585
8585858585858585858585858585825949543C353C36383D
282F414B4C4F5B696D727777777A7A767A7F7A777B7C7179
7D7775777675767B777B73716F73706A6D6D64646363635F
5E595A504341352C3224130C190E203D393738554C7E7285
858585858585858585858585858585858585858585858585
8585858585858585
85858281828185858585858585857EE96F34322F2F2F332F
403A3C4759595D696F75777676757A7D7577757C71767B77
767677777878767677717677726F6F716770686863636763
635957474645483F262214121714223E42413C595F5F8585
858585858585858585858585858585858585858585858585
8585858585858585
8585898589858585858585858585859C6638322D2F302A31
363F464D525D6069706D6F777672727771797A7F807B7079
7D7877777777787771747474757475776F746C68635F5E63
64585452503D34262016170C11122244393B3F6477678585
858585858585858585858585858585858585858585858585
8585858585858585
8585858585858585858585858585857EBB5936363233362F
2D363C484E5A636A6E77737775797B79807A7A7A767A7D71
797B7676767777777B777871746D6F706F6C686964675E5F
5758594A474C3E2A2119191315172155424242587B858281
858585858585858585858585858585858585858585858585
8585858585858585
85828185858585858585858585858585B170322A2D2F3135
313445515A5D656F6A6D6E74787278727577757677727677
71767678777676777870727573726F706B6F6E6F6863645B
6055504F433A3429211C161D1D1218404F4A586267858985
858585858585858585858585858585858585858585858585
8585858585858585
858985858585858585858585858585858981503935373132
383837435769666A73757777777675797A7B717876757675
777876767778777474747470706F6E6F706A676565636465
5B564D4A413A2F27241E171A110C1A374142536B7E858585
858585858585858585858585858585858585858585858585
8585858585858585
8585858585858585858585858585858585E9BC724B46483A
3337474749556B6F6A6E6F6E72767670717876797D777778
7777757374707074777573716E6F6F68696B6B6668635D5D
58504A483F342C30232119100A22354A484C535682818585
858585858585858585858585858585858585858585858585
8585858585858585
858281858585858585858582818585858582C1DB7041353B
3D36384A5253606F6F6E7577787573767677787277787676
77777B777874747774736A7070706F736965686D63605B55
59544C3731352F21241A1C100B33423E40465F6889858585
858585858585858585858585858585858585858585858585
8585858585858585
85898585858585858585858985858585857E7E94A141372F
343A3E44525A5D64676A6E6E6C7171747777747377777573
726E6F6F747472696A6F6F6F6F706E6D6968686464685B66
594741403C363D261F1D110C4E4B3E3E43646C7A827E8185
858585858585858585858585858585858585858585858585
8585858585858585
8585858585858585858585858585858585858582AE3F294B
3B4247484E5761706E6F69707677786F7274777777777B74
7577796F6E6F70756F6F6F706F6F6A6D6C67636360565453
534C48443B2D2B4A1E101539243745484A57678186898B85
858585858585858585858585858585858585858585858585
8585858585858585
858585858585858585858585858585858585858280723A27
383C4748525A5C5E6A706F6C6C6D76737074707070707375
6E686A6F64676A6E6E6F6E6F706F6D6268646363615E4E4C
45403B333537341E332D342640434F585D5D5E898F7E8585
858585858585858585858585858585858585858585858585
8585858585858585
858585858585858585858585858585858585858284743C2D
302B3640474A5961616A6867736B736E6B6C707477746A71
6D6F6860665F676F6C656464605F6360605F5A5751545050
4B4948352D2B2A2B272240563C3F4D5F5B87857E82818589
8B85858585858585858585858585858585898B8585858585
8585858585858585
858585858585858585858585858585858585857EAF963921
3837364247555C5F5F6069656D6A6A72736D6A6A676E6B6F
6C64636161635F5D5C5F5C5B5A5F615C5E5E59585A4D4A4C
4D423939373440413246414C475853766959818589898B7E
85858585858585858585858281858585857E858585858585
8585858585858585
858585858585858585858585858585858585858597757745
2F4138363C3E4F64675F645F66716F6C6E69656565635B56
595E5D58554E4D51525351554D464E4A4E48484A50504A3D
353B46383E482D3549413840494D4F6284838585857E8585
858585858585858585858589858585858585858585858585
8585858585858585
858585858585858585858585858585858585858585C1A362
3D343E444D423B3B526368736E69656566635B565565665C
5B5A554F4E4B4C514A474640463E4548444A4A4148575458
564C403F3E4A4623233F53554A6563636085858585858582
8185858585858585858585858585858585898B8585858585
8585858585858585
85858585858585858585858585858585858585858585BDDD
8E5036343E393C555C72736E6B6B665E575B5C5F5A525E5D
554B51484D484D3A48454535444540423D414247342C383B
403E474833293D514C4142526B6B596D8585858281858589
85858585858585858585858585828185857E858585858585
8585858585858585
858585858585858281828185858585858585858585858590
7F5257474B716C5D5152515C6661615E5F5D544E5959504F
584F4C4A42474D57534755553B524D514E474B51453A4447
403E473E45413E3B3D4968725F5C7D698585858D8B858585
858585858585858585858585858985858585858585858585
8585858585858585
858582818585858985898585858585858585858585858585
DE72464937313E49445D66605B5C5D5C5353544C474C504C
4D524D3D4832403F4B493C474D4844343E49493942352A24
272F2B2D2C303346586A6E62584D4C858585857E85858585
858585858585858585858585858585858585858585858585
8585858585858585
858589858585858585858585858585858585858585858585
7EF28E554F5561666B6866685E53505954545D545147524D
463C3B444D44243230424B47472E3D442C1A2A3531373D45
473E41373B45656E6169363A436E6B8B8585858585858281
858585858585858585858585858585858585858585858585
8585858585858585
858585858585858585858585858585858585858585858585
857E925D3B2B2F31415B62636A58504C505050474B514448
523E544F3754542D4736323530362D203236353532393630
28303F5A5C674D6A70485447564B7E858585828185828585
858585858585858585858585828185898B85858585858585
8585858585858585
858585858585858585858585858585858585858585858585
8585C657425B5C48414D605E5F4E42484B545145444A4C4B
4A583035472D47402E3B3633372F3137322D222D332E2F32
3C494A42424669412D4661598B777E818582858582858589
8B858585898B8585858585858985857E8585858585858585
8585858585858585
858585858585858585858585858585858585858585858585
85857EFF78243A5F5C4C526D695A4A4C3C4146444149443B
413E403C43422C2A3C37313234342C2A22202625252D3F3E
37405D667C78585E444D3C5E89948C81858985858985857E
858585857E85858585858585858585858585858585858585
8585858585858585
858585858585858585858585858585858585858585858585
85858281EA932420384B4F67695B384B514B5C5C40404E3A
41474639494849261932473C31252E2C27201F1D1C232B4C
645649644D2E2C4557355E547E7E8985858281898B858585
8585858585858582818585858585858585898B8585858585
8585858585858585
858585858582818585858585858585858585858585858585
858589857EC06B302A36414E666547365041343E43313A48
39374B453741495545301F35363A373948443B425054534D
557C6B474A332F415366758585858585898F827A85858585
898B85858585858985898B8585858585857E858585858585
8585858585858585
858585858589858585858585858585858585858585858585
8585858585A2C16F4930252A376A543437504A3A36312B31
383B3B3A3A3D4E4C47404D3A324146423746515A67625D6A
6542514438494F4D41778B89908B828582858F8281898B85
7E85858585858585857E85858585898B8585858585858585
8585858585858585
858585858585858585858585858585858585858585858585
8585898B8585AEA459484A444A417D53373D5247523F3433
3C3F403741434953526B473E3A3A45545C5D5963646C4E2E
382C1F1E464E43509D85857E82908F7E8D858589857E8585
85858585858585858585858585857E858585858585858585
8585858585858585
858585858585858585858585858585858585858585858585
85857C81858281BDB3503A46535258825B433A4742534B37
2A262C393443475C718F9D888B837E738593856A53323E3E
31334153584E49758585898B7E7E85857E8582818589908B
858585858585858585858585858585858585858585858585
8585858585858585
858585858585858585858585858585858585858585858585
858589858589898BB4EF7F3F2C305369875E604F574D5D81
6940373734525B653B426D7C73888E7F533F443C40453B30
2F404C4E4853967E85827A85827E818585828585857E7E85
828185858585858585858585858585858585858585858585
8585858585858585
858585858585858585858585858585858585858585858585
858585858585828B858AE47F443936486D8671827D8E8A6A
90CDD5EEC69F8D87927772737261414051413C423D38324A
60554F3F89D6858989858585898681858589828185898B85
8681858281898B8585858585858585858585858585858585
8585858585858585
8585858585858585858585858585858585858585898B8585
858585858585828B85857EE3E058313640647C7F8D717988
736C555F69717F8B77766A504B5C615248423A354953706A
5B4F5DA67E82817C858585858589858281858985857E8585
89858589857E8585858585858585898B85898B8281858585
8585858585858585
85858585858585858585858585858585858585857E858585
85858585898B82908B898B859CEF7F433E465755626B757C
7580868882757477736771693F4F47374649464B6066584C
578CAE858586818985898B898B8582858585858585858585
898B858585858585898B858585898585857E898F85858585
8585858585858585
858585858585858585858585858585858585858585858585
858585857E857E7E857E85827A94E2DE8839314366737575
726A626D68614E463C4650605535405861608A786D55579C
C39785858589898B857E857C81858D8B898B85858281898B
7E858585898B85857E858585857E85858990898981858585
8585898B85858585
85858585858585858585858585858585858585898B858585
85858585858585858582858F85828B85CEE3DC783F3E5156
6980757C8086827D745C50618C8D7D858F624C548AD2C994
8B8585898B857E8585898B8985857E857C81858589857E85
898B89908990908B85858585898B85858289858D8B858585
85857E8585858585
858585858585858585858585858585858585827A85858585
858585858585858585897E85857E8585898B89CECE835659
504C616A717A8F9EB0A19A85778F6547517FA7A490828982
8185857E85858582817E8281858582818985858585858281
7E857E7E7E7E7C81898981857E8585827A7E857E82818585
8585858585858585
85858585858585858585858585858585858589898B858585
858585858585858585858585858281858289788185BDBFA7
B9A28F8A828D7055516171696B6F9AB9B2A490858582898F
8990908B85858589827E8585858589858281898981858989
8B858585858589857E8D8B898B858589858585858D8B8585
85858585898B8585
858585858585858585858585858585858585857E82818585
858585858585858589898185858982817E89898585858989
8D9690978A91A0A7A79DA4ADA7A290898589908B857E828B
7E7E7E8281898B858D8F8585898B898B8D8B7C858582817E
8585858585858585857C817E898B858585898B857E858585
858585857E858585
858585858585858585858585858585858585858589858585
85858585858585857E8985858582858582858B8585828182
7A858989818589898989828B85828185857E7E85898B828B
858582898B82908B7E8585857E857E858289828182858585
8585858585898B8585898585828B8585827A89908B858585
85858585898B8281
858585858585858585858585858585858585858585898B85
85858585858585858585858585898589948585858285858D
8B857E8D8B85898B85857C81858985858582818985858290
8B85897C817E7C81898B858585898B857E89898589858589
8981858585828B85898B85827A85858589857C7E8B858585
858585857E858D8B
8585858585858585858585858585858585898B85827A8582
818585858585858585858582858B857E7C81858589828582
818585828B857E898B828585828185858589857E85857E82
8B858285898B89857C85908B857C858B858585898B858582
8F8585898B7E898B7E89908F85898B858582857E85858585
8585898B85857E85
85858585858585858585858585858585857E85858985898F
8585858585858585858585897E8585858985858585867A89
8589897A898B857E858D8B898F85858585858281898B857E
858589857E858585897E7C8185897E8585828582858B8582
8B85827A85857E85857E7E85857E85828189858585858585
85827E8B85858585
8585858585858585858585858585858585858585898B7E85
858585858585858585858281858585858585858585867E81
857E89827E908B858982817E858585898B8282817E898981
898B898B85898B898B85898585898B8585897E867A898B7E
85898F8585898B898B8589898185858985898B85898B8585
85897E858585827E
85858585858585858585858585858585858585857E85898B
8585858585858585858589898B8582818281858585898989
8B8585897E7E85827E8F85858585857E85898985827A8D8B
828B7E85827E897E8B858582817E85858585858989827E81
857E8281857E85828B857E89858585898B7E85857E858585
8585858582818D8F
858585858585858585858585858585858585858585857E82
818585858585858582858B7E828189828281858589908B7E
85828185858582857E898B82858B85858585898B8D8B7C85
85828182857E8D85858281898989858B82818285858D8F85
858285858585857E858585858585857E8582818585858585
8585858589857E85
858585858585858585858585858585858585858585858589
8585858585858585897E85858D8B898F8685908B7C7E8B85
8589858585858D908B7E8589828B858585857E898585897E
858D9094908B7E858586818985897E8994909485857E8585
858D908B85858582818585858585898B858985898B858585
898B898B85898B85
858585858585858585858585858585858585898B898B8582
81828185858585898B8585857E857C81867A7C81897E8585
8585828185857E7E85898B857E8589898189908585858585
857E7E7E7E85898B8589857E8281857E7E7E7E898B898B85
827A828B8585898F8585858585857E828182817E85858585
7E857E85857E8585
858585858585858585858585858585858585828B7E898B89
858985858585857E8585858582818985898589898B898B85
858589858585858589898B8585827A898989858585858585
85858585858989908B858585898585858585858290898B85
89857E8585857E858585858585898B8681868185898B8589
8981858585858585
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.35119 0.015625 0.64881 0.313244 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00751202 0.0192308 0.00751202 [
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(240) show
81.000000 12.812500 moveto
(deg) show
99.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(.) show
105.000000 12.812500 moveto
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
128 string
128 128 8 [128 0 0 128 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
B3B3B1B9BCB3B5B2AEBCB1BB9F9F9F9EA6A0A0A0A096B6AC
6397A2999B939B9C929A9B9A9D95939B999FA09B9B9B9B9A
9D909B9B99A1A1A1A1A1A1A29EA39B9A9CA39B9B9B9B9B9B
9B9B9A9B9C999B9B9A9B9B94A5B8AB7195939B9C95959399
9999999997A0A09B9CA7A0A5A5A79EA7A19A9B9291959595
88A9AD8397ABB3BC
B3B3B2B7B8B4B8B6AFBAB5BFA9A0A09EA4A0A0A0A096ABBD
6D98A29A9C94979A92989B9B9E9995989A9E9E9B9B999698
9F92989B989D9E9F9E9D9EA19BA19E9A9AA09B9C9C9B9B9B
9B9B9B9B9C9999989B9B9B939DB4BA7287969B9C95959396
979A9B9B989F9F9C9AA49EA2A2A5A0A5A19A9D979495969A
96A7A88791ABB3B9
B3B2B3B5B2B1B6B9B4B1B9B8C0ABA0A0A09F9FA09F9E98C5
7F819F9B9997939698979A9B9A9B9C9295A19D9B9A9B9392
95968F95999A9A9E9F9B98A09B98A09C9E9F9F9C9F9E9C9B
9B9B9B9B9B9C9C969B9C9B9C939CC2AB7885979996989795
939997989AA19CA19C9F9FA1A3A1A7A0A29A9A9A9C989995
A7BA9B9389A7B5B6
B3B3B3B3B7B4B7B6B3B7B3B6B8C0ABAAA29F9D9D9E9A97A0
D276919B9D9991929797979B9B9B9C968F9C9E9C9C979893
9493928E91979B999E9B9B9B9B9A9B9CA2A1A2A1A0A49F9E
9F9E9B9B9C9C9B9B9C9C9B9B9C9894AECF798799969C9D99
989E99969A9F9D9F9DA0A0A1A4A5A4A29E9D9A9E9BA39FA4
A0A6AA968CA6ACB6
B4B4B3B2BAB4B7BAAFB9BCB7B6B5B6BAB29FA29E9C9D9C95
B6AE879A9C9D9595969792979B9B9E99969B9A989A949E9A
959899938F9298989596969B9B9B9999A2A09D9CA8A2A09F
9FA49C9C9E9E9C9C9E9E9D9C9D9B9994AEBC73949C9D9D9B
9E9B9B9E9CA19CA29C9F9FA6A4A7A0A69F9E99A69DB5AAA3
BA91AB9887AFB4AF
B3B3B6B2B3B8B5B6B3B5B7B7B8B4BCB4BFB1A3A39DA19B99
A7C3979C9DA39897929B98959B9997989996979695949B9B
9B9B9D9C94928F99939393979B9B9B9B98A19D9AA2A49CA2
9DA2A19CA0A19E9C9E9F9F9A9F9C9D9994C09E8A939D9FA1
9D9C9C9FA1A0A0A2A0A09EA3A4A4A69F9C9D939DB2AEA2A3
AD99B3968FADB9B6
B3B2B9B4B8B2B6B2BAB2B7B5B2B9B8B5BBBFB7AAA4A3A3A2
9BABB99D9EA29E9E98949795969A948D93938E9394909B9C
9D9E9D9EA299958F988F99909696979B9B9A9B9FA0999D9D
9D9C9E9CA19F9E9F9A9E9B9B9C999D9B9993BDAB96989D9D
9E9A9F9DA1A1A0A29FA4A1A1A4A3A09A8F918EA4A7BB96A5
9A98AD8EA0B5B5B9
B3B1B6B7BAB0BCB2B7B2B9AFB6B9B4B7B9B9BBBDADA8A9A7
A8A0B7B08F8BA09F9A989595949190908C90908E938C9799
9D9F9F9EA39B9E8F9390949093938D939497959B9A979797
989A98999A9B9A9B9A979797979895989A9195B0B2999A9B
9C999D9BA0A29FA2A0A79EA2A0A1908F8A838CA995A5969A
9AA09F87ABB6B0B9
B3B3B6B4B7B5BBB2B9B5B5B5B4B0B7B5B7B9BBB5BBB0B3B1
B2B2ACBDC8859A9B9E97959594978F8B9393959796909098
9A9F9F9EA39FA19792959590979493928E908D8B908B8D8E
8B90898F918C8F8F928E8E909393949298928B91A59E9686
879297969C9E9D9DA2A5A29F928592838A818DA2A08C919C
97A29B90AAB6B3B3
B7B4BAB3B6B9BCB6B4B5B2B8B5B4AFBBB2B5BCB0BCB2BBB5
B2B9B9B5B5CA9E8E8F9F92909792958B8F8E91979A978E94
999DA09F9FA09E9E92949B949897999B96989492938C8F90
8E908C908E8F9291929192909891989899959499889AA99F
8566748E9298989B97827A788678838F908C89979A9B9387
AA9F88A2A7B3B7B6
B5B7B2BBB1B7B5B8B5B7B5B3B5B6B4BAB5B0BCB2BBB3BBB5
B2B9B4B8B1BABC957296908894959792928A8F9496978F92
9B989E9CA1A09D9F989697979D979B9B9D9699959A9A9599
93939298979497949696969B9F929A989C949D999895979C
A2BD5D997E7C84817D7E6F6B6E72829091869F939096988A
A4A88CA2A7B0B1B8
B6B5B1B9B5B6B5B5B3B3BAB4B3B9B8B7B4B3B9B5B8B5BCB6
B7B5B0B8B2B5BFA28183857F87949492958C909293989191
9A9B9A9A9D9E9DA09D9894989B9B9B9B9B9D9B929697989D
999695939698979998929B9B9B9A9A949C9499979B9D959A
959995AEA08E69676A67716E6F7A72888B7AA6888D9B7B99
AB8AB599B4AFB3AF
B6B9B6B4B9B0B9BAB5B7B4B8B5BCB2B9B6B7B5BCB1B7B9B9
BAB3B4B4B1B6BC9DA378817E5D799290968B93948F949291
9B9B9A9B9AA0999E9B9D99979B9B9B9B9B9B9B9D9396949A
979B9695959394979A919B9B9B9B95979C939A939B999799
959288897D7282635E6A6C7076787D7D8681A87F849B809A
A58BB2AEB4AFB7B4
B7B4B7B9B4B1BBB1B8B5BCB0B9B8B8B1B9B9B9B8B4B5B9B8
B8B4B2B5B6B4BDA8AE8F707E66456A928F8F8F8C94949092
9B9B9B9B999E9B9B9B9B9A979797989A989B9B9C9696949A
95929995939696969493989A979B919B9C95959497999292
8E8D82716C696671726E6573757B7B898B879381859488A1
9899B0B0B9ABB7B8
B6B8B6B6B6B0BCB4BCAFBCB2B9B4B9B4B9B6B9B3B2B8B8B4
B9B5B5B2B9B3B7A3B29E6D716354306A84918C8E90939191
989B9B9B99999B9B9B9B9D999897969A94989B9D99979394
97959594949594949394939D959893979D99949594948C91
8686776B6667696F767B726979787D857F8E8F8790899C92
96A2B5B3B2B3B4B9
B4B3B2B8B6AFB8B5B8B0BBB8B3B9B3B6B9B7B2B8B2BAB2B8
B5B4B8B7B7B2BB9EB9A97B6B68533F29638A87918D969092
969B9B9B9D9697989B9A97979A93979597979B9A979C9491
93939397939694909095909A949A979297958D8C89838682
7E62596364756B647183827B737C70827E8881939596AB8C
94B0AEB5B0B4AFBB
B3B3B7B4B4B3B9B2B6B2B7B7BBB2BBB5B4BCB2BBB6B1B9B6
B2B8B0B9B5B6B8ACB49E8E6865534638256389908693938E
989A9797979B9894989C9697989892929297979A98959393
90938D9293958F94888F8E949391928F94948988857C756B
5B5C5752687C7F6679788480887973797E89839488AA969A
A5AEAAACB5B5B0BB
B3AFB7B8B4BBB3B6B5BBB4B2BBB3B8B2B7B8B2BBB8B7B2B9
B8B4B1B5B4B6AFB4A39F7F6D61504B423317588E84908E91
9399969696949C97969A969499959893919395909A979491
9290908C8A91908F8D8E8B90958794888E8D8B837F6F655F
5D526063707478737C73757676847D7B84868B949696A1A3
ABB3ACAEB7B8B4B9
B3B4B2B7B9BDB2B6B7BCB7B2B8B2B7B4B8B7B4B7B6B9B5B3
BCB5B4B4B5B7B3B59CAA746E644F4844302C14568B8A928F
9594969696949B979C969696979496979392959094949392
918F928D8A898F88858F88909089868E8684867863634954
5E5F63717674727683807A7782788587898793959494A8AE
A9ADB5B4B7B9B7B6
B6B2BAB2B9B7BCB6B5B7B8B5B5B4B2B5B7B7BBB8B3B5B7B2
B8B5B7B6B3B3B7B4A2A5776761584B3D30232F118A879491
94949698979894979A969594969595969392948F918E9290
908F8F8B89878888848A90818B7E838381757575564D5C4A
555E6774706F79748585837E878B858C8A93949697A1A3AC
AFB5B4B9B3BBB5B4
B9B9BAB0B8B3B6B9B8B7B6B1B5BCB5B4B5B5B7B9B4B5B9B4
B6B5B9B8B4B6B4B1A097776D5A5951493530332A6A8A9095
9795929C949A9696969597929493929791939390918C8D91
91918C8B88817E838889887F7C7C7C7D776B655A6F565F61
6B6370767170717A757D867E7C89858B93939695A1AAA1B5
B4B6B7B7B5BAB2B9
B9BBB8B4B6B5B2BAB4BBB4B4B9BBB5B8B2BBB4B5B1B9B6B1
B7BBB3B9B3B5B1B2A4827469645850453D3A3A2D29899492
9C949199939595939597949595919095949090958B938A8A
8F8D89887F837A7D8B8C83777A7C6D696162675953686163
646F777870696C83787C8084858683939394939AA5AEAAB3
BBB4B2B9BBB4B5BB
B9B9B9B3B9B6B7B5B9BBB2B9B9B9BCB3B3BCB6B7B3B0BCB4
B5B8B3B8B8B5ADAD9885686656584B4249443A220D8C9292
9A95949791929791919394939194928F9591908C91859089
8B8A88837E737D7D84856F7074726A575B58655E5A585E62
5E6E78767377658574846E8C807E8D949493A09FAEAFADB5
BCB0B9B9B9B2B6B9
B9BCB4BBB1B9B9B7B9B9B5B7B9B9BBB8B2B7B9B5B7B2BBB3
BCB4B4B9BBB7ADAE86846F625E4B454349463B3506959098
939494979492959292908F928F8E8F8E8D918C8F898A8888
8684857A7975717E80726E6D6C5F5B5F53607065605B6467
626B7379797B797E757C7876858E899796979FB4B0ACAFB6
B7B5B9BAB6B8B4B9
B9B9B7BCB4B9B9B3BBB5B9B5B9B9B9B9B7B5B5B7B5B7BBB3
BAB2B7B7B9B6B2A7857A6B625C584A4C4C38342C13968D96
929097938D92918F8F90888C908B8A8A878F888887858A84
83827C7D6F747671696667665E635A5B5A59736F6A645D6C
6A686B73748B8482777C7D787993939E97A8ACACB4ACB2B5
B2B9BBB3B6B7B6B7
B9BBB5B9B7BBB7B3B9BBB5B7B9B9BBB5BBB7B5B9BBB3BBB5
B5B7B4B5B7B9AE9C877B6C605B4F4F474732312C0E969198
8C92939A8F8A918E8A8B8A86898988858A848D8784818383
837E7E76756E7468645B60535D53515359606D75786A6964
61706870708684847B7D8B7C7E93939BA3AAB0ACB5AFB5B2
B9B7BBB8B6B6B4B5
B9B9B9BBB5B7B9B5B7B6BBB5B9B9B7B9B9B9B9B9B9B5BBB5
B2B9B3B4B7BCB0917A78635A5251494E4139353311929093
92958C929589908C87888882848286828383868582807C82
7E7B79766E756D61595B555D5451524D555A6F7170786D6A
615B6779717F87897B81847D869590A4A7B2ABAEAEB5B7B3
BBB5B9B9BBB5B5BB
B9B9B7B7BBB5B3BBB8B4B7B6B9BBB3B9B9B7B7B8B2B9B9B7
B4B9B0BAB4B2B4887C6D6A5B53514E52352C2E3618968892
8B939188918A888A86838484807C7D7B7B8181847E7D7A7A
787A727365666259585A5C5355575455585E687A7A80786A
5C60616A788180878281767B8C9594A9A8A8B4B2B0B3BBB5
B9B9B7B9BBB5B6BB
B7B9B7B5B9B5B2B6B6B9B8B4B9B8B5B7BBB5B8B4B4BBB7B5
B9B9B2BAB2B6A0857C6B5D5659504A4330272C2F19968993
8C8F8F8A87898388857E827F80827A78767A7B807C7C7874
72706D6B6A5A515954575B473E44515D6562676D80788B81
646265746C76888282787871929A9FA4B1A7B3ABBAB2B6B9
B9B9B5B9B9BAB4BB
B7B5B9BBB7B6B7B7B6B5B9B9BCB3B8B3BBB3BBB2B9B7B9B7
B8B6B5B4B3B394846F675F4F514D4F3B353130351F91888B
8D8E898B87858381837E7A7977757973757873777C787474
6E6F6A676B4E5352584D44462D4353586362636C78837987
756A726F7B6E828274727B799596AEA5ABB0AFB1BCB3B2B9
BBB5B6B9B9B5B7B9
B9B9B9B7BBB3B7B6B7B7B9B7B9BCB6B5BBB1B8B3B8B5BBB6
B6B5B9B2B6A4887C6C6259584E4B3E3732323433278A8A8C
8E8D8C878C888B8584857973766D6E716B7076707370746B
68646760664C46584C413D3E483D576D5C695C6375857C85
716E766E7A7B877A7E77788394AAA6A9A8AFB7B4BBB7B3B9
B9BCB4BBB5BBB3B9
B7B7BBB5B7B4B8B4B7B5B9B3B9B9B6B9BAB6B3B6B1B9BBB3
B7B9B2B5B79C86776463565C504B2C353532303E2D8D9490
9D969791928F8E8E8A8C8A817070686A6B6966696F6C696C
65615B5E574A464D4935344440495568675C655C767E8F84
80736E6565878775817C8A8799B9A8A6B4ACB7B9B7BBB5B9
B9B7B9B9B9BBB5B9
B7B5B7BBB6B2BBB3B9BBB7B5B9BCB2BBB5BAB6B8B0B9B9B7
B5B4B5B4A99282736556554C5B4235303B353141458E9BA1
9D9D9B9F99989991908F8D8A8A776E656569686961676966
676056575F4E52483D3438414D445265645E5C606D78898A
8B79716C5F81877B7A898085B3AAA8ADAFB6B3BBB2B7B6B7
B9B5B9B7B9B9BBB8
B7B9B7B3B9B7B8B5B6B9B9B9B9B9B3B9B9B3B9BAB0BBB3B8
B4B3B5BD9F887A6C616252514F35363636354D44739F9DA7
A1A0A19CA19C9F989794908D8A878579676263626A606465
5E5B4F3F5D50574B3326273E654752616864626271758B91
917372676E777A817C937994B0A8A2B3ADBBB5B9B6B8B6B7
B3B7BBB5B9B9B7B9
B7B5BAB4BBB8B4BCB1B7B6B9BBB8B1B9B7B3B9B5B3BBB8B7
B6B3AFB29A837165545357514436363B394658799BA0A8A2
A99EA79CA19F9E9B9F98998F8D898A8483675D5C5D625D60
5D55483F444F4A6F3A3D242C564F4A5B6C5C74666B778293
968E626D70797581888B7AADAA9DADB2B5B6BBB2B9B9B7B9
B7B3B7B9B9BBB5B9
B9BBB5B9B9B6B9BCB6B8B4B9B9B8B4B3BBB7B5B7B5B9B9B9
B9B5B1A09477726558504F4F3C353236512B9AA19C9FA3A6
A4A6A8A2A19CA19C9B9A9997908C8E8A84806F61575D595A
564D4A3C3E7449713F243C3D497957626F5C69706E77788E
9A896D656B71758C8E8485A3A7A9B3B0BBB2BBB3B9B9B5B5
BBB7B5B7B9B9B9B7
B6B6B9B7BCB4B9B6B9B7B7B9BAB4B6B1B9B9B3B6B9B8B5BB
B6B3B19B8D756C604F4C494A31323547386E9DA49CA1A0A4
A1A4A1A1A89E9E9B9B9E9B9394928E8C8A8875805B565952
544A422F396D53616B533140465D6362677361726C717C7D
96966E62746E72838E8D8897ABB1B3B2B9B5B9B5BBB5B3B9
B7B7BBB3B7B9B9B5
B5B2BBB3B9B9BBB2B9B7B5BBB7B5B6B4B9B7B8B4B9BDB2B9
B1B3A79A816C695B544A4A37393743495A9B9BA1A1A19DA4
98A39C98A29A97969799979B908F8E8B8C8A847E7E5A4D53
48493838334E82497C4C654459496F596469616177658772
87A8825F6971797A898B92AAAAAEB5B0B5B9B3B9B9B7B5B9
B7B3BBB7B5B9B5B9
B7B5BBB3B9B9BBB5B5B7B7B7B9B7B5B9B5B7B6B6B7B7BBBA
ADAF9A94736B58554F4D3537312D43589D9D9D9D9EA09A99
9391908F8F918B8B8B928E9490938D8D8A8A87827E83664D
4D433F3537406C75598B596F45505F6F605F6E5971737B7D
888D94796A747872848CA5B2AAB1B5AEBBB7B3BBB2B7BBB3
B9B5B9B9BBB5B9B9
B9B9B9B5B9B9B9B5BBB7B7B5B5B9BBB5BBB6B5B4B7B5B7BC
B3A49F8A7164604B4B483A313D4B3F9E9CA2A09B9A9C9791
8D86838080817D838585858A8B9090918A8A87827D7E7B5C
4441382A3041516F5B587D6F794C536B6C696169647F787E
7E8DA67B78807D758485B7A4B6B1B6B2B7BBB5B9B6B5BBB5
B5B9B7B9B9B9B9BB
B9BBB3B9B9B9B5B9B9B9BBB3B9B9B9B9BBB7B5B3B6BBB5B5
ACA39A7A6D595B51413A39343925999D9C9E9E9B99867574
7A7A7A7777776F676E6A7587848D90938D8C8885817B787A
4D3633262A38497A75528774817C655B6F705E66607C7182
82829E8C817E7A7E8A8EA8ABB4AEB2B8B5B6BAB4B7B9BBB5
B7BBB5B7B9B9B7B9
B9BBB3B9B9B5B7B9B9B9BBB3B9B9B7B6B9BBB6B7B4B8B8B7
A89A93755F5A4E494640353B46519C9C9B9B9D91858B7670
8C7F7A7D84807B6F6D6A5E7085878D90918A8B89817F7A72
79482B2821362A468C64607D71877F7069636E64646D7E6E
858595946F7D76788AA3A4AFB4ACB5B4B9B4B3BBB3B9B7B9
B5B9B9B5B9B9B3B9
B7B9B5B9B5B9B5B7B9B7B9B5B7B9B6B2B7B9B3B9BBB1BBAA
9C927B70534E494E2F36354732A29E9D9B999E9578757463
7B7D746B6A7162646E736A596D888A90938E8C8A84817C7A
757140321B254C317485538C6A7B9781667760675F6D7677
7B80929C7C71757A74AEACB3B2A8B9BCB6B7B5BBB5B9B7B5
B9BBB5B9BBB7B5BB
B7B5BBB5BBB3B9B5B9B5B3BBB5B5B5B7B7B6B2B9BAB2BFA4
99846F5C51484733422F413670A09F9F9B90828053525961
5C585A5E4E45444D3B514A4842688190908E8E8C867F817D
7A6F60211C2834415E7E5C5E7F667DB08A6D686E6364736B
777C949F877C837779AAAEB3B1ADB5B9B9B7B9B7BBB5B9B9
B9B9B9B9B7B9B7B9
B7B7B7B7BBB7B3B9B7B5B5B9B7B5B5B7B9B5B3B9B5B5B9A5
9173644E4F4344433B4038599F9EA29E9BA78F8E755E595B
645F63655E5D545660577173696679908F908A8A8E817F7E
82756B411B162B404965914F7C666E8FAD7875646D676F70
61828D97927A89798DA6B2ACAEB7B0B7B9B5BBB5B9B7B9B9
B7B9B9B9B5BBB3B9
B7B7B5B3B9B9B7B5BBB3BBB3BBB5BBB7B7B5B7B6B2B8B1A1
8767605343453D3E3E43209FA09C9EA19D9F96AE9D919083
8B878296898B868582728A8C8A8E8B90928E8C898C88817F
7E7C745A2F122F3A444D7069526F56838FA96F726B5F6B77
687E7D939D747E699FAEAFAEAAB7B7B7B3B9B9B9BBB5B9B9
B5B7BBB5B9B9B5B9
B7B9B7B5BBB5B9B7BBB5BBB3B9B7B7B9BBB2B8B7B3AFA697
7A5F4B4B46343E3E3D4C4AA19C9FA09C9F9C9CA1A0A5A7A2
9AA89B989BA09497948F95929494919092918D8B8A85867C
7B7876602D2226474F575F6B496A656690A08F7C746C6264
687571939C80825CA8AEAAAFABB9B9BBB3B9B9B7B7B7BBB5
BBB5B9B9BBB5B9B9
B5B3B9B7B7B7B9B5B6B9BBB5BBB5B5B7BBB6B4B5B9BA927F
675C4B4239413A3F4023909F9EA19EA29AA49BA19FA59FA5
9FA69B9B9B9D919393909591939B958E928F8D8E8A848685
79787B684A3118383E564C6E584E686480919388736D6F66
6765738C9E7B8564A8B2A7A4B4B7B9BBB3B9B9B7B7B5B9B7
B9B9B9B7B7B9B9BB
B7B5B9B7B5B5B5BCB4B7B9B9BBB5BBB5BBB7B6B4B1AF9874
6348513940303C4137189F9F9B9FA3A09EA0A0A1A1A1A0A1
A19E999698978D91968F96909D8D9C97978F8D908B878083
7D74756F4E28292C494F585C624C555C6B819A887D6D6860
78657B809783767F9EAEB49DB9B5B9BBB5BBB5B7B9B9BBB3
B9B7BBB7B5B9B9B9
B9BBB5BBB7B5B9B9BBB5B7B9B9B9B9B7B7B9B7B7B7958E6C
595940463B423A36532D9E9C9BA0A1A1A4A0A1A0A1A29F9D
9E929286958D878A918F91939C98949A9A91918C8C85867F
827C70695C3A302F3F48535364514D43687B7F91896E7458
706F7E78998B639B95B2AFB1B5B9B9B9B9B7BBB5B9B9BBB5
B9B3B9B9B7B9B9B9
B7B7B9B9B9B9B9B7B9B9B3B9B9B7BBB7B7B3B9BCB6927164
4B464736353D3F3529739A9C9BA1A1A19FA5A29EA1A1A399
98928B8188878086898D8E9492969B9F969597908D87867F
7F7A766D5B3C13223446495051614D493B78868090727A68
666B7475969B72AB8DACA0B9B9B9B9B9BBB3B9B9B9B9B9BB
B7B5B9BBB3B9B9B9
B7B5B9B9B9B9BBB5B9B7B5B9B9B5B9B9BCB4BBB7B488644F
49383F3E3D3A33310C9A9B9B9BA1A0A4A3A1A29FA098858B
9B93956D6270777378828D909B949B9B9F9299928D8B8881
7F82726963471F1E26394050495E4C573D706F769C7B7064
5D696D739494968EA3999FB9B9B9B9B9BBB5B9B9B9B9B9B9
B9B9B9BBB5B9B9B7
B7B7B7B9B7B7B9BBB5B9B7B9B5B7B9B9B9B9B9BBA6786156
4443343B3D37313E159D9A9E9CA59CA1A69FA1A29DB69C78
9DA19AA07B727C936E76838D9B9B9B9B9A9B99978F8E8786
7D7C787263591717212E3E4845555145303E717F7B856B6B
556867758F88AA76AF8EB9B7B9B9B9B9B9B7B9B9B9B9B7B9
B9B9B9B9B7B7BBB5
B7B7B5BBB7B5B9B7B9BBB5B3BBB5B9B9B6B9BBBBA166563B
43413E3B40302B3D3A9B9B9D9EA7A69FA9A0A29F9EA7A0A0
A2A2A2978D8B8A908E7C7E8E9B9C9C9B9F939599948E8C88
7E76776C655A191C182F3F4A4246524839227F76788E6770
5E616E7482989F8B7EB9BBB3B9B9B9B9BBB5B9B7B9BBB5B9
B9B9B9BBB7B3B9B9
B9B9B9B9B7B9B9B5B9B9B7B3B9B9B6BBB2B7B9BE915E4E4E
3D3E43413D2E2E256D9AA0A09FA4A5A5A6A6A3A099AA9DA5
A8A79F9F928C8C8A8A8785909B9B9F9C9C9F989693928D8D
877B766E6455360A1D2A2A425045484252396F6E80996B72
6363646C839697949BB9BBB5B9B9B9B9B7B7BBB5B9B9B9B9
B9B9B9B9BBB5B9B9
B9B9B9BBB5BBB5B9B9B3BBB3B7BCB4B9B7B5BBA67A5A3B3D
3D3E4140262C1F079A9BA09EA5A5A5A4A6A4A9A39AA2A2A1
AAA7A09A9088878989878E949C9AA19D9D9B9B9F96938C8E
89857A6E665F4D13152745384F4A4C403F4B5E6C818D7E61
68606C6887947F91B5B7B9B7B7B7B9BBB7B3B9B9B9B9B9B9
B9B9B9B7B9B9B9B9
B7B7B7B9B9B9B7BBB7B5BBB7B5B7BBB3B9B9BBAA69473E3E
42403F1E2A212F019B9FA59EA5A5A4A5A5A5A5A8A3A19CA1
A4A19E9B8F85878C878D929B9C9A9EA39C9D9B9B9D958F8D
8A888475685E51172122313F434554464748606E75879361
605B626A8CA77E9BBBB5BBB7B7B5B9B9BBB5B9B9B9B9B7B9
B9B9BBB3B7B9B9B9
B7B7B5B9B9B9B5B9B9B9B9B9B9B5B9B5B7B7BAAD5F48423E
423F42301E263A379B9FA6A4A4A4A5A8A8A7A4A5A9A1A19A
A9A29E9191868B8E8C8F9C9D9C9C9DA69D9F9C9B9D92948E
8D82867A6B5E5A2B0E28243C47434555484963767782916A
5B596162889A8EB5B9B9B9B9B9B9B9B9B9B9B9B9B9BBB5B9
B9B9BBB7B5B9B9B7
B7B7B7B7BBB5B9B9B9B9B9B9B3B9B5BBB5B5B2955D424243
453F2B251A323D8B9FA0A8A4A5A7A1A7A7AAA4A5A5A7A69B
A5A9A1998D8C8B908F939AA0A0A19BA6A1A39F9EA0999594
8F898185755F574B2D293B35494C484C4B4A5B7F7C809E60
5B4B69588BA399B9B9B9B9B9B9B9B9B9B7B9B9B7B7B9B9B7
B9B7B9B9B9B9BBB5
B5B5B7B3B9B9B9B9B9B9B9B7B7B3B9BBB7B5936C4E353D41
40422F31300092A09EA3AAA5A5ADA4A4A5A7A4A4A4A4A79F
A5A9A39F9289919291929B9AA4A79FA89EA3A0A29E9C9D94
918C867F7D6855493931324140534D5056545E827B7E8F6A
514968677F9DB2B9B9B9B9B9B9B9B9BBB5B9BBB7B5B9BBB5
B9B5B9B9B7B9B9B9
B5B3BBB5B9B9B9B9B9BBB5B9BBB3B9B9B9B7A95C463B3A4A
413B3B2648299D9BA4A5A5A5AAAAA5A4A3AAA5A8A7A4A8A1
A5A4A4A192888D949697989DA59EA5A3A49DA3A1A19C9E9A
938A8C817F69594B332D3237424853544A5A717F7E7C8E73
624E5F6F79A4B9B9B9B9B9B9B9B9B9B9B9B9B9B7B9B7B9BB
B5B9B9BBB5B9B9B9
B7B5B9B7B9B7B9B9B9B7B9B9BBB5B9B9BBB5A26152423546
45323943296F9F9EA4A4A1A7AAA4A5A4A4A3A1A7AAA4A4A4
A1A8A2A5948B87929298989EA09EA2A7A09EA39F9F9C9B9C
9A8F8B848273624E423031324045504B4643827B7B7C8070
595E606573AFB9B9B9B9B9B9B9B9B9B9B9B9BBB5BBB5B9B7
B9B9B9B9B9B9B9B9
B7B7BBB5BBB3B9B7BBB3B9B9B9B9B9B9B7AB8152504C4740
39363445509EA0A1A4A4A4A5A7A4A4A5A39BA0A2A2A4A4A6
9BA4A4AC998C878B909091999F9EA0A49DA49F9B9C9B9D9B
95978D887F7A6556442C3034374C4E504C3E817E796B6A64
49646B6A6EB4B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B7BBB5
B9B9B9B9B9B9B9B9
B7B5B9B9B9B5BBB3BBB5B9B9B9B9B9BBB3A1845B484B4643
343A3B2094A497A5A5A7A4A1AAA4A1A19A9B999D9BA3A89D
A0A5A4A99D8B888787948B989F999F9B9A9E9B999B9B9B9D
95968F8A87786E56492E21313940554E4C4A7D757C5F437D
4454717B75B9B9B9B7B9B9B9B9B9B9B9B9B9B9B9BBB3B9B9
B9B9B9B9B9B9B9B9
B9B9B9BBB3B9BBB5B7B9B9B9B7B7B7B9B57F5A615B455440
2E3C5A48959796A5A1AAA4A3A2A29DA4918F9298999BA49B
9DA5A4A69B86888387859099989C94938D8F8D8D8F929896
9C8F968B827B6B614D421C2430414B564B487C726D603382
4A4D6E7E8DB9B9BBB5B9B9B9B9B7B9B9B9B9B9B9BBB5B9B9
B9B7B9B9B9B9B9B9
B9B9B9BBB5B9B9BBB5B9B7BBB5B7B7B5B9A84A5C484D4B2B
42353B868D849AA6A4A4A4A399897D8391807D8C929CA39A
99A5A4AD978A7C82848B8996938B8779777B827C83859492
8E8E928B857971584F433B292A38474A54486D7763643278
4D43757895BCB9B9B9B9B9B9BBB5B9B9B9B9B9B9B9B9B9B9
BBB5B9B9B9B9B9B9
B7B7B9B9B9B9B7B9B7BBB5BBB5B9B9B9A29E5A4F4343473A
355B4E9C787C9DA3A4A39D857E89855E5D6D6B7E738B9F9B
97A5A5A8A08E817B74635B777F8F7B595B6268696A738A92
8B8B8A88837A6A635144452C2735464755536D6E655A3982
594983729ABFB9B9B9B9B9B9B9B9B9B9B9B9B9B9B7B9B9B9
B9B9B9B9B9B9B9B9
B7B5B9B9B9BBB5BBB5B9B9B9B7B9B9B9AC7E685D3242463C
24259596817EA0A1A09E8781737A7869484F5D75786B9194
95A5A5A69D957C796B904F537F74785E50566266585C7886
878A8B8385786C5D4F442F161E324A3E4A5A67695E664069
56618872AFB9B9B9B9B9B9B9B9B9B9B9B9B7B9BBB5B7B9B9
B9B9B9B9B9B9B9B9
B9B9B9B9B9B9B9B9B9B7B9BBB5B9B9B9E77D5C473837444E
49129E8583839AA39B8B763D4E7D926B1E3B434D6C6A8588
98A5A8A29F9789776465884771785D1F3D54463D434F6277
7B868881797C6A584F45261C1C203E454557636A5E615069
426F8776B9B9B9B9B9B9B9B9B9B9B9B9BBB5B9B9BBB5B9B9
B9B9B9B9B9B9B9B9
B9B9B9B9B9B9B9B9BBB5B9B9B9B9B99D99A66C4B433B464B
554597837A85999E96845558393E322E65325A4A62747A8E
9DA3A7A39D96987E785E5F735451214B2342305E3B49626A
6E7D8182716E5D544E433D222A2F2D3F435F59575E67557B
4A6F7492B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9
B9B7B9B9B9B9B9B9
B9B9B9B9B9B7B9B9B9B7B9B9B9B9B9A2619260494C464141
4F62917D7D849AA39C958D59544F463D3E4D6464747E9194
A2A2A7A39E9C9A90817D6E545F7C5C4A3E343E47605B6A71
727A7B7C78685C4D494A3F2C2A2D2D35455D6258566C617D
567069AAB9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9
BBB5B9B9B9B9B9B9
B9B9B9B9BBB5B9B9BBB5B9B9B9B7B9E8766554403A433947
4E68827A78819C9EA0A4A1998C83787677717474818B9C9E
9FA5A7A69F9D9D8E847F7E886C747577746C67637082837D
7E81807375715B504B39382C2C3A39313F5F6458586B7080
5C6E7DB6B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9
B9B9B9B9B9B9B9B7
B9B9B9B7B9B9B7B9B9B9B9B9B9B5B9C36D53383434473536
50687678717D999A9EA8A6A1A5A1987E706B6E718B8F9CA8
A3A7A4A7A4A3A4997C695C666F848B8D8D8A8B8E8A8D8E8B
7F7678786B68644F4B4A2E29252D26393C51665655707388
60619FBFB9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9
B9B9B9B9B9B9BBB5
B9B9BBB5B9BBB5B9B9B9B9BBB5B9B5B56F3936303B3B4A3F
4E596D756C77A19098A1A6A4A48B7D6E656E796D969AA6A8
A3ADA4A6A7A1ABA19F82574B4B52788D959C999992918D83
74746D736A5F5C543B362E2B27223C3B4B546154516F6C96
6960AFB9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9
B9B9B9B9B9B9B9B9
B9B9B9B9B9B9B9B9B9B9B9B9B7B9B08C9139413A2E3E4342
4D4D5A6A6D729D907D848C85767C707E86788DA1A7A5A6AD
A5AAA4A5A5A7A3A5A6A79C7C695A4A5E606C777E75746D74
796979736B5E5850582637363528204050585E5950756B6E
6C6CB9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B7B9B9B9B9
B9B9B9B9B9B9B9B9
B9B9B9B9B9B9B9B9B9B9B9BBB3B5C15F6E41464743374140
4B4F505E687798B58D88827D857D7A88A5A8A6AAAAAAAAAA
ADA4A5A8A7A8A7A4A3A5A79F9C968C7780645F65676F7370
70797A766D605D53364B2E2F1C1B1F3153505E5C56716F6C
4997B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9BBB5B9B7B9B9
B9B9B9B9B9B9B9B9
B9B9B9B9B9B7B9B9B9B7B9BBB5B9CD7C56404A5A4D454045
4A4E555D5E7B989EA1AB9D98888EA2AAAAAAAAAAAAAAABAA
ADA5A5AAAAA9A5A5A4A7A5A09E9E9C9BA799888381768083
7D7978706A625F634834271B1B181D2E565354685572765B
54AFB9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9BBB5B9B9
B9B9B9B9B9B9B9B9
B9B9B9B7BBB5B9B9B9B5B9B9B9B9BC6A494B4A624F4A4A45
4B4B535F5C769B9CA09DA5A6A5A8A4A7A8AAAAAAA8AAABAA
ADA2A7AAAAA5A7A4A5A4A8A29EA39C9B9C94989792898884
7D827876675F61565C422C271F28222375534978565C7B55
64BCB9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9
B9B9B9B9B9B9B9B9
B9B9BBB5B9B9B9BBB5B9B9B9B9B9CA744D4E4C5E594F4C47
46464B5E5870949E9F9DA3A6A2A7AEA7A3AAAAADA6AAAAAA
ADA9A5AEA8A4AAA4A4A3A3A79EA39C9B9C959C92918D8686
818279726B6260604337362D1B182021736351755A4F773B
8DBFB9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9
B9B9B9B9B9B9B9B9
B9B9B9B9B9B9B7B9B9B9B9B9B9B9C88E454A45524F4C4C49
49474E60626A8F979FA09FA5A6A1A7ADA6AAAAAAA7A8AAAA
AAAAAAA7A7AAA4A3A2A1A1A19FA09C9A949A9595918A8B85
807978786B60604F483735241B18272976735D7D654B783F
B5B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B7B9B9B9
B9B9B9B9B9B9B9B9
B9B9B9B9B9BBB5B9B9B9B9B9B9B9BB8653494C4F54554A4B
464E4C656A708C919FA0A2A5A6A5A5AAA7A8AAACA6A6AAA7
AAAAADA4A4A4A5A8A1A3A1A2A09B9B9D91929194928A8A85
8879786D6F685F553B3F252420191F345970627F6D5C4479
B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9BBB5B9B9B9
B9B9B9B9B9B9B9B9
B9B9B9B9B9B9B9B9B9B9B9B9B9B9B5B8464F4E554F524C48
524E535C6F7284919D9EA3A3A5A3A8ADA8A2A8ADA5A7ABA4
A7A7AAA5A4A4A5A5A3A7A1A19F9E9B9F97939392908C8A84
807C786F6B635D544834291A11113038536D5E7B7D813C9F
B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9
B9B9B9B9B9B9B9B9
B9B9B9B9B9B9B9B9B9B9B9B9B9B9B58863594F51544B4E4E
3E4E56616B72809299A0A2A2A5A6A6AAAAA7A6AAABA7A3AA
A8A5A4A5A4A5A5A8A2A8A2A19AA29C99999791928E8A8A84
84777A6F6461504649331D122111284E5257597A728E6DB9
B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9
B9B9B9B9B9B9B9B9
B9B9B9B7B9B7B9B9B9B9B9B9B9B9B5F86953524748484A46
55475464747380929A9FA2A5A5A3AAADA2AAA8ACA3A9A6A4
AAA5A4A4A6A5A4A5A5A4A69E9E9E9B9D909D90928A8A8C86
86787B6A665E5C4F37331C191E1B2753595852787A69A8B9
B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9
B9B9B9B9B9B9B9B9
B9B9BBB5BBB5B9B9B9B9B9B9B9B9B9C38E55474244443F47
4A555966707D82929A9DA1A6A4A3A7AAA3AAA6ADA9A7A2AA
A8A5A4A5A5A5A6A4A4A59EA1A39C9E9F949E93928A88878A
877B7A6E6858513E332222121A1A285A5357537C8575B9B9
B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9
B9B9B9B9B9B9B9B9
B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B5E061494843464741
445058686E7D869299A39CA6A4A5A8A5A9A5AAAAAAAAA8A2
AAA8A5A5A5A5A5A5A99FA3A1A29AA09B9B9A95928B8C8488
808078696765523B2F2222191C1F276A56585577879DB9B7
B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9
B9B9B9B9B9B9B9B9
B9B9B7B9B9B9B9B9B9B9B9B9B9B9B9B9D18A473F43434648
44495C68737D8996989E9EA4A5A2AAA2A8AAA8AAAAA2AAA5
A2AAA4A6A4A5A5A5A79FA4A29F9F9B9C9A9B93948D8A8A82
8577756E6059503B2E261F26241A29606A57677585B9BBB5
B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9
B9B9B9B9B9B9B9B9
B9BBB5B9B9B9B9B9B9B9B9B9B9B9B9B9BBAE5F4646484446
4B4A546675868A989C9DA0A2A5A5A5A5A6ACA2AAA4A5A5A4
A5A5A4A5A5A6A4A5A5A1A29EA19D9B9B9D9594928F8A8B87
7F7C6E6B5E554638312920241A122655625A6D7B9AB9B9B9
B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9
B9B9B9B9B9B9B9B9
B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9EB9C725455564A
484D5D5F70809496989E9FA2A3A5A4A1A7AAA4A5A8A5A4A5
A4A5A5A2A5A3A3A5A2A3A19F9E9B9B98999595908D8A8784
81756B685A4E41402F2E2119112A2A5E605E6F71B2B7B9B9
B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9
B9B9B9B9B9B9B9B9
B9B9B7B9B9B9B9B9B9B9B9B9B7B9B9B9B9B5DCC178584F54
4E4B556770798A9A9B99A2A0A2A4A3A4A4A5A6A2AAA6A4A5
A5A5A8A2A7A1A1A2A1A59AA19B9B9B9E929294938A8D827F
81726C56504D413235252816102C455F5C617478BBB5B9B9
B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9
B9B9B9B9B9B9B9B9
B9BBB5B9B9B9B9B9B9B9B9BBB5B9B9B9B9B5BBC5C3565145
4E505560747B859697989E9FA1A4A0A3A4A5A5A3A5A5A5A2
A5A2A3A2A5A1A19DA1A09B9B9B9B9A9B9590908F8F8D7F88
786D645B50494E332D291A1339395C5B576F6D99B9B7B7B9
B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9
B9B9B9B9B9B9B9B9
B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B5DA55425B
4A5759636F7B8896939B989FA0A0A39FA3A5A5A2A5A5A8A1
A6A0A49F9EA09FA19B9B9B9C9B9B999A94908F8F89847F7B
7C6C635B50434357251A1E392A5F5F5E596D80ADBBB5B9B9
B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9
B9B9B9B9B9B9B9B9
B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B5C1954342
574F6363707B868E979B9A999E9CA6A19EA59FA3A3A3A3A6
9F9CA1A0979C98A09B9B9A9B9B9B9B90958F8E8B89857276
6D635A50504B44334A32352F51526765687781B5BEB2BFB9
B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9
B9B9B9B9B9B9B9B9
B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B5C0954E43
4547595F6B768589909898969F98A59D9E9E9FA1A2A29CA5
9C9D9995988D979B9A9796969594968C8D8D8685817E7373
69625F4B44423F3D35324358485D6074708A92B5BFB7B9B9
BCB9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9BCB9B9B9B9B9
B9B9B9B9B9B9B9B9
B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B5D99B4C35
4B4A4E5D68757C8A8C90998E9C9B9C9F9E9A9A9D9CA3999F
9A97968F8E8E8D9392908C8F8B8C8E86898881817F71706D
6B5E565248454C4C3E4D41675C685F897C7FB7B9BBB5BCB5
BFB9B9B9B9B9B9B9B9B9B9B9B7B9B9B9B9B5BFB9B9B9B9B9
B9B9B9B9B9B9B9B9
B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9C2A99946
40594B5660667C898C8D908D969C9A999E99979797969290
92908C8685818386838382847B7B81797F77777478736960
5A5C5D4C51564050564D536260666C839791B5B9B9B5BFB9
B9B9B9B9B9B9B9B9B9B9B9BBB5B9B9B9B9B9B9B9B9B9B9B9
B9B9B9B9B9B9B9B9
B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9D8A66F
4E4B575862606872888A8D949299979798958E8B8B929187
8686837C7A7777797476727071696F706E716C676F736F6E
655C5856505E5835425963675E79728981B4B9B9B9B9B9B9
B7B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9BCB9B9B9B9B9
B9B9B9B9B9B9B9B9
B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9D6BA
845B4D525E5C5E72758F92959A98938F8C8E878981828F83
807A7C6F756B736374666B5969636266616465675659635F
635D625A4B4A5C5B4D51626E727A838292B9B9B9B7B9B9BB
B5B9B9B9B9B9B9B9B9B9B9B9B9B9B7B9B9B5BFB9B9B9B9B9
B9B9B9B9B9B9B9B9
B9B9B9B9B9B9B9B9B7B9B7B9B9B9B9B9B9B9B9B9B9B9B9BF
AD6E67556177677676878C919791918A8983807C81817C7C
8073716C66686D7068686F67566E636D636165685E525B5F
5C5960585D505153576070747A89966EB9B9B9BBB9B9B9B9
B9B9B9B9B9B9B9B9B9B9B9B9B9BBB5B9B9B9B9B9B9B9B9B9
B9B9B9B9B9B9B9B9
B9B9B9B7B9B9B9BBB5BBB5B9B9B9B9B9B9B9B9B9B9B9B9B9
E57D6364565D7178708786898B8C88877F7E7E71727A7772
75746D6168526A5F70675D6A665C66586265645C634C4946
494D4A4F484C4E5C616D7388867B6B9FB9B9B9B5BFB9B9B9
B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9
B9B9B9B9B9B9B9B9
B9B9BBB5B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9
B5F6836D6462737A7A808C8F88807D847A7A7E72736B746E
6C626262635F405B5168626363516558463F55544D515053
504D55494D545C6D6B7D677F6E8A59BCB9B9B9B9B9B9B9B7
B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9
B9B9B9B9B9B9B9B9
B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9
B9B5C8795954606672888C8C917C77757773776E706D666F
6E5A6A5E5A6D5F41634C58575255463E5143464D494E4C4A
444D56645E685F8981788256784A9BBFB9B9B9B7B9B9B9B5
B9B9B9B9B9B9B9B9B9B9B9B9B9B7B9B9BCB9B9B9B9B9B9B9
B9B9B9B9B9B9B9B9
B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9
B9B9D97163606B5E637989888B776B6E6D767368656A6C66
69714A62624A6D53485A4D4D5145484942413A4847454948
4D53595D646783696E7B726C8665B7B7B9B9B9B5B9B9B5B9
BCB9B9B9B9BCB9B9B9B9B9B9BBB5B9B5BFB9B9B9B9B9B9B9
B9B9B9B9B9B9B9B9
B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9
B9B9B5FF6E456B7070707D908A7D656A606B6C645D69645D
655E5D505C5B4649504C4B494B49403F37343A383B44504D
4A556D7376787C875F645D7474B4BBB3B9BBB5B9BBB5B9B5
BFB9B9B9B5BFB9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9
B9B9B9B9B9B9B9B9
B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9
B9B9B9B7EC8B385668746F8E9080596D6866736E5A626955
605F5F4E645D5C353451524C4739443D382E2E2E2E384360
6361678072676A7071527E3FABBBC1B5B9B9B7B9BCB9B9B9
B9B9B9B9B9B9B9B9B7B9B9B9B9B9B9B9B9B9BCB9B9B9B9B9
B9B9B9B9B9B9B9B9
B9B9B9B9B9B9B7B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9
B9B9BBB5B5E373414D5E6A8091866154725F5E67624F5E62
51596558545F606247403B55484A424A4F4841474C4D5659
6D847B6E7A544C5E6E765183B9B9B9B9B9BEB5B3BFB9B9B9
B9BCB9B9B9B9B9BBB5B9BCB9B9B9B9B9B9B5BFB9B9B9B9B9
B9B9B9B9B9B9B9B9
B9B9B9B9B9BBB5B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9
B9B9B9B9B9C8CA6F564B51616F9069515A706057554C4752
54545659555467625B525247495153534B5B595D646B6D70
7A70876C5E635262626978B9BCBCB9B7B9BDBEB5B7B9BCB9
B5BFB9B9B9B9B9B9B9B5BFB9B9B9B9BCB9B9B9B9B9B9B9B9
B9B9B9B9B9B9B9B9
B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9
B9B9B9BCB9B9CFB36A5E5A5768669B5F525D6E5D624F4948
535458515657646C657155594B4D5D636465666E75866D60
715A484A67585E6D7165BFB5BBC2BEB2C1B5BFBBB5B5BFB9
B9B9B9B9B9B9B9B9B9B9B9B9B9B9B5BFB9B9B9B9B9B9B9B9
B9B9B9B9B9B9B9B9
B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9
B9B9B5BDB9B9B7D6B06158606C6E7B9566595B66596C564B
43434C534A605F766F85977C717078727F87897A7C656E5D
515253525A67675576BFB9BCB5BBBFB9B5BFB9B7B9B9BCBC
B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9
B9B9B9B9B9B9B9B9
B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9
B9B9BBB5B9BBB5BCD2C9765A536176879A6B735E6F626F77
664D474C4B66677E65829A98849897937E8183747265544E
4B52575B68746D61BFB9B3BFB9B7B7B9B9B9B9B5B9B5BBBF
B9B7B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9
B9B9B9B9B9B9B9B9
B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9
B9B9B9B9B9B9B5C2B9BCE3835A4F607D8E9B7A8480847F80
969875977A7D8995927A969694938587846D66695D564F5E
5E5B635E748F75B9BCB9B5B9BBB7B3B9B9BBB5B7B9B9BCB9
BBB3B9B9B7B9BCB9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9
B9B9B9B9B9B9B9B9
B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9BCB9B9
B9B9B9B9B9B9B5C2B9B9B5F09F60586075958F8EA389A1A1
859D95A7A7A2A3AA979F988A87948A6E71655856635F6F62
6E6D707A61BFB7B5BFB5B9B9B9BBB5B9B7B9BBB5B9B5BFB9
BBB5B9BBB5B5BFB9B9B9B9B9B9B9B9BCB9B9BCB9B7B9B9B9
B9B9B9B9B9B9B9B9
B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B5BFB9B9
B9B9B9B9B9BCB5C2BCB9BCB9C3E4765C6973898F9C9A9DA1
9DA99EA4A69BA2AAA399A08F6D856F666D5F5F5B66726F74
7B807F83B9BBB3BBB5B9BCB9BCB9B9B9B5B9B9B9B9B9B9B9
B9BCB9B9B9B9B9B9B9BCB9B9B9B9B9BFB9B5BFBEB5B9B9B9
B9B9B9B9B9B9B9B9
B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9
B9B9B9B9B5BFB5BBBFB5BFB9B3C5E09887616F7A8F969DA3
A29F99A9A29C928F83888690785B6C6A70678A6A7B787A89
8E86A8B9B9BBB5BCB9B5BFB5BDB9BBB9B9BCB9B9B9B7B9BC
B5BFB9B9B9BCB9B9B5BFB9B9B9B5BFB9B9BCB9C2B7B9B9B9
B9B9B9BCB9B9B9B9
B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9BCB9B9B9
B9B9B9B9B9B9B9B9B9B9B7BEB5B5C2B9DFA8918079829396
9CA59BA7A3A4A09389787B868E8D6C7A93777B7E94AB8E8A
B9B9B9B9BCB9B5BFB9B9BCBBB5B9B5BFB5BDB9B9BBB5B5BF
B9BCB9BCB9C2BCBCB9B9B9B9B9BCB9B9B5BFBFC1B9B9B9B9
B9B9B5BFB9B9B9B9
B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B3BFB9B9B9
B9B9B9B9B9B9B9B9B9BBB2BFB9B5BFB9B9BCB9DFA38D8486
86919A9FA1A6ADA3AF9D9B8492AD81818C9C948598ABBFBF
BDB9B9B5BFB9B9B9B7B5BFB7B9B9B9B7BBB5B9B9B9B9B9B7
B5BFB5BBBBBBBBBDB9BCB7B9B5BFB9B9B3BBBFB5BFB7B9B9
B9B9B9B9B9B9B9B9
B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9BBB5BCB9B9B9
B9B9B9B9B9B9B9B9B9B9B9B9B9B9B7B9B5C2B3BDB9D6A695
B0989DA79EB0A39DA0A3A299A09CACA1939CA2AFB9B5BFC4
B5BCBCBCB9B9B9BBB5B7B9B5B9B9BBB5B9B7B9BCB7B9BBB5
BCB9B9B9B9B9BBB5B5C1B9B9BCB9B9BBB5B9B9B9BBB9B9B9
B9B9B9B9B9BCB9B9
B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B5BFB7B9B9
B9B9B9B9B9B9B9B9B9BCB7B9B9BBB5B7B5C1B7B5B9B9BBB7
B7BFB5B8ABBABEB1A7A1AAB3ACA9A4B1B5B9BCBCB9B5BBC2
B5BBBBBFB7B9BCB9BBBBB5B9B9BCB9BCBBB9B5BFB5B9B7B5
BFB9B9B9B9B9B9B9B9B5BDB5BFBCB9B9B9B9BCB9B5BFB9B9
B9B9B9B9B5BFB9B9
B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9BBB5B9B9
B9B9B9B9B9B9B9B9B5C1B5B9B9B9B9B5B9B7BCB9B9B9B7B9
B3BFB9BCB7B9BBB7B7B7B2C2B9B9B7B9B9B5BBBFB9BCB5C2
B9B9B9B9B9B5C2BCB5BFB9B9B5BFB5BFB5C2B9B3B9B9B5B9
B9B9B9B9B9B9BCB9B9BBB5B9B5C2B9B9B9B3BFBCBCB9B9B9
B9B9B9B9B9BCB9B7
B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9BCB9
B9B9B9B9B9B9B9B9B9B9B9B9B9BBB5B9BEB5BFB9B9B9B5BB
B9B9B5C1B9B9B9BCB9B9B5BDB9BBB5B9B9B9B7B9B9BFB5C2
BCB9BBB2BDB5BBBDB9BCB9B9B9B9BCB9B5C1B7B5BBB5B9B9
BCB7B9B9B9B5C2B9B9BCB9B9B3BFB9B9BBB5B5B9C2B9B9B9
B9B9B9B9B5BFBBB9
B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9BCB9B9B3BFB9
B7B9B9B9B9B9B9B9B9B9B9B9B7BCB9B5BBBDB9B9BBB5B7B9
BDB9B9B5C2B9B5BFBCB9B9B5B9B7B9B9B9BBB5B5BFB9B5BB
C2B9B9B9B5BCBBB5B5BDBCBCB9B5BDBCB9B9B9B9BCB9B9B5
C4B5B9B9BCB5BFBCB5BFBCBEB5B9BCB9B9B9B9B2BFB9B9B9
B9B9B9BCB9B9B5BF
B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B5BFB9BBB5B9BE
B5B9B9B9B9B9B9B9B9B9B9BBB2BFB9B9BBB5B9B9B9BBB0C1
B5B9BCB3BFBCB9B5BFBBB9B9BEB5B9B9B9B9B9B7B9BCB9B5
BFB9BBB5B5BFB9B9BBB2BBBDB9BBB2BFB9B9B7B9BDBCB9B5
C2B9B9B3BFB9B5BFB9B5BBBFB9B5BFB9B7BBB5B9B9B9B9B9
B9B9B3C2B9B9B9B9
B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9BCB5BF
B9B9B9B9B9B9B9B9B9B9B9B7B9B9B9B9B9B9B9B9B9BBB3B7
B9B5C1B5B3C2BCB9B9B9BDB5BFB9B9B9BCB9B9B3B5BFBCB7
B9BCB9BCB9B9BCB9BCB9BBB5B9B9BCB9B9BBB2C0B0BFBCB5
BFB9BEB5B9B9BCB9BCB9B9BCB7B9B9BBB5B9BCB9B9BCB9B9
B9BBB2BFB9B9B9B7
B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B5BFB9BC
B9B9B9B9B9B9B9B9B9B9BBB5BCB9B9B7B9B7B9B9B9BBB7B5
BCB9B9BBB2BBBFB9B3C4B5B9B9B9B9B5BFBBB7B5B9B3C1B9
B5C2B5BFB9B3C2B3C2B9B9B9B7B5BFB9B9B9B9BBB5B9BDB7
B9B5BFB7B9B5BFB5C2B9B5C1B5B9B9B9BCB5BFB9B5BFB9B9
B9B9B9B9B9B7BBBB
B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B5BF
B7B9B9B9B9B9B9B9B9B7BCB5BFB7BBB5B9B3B9B9B9BCBCB5
BFB9B7B9B9B9B9B9B2BFBCB9B7BCB9B9B9B9B9BCBBB9B5BD
B9BFB7B9B9B2C1B5BFB9B7BBB5BCB7BCB9B7B9B7B9C1BBB5
B9B9B9B5B9B9B9B5BFB9B9B9B9B9B9B5BFB9B7B9B9B9B9B9
B9B9B9B9BBB5B5BF
B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9BB
B5B9B9B9B9B9B9B9BBB2BFB9BBB9B9BEB7B3BCBCB5B9C2B9
B9BBB5B9B9B9BBB9BCB5BFBBB2C2B9B9B9B9B5BFB9BFBBB2
BFBBB9BEB9BCB5BFB9BBB3B9B9C1B2BFBEB9BEB5BFB5BFB9
B9BBB9BCB9B9B9B9B7B9B9B9B9B9B9BCB9BBB5B9BCB9B9B9
B9BCB9BCB9B9BCB9
B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9BCB9BCB9B9
B7B9B7B9B9B9B9B9BCB9B9B9B5BFB5BDBBB0BBBDBBB2BFB9
B9B9B9B7B9B9B5BBBFB9BCB9B5BFB9BCB7B9BCB9BFB9B9B9
B9B5BBBBBBBFB9BCB9BBB5B5BFB7B9B5BBBBBBBFBCB9BCB9
B9B3BBC2B9B9B9BEB5B9B9B9B9B9B5BFB7B9B7B5BFB9B9B9
B5BFB5BFB9B5BFB9
B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B5C2B5BFBCBB
B5BBB5B9B9B9B9B5BFB9B9B9B9B7BBB5BBB5BBB5BCB9BCB9
B9B9BBB5B9B9B9B9B9B9C2B9B9B9B3C1B5B9BFBFB9B9B9B9
B9B9B9B9B9B9B9C2BCB9B9B9BBB5B9B9B9B9B9B5C2B9C2B9
BBB5B5BFB9B9B5BFB9B9B9B9B9B9BCBBB3BBB3B9B9BCB9B9
BCB7B9B9B9B9B9B9
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.678571 0.015625 0.97619 0.313244 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00751202 0.0192308 0.00751202 [
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(300) show
81.000000 12.812500 moveto
(deg) show
99.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(.) show
105.000000 12.812500 moveto
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
128 string
128 128 8 [128 0 0 128 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
CBCBCED1CECBCAC9CDCDCABEB4B4B4B7B7B5B5B5B5C0C994
9AB1B0ADAAACAFAAABAFAFAFABA8ACAFB1B3B1AFAFAFAFAF
A9ABAFAFB3B6B6B6B6B6B6B4B5B2AFB1B4B2AFAFAFAFAFAF
AFAFAFAFAEAEAFAFAFAFAFB8C6C59A9BA8ACAFABA8A8ABAD
ADADADADB1B4B1B2B7B8B9BBBBB7B8B7B0AEA8A4A7A8A7A5
B3BEA8A9BCC9CFCE
CBCBCED4D2CAC5C4CDD0C5BCA7B4B4B8BAB5B5B5B5C2D89B
8CB0B1ADAAA9B2AEABB2AFAFACA4A8B2B1B3B3AFAFAEB3B2
AAA6B3B0B3BABAB8B8BABAB4B7B6ABB1B6B6AFAFAEAFAFAF
AFAEAFAFAEADB0B3AFAFAFB8D2CB998EBCA8AFABA8A8ABB0
B0ADACACB0B4B4B0BABCBABEBEBBB5BAB0AEA8A0A2A8A89E
9DB9B6A3C3C9D0D2
CCCDCFCDC9CFD6D2CACFD1C5B6A7B5B5B5B5B6B5B4B6BEAA
82D2B4ACADACABA8A5A9AFAFAFAFABADB8B2ADAFAEACA5AD
B2B0AEB5B2AFB2B5B0AFB3B6AFB4B6AFACABABAFB0ABAFAE
AFAFAFAFAFAEAAA8AFAFAFAFB8D2B8697BC9B2AEA8A4A5A8
ACAFB3B3B2B0B0B1B0B4B4B5B1B5B8B5B2ACAEACAAA5A4B4
CDB49EA7B9CFCDC7
C7C8C8C7C7CAC5C7CBC5CBD5D3BEA4A7B0B5B2B7B4B3BECF
9674B8B0ABA2A3ACB2B2B3AFAFAFABA6ACB6B3AFABA9A5A7
A7A1A1A6B0B3B0B2B3AFB0AFAFAFB0AFB1B6B4B0AFB2ABAD
ABABAFAFAFAEAEAFAFAFAFAFAFB2C5D38F74BCA4A8ADA9A4
A5AAA4A8B2B4B6B4B6B4B4B4BABBBAB1B3AEAEABAAA2B3B7
B7CFABA4B3BFD1D6
CCCBCBD1CFCAD4CFCCD1CDC6C7C9C4BEAAACB1ABAFADAFB7
BEA1A6ACADA8A8A8A8A4ACB3B0AFAAA4A8AFAFB2AFACAAA1
9FA3A1A0A5ACB2AEB4B4B4AFAEAEB1BABFB6BABDB8B3B8B3
B8B2AEB0AEAEB0AFAEADADAFADAFB2C5D39892B9AFADADAF
B3AFB0AEAFB1AFB0B0B4B7BABAB7B5B7ADACB1A9A9BDAFB5
B1ABB1ADB7C3BDC5
CBCCCCCDD0D3CECBCBD6D4D4D2CACDC9BCABAFB3AEB0B0C1
D2AC91B0AFACA5A5ACAFA4A9AEAEB3B2AFB2B2A9A9ADAFAF
AFAEABA29FA8AEAFA3A6A5B3B0AFAFAFB3B6ADB2BDBBB1B5
B3B5AEAFB3B2ADB0B6B4B4B2B4AFADB2C5BA84A3BBB6B3B0
ADAFAFB4B2B2B4B5B4B4BABEBABAB7B5B8B5B9C3C9C1D3CD
CDB9AFA6AAC7D0C9
CBCBC7C5C9CBC9D2CFC8CBCCC8D2D2CCCEBFA9A7B2B0B0B1
BBCCB4ACB6B0AAA7A5A9B1B1B3AFA8ADB4A8A7ADA9AEAFAE
ACACACADA69F9DA7A6A7ADAEB3B3B5B0B0B1B6B8B6B2B7B7
B7B7B9B8B6B4B7B4B2B4B0B0B0B1B4AFB2C7BF8A96B3B7B6
B4B3B3B6B6B6B7B5B5B3B5B5BAB9BDB2B2B4AEB7CDBBB3B5
AEC0BEB0BACDCDC8
CBCFD5D4CFCBCCC8CAD1D1CED6D1CAD3D1D1CEBFAEB5B6B5
B7C3C8A9A3D1B4B2ADADA8A8A7A6AAA29DA2A2A5A7A9B3B2
B6B3B3B5B2AEA7A5ABAAA9A6A7A9ABB4B5B3B5B7AFB3B3B2
B4B0B3B2B7B8B2B1B0B3B3B3B3B2B1B3AEB7CFD1B2AEB0B0
AFB1B5B6B7B5B5B6B4B7B8BDBCB9ABB19CA1B6C7C7D2B4B5
BBAFAEB6CACCD0D1
CBCAC9CDC9CCCFD1D1C9C7C5C9CFD3CDD3D1CFCCC0B7B3B6
B4AEB8BE877BBBB1ABA5A8A8A7A3979EA0A09F9C9CA2AFB2
B2B3B3B5B4ABA79FA29F9CA5A5A0A0A0A6A9ADB0B1AFADAE
B0B1B3B5B2AFB5B6B2ADADAEA8ABA8ACAEAAB4C6D1AAA8AE
C3B9B3B6B8B9B7B8BEBBB2B5AAB7A78F96A2BEB8A39CACAD
A3B5ADABC9CCC8CC
C5CACFCBD4D1CDC7CBCDD2D3CDCACCCFD1D6CECECDCCCFCD
D0D1D1CDCCAE94ABC1A4A7AEA5A3A3A4AAAEB0B2AEA5A6AD
B1B6B2B3B3B6B3A8A5ACACA5A6A9A4A19C9B929592929896
989593969899969796969698A1A6A3A3A1A09FA1A3BAA67E
7979D3ADB9B3B3B8B5B1B9B6AA909097979CA0B1ADA1A2BB
B9A8B8BCCCCBCAC4
D7D4D0CECFD4D7D3CDCAC6CCC8C6CBD0C8CBCDCCCFCFCFCD
CDD2CDC9CFD0B497A6B9A9A3A8A8A39C999EA5A8A9A5A5AC
AFB2B9B7B6B1ADAAA6A9A9A9ABA9AFAFABA9AEACA5A19FA1
A1A1A2A49DA0A8A7A8A8A8AFA8A3AEB2ABABABA4A5AAB6B5
B0734A949DB1BDABA69676787E8BA9A6A6A097A8AFAFB09C
B5B09CC7BDD0D2D2
C3C5CFD0C8CBC4C8CFD1CFC6CFD2D2CACECFD1CDD2CCCDC7
CACDCFD3CDCDB99585A49A9EB8A7A6AAA3A3A3A8ADA5A3AB
AFAFAFB2B6B3B6B1ABA6ACB2AFAFAFAFAFABA4A5B3B1B2AB
A4A4AAACB1B1A9A6A5ADAFAFAFAEAEACABADAEB3AFABA8AF
B4B7BAAA7D6E708B8478807A82909AAF9DADAFB1B09DA8BE
B4B1ABADC7C4C8CC
D6D1C6CBD2CED2CFC4C6CBD2CCCDCDD0C7C9CCCDCED3D1D1
D0CBC9C7CACCB9AA9787A1868AC8ABA3A39FA6A7A4AAA9AB
AFAFAFB0B2B1B1B3AFABA6A9AFAFAFAEAFAFAFA9A5A9ACAE
B1ADA4A9A8A5ACB1ADA9AFAEAFABACA9ABABADAAAFAEB2AE
A8A7B0BBADA592626D7B7D7E89888A889BB3A892A5A3A0AE
B4B1C9C3C7CCC5CA
C5CAD4D1C9CDCECED2D6CECED2D2C9CED1D1D2D2CACCD2D2
C9CACDCCC7CABDA7947F91866B6ACBA6A7A2AAA9A8A2A3AB
AFAFAFAFB1B3AFAFAFAFAEB1B1B1B2AFB2AFAFABA9A9ACAE
A9ADAEA6A5A9A9A8A8ABB2AFB2ACA8AFABA9AAACB1ADABA7
ACA39A8983767074736F7A8D838A8D9A9C9EA59DA1A7A1B7
B0B7C1CBC8C7D4D2
D6D3CBC8CCCFCDCACDCCCDCDD1CBD1CAD2D5D1CBD0D2D2CA
D1C9C5CDD1CCC4C4B9978081695855D0A5A69D9BA6A6A9AC
B2AFAFAFAFB2AFAFAFAFABA6A6A9A9AEACB2AFABA6A6ABAC
A8A6A6A7ABA9AAABA9AAAFAAA7A6ACB3ABA5A7A9AAA9A4A6
9A998476736D7687867D777D8C87A09AA7A69889959CA2B7
B0B7CDC9CECDCEC8
CACCD1D3CCCCD2D7D2CFCEC8CBD0CBD5D1C7CBC9CDD0C9D3
CCCBD2CACBC9C2BFBE956C786854404FC79BA2A6A9A5A2AA
A8AFAFAFABA9B1B2AFAEB1B1AEACB1AAA9A9AFAEB1ACA2A6
ACAAADA7A5A8A7A3ACA6AAAEACAEA8AAB1ADAFACA8A8A59F
927E757E71797185898E77778292919A9595A0A6A3A3B79A
B5CCCFCEC5C9CCCF
CDCBC6CACACBD1C9C8C9D4D3CECDCEC9CACDCCCFCCCED0C7
CED2D0D2CDC9C2BABC9F8A766C58473C49D0A09DA5A7A6A7
B2AEB1B1B1AFA6ACB2ABA9A9A6A7A3AAAEB1B1B0A6A9AAA8
A5A6A6ACADA8A7A4A3ABACACA8B0A7B1A9A1989A918D8C89
72715C67828D786F818F97978F7A858D929B9DA6B6C4A6AC
B9C5C9C8CACACECE
C7CDD3C8CACECBC7CCCFCED0CFD0D2D2D4D3D0CEC8C7CED1
C9CACACDCBCCCEC7C39E8E7864564F42352EDBA49DA9A5AA
ADAFA9A9A9ACABA9A9AEA9ACAEAAA7A3A9ACA9ADAEA6A2A1
A3A3A1A4A8A9A1A29E9AA2A6A6A3A99DA9A39A9591847E73
625A64697D8787878D8F959591957E89969A9BA6A8A4A2B7
C9BFB6C4C9C8CAD1
CDCAC9D3D1CCC9D5D3CDC7CDD2CDCAC5C8C5CAD4D5D1CDCF
CDC9C9CBCDC7C0BAB6977C7864535249322E2AD69DA0A0A5
A8A8A9A9A9ACAFA9ABA9A9A9A8A7A9A6A3A5A4A7AAAAA7A7
A4A3A19C9BA1A39EA5A5A2AB9CA09EA299A0988C7B7D5570
63637280868382908880777C808596949596A7A8ABB6CBC4
BDC7CCCBD3D1D4D5
C3C8CFD1D1D3CDC7CDD4D2CEC7C6D1D6D4D3CEC9CBCCCAD1
D3CCCACCCBCCCBBEB89D7F726A5B4F42332832629CA2A8A3
A7A8AAA6A9A6ACB1AEA9A9ACA9A9ABA7A8A7A9A7A7A8A5A2
A2A2A29D9EA09F9A999D979EA59B9F9E9495908758655B56
657A808482858787968B8993968D979A99A7A7A8A7B5BAB8
C1C4CBD1CFCFCCCA
D1D1CFCCD2D0D5D2D2CACCC9CCCDC7C6CDCDD4D0CACDD2CA
C7CDD1C9CAC9C6BFB6A17F706065514933313855C8A0A3A7
A4A8ABABACAEA9A9A9A9A8A5AAABA9A6A5A7A3A0A39BA7A3
A09F9E9B9A939B9A969B9E9C928D938F868375726E4F6260
6364787D7C7D8A8B97A099939CA7A09BA6A7A8A7B3B1BBC9
CBD6D3C9CDD0CCD1
D1CEC9CBC9CDCDD0CACECACAD1CECDD2CDCFCECDD2D1C7CE
D3CFD0D1CCCECBBEA7898470695F534E3E3D3F348AA3A6AB
AAA7ABAEACABA9ACABA8A7A9A6A2A8AAA4A5A6A49DA69AA8
A8A39E9B969589979C99978589898587787F6A606A766C71
81858784807C948386839487968C90A6A6A7AAB8B8C4C8CF
CECAC8D1CFCDCCCE
D1D2D1CBD0C7C9CCD1CECDD1D1D1CDCBD0CDC8CAC8CFCDCA
CDD2CCC8C6C5C5B6AB85777266694F4D4B453E25799DAAAC
AEA6A8A6A6A9A6A6A9ABAAA6A6A5A3A7A9A0A2A3A5A0A49B
9E9B97958B8B9696A29B868D8F877A646C6B6C66646C7472
7683878280777C91909295A7909EB0A6A6A9A1A7C5C5C5CC
CCCBD1D2D1CDD5D1
D1CDCACECED1D1D3D1D1CDD3D1D1CEC9CED4D1CDCAC8CFCF
CECACAD1CEC8C5B09A8A736863514E4F514D3F3364A4A5A4
A7ACA7A8A3A4A9A4A3A4A8A4A5AAA9A6A7A4A6A09A9B9A9F
9C9C9A8C8E848E9C91827D7F7D6E71645E756C6764687064
71818A867F7A898A8C8D888F9A8D96A3A6A6C1CBC2C8CED5
D3CCD1CFC7C8CAD1
D1D1D3CDCAD1D1CFCECDD1CCD1D1D1D1CACDCCC9CDD3CFCF
D0CDD4D4D1C7BEA59085756D68574A534E3E3D327EA5AAAD
ABA4A8A5ACADA5A6A9A4A1A9A49D9F9FA0A69A9F9D9E9C96
95958E877E8A85887F81797F6D725F63657682736B6A6E7D
7B77888592948B84878A808D9DA7ACABA5B3B9C7C7C6C9C9
C8D1CFD0D5D4D5D3
D1CECCD1D3CECACFD1CECDD3D1D1CECCCEC9CCD1CFCFCFCD
CCCACECCC6C3BCA9947E716967535C5452363A2F77A6A3A1
9DA8ADA399A2A3A19F9D9D9E9E9F9A9E9D9B9B9596989A95
948E8A8284828578716C72666E63606A6B747980766A7571
797F7580969B97908A8A8D8996A7AAACBBC9D1C7C5C2CACD
D1D3CEC8C8CBCACD
D1D1D1CECDD4D1CDD4D5CECCD1D1D3D1D1D1D1D1D1CCCFCD
D2D1CBCAD4CDAD9F8B886B6C60585854463A3B3373A6ADA7
AAA4A5AEA1A1A49C9C9F9A979C9B999899999D9896909395
8F8C8E828482786D696A63655B5D5C5A66778880877F766D
6E728A878398998788969C96A2A6ACBBC5BEB7C4CECCCACF
CECCD1D1CFCCCCCF
D1D1D4D3CFCDCFCEC8CAD4D5D1CFCFD1D1D4D4D3D0D1D1CA
C5C8CBCFCECCB591847C6C63545A575637353A3D77A1A3A6
A8A79FA2A59DA19C9999969591919793989898938F8F9090
8E8C81817A7F75676765615D655F595D62717E82777C726E
6D6F76829791909A95958B9B9BA8B7BEBDCCCCC8C0CFCECC
D1D1D3D1CECDD5CF
D4D1C9CDD1CDD1D6D5D1C8CAD2D2CDD3CFCCC9CACACEC9CC
D1D2D1CFC9BFAC908673676B5D5D5251332D35367EA0A0A0
9CA2A29DA09D999A93939592918D85888B9093918D8D8885
87837E81716661695D68674F535A676A686D7D8E9792976B
606D74837F9E98949487879AAAABA8C1C0C1C8C6CFD2D4D1
D1D1CCD1D1CFCACE
C9CCD1CECACBC6C5C7CCD1D1CDCBD2CFCFD0CECDD1D3D1D4
D2CBC8CECBBCA2897F73665A5D5F53413733343A77A69FA6
A6A29E9D94969498958E91918E938E878C8888948D888584
7D7C747D6B56645D615D5650345A5B647C707D868D888F86
78737883828A9695848B8D8EA5B3C4C1C8C1C4CDCCC8CDD1
CECDD5D1D1CDD3D1
D1D1D1D3CFCFD4D5D4D3D1D3D1CDC7CCCECFD2D0D2CCCFCB
C7CDD0C9C5B19B877B68655D55594441373A3A3B7A9C9C9C
969C97989795928B8E898386877C8682828987818689857A
7D79787A6B505D67544F47484449726F677468898F968E92
7B8484828E888D897F7E86A7B2B2C1BDBCCCC6CACECACFD1
D1CDCACECCCFCFD1
D4D3CECDD4CEC9CAC9CDD1CFD1D2D5D1CFC7CCCCCDD1CFCF
D4D2CCCDBCA28F7D716B606751582D43383937476D9C9298
9E9593929995969793908479767F797D7C7B7F84857B7B7A
706D6B795B53575D503C3F52435F6E75706D73788E958F7F
797C7A7B9A998C8B90899995AAC5B4BFC6C8D3D1D3CECCD1
D1D3D1D1D1CECDD2
C9CDD4CEC3C8CFCFD1CEC9CCD1CDCCCECDD0C7CACFD1D1CA
CDCAC9C6BDA38F7A6F61655F6548353C40393655649BACA9
AEADAEA99E9F9C9C9B9A9791817070747A777374717E7773
716962735C515949463941564A586B7B6D6A6C7A8A9D9B9A
8E8276757C9B93848F90A7B9C7C8CCC6CCC8CFCFD1D4D5D4
D1CCD1D3D1D1CEC8
D4D1CAD0D1D4D2CDD5D1D1D1D1D2D0D1D1CFD1CFCBCFD0D2
CBCBCDBEA69588756E6557585C373E3F3C3D4C3376ABB0B8
ADB0A9AFAEAEAAA09FA09998918B7A6C66747677766B7673
6C6B5855745270433A2B35675E4A6A75676F6378828B9C94
8C798673888E9590969F93A8CABFB6C1C6CECDD0C7C8C7CA
CFD3CECCD1D1D3D1
C9CDD0CACEC8CACECED4D4D1CEC9CFD1CACFD1CDCFCEC8C5
C7CDD2C9A1917D7162686358513740423C3C1A7AB1B9B8B6
B6B2B6B4B6B0ABAFAAA09C999B958E8879636C6D7370716F
68614E48674D7A59343B234B794C6777727678728798A8A7
9F7F6C83848589909998A6C7BCB7C5CDCDD4CECDD1D1D4D1
CACFD3D1D1CECCD1
D1CECCD1D2D5D1CDC7C8CAD1D2D2CBD0CECACCC9CCD1D1D1
D0C9BDB599897B695B5A5A5A413A3F405759AFB4B7B9BEBA
BABAB4ADADB4B4AFAEAEADA396999A908876675B696C6768
625950416A655E73392D44415F654F6D7268867B828D9CB0
A082767E7F8D9296939DBBC3B1BAC7CBCECDCFCFD1D1CCCC
CEC9CDD3D1D1D1D3
D6D5D1D3CDCAD2D4D1D4D3D1D0CACCCED1D1D0D4D1D2D6CF
CCC8BEA79481746A585E545A323C3F4B4D78B8B2AFB6B9BB
C0BBBFBFB6B2B0AFB0ABA19FA69F9A9991847D765866655E
624F4B35687F53874D382A5D598C6E7E79776E857B968DAB
A685727A7C7D91ABA79E9BAFC9CFCCD2D1CDD1CCCFCDCFD1
D4D3CFCFD3D1D1CC
C9CCCFCFD1D1CECED1C9CCCECACDCBCBD1C9C8CAD1CCC9D1
CEC5BC9E8F7B796359534F423D3E454356B0B1B6B6B6BBBA
B9BCB4B9BCB3B7B4B3AFB3AAA3A2A29B999188806D545A63
52533F3C4B86725D864765415F6279637C7C6E8B7F859396
B5A4676C89898C999A98A5BAC9C6CACACDD1CFD1D1C9CDD1
CACFCEC9CDD1CCD1
C9CCCFCFD1D1CFCCCDD4D4D4D1C9CDD1CDD4D5D5D4D3CEC6
C6C2AF9E827765625A573B4336395C54AFAEB5BABAB6B4B5
B4B6B5B7B7B0ABAAB0B2AEA9A39F999A9C98928A836E5150
534B423946678B676D7A4C674870756D6C72786A87809395
9A9B88776D7F8994A1ACB7C9B9CACACDCECACFCFD1D3CFCF
D1CCD1D1CECCD1D1
D1D1D1CCD1D1D1CCCEC9CACCCCD1CECCCFCCCACAC9CDD4CD
BEB6A68F7671635059523A38422B34AEB1B4B1AFB1B2AEAA
A2A09F9F9F9D9CA29CA0A1A4A9A3A39E9B98948E8D8B7555
4B4C3F313F5B7A7A6B907B795A4D7184716D6F6F86898D8F
A5B49479878C8289A0BAC7C0CCCAC8C9D3CECDD1C7CCCFCC
CCD1D3D1D1D1D1CE
D1CFCFD1D1D1CCD1D1D1CFCFD1D1D1D1CECACDD1D4CFCDCB
C5B69E8A7A676B524D45403B4585B0B6B8B8B3AFAFA0A2A8
9F9A918D8D8D85909594A99F9BA6A3A0999993908C84806D
413E3B29365076895A6D91727F625A6E84736B7D849288A1
8FA4A58A908591969AB3CCC8CCCED2D2CDD5CFCAD3D1CECD
D3CECDD3D1D1D3D1
D1CFCFD1D1CDD3D1D1D1CFCFD1D1D4D4D1CFCBC6CBD2C9C2
B2ACA17B6C645C51504039433B45B0B0AFB0ADA7AF99756F
677383847B767C6E706F7BA3A29FA6A29E9C99908D8A837A
653A2C2D284E38A482639F8597887571746E806577878A8B
A0A1A7918E9A8C9CB3A6B7C5C7C6C4CBD1CACFCFCFD1D4D1
CCD1D1CCD1D1CFD1
D4D1CDD1CDD1CDD3D1D4D1CDD4D1CCCED4D2D0D1CECECBC7
BBAC8F7A5B61545534453D536BB2ADADAFB1B4938C858395
B19F918B9F9185818B737575AA9F9FA3A0999897918C8381
745E32321C3A505CA07F779475A588687A7F69707C89868E
94A8AB977D7D8799B0C4C6C8C9CAD1CDC7C9CCCECDD1C9CC
D1CECCD1CEC9CCCE
C9CCCECCCFCFD1CDD1CDCFCFCDCDCCC9CACCCDD1D0CDC6B4
A290776C58564D3F49324A4973B4B4B4AFA7B3936C7A8082
72767E7566596168597B685F76B0AFA2A2A2A2988E8F8C86
7D735121203546638F835FA28292AF9C626F707C687F8884
9D98A9997E87838EACC9C7CCC1C7D6D1D1D3D1D3CECCD1D1
D1D1D1D1D3D1D3D1
D4D4D4D3CECACFD1CACCCDD1CACCCDD4D1CDCFD2CECEC6AF
9785705B594C4D443F403C54B5B7B1ABAF9B796859505766
6561635B594D48514E423B3131558BA2A2A19A9C948C8F8F
867562331A1E3F566B9778619B74ADAEA16E836E767B8078
8BA0AFA6909991959FBFC9C7CECACBD4D1CCCECCD1D3D1D1
D3D1D1D1CCCFCFD1
C9CACDCFD1D1C9CCCFCFCFCFCECCCEC9CACDCACCCECABEAE
8F756A534C4F4549464C80B5B5B0B6B6ADA9A29562474447
43415755373C43474D62868E93989CA29F9B9C9D9A938C8F
8A836E4A281343405E7C976B7F7B90BFAE916B787377867C
8099ABAB948D93ADBBC6C5C4C8C9C9CACFD1D1D1CECCD1D1
CDD3CECCD1D1CCD1
D4D1C9CCCECCD1D3CECCCFCFD1D4D3D1CECED2CAC9CAC6A3
81695A5A4F3C4B45445459B1AFB4B2AEB3ADB7B6B9BAB6A9
B1B4AFB2BDB9B6B1A8A6A5A3A09CA3A3A1A09D9A9897928C
8E88795B2A233D5158587A6163846C94AD997D7A786D6D85
8B969BAB988D809DBCC4CAC4C6D1D1CFCFD1D1D4D4D3CECC
CECCD1D1CECCD1D1
CDCFD1D4D4D4D1CDD4D1CECCCFCCCDD3CFCCCBCEC8B2A195
74684D4D4148404846749FB4B6B3B2B4B1B2B0B6B9BBB9BB
B9B8AFB0B0A8A3A1A0A6A4A6A7AF9DA5A6A39F9A98969687
82887C603D2C1E565A717280576E7F95AEAC9F91757F7475
6D8597B39E8D97A3CDC1BDCFCBD3D1CFCFD1D1C9C9CCD1D3
D1D1D1D4D3D1D1CE
C9CDD1CACDCCCCCDCBD3D1D1CECCCECCCECACCCBCECB997A
67525D3D49374C493E8DB4B4B2B5B4B0B2B7B4B6B6B6B7B6
B5B4AEB5AEADA8ABA7A6A7A6A8A8AD9C9B9C9EA097949195
8986846E482A2C3D56586068605E708794B69F7A7B816D80
757C93A79E899094BFC4BBBCD1CCD1CECCCECDD3D1D1CFCF
D1D3CEC9CCD1D1D1
D1CECCCEC9CCD1D1CECDD3D1D1D1D1D4D4D1C9CABFAB9B6F
665A464B4243403F595EB5B0B2B4B6B6B3AFB6B7B6B5B4BA
B4B2AFAFAFA2A3A8A9A5A9ACADA0A5AEADA2A09E9A97928F
8A7E78725733313956586D6877525E60A18198B0857A6E71
8889909E9F8593ABC8C0C3C0CCD1D1D1D1D3CECCD1D1CECD
D1CFD1D1D3D1D1D1
D4D3D1D1D1D1D1D3D1D1CFD1D1D3CEC9CAD0D1CCB299846F
57584F3E414A47396279AEB0B2B6B6B6B9BBB5B6B6B6B2AF
ADA1949DA09A9CA0A2A7A7ACABB4B0AAA0A49B9A9794928F
8F87826F593A17324D5360596E5D564D8298AA927C817D6C
7B8493A2A38F94B8B4D5D7D1D1D1D1D1CFCFD1D1D1D1D1CE
C9CCD1CFCFD1D1D1
C9CCD1D1D1D1CECDD1C9CCD1D1CCD1D1CDCACECBB7906E5C
53404D4140413B387DAEB2B2B6B6B8B3B3B6B4B3B8AEB3C5
9C99977D92A19B8DACA5A7A7A4A5AEAEA9A5ADA19D97938C
8F85797266401B25344D575B6068545E5D9E889AAC78826D
807E8895A6A198C3AFC1AED1D1D1D1D1CECCD1D1D1D1D1D1
D1D1D1CECCD1D1D3
D4D4D3D1D4D3D1CECCD1D4D1CDD3D1D1D1D1D1CDA6846759
46463A46463E37446AAEADACAFB1B5C0B8B8B6B5B4A1737E
AEA89A7B505B7A7B749AA7AAAEAFAFAFAEAF9F9B9B9A9492
8D8D80746352141D2B3F4E55556C51593989819B9B7D8268
69797FA0ADB3B5B1C397D1D3D1D1D1D1D1D3D1D1D1D1D3D1
D1D1D1D1D4D3CECC
C9C9CCCEC9CCD1D3D1CFCDCFCECCD1D2D4D1CEC2976D6247
534A40424733325575B1B0B6BBB9B0B2B6B0B4B3BBB7B4AB
ADACA698989C9F9F8B8297A9AFAFAEAFA9A5B3AEA09A9890
888882786D5E15211C42485646655555356E908A91827B6E
69758692A3ACA094ADD1CFCFD1D1D1D1CECCD1D3D1CECCD1
D1D1D1CECACFD1D1
D1D1D1D1D3D1D1CCD1D1CACFD1D2D4CECED3D1C588665A4C
404849474430355170AEB0AFB1BABBBCBAB7B3B6B9B4AFB9
B5B5B0A79D9FA09C98979BABAFB1B0AFAEAAA0A0A49E9C95
89807E766A5C2E0B253B34654E574B544E598C8EA1926D7C
69787D9AA5AAAE9CADD1CECCD1D1D1D1D4D3CECCD1D1D1D1
D1D1D1D1CECCD1D1
D1D1D1CECCCECCD1D1CFCFCFD3CDCBD1C9CCCFB18363424E
48494A492B352687AEB2B7BBBBBBBBBABABAB5ABB2BEBFBE
C1B5AEAAA5A09D9B9C99A0A5AFB1B0ADB2AFAFA9A0A19E9A
928A7E766C5E40101A3747425A594D4B4B6B7B8E9E906F7A
737378809CA0B6C2CDD3D1D4D4D3D1CECACFD1D1D1D1D1D1
D1D1D1D3D1D1D1D1
D4D4D3D1D1D1D3CEC9CCCEC9CDD3CFCFD1D1CE966A524348
4346482333263469B1B1AFB2BCBBBABCBCBCBCB8B3B6B5BE
B9BCB5AB96979798969CA3B0B0B2B6B2AFADAFAFA8A29B9C
979482756B664F142729464E53565B474C5F748394A27C6E
6B717E9FB39B82ADCECCCEC9C9CCD1D1CECCD1D1D1D1D3D1
D1D1CFCFD3D1D1D1
C9C9CCD1D1D1CCD1D1D1D1D1D1CDD1CDD4D4D090604D4548
494A4B2B212C3C42B0BABABABABAB9B5B5B5BABBB5AEB2B8
B5ACAAA39F969C999DA7AFADAFB0B4B0AEB0AEAFA9A5A39B
9994927D7066592311352D504E49595B4B647F7F90A98178
59746E939BAABECCD1D1D1D1D1D1D1D1D1D1D1D1D1CECCD1
D1D1CEC9CCD1D1D3
D4D4D4D3CECCD1D1D1D1D1D1CFD1CCCFCDCCCA9262464D4C
4B46322B1E342097B5B3B7BAB9B5BEC5C5C1BABCBCB9B0B2
BBB4A89B999C9CA3A6ACB2B4ABADB7B8B4ACADACA99E9E9E
96908C866C625F3F242D3B3D5B4D54565262818A96AA8C6E
5F6F768CB4ABB0D1D1D1D1D1D1D1D1D1D3D1D1D4D3D1D1D3
D1D3D1D1D1D1CECC
CDCCCACFD1D1D1D1D1D1D1C9CACFD1CEC9CC9A815A3A5249
4B4B2E342B5CA8B6B2BEC1B9B9BDBABAB8B5BABABABAB8B9
BBB5ABA69FA0A2A0A3ADB2B3BAB9B1B5B2BDB5B2ADAEA7A2
9E988E8F7D695A4A38363D4E4E5D55585A5B7C9393A5936E
53687684ACBBC8D1D1D1D1D1D1D1D1CECCD1CEC9CCD1CECD
D1CCD1D1D3D1D1D1
CDCFCECCD1D1D1D1D1CECCD1CFCFD1D1D1D3855D493D4B4C
45443B2B5257AEB2BABBB9B9C1C1B9BABEC0B9B5B5BAB8B4
BBBCBBA99FA0A9A8A8A7B0B8BBB8BBBABBB3B1B4B2B0ABA1
9C9C948C806C5C4D35363C464F5B5E5A597F7E8F8F948F65
5D5A7C98A9BFD1D1D1D1D1D1D1D1D1D1D1D1D1D3D1D3D1CE
CCD1D1CECCD1D1D1
C9CCD1D3D1D3D1D1D1D3D1D1CECCD1D1CECD85674D414256
4B3743404275B1B7BABABEC5C1BABBBABCBEBEC5C1BABABB
C1B5ADA59D9BA3AAACB3B4B8B5B8BDB5B0B2BBB8B4B0AFAC
A1969791856F5F4D3F32383D4F555E565482898C93909C68
6F697490B4CCD1D1D1D1D1D1D1D1D1D1D1D1CECCCECCD1D3
D1D1D1D1D1D1D1D1
D4D3CECCCFCFD1D3CFCFD1D1D1D1D1D1D3C6846757504648
413B3E4B4BADB9B4BABABAB9B5BABABABABABFBDBCBABBBA
B2BABAB09E9DA0A9AEAAB8B4B6B7B5BAB8BBB5B1B0B0AFA9
A8A1988F877E6457452E3C3A465D54574F76968F887BAC55
69756F84B1CAD1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D3CECC
D1D1D1D1D1D1D1D1
C9CCD1D1D1CCCFCFCECCD1D1D1D1D1CFCF9984514A5D484F
3743407DB5B9B8BBB9B5BABEC0BABDB9BBB2B3B8BBBEB6B3
B8B9BAB4A49F9BA0A2A8A1B1B3B3BEB8BCB6B0B0B1AFAFAC
A4A697978C7B6E574C2D293E44576154567A8889925D9967
517A8888A6D1D1D1D3D1D1D1D1D1D1D1D1D1D1D1CFCFD1D1
D1D1D1D1D1D1D1D1
D1D1D1CFCFD1CECDD3D1D1D1D4D4D4D1CC6D8B615E4E5944
304F4451ADBBB2B9BEC1BABABEBBB7AFA3B5B9B4B4BBBAB9
BCBBBAB3A8989D979FA5B0B0B3B7AFB0AEB4B2B8B5B9B3B0
A8A0A0978F8570624C3D1B313F5658604F7C8E7E905A7C69
4E7585A0B8D1D1CECCD1D1D1D1D3D1D1D1D1D1D1CECCD1D1
D1D3D1D1D1D1D1D1
D1D1D1CECCD1D1CECCD1D3CFCCC9C9CCCF7465605C57582F
4C418E97B7ADB4BABABABAB9B5B0B4C4AF9AAEAFB8B0B0AD
B5B9BAAE9A95959C9B95A9ACB1AAA89CA4A69C9BA4A8A8A7
ACABA5988D7F735D5647342A324F545F596F8C81785F7B6B
54748DB0C2CCD1D1D1D1D1D1CECCD1D1D1D1D1D1D1D1D1D1
CECCD1D1D1D1D1D1
D4D3D1D1D1D1D3D1D3CECCCECCD1D1D1C5A36651534D5935
474E589D8FA8B8BEBABAB9A8B0A0786D8F98989EACD0B5B0
B8BBBBB4A5908F88A17BA5B8AD9C786E87838C8C95ABAFA7
9D9D9B9A8E8473665146482B2E4C4F565F6A7F72755A896C
5869899DC0D9D1D1D1D1D1D1D1D1D1D1D1D1D1D1D3D1D1D1
D1D1D1D1D1D1D1D1
C9CCD1D1D1CECCCECCD1D1D1D3D1D1D19A86615836555239
319D9D9B8BA3B4B4BCB89F957C77787855728195819EB6BA
B4BBBBB8A7988C8C8E7E47806679935F656082636E8FA69F
A09D9994917D7265544B3919274B534767737D7374637D62
757998ACC3D1D1D1D1D1D1D1D1D1D1D1D1D3D1CECDD3D1D1
D1D1D1D1D1D1D1D1
D1D1D1D1D1D1D1D1D1D3D1CECCD1D1CF925F66583A4A524D
3C5EA49CA3AABCBBB1A48450AFBF8761197353869295ACA2
B2BBB7B0A89A857E728D7766E371791C7D5D7C4065778A9B
A09E9A8F91846F60564A271E212F5B495C6A7C7169658659
7193A0A9D1D1D1D1D1D1D1D1D1D1D1D1CECCD1D1CECCD1D1
D1D1D1D1D1D1D1D1
D1D1D1D1D1D1D1D1CECCD1D1D1D1D1C0FF9E614640444F54
5C7DA39594A7B0B0A88E5A5C5463495C683E5657727D89A9
B6BEB8B2ABA3927A726A7D817D524253345650673E667882
929A978C828169615547391F2E30394D5F6E676B796B8064
67899CADD1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1
D1D3D1D1D1D1D1D1
D1D1D1D1D1D3D1D1D1D3D1D1D1D1D18FA19C5E5154484A52
748F9A8C97A7B2AE967F5A46564B3D37455F635D6C829BAD
B6B6B8B2ACA296887B70656184643031373B46525356727A
7E898D8E7D70605752503F2A33343643606B655E6D747F6E
728AA6C7D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1
CECCD1D1D1D1D1D1
D1D1D1D1CECCD1D1CECCD1D1D1D3D1925A7D5E494C514159
658D9B8E9BABB0AAA596815D3F31292924335D849CADAFAC
B9BCB9AFABADA7999687826151687061482F273D63737177
878D898386735A594F41432E353F37375F75656270798C72
75838DC3D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1
D1D1D1D1D1D1D1D3
D1D1D1D3D1D1D3D1D1D1D1D1D1CCCFC25E713D413F553254
768C8B8793A4AEBBB7B7AEA9A4999599A09F9AA8949DAEB8
B4B5BAB8B2AFA294847F8A94A099726E6F79868B92999A98
929094817A786655534A2E2E2D3C2F495175705F75809375
7A9EC7D9D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1
D1D1D1D1D1D1CECC
D1D1CECCD1CECCD1D1D1D1CECCD1D6E4524C3939414C484A
5E798B858CACB0AEC1C1BABABCA9AB8A797551619EB1BAB7
BEBDBABAB7B6B39C8565575F6F92C6B9B7AAA4A1A2A0A196
878A7A84766C6959424532312A29433D5363675A78839D8C
78A7C3D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1
D1D1D1D1D1D1D1D1
D1D1D1D1D1D1D1D1D1D1D1D1D3CFBFEF633D433B34534955
5F67808289A1AE9CB5C2C4BFAA9D7F56344F89A6AFB2BABD
BBC1BABCBCB8B4B2A07E513944586E9D9BB5BBB1A8A19A96
8176847A6E6663555523413633282C605E6A695F70828188
9A96D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D3D1D1D1D1
D1D1D1D1D1D1D1D1
D1D1D1D1D1D1D1D1D1D1D1CFCFD5B09B7A484D463F404A50
595A66768C9BB2996E80908A7A494A84B2B7BAC0C0C0C0C0
BCBAB9B5B5B7B7B3B4B2A892795536314E5E757F7C7C6C6C
7D85817F71686551454D323822222651625E725D7385767C
7CB2D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1CECCD1D3D1D1
D1D1D1D1D1D1D1D1
D1D1D1D1D1D3D1D1D1D3D1CECCD1AC6854445C534A484451
535B676B88A6B1B6B19B7567709BBDC0C0C0C0C0C0C0C0C1
BDB9B9C0C1C1BCBBBAB9B1AFACABAEAC9A6D4D505B698085
84848B81756C695F403A2D211F1B2254545D6D5C76956978
97C3D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1CECCD1D1
D1D1D1D1D1D1D1D1
D1D1D1D3CECCD1D1D1CCD1D1D1D1B8655852616153534D4F
56586B6A85A2B1B0B4B7BBBAB9B5BAC5C4C0C0C1C4C1C1C0
BDBDC5C1C1B9B5BAB9BAB7B0B6B2AFAFACABABAC9F9B9B92
928C82776A6E6E5F5E3A2B28202A22616A527A766693707E
9BCCD1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1
D1D1D1D1D1D1D1D1
D1D1CECCD1D1D1CECCD1D1D1D1D1B3585350676A5D525250
5253676E7EABB5B6B4B9BEBABDC5BCB6BEC0C0BDBAC0C0C0
BDB6B9BCB5BAC1BABCBEBEB9B2B3B0AFAAA8ACA19F989192
8D8A827C756E68634D3F3B2D1D1F2768756271706187777E
A4D9D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1
D1D1D1D1D1D1D1D1
D1D1D1D1D1D1D3D1D1D1D1D1D1D1BC62515A5B645D575950
524E62667492AEB7B4B4B7BBBABEC5BDBAC0C0C1C4C4C0C0
C0C0C1C5C5C1BABABCB6B6B6B8B6AFADB3AFA8A49E9C9794
8E928A816C6D6B5B50383C261E1B2D5C8B62767863658B74
CCD1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D3D1D1D1
D1D1D1D1D1D1D1D1
D1D1D1D1D1CECCD1D1D1D1D1D1D1CC665E4B55565C565053
4F5860787B98AAAEB4B5B6BBBAB8B9C1C4C4C0BDBABAC1C5
C0C0BDBABABAB9B4AFB3B6B4B1AFAFA9A7AAA9A89F9A9996
8C82817C7B6E64573E452929221B285E817B8D836B5B7EA2
D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1CECCD1D1D1
D1D1D1D1D1D1D1D1
D1D1D1D1D1D1D1D1D1D1D1D1D1D1D47F495C595E5A615354
5A5365778592A6AFB7B8BEBEBBBEC4BDB7BFC4BDBBC5C0BA
C4C5C1B9BABABBBBBEB8B6B4B3ABAFAA9FA1A1A1A09E9895
8E8F817A796D6B59463A2B1D15153D4879797B807A5F67AE
D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1
D1D1D1D1D1D1D1D1
D1D1D1D1D1D1D1D1D1D1D1D1D1D1D4716E4F52635C565655
496768727E93A1ADB3B7B6B6BBBABAC1C0B5BAC1C0B6BEC1
B7B9BABBBABCBCB8B6B8B3B6B2B4AFAEB0A4A9A6A29C9895
8A887E7A726D5C5252341F15251147586369878B909385D1
D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1
D1D1D1D1D1D1D1D1
D1D1D1D3D1D3D1D1D1D1D1D1D1D1D5893F60615557555754
594E6A7A81869FACB2B5B6BBBCBEC0BDBCC1C4BDBEC1BABA
C1BBBABABAB9BABCBBBBB9ADB0B3AFA9ABA8A39F9C9C9892
8C88817970665C4B3E391D1B251B4A5D655D7887889BB9D1
D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1
D1D1D1D1D1D1D1D1
D1D1CECCCECCD1D1D1D1D1D1D1D1D1C2705D504B514D4C55
585F697688919EACB2B7C0BABABEC4C1BEC1BABDB6B6BFC1
B7B9BABBBBBBBABABBBBB2B6B2AFABAAA5A8A09F9C9A9E97
908884766A6061473B282513221D545E62637A8887A0D1D1
D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1
D1D1D1D1D1D1D1D1
D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D595444E4D4B4E4B4A
556670808998A0ABB3B4B4BABABBB7BBB6B9C0C0C1C0B5BD
C1B7BCBBBCBBBBBBB6B2B3B6B4B1B6AFAFABA99F9B98959A
91907D747666543B3424271A2022566C5466749B9BACD1D3
D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1
D1D1D1D1D1D1D1D1
D1D1D3D1D1D1D1D1D1D1D1D1D1D1D1D1B05E4A4C4F4E5050
4B5F70788592A4A8B3BABABDB9BDC0BDC4C1C4C1C1BDC1BB
BDC1BABABABBBCBBB8B9BBB5B0B2AFAFAEACA19E999B9794
918285746D66593C32282329261C5B7B65657890B5D1CECC
D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1
D1D1D1D1D1D1D1D1
D1CECCD1D1D1D1D1D1D1D1D1D1D1D1D1CE8253434E4D4B52
515A6C888F97A0B3AFAFB4B6BBBBBCBBBABDBFC0BABCBBBA
BBB9BABCBBBABABBBBB6B4B5B5B2B0B0ABA8A8A6A09B9892
8A867D74695D4D3C362B232A1E15556D6E758B9CB2D1D1D1
D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1
D1D1D1D1D1D1D1D1
D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D18B37474D55524B
52606B7594A7ABA8B3BAB9BFBEBBBABEC5C0BABBB7B9BAB9
BABBBABCBBBEBEBBB6B3B7B2B4AFAFAEB0A7A4A09E979B97
8A857774615747443132231D132F445F69738CB3C9D3D1D1
D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1
D1D1D1D1D1D1D1D1
D1D1D3D1D1D1D1D1D1D1D1D1D3D1D1D1D1D4B0584B615B5E
53596F81869DAEAFAFB3B5B4B5B9BCBABABBBABDC1BABABC
BBBBB8B6B8B6B6B6B6B8B6B6AEAEAFA9A4AAA69F9C9C9790
8E7B72655F58433B3B2A2C1711414F69737C95A2CECCD1D1
D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1
D1D1D1D1D1D1D1D1
D1CECCD1D1D1D1D1D1D1D1CECCD1D1D1D1D5DDCF864F5F50
5F5A697B8D95A6B2B5B3BAB9BFBDB8BCBABBBBBEBBBBBABC
BBBFBEBFBBB6B6BABFB6AFAFB0AFAFACA8A3A3A2A1948F90
7D7E726253514F32342C1D1534306B65707985B5D1D4D3D1
D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1
D1D1D1D1D1D1D1D1
D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D4AB435A5E
4A66637A8999A4A7A6AFB4B8B2B3B3B9BEBBBBB6BBBBB8B6
BAB4B2B5BAB6B8AFAFAFB0AFAFAFAEADA2A3A3A29C959990
88766960554D5352202023353E8165656F8FACC6CFCAC7D1
D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1
D1D1D1D1D1D1D1D1
D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D4BD71415A
65656F7A8894A2B0B1AFAFB3B8BDB8B7B8BBB9BEBEBEBEB8
B8BBBFB6B2BCB3B6B0AFAFB0AFAFAAAAA9A1A29C998D898A
7D7467605B4E4A414D293038625970667690BCCAC9D1D9D1
D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1
D1D1D1D1D1D1D1D1
D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D4B0874352
5460757B8A99A5A2AFB3AEB7B0B4BAB4B9BAB8B6B6B3BCBA
B4B2AFB4AFACB5AFAEB1B3B1B4B4ACA6A4A19E9D9891837F
706C604F514D4C4040365342566B79758C8D9CD5D9D3D1CF
CCD1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1CFCCD1D1D1D1D1
D1D1D1D1D1D1D1D1
D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D5B2763A48
5D4D6673818E93A3A9AEAEADB4B5B8B4ADB1B6BABCBBB3B4
AFB1AEA7A5A6ABB2B3ACAAAAAAA79FA09D9B94968981837D
716B61594D4950433F4951686869738888BFD3D1CECACCD5
D9D1D1D1D1D1D1D1D1D1D1D1D3D1D1D1D1D5D9D1D1D1D1D1
D1D1D1D1D1D1D1D1
D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1C4A57337
506157717B90A1A19BA7A8ABB5AEADB2B4B0B3B3B4B2B3B6
B4ABA2A1A0A5A9A7A3A1A19F98A29F9A9D9394918A7F7771
6E70604F5B52486153526B6F7373909CA09DCCD1D1D5D9D1
D1D1D1D1D1D1D1D1D1D1D1CECCD1D1D1D1D1D1D1D1D1D1D1
D1D1D1D1D1D1D1D1
D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1A66254
4E5C62656E7592A3B29FA2A1A4B0B3B3B2ACADABB1AC9C9F
9D9F969A8F958E97879A889588878E8789857E7D897E716E
5D605D5C5C664F4060716664707F7EA1BACAD1D1D1D1D1D1
D3D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1CFCCD1D1D1D1D1
D1D1D1D1D1D1D1D1
D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1A94C
3F51556F766B8384909A9CA8AEADA7ABAAA99D9B98A4A496
93988E89868484808C7D7974836D7E767A7A79766A7F7F79
7370685D5466694E465F757E747E96A79CD1D1D1D3D1D1CE
CCD1D1D1D1D1D1D1D1D1D1D1D1D1D3D1D1D5D9D1D1D1D1D1
D1D1D1D1D1D1D1D1
D1D1D1D1D1D1D1D1D3D1D3D1D1D1D1D1D1D1D1D1D1D1D1C9
8C705F5970675B7D9BAAB9B7AFA9A89E9B96939B9993959A
8E84827F7586757B6C767761677E6676666E72705C616969
656A6B6062515C5F6970706A89A39893D1D1D1CCC7D1D1D1
D1D1D1D1D1D1D1D1D1D1D1D1D1CECCD1D1D1D1D1D1D1D1D1
D1D1D1D1D1D1D1D1
D1D1D1D3D1D1D1CECCCECCD1D1D1D1D1D1D1D1D1D1D1D1D1
935076696C8B999398A2959FA7A4A09797978C8B8F97888C
8687747576698775876D78796B756A7775766E706D57615D
61665F625C5D626764687A8FA48EB7AED1D1D1D5D9D1D1D1
D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1
D1D1D1D1D1D1D1D1
D1D1CECCD1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1
D58D446B676D747B7D8B9D9E959A9A978A8F84807F81877C
7D7E72766B5F558365846870706979644E6179645E5C5750
4D51584C5756585474877EBB899B79CCD1D1D1D1D1D1D1D3
D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1
D1D1D1D1D1D1D1D1
D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1
D1D5A772647F8596A7A6A0A194888D8B8D888882837A7984
7563765E6B794953705A7170656355555E475654555A5758
5762645C525E7199808F87727B8EB1D9D1D1D1D3D1D1D1CC
D1D1D1D1D1D1D1D1D1D1D1D1D1D3D1CFCCD1D1D1D1D1D1D1
D1D1D1D1D1D1D1D1
D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1
D1D1A45576625E6B85A1A19D9C818A8287857F757D7C7678
74705B8367647D506067575F5950534B494A4C5951535752
54565D6E798A8A80A49477717A6FD4D3D1D1D1CCD1D1CCCF
CCD1D1D1CFCCD1D1D1D1D1D1CECCD1D5D9D1D1D1D1D1D1D1
D1D1D1D1D1D1D1D1
D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1
D1D1D581385D9B707788A6988F7778737B897D7075797079
75775E6563625659664E59565550494C434146444A54584C
576C726866668C87657D6FA273BAC5CFD1CECCD1CECCD1D5
D9D1D1D1D5D9D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1
D1D1D1D1D1D1D1D1
D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1
D1D1D1D38A3A4790908E95A1987A6E8569787567647D6E62
746A5E636E61593554615949524252413D343938394B5B69
555F818E89899C8A706A8D70C8DDD6CCD1D1D3CFCCD1D1D1
D1D1D1D1D1D1D1D1D3D1D1D1D1D1D1D1D1CFCCD1D1D1D1D1
D1D1D1D1D1D1D1D1
D1D1D1D1D1D1D3D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1
D1D1CECCD5A0454D6B8895A9A4796373826C7E8369657867
606F6E5E6573624F3E4454674D4A484A4A393C3F3C3E4D64
7D7B6B92895A6C767B6B5A88D1D1D1D1CFC9CDD8D9D1D1D1
CFCCD1D1D1D1D1CECCCFCCD1D1D1D1D1D1D5D9D1D1D1D1D1
D1D1D1D1D1D1D1D1
D1D1D1D1D1CECCD1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1
D1D1D1D1D1BC72455460789CA09C56687A7A6168615A5D69
63636966616A6F615F4E514653595253585F5352585E6C71
789A9A876969556A797D70CFCACCD1D2D1DAC9CDD3CFCCD1
D5D9D1D1D1D1D1D1D1D5D9D1D1D1CFCCD1D1D1D1D1D1D1D1
D1D1D1D1D1D1D1D1
D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1
D1D1CFCCD1D1B3725A625B677A90864E647A725F63485455
615E66576860796B6A5D535D515F65645A5D65727982748E
98776471775B6D80525FD9D5DCD3C9D1D5CCD9CECCD5D9D1
D1D1D1D1D1D1D1D1D1D1D1D1D1D1D5D9D1D1D1D1D1D1D1D1
D1D1D1D1D1D1D1D1
D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1
D1D1D6DBD1D1D3A960506D747982917A516D6978646B4F4E
56576959656D79766F635E4942465961695F6A7E89848A6A
6460544E596B736577D9CFCCD5DDD9D1D5D9D1D3D1CFCACC
D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1
D1D1D1D1D1D1D1D1
D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1
D1D1CECCD1CECACCAF4A3D6A6F9599907C5F6D6171676F51
424456506471707D8AC7AB92898E818697B1AD9A8970635A
5A5D586A75835264D9D1D8D9D1D4D3D1D1D1D1CCD1D5DDD9
D1D3D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1
D1D1D1D1D1D1D1D1
D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1
D1D1D1D1D1D1D4D4D1CD874A5A6C8BAE9F7D6F6F66655D7E
7C2D000410456F7E7275A1A1A4ADADC29584837E67685B66
4D556974732575CFCDD1CCD1CECACFD1D1CECDD3D1CFCCD1
CFCFD1D1D3CFCCD1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1
D1D1D1D1D1D1D1D1
D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1CFCCD1D1
D1D1D1D1D1D1D4D4D1D1D5961F447992AAB08E8E9196AA94
93B4CBD9C8BDAEA3A0AEA6ABC0A792827979656E6D5F5851
6D757A4D63D9D3D6D9CCD1D1D1CECCD1D3D1CECCD1D5D9D1
CECCD1CECCD5D9D1D1D1D1D1D1D1CFCCD1CFCCD1D3D1D1D1
D1D1D1D1D1D1D1D1
D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D5D9D1D1
D1D1D1D1CFCCD4D3CCCFCCD1C26C3E6F8CA7AEBEBEB5B0AB
B0B1A2A2A9AEBDBBB6B1AF8C92A67F89796F5C67646B7A87
8E6B4788D1CFCFCECCCFCCCFCCD1D1D1CCD1D1D1D1D1D1D1
CFCCD1D1D1D1D1D1CFCCD1D1D1CFD1D9D1D5D7C9CCD1D1D1
D1D1D1D1D1D1D1D1
D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1
D1D1D1D1D5D9D5DDD9D5D9D1D8CF81265380A3B6ABABB0B8
B9BBC6C7C1BEC0C0B7BCAE9B7F738873656E60537582946B
3F73BAD1D1CECACCD1D5D9D6DBD1CCC7CFCCD1D1D1D3CFCC
D5D9D1D1CFCCD1D1D5D9D1D1D1D5D9D1CFCACFD5D3D1D1D1
D1D1CFCCD1D1D1D1
D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1CFCCD1D1D1
D1D1D1D1D1D1D1D1D1D1D2C9CCD4D4D19D341F64A7C6C4C4
C0ACADB5AAA193897B85919A745954626F7897A690553A81
C7D1D1CFCCD1D5D9D1CFCCCECCD1D5D9D6DBD1D1CECCD5D9
CFCCCFCACFD3CACCD1D1D1D1CFCCD1D1D4D7D9D5C7D1D1D1
D1D1D5D9D1D1D1D1
D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D8D9D1D1D1
D1D1D1D1D1D1D1D1D1CED1D9D1D5D9D1CFCCCF9D4B6E9FAB
ACCCC5BDBEB6AA8B7D727377999A87ABB99B675E94C6D7D9
DBD1D1D5D9D1D1D1D3D5D9D3D1D1D1D3CECCD1D1D1D1D1D3
D5D9D5DDDDDDDEDBCFCDD3D1D5D9D1D1D8DDD9D5D9D3D1D1
D1D1D1D1D1D1D1D1
D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1CECACCD1D1D1
D1D1D1D1D1D1D1D1D1D1D1D1D1D1D3D1D4D5D9DBD1A9626C
787394A4ADB1B9D1DACFB8B4BAB39A625E7EA3C3D1D4D7D1
CACACACCD1D1D1CECDD4D1CCD1D1CECCD1D3CFCDD3D1CECA
CCD1D1D1D1D1CECCD5D5C7CFCCD1D1CECCD1D1D1CCC7D1D1
D1D1D1D1CFCCD1D1
D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D5D9D3D1D1
D1D1D1D1D1D1D1D1CFCDD3D1D1CECDD3D5D6C9CCD1D1CEC9
C7BFBBB6B7C2AD91848C958F8F92A5C0CCCFCACCD1D5DCD4
D5DDDDD9D3CFCCD1CCC5CCD1CFCCCFCCCCC7D6D9CCD1D3D5
D9D1D1D1D1D1D1D1D1D6DBD5D7CCD1D1D1CFCCD1D5D9D1D1
D1D1D1D1D5D9D1D1
D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1CECCD1D1
D1D1D1D1D1D1D1D1D5D6CCD1D1D1D1CCD1D2CCD1D1D1D3D1
D8D9CFCDD3D1CEC9C9C9CFD4D1D1D3D1D1D5DDD9CFCCD4D4
D1D1D1CFC7D4D3CCD5D9D1D1D5D9D5D9D4D5D1CFD1D1CCD1
D1D1D1D1D1CFCCD1D1CECCD1D4D4D1D1D1D8D7CACCD1D1D1
D1D1D1D1CFCCD1D3
D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1CFCCD1
D1D1D1D1D1D1D1D1D1D1D1D1D1CECCCFC8CCD9D1D1D1CCCC
C7D1D5D5C7D1CFCCD1D1D6DBD1CECCD1D1D1D3CFD1D9D4D3
CCD1CED1DBD5DEDBCFCCD1D1D1CFCCD1D5D6C9CCCECCD1CF
CDD3D1D1D1D4D4D1CFCCD1D1D8D9D1D1CECCD6DFD4D1D1D1
D1D1D1D1D5D9CCC7
D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1CFCCD1D1D8D9D1
D3D1D1D1D1D1D1D1D1D1D1D1D2CCD1D5DEDBD1D1CECDD2D1
DBD1D1D4D4D1D5D7CCD1D1CCD1D3D1D1D1CECCD5D9D1D5DC
D4D1D1D1CACCCECCD6DACACCD1D6DACCD1D1D1CFCCD1D1D4
D1CCD1CFCCD5D7CCD5D7CAC9CCCFCCD1D1D1D1D1D9D1D1D1
D1D1CFCCD1D1D5D9
D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D5D9D1CECCCFC9
CCD1D1D1D1D1D1D1D1D1D1CED1D9D1D1CECCD1D1D1CFD3D6
CCCFCDD8D7CCD1D5D9CCC7CFC9CCD1D1D1D1D1D3CFCCD1D5
D9D1CECCD5D9D1D1CED1DEDBD1CED1D9D1D1D2D1DACCD1D4
D4D1D1D8D9D1D5D9D1D5DDD9D1D5D9D1D3CECCD1D1D1D1D1
D1D1D7D4D1D1D1D1
D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1CFCCD5D9
D1D1D1D1D1D1D1D1D1D1D1D3D1D1D1D1D1D1D1D1D1CFCFD3
D1D5D6CDD7D3CCD1CFD1DBD5D9D1D1CFCCD1D1CFD5D7CDD3
CFCCCFCCD1CFCCCFCCD1CECCD1CFCCD1D1CED1D6D3D7CCD5
D9CFC9CCD1CFCCCFCCD1CFCDD3D1D1CECCCFCCD1CFCCD1D1
D1CED1D9D1D1D1D4
D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D5D9CFCC
D1D1D1D1D1D1D1D1D1D1CECACCD1D1D3D1D3D1D1D1CEC9CA
CCD1D1CED1DDD9D1D7D1CCD1D1D1D1D5D9CEC9CCD1D8D5C7
D4D4D5D9D1D7D5D7D4D1D1D1D3D5D9D1D1D1D1CECAD1DCD3
D1D5D9D3D1D5D9D4D4D1D5D6CCD1D1CFCCD5D9D1D5D9D1D1
D1D1D1D1D1D3CCC5
D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D5D9
D3D1D1D1D1D1D1D1D1D2CCD5D9D3CECDD1CFD1D1CFCACCD5
D9D1D3D1D1D1D1D1D1D7CCD1D2CCD1D1D1D1CFCCCCC7D6DA
D1D9D3D1D1D1D5CCD9D1D3CECACDD2CCD1D3D1D2D1D5C5CC
D1D1D1CCD1D1D1D5D9D1D1D1D1D1D1D5D9D1D3D1D1D1D1D1
D1D1D1D1CECCD5D9
D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1CE
CCD1D1D1D1D1D1D1CED1D9D1CCC7CFC9CACDCACCD6DFD4D1
D1CECCD1D1D1CCC6CCD5D9CECFD4D1D1D1D1D5D7D1D9CED1
D9CCC6C8C6CCD5D9D1CFCFCFD1D6D1D7C8C6C8CCD9D5D9D1
D1CCC6CCD1D1D1D1D3D1D1D1D1D1CFCCD1CECCCFCCD1D1D1
CFCCCFCCD1CFCCD1
D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1CFCCCFCCD1D1
D3D1D3D1D1D1D1CFCCD1D1D1D5D9D6DBCFD3DEDBCED1D9D1
D1D1D1D3D1D1D5DDD9CFCCD1D5D9CFCDD3CFCAD1D9D1D1D1
D1D5DDDDDDD9CFCCD1CECCD5D9D3D1D5DDDDDDD7CCCFCCD1
D1D8DCD4D1D1CFC9CCD1D1D1D1D1D5D9D3D1D3D5D9D1D1D1
D5D9D5D9D1D5D9D1
D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D4D4D5D7CCCE
CCCECCD1D1D1D1D5D9D1D1D1D1D3CECCCECCCECACCCFCCD1
D1D1CECCD1D1D1D1CFCFD4D1D1D1D8D6CACFD9D9D1D1D1D1
D1D1D1D1D1CFCFD3CCD1D1D1CECCD1D1D1D1D1D4D3CFD4D1
CECCD5D9D1D1D5D9D1D1D1D1D1CFCCCFCFCFCFD1CFCCD1CF
CDD3D1D1D1D1D1D1
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.343006 0.321429 0.640625 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00751202 0.0192308 0.00751202 [
[.5 1.0125 -17 0 ]
[.5 1.0125 17 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
69.000000 12.812500 moveto
(deg) show
87.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(.) show
93.000000 12.812500 moveto
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
128 string
128 128 8 [128 0 0 128 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
9D9EA7A1979E999BA9949F768B8B8C94878C8C8C8CB39434
AE927F867D8C877B8D8886887C828C878F8A848786878788
77908787938D8D8D8D8D8D888F82878C9082878787878687
8787888784898786888786A6A88A439C828C877C82828A86
86868686918A858D97889590908696858185787F8582807D
AB925E9FAAA6A597
9D9FA29F9EA19995A3A09784798B8C908C8C8C8B8CA0AB3E
9C90818581838781888C87878281838C8F87878787808A8C
7F828D888D8E908C8B8D93858D8D828A8D87878A85878687
878787878686838D87878796B09D4370A587877C82828686
8B8686868F878C87958D929191908C8B80867E7E7D82858F
927B778CB5A6A19D
9D9F9F9D9DA3A39D9CA3A29982768B8C8C8A8D8B888FA76E
4EBB8984817E86878287888688867D8698878486837F8187
8482878D8B888B8D84878D87878E878B888784888A828787
87878787878582878787878796A5815255AB878287807D82
8C82888E8F868C868C8B8C8F8C8F878A8384878481858999
A5737382ADABA397
9B9B9DA097A19B96A39B9DA29F85867D828D878B888B97B0
467096878179828787878D8787867C7F918B87877E877B7E
817E7B828C8D878B8787888787878B91888D8A8D88878489
878287888787878887878787878CA5A94A56A68187868184
838182878F878F878F8C908E908C8F8288848C81987E8E98
81A1737DAE9CA3A3
9D9E9DA49F9EA299A7A19C9B979F958D778588828A848DA9
8D59968788798282877C878D8787818187878388838B807D
8080797985888C8088878F8787878B9193878D9B8C84908A
9084858C8784878B8787838B83878CA5A9428B958A878787
87878B878A878D868B8D958E8F8B8C8787819590948B8B9B
6C9F7181B5A1919B
9DA099A2A19FA09F9BA6A29FA3A198A0887C848889878D9C
AA70758C8A7C817D878780888782878C82838883818D8787
8786837D798087847B89828D888787878D8A8A918B8C8C89
8D8B858D898887888F88878B878A848CA5845D81998F8A86
848A8A8D8A8B8D898D8C91948F8F87868A839FA89E80A394
91A4698EABA29D98
9DA3999D95A397A69BA197A1A19DA3A19D8E807C8A8B898C
9BA775848F86837D8183868788827D82877E83877D91878A
87868789787D75887C897D8A88868F87888A908A878C8B8B
8C8D8B918B898B888B888888878989878AAB8B6B778D8B8B
878F8A908D8B8E8992868F8F8F868C7A818EA891A96E9386
8B9A78AAA69DA395
9DA3A4A29BA597A199A39AA4A3A19EA5A1A19989858F8E8F
8E9F987663B686868082828180797D7D7D7D7D817D8C8D8B
8E8A8A8F8187768181837F857E7F87888C888B8D82888987
8E828D8A878D8988828888888886888D8190AFA071878988
878B8A918E898D90908690908A8272807593A48A8D919085
9A827BB5A79AA49C
9DA299A39DA199A39E9C9E989BA1A59EA5A199A18D978E92
928E998B556D9089807D82827D7B73837D7F817C797C8D8C
8F8A8A8D89847B76818176857E7C7D7A827C82867E868282
877E8A86828687878282828B7F8582877F8194919B857375
999288928D8B8F92918F87866885797874869F8573818891
867D8FA3A59D9A9D
9B9E9F9DA7A19B999E9BA49E9D9BA799A1A997A798A59A9D
A79E9E9DA1706974A975798B7E8075817E888B898378878D
8B91888D8A87877A83877F877E86817C797B737772757B75
78747B75787D767977787D80758A808078827C788C917662
6E43BF83918C8C8D7C747C7C6F81817A6E8187878A7B73AE
886BAF98ABA09E95
A3A0A797A49FA4A09E9E96A09F9C9E9C9BA598A59AA5999E
A29DA397A49C625D987E7D8A82817B7C728085848378848E
878D8B908A87877E7E838787828787878283808A807D8078
7D7F81827D7E8183818787877D87838B7D8B81828283918A
84388361708190726B6854607277947A75A569828F759198
7C8787AA9AA3A3A3
9997A3A199A09B97A0A29F9AA59DA399A0A2A19DA3A19B9D
999DA19DA29B696B5D8379739B827D857385827F887B818E
8787888B8E878F83827E878B8787878787827F808A878B81
807D8486858687827A8F87878783838B7D8C818E87818782
8B8999746159445E6A5F60686D6E7D857CB45E8A9462A19D
73B27DA0979D9BA7
A3A19C9D9DA79D9F9C9C9DA3A198A1A19D9DA197A4A5A19E
9B9D9D999F9B71815968835168AC867E79847E80817F848D
878787878F838B8787828287878787868787877B83838B83
87857D8083838786808C8786877B8A877D87818B87828782
81798385706957515D5C6D656B6977757CA35D7B906B9F86
84AD9B9E94A89B9E
9B9EA19E9BA797A79BA997A79DA397A7A1A19D9FA1A19DA3
979BA0A1979C7D88674577504955C37986797F86827D828D
878787878B8687878787838787878C838B87877E83838783
818781818383837F83878C81897F8B877E818487877C8679
806F6C59555B655C5D56617168747C77827D6A8180868F86
93AB98A096A4A29B
A3A09F9A9AA99BA195A798A1A29DA1A19DA29E9DA79BA39E
9B9F98A29A9E83A975495E5A463848BB8579827B847D8488
8C878787838B8787878782827E878383878B8782827B8387
818181808681818383818F7D877E868D827D83817F7D7C78
6F6F574B62615B6C7158586B7768856F88767B7777996B96
A59F9E98A19DA597
9C9EA39F9BA79BA49BA99D9B9DA19DA2A197A398A1A09D9F
A19DA39A999B83A4735B40604436294BC17986798A7D7D8C
878787878283878B878387878383858487878783877F7D81
8480887F837D8179897F898387838187857A837D777C7777
605149677260477672725E65656877737F708E81987C7C90
A79CA09E9C9BA79A
9DA3989BA19D9B9F9E9EA2A599A599A0A198A59A9BA2A199
A19CA69D9E98928C84634A5B4539302C42C784708D7D8189
8B83878787877E878B7E83877E7F7D84898786897E7F8081
7F7D8383867C8176818188877A8C778C7D7471746969645F
454D466D75684F6F697B6E736A586B7978778A8298868E9A
9991A0A49D9BA79D
9BA1A59BA195A39DA1999EA799A49BA6A19FA79D9C99A2A1
979B9F9E9D969D849D4C5C573F3B3B302428D47C80828187
86848383838B7E878383838781847F7D8384808B837D7D7D
7C7F787B8383787A7F75868076807D7B7D79706F6557564F
414F5E676467687368686B756E7369747385828285988B93
9F9695A39D9BA1A1
9DA19EA5A1999DA4A59C98A19CA29E9D9B9B9EA1A49E9EA5
989C9D9D9E98907D984159573F393F33202028D979867A85
81848383838787877E8383838183837D7F837B8581827E7F
7D7F76777A7F7776837C7E886D7C7D786F7D6D5C4E57355E
50576E656467647D6461616E657477727E818282909E9D98
9CA0A19EA59EA1A7
99A197A99EA59C9D9EA29BA09E99A1A6A2A59D97A0A199A3
A0A19A9B9E9D94868B4B594E48413A2C201E27C879868281
8282897E877E878783837F878381857D83817D817B837D7D
7D7A7A77777977747B846E77737878776472615C32543D54
4C696F60636A6E73767065788169797F8182818C8F8FA296
9F9C9E9EA599A1A1
A19E99A2A0A1A79DA3999BA3A1989E99A39EA29DA19D9DA1
9D9EA1979E989485735D594A4251363321253457BB858287
7C818D7E87838383838180817F83867D807F7F7781748481
7A767A727468787E807865717369746A58624D544F435652
5363665C61637865787C6E797A758A8181828A91988DA5A0
9DA1A59D9E9CA59E
A19D97A2999EA2A0A197A1A1A19D9D9FA599A09BA4A197A4
A599A49B9D989A7C6455604A4E4C333B29333624CD8A828C
7B81897F84857F84858181807F7E83847A7F817D777F7683
7C7977706C6E6E8B825E696E6E61605D4E684748595B5C51
6D6F696160578E5976628662747B818181868BA39897A6A5
95A1A1A199A3A19D
A19DA19DA19D9DA1A199A5A1A1A1989DA79B9A9B99A998A1
9D9DA39C95919869734E554D4C4C313C393A2C16E87D8686
837F847B81877B818383817F827F7D81817A7D7A777F7A77
79776D6E616D80826C61676F695C544253634A4D4F585652
6C6F695E605D7B637A647D7874818F8081949191999BA5A1
97A5A19D9EA1A7A1
A19BA197A7A19EA59EA19EA5A1A19D99A2A29E9E9EA19AA5
97A1A1A197928E616E564F4B4A37344243392922E07A8B7C
7E87817F807F80807D7A857F7B817F7D86768076777A7478
77736F6169687C725D6160635A485446516E4C534A4F624F
64696A6571626F636F6969778674867C8F93A49B94A0A4A1
A5A19E9F9D9BA1A1
A19EA59BA19E9EA59D9EA1A1A1A19EA19A9EA19D9EA59AA2
9CA2A2A19C92835F625A504D4F38384F39282A24E67A8A79
8684817883857E7D7F7A7D817A777A7C797D7478777A7374
6E6F695E6176635D5766586148554B4D506B65584A575E5D
6655716A846E6E5C69765D7394828C8B989791A093A29D9F
A1A19AA1A4A1A4A5
A19DA19EA59D9AA5A19D9EA5A1A19DA19D9DA1A19AA59A9E
A1999EA29B8C776469564C4C4F344B4335202F21E57E8178
817F8877738578777C77747D777A747A747D74717172796F
6E6E645C696A58525554534850524152566D65615B515A55
5E62696088796F62777860778A8196959B989FA0999D9DA5
9EA59D9B9A9CA19E
A1A1A19D9EA2A19EA1A79DA1A19EA5A1A1A1A19EA1A19A9B
A69AA39EA1965B67645E4251443A4F3930273424E0798A7D
857A7F88737F7A7577777472757B71747877776E726D736F
6F65685C715D504E504E494C4B43414C566A6D606C585E4C
555A716E73757768756B73818B869E949F969598A7A19AA5
9DA1A1A19AA1A19A
A19EA2A59A9EA59D9B9EA1A7A19AA5A19EA2A19EA79E9E9E
9D97A5979F8E5F66585945533648483D22262F2DDC718778
867D76817A747D7471787170706C6F6F7973756C6F696D6D
6A6561615A5752494F504A484B45484F51626D6F61695245
53566D687C76767668696D918687A19893A898A19AA59DA1
A19EA5A19D9DA79A
A2A19D9E9E9DA2A3A4A19BA19DA39EA59AA197A1A19D9DA1
9E9DA4999D716B615C4F45553B5337391D222C2ADF708379
7D7A7A74797477746C726F726E6964696D6D756E69696961
64645A674A484653475450303C45575D545B687973717142
48606369648C76686869689A8C988B9F929D9CA797A4A7A1
9EA1A1A19E9FA19D
9DA1A19D9AA09B9B9DA1A1A19B9DA0A599A799A59EA59EA1
A09F97A0916B7156594D48434350342D242A2C2ECA797D7E
7F78767870746E7470686D6F657068647069657469696160
615F506E4337524F46473B3324595C4D6551667379657F50
57675B6F608569695F6C7B908F9D9298A3999CA7979DA5A1
9D9DA79EA19EA5A1
A1A19EA59AA2A1A4A2A59EA5A19C9DA197A3A0A1A3A19AA0
9D9D9D9B7C6C6C5159474C4340462A2E282E2D2EC4787981
7278717B71746F6C70646063665C67616767666863676059
5F57576C3F31555237373039354F695055584F7E78766A61
5C6B62667B765D6F5C727796AB84969B98A79CA19D9AA5A1
A19BA19DA19AA59E
A2A59D9B9FA598A19D9E9EA5A19DA79E9F97A09BA7A19AA2
A19D9F9672685F4F554A475535451839292D293FB4857981
7978757277777374746C625C555C5E605F5C6262655C5C5B
534E53683139514632292F523054695A51535575777F6A66
546456579A765C6F757681A09A8D91A099A4A59EA59DA1A1
9EA5A1A1A19D9E9D
9D9EA29E99A19AA5A19D9DA1A198A59D9EA09D96A99EA199
9C9E9C8376695E5151414C4A46331D3A302B286CA686907F
878487817C7F727A7974726B5A5851565F5B5A5B55605B59
524C48633444552D2F27385F2A535E624C4E596C718A7974
61614B5F80756869896495BD8E93A69BA79AA599A4A1A4A2
A1A19EA5A1A19D9B
A2A199A79EA1A39DA7A1A1A19E9DA79E9EA59E9BA59AA19D
9DA09E7367615F4E504744404C1E2D3A2B2D5E838C8B8D8D
828E7F8D84857E7F767A73746B6958534A59595A59535E55
4C4F3B405E3C6E1F291E2B6C413B5D6D42624C6972818176
6347656273687876806CA9978C9A9F98A59D9DA19D9B9D9A
A2A59DA1A19EA5A1
9D9EA0A19D9CA197A4A1A7A19D97A4A19AA29E9EA59D9B9B
979A95825E635549445048403C1E3B37298662858F958C8F
898F838D8A8A81877F7F747174756964524551535D505951
4B4930347A288928212F194B702A636A486E5760757C9582
6B4558696D647C77757EAF908FA39DA59DA799A5A19EA2A1
9AA2A5A1A19DA1A1
A19DA1A19DA7A19B9D9CA1A19D9F9DA79D9AA19DA1A1A19E
99947C7C576253474049434329263A2E5BBD8E859391958F
908F8789828D858787817D7B7476736B644A5A3C52524F4E
483F35307D3966491B21344A6943505B5750715F6D74888E
754A4F6C5F728A7B6F7DA4A2969B9CA599A59AA59E9EA1A1
9D9D9EA5A1A19EA5
A3A79EA59BA19DA79EA2A59E9C9E9BA79E9EA1A7A19BA999
9A8E7D6C5A5E4F493B493B471B30353FA28C92878D8D958A
988A9098828A858788817C787D7974746B5D644A3C514D44
4B343723707530802234205F438047675F585F6B598A689C
8A404C6C5E6F7C887A81989F9FA39DA6A19EA1A19A9EA59E
A2A59AA2A59EA1A1
9CA59AA5A1A199A2A19DA19D9A9EA09EA19D9CA1A1999E96
9C83865B5F5355433D43382F253B3D8A878B8F8D8D8A9286
918A8A91898288898D8289797E777A77746B645E4A3A404C
3B392C2A4D8A3C57672A4F3B485F574F6567467B5B806989
8D693E5171756984818EA08EA39F99A59E9EA59EA19D9EA1
9AA59D9D9EA1A1A1
9DA19AA5A1A19AA19EA2A2A2A19D9EA19EA1A2A4A2A59D8D
8E85785B575048434343242F282FA3888C888A8D8F878683
84888587877C83828781887E7E78797378716A686546383D
39392D2B3E61784B5D524B4730616A4E5C5354607767747D
848544596A6564878DAE909E989F99A99D9AA599A4A59AA2
A1A1A1A19DA1A19E
A19EA1A1A19EA1A19D9D9AA1A1A19DA19A9D9CA19D9EA291
8284685A4B544436473D222E37758D878E88848789827B7D
7576737777737780747C817A877E7E7377716F6B68664F32
33392B213556874F449C496633425F6E544C655382617C6E
899853616D68667E8DBA91A599A09E9EA59D9DA19DA19AA1
A19EA5A1A1A1A19D
A19AA5A19EA1A1A1A1A19AA5A1A1A1A19D9A9DA2A79A9B8B
89875C5551494F343C2E2C2F3CE18B8B8D8B878780606C7E
71726B6B6B6B5C6D6A6D8C7E7D837E7873746F6969645A48
242D291C2E4C726F3B72705D6047495B65594F5C76736884
7591765B765F74898AA0A4A198A3A4A39DA49F9EA5A19D9E
A59D9EA5A19EA5A1
A19AA59EA19EA5A1A1A19AA5A19EA1A7A19AA09C9DA39186
84725E4C4B4645353E2C2B388C848787878B846B77605A83
585567726E515A565954668C817E827E7377746A6B64605B
3B221E201F4D27BC633BA34F886A4C56684763516972647C
7E8D865069707487AF8C9C9B94A69C9D9E9EA59AA59EA2A1
A19EA1A19E9EA59E
A2A19EA19EA19EA59EA2A19EA29E9DA2A29DA7A197A7848C
7B685D5139493B4122322D62C3878783868B874C6A66627C
786971647558625D794F595B9B80817E7878736E6B696262
53371A2912373E827E427A6D5E8D723F5958604B66756875
769787545A6C6884C298A19697ADA19B9D9DA19D9EA19DA1
A19DA1A19D9DA19D
9DA19DA19AA2A19E9E9EA59A9E9EA19D9A9DA59E9CA27D7C
62614D493647352D312745A78B8A8787866C7D5148575D63
5056624C473A494E4155493F6794957D7D787873666F696A
55502A1415344056816A39A34B8A9F673A614B5F546E6861
8A8D836858745F85B4A39A9C9A9FA9A19EA59EA59DA1A1A1
A1A1A19EA59EA5A1
A2A2A2A59D9AA2A19AA19EA19AA19EA29E9EA29DA0988373
5859443B433B363136309B8C888F888286636B3E39454859
48515B3F453D42473B5C42394967837D7A78767A6A696E6E
5D543C161119364D668E42547959AC8B6F3C5D6054696353
92808F835384659D9E9C979CA79BA2A2A1A19DA19EA5A19E
A5A19EA1A19AA5A1
9D9A9EA59EA19DA19AA59AA59DA19D9D99A39A9AA0927E6D
514A49393B393239353DE6888C8A8A8A83828867564C4352
51485E4F4A424B484C716E7278787D7E7977767A716F696E
64624725170D50364F6F743C7E4B87A58C455D5B4F5E6C61
7A709C8A517565C5A0989897AA9D9D9AA5A1A1A19DA19EA1
9EA59DA19EA1A1A1
A2A19DA19DA19EA59DA19AA59EA2A5A199A1A09B97848663
49433F4039293B3733859D878B898A858C85938D958C8B82
957D878D917F88827E857B8083757D827A77787671746966
6B694D341518473D5E4A7C33506E5F988A725950575A5468
69779C8A577557CD9891A09DA7A1A19AA5A19EA2A2A59DA1
9DA1A1A19DA1A19E
9EA59EA2A2A2A19DA7A19DA19AA19EA59A9D9DA0976C6559
454C313B2D35373736D98B888F8B8A8790858E8D918D918D
8F8387878775817F79857A8A7E8774817A7A7D7371707361
6469543B1F22174E4D535E543E6D5C879A87606655654C65
4F80899362686FBFA4918EB59EA5A19AA59EA19D9DA19EA5
A1A19EA2A5A1A19D
9D9EA19A9EA1A19C9EA5A1A19DA19DA19D9A9D9D8A83534B
4539432A37293E392CF788888F8E89898A8E8D8D8D8B8E8D
85877E917E7A85877B84818B7687867C717A7A776F706F6E
62636047271B1F424B4C4E6040495383798F7B5E4B694379
537A759769569597A5978BAAA1A1A19DA19D9EA5A1A19AA5
9EA59D9DA1A1A1A1
A19DA19D9DA1A1A19D9EA5A1A1A19EA2A2A19D93746F5E41
483E34333730382E5DB98A88908D8D8D8D888B8E8D8B878D
7D817A8D7C75818481808886847F877F7E7C77777174696E
675E564D331D2A324E435D4F58334F4D9C7D747B4F674366
697870966F51B87DBC91A19DA1A1A1A19EA59DA1A1A19D9E
9EA5A19EA5A1A1A1
A2A5A1A1A1A19EA59E9EA5A19EA59D9D99A79E9766595443
3C41352D313B3726C088888A908D8D8D918D898F8D8D8280
797A687E786F7C807D848387848F877F788572737271696F
6E5D5D4F37210F274640593B653A4832AF6B7B9146645851
6868739D79669E87A196BFA1A1A1A1A19AA5A1A1A1A1A19D
9DA1A19AA5A1A1A1
9DA1A1A1A1A19D9EA19DA19EA1A1A1A19CA19D946051423D
3A2D3C2E35362A26F4868A8A938A948C888D8A8A936E75A8
7975684C677B815F8A87848C7F8787877E807D77776F6F69
6E5E5A4D43240F212E404941594A3A49577A847F71506543
6B5E7B957D9866B871B6A1A1A1A1A1A19DA1A1A1A1A1A1A1
A1A1A19DA1A19EA5
A2A2A59EA2A5A19DA19EA2A19EA5A1A1A1A19E8C4F4D4042
31322D36392C253DDC858B8890858E9885908A8C94665A89
877C6D494F62745160808E91878787877F877D7275737169
68695A524632091823384246425B334C21B566709141693D
5C66728E8F9A66A0A1A19EA5A1A1A1A19EA5A1A1A19EA5A1
A1A1A19EA2A59DA1
9D9DA19D9DA19EA5A19A9EA59DA1A19DA7A19D7D423F442F
3B3A2D383A202569BC8B8B8D978D889087898A8A98828F88
8880796E767A7B74626F8A90878A85877F7F877F77747368
60685C564A40071C16423F4B2E6034461CAB607C8D3C6945
59646F8594856E84C2A19AA5A1A1A1A19DA19EA5A19DA1A1
A1A1A19D9AA5A1A1
A1A1A19EA59EA1A19EA19AA5A19DA799A2A59E79373C4432
3438373A331D2BB8878E898D8F908F918E8D85879B868E95
8883847773787A77717A8590878D848A857E7F787D74776B
63605A53493E13071E3E246032572D44366D6F858156505E
4E606392977A8F9BA5A19DA1A1A1A19EA2A59DA1A1A1A1A1
A1A1A1A19DA1A1A1
A1A1A19DA19DA19E9EA59AA2A59C9EA19DA199583C452B39
34393A381A261CFF8A8F8B98908F90908F908882918E9696
8F86827573787C737A808988878E88848786877E78757973
6D6457534D42230818343A42424E2E3F39646F7A83773863
4D5F67908B63ABBE9EA59EA2A2A5A19D9AA5A1A1A1A1A1A1
A1A19EA5A1A1A1A1
A2A2A5A1A19EA59D9DA19D9D9EA59AA5A1A197343A392840
34383715231E29F08F8F8790908F90909090918C858C8E97
888B7F79697979737E878788898D908289848787777A7477
6E7058544B48300924233F3B4342453739646A6E88963155
4A5F6B98976D9EA59DA19D9D9DA1A1A19DA1A1A1A19EA5A1
A1A19AA2A5A1A1A1
9D9DA1A19EA1A1A1A1A1A19EA19EA19EA2A29C2C37333240
35393A171B227EA08D978E8F8F8F958E8E8991908887849A
887E777773777E79828E8B848A8A948287868687777E7A74
6F6F69564A493D0E0E2D254842344C4537617C6B81A03264
366C54A48F86BEA1A1A1A1A1A1A1A1A1A1A1A1A1A19DA1A1
A1A19D9DA1A19EA5
A2A2A2A59DA1A1A1A1A19E9EA2A1A19A9EA182363B2E3F3D
3636221B158C80899295898F95899696968F9090908D8395
907F7C6F737D7D7F868E8B8F89829785908287837E7B7776
6F6A6A614545451F192E31394F344C43385F8D6A7F983D56
336D579FA394A9A1A1A1A1A1A1A1A19EA5A19EA2A5A19EA5
9EA5A1A1A1A19DA1
9EA19AA5A1A1A1A1A19EA19D9AA5A19D9DA13E433C234B35
383A1A2B22E78D9191948F9595898F9093898F8F8F918796
90887F727383807E828D8E958C8E8E898A8E8C878385797A
7372666E4C483F2E262D3042424848404B5F826E75895345
306A6987AEAEA1A1A1A1A1A1A1A1A19DA1A19D9DA1A19D9E
A1A1A19EA5A1A1A1
9EA59DA1A1A1A1A1A19DA1A19AA5A1A19EA51C3E31274D37
3434262162BC8A94908F95958F908E91958E958E89908C90
8F8B8A72737E8A82878690918C958F8B8A93878A84878178
6F776A6A52493C3422292F3E3D50484447876F6E6E7A6736
41586C90BEA9A1A1A1A1A1A1A1A1A1A1A1A19EA59EA5A19D
A1A1A19DA1A1A1A1
9DA19EA59EA5A1A19EA5A1A19DA1A1A19D9E1F4B302F3843
37243534AA8E8A948F8F96968F90908F8D9496968F909088
9888896E71778786888C8E908C9094858E8C898B8788857D
786F6D6A5D483F3429252E3044494A3E3CAA66677570822C
5D546292CEA7A1A1A1A1A1A1A1A1A1A1A1A19DA19DA19EA5
A1A1A1A1A1A1A1A1
A2A59DA19AA59EA59AA5A1A1A1A1A19EA5712F4F383F353B
2C2836929384958E8F8F8F95898F918B8890949095908A8B
938F91776D767F828A7E97908A948C8C9188868A8788867C
8270726A5E56403A2F1E312D3E553F403D9B696E6F4CAE1A
60676184D6A1A1A1A1A1A1A1A1A1A1A1A1A1A1A19EA59DA1
A1A1A1A1A1A1A1A1
9DA1A19EA1A19AA59DA1A1A1A1A1A19AA536513C2F552F3E
223836DD95849C8F95898F978E8C91808F8A8C8D9596838E
948E917D6A79747E81828C8C8C8A8C889188868889888581
777F6F6E63564639331A20333A4F483F4391656D732ABD1F
47767C89C6A1A19EA5A1A1A1A1A1A1A1A1A1A1A19AA5A1A1
A1A1A1A1A1A1A1A1
A1A1A19AA5A19D9EA5A1A19EA2A2A2A1A117863544413D33
1D5568957D95998E968F8F8D8E8A8C7E7887928D8E958590
998F9176707079757B88928987867F818386808C87928686
7A81706D655A49433327112B344E464D388E71557326C326
368581A0BBA1A19DA1A1A1A19EA5A1A1A1A1A1A19DA1A1A1
9EA5A1A1A1A1A1A1
A1A1A19DA1A1A19DA19EA59AA19D9DA1A60868334B3C471A
3E3FD26785A2978E8F8F8C867D737C98786C94869D8C8188
998F90756A6773758873947B8079746A778073787F928279
8181776E63584E3D3A312124294B3F503D7A6F536031C226
379477B4C09AA1A1A1A1A1A19DA1A1A1A1A1A1A1A1A1A1A1
9DA1A1A1A1A1A1A1
A2A5A1A1A19EA59EA59DA19DA1A1A1A17040512E43364C1A
4F758B587BA692948F887F66787E5D466571877186B28886
9D90907D6F6170638C427D858A8442437166656673958779
7A797273635B4D443A31381B234B3D484D6A6B4B5C34C723
48916EB7B4A1A1A1A1A1A1A1A1A1A1A1A1A1A19EA5A1A1A1
A1A1A1A1A1A1A1A1
9DA1A1A1A19DA19DA1A1A19EA5A1A1A134643F372345481F
28F4706975A1908B8A7D5E6180873C433D666B7A629D8696
9C908B837466655E724D2FAC8143533D683E7E42527E8C78
7F796F6F69544C483733290E1F4F43335E6A64475F3EAC22
7B8576CEA1A1A1A1A1A1A1A1A1A1A1A19EA5A19D9EA5A1A1
A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A19EA5A19DA1A1A1A63F34383C21494133
34D8656E859C968878684A30AFA1356A08773775707F9195
979087827770535A50784961D3228F0A7837961B4E707875
847873636E594B40393617131C2B4E3163575F4F5945A01C
87818DC7A1A1A1A1A1A1A1A1A1A1A1A19DA1A1A19DA1A1A1
A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A19DA1A1A1A1A1A169C33E39302C413D44
5CB0626F82988F7A6E582E3F584328493054385E6D7A8796
919588827C795E574F545C5D7B1E3824353E44383A696665
7B7872605E5B4143403223162A2A333A60564E4E654B9723
777AB4AEA1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1
9EA5A1A1A1A1A1A1
A1A1A1A19EA5A1A19EA5A1A1A1A1A12A975E343347383642
7A96646F819A8A7D6D582E3C3F302D333E58596971838293
90908882827C6A5E5D504C466A3A2C2D2830365651585E66
6F6F6769594C3C423D3A2C1B2D272939625B4844655E892F
737ECBA9A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1
9DA1A1A1A1A1A1A1
A1A1A1A19DA1A1A19DA1A1A19EA5A1373C5232333F392D56
707D7169849D8B8585705E4C3C35383D3C4A547884959188
94908D8284837366715F6A485753584B3D3A3D5267636064
6E6B6261624E3846382D2F1E2D352C2D636C42466D688833
75A2B29AA1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1
A1A1A1A1A1A19EA5
A1A19EA5A19EA5A1A1A1A19EA1A1A69214502331304D1E52
6A796E6084A28297958B85877F7A63676E6B67A18390908C
9389918B878A6E6659506A6A7C8768656469726E787A736E
6763735C5954433F3A351F202432203D4F6A4845786A9433
7BC9B4A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1
A1A1A1A1A1A19DA1
A1A19DA1A19DA1A1A1A1A19DA1A19FBA0241212F36462C4D
546B6F617CAA7E8A999A8E908B626956577163828695958B
9A89918F8C8D8172543D3A44597CA68E9283817680757465
566F615E514D4D3D2B331F2620203B3F4D5C4A3E7C66954B
71DCA1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1A1A1A19EA5A666EC003031322649344C
4A506C6679A58A5E8A9589826A5C71684B6D898B8B8F958F
8F8F9090918B8986775A35353C4657766E838879766A6B6B
6068625B4A484D384214352D261D2559515A4B42776E6455
A8C2A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A19EA5A1A1A1A1
A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1A1A1A19AA5A847742D3545362C393744
47475B5F889C9161655F676265636C8B8F8F959595959595
888F958E8F8A8C8B8D86796E5D493A4B39485B605B675D5A
696C625C4A4C5132332E2C2816171D5F54455D4379724464
C9ADA1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A19DA19EA5A1A1
A1A1A1A1A1A1A1A1
A1A1A1A19EA5A1A19EA5A19DA1A14F2C3332603B35393346
43495B558BA28C8F8773645E758F9B959595959595959495
899595958F90908F908D83878882868665564F4D51666863
6D6363595054523E282D1E1715151C853C4080376D88337F
DCA1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A19DA1A1A1
A1A1A1A1A1A1A1A1
A1A19EA59DA1A19EA1A1A1A1A1A15D243E3F6E3F37413A43
4246624F8AA18E8B8C96908E958E8F979A9595909A959595
8A949B8F8F9589908F908A84908287867D8C7C7E7372736B
726063564956543F45251B1E18251BA03F388C42509F32A0
D59AA1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1
A1A19DA1A1A1A19DA1A1A1A1A1A15C154941604444413D3D
3F405D5379A8938F8C92968F949B8E8B9A95958F95959595
8F8E958E8E8F8F908E9191898D82878583827D7A74726E6E
6B6763544F594D4436252B2313181DA84A408642428F3CE0
ACA1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1
A1A1A1A1A19EA5A1A1A1A1A1A1A17E0E3F42474A4A3D433B
413B61556E998C958C8D95908E969B8F95959590959A9595
95958F96968F8F8A908D8D8A8A87877E8A81827A73796F71
636F615B4F544B3D332534181415287C74447E4644557BD7
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A19EA5A1A1A1
A1A1A1A1A1A1A1A1
A1A1A1A1A19DA1A1A1A1A1A1A1A1A20C4B374749493E3E3F
3D475B696B8F8C958C9190908F939590959A958B95958F9B
9595898F8F908F888C888D88848787778081827E74767072
64645B5D5A50473A28351D1A1A142370814A81564E3CBFBF
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A19DA1A1A1A1
A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1AE0A35444E4B414A3A41
4B44576B6F8391929291919590959A8F8A979A8F8F979390
9496908E9090908D95888D858D82877F787D7E7A76776F72
636B5B5A5D494D3D2C2D1A150F0F44526D507E5E6A3FD0A1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1AE1455483D4C42433E47
34525E686684918E918E90909095958F958F9590938B9496
8A8E90908F90918C908C838A8E84877F8978827879776F72
5C70575A504941373D21140E1F0C5F4D534C86677A8CB5A1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1
A1A19EA59EA5A1A1A1A1A1A1A1A1A81A2C3F4141413F4341
4047616B6C7A908E8F92908F919A958A9A909A8B94919390
8F8F90908F8F8F91908A8A89858787778F757E737878736E
617053574C4D43332C24121421126A4C5143826C73CAA1A1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1
A1A19DA19DA1A1A1A1A1A1A1A1A1A192183B3D36403B3943
4B4D6465787B8C8E918E988E919595909496958F8E8A9696
8A8F909090908F908A8D8D8D828D827E8779797377737D6E
6C6357584D43462C261B1A0E1D147B464B48887A82C2A1A1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A81F23393A3C3C3A3B
4357626A78838A8E9389958E90968A968E9595958F958A94
968A918F919090908590888A888A8786877A7E7477737373
6867595456463B2325181F111C1A805537577C95ACA19EA5
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1
A19EA5A1A1A1A1A1A1A1A1A1A1A1A1A16C1330393E3C3F3E
3A57656A787F91888E9093948F958F959A909A8F90958F90
948F918F908F919088918A8C87858787817E7D7573786E6F
695D624E50473B23251C1B1F1F14766A3C657A9AC1A19DA1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1
A19DA1A1A1A1A1A1A1A1A1A1A1A1A1A19D183631413C3A42
3E535C7A8284878E8D8B9090908F9096958A978F8F908F90
908F8F91908F908D8D8D888D868787887C817D7A7678706F
645B5E4F4B3F3426291E1A23150E735C4A7189B2A9A1A1A1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1401D283E444139
40545E6C82928B888D938F93948F8F96978F8F968A8E908F
90908C958D91918D90858E848787878084807A767D6E7474
59615454413B3032232518160D2B7848527484D49EA5A1A1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1
A19EA5A1A1A1A1A1A1A1A19EA5A1A1A1A1AE6B341D494146
414B6272738A978887938B908F8C938F91908F95908F8F91
90908C90888D8D908D848D878786877A7D817D78786A7766
625E4C453E412C2B291E200F0C6B5C4463719EC09DA1A1A1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1
A19DA1A1A1A1A1A1A1A1A19DA1A1A1A1A1A8A89A1E2D473B
4D475F6F78839086908D938F918F909490908D9590908C95
8B9390928D8D8A8E8D8787878886877B7C7E7E78786A6F6B
58574B423D40391F281F150E5D4F4E44707DABAD9EA2A5A1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1AE46114E51
375B566B78868B8489878E908A908890968D909090908C8D
8B908787938790828787888787878181797E7A777665766C
58514A473B36403F131619394D6747507397BCA59AA69AA1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1AE5B1D354A
4663556B7882828F8E86888F8B9B868E918D919191919585
8D8F8D8785908D8787878788868778837E787977705C6D5F
5452484441383C2F2F1F2F365E505A5A7C8BCBA696A8A1A1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1AE474F1F42
444F5D6B757C89858C8C809587938A8A8D8F908D90849586
8A87808680898F8783848A84868777807C7378736A67615B
4D5444353E37392A36246633584D7E5C919EA1A89EA5A1A6
9AA1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A69AA1A1A1A1A1
A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A8585B0C3C
55385D646B7E817F878980928A8A8D8C838A8D8E91878C87
83827B7F7E828982838083798280718073736D70605E605E
4F50403D3C36483131416A44575A7F757FCBA5A19DA69AA8
A1A1A1A1A1A1A1A1A1A1A19EA5A1A1A1A1A8A1A1A1A1A1A1
A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A18E57212D
4849495E637F8487768282879286878B8683888888838386
837E747A767C7E787B7778746F7A717671696A71615B594F
4C5644394C41354C424B5C4C6A5D8E8A9AA3A1A1A1A8A1A1
A1A1A1A1A1A1A1A1A1A1A19DA1A1A1A1A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1612B2D
394D4C595E5E78828B7E8583868388888579827B88876C79
777966776375677A5D795D725D656F636661615D6A645054
455240425354302F4D65574D69717F85C9A1A1A1A1A1A19E
A5A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A69AA1A1A1A1A1
A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A16532
1A3F3D605F4777718C82818781827B807A7B767378817374
6772616A5D6A5E6064664E58674D6B505D5E5B574D60595E
5155494B3D4F4A3A465C5B6A76756CBAA1A1A19EA5A1A19D
A1A1A1A1A1A1A1A1A1A1A1A1A19EA5A1A1A8A1A1A1A1A1A1
A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A19EA59EA5A1A1A1A1A1A1A1A1A1A1A1A195
2B4C454E625B64658D7F8D8D827C7B7472766778796D6D76
62625D615075506456575D47526A4F5A4F565B5B37505953
4754574446414E4856616F6B777C7FBFA1A1A1A29AA1A1A1
A1A1A1A1A1A1A1A1A1A1A1A1A19DA1A1A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1
A1A19EA5A1A1A19DA19DA1A1A1A1A1A1A1A1A1A1A1A1A1A1
4B1B614B5476756980817B7C7C777C6972735D706B706270
5E694F565751665E6749635550753C605562545148414A40
4453454247445055646C8660815DDEA1A1A1A1A8A1A1A1A1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1
A1A19DA1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1
A83626494E6F636775797B796773756C67715E675A656A5D
56634761583B3F6D47695157574C4F59304A5C444643463D
444441384A47704B777E4B8B638CC79AA1A1A1A1A1A19EA5
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1
A1A83947426C5E7690847B7E63636B666B6B615F61615A62
5843684D49672A4A574A50564743423D3D3A4F3A414A4340
414A544E4D5E6F81705D487E4EE0A8A1A1A19EA5A19EA1A1
A1A1A1A1A1A1A1A1A1A1A1A19EA5A1A69AA1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1
A1A165175A68415D78887E756E4F6A5D71675A5067605267
5451465E495456365348404B3F3B3E383D363A4340413F3D
4553525B5B80745A705F6C6289AAA2A5A19EA1A19EA1A1A6
9AA1A1A1A69AA1A1A1A1A1A19DA1A1A8A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1
A1A1A81D20408160676D90736A416852626A564D655D4D63
4F60356149483F39623443443F3A3639302D363738424D38
4A66685470646B4D46794FBAA69B93A5A19DA1A19DA1A1A8
A1A1A1A1A8A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1
A1A19EA53E0638756F6D90816A40536E4C675B4D4A664E47
5D573A5B53493D204C4156333E2D42302B262E292A404F59
5654737A6C516E654E5870D5A8A89DA1A19EA5A69AA1A1A1
A1A1A1A1A1A1A19EA5A1A1A1A1A1A1A1A1A69AA1A1A1A1A1
A1A1A1A1A1A1A1A1
A1A1A1A1A19EA5A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1
A1A19DA1A8351444557783887B3F4368624F5E6044505C48
4F54534B4A5C49303B33444939354335432933373B444A65
70754C7D512F63656551B2A1A1A1A1A1A6969EACA1A1A1A1
A69AA1A1A1A1A19DA1A69AA1A1A1A1A1A1A8A1A1A1A1A1A1
A1A1A1A1A1A1A1A1
A1A1A1A1A19DA1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1
A1A1A1A1A1822127444F5A7F79762B546559465040424950
494F574747615746493250353D50443E4B464A4E5E4E5D76
5E805B683B4C5D585FBA9AA69F9A9EAB9EAB969EA5A69AA1
A8A1A1A1A1A1A1A1A1A8A1A1A1A1A69AA1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1
A1A1A69AA1A1742A364A4A6263864E3351695243522F4244
504B53385E506A4A584C423A3F594D564D55586E6C614F6F
654E3E535857576C91A1A1A8AE9F96A8A2A1A19DA1A8A1A1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A8A1A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1
A1A1A5A5A19EA565282D58666671764F3463475F4F493E38
443D563A62507554816340394F4D525E6D5E557459565D4C
46403F56604F56BCA1A1A69AA8A8A1A1A8A19EA5A1A69F9A
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1
A1A19DA1A19DA69A6E2621534E7E8C744C47515656515D4A
302D51375E66725D73A87C6B7E7A6C66727B756B524C4F3B
40514F6E55658FA8A19EACA19EA2A5A1A19EA1A1A1A8A8A1
9EA5A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1
A1A1A1A1A1A1AE9AA19B45183B6C788E874B626555685C63
6B32431E3A5A6C5E647A7F7E8A7E6B8F5B5A615944503F54
4B50565FA64AA1A697A1A1A19D9AA5A1A19D9EA5A1A69AA1
9AA5A19EA5A69AA1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A69AA1A1
A1A1A1A1A1A1AE9AA1A1A83C24255F858E857C846B887E6E
9186A19E8C948D77818674759F665E72455B46535353515A
5655717EA89EA5A5A1A1A1A1A19DA19EA5A19DA1A1A8A1A1
9DA1A19DA1A8A1A1A1A1A1A1A1A1A69AA1A69A9EA5A1A1A1
A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A8A1A1A1
A1A1A1A1A69AAE9F9AA69AA1921F2461719A88958D8E8E87
8E838E82818F998586827C56717653654B633862635E6861
6E7D75A1A19AA59DA1A69AA69AA19EA1A1A1A1A1A1A1A1A1
A69AA1A1A1A1A1A1A69AA1A1A1A6A1A1A1A8A696A1A1A1A1
A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1
A1A1A1A1A8A1A8A8A1A8A19EAC9A3D422F6377A08F918E8E
8B8AA48C8C89877F7E898560575060684B74476466597E82
5F8EA1A1A19DA69AA1A8A1A5A5A1A29AA69AA1A19EA5A69A
A8A1A1A1A69AA1A1A8A1A1A1A1A8A1A1A69FA697A5A1A1A1
A1A1A69AA1A1A1A1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A69AA1A1A1
A1A1A1A1A1A1A1A1A19EAB96A1AE9AA1533C44497DA19093
9C848E89847C646A596F6A7D6A336A6D56626D958B58629B
9AA1A1A69AA1A8A1A1A69A9DA1A1A8A1A5A5A1A19DA1A8A1
A69AA69FA69F9F9AA1A1A1A1A69AA1A1AEA6A1A29AA1A1A1
A1A1A8A1A1A1A1A1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A19EACA1A1A1A1
A1A1A1A1A1A1A1A1A19DA8A1A1A8A1A1A69AA653534E7690
809E9A90998B847E615F5B7D8267697D8E786C8095AEA69E
A5A1A1A8A1A1A19EA5A89EA5A1A19EA59DA1A1A1A1A19EA5
A8A1A8A8A8A8A5A5A697A5A1A8A1A19EACA8A1A89EA5A1A1
A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A19DA69AA1A1A1
A1A1A1A1A1A1A1A1A1A1A1A1A19EA5A1AE97A9A5A1655D76
647185809C8688959999898C898C7A63718095A1A1AEA696
A69F9F9AA1A1A19D9EA2A1A1A1A19DA19EA5A697A5A19DA6
9AA1A1A1A1A19DA1A8A29AA69AA1A19DA1A1A1A1A29AA1A1
A1A1A1A1A69AA1A1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A89EA5A1A1
A1A1A1A1A1A1A1A1A697A5A1A19D9EA5A89D9DA1A1A19D9D
A28E958E9C947E76768289767D82959DA1A69F9AA1A8AE9A
A8A8A89EA5A69AA1A296A1A1A69AA69AA29AA5A1A19EA5A8
A1A1A1A1A1A1A1A1A1A5A5A8A69AA1A1A1A69AA1A8A1A1A1
A1A1A1A1A8A1A1A1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A19DA1A1A1
A1A1A1A1A1A1A1A1A89DA1A1A19EA1A19EAB9AA1A19EA59E
ACA1A697A5A19D9D9D9DAE9AA19EA5A1A1A8A8A1A69AAE9A
A1A19EA69AAE9F9AA8A1A1A1A8A1A8A1AE979EA59EA1A1A1
A1A1A1A1A1A69AA1A19DA1A1AE9AA1A19EACA69F9AA1A1A1
A1A1A1A1A69A9EA5
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A69AA1
A1A1A1A1A1A1A1A1A1A1A1A1A19DA1A69BA1A1A19EA1A1A2
9AA1A8A29AA1A69AA1A1A5A5A19DA1A1A19EA5A6A1A1AE9F
9AA19DA5A5A8A5A5A69AA1A1A1A69AA1A89D9DA19DA1A1A6
97A5A1A1A1AE9AA1A69AA19EACA1A1A19DA1A5B29AA1A1A1
A1A1A1A1A8A1A29A
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A69AA19EACA19E
A5A1A1A1A1A1A1A1A1A1A19EAB9AA1A8A5A5A1A19D9EAB9E
A5A1A1AE9AA1A8A69A9EA1A19EA5A1A1A19DA1A8A1A1A8AE
9AA19EA1A69A9DA1A5AB9F9AA1A5AB9AA1A1A1A69AA1A1AE
96A1A1A69AA8A69AA8A69F96A1A69AA1A19EA1A8A1A1A1A1
A1A1A69AA1A1A8A1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A8A1A19DA1A696
A1A1A1A1A1A1A1A1A1A1A19DA8A1A1A19DA1A1A1A19AAC9D
A1A697ACA69AA1A8A1A29AA696A1A1A1A1A19EA5A69AA1A8
A1A19DA1A8A1A1A19DA8A5A5A19DA8A1A19EAB9EAB9AA1AE
9AA19EACA1A1A8A1A1A8A8A1A1A8A19EA59DA1A1A1A1A1A1
A19EB29AA1A1A1A1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A69AA8A1
A1A1A1A1A1A1A1A1A1A19EA5A1A1A1A1A1A1A1A1A19AA2A5
A1A89D9EB29F9AA1A69EA5A8A1A1A1A69A9E9EA5A8A697A5
A69AA69AA1A69AA69AA19DA1A1A69AA1A19DA89AACA69AA8
A1A696A1A1A69AA69AA1A697A5A1A19DA1A69AA1A69AA1A1
A19DA8A1A1A19EA2
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A8A1A69A
A1A1A1A1A1A1A1A1A1A19DA69AA19EA59EA5A1A1A19D9DA6
9AA1A19DA8A8A19EB296A1A1A1A1A1A8A19D9DA19EACA29A
AE9AA8A19EB297B29AA1A19EA5A8A1A1A1A1A19DA69EA2A5
A1A89EA5A1A8A1AE9AA1A89DA1A1A1A69AA8A1A1A8A1A1A1
A1A1A1A19EA5A296
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A89E
A5A1A1A1A1A1A1A19EAB9AA89EA59D9E9EA5A1A1A69F9AA8
A19EA5A1A1A19EA1A8A69A9EAB9AA1A1A1A1A69AA29AA5AB
A19EA59EA1A8A2A1A19EA59DA697AB9A9EA59EABA1A296A1
A19EA1A1A1A1A1A8A1A1A1A1A1A1A1A8A19EA5A1A1A1A1A1
A1A1A1A19DA1A8A1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A19D
A1A1A1A1A1A1A1A19DA8A1A1A29AA6969AAB9F9AA5B29AA1
A19DA1A1A1A1A29F9AA8A19DAE9AA1A1A1A1A8A6A1A19DA8
A1A29F9B9F9AA8A1A19AA5A6A19DA8A69B9F9BA1A1A8A1A1
A1A29F9AA1A1A19EA5A1A1A1A1A1A69AA19DA1A69AA1A1A1
A69AA69AA1A69AA1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A69AA69AA19E
A59EA5A1A1A1A1A69AA1A1A1A8A1A5A59AACA5A59DA8A1A1
A1A19EA5A1A1A8A8A1A69AA1A8A1A697A5A69FA1A1A1A1A1
A1A8A8A8A8A1A69AA19DA1A89EA5A1A8A8A8A8A69AA69AA1
9EACAE9AA1A1A696A1A1A1A1A1A1A89EA59EA5A8A1A1A1A1
A8A1A8A1A1A8A1A1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1AE9AA8A69A9D
A19DA1A1A1A1A1A8A1A1A1A19EA59DA19DA19DA69AA69AA1
A1A19DA1A1A1A1A1A6A69AA1A19EAC9DA6A6A1A1A1A1A1A1
A1A1A1A1A1A6A69F9AA1A1A19DA1A1A1A1A1A1AE9FA69AA1
9DA1A8A1A1A1A8A1A1A1A1A1A1A69A9AA59AA5A1A69AA1A6
97A5A1A1A1A1A1A1
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.35119 0.343006 0.64881 0.640625 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00751202 0.0192308 0.00751202 [
[.5 1.0125 -20 0 ]
[.5 1.0125 20 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(60) show
75.000000 12.812500 moveto
(deg) show
93.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(.) show
99.000000 12.812500 moveto
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
128 string
128 128 8 [128 0 0 128 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
9C9DA7A1969D999BA9949F768B8B8C94878C8C8C8CB49433
AF927F867D8C877B8D8886887C828C878F8A848786878788
77908787938D8D8D8D8D8D888F81878C9081878787878687
8787888784898786888786A6A88A429D828C877C82828A86
86868686918A858D97889590908696858185787F8582807D
AC925D9FAAA6A596
9CA0A0989AA5A29BA0A19C91858C8C8D898C8C8B8B929D48
AB9180858482807E86898787858883898F858586867B8389
8383898888868B8885868F83878D85888884878B86878687
8887888787867E898886878C9F9D5069968A877C82828380
898888888F858C878F888D8A8A908C8880868388828288A7
AB72708CAEA69D99
9B9C9A9C9D9E9B999C9FA1A296848B8B8B888B8B868CA489
4A9886857F79838A898A888688867D8092898686807E8282
7A797F838888898B84878984868A848E8F8E8A8B8E858787
888787878786868B878788878C8E9294598D807E8A878082
8C7E808A8F898E888E8B8C929292868983858885848E9698
9C7C7C83A9A4A49B
9D9DA0A69AA5A398A5A39D9B9A91A18D838C868685888AA5
6C898C85847E84848080898788867C818F8785877E8A7E7C
81827D7F858987898586888686878D978C8D8C938D8A8A8F
8E8587888888878888878787878995A1796497898B87868E
8A858A8B8E858D858D8C949290888F8386848F83A78F919F
7893797FB29F9A9C
9C9F9CA0A09F9D97A8A19FA29BA49B98878B8C858D8690AE
945F97898C7B82828A808489878784888B8780817F8B8487
8B88807C8584897B7D7D8A87878789898C8486978F838E89
8E85868E8C87888E8C8C868E86878995A1528E8C8D8B8B87
85878D8C8C8A90898D8E958E8F8E8C878D8398A5A5929AA7
75A96F7EB6A99C9E
9CA098A19D9A9FA39A9E9D98A2A599A5978C888B8D8A8E91
A0878B8E8D8087808487878C877E80897E7A8283808C8787
888686877E7D7F807C8D8389888787878987909282888E89
8D8C8A908A8B8C888C86858A848D868995937B7D8E8D8B89
878C8D8E8D8D8E898E8C8D908F8F8783827A9BA49E768F7E
82A86B98BBA49B99
9CA6A1A597A699A19AA698A4A699A2A4A09D9A8B8F929093
98A47F878D8A8A83878280807F7E7A767B7B7F827A8F888D
8C8B8C8F81887B887E887884817C8A8788888D8484898686
8787858D8A8686868885878787868687869C969488898686
848E898F8D8A8D89958992928F80816D6F84B194A46D9087
8D8F6DB1AE9CA498
9C9F9D9D9AA899A69A9D96A09BA19FA3A1A1999594969697
939A9B86539B85857E7F82818173747D817D7D7F7B888989
8C8A8A8F8187777F7B7D7B857C7B807C828081867E808280
897E89867D8587867E808080807F81897D849A9974868788
8789868E8D898C9394868D8A807862707396A07A6F768A7C
958279B5A698A098
9CA59BA5A2A4979E9B9FA49E9C9DA29EA3A197A497A7A0A1
A6A6A5988D898588828082827B7F7A8882858B8A827D8789
8E8A8A8B8B8A827B858B7E878182837C7F7376776C787575
776C797474787575737676847C828183787C8873868C6B5A
7B84808B87858D8E8A8F8A8354697280787F907F7986839A
8F7695AEA49D9B9B
A39FA09DA3A19F9D9F999F999B9DA8979BA496A799A79A9B
A69B9B9CA48C79639D7A74858083757D757F84828078868C
8890898E8A84857C85847E8C81898886828984858281847E
807E877E8087838684848D8F788E88887F8B827E8D89828A
8D309477838787856B514E5056868D8673868A808D8571A6
8868AB96A6A0A29B
999AA697A1989B9C9EA299A0A4A39F9B9EA899A79AA5979E
A199A599A19B635D8B69758A81817F84788185848378848D
8889858D89898B8381838A8A858A878785837B8B87878B7F
8285858989848284818A8A87838D80887E8C858988818A86
876FC46A606272554C5C56627B778E746EB678818A6692AA
759191A89E9D9CA2
A39B9FA19BA3A4999D9EA09FA599A29A9FA0A19BA2A49FA4
9A9B9D97A1996A7F617977638B827C827186847C857D838E
878688898C848C8385818488878787878785877F83818885
887F83837D818A887B8D87878780808B7D8C7D8986858B7E
817F917F8A813D45625C5D6F6F686D747DB550788F639E95
6FB992AE9AA09DA8
9BA1A39C99A799A0A4A39CA2A4999FA1A4A2A497A1A3A19B
989C9F9C9E9B758462687B4A4D87827E7A877C81817A838E
878787878E8388848785888A878788868787877D85838B80
81867F7E8385847F7E8E888687798B8A7E857F8D877E807E
817370674C41485F5F597167696980807B98587F8C69A885
85B29BA393A8A39F
A39F9A9B9CA797A796A496A799A299A7A1A1999CA5A499A2
9A9A9EA49B9C839C854F6E4A49429B74857576818180848D
8787878789848787878780818181897F8887877E83838480
80827D838583837F8485897D827E8E877E80838481778273
75646049465B6F666A605D6B6A7A8377887A5F7D7B899380
96B49D9F99A59D96
9B9CA39E98A89FA597A8999EA19CA1A5999B9B9CA696A29F
99A49EA1969D7FAA73445854453735897C738780847B8285
898787878088878787878588818A838084888785887B7E84
8283837E84807D80827E8D7D8B818289858084807A7A7671
68685043666D5B67755E5D6C7B687D697B6C848983AB6A8C
B1A89E979E9BA59B
9D9D9D9A9AA8969C96A8A0A19DA19D9BA19AA69C9EA19D9A
A49DA29D9B9B85A46F6D4C624737293996798473877F7D8D
8A8787878583818887808181807E7F838A8A8780817E8180
807B8581857C8176847F8780848082857E6E746E666A686B
543D3360826A43706E79747A645E6E6B81718E80AA8079A1
AC96999CA09CA89A
9BA59D9CA59C98A0A3A09DA399A699A4A599A79A9B9FA19D
9E97A2999E999A8F8865485B4037322E3195846E8A7B8089
8880818181878184887E838A81817E8185817F87817C7B7E
7D7B7F7C81797E747C778184748670837A73707169665A4D
31414A7574655980727C696D70606B7D79778D838A7997A7
A08D9CA59E9BA7A0
9D9DA2A1A594A6A4A4989CA698A096A19A99A6A0A29DA0A1
999C9F9E9D93977A974353573D393E34261C94777D7D7F85
82808383838B7E8A838083847D83817E7F807D87807E807F
7C8077757B7F77778278877D73797A7974746F6C5D4A4744
41566E7967626876655C5A6A6373797B738B898388AAA197
9BA0A3A9A2A1A5A1
9BA5A0A3A19E9E9DA39F9D9E97A0A2A5A1A39F9A9E9B9EA5
999F9F9C9C9D95809A425B57403A3F331F221EA078897D85
818483838384878A7E8383838284837E81857C847D7E7B7C
7C7E75797B7C73717A7778846B7879746975684F3B492C55
576378666169647D6A6D727D757D7A76888B8382959C9398
A3A2A49FA39B9AA3
A3A695A79BA39FA39E9D969FA49C9B9E9DA3A09AA0A49A9D
9CA49D9A9D9B91898846594A43453D2A1F1C2AD478848183
82818A818A81848180837C84837F837C827F7A7E767F7C7D
7D777776727271717B89726D656F6E6E5B6551522D4C425B
47646D5B5F667276777B6B788A737A86888381939A92AAA3
A9A49F9BA597A4A5
A19B98A09C9DA399A29A9AA7A499A49DA49E9D9BA59B99A5
A49EA19A9F9996836351594C4253393625293A479288848B
7F818D7E84808383838082827A7F857E7F7E817683758083
7C767A7072626E7D8A7856646F6670655058434857536361
66786F606665785F6B6F68796F668B878082909BA19AADA4
9C99A2A29E9BA79B
A1A099A59B9EA1A1A597A5A5A1A09B9CA6979F999EA19AA2
A398A0999B92967760515B48525131392A383B21C28A838D
7B81867A80837C808382807D7F8080837A7D7D7F767E777B
7474726A646A719187536073715F544A3E5F4949545A614D
676E68615E4F8A5F81668F6A748B8D80808A8CA79F98A6A5
94A5A6A197A5A4A0
A199A19DA1A4A2A4A199A6A1A1A1999DA69F9E9D9BA899A5
9B99A6A29A92985E694E504846452D3B3F432D13E7818483
8080847B80867B807F7E7D7E82807E7E7F7C7D75727A7677
77786B6A5E668183595061655D504C3A50664A4F52554D4D
6C70695D6069825F7660706D76788781829CACA3999EAAA4
99A8A1999B9EA3A1
A19FA597A7A19BA39BA19EA3A1A1A09CA09D9B9EA2A69AA5
96A5A5A1979187596853524D4D352F4346382725EE7A8F7F
7B84817F847F7D817E76817F7778777883717A74777B7172
736B6959626A7864525E5F61543F4A475573565D4E4E6B5C
69656565807172616B6669758C8794809AA0A39A96A0A199
A2A49BA0A4A1A5A1
A19BA39FA59B9BA5A09EA1A4A1A19BA19D9EA4A29EA39AA0
9BA19D9B9891825F5F564D4B4E3A3E5A3D232622E47A8770
82878274787E7D77777678797676777B7377727273747074
6A6B665D607761504A5D51593E53524F5167645F4E5F6059
6750696A847378606A7E647394828B94A9A699A093A39EA4
A6A19A9D9E9A9EA3
A1A0A49BA3A09DA5A1A09EA3A1A1A0A4A0A2A4A19AA59A9E
A49A9CA4A28F6F58675A4C4C4F324C402E1D2F22E67F837E
877C857B778576747B76717972777274717C75726E6D756C
6B6E645A6B694E4B53504C3E4951394954736963695A5B53
5562725E81776A5D7F82648191819CA0A09096A09EA39EA6
9BA3A0A19E9DA59E
A1A1A1A09E9DA19E9AA3A0A4A19BA3A1A1A1A19BA1A49A99
A196A59F9B9756605E583C4B3F3750392F293826E674847B
82797982737C76757372726E6D766C6F767572696E6C706B
6E60615A715A4C4B4B4A454E503F3F4D5665675D6758644E
55536572796E77767F626A818B8AA5959D9FA098A3A49DA5
A0A4A1A19AA4A49A
A19B9DA39A9EA5A0A19F9AA3A19AA5A19B9D9B99A69B9BA2
A59BA8959D8255675554455A374A4C3F20222A2BDF708473
817B767C757178706C756E6D70666567716C706A6F656868
62605E60524749444C514F4947464D5655626D7A717E5F43
4E557163737A7B7660616A93908AA19B94A393A6A2A5A0A4
A19BA3A1A09BA39A
9DA1A29E9B9C9D9B9EA1A1A599A29EA39AA49AA5A5A0A2A4
9B99A0989E69635C594D414F3A5735311A202B2ADE70837C
80777771727075716C6F6B706D6B67696A68706D6666695C
5E5E5362474340514853502B313A52635D5F65706D697355
5268676C618477616069689B8CA6989F959E9DAC959FA3A1
9BA1A4A19BA0A5A0
A2A4A1A09DA3A2A3A4A4A1A19F9D9CA598A699A69BA39B9B
9CA3999F895F6C53524748413F4D322C252F2F30CA737977
7974727773746B6F6D6567685B64615E6B695F6A66695C5B
615F4E6E443250514542302B215A6B4D5E4D60717C6B8351
5E726070638961615B65829E9BA18F94A1A0A1A799A0A6A1
A09BA39BA19EA3A1
A1A19BA39AA09A9E9DA39BA3A19FA3A4979F9C9DA2A49AA3
A39B9B9B7161634855454B454244252A272E2D2DC4787888
797A747E74787775756A615C635A605D625E63685C5E5B55
584E506A3A2E5352332F2B383F586757585A4E787578665C
5D676163807F5C7163828194B58B93A29DA8A3A5A09DA5A1
A19FA5A0A49AA59B
9DA3A09998A59CA5A29E9BA5A199A39BA09BA09BA7A19AA0
9A999D926D665C4C534A4659374416362C2E2842BF8F8D90
868A898080827A797C76716D58585C5C5C5759575F5B5759
524B50632B3652422C252C5933506A5A514E527676807478
606A534B90765B6B7A7E89BCA88F9CA59DA5A39BA3A0A4A1
9BA3A1A1A1A09E99
A29E9DA0A3A69AA5A1A0A2A4A199A7A09EA1A397A89BA19A
9B9F9F7A675F584F503C474343321B3C312C287DC9929887
8A868788898A7B817E78767169695752595B5C5D50595B59
514C445C354C602D2B263B652C545A5E4A4C596A69847974
64654965866C6770946690BE8B889F9AA89DA597A09A9E9D
A1A49BA3A1A1A0A1
9DA19AA69B9BA29BA3A1A1A19B99A69B9BA59B9AA89A9D99
9DA09E73635A5A4A4B4B49404C1B2B3E2B2C7BCBB095908F
879487908786838A7C7F777971726968515454545A555B52
474A363458407120261B26644B405972456B546978878784
704160697160727C7E69C1A2809CAAA0AAA09CA1A4A1A49D
A0A3A0A4A19BA3A1
A29EA1A5A0A2A596A29BA3A1A09AA1A19DA09B9EA5A0A1A3
9A958473555E51433D494640371B3E3A29C6C4A791958F91
8E94828B878E858783897D75757C706B604C4E4F584B544C
48472D317F27853328371C42692A5F66456E5C6571738F83
6A4E5C646C65847C7587B48790AB9FA69CA399A6A19B9DA1
9DA0A3A1A1A0A4A1
A1A0A4A199A3A19FA4A2A5A1999C9DA6A09DA4A2A4A1A19B
96937874505D5048434B414126253A2B6CE39283908E9290
91908C93878B8387877E787F7D7976716B5570454D4E4C4B
443A33317B456F491D1C3359735769605F4F6A626D748286
7B4F4C6A596B8E86787995A0A6A5A0A899A69AA59B9BA4A4
A0A29EA3A1A19BA3
9BA39BA39FA599A39B9DA39B9B9F9BA79B9B9DA3A196A497
98897866555E4D4636433645192E3647D2AA908A908D9584
93848794828985868885867C7C7C767671686B55424E4B41
4833351F657C2F7A3455285C3A70415F5D5F646B55876594
92454B6C627777797185AAA99B9F9BA1A19EA1A49A9EA59B
9DA39AA0A39BA1A4
9FA79AA5A1A199A0A1A2A4A09D9EA39FA1A2A2A5A19EA090
967B8056584B4F413D45392A224147C6B98D918D8D878C80
89828789817A7C81897D82767E74787876716A655D433A48
38362A294B7C44586C2D5A494B6056505F673E6D5C816785
7A70554F6774658088A0B390A1A299A79E9BA59BA1A29EA1
9DA5A0A29EA1A4A1
A2A49AA5A1A19AA49E9D9D9DA1A29EA19E9B9B9E9DA3A08F
877E6E504F4B433C4143202A282BCBBB908C868689847F77
75777374746C777777727F7A7D7C7F7578716C6C6E594D42
37392E2C3C55725E5D6567522F576B56614B5363796A707D
8B9047657E695F858DBB94A0A29F99A9A09DA597A0A39AA0
A1A4A1A1A0A4A19B
A19BA1A4A19BA1A4A0A29DA4A4A1A0A49A9D9EA5A29E9D8E
8182655849534635443B212F3CC2D48C91888487877D7275
6E6C666969686B766D757B71817E7E737871706C65655737
3136291E3052864938944B6F4B4E566A594F6D578261816E
7D8F5E706F696F858EB691A998A1A3A0A3A09BA1A4A49AA4
A49BA3A1A1A1A1A0
A19AA5A19BA1A4A1A1A19AA5A1A1A1A1A09D9C9EA39A9981
7F85564A4A444A35392829313CE28A86878585867A4B4C60
5B636365656550565154767A7C7F7E7B7676726A6D675B56
2D2B261A2D4865725577766B6C635E5A5F624C516E70617D
7B8E7B607B617190969F9DA1949E9FA29B9EA09FA3A1A09E
A3A09EA3A19BA3A1
A19AA59BA19EA3A1A1A19AA5A19B9BA3A19AA3A39DA29186
8A685148474342303D2E2C3BD0C18787868D865C5B5666A9
85696D808A5E6263635B5D7A7B7B7F7E7377776E6D64635E
4A2E1E1F1E4A1EA1763B94478276575E7341605B6B6E647B
798E8A4F5A627481B3A0A69E93ABA49C9B9FA59AA59B9DA1
A49BA1A49B9BA59B
9DA19EA19EA19EA39B9DA19E9D9B9DA09D99A6A197A77D7E
6552514C33423742202B2C73DE898C868688844765666066
53526753543D4F4D76545A4F857E827E7B7E766E6B6D6667
5B47242E13314389694278726382905551596A475E706774
709184546375677FC399A39595AEA19FA4A2A4A09EA1A2A4
A1A0A4A1A0A2A4A0
A2A4A0A49AA0A19E9B9EA59A9E9EA4A29D9DA69B9BA17978
5A5D4840314635262E294BDCB08B8585865C5D3C363D4553
43454F3D392C3A412E38352E4D70887D7D747476696F6C70
5852331412353E487077378F4682937D5B7148605C6B6355
82928275677E678CB5A1989AA19FA4A19BA39BA3A0A4A1A1
A1A1A19BA39BA3A1
9D9D9DA3A09DA0A19DA49EA19DA49E9D9B9EA0999F937E70
524F3A33413A33343B34DAC2858C8C858670905E525D555F
4D5C6D4C52535958518C808191938F7D7777777B6E6D6E6E
615C451D13172E495F8253546F599E8581425A6854696252
927A8787538066ADB29F9499A39DA29DA1A4A0A49BA3A19B
A3A19BA1A49AA5A1
A29D9EA59BA1A2A49AA59AA5A0A4A0A29AA49D989E907A64
4841463D3A363038353EEC848B8C8689858A9583969E919A
A4969995A695978D899C83808280817E7C79767970726D6D
64664F2D1D0D563A465C62387541728E854E70604D56666A
7F64948A53725AC1A2979897ACA2A29DA5A1A1A1A0A49BA1
9EA3A0A49BA1A4A1
9DA1A2A4A0A49BA3A0A49AA59B9DA3A1999E9C9D95737358
403E38383625383932ADCC898E888D868E87908D95898F8C
997C878A87727B797B857A838C7B7D847D77797771746962
67694D361519483B6D55823746696A94848370555C68545A
576B9D8A577C5FD59D8D9AA1ABA1A19AA5A19B9D9DA3A0A4
A0A4A1A1A0A4A19B
9EA59B9D9D9DA19CA3A1A0A49AA49EA39A9D9D9F9B735B46
394A323929363B3737E997868C8D89869288918D8E8A8E8A
8B7F8787877483857C857A8E7C877A8076787F74716E7469
68695741262A154343444E49456B52788F8355665C644B6A
5181858864646ABE9C948AB19FA3A19AA59BA1A2A2A49BA3
A1A19B9DA3A1A1A0
A29EA19D9EA4A49F9FA3A1A1A0A4A0A4A09D9D9D7A704D47
45343F2936283A392AF186868F8E8B8D898D8E8D8D8A8D8D
8284788A787180837A82838F77838789797F7A7670736E6A
605E5C4A2A191F444D5253684543457A697587754C684178
5C8270926953A2A9A59894B0A1A4A1A0A4A09EA3A1A19AA5
9BA3A0A2A4A1A1A1
A1A0A4A0A2A4A1A1A09EA3A1A1A19B9D9DA1A2916D62543E
444234323A343B2B6FD98688918E8D8D928D8A8D8D8C8586
74726B7F716F7A7C7C7F8783868A8D7A7A7D76767074696E
6B66584A36232F33493C574752344D3F8E936D6B526E4964
62766E967357C57DB795A9A7A4A1A1A19BA3A0A4A1A1A09E
9BA5A19BA3A1A1A1
9DA3A1A1A1A19BA39B9BA5A19BA3A0A29AA69B996751473A
3639312B2C393725DCA7898B918D8D8D8E8A888F8D8D817A
727C68787269757B78808084808A87837D8B7B787673696F
6D595B533A210C1F3E3C5836613E4D30AA5868A254645D58
686269987B78A8899F81B4A1A1A1A1A19AA5A1A1A1A1A1A0
A2A4A19AA5A1A1A1
A2A4A1A1A1A1A09EA1A2A49BA1A4A1A19FA5A09255473A35
3729383039382623F5858888918794918B8D8C89935E5393
887F6E3F4761774F737E818F878D8787837F78767870726D
6D625E4A442810222B3A423D5848384D4E628B746956623C
60577B997DAD6AB16BB9B4A1A1A1A1A1A0A4A1A1A1A1A1A1
A1A1A1A0A4A19BA3
9D9DA39B9DA3A1A0A49B9DA19EA3A1A1A1A19B8443423D46
33342D33392A2344EE868F8F978A8B93838E898C977A88A6
8A837667848D8D6A6A758892878887877A87887B77757369
65665A564C39091620343E463E56344819AD67639441653E
5C6873838B91598DA9C29BA3A1A1A1A19BA3A1A1A19BA3A1
A1A1A19B9DA3A0A4
A2A2A4A0A2A49BA3A19A9EA5A0A4A199A3A1A07C3D383E27
333A2F3A3B1F2273CE8B8C8A948F90958C8E8C8996809392
918681787B7C79736E7C8F91878B8687847F7D7A7A78766A
5F665A544841081D1541434E2D5A33461DA75783973B6948
5F646C8595857595CEA19AA5A1A1A1A1A0A49BA3A1A0A4A1
A1A1A1A09DA5A1A1
A1A1A19BA39BA1A49BA19DA5A199A399A0A39B732F354136
3938383D321B2CDFAB928D9495918F918E908684998C949A
8D83857A76757777717E8990878E848B8683897D7F76796F
6B675C53493D15071C3F1E55355B2A3F3E716685775A5660
515C5B89977591B7B8A1A0A4A1A1A19B9DA3A0A4A1A1A1A1
A1A1A1A1A0A4A1A1
A1A1A1A0A4A0A49B9BA59AA0A39F9FA1A2A498432A422731
30383B3716221BF78C908896908F909190918D8B92869192
8B8884706A727A707985918E888F8D86868688837D757975
716959534F472B0918314248404E2D41355E6C727F873F5D
485E6FA2935A9EBF9EA39B9D9DA3A1A09DA5A1A1A1A1A1A1
A1A19BA3A1A1A1A1
9D9DA3A1A19BA3A0A2A4A0A29EA39AA5A1A1972F37342544
3A3B37111E1E2BFC91958F948F8F908F8F8F918F868B8B93
858476766B7B7B7785928E88888C8F828B868787787D7879
6E73605B4E483109272439353F3D483C3B6A6E6F879C3755
475C648B8E80C8B8A0A4A0A2A2A4A1A1A0A4A1A1A19BA3A1
A1A19AA0A3A1A1A1
A2A2A4A19BA1A4A1A1A1A19BA19EA19E9D9D9B2C35313544
343739191C21B0DA8E958E8F8F8F9996968D91908D8D8499
8D827773737B818088908E878B8B97878A868788777D7B76
6F6C6858494942110D2A2245473549473A5F7F7485A02F69
376B53A69B8AC1A4A1A1A1A1A1A1A1A1A1A1A1A1A1A0A4A1
A1A1A0A2A4A19BA3
9D9D9DA3A0A4A1A1A1A19B9BA0A1A49A9EA47325362C3F3E
37371D1614C9D698959C8C8F998D928E8E8B908F8F8F8998
908183777680817F868F8A9394879783948A8C8784867E7A
746E6D694E4846262135393D4E385142365E916E7E913F56
2D67569EA0A7B9A1A1A1A1A1A1A1A19BA3A19B9DA3A19BA3
9BA3A1A1A1A1A0A4
9EA49DA5A1A1A1A1A19BA1A29DA5A1A0A2A4272B361F4834
353A1B2F2AFD909396908B9999898F91988D8F8F8F918695
908D867373838383848B8E98898F938E89898C8A86867C7B
7376696D4E4B3F2E292F2E4141494C3F536F886B717D4D43
2D69718FB1B6A6A1A1A1A1A1A1A1A1A0A4A1A0A2A4A1A09E
A1A4A19BA3A1A1A1
9EA5A0A4A1A1A1A1A1A0A4A19AA5A1A19BA31C423127503A
3632272174E28E97908F99998B8D8F91928B99968D908F94
8F858472737B87828B8B918E88948F8684968B8A8487857E
72776C6C544A3C3622262E3C3A4F48464589786E6E78703D
4A61668BC7B1A1A1A1A1A1A1A1A1A1A1A1A19BA39BA3A1A0
A4A1A1A0A4A1A1A1
A2A49BA39BA3A1A19BA3A1A1A0A4A1A1A09E1B4D3533363D
3722343FDFB28D948F8F928E8B90908F8890928E8B919182
928D93757478858484878B8D8C8D9186948D82868588847C
7E756D6B614F46382D282F2E4248473A35AA6B63716C7F28
59566090CEA8A1A1A1A1A1A1A1A1A1A1A1A1A0A4A0A49BA3
A1A1A1A1A1A1A1A1
9DA3A0A49AA59BA39AA5A1A1A1A1A19BA3571B4634433C3E
292637C5D18695928F8F8F998D8F918883888C8A93918489
968F917B71767B7984758D8E86948C898E8283898788867D
8270756F5F58433C311D2F2D3C564140429B5F6E723E9F18
586B708BDAA5A1A1A1A1A1A1A1A1A1A1A1A1A1A19BA3A0A4
A1A1A1A1A1A1A1A1
A2A4A19BA1A49AA5A0A4A1A1A1A1A19AA528524A2F56303B
20393AE1917E9A8F998D8F938B898B74858889878F928490
948F917D6877717B7B82928B8D86817D8682848688888483
7580746E6759493C341B1E2F3A4B47414292656B7023AD20
496F809DD4A1A19BA3A1A1A1A1A1A1A1A1A1A1A19AA5A1A1
A1A1A1A1A1A1A1A1
A1A1A19AA5A1A09EA3A1A19B9D9D9DA1A40D793348453D35
1B5A9FC6748C9C8F928B8F8987838781747584878A8F7E88
958F91716C6C767475828D877F7C767676746D7876847F80
7B85706D62584946382C12282F4B444F398971506422CA2D
368689A9C2A1A1A0A4A1A1A19BA3A1A1A1A1A1A1A0A4A1A1
9BA3A1A1A1A1A1A1
A1A1A1A0A4A1A1A0A49BA39AA4A2A2A4AB116A2C45384616
3F43D45F6FA0998E8F8F89806F585774685E8478968E8389
9A90917A6F666C6C8D799374736A61535C6D686C738D8274
7677726D655A513C3732272928483C4C3D78644C5B31CA22
349775AFC69EA1A1A1A1A1A1A0A4A1A1A1A1A1A1A1A1A1A1
A0A4A1A1A1A1A1A1
9DA3A1A1A19BA39BA3A0A4A0A4A1A1A14E29522A3F33491C
55A8B3537DA68E908F836F49577B743C4458796068958584
9B90907C726374627F294E5B778E40315D5751525E807873
79796F7061594A443F323E1D214A3D464F6F6D4B5A32C625
53A579C6B89DA1A1A1A1A1A1A1A1A1A1A1A1A19BA3A1A1A1
A1A1A1A1A1A1A1A1
A2A4A1A1A1A0A4A0A4A1A19BA3A1A1A12C68483D22404B1F
23E5736D7FA5948B806E495397AD3434395C5C716595738B
9C90877F74696253645D39BBBC3B3A3F6F387E49486A7C71
7B776E6C69544B493532240A1C4D4430576B60405A42B01B
7E9477D7A9A1A1A1A1A1A1A1A1A1A1A19BA3A1A09EA3A1A1
A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A19BA3A1A0A4A1A1AB784B2C311E493E37
48F361657E988F816D563B2184842E8C09642C5A5D70879B
9A9088827978585C4B6A595A9E159F085C3094123B666C65
79726F5E65574C3D373715121D264331685456505F46A01B
857A92D4A1A1A1A1A1A1A1A1A1A1A1A1A0A4A1A1A0A4A1A1
A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1A0A4A1A1A1A1A1468332423732463D47
6ABA576B839990746451253F5728132C26653D6A768D989B
909288817D7A66615A554C5B731225163433332D446A635F
71706D5D5953393C413326192F3032365D554C455F4E9C28
7F7AC3BEA1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1
9BA3A1A1A1A1A1A1
A1A1A1A19BA3A1A19BA3A1A1A1A1A1227F56332E4A3E343D
79946170819A867F7C70555644353B42445A6A8B949D8F96
939388818586766C6D615C41594D5A4A333036616E71656E
797262665C4B39423B3A2F1D2F26263662604C4565659231
7681D2ACA1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1
A0A4A1A1A1A1A1A1
A1A1A1A1A0A4A1A1A0A4A1A19BA3A16C5741262E3A332959
7A7568637C998D8C9489838A88888B92989677828392978F
938F8F898A8673626E5F7770856867666C7D888C8B817E79
776D635E5E513A473A292A1D2D39332E606E4444716F8D35
7ABFD8A3A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1
A1A1A1A1A1A19BA3
A1A19BA3A19BA3A1A1A1A19BA1A4ABA30C3E1D2C2D50204B
5D716B5B80A57E92968E8E9490926B564D45479592A1978F
9A8D918D8A927870573F504D628E91928F8A89808380766D
6154695C554D4441383A201F222D1A3A4F5F4245796C9A39
82D3B49DA1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A0A4
A1A1A0A4A1A0A4A1A1A1A1A0A4A193AE003C1F2F39462D57
5763645D78A37E848B948E90854643414E83A0B49599988E
9A8991908F8D85826C543D3A465B7E7B8987897A84746E5C
496C64584C484A3D272B1B27211E404C55614D3D79628B4E
7BE4A9A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1A1A1A19BA3AB53CD043334392544344B
45455D5F77A48E536B72645A403F79A8A8B3AB9C97999893
8F8B908F918D8B8A898476786651444F46525C56554A4E57
6470635F4C484D364D1635352C202150535A48427A755E41
ADDBA1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A19BA3A1A1A1A1
A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1A1A1A19AA5A4414E12344C3D323C3442
44485A5987A1917B926F65607EADB9AF9996989494949496
898F9996978E8F90928A8385868B90A069565555536C736B
6F72675D4A4D56342B2D312512131B5F55405A497F743C65
E5BBA1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A0A49BA3A1A1
A1A1A1A1A1A1A1A1
A1A1A1A19BA3A1A19BA3A1A0A4A15C32353567473C3E3548
44495C5688A08B8C898C9699A5A09B949494949494969495
899999948B8C8F8F908F878B8F858788748693888087776C
78645B524C5655452F2D1A1313151C93433D8E4166863685
EDA9A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A0A4A1A1
A1A1A1A1A1A1A1A1
A1A19BA3A0A4A19BA1A4A1A1A1A1551A3641784337423E45
4144614E89A08F8D8C96908E99968F8F9694948D96959494
8B91978B8B998D9190918E868F8287857C8D7879736F706A
705D665E4C55533B4A2D1D211B291EA5483D88414E9832AD
EB9EA1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1
A1A1A0A4A1A1A1A0A4A1A1A1A1A1671A50495D3D47483F3D
3C3C574F739C8E8C8B8E92909197928F9A94949398949494
93969992968F8B908A8B8B888F82868487827B7C73757271
6D6B68504C5C4E47331E2B2613161AA84A449046408436FB
C39DA1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1
A1A1A1A1A19BA3A1A1A1A1A1A1A190183E3B3E434839403B
423D665D769B86908C8E95908E9297939894948D8F969494
94948B8E8E8B8F858C8D8D898484877A827D827A72787072
5F685A5C555447372E25361713152B77745788484A4D81FE
A4A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A19BA3A1A1A1
A1A1A1A1A1A1A1A1
A1A1A1A1A1A0A4A1A1A1A1A1A1A1A90B4C3B4A4F4E434140
3D495C6B708B88968D9493909098998D8F96948B98988B97
9494898F8F91908E948B8D88848787777E7D7D7B76776F72
68685B5B5A53483C27361B171A15226D7C4176575640D0D2
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A0A4A1A1A1
A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1AE143840534E3E46393F
504957696D818E8F908F8B92909296938D9396938F8F9491
8D8E8D8F9191908A92888D838E8586838082837C74766F72
5F665B5A5D44493D2F2D18140E0E4C5A614A82647F5FFFB4
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1AE0B565D404741433E4C
3049606D6580908E908D93939098988B9497988D948F9095
8E8F90908F8F918F938F82878E82877A88797D7275776F72
5C735A5B4B443D303B21120D200E635252447E6474A5DAA1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1
A1A19BA39BA3A1A1A1A1A1A1A1A1A4565237383D3C3B413D
434E616B7281908E8F95938F919A948B9B8D968B908D9791
8B8F919190908F919084898F858587778F757E7378787670
64745251494F493A2A2112152213704F5345826F7BDEAEA1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1
A1A1A0A4A0A4A1A1A1A1A1A1A1A1A1A318363D343E3A3540
4C4F6B697A7F8F8E928A938E91928F8D90959893968D9195
8E90919090909091848A8F8D819085838C7C7C7377707A6E
7062535C53413F252118190D1B14804A48448B869BD4A1A1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A43C383B3C3F3D3D3C
3F535F6777848D8E938B978E90988D98969994948B948F91
958D918F9190909087958B878888848687767B7477767270
63635C52524A3E2225181F121D1B845F3B5A8097C7B69BA3
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1
A19BA3A1A1A1A1A1A1A1A1A1A1A1A1A1892330353B3A3E3F
3A5668717F83948C8A8C8F9190938C93968D968B8D938B90
918B9190918F9190888E868C898487877E7D827A75786F6C
6A5C5E4E4E413622251C1B21231471653F7188A9C8A1A0A4
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1
A1A0A4A1A1A1A1A1A1A1A1A1A1A1A1A1A01E4338453F3A41
41555774858D8A8A918F9493908F8F989889938C8F8F8F90
90908F919090918A8A8D888B838587887C817A7674787073
64585C4C483C31242A1F1A23140D705645728EC5B8A1A1A1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A185704B4E4D4D3E
3F53636E7A8A8C8C898F8B8C908F8F928F8C8F988E8F9190
919089938A8B8B8A93868D838486877B7F8079747F6E7072
555D505240372D35242519150B2F8F4F567D87D7A0A3A1A1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1
A19BA3A1A1A1A1A1A1A1A19BA3A1A1A1A1AE908B3A4B3D44
464B5C717586938887938C94938A908F919090938D908F91
90908F93888D8D938D8088838786887D7D7D7C7B78647560
5E604B3E363F2D29271D200F0C7F6D3E6170AAD2A0A4A1A1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1
A1A0A4A1A1A1A1A1A1A1A1A0A4A1A1A1A1A49FA235314339
4947606E77858D7D8B898F8A898B8E9291908A9290908993
878C8A8C8A8D898683848786888687797A7E7E75756D6F70
5B4F434140423E21261F140D847349417592CAB99B9DA3A1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1AE5A13475C
3E5F5D6C76848A888E868A8E8D958B8C928A909390908F8D
89948B848F848E838786888787867D7F7A7D7674745C6F67
51504B4B3D333A4B1614184B525847567DA0C6AA9AAEA1A1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1AE51254041
3F66566C7A847D878B86888D8597858D8F8A8E8B8B8B9283
888683847C878883878687888687757D7B7576776F5B6956
4A4B423D3D3A3F282D293D3B6459606A8E93CBAE9DA69DA1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1AE4159233E
414653666F71828485887B8F8991878785898E8D93838D80
87857A7B78828A87807C837B7B7B6E7A776D726A5E605F58
4D5648343A3335293622764B604986699DC5BEA497A3A1AB
9EA1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1AB9EA1A1A1A1A1
A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A46D850E36
563B5B63677F837A81817B908785878B8588888787808985
7F797278797F83747576796D777A6B7B6E6F686C6059595B
504F3B3B3F39513D36507E465C688E898FC7A3A1A0AE9EA4
9DA1A1A1A1A1A1A1A1A1A19BA3A1A1A1A1A49DA1A1A1A1A1
A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A19A532C41
494A4B5559737A89787C7F808C878889827E8080807A7473
73746C716A6D6B686E6B6B6962676268635B5C685B585747
404F473B504D35474E5557466E608F8EB3BFA4A1A1A49DA1
A1A1A1A1A1A1A1A1A1A1A1A0A4A1A1A1A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1895B40
3F4B4C5E645A676A7A7E878B8B7E80807E70766D78836A73
71725D6C596A5D73536B5061505763595B595D546268555D
545C4143585A372B406363596F809085CBA5A1A1A1A1A19B
A3A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1AB9EA1A1A1A1A1
A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A18B8F
4D503C58593E6F74948F8C8A7E7F77766C70717075756A73
60655862566558525761454C5F4C644953565453434B4955
4A504A523A41454B5C63566E908A67CBBEA1A19BA3A1A1A0
A4A1A1A1A1A1A1A1A1A1A1A1A19BA3A1A1A49DA1A1A1A1A1
A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A19BA39BA3A1A1A1A1A1A1A1A1A1A1A1A19D
2E4F53586679886E896F787F7B75736F6F755E6C7568636C
5E5E585D49714F6B5F5362534F6D565C57575C61394F5B57
45515943494952465465878B7F7592DAA1A1A1A9A1A1A1A1
A1A1A1A1A1A1A1A1A1A1A1A1A1A0A4A1A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1
A1A19BA3A1A1A1A0A4A0A4A1A1A1A1A1A1A1A1A1A1A1A1A1
89355F4D4C63605B737C8179726D77646A6B566A5F635C6A
56684E4D5448595961485B50547B37544C635548433F3F31
364A3A373F3C4B58778AA3617851DCB4A1A1A1A49DA1A1A1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1
A1A1A0A4A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1
A47D5950567F73768A857D7A63696B66646E6069585E685B
4E583B5F5E3C345D3C5F5756573F435E2A36473C3F3F4B47
534B463B4D50956D8C8F36685698F39EA1A1A1A1A1A19BA3
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1
A1A43C4F3D59465C7D7C787C6562655D65685C565B63555A
5B3F7159406D3C48564A414B3C3C3D2F353F52383F4B433A
38425562677B7889854E3E874EF5B89DA1A19BA3A19BA1A4
A1A1A1A1A1A1A1A1A1A1A1A19BA3A1AB9EA1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1
A1A1931F547F5162727E7B7069485E566D67584A635E5069
5259414C4A4C4E3B4D423F473C393C3B4134323B403E3A3B
49625D5A547C804F4B4C7C6EB7DB9DA3A19BA1A49BA1A4AB
9EA1A1A1AB9EA1A1A1A1A1A1A0A4A1A49DA1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1
A1A1A46C4C316C707368887971426951595D4E48635A495B
485A33644A49392E64343E423D3A35352A273334323E533F
4B68776999896A4A467E47C5DFAF9AA5A1A0A4A1A0A4A1A4
9DA1A1A1A49DA1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1
A1A19BA3843A34555C658F826C404A6A5369665B4A5F5143
595A3C5B554E45203E3862393C283F302A252C25253B4961
7566728267334D59545174FEAB9F9BA4A19BA3AB9EA1A1A1
A1A1A1A1A1A1A19BA3A1A1A1A1A1A1A1A1AB9EA1A1A1A1A1
A1A1A1A1A1A1A1A1
A1A1A1A1A19BA3A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1
A1A1A0A4A4552E454769777879444461604C4D534048524A
4D4A555244584E414E3539403C3A4A39543B404756626173
7894607443265B626963F0CAA1A1A1A1AB9D9EA59DA1A1A1
AB9EA1A1A1A1A1A0A4AB9EA1A1A1A1A1A1A49DA1A1A1A1A1
A1A1A1A1A1A1A1A1
A1A1A1A1A1A0A4A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1
A1A1A1A1A1955649504944615E79354D5A594C4C393C4046
444E544043615B4C4F38623C3A574F454D4A5D687E656D92
6B704A5E2F4E725F58E7D2ABA89E9BAD9BA89D9EA3AB9EA1
A49DA1A1A1A1A1A1A1A49DA1A1A1AB9EA1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1
A1A1AB9EA1A19051444F5468627D5D434D6356475F374243
514E533561546A5062674D39435C5063626B69837E6D4F57
4A38283B5366576DE2E19DA4A9A49DA6A5A49DA0A4A49DA1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A49DA1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1
A1A19E9EA19BA38B613953686B74756947663F5D51504D3A
3D324A37614D785DA496746C8D837C819A947A87523E4B48
3C384570785455F7D39DAB9EA49F9DA1A49D9BA3A1ABA89E
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1
A1A1A0A4A1A0AE9E8E8C4F513D678A7D67595F635D586C79
523655375C708568658B797A9396917E6A5B59533F484E32
3A565C7B5365DAE39D9BA59D9B9DA3A1A19BA1A4A1A49F9D
9BA3A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1
A1A1A1A1A1A1AE9AA19F8B3C3D6B697B8F647D8A779A8E73
9299CCA9AFA49A7C909B868692744B6C4C4C52503E4A395A
69655E5BDFC1D5AB99A1A4A1A09DA5A1A1A09EA3A1AB9EA1
9AA5A19BA3AB9EA1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1AB9EA1A1
A1A1A1A1A1A1AE9AA1A1A47799395074787D929E85978585
A5818A837C9197898C8B706187575C763C54414954627480
63577FD0E497A39E9DA4A1A1A1A0A49BA3A1A0A4A1A49DA1
A0A4A1A0A4A49DA1A1A1A1A1A1A1AB9EA1AB9E9BA3A1A1A1
A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A49DA1A1
A1A1A1A1AB9EAEA49EAB9EA1A36F5161638C7B827F8A9390
938AA3958D949882837B7A5960644A5242683A6C7A747159
6DB1CDCAA19AA5A0A4AB9EAB9EA19BA1A4A1A1A1A1A1A1A1
AB9EA1A1A1A1A1A1AB9EA1A1A1ABA19DA1A4A69DA4A1A1A1
A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1
A1A1A1A1A49DA49F9DA49D9BA5A283BA595656898E98938D
8881977F80786B5B5A6C7458574351745C8B71937C577DC0
C1C7AEA1A1A0AE9EA1A49D9E9EA1A9A1AB9EA1A19BA3AB9E
A49DA1A1AB9EA1A1A49DA1A1A1A49DA1ABA8AB94A3A1A1A1
A1A1AB9EA1A1A1A1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1AB9EA1A1A1
A1A1A1A1A1A1A1A1A19BAD9DA4AE9AA184AEBF686380767D
958E958C8F8E757F6C76627E935E9D9E7F6F5F8EACB6CCCE
A1A1A1AB9EA1A49DA1AB9EA0A4A1A49D9E9EA1A1A0A4A49D
AB9EABA8ABA4A89EA1A1A1A1AB9EA1A1AEA69DA5A1A1A1A1
A1A1A49DA1A1A1A1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A19BA59DA1A1A1
A1A1A1A1A1A1A1A1A1A0A69DA1A49DA1AB9EAB84B26E6C89
6E808B87978D98AA979389A6917C72667A89ACC8BAB6A697
9EA1A1A49DA1A19BA3A497A3A1A19BA3A0A4A1A1A1A19BA3
A49DA49F9F9F9A9EAB99A3A1A49DA19BA59F9DA497A3A1A1
A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A0AE9EA1A1A1
A1A1A1A1A1A1A1A1A1A1A1A1A19BA3A1AE949F9EA18BA9B6
A2A9A693AD96837775838586818B9AAEBEB7B2A9A1AEA698
AEA8A89EA1A1A1A09E9DA1A4A1A1A0A49BA3AB99A3A1A0AE
9EA1A1A1A1A1A0A4A4A5A1AB9EA1A1A0A4A1A1A1A9A1A1A1
A1A1A1A1AB9EA1A1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A497A3A1A1
A1A1A1A1A1A1A1A1AB99A3A1A1A09EA3A49BA2A4A1A1A0A2
AC9DA4A1ACA097A2A9ADB6A6ABADB1A7A4ABA89EA1A4A99A
A49F9F97A3AB9EA1A9A0A4A1AB9EAB9EA9A19E9DA49BA3A4
9DA1A1A1A1A1A1A1A19E9EA4A69EA1A1A1AB9EA1A49DA1A1
A1A1A1A1A49DA1A1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A0A4A1A1
A1A1A1A1A1A1A1A1A49BA4A1A19BA1A49BAD9EA1A19BA39B
A59DAB99A3A1A0A2A2A2B09AA19BA3A1A1A49F9DAB9EAE9A
A1A19BABA1AEA49EA49DA1A1A49DA49DAE949BA59BA1A4A1
A1A1A1A1A1AB9EA1A1A0A4A1AE9AA1A19BA5A6A89EA1A1A1
A1A1A1A1AB9E9BA3
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1AB9EA1
A1A1A1A1A1A1A1A1A1A1A1A1A1A0A4ABA7A49DA19BA1A4A9
A1A1A4A5A1A1AB9EA1A19E9EA1A0A4A1A19BA3ABA19DAEA4
9EA1A0A19EA49A9EAB9EA1A1A1AB9EA1A49BA2A4A0A4A1AB
99A3A1A1A1AE9AA1AB9EA19BA59DA1A1A0A49EAB9AA1A1A1
A1A1A1A1A49DA9A1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1AB9EA19BA59D9B
A3A1A1A1A1A1A1A1A1A1A19BAD9EA1A49A9EA1A1A09EAD9B
9EA1A1AE9AA1A4A69E9BA1A49BA3A1A1A1A0A4A49DA1A4A9
9AA19BA1AE9EA0A49EA8A89EA19EA89EA1A1A1AB9EA1A1AE
98A4A1AB9EA4A69EA4A6A89DA4AB9EA1A19BA1A69DA1A1A1
A1A1AB9EA1A1A49D
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A49DA1A0A4AB9D
A4A1A1A1A1A1A1A1A1A1A1A0A69DA1A1A0A4A1A1A19AA89B
A4AB99A5A69EA1A49DA9A1AB9DA4A1A1A1A19BA3AB9EA1A4
9DA1A0A4A49DA1A1A0A69A9EA1A0A69DA19BAD9BA89EA1AE
9AA19BA59DA1A49DA1A49F9DA1A49D9BA3A0A4A1A1A1A1A1
A19BAF9AA1A1A1A1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1AB9EA49D
A1A1A1A1A1A1A1A1A1A19BA3A1A1A1A1A1A1A1A1A19AA0A3
A1A49B9EAFA49EA1AB9B9EA49DA1A1AB9E9B9BA5A4A699A3
AB9EAB9EA1AB9EAB9EA1A0A4A1AB9EA1A1A0A695A8A69EA4
9DAB9DA4A1AB9EAB9EA1AB99A3A1A1A0A4AB9EA1AB9EA1A1
A1A0A69DA1A19B9D
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A49DAB9E
A1A1A1A1A1A1A1A1A1A1A0AE9EA19BA39BA3A1A1A1A0A2AE
9EA1A1A0A69F9D9BAF98A4A1A1A1A1A49DA0A2A49BA5A5A1
AE9AA49D9BAF94AF9AA1A19BA3A49DA1A1A1A1A0AE9B98A3
A1A497A3A1A49DAE9AA1A49BA4A1A1AB9EA49DA1A49DA1A1
A1A1A1A19BA3A9A0
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A497
A3A1A1A1A1A1A1A19BAD9EA497A3A09E9BA5A1A1ABA89EA4
9D9BA3A1A1A19BA1A6A69E9BAD9EA1A1A1A1AB9EA9A19EA8
A197A39BA1A6A5A49D9BA3A0AE99AD9E9BA39BADA1A5A0A4
A19BA1A4A1A1A1A49DA1A1A1A1A1A1A49D9BA3A1A1A1A1A1
A1A1A1A1A0A4A49D
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A0
A4A1A1A1A1A1A1A1A0A69DA1A9A1AB9D9DAFA89E9EAB9AA1
A1A0A4A1A1A1A9AB9EA49DA0B09AA1A1A1A1A4A6A19DA0A6
9DA9ABA7AB9EA49DA19AA5ABA19BA6A6A7ABA7A49DA49DA1
A1A9AB9EA1A1A19BA3A1A1A1A1A1AB9EA1A0A4AB9EA1A1A1
AB9EAB9EA1AB9EA1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1AB9EAB9EA19B
A39BA3A1A1A1A1AB9EA1A1A1A49D9E9E9AA89A9EA0A69DA1
A1A19BA3A1A1A49F9DAB9EA1A49DAB99A3ABA8A19DA1A1A1
A1A49F9F9F9DAB9EA1A0A4A497A3A1A49F9F9FA69EAB9EA1
9BA5A99AA1A1AB9DA4A1A1A1A1A1A497A39BA3A49DA1A1A1
A49DA49DA1A49DA1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1AE9AA4A69EA0
A4A0A4A1A1A1A1A49DA1A1A19BA3A0A4A0A4A0AE9EAB9EA1
A1A1A0A4A1A1A1A1ABAB9AA1A19BA59BAEAB9D9DA1A1A1A1
A1A1A1A1A1ABABA49EA1A1A1A0A4A1A1A1A1A1AEA4AB9AA1
A0A4A49DA1A1A49DA1A1A1A1A1AB9E9AA59AA5A1AB9EA1AB
99A3A1A1A1A1A1A1
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.678571 0.343006 0.97619 0.640625 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00751202 0.0192308 0.00751202 [
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(120) show
81.000000 12.812500 moveto
(deg) show
99.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(.) show
105.000000 12.812500 moveto
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
128 string
128 128 8 [128 0 0 128 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
7273787670737172786F735F6666666A65666666667A6E38
6F6860625D64635C656362635D5F64636765626362636363
5B6663636967676767676764686163656861636363636263
636363636164636263636272766940685F64635D5F5F6362
62626262686562666C656B6969646B6460625A5D605F5E5C
746B4F6C75767770
7275736A6E7B7E777177777B6F67676463666665655C6450
7C686062645E585B5E606363666A60616861606262575860
66605F635F5B61615D5C645F5E6766625E5E636664636263
63646363646259606362635C607356455967635D5F5F5D59
61656565686066636160625F5F6966626062666B635F6689
8B52536271766F6E
706F6D72746F6B6E7370767E837065656562646561646F84
3A4860635C565D676966636263625D58626665625C5E605A
52535557606361646363605E62605E696E6E6B676B666364
6363636363636768636363635C5280A94848585B6768615F
645A5760676769676966666C706C646362636463646F766A
696A65606E6E7876
7575777D757B7E737A7E736B6D798B776365615E5F61596A
81755A616563625C5858606363625D60645E60635E66605A
5E625E595960626160626362626268726A6768716C6A6B6D
6E666364646464646463636363615B6D8F565A6B68646770
6A666C686660646165676E6D6862696362626A6482786B78
545E63607C74676C
7275727177756F6F7976787D767B777C756B6A6668656C7B
76566966695F5F5F67615C606263656A68635B595B64656C
6D6A655F605C605753535F636464625C615E5C686B616564
656464696A6564696A6A65696563615B6D5A635D686A6A63
6063686A68686C6868686C68696B66656B646F8883747E7F
667C585A797F7D75
727470746F6D737A706D6F6A757A737B7F7969696A68685E
68807869696468615C636867645B58605A525A605D636363
6363666C6259555B5C6861606363636360626D6A59616865
66686A6C66686A6364616162606865615B7E78575B656667
65686868696A6865686763666969655E585568707454564C
55785A758C787172
727A7D7E727A7270727C71797C6E757978828A766E717070
69726C6665696B67685E5958565A584D5058595A57636369
6A6A6A6D696D60615F61555A57545E626362635D5E615D5E
5F5D5C6364605F61615F6262625F5F635E607B9272605E5E
5F666467676466656E686C6C695A574A44577F6F6F596565
685C4E7E80727874
72706E6F727A747C736E6C706B7675747676737B7A747474
71697575365361615C5B5F5F5F514F5C605C5C5A595E6061
6465656861645C5B565658615A5755505657565C5A575958
5F595F5E545A6061595757575758595F5B55596960616163
63625F646665656D6E64646158533E45536A6A5039425F54
66615A7976706F6E
727B74787B79706F71767C79736E7474747670797A878583
8A8D827EA279586263615F5F5961606563666D70695C5C60
66656564686B6861646D63626365655D594E4C4A434B4B4B
49434846494B4746494D4D59595C5E5B5556553B516C4C2E
3D53575E5D5C64645F68685E343550635B53575B62655B76
6F5571807474726F
7E75777373767978756F6E6D717479706C72707873797271
7670707279866B3D6161525B616158574F5458595C5A5F63
61676669655E6160635D5E6962676A6C6970706D6D686965
64666C65646B6B6C6C6B74725E696A6A646D6564645D6D8B
7F193B4D535E5E5B442114172E606E6A5B656359696A5368
674F706B72757B77
686C7670726A6A6F747B74747C7D7571777A737972777074
736E78737271554A523F50615E5E61675E5F6060605A5F64
63605C6263676A66626066666566636365605765696C6D64
6365646A6F6660615F676763676A5C605E65656B695D5E5E
678EB55A3A2D3829223C43495C535C514D88695D5F436983
55746E73756D6B75
80767076747A7F72706F7778776E7573737276717579797D
73716E6B746F5B724D4E553D535F5A5D546061585D5F6165
62626361645F636165625D606363636363656A5D585A6065
6A605F5C555A66685D636363635C5C645D645A5F6265675A
5655606C8B822D204041435550473F465C763A4860506763
5582818573777479
6B767D726E786E777F7D7275797371767D7B797173747670
6F72767573726265584C5036213B5B5C5C645A5F5D575D65
636362626661615F6365686663636363636363606260645C
5A63605A60625D585B666363635965665E5E5D65635B585B
5E5141331C122F50453E534D4B4D6364585E485D5F527861
647C727A6D797E75
7E756C70747870786C7270786E75737876766E707A796E75
7471717976736C83804C4537391E41525F5450585E616165
636363636260636363635C5A5A5A605B6063635E60605D5C
5D5A5A626260605E615E6059595E67635E5D5F5D5A545C51
4C433F2B2A435653584F3F484F5C62586656415653666A5B
6D82777375786F6C
6B6F7A777077797B727973717672767B6E6B7072766C7575
6F7B79736C7260775A3B3C3A342A122D515165625F595C5C
606363635C606363636365686266605C5D606365685C585E
6062625C5E5D595B5D5A635F68625B606562615D5757524F
4949392E4C584346574D4A4D5B4C51494C4968726A83535C
837E746F706F7777
73726E6D72796C6B6C77787C7376736C76757A767177746D
7973757573726972576749493B2D20163A595C515D5F5C66
6763636365605A60635C5A5A5C58585F6666635C5A5E625C
5A565D61625B5E555B5E5F5C5D5C605F574A49453F3F4145
371F163D655633484C5E6969493E45485C55635E86615B7E
7A69697177737972
6F7A78737A726E767C766F747378737B7A73797273717678
706B716E7472796D6C523C43302A282411335E525F595E61
605C5A5A5A63625D605E606662615E5C5C5A5862625A565A
5A5959555A5859555650575E525B4E57575653524F493B2B
18263B554F484F665A594B4B584F4D5B5757646054527380
78656C7775737878
756F747C7B6E7A7D7970707670716C706C6D76787C777376
74737374736A685768373A412F2B302B1E07245357575A5D
5B5B606060645E66605C605D5A5F615E5A5A5A5D5C5F615F
5B5E5751525A5756615B6159545157574F52524D402F292B
32435A624D444C56483935433F54655D5467686066858671
6D7D817F7B7C7B76
6F7A76747679746E747878716B737B7E7C7E756C6E707477
737676727178736670414642352D2E27181B0A3058635E60
5E606060605D63665E6060606061605E60635D5E595A5858
5A5B575A5B57514F5054525C505555524A4E4A341F2A1C34
46505A4B454D4858555B616563605B596A6A605F6D6B626F
7A76797574706C73
807C6E767074787C746F6C737C756C6D6F7478747579736E
6F797572736F6A6A633D44353137301F17142080585C5E61
5F5E656266625D5A5C605A5E605C5E5B5E5B575952585A5C
5C565655504E4E5259655A46414948493E3E3037232F3745
30404B414246555658635556695E5A6667605E6F766C7F80
817F75707770797B
76707072706F736E7573727B79737C7678746F717A716E7B
7D74767475727062423A443D333D2E2C20212D1F3B636168
615E655E5D5C6060605D61605759605E5D5B605761575961
5D585952534548596A58383F4E494D4738392C2B484B5152
5B65574C4E4C544342444957474062665E5E6C757B7C807B
7269747B74717970
7678737A747473777A717B7B767871707870736F6D767572
7470716F6F686B5A4C3D4137413F2629222C2D1665616065
5C5E5E565A5E5A5A5E605D5A5E5F5B5F5B5A5960555C5852
4F52504B434C5469663B425754463528233C3A3837424936
434D4C484434594F63506B5655706E5E5E66657778707777
6E7B7C7670787978
766E7673767D7B797673787676767373777977757377737B
716D797C766E6F46494038332F2D222A3337220D7E605D5B
5C5F605C5C605C5C5A58595C5E5F5E595C5D5C5150545557
56584E4C45445B5C343241403A3334273749393C3E393135
4A4F4D4546575E464F464348584F595F6075908370757E79
747A766E70717376
76797B70787670747076747476767876736F70747B7C7277
707B7B76706C5F464940413C3D272130342A1D208E5C6962
585E5E5E645D5B605E555A5D545051535B515354585B524F
5048493D424E513E384346443B292F383F534A4C3E39524F
4E46444B685F54484A494D5067727462767C717071737169
747970777D7C7B76
767074797B70707778747679767670767574797B74747272
71736F6D6E6D634F4740393638303347311819187C5B5D4D
5B6360544F575A5351555351555554584F53534F51505054
4C4C4946465446332E3B3639293B413C3C43494D404B453E
4A38444C5B5A604E4D605152655E6273858477736D76747B
7C76726F6E6C6E74
76787970747875777678747476767879787B797672777274
797370797D6F513E4D483C393A26362D1E15211A7F5F6163
66585D605C5F56535855515550545350515857554F4B524D
4D514B424F4B35333C3732273138242D3A53504B594B433C
3647574453554C4460645163695E737B75626673797B7578
7074787C77757B74
76767678746F76746C73787976707476767676707679726F
706C7A756D724845423E2C322B28392B23212B1F83535A59
5D5A5459575755575250534D4B514C4D5352504A4E4F4E4C
504443424F4237363333303C3E2C2D383C41464346444D3F
3E353D555A4A57636243475A6268786C6F7C7E6F73797577
7879767672797972
76706F74727477787C756C7376727776706F6D6D7670707B
7E777A6E715A444F413B37462D383A3118161B1F7F555C52
58595856545153504C524F4F524642454A4A4D4D50484747
42444446362A2F2F353C3E3530343D4340454C61616D5334
353D51424A5C5C55424349666E676F736C706A7C7C777879
7670747678717372
6F767B7470726E6B6E767C7B6E7574747279747B7B787B79
706E7170744F4944423B2E332C40271E13171E1D7B555D5E
605656514E505252504E4C504F514F4D4B474D4F49494D41
40413A42362F2A39363A3A1D1A21354A4C4846474A455755
47514C5044535744434D4C67648079717272747D6E6E7376
7076797670777B78
7B797678757A7D7E7D79767679737077707773787074706D
707A727361474F403932362E2C3426201D26252572515551
5353505657564D4C4F4847463C3F43414A4D4044494D4140
46463A4D3724383C332D1B1C163C55383D363E4D5A565F43
4C5A4C504E6043434144617777746868727A787874777876
7871737076747476
7676707472726C6E6F74707476787C797070706F7579727A
7C717172524644343C353636322F1A1C1D2121206F575867
5F5B595E595B5F5D5B554A3F47413F42423D474B3F3D403D
3B3237472C22363A251D1C28384245474243384B50584843
474746465E61485451696364846E687A76797D7A78757776
76797B7879727770
6F74786F6A77767B7B747077766E73707776747378767272
6C6E72695650453B3C3834432D30112422221D32796E7773
6F74756A6668605E61606260453E4140403C393640413C40
3C3637412027392C1F1A1E42293448423D353B50515B6068
54523C2F5556474A5C616896816E7A797677747074787976
707476767678746E
7B746F78807C727776787B797673797874777C7177707673
7175765846423F3C3C2A302B3025162A26221E5D9772746B
6864646B6F6E6364625C5A595D5D473A3D424546373A4241
3C39303B2D3E4C241D1C2B4726393A3F37373F4744565855
514E384E5D484E586E4F5F7D665C6C6F79777770716C6E6F
767970747676787C
6F767377706D757173767676706E7770707770727A726F6D
7375745D4C414137353C3A3036141E2E201F6ABA93746B6B
68716B6C6764666E62615D5D595C5E60433A383843403F3A
3233261C3A344E1F1B12163943343A52395345495962656C
603043504D404C5D584E927B5872817B7D7872767D7C7D75
7274787976707476
7B74777A787C7A70726D7376787472767572707477787C7E
756A554E41443B2F292E323025142D2C1FB1D38D6A6B6B6B
6D6E6163626B6663666D665A585F5B56574137363A343834
3533212255225039252F182340243D42344A494D4C4A5E60
524A46444C4C615D56687B5E6B7E74797273737876706F76
7572747676787976
767879766E7376797D7C7A766E7073777875797B79767670
6D6D5B523D413C3935372E2E1C1B281D57A46C5F6665676A
6A6A6C7368635F63645B5561645C5A59564C633E34363634
302726254B43503A1C11254953565E494D3A454A4E525459
624539483D47646961545870857F777A7378727770707979
787B747476767074
6B737074797B6E73706F74707175727870707073766C7270
70645A4B40463A33262C252F141F2739A78A666A6C676B5E
665E5B676265626263666C5F5A5E59595959544C3936362E
32262616355C264D3F5B263A223E2F3C414D4C4C3C58485D
6F433B4B4C5A4F4A4D64827D6D706F707674767972747770
6F74727274707679
7679727776767373767B797875747A75767B7C7A76797667
69585C433F3336302F332C1C19323AAFA0686A676762605C
5C5A605C59545157605959575C5356595A595552593C2731
28261E1F2F43423D54284B403B40413C3F492A3F47574D57
4660583941514756677E8B6D7277717A74707770767B7476
7577787B74767976
7B79727776767279746F6F6F767B7476746D6B6E6F74786F
5F5A4D3A37362E292F31161B1E1C9EA36B695F5C5F5E5850
4B49464545444D4D494854575B5F62595754525458584E35
292A2522272D4A58415F604925334B484A313E48564F4E59
687041566950435962886F767D7371787875777071747272
7679767678797670
7670767976707679787B7579797678797274767B7B746F6A
63604E45393C38282F2A1A222FBCBE6A6A64626361584F50
4D4841414143444D4B4F544C575B5C5758545451494A4C31
24261E141D34563423573F5652413348463E524457495E50
4D5D595F524F596264766D7A70757C76747871767D797279
7970747676767678
767277767076797676767277767676767875726F73726F5B
58614331342F322B281A1D252A81635E5D5D6062572B1F2C
323C42454545332B27283F5558595B5E5B5A5750534F4551
2D1E1A131E2C375559525B5A5B64563E41503733444E4153
5E5F61505C4C4F69736C6B736B6E6E75716E777574767874
7478747476707476
76727770767474767676727776706D7376727A7D73756D67
6B49393733312D222C26222BBAAD62626268653B2D3D5690
886055677B55505451483A435356595D57585957534B4C49
4B301717152D0F4A6931533554624E4E592F434B4D4A4B54
52646743363E53537B837F756D7D7F727075777277706F76
7970767970707770
6F76747674767474706F76746F7074736F6E777670785C54
3D313537252A263216191F5A98676A6562615F3A464B4533
202C422F211C292C4F45442F46595E5B5E625A5250535052
4B4827260F1B355839394D5A4B508357364453343B4B4B51
4D5F5D48525A4A557D70766D6D7B76797D7B797874767B79
76787976787B7978
7B79787972727674707477727474797B7574787071735F59
4345362A2331281821203AB093666060623C2B221A161E2E
282528231F161C23111118161D2D535C5C53535A52515257
474134100C2428253C602B4A374F5976675E354649474435
53685E655C62556776726D707B7372767074707478797676
7676767074707476
6F6F6F7478757276757974767579746F7074726E736A5F55
3E3527222E2A242B2E2BB9A960636A666264876757574948
3F4C5C464850544E4F85929AA1896C5C5657595A57535150
4E4C3F21110D192E394C553A48415A5A733D42503F4A473E
60515A6745564F808A746C6D7375756F7679787970747670
7476707679727776
7B75747770767B79727772777879787B73787570716B5B48
352C33332A262327262E8A5F65685F63646C757EA7B8AEAB
BCAF9FAAC4B4AEA2978F706A6764605D5E5C575752585350
4B50452F1C0A3B2C292D372C442C384E5A4E614C3B374355
5A415D63494F3C76756E6F6F7C7B7B757776767678797076
7474787970767976
6F767B797879707478797277706F7476737170756D4C493F
2F2C25242719262A258FA56869636A64696566676B646D70
705F63615A4D4F53595F5A616D615B615E595B5954554F45
484D3D3013142E2B56465C332846555D5A716A4849573F35
314368634A5F508A76666B787D7676727776706F6F747879
7879767678797670
7477706F6F6F76727376787972797474727473737764412A
253528281C282D2829927461646965636A676B6765636563
625D6362625961655E615B695A63615B54565E58544F5656
504D473A28260E24252627303A453444595A3C4F4B473A4E
3E57575752464B7669716477757476727770767B7B797074
7676706F74767678
7B7476757479797875747676787978797875747350493D35
35242C1F271D252A1E8161616767686B6566686767646667
5E5E545E554F585C5A5D61685B5B646F62615A575557504C
4841413E2713172E373E40503B2B27493C3D6D6B3F493250
4E5E4D5F524077807470767F767976787978747476767277
7074787B79767676
767879787B797676787474767676706F6F767B6C53413C30
2F3627262C2A2D1D5A9A6063696867676F6C64666768605C
5048444E4B4D5253575B605C646E6A57585D585652554F51
54534437302127252E26372D382A352152784A4346544042
41514F655A4C885D77737F81797676767074787976767874
7077767074767676
6F74767676767074707077767074787B73777074573D2D28
2423231E1C26291C978A6566696767676563646767676157
515D50514F4A4F5453595A5E595F6266616A645D5A574F51
50414344311C071023293A263E363B2461333D7C52494C46
494143625E6B77686B4F7276767676767277767676767678
7B79767277767676
7B79767676767874767B797076797676787A786B42342823
271D25252D2A1A188761616167626B6F696768646A3E2454
706659281A2F4C2F3C515A686A6A6464675D55575A555853
504E493736260F191B23282A3A35293C2C3264484B49452A
393A556A5C8956714F808E76767676767879767676767676
7676767879767074
6F6F74706F74767879706F767474767676767060352D2D38
29292123291E193594646A6E726A6366606563676E738E88
6868626E8D87786854495A676463636357636D645B59574F
494944463F34090E1420293129382A2F0F614C3E673A4535
404B5050605C404E7F9E7074767676767074767676707476
767676706F747879
7B7B79787B797074767274777879766E7376786137292B18
1F2B262C2C17185288656662686B71706C6B6864695F6D73
716968635E5C56555D63676763666463675E54575D5C5A53
4848433E363408150F2B3139223728321A5C3B606E374A3C
48474A5C676160778F767277767676767879707476787976
7676767875777676
767676707470767970767577766E7373737470592A262E2E
2D282A2F251520A2906C6B72706A6869686C645E6B6E7073
6C62625F5A545658545E64666367636664666D615E5A5A56
5852473F382D1605122912302D412029364A415A4D4E4549
403E3A54685369958E767879767676706F74787976767676
7676767678797676
767676787978797070777272747875767B79702D1A301B1C
21272A270E16127F676861696968696A6A6A6D6E6A5D6566
63676452494F565058636E6B64686B656162636761585959
5854473F3D3B2C0A101E36362E37252F2439474856703D3D
334155796E415F807474706F6F7476787577767676767676
7676707476767676
6F6F7476767074787B79787B74747277767670302B241B32
2F2D280A131621936A70706E676868676767696B64656367
605B5357545B5B5B65706B6363646762676463635B605C5A
5257514C3E3729091D1A2222292737312E4A4F4F5C713B3E
333E40515C72A78E7879787B7B7976767879767676707476
7676727274767676
7B7B79767076797676767670767476746F6F71352B242A32
26272A18151896B5686A686969697275756C6A696D6C626B
6D655A53565C60636768696666666E6A676364635B5B5D59
534E4E4638363714091A172C36282F372F3E585B5F6C2F4F
2E473C6B7568837976767676767676767676767676787976
7676787B79767074
6F6F6F7478797676767670707276797274794E1E28222D2E
2A29130E0EACCD776E766B69726C666161646867676B6B6F
696368625B60605C6066626D75686B606E6C6C66676C625F
5B57535646393427222A302E362E3B30273F6254585E3E3E
213F3F626A878D7676767676767676707476706F74767074
7074767676767879
74797577767676767670767B757776787B79181324162E26
252A1625279D696B6F6664727267696A726C6969696A646A
696D695A565E62646262676F636B6F6E6561666866645F5D
575A5250403D302522231F2D2C35392F43595E4D4D4D3D34
2344556677857C7676767676767676787976787B79767874
7679767074767676
7477787976767676767879767277767670742C36251F382F
2A2320185BA46B6E686872726465696A676472756C686C6E
685E5E5856565D5F68696964626A685F5E6F6A6662636663
58585452443B2F2B1A192027273535362F5B5C5050545D3B
414A42598882767676767676767676767676707470747678
7976767879767676
7B7970747074767670747676787976767874273B2E2B2428
2A192437B094696A696966616468696961666661646A6A5C
646C73615B595D5E5C5E61646664676671685B5E6063615C
635D52504F443B2E2621221F2D323228236754474E4C5725
3C40435C8379767676767676767676767676787978797074
7676767676767676
6F7478797277707472777676767676707434122B2635322E
1C1B27A5B7656B6D696969726C696A625D5C5F61686A5E64
6E696A635A5755505A505B645F6A6663645C5E636363635E
5F565A584946383028162021273C3230355E405055285A1C
344E5B648C7A767676767676767676767676767670747879
7676767676767676
7B79767076797277787976767676767277244345253D2629
192A2E8362596A68726C69676463604F5861605E62676469
6B696A6050565155545F6C63685E5654585C606062646162
575F5B5252483C312917131E29303332315C4C4C4E1D5928
34445C7B9376767074767676767676767676767672777676
7676767676767676
7676767277767874747676706F6F6F76791444293A342F29
143F97A44F5C6F69666469625D5C5E635447535D6062595D
67686A54504D5453515760615754504E4B47404648535859
5E635652484239392F280F181E302F3A2D51523A3B1E7B34
2A5764788776767879767676707476767676767678797676
7074767676767676
767676787976767879707472797B7B797F2D47212D273210
2E317E423F6B6E686969635A482D2234413C4D4C64696365
6D6B6A64594D4948675E66514B433A2D2D3D4445495E5F52
4E4F51524E46412F282725221C2D29312E4C3E373E2B7C23
2660516E8979767676767676787976767676767676767676
7879767676767676
6F747676767074707478797879767676271B3D202A23311A
3C999343596E6466695D482426566927162B4739304D6060
6C69695F5B5058494B110E1F446E361930322B2C32464B51
585950514943373634283218162F2D313B4E4F3B4029732B
4677618B8170767676767676767676767676767074767676
7676767676767676
7B7976767678797879767670747676762E5140361929361B
1473595764736E6758482A377A952920263534494D5B465B
6E69615D595446383C593581B12C1C335028553E2C36484D
5557524D4F423A3728241706113033213649412D3B386D19
566D578F7F76767676767676767676767074767874747676
7676767676767676
7676767676767676707476787976767F9C521C1D16312B2F
459E4C445365605B4B35260E2D412B7D0A2F192533405671
6F6966625E614B47343D5536371374092221590C193B3F3C
4C4E504444413C2C282A110E15152525483A363E4837631F
514E69927676767676767676767676767879767678797676
7676767676767676
76767676767676767879767676767620262C3E312C342D35
55793E4D5D6A6853463C1A31370800051B4E355058707670
676765615F5C58524F3F2B42450C080B211D151E3746443F
46494C463F38262931272216252821233B3C362C3D3E672F
58548B8E7676767676767676767676767676767676767676
7074767676767676
767676767074767670747676767676263F402B2038322527
4D5F49535B695F616C6C6956372E383C3440597A8382716D
6D6D6561656B645F5F59532D314F694F2F23284A66634F56
5D55464948392C302B2C2719221B192441473D35454F6831
515B8A7C7676767676767676767676767676767676767676
7879767676767676
767676767879767678797676707476925C24172023201C3F
574945455064686D787C839CA7ABABB1BAAA74625B64726E
69676B6C6B6559494F496179835F59647994A0907F777669
5D534C43434131352D1C1B16202D2C233B4E37324F536334
5694AD7F7676767676767676767676767676767676767676
7676767676767074
76767074767074767676767076797F89111E141C1D3A1C2B
34464A4155715B636C6C717679805B341E151B59757E726B
756C6A6A697265604224232030698B908D7F766D68635A52
433444463C35363129301A16171B102634373033514F6C3B
5C8B7C707676767676767676767676767676767676767676
7676767676767879
76767879767879767676767879766371112517222B2F2643
3E3D3F424F655E5A576568685E231722326AA3A17770716C
6E676A6A6C6769706B593222222134485B666B6063564E40
2E4B4A3E3732352F1B19131D1914314042473C2F4C445446
5D937F767676767676767676767676767676767676767676
7676767676767676
767676767676767676767670747F38691E282A2F1A2A2832
2D28343E516B6B3B33342C23101C5CA9C7B4937F7977716F
68646867696A686A768A95937045201711121D23231E2131
4E554B4B3C3738294214262D261A142E3C3F343352593F23
739F76767676767676767676767676767676707476767676
7676767676767676
76767676767676767676767277733E1804263B332C2C252C
2F343C3A5A6F677890624A4771B6BE967773716D6D6D6D6E
67697275746C6C6D6E6A6B7789A1B4B87A4C38353751655C
545751473A3B422C192327180B0B113B3E2B3D3C59542B49
A28B76767676767676767676767676767676787970747676
7676767676767676
767676767074767670747678797660352C294B4034322934
3334413E56696364687F9AA29B7E6F6D6D6D6D6D6D6E6D6C
6672726D64636768686B68696E666465698EA596857A6358
604B3E383741403B2C21110B0D0F1464382C683D3F59345D
9E7F76767676767676767676767676767676767678797676
7676767676767676
76767074787976707679767676764717223156382A303233
2E2F423A586A6868676C6968727569636A6D6D656A6C6C6D
68666A6464726C6A6B6A6C66676263605C6656565650504F
4F464E4D3D3C3C2B3C2A181A1621186443345237375B2F78
A47976767676767676767676767676767676767676767676
7676767676767676
767678797676767879767676767663273F3C3C2A383A312C
2A293637465C60646563676A666A706D6E6D6D6F716D6D6D
6F74727075696468636161656A616261665F5B5D565A5756
5353513B38453B392313201F0F0D11603C39653C304A2BAA
957076767676767676767676767676767676767676767676
7676767676767676
76767676767074767676767676767F2F2C25242B32272C2C
312E484A58685B6366686C6968666A6F716D6D65636A6D6D
6D6D64616164695F636767635D5E635858595F5C56585554
44463F46463D3325211E28120D0F20435354623D3E2F5FB6
797676767676767676767676767676767676767074767676
7676767676767676
7676767676787976767676767676811B3830383D3C373230
2D36404C525A5D6A676D6D696A727265636A6D687171646A
6D6D6769696A6B6E726967646263635B5A58585959595253
53504542434137301E281310141016404E2E464549358A96
767676767676767676767676767676767676767879767676
7676767676767676
76767676767676767676767676767C332D2C3D3A2B302A2C
3D393D464C5760636666616769676A6F6A676A6F68636D6A
626165696A6A69636765675F696662666563645D55565354
444845434432332F2821120E0909384138355B4F6C66BF8E
767676767676767676767676767676767676767676767676
7676767676767676
76767676767676767676767676767C154155332F31312E3B
202C45504855636566666D6D697171646D7471656D6D666C
6C6968696967696B6D6B606266606357615C585154585354
4855474434302A1F2B1A0D09180B3F3F382C4A484C88AA76
767676767676767676767676767676767676767676767676
7676767676767676
767670747074767676767676767673906125242927282E29
353D424A565F6465676E6D68696E6D686F656A686665716A
64686A6A6A6B6969695E656D6260635B65595C5657575A56
4F563F39363C3D331E170E10190F483B3D3555535D9B8676
767676767676767676767676767676767676767676767676
7676767676767676
7676787978797676767676767676768926262C242A2A242C
363B4F4D565C65656A6166686A676365666C716F746B656C
6C6B6A6969696A6A5E636A67616C666669605E5658515652
57493D47443129181610120A110E503A32305B6881987676
767676767676767676767676767676767676767676767676
7676767676767676
7676767676767676767676767676767361412E2E2F2D2F2C
29373F46515C656669686E6868706A7074726D6D646D6D66
6C6A6968696969696770696264625E6263575857585A5351
4647483C3A3C321B1B13170F1515514E324257679B907074
767676767676767676767676767676767676767676767676
7676767676767676
767074767676767676767676767676768738252428292C30
2B394A545F5F6A68616264686B6866686A656A6465686469
66646A6A6A68696965656067666163635B5C635F5958534E
5045433D382C261B1C16141A1C0F3E423756687C89767879
767676767676767676767676767676767676767676767676
7676767676767676
7678797676767676767676767676767678333F3134322B2E
313D384A5E6B64616B6C6E6D696867707166676669676868
696B6969696A6A63636764645F6062635D5E585454585458
4B414238342C231B1F1814190E094137314E63918B767676
767676767676767676767676767676767676767676767676
7676767676767676
7676767676767676767676767676767676AEA25B46404333
2E39494D4D5965686064626166686966636669706C696A6B
6A696468636161636D6466605F626357595E5A565F524F52
3F423A3B302721291D1C140E07246941425B5E8A76747676
767676767676767676767676767676767676767676767676
7676767676767676
76707476767676767676767074767676767C95BB4D382B32
37353B4E535863636369686E6D6567696A696A68656A6969
69696B6D6567676D675D5E5F646363605B585A5E57485343
454A3929222D241C1C15170C095E562B424C7A9678797676
767676767676767676767676767676767676767676767676
7676767676767676
7678797676767676767676787976767676736D7F522D2E28
3134434A525E60555F6064615D6265696A69636769696468
616160616367635B585E636263626259595C5C5455555157
48362E313231331C1B170E097469332F52759B89706F7476
767676767676767676767676767676767676767676767676
7676767676767676
767676767676767676767676767676767676767C671B2B4A
3445474B515A6166696260656A6F69636763696D69696B67
646E695F645E65636362636363625A5D5C5B545353404A47
3A3B3B3B2F232643150C1142383337435B708A7D72837C76
767676767676767676767676767676767676767676767676
7676767676767676
767676767676767676767676767676767676767C43353725
2A473F4B565D5559616263645D6862666663656161616760
605B585E545A5F5D62626263626357565855545751464839
32332D272A2E30182328372C49454A586F6B84837B767076
767676767676767676767676767676767676767676767676
7676767676767676
767676767676767676767676767676767676767C3E53242A
2D2A32424746565D5A5F5761666561605C5F65676D61605C
6060565154585E635C55585451514C54534C4E483E434440
3B413A282723242026195A4E4733605771A49A736B74767F
79767676767676767676767676767676767F797676767676
7676767676767676
767676767676767676767676767676767676767373881721
3D2E3C4445595E5458575764605D5D6564625E5D5A5A6060
5B524E535559584B4A4F50484E544C544E4F4A4C483F3D41
3D39292C322D41382D46613A45566B74717D747678837973
707676767676767676767670747676767673707676767676
7676767676767676
76767676767676767676767676767676767676767F453B41
3238373537434C635A5559575F6464615D59575757524945
484E4B4B45423F40464543453E3A3D403E3838423F403E2F
2734392E3C43262F44443930504860669199797676737076
767676767676767676767678797676767676767676767676
7676767676767676
767676767676767676767676767676767676767676937847
343337464C3D3936495B636C68595757574D4D454A5B504F
4E4E3F453B433D4C3740333733343D3A393C41364050454D
4C4A32334147331D2143514C5267715F857A767676767670
74767676767676767676767676767676767F797676767676
7676767676767676
7676767676767676767676767676767676767676767692C3
6E492C363A2844556B706E665B5B554F454A4F51524A4953
433F3C403C433E3037412F2D3E3840323438383B29232935
3236394329233047524A3B51787248929A76767074767678
797676767676767676767676767074767673707676767676
7676767676767676
76767676767676707470747676767676767676767676767B
39404B474C707B575A4445505550504E4F544145514A4146
45433E41324A3C524D3B4D49365045474640454B31384342
33384332393C3D333A4A727C605079A0767676817C767676
767676767676767676767676767879767676767676767676
7676767676767676
767670747676767879787976767676767676767676767676
A94A433C31333539455561564C4A524747473E473C3F4046
3C4A3C323C2C363A41373A38435729313247402E302E2418
1C2C2220272631426378854B4F35878E7676767370767676
767676767676767676767676767676767676767676767676
7676767676767676
767678797676767676767676767676767676767676767676
73AD75444663606272685C5B49454648474D4B4F413F4A41
3536264249311D33243C443F40242A461C152227282C393D
473C382F3A42826D70711C2D3574BB797676767676767074
767676767676767676767676767676767676767676767676
7676767676767676
767676767676767676767676767676767676767676767676
767345462B2D212B455356595149453E454940393F4A393C
472E564B295341303F34252E2427281723333B2A2C363027
21293E585F6F596870302E5F3EA48C707676707476707679
7676767676767676767676767074767F7976767676767676
7676767676767676
767676767676767676767676767676767676767676767676
76769E2A396A4D49484E574F4C34393A4A4B413442423B4C
3D4A2B283A2D3532302D2D2F2C282A2F31251E262E2A272A
39504B3F38516632192D6559A4B46F74767076797076797F
797676767F79767676767676787976737076767676767676
7676767676767676
767676767676767676767676767676767676767676767676
767673AD6418395E5B46565F5B394B3D38393534433F3439
313B29463837241B4529292E2C2C26241B1822231F294035
3749615F8C804D3C365A2F87BF8E79777678797678797673
707676767370767676767676767676767676767676767676
7676767676767676
767676767676767676767676767676767676767676767676
76767074AF66211F31425F5F54372F48444C5450363D402F
3C43323E403E3B1A1E244E312B1B2B251F1B1D1817242D4B
6C574E6446111C38463357B87C6D72797670747F79767676
76767676767676707476767676767676767F797676767676
7676767676767676
767676767670747676767676767676767676767676767676
7676787973714431263B47485740373C45362A32302D323A
362E41412D3C3F4248291E292E303A304A3B3941545D575A
5A825A492C1A37424F5AC8A8767676767F7B747170767676
7F79767676767678797F7976767676767673707676767676
7676767676767676
767676767678797676767676767676767676767676767676
7676767676848058452F1D292D5C373136433E332728272A
2E37392C2F4247404031543329434239383B525F735D5C7A
5B412F3C1E3C5E4A3AB8B97F8379707D70787B74747F7976
73707676767676767673707676767F797676767676767676
7676767676767676
767676767676767676767676767676767676767676767676
76767F7976768A6E433F464C464C5B43333F443A4F32302F
3A3A3C2846404B424F64422C34413D525A5E596C675D3C29
221A0D153A543E4ED6C47073767D7B767C79707879737076
767676767676767676767676767673707676767676767676
7676767676767676
767676767676767676767676767676767676767676767676
76766D6E76707492863A3749515453694A482A413C43452E
261C2A293F38534D8B96887D978B7E7891987B6F3B1D2A32
2425396167433EC9B4707F79736D707673707074767F8379
767676767676767676767676767676767676767676767676
7676767676767676
767676767676767676767676767676767676767676767676
76767879767883798DCB68391F325C63695353514C475A7F
5D333D2A3C566A573A45596979848972472A2D2A24343721
25414D5D3C4ACDC170707170706F74767670767976736D70
707476767676767676767676767676767676767676767676
7676767676767676
767676767676767676767676767676767676767676767676
7676767676767C747679B15833473A456C67718376988F61
8CCAFFF3DEB194788E8668686F4F2131322F30342B312647
64594B3CBFEDB57F747679767875777676787474767F7976
72777670747F797676767676767676767676767676767676
7676767676767676
76767676767676767676767676767676767676767F797676
7676767676767C747676739FD9422C3F40567B857A766877
825B4E4B506676776F6A5338493A47552B382D2D40537178
534264D1C26B746D70797676767879707476787976737076
78797678797370767676767676767F79767F797074767676
7676767676767676
767676767676767676767676767676767676767673707676
767676767F797C7D797F797689AD69443A524E4C51606E71
6E6D867D736F6C605F555B4B363C322C2E4D32536966573D
4EA4D5A876727778797F797F797670767976767676767676
7F797676767676767F797676767F767076737A7B79767676
7676767676767676
767676767676767676767676767676767676767676767676
767676767370736D70737070717FADEC6D32244A63716E67
62585F55544C3929263645404227305C55727B8D6C4257B7
DAB78576767883797673706D6E76817C7F79767670747F79
737076767F79767673707676767370767F837F6E74767676
76767F7976767676
767676767676767676767676767676767676767F79767676
767676767676767676707D7B797C74769AE2F16A333C4048
6471706B73786A716359425C8D719596835C3C5C94D4E7B5
7C76767F79767370767F7978797673706D6E767678797370
7F797F837F7D8379767676767F7976767C7A707C7C767676
7676737076767676
767676767676767676767676767676767676707170767676
767676767676767676787670767370767F797F9AD3714759
4241575C6A6A819FA0998E9575735B374673B0C59F867A6B
6E7676737076767074736B74767670747879767676767074
7370736D6D6D686E7F74747673707670716D70736B747676
7676767676767676
767676767676767676767676767676767676788379767676
767676767676767676767676767074767C6E6B6E7692BDB6
AEA8917D887D5E3F394E5F5D59648DBDC5AF967F767C7A75
8383837976767678746F76797676787970747F7474767883
7976767676767879737C7C7F7976767879767676817C7676
767676767F797676
76767676767676767676767676767676767676736B747676
76767676767676767F7474767678747473727B797676787B
858285888880899DA6A0A8A3A3A19481797F837976737674
736D6D6B747F7976817E79767F797F79817C6D7079707473
7076767676767676766D6E737A797676767F797673707676
7676767673707676
767676767676767676767676767676767676767678797676
76767676767676767372797676707679707D797676707470
71707F747476787B7B7B7F747670747676736D707F797C74
7676707F7C7C7D7973707676737073707C6E707770767976
76767676767F7976767879767C74767670717A8379767676
767676767F797074
7676767676767676767676767676767676767676767F7976
7676767676767676767676767678797F8579707670767981
7C76737C7C767F7976766D6E767879767670747F76707C7D
797678706E73686E7F797676767F797673727B797879767F
74747676767C74767F7976707170767678796D7474767676
767676767370817C
76767676767676767676767676767676767F797670717070
7476767676767676767676707D797673686E767678747D70
6E76767C7476737A79707679707476767678797370767376
74767076837978796D788379766D78797676767F7976767C
7579767F79737A79737A837B797F79767670767670767676
76767F7976767370
767676767676767676767676767676767673707678797F7B
797676767676767676767678767076767879767676727472
797F74717A79767370817C7F7B797676767670747F797673
70767879737076767876686E7678767076707D707879767C
747670717076737076736D70767370707478797676767676
76707A7476767676
76767676767676767676767676767676767676767F797370
767676767676767676767074767676767676767676727274
767372747A7D79767F706E737076767F79707077737A7474
7F797F79767F797F79767879767F79767678766D747A7973
707F7B79767F797F79767F7474767678797F79767F797676
767876707676706F
767676767676767676767676767676767676767673707F79
767676767676767676767883797670747074767676787B83
79767678766D70707A7579767676767370787B7970717C7C
7C747370707A6E7A74767670747370767676767883706974
76736B747673707C747673727976767F7973707673707676
767676767074817E
76767676767676767676767676767676767676767676736B
7476767676767676707D79736B747874707776767F837973
7070747676767076767A79707D79767676767F79817C6D78
766B747076767C797070747883747D797074707D767C7E79
767076797676767370767676767676737070747676767676
7676767678797370
767676767676767676767676767676767676767676767678
797676767676767678767076817C7F7B758183796D747476
7678797676768186797370787F7476767676737A76707876
70818685867973707672777F7672767A8586857970737076
76818679767676707476767676767F797678797F79767676
7F797F79767F7976
7676767676767676767676767676767676767F797F797670
747074767676767F7976767673706D6E7274686E78767076
767670747676736D707F797673707F74747F837670767676
76736D6D6D707F79767879736B7476736D6D6D7A797F7976
7071767476767F7B797676767676736B7470747370767676
7370737076737076
7676767676767676767676767676767676767C74737A7978
7978797676767673707676767074787978797883797F7976
76767879767676767F7F747676707172837F707076767676
76767676767F7F7D79767676787976767676767C7D7F7476
787973707676737076767676767F7972777277767F79767F
7474767676767676
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[38]:=",
  ImageSize->{450, 295.313},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007200019b000`400?l00000o`00003oo`3oooo3
0?ooo`00o`3oooo30?ooo`00o`3oooo30?ooo`00o`3oooo30?ooo`00o`3oooo30?ooo`00o`3oooo3
0?ooo`00o`3oooo30?ooo`00o`3oooo30?ooo`00o`3oooo30?ooo`00o`3oooo30?ooo`00803oool2
0861P@0808F5Q@26QXH0PH6108:2PP20P800OWin07moO`26QXH3079bLP0307MgM`1cLg<0Lg=c0080
Lg=c00X0Ph>307YjNP18B4P0KFe]07AdM01^KVh0JVYZ06m_K`1`L700JFUY0P1_Kfl0201`L700Jf][
06YZJP1_Kfl0KVi^07=cL`1_Kfl0L71`0P1_Kfl01@1aLG40IfMW06m_K`1_Kfl0KVi^00H0M7Ad00D0
MGEe06m_K`1_Kfl0L71`07EeM@0306m_K`03071`L01_Kfl0Kfm_0080Kfm_00<0L71`06i^KP1_Kfl0
0P1_Kfl02`1`L700Jf][07MgM`1jNWX0DU9B06][J`1ZJVX0Kfm_071`L01[Jf/0JVYZ00@0KVi^00H0
KFe]07=cL`1cLg<0Kfm_071`L01cLg<207MgM`0307QhN01bLW80Lg=c0080Kfm_00/0JFUY06QXJ01[
Jf/0Jf][069RHP1iNGT0Ng]k05iNGP1kNg/0PH6108J6QP0N0?ooo`80/k>c00P0^KVi0;bl_02c/k<0
]KFe0;:b/P2^[Zh0/K6a0;^k^`<0WinO00<0YZJV0:2PX02PX:000P2PX:002P2f][H0[:b/06=SH`2G
UiL0XZ:R09VIV@2CTi<0Vi^K09bLW02BTY8209ZJVP0609fMW@2EUID0Ti>C09^KV`2IVIT0X:2P102K
Vi/01@2MWId0T92@09^KV`2KVi/0VIVI00D0XJ6Q00H0XZ:R0:>SX`2KVi/0VYZJ09bLW02SXj<609^K
V`0609ZJVP2KVi/0W9bL09VIV@2KVi/0VYZJ0P2KVi/02P2DU9@0YJFU0:^[Z`1aLG40UIFE09>CT`2K
Vi/0W9bL09FEU@2CTi<409VIV@0609NGU`2PX:00X:2P09^KV`2LW9`0X:2P0P2UYJD01`2WYjL0WYjN
0:6QX@2JVYX0Vi^K09:BTP2ATI400P2EUID01`28R8P0ZJVY0:f][@23Ph<0Zj^[0;>c/`2l_;`07P3o
ool20<_;b`080=7Ad@3>c/h0bl_;0<[:bP39bLT0cLg=0<[:bP2n_[h30;Bd]0030;Ng]`2e]KD0]KFe
0080]KFe00X0bLW909BDU02JVYX0/K6a0;2`/02][Jd0[:b/0:n_[`2ZZZX0Zj^[0P2_[jl0102[Zj/0
Z:RX0:b/[02_[jl20;6a/@@0[jn_00D0ZJVY0:^[Z`2_[jl0[jn_0;>c/`050;Jf]P060;Bd]02b/[80
[jn_0;6a/@2d];@0/[:b202_[jl20:j^[P@0[jn_00X0^;Rh0<K6aP2JVYX0Vi^K0:RXZ02/[:`0[jn_
0:^[Z`2XZ:P0Zj^[102][Jd01P2a/K40];Bd0;6a/@2b/[80]kNg0;Vi^@80^k^k00H0]kNg0;Rh^02`
/;00[Zj^0:RXZ02TY:@20:NWY`080:FUY@2c/k<0_[jn0:RXZ02YZJT0bLW90<o?c`3>c/hR0?ooo`00
803oool03021PH40PX:207alO020P800QHF508b<S028R8P0Ng]k08J6QP2EUID0QHF507AdM0@0Lg=c
0P1bLW80301]KFd0TI6A05aLG01^KVh0M7Ad06m_K`1ZJVX0IVIV06][J`1VIVH0JVYZ06m_K`80MGEe
00<0K6a/06][J`1_Kfl00`1_Kfl05P1YJFT0I6AT07IfMP1ZJVX0JFUY06m_K`1ZJVX0K6a/06m_K`1/
K6`0JVYZ06i^KP1bLW80M7Ad07EeM@1]KFd0JVYZ06m_K`1aLG40LW9b06m_K`1`L70406m_K`03075a
L@1^KVh0JFUY00<0Kfm_0P1QHF400`2@T900Bd];05=CD`0206m_K`0=071`L01[Jf/0IfMW06MWI`1[
Jf/0L71`075aL@1^KVh0Kfm_079bLP1`L700JFUY06e]K@0206i^KP0607MgM`1cLg<0M7Ad06m_K`1f
MWH0MGEe0P1_Kfl02025QHD0Ph>3071`L01cLg<0HF5Q07]kN`1mOGd0PH617P3oool20;>c/`090;Ng
]`2h^;P0];Bd0;Rh^02f][H0[jn_0;Fe]@2o_kl0ZJVY0080X:2P00<0Y:BT0:2PX02PX:000P2PX:00
4P2[Zj/0_Kfm06e]K@2HV9P0XZ:R09ZJVP2DU9@0UiNG09ZJVP2BTY80V9RH09^KV`2NWYh0VIVI09FE
U@2HV9P0VYZJ09jNWP80Vi^K00`0VIVI09JFUP2OWil0TY:B09RHV02KVi/0V9RH09jNWP2OWil0WYjN
09fMW@2NWYh20:6QX@0409jNWP2JVYX0VYZJ0:2PX080W9bL1P2KVi/00`2LW9`0VIVI09VIV@0309^K
V`0?09>CT`2MWId0^[Zj079bLP27QhL0UYJF09^KV`2LW9`0UIFE09>CT`2FUYH0UiNG09ZJVP2KVi/0
V9RH0080WinO00<0W9bL09ZJVP2NWYh00P2RXZ80402UYJD0X:2P0:6QX@2JVYX0WIfM09NGU`2DU9@0
UYJF09ZJVP2FUYH0YjNW0:RXZ027QhL0Zj^[0;>c/`2i^KTN0?ooo`80bl_;00T0e=CD0=;BdP3:b/X0
aLG50<C4a03=cLd0aLG50;bl_02WYjL00P2d];@00`2j^[X0]KFe0;Fe]@020;Fe]@0B0=SHf02KVi/0
S8b<0;2`/02a/K40[Jf]0:VYZ@2b/[80[Zj^0:^[Z`2b/[80[jn_0:b/[02TY:@0Z:RX0;:b/P2a/K40
/k>c0P2_[jl0202^[Zh0/k>c0:ZZZP2VYZH0/k>c0;2`/02c/k<0^[Zj0P2h^;P20;Zj^P040;Bd]02f
][H0Zj^[0;6a/@80][Jf00<0[jn_0:j^[P2_[jl01@2_[jl00`2^[Zh0[Jf]0;2`/0030:n_[`0:0;Rh
^03Bd]80VIVI08j>SP2l_;`0Z:RX0:n_[`2[Zj/0Z:RX0:^[Z`80/;2`00<0[Jf]0:b/[02`/;000P2d
];@00`2`/;00^[Zj0;Zj^P020;jn_P0@0;^k^`2e]KD0/;2`0:j^[P2XZ:P0X:2P0::RXP2XZ:P0WYjN
09fMW@2i^KT0][Jf0:>SX`39bLT0d=3@0=;BdR80oooo000P0?ooo`0407moO`1mOGd0PH610861P@80
Ng]k0P21PH401024Q8@0S8b<09bLW027QhL2079bLP0]075aL@1`L700LW9b071`L01[Jf/0YZJV05QH
F00m?Cd0Kfm_075aL@1XJ6P0IfMW06m_K`1cLg<0Kfm_071`L01_Kfl0L71`06m_K`1TI6@0IVIV07=c
L`1`L700K6a/06m_K`1ZJVX0HV9R06ATI01OGel0HV9R06][J`1/K6`0L71`07=cL`1_Kfl0JVYZ06m_
K`1YJFT0Kfm_079bLP1hN7P0NGUi079bLP1fMWH0MGEe0080L71`101_Kfl0401aLG40MGEe06m_K`1`
L700Kfm_071`L01QHF40Vi^K0;Vi^@1JFUX0ADE506IVIP1[Jf/0Lg=c06m_K`1[Jf/306YZJP0406m_
K`1fMWH0LW9b07IfMP80LW9b0180MWIf07]kN`1fMWH0MgMg07AdM01`L700Kfm_071`L01bLW80NWYj
06][J`1aLG40SHf=07MgM`1ZJVX0LG5a08>3P`26QXHN0?ooo`0<0;>c/`2b/[80]KFe0;:b/P2a/K40
][Jf0;Vi^@2d];@0^KVi0;Rh^030`<00Zj^[0P2PX:0209nOW`0/0:2PX02OWil0V9RH0<G5a@1oOgl0
PH6109nOW`2KVi/0UiNG09>CT`2FUYH0V9RH09NGU`2KVi/0VYZJ09^KV`2LW9`0TY:B09FEU@2MWId0
Vi^K09ZJVP2KVi/0Ti>C09FEU@2FUYH0Shn?09FEU@2IVIT0VYZJ09jNWP2OWil0Vi^K09RHV02PX:00
V9RH0:2PX02LW9`0WYjN09nOW`2LW9`0WinO09jNWP2LW9`509^KV`80W9bL01`0Vi^K09bLW02KVi/0
W9bL09>CT`32`/80Zj^[07QhN025QHD0UiNG09VIV@2HV9P0UiNG09FEU@2CTi<0VIVI09RHV02JVYX0
XJ6Q09bLW02QXJ40W9bL09nOW`2QXJ40Xj>S0:6QX@2WYjL0XZ:R0`2JVYX02P2LW9`0VIVI09FEU@2W
YjL0^[Zj09^KV`2CTi<0YjNW0;Fe]@2f][HN0?ooo`0<0<c<c03=cLd0cLg=0<W9b@3?cll0e]KF0=;B
dP3:b/X0dM7A0<G5a@2f][H0YjNW0`2e]KD0202f][H0]KFe0;Bd]02n_[h0ZZZZ08:2PP3Bd]80];Bd
0P2/[:`0102[Zj/0Z:RX0:FUY@2YZJT30:n_[`0<0:^[Z`2][Jd0^;Rh0:f][@2_[jl0[Zj^0:b/[02U
YJD0/[:b0;2`/02^[Zh0]KFe0P2b/[803`2e]KD0/;2`0:n_[`2c/k<0][Jf0;Bd]02f][H0[jn_0:b/
[02[Zj/0[jn_0;2`/02[Zj/0[jn_0:j^[P040:n_[`030:j^[P2ZZZX0[jn_00<0[jn_0P2h^;P0301Y
JFT0Ng]k0<W9b@2b/[80[Zj^0:BTY02UYJD0Z:RX0:b/[02_[jl0/k>c0;:b/P80/;2`01D0/K6a0;2`
/02d];@0]KFe0;6a/@2e]KD0^;Rh0;:b/P2/[:`0[Zj^0:b/[02ZZZX0Y:BT0;Bd]03=cLd0];Bd09jN
WP2WYjL0clo?0<g=c@37alL08P3oool00200oooo00P0P82008:2PP1mOGd0QhN708:2PP1nOWh0Q8B4
07moO`80RXZ:00@0QXJ608N7Q`28R8P0SXj>0P1hN7P02@1eMGD0LW9b07AdM01_Kfl0RXZ:08:2PP1R
HV80LG5a07=cL`0206][J`0<06m_K`1`L700JFUY06i^KP1_Kfl0MGEe07AdM01_Kfl0Jf][06MWI`1/
K6`0Jf][0`1eMGD04@1dM7@0KFe]06MWI`1ZJVX0J6QX065QH@1RHV80IfMW06m_K`1`L700K6a/06IV
IP1^KVh0Kfm_06e]K@1kNg/0M7Ad0080LG5a00H0L71`079bLP1bLW80MWIf07=cL`1aLG4207IfMP09
07=cL`1bLW80Lg=c06][J`1LG5`0MWIf09FEU@1GEeL0HV9R0080MGEe0`1_Kfl06@1fMWH0Lg=c07If
MP1dM7@0MgMg079bLP1cLg<0MgMg07IfMP1jNWX0Lg=c07MgM`1dM7@0LG5a08^;R`21PH40R8R80820
P02>SXh0LW9b07YjNP1ZJVX0QHF508b<S020P8007P3oool20;Bd]00?0;:b/P2j^[X0];Bd0;Ng]`2j
^[X0[jn_0;bl_02g]kL0][Jf0;Fe]@2f][H0/[:b09nOW`2RXZ80WYjN0080W9bL00H0UIFE0;Jf]P2^
[Zh0QhN709ZJVP2MWId209FEU@0309JFUP2GUiL0UiNG0080Vi^K00d0WYjN09VIV@2FUYH0VYZJ09RH
V02JVYX0U9BD09jNWP2EUID0V9RH09VIV@2CTi<0Shn?0080V9RH00<0UIFE09JFUP2FUYH00P2KVi/2
09VIV@060::RXP2PX:00W9bL0:RXZ02RXZ80X:2P0P2OWil209bLW080WYjN00`0W9bL09jNWP2NWYh0
WIfM09bLW02MWId0VIVI09BDU02^[Zh0_;bl07=cL`2DU9@209fMW@0L09^KV`2NWYh0Vi^K09jNWP2L
W9`0XJ6Q09bLW02RXZ80W9bL09nOW`2VYZH0Y:BT0:NWY`2PX:00WinO09jNWP2IVIT0YZJV09fMW@2Z
ZZX0Xj>S0;Zj^P2ATI40Zj^[09RHV02_[jl0];Bd0:n_[ah0oooo0140c<c<0<_;b`3AdM40clo?0<[:
bP3De=@0clo?0<c<c03=cLd0a/K60<O7a`39bLT0a<C40:ZZZP2/[:`0/K6a0:^[Z`020:n_[`050;Ng
]`2n_[h0XJ6Q0:JVYP2/[:`0102XZ:P04`2TY:@0/k>c0;2`/02_[jl0ZZZZ0:BTY02XZ:P0[jn_0;:b
/P2_[jl0[:b/0:ZZZP2OWil0Xj>S0:6QX@2PX:00YJFU0;:b/P2^[Zh00`2d];@03P2_[jl0[Zj^0;6a
/@2j^[X0_kno0;Jf]P2m_Kd0^;Rh0;>c/`2h^;P0/k>c0;Rh^02^[Zh0/;2`0P2^[Zh0302`/;00[Zj^
0:f][@2][Jd0[jn_0:f][@2b/[80aLG50=?Cd`2HV9P0TY:B0;Vi^@80[Jf]00L0[jn_0;>c/`2_[jl0
[Zj^0:n_[`2a/K40[jn_0080/;2`00P0]kNg0;Zj^P2j^[X0]kNg0;Fe]@2][Jd0[:b/0;6a/@80ZJVY
00T0[jn_0;Fe]@2a/K40Zj^[0;6a/@2][Jd0`l?30;fm_@35aLD08P3oool00200oooo0240PH610820
P01oOgl0OGem07moO`21PH40QhN70820P01nOWh0O7al08>3P`25QHD0R8R809NGU`2?Shl0NGUi07Qh
N01eMGD0LG5a06ATI01^KVh0XZ:R0820P01bLW80N7Qh07=cL`1_Kfl0IVIV06m_K`1^KVh0L71`06][
J`1VIVH00P1ZJVX0101WIfL0K6a/06YZJP1YJFT206m_K`0:071`L01dM7@0NGUi06m_K`1OGel0JVYZ
06][J`1]KFd0Jf][06UYJ@<0Kfm_00T0JVYZ075aL@1`L700K6a/079bLP1aLG40M7Ad075aL@1hN7P0
0P1dM7@207IfMP0>06m_K`1`L700LG5a06e]K@1`L700Lg=c06][J`1LG5`0VIVI08f=S@1PH600Kfm_
07=cL`1fMWH307=cL`0307IfMP1eMGD0M7Ad0080M7Ad01<0KVi^079bLP1fMWH0MWIf07MgM`1XJ6P0
JFUY06IVIP1^KVh0P820069RHP1QHF40KVi^079bLP22PX80MWIf07inOP24Q8@0Ph>301h0oooo0P2c
/k<01P2b/[80/k>c0;Rh^02e]KD0][Jf0;>c/`80]kNg00D0^;Rh0;Bd]02l_;`0_kno0;6a/@020:>S
X`0F09fMW@2KVi/0VIVI0:NWY`33`l<0UiNG09bLW02SXj<0V9RH09NGU`2BTY80Vi^K09FEU@2KVi/0
VIVI09NGU`2HV9P0VIVI09NGU`2FUYH0UIFE09BDU0<0Vi^K00D0WIfM09bLW02DU9@0Shn?09VIV@03
09>CT`0@09NGU`2KVi/0Vi^K09^KV`2HV9P0XJ6Q09ZJVP2RXZ80Y:BT09bLW02RXZ80WIfM0:6QX@2L
W9`0X:2P0:6QX@80WYjN0P2OWil03`2JVYX0WinO09fMW@2IVIT0U9BD0<30`02NWYh0RXZ:09fMW@2O
Wil0XJ6Q09fMW@2LW9`0WinO0:6QX@020:2PX0040::RXP2PX:00WYjN0:>SX`80Y:BT00l0YZJV09bL
W02MWId0Ti>C09fMW@2b/[80XZ:R0:>SX`2][Jd0VIVI0;>c/`2FUYH0[Jf]0;Vi^@2f][H07P3oool0
1P3;bl/0c<c<0<g=c@3@d=00dm?C0<k>cP80bl_;0P3De=@03`3Bd]80b/[:0<g=c@2l_;`0Zj^[0:n_
[`2c/k<0[Zj^0;2`/031`L40d];B0:b/[02ATI40/;2`0:b/[0020:FUY@030:b/[02_[jl0ZJVY0080
[Zj^00@0/k>c0;:b/P2_[jl0/[:b0P2YZJT03@2][Jd0[jn_0:n_[`2^[Zh0Zj^[0::RXP2OWil0[Zj^
0:n_[`2SXj<0YZJV0:FUY@2c/k<00`2_[jl03P2c/k<0][Jf0;:b/P2m_Kd0^k^k0;6a/@2e]KD0/k>c
0:j^[P2_[jl0/k>c0;:b/P2][Jd0][Jf0P2d];@03P2b/[80];Bd0:f][@2b/[80aLG50;Zj^P24Q8@0
Xj>S0;Jf]P2c/k<0/;2`0:f][@2_[jl0];Bd0P2b/[801@2d];@0]KFe0;Bd]02j^[X0_[jn0080^[Zj
00L0]kNg0;Rh^02e]KD0^KVi0<?3``39bLT0dm?C0080cLg=00H0^KVi0:n_[`2VYZH0alO70=3@d039
bLTR0?ooo`00803oool02@21PH40Ph>308V9R@26QXH0Ph>308B4Q01kNg/0QHF508B4Q00208F5Q@0/
0861P@23Ph<0RHV909JFUP2LW9`0R8R807]kN`1lO7`0Ng]k06e]K@1hN7P0SHf=07AdM01iNGT0N7Qh
07MgM`1cLg<0JVYZ06EUI@1TI6@0JVYZ06MWI`1KFe/0GUiN069RHP1UIFD0IfMW06EUI@1_Kfl0MGEe
07IfMP1eMGD0MgMg07alO01`L700IfMW06m_K`1VIVH0JFUY069RHP1TI6@0IfMW06i^KP1_Kfl206e]
K@0306m_K`1[Jf/0K6a/00<0K6a/00D0KFe]079bLP1_Kfl0KFe]06a/K00406m_K`0706i^KP1_Kfl0
JVYZ05aLG02BTY80XJ6Q06YZJP0206a/K080KVi^00H0L71`07AdM01bLW80LW9b07AdM01eMGD307If
MP0@06m_K`1YJFT0EUIF05mOG`1_Kfl0NGUi07=cL`1YJFT0MgMg075aL@1SHf<0LW9b06e]K@21PH40
Ph>308R8R1h0oooo01T0/k>c0;:b/P2d];@0^;Rh0;:b/P2f][H0/[:b0;Zj^P2g]kL0]KFe0;:b/P2i
^KT0^;Rh0;^k^`2o_kl0]kNg0:ZZZP2TY:@0Xj>S0::RXP2KVi/0Zj^[0;Vi^@2MWId0XZ:R0080WYjN
01X0V9RH09BDU02EUID0UYJF09ZJVP2DU9@0SHf=09>CT`2>SXh0Ti>C09BDU02@T900Vi^K09fMW@2N
WYh0WIfM09jNWP2RXZ80UIFE08n?S`2HV9P0Shn?09VIV@2@T900UYJF09NGU`80Vi^K00@0VYZJ09nO
W`2PX:00VIVI0`2MWId01`2NWYh0W9bL0:6QX@2OWil0WYjN09ZJVP2NWYh00P2KVi/0202LW9`0WIfM
09^KV`2IVIT0Ti>C0;fm_@2[Zj/0V9RH0P2MWId00`2NWYh0VYZJ09fMW@020:6QX@030:2PX02RXZ80
WinO0080XJ6Q00h0Y:BT0:>SX`2PX:00Shn?096AT@2>SXh0Y:BT0:NWY`2FUYH0YJFU09ZJVP2HV9P0
[Jf]08j>SP80]KFe00<0^KVi0?ooo`3oool0703oool20<_;b`090<G5a@39bLT0bl_;0<W9b@3Bd]80
clo?0<_;b`3<c<`0b<S80080d];B01/0c/k>0;no_`2YZJT0YjNW0;:b/P2`/;00/K6a0;^k^`3<c<`0
];Bd0:b/[02`/;00ZZZZ0:NWY`2UYJD0ZJVY0;6a/@2c/k<0[jn_0:RXZ02][Jd0];Bd0:NWY`2][Jd0
ZJVY0:j^[P2_[jl00`2/[:`02P2][Jd0YZJV09fMW@2WYjL0YZJV0:NWY`2][Jd0[Zj^0;>c/`2e]KD2
0;2`/0040;6a/@2h^;P0][Jf0;:b/P<0]kNg00L0^KVi0;Rh^02f][H0];Bd0;Ng]`2b/[80];Bd00<0
/;2`00/0];Bd0:n_[`2b/[80alO70;no_`2:RXX0/k>c0;Ng]`2f][H0];Bd0;>c/`030;Jf]P030;Ng
]`2e]KD0]KFe0080]KFe00h0^[Zj0;Vi^@2m_Kd0/[:b0;Bd]02^[Zh0]kNg0<g=c@2c/k<0]KFe0:j^
[P30`<00_[jn0;2`/080cLg=00<0b<S80?ooo`3oool0803oool00200oooo00H0PH6107alO01nOWh0
QHF50861P@29RHT208F5Q@050861P@1jNWX0Ng]k08F5Q@22PX800P25QHD03@27QhL0Ti>C08Z:RP20
P800Ogmo07inOP1^KVh0QXJ608f=S@1;Bd/0LW9b075aL@1/K6`00`1[Jf/00`1SHf<0GemO06MWI`02
06MWI`0506ATI01WIfL0HF5Q06UYJ@1_Kfl00P1bLW80401aLG40MGEe079bLP1UIFD0I6AT069RHP1W
IfL0J6QX06IVIP1NGUh0GemO065QH@1UIFD0JFUY06YZJP1UIFD206IVIP80JFUY00D0JVYZ06IVIP1X
J6P0KFe]06YZJP0506EUI@0506UYJ@1/K6`0GEeM05QHF01gMgL00P1]KFd01`1_Kfl0L71`06a/K01]
KFd0LW9b07AdM01aLG400P1gMgL206m_K`80JVYZ00H0F5QH065QH@1QHF40HF5Q06YZJP1?Cdl206IV
IP0706][J`1cLg<0L71`069RHP21PH40NWYj0861P@0N0?ooo`0=0;>c/`2a/K40]kNg0;Zj^P2`/;00
_;bl0;:b/P2g]kL0^KVi0:n_[`2f][H0^KVi0;Bd]0020;Vi^@0A0;^k^`2m_Kd0[Jf]0:VYZ@2WYjL0
Z:RX0:2PX02g]kL0/;2`08^;R`2PX:00WinO09ZJVP2HV9P0UIFE09BDU02ATI400P2@T9001`2<S8`0
T92@08j>SP2CTi<0S8b<09NGU`2MWId00P2OWil03`2NWYh0Xj>S09jNWP2?Shl0Ti>C092@T02DU9@0
T92@09>CT`2=SHd0Ti>C09BDU02GUiL0Vi^K09ZJVP0309NGU`80V9RH00<0VIVI09ZJVP2KVi/00P2J
VYX409NGU`0L09FEU@2HV9P0VYZJ096AT@2EUID0/;2`09VIV@2JVYX0Vi^K09bLW02IVIT0Vi^K0:2P
X02RXZ80WinO0::RXP2PX:00WYjN0::RXP2PX:00XJ6Q092@T02:RXX0Ph>308b<S02YZJT0UIFE09JF
UP80VYZJ00H0X:2P09nOW`27QhL0][Jf0;2`/02i^KTN0?ooo`0=0<_;b`3?cll0e=CD0<o?c`3;bl/0
c<c<0<S8b03:b/X0dM7A0<k>cP3Fe]H0dM7A0<[:bP020=7Ad@0<0<k>cP2o_kl0[Zj^0;Jf]P2e]KD0
]kNg0<?3``38b<P0ZJVY0=7Ad@2d];@0/[:b0P2][Jd0302XZ:P0YjNW0:JVYP2ZZZX0XZ:R09fMW@2R
XZ80YJFU0:NWY`2YZJT0/k>c0;Jf]P80/k>c00l0]KFe0;:b/P2WYjL0YJFU0:^[Z`2ZZZX0ZJVY0:JV
YP2YZJT0Zj^[0;Bd]02e]KD0/k>c0;Ng]`2_[jl00P2c/k<0202b/[80];Bd0;>c/`2b/[80]kNg0;Rh
^02b/[80/;2`102c/k<01`2a/K40/k>c0:j^[P2g]kL0clo?0=7Ad@2^[Zh00P2`/;00102_[jl0/K6a
0;Jf]P2g]kL20;Fe]@0:0;Jf]P2d];@0^;Rh0;fm_@2l_;`0^KVi0:^[Z`2LW9`0XJ6Q0;Jf]P80alO7
00T0];Bd0;Fe]@2k^k/0[jn_0:j^[P2f][H0c<c<0=3@d03AdM408P3oool00200oooo00@0PH6108B4
Q023Ph<0RHV90P25QHD01P1lO7`0Ph>308R8R028R8P0Ph>307YjNP80PH610`25QHD0602?Shl0TY:B
08j>SP2BTY80UYJF08N7Q`2DU9@0NGUi06EUI@1^KVh0M7Ad06m_K`1[Jf/0J6QX071`L01^KVh0J6QX
06i^KP1dM7@0NGUi07EeM@1XJ6P0HV9R06i^KP80LW9b00h0L71`07MgM`1jNWX0LG5a06e]K@1dM7@0
LW9b06UYJ@1`L700Kfm_06][J`1SHf<0GemO05IFEP80EeMG00P0FEUI05YJFP1EEED0DU9B05IFEP1J
FUX0EeMG05IFEP<0Fe]K02H0HF5Q06MWI`1ZJVX0IFEU06MWI`1TI6@0FEUI04e=C@1gMgL0IFEU04M7
A`15ADD0G5aL06IVIP1ZJVX0K6a/06m_K`1]KFd0KVi^07MgM`1_Kfl0EUIF04E5A@1RHV80IfMW05IF
EP1GEeL0Kfm_07UiN@1TI6@0NGUi07IfMP1^KVh0MWIf07=cL`24Q8@0PH6107moOah0oooo0P2c/k<0
1P2d];@0]kNg0;Fe]@2k^k/0/[:b0;Vi^@80]KFe00X0];Bd0;2`/02g]kL0]kNg0;Vi^@2k^k/0]KFe
0;^k^`2c/k<0/K6a0P2b/[80402/[:`0_Kfm08F5Q@2JVYX0Vi^K09jNWP2GUiL0UIFE09BDU02GUiL0
Shn?08^;R`2CTi<0UIFE09NGU`2FUYH2092@T00809ZJVP2OWil0WinO09jNWP2SXj<0XJ6Q09NGU`2B
TY8209FEU@0B092@T02DU9@0Ti>C09:BTP2>SXh0T92@08^;R`2@T900Rh^;08f=S@2>SXh0Rh^;08V9
R@2?Shl0TI6A08b<S02?Shl0TY:B0P2>SXh0402@T900Ti>C09BDU02BTY80V9RH09:BTP2;Rh/0TI6A
09jNWP2FUYH0QXJ608N7Q`2BTY80UYJF09bLW02NWYh209fMW@80XZ:R0100WinO09:BTP25QHD0TY:B
08Z:RP21PH40SHf=0::RXP2PX:00TI6A09bLW02GUiL0XZ:R09^KV`2@T900][Jf0P2c/k<N0?ooo`06
0<_;b`3:b/X0cLg=0<W9b@3<c<`0clo?0P3AdM401037alL0aLG50<W9b@3?cll20=?Cd`0F0=7Ad@3?
cll0c<c<0<30`02c/k<0][Jf0;Bd]02^[Zh0^;Rh0;jn_P1kNg/0^k^k0;6a/@2[Zj/0YJFU0:RXZ02W
YjL0Xj>S09NGU`2NWYh0X:2P09nOW`80W9bL00<0XZ:R0:n_[`2b/[800P2c/k<0202e]KD0];Bd0:NW
Y`2OWil0XZ:R09nOW`2LW9`0YJFU0`2PX:003P2VYZH0ZJVY0;2`/02a/K40[jn_0:f][@2^[Zh0/;2`
0;>c/`2e]KD0/[:b0:n_[`2e]KD0/[:b0P2][Jd09P2^[Zh0Z:RX0:RXZ02/[:`0[Zj^0:ZZZP2d];@0
a/K60:ZZZP2XZ:P0[Zj^0<?3``2i^KT0][Jf0;Rh^02i^KT0]kNg0;Rh^02n_[h0/[:b0;Fe]@2ZZZX0
]kNg0:NWY`2FUYH0XZ:R0;jn_P2h^;P0Xj>S0:b/[02][Jd0Xj>S0;Fe]@2][Jd0Zj^[0<c<c038b<P0
c<c<8P3oool00200oooo01h0NGUi07inOP26QXH0OGem07alO01jNWX0P82008:2PP25QHD0PH6108N7
Q`2:RXX0PX:208F5Q@21PH40R8R80861P@26QXH0QHF508:2PP1nOWh0PH6108>3P`26QXH0Q8B408N7
Q`1ZJVX0ATI605QHF01RHV8206YZJP05071`L01aLG40KVi^06MWI`1ZJVX00P1/K6`00`1VIVH0Kfm_
06YZJP0206a/K005079bLP1eMGD0MgMg071`L01/K6`01@1_Kfl03P1cLg<0K6a/06a/K01eMGD0N7Qh
07EeM@1dM7@0KVi^06e]K@1dM7@0N7Qh071`L01]KFd0K6a/0`1_Kfl08P1hN7P0K6a/06][J`1aLG40
Jf][07AdM01eMGD0JVYZ06MWI`1/K6`0MgMg0;^k^`1eMGD0C4a<03`l?013@d<0@T9203dm?@1BDU80
Cdm?05MGE`1BDU80F5QH069RHP1`L700P82006UYJ@1SHf<0KVi^07EeM@1_Kfl0PX:206i^KP1bLW82
07UiN@0308>3P`3oool0oooo01`0oooo00L0]KFe0;Ng]`2k^k/0/K6a0;Ng]`2e]KD0^;Rh0080]KFe
00P0/k>c0;Fe]@2f][H0];Bd0;Fe]@2`/;00_;bl0;:b/P80^k^k00h0]KFe0;:b/P2i^KT0];Bd0;Rh
^02j^[X0_;bl09FEU@1bLW80UYJF08R8R02DU9@0UIFE09NGU`80TY:B00h0Shn?09BDU02FUYH0UiNG
08n?S`2KVi/0V9RH09jNWP2LW9`0XJ6Q09fMW@2OWil0V9RH09JFUP<0UiNG0P2KVi/00`2MWId0UYJF
09FEU@0209ZJVP0809FEU@2IVIT0Ti>C09:BTP2HV9P0UiNG09BDU02GUiL309JFUP0V09^KV`2OWil0
VYZJ09RHV02LW9`0U9BD09fMW@2IVIT0UIFE09NGU`2LW9`0XZ:R0;fm_@2IVIT0OWin07alO024Q8@0
PH6107emO@1_Kfl0Jf][06i^KP1bLW80PX:2096AT@26QXH0WinO09>CT`2@T900V9RH08Z:RP2TY:@0
Z:RX08b<S02RXZ80/;2`0;6a/@2h^;PN0?ooo`0A0=OGe`3De=@0c/k>0<o?c`3De=@0emOG0=?Cd`3=
cLd0a/K60<c<c038b<P0a/K60<_;b`38b<P0bl_;0<g=c@3<c<`00P3?cll20<g=c@090=;BdP3=cLd0
bLW90=3@d02d];@0UiNG0:JVYP2i^KT0Xj>S0080Z:RX00H0Xj>S09bLW02IVIT0YJFU0:RXZ02YZJT2
0:FUY@080:n_[`2b/[80^KVi0;Ng]`2f][H0[Jf]0:ZZZP2VYZH40:VYZ@80[jn_00H0Zj^[0:VYZ@2/
[:`0YJFU0:6QX@2OWil20:6QX@040::RXP2TY:@0WIfM0:2PX0@0Z:RX00@0[jn_0:RXZ02^[Zh0/[:b
0`2[Zj/07@2TY:@0ZZZZ0;Jf]P2e]KD0/;2`07=cL`2DU9@0WIfM0;6a/@2m_Kd0Zj^[0:JVYP1fMWH0
N7Qh07inOP2;Rh/0ZJVY0:JVYP2PX:00UiNG0:RXZ02_[jl0/;2`09bLW02e]KD0/;2`09bLW037alL0
d=3@0080d];B8P3oool00200oooo00X0S8b<08J6QP25QHD0QHF508J6QP2:RXX0Q8B407inOP27QhL0
QXJ60P21PH406023Ph<0P82007inOP25QHD0PH6108>3P`2:RXX0RHV908F5Q@21PH40NWYj07moO`20
P800RXZ:08N7Q`1PH600EEEE04e=C@1BDU80Jf][06QXJ01WIfL0JFUY06YZJP80IVIV00<0Kfm_06YZ
JP1^KVh00P1_Kfl00`1/K6`0Kfm_06i^KP0207=cL`03071`L01WIfL0Jf][00@0Kfm_00h0Lg=c06UY
J@1TI6@0IfMW06][J`1dM7@0MGEe06YZJP1WIfL0I6AT06QXJ01_Kfl0KVi^06MWI`<0Kfm_00<0K6a/
06][J`1_Kfl00P1ZJVX07`1XJ6P0M7Ad06i^KP1[Jf/0Hf=S06ATI027QhL0VIVI08b<S015ADD0<c<c
04I6AP1?Cdl0EUIF055AD@1BDU80@d=306EUI@1HF5P0JFUY055AD@1QHF40EUIF06MWI`1fMWH0Jf][
09FEU@1kNg/0PH6108:2PP1oOgl07P3oool01@2f][H0]KFe0;Vi^@2e]KD0][Jf0080]KFe01P0/k>c
0;Zj^P2d];@0/k>c0;Vi^@2h^;P0];Bd0;>c/`2i^KT0]KFe0;Rh^02l_;`0][Jf0;Ng]`2e]KD0/;2`
0;Rh^02e]KD0_kno0::RXP21PH40Ph>307moO`27QhL209BDU00909:BTP2EUID0T92@09:BTP2CTi<0
V9RH096AT@2JVYX0Vi^K0080VYZJ0P2MWId01@2PX:00WIfM09RHV02DU9@0V9RH00@0Vi^K00h0WIfM
09:BTP2FUYH0UiNG09RHV02MWId0VIVI09FEU@2CTi<0UYJF09RHV02GUiL0V9RH09:BTP<0Vi^K02@0
VYZJ09BDU02LW9`0U9BD09VIV@2GUiL0WIfM09FEU@2JVYX0UIFE09VIV@2^[Zh0X:2P08j>SP1YJFT0
IfMW06YZJP1aLG40KVi^06m_K`1jNWX0LW9b08^;R`1jNWX0YZJV08R8R02=SHd0Ng]k09VIV@2[Zj/0
RXZ:0;Fe]@2IVIT0[jn_0;>c/`2_[jlN0?ooo`070<?3``35aLD0d=3@0<S8b03;bl/0a<C40<S8b002
0<o?c`0I0<K6aP3?cll0d];B0=;BdP3>c/h0clo?0=7Ad@3=cLd0d];B0<g=c@37alL0b/[:0<g=c@3?
cll0dm?C0<g=c@2i^KT0UIFE08F5Q@2TY:@0WYjN0;Rh^02WYjL0YZJV0:ZZZP020:>SX`040:RXZ02]
[Jd0YJFU0:>SX`<0[jn_00P0/[:b0;Jf]P2f][H0/K6a0:^[Z`2VYZH0[:b/0;:b/P@0[jn_00T0Zj^[
0:FUY@2c/k<0/K6a0;:b/P2[Zj/0Y:BT0:ZZZP2/[:`00P2a/K400`2YZJT0YJFU0:f][@030:n_[`0T
0:j^[P2/[:`0Zj^[0:f][@2^[Zh0/k>c0:^[Z`2XZ:P0[jn_0;Bd]02g]kL0ZZZZ07emO@1^KVh0L71`
08^;R`24Q8@0P82007YjNP22PX80T92@09ZJVP2MWId0[Jf]0:n_[`2a/K40/;2`0:RXZ02n_[h0];Bd
0;6a/@2[Zj/0[Jf]0<C4a038b<P0c<c<8P3oool00200oooo00d0Ng]k08F5Q@21PH40PH6107moO`21
PH40QhN708Z:RP21PH40Ph>308F5Q@28R8P0OGem0080RHV900L0QHF508N7Q`1mOGd0QHF508:2PP23
Ph<0PH610080Q8B40100PX:208Z:RP1dM7@0OGem05IFEP1DE5@0:RXZ03@d=01UIFD0J6QX06a/K01X
J6P0Jf][06MWI`1VIVH0IfMW0P1_Kfl306i^KP0306][J`1_Kfl0Kfm_0080Lg=c0`1_Kfl0101`L700
Kfm_06m_K`1cLg<206a/K00506][J`1/K6`0IfMW06i^KP1XJ6P00P1/K6`02`1WIfL0K6a/06YZJP1_
Kfl0L71`06m_K`1/K6`0Kfm_075aL@1WIfL0KFe]0080Jf][00/0IVIV06][J`1ZJVX0Hf=S04M7A`0g
=cL0;2`/04m?C`1CDe<0ATI6059BDP0205=CD`0@05IFEP1SHf<0GemO05=CD`1dM7@0GemO05aLG01T
I6@0KVi^07MgM`1YJFT0P82008:2PP1oOgl0RXZ:08:2PQh0oooo0180][Jf0;Vi^@2d];@0^KVi0;2`
/02i^KT0^[Zj0;Fe]@2d];@0^;Rh0;Fe]@2l_;`0/[:b0;Jf]P2g]kL0]KFe0;bl_02a/K420;Vi^@0D
0;Zj^P2c/k<0];Bd0;Bd]02f][H0_;bl09fMW@2SXj<0N7Qh07inOP1MGEd0NGUi09:BTP2@T900UYJF
09>CT`2DU9@0Shn?09BDU02BTY8209^KV`0909ZJVP2KVi/0VYZJ09VIV@2NWYh0Vi^K09fMW@2IVIT0
UiNG00D0Vi^K00L0WIfM09>CT`2FUYH0U9BD09ZJVP2GUiL0UYJF0080UIFE00@0Ti>C09BDU02JVYX0
TI6A0`2KVi/0902EUID0UiNG09bLW02CTi<0VYZJ09>CT`2IVIT0UiNG09VIV@2EUID0TY:B08V9R@1m
OGd0LW9b08:2PP1SHf<0GUiN06a/K01`L700MWIf07QhN01mOGd0QXJ60861P@2XZ:P0Ogmo08B4Q020
P800VYZJ0:FUY@2;Rh/0/[:b0:j^[P2_[jl0]kNg0;Bd]1h0oooo00/0e]KF0=7Ad@3;bl/0d];B0<k>
cP3Bd]80clo?0<C4a03;bl/0d];B0<c<c0020<g=c@050<O7a`39bLT0c<c<0<g=c@3>c/h00P3AdM40
3@3@d=00bl_;0<W9b@37alL0c<c<0;Vi^@2ZZZX0UiNG08N7Q`26QXH0RXZ:0<S8b02[Zj/00P2SXj<0
1@2VYZH0YjNW0:BTY02ZZZX0ZJVY00<0[jn_00P0/;2`0;:b/P2a/K40/k>c0:n_[`2[Zj/0YZJV0:VY
Z@80[jn_01D0[Zj^0:n_[`2_[jl0ZJVY0:FUY@2YZJT0[:b/0:j^[P2a/K40Y:BT0:VYZ@2XZ:P0YJFU
0:b/[02][Jd0ZJVY0:n_[`2^[Zh0[jn_0:b/[02YZJT00P2[Zj/0802][Jd0ZZZZ0:j^[P2b/[80[Zj^
0:RXZ02WYjL0^k^k0:f][@2UYJD0TY:B069RHP1]KFd0OGem07inOP29RHT0R8R808Z:RP2KVi/0/k>c
0:RXZ02BTY80YJFU0:2PX02^[Zh0];Bd0;6a/@39bLT0`l?30<c<c035aLD0b/[:8P3oool00200oooo
00d0RXZ:08:2PP22PX80Ph>307moO`26QXH0Ogmo0820P026QXH0Ogmo0861P@23Ph<0QXJ60080QHF5
01T0PH6108:2PP25QHD0PH6108>3P`27QhL0P82007inOP25QHD0PH6108f=S@2<S8`0VIVI071`L01D
E5@0BTY:020P800X:2P0I6AT06EUI@1OGel0H61P06UYJ@1]KFd0JVYZ00@0Kfm_00<0K6a/06m_K`1_
Kfl00P1_Kfl0201/K6`0IfMW06MWI`1ZJVX0K6a/06][J`1_Kfl0L71`0P1/K6`01@1WIfL0K6a/06YZ
JP1ZJVX0KFe]00<0K6a/00P0Jf][06MWI`1ZJVX0JVYZ06IVIP1[Jf/0Kfm_071`L080JVYZ00@0IfMW
06QXJ01VIVH0Hf=S0P1KFe/03012@T80?clo04];B`1CDe<0FUYJ05iNGP15ADD0CTi>05IFEP1NGUh0
GemO06YZJP80GUiN0P1JFUX02@1VIVH0KVi^071`L01fMWH0Ph>307inOP1mOGd0OWin0820P00N0?oo
o`0;0;Ng]`2d];@0^KVi0;Bd]02a/K40^k^k0;6a/@2h^;P0_;bl0;2`/02i^KT00P2h^;P30;Vi^@03
0;Rh^02d];@0^KVi0080^;Rh00d0];Bd0;:b/P2e]KD0];Bd0;fm_@2XZ:P0[Zj^08n?S`1nOWh0IVIV
04E5A@1ZJVX0TY:B0080Shn?00@0S8b<09BDU02DU9@0T92@102KVi/00`2IVIT0Vi^K09^KV`0209^K
V`0809ZJVP2GUiL0UiNG09RHV02JVYX0V9RH09^KV`2LW9`209JFUP0609BDU02JVYX0UIFE09VIV@2E
UID0Ti>C0P2FUYH0202DU9@0Ti>C09RHV02JVYX0UiNG096AT@2KVi/0W9bL0P2EUID03`2DU9@0VIVI
09:BTP2BTY80SXj>08f=S@1aLG40K6a/06UYJ@1VIVH0LG5a079bLP1UIFD0Lg=c07EeM@0207]kN`09
08^;R`27QhL0Ti>C0861P@25QHD0R8R80:6QX@2HV9P0VIVI0080/;2`00<0Zj^[0;Ng]`2h^;P07P3o
ool01@35aLD0b/[:0=7Ad@39bLT0cLg=0080c/k>00<0d];B0<k>cP3>c/h00P3Bd]800`39bLT0dM7A
0=7Ad@020=;BdP0G0<[:bP3Bd]80d];B0<W9b@3:b/X0cLg=0<c<c03:b/X0_Kfm0:NWY`2DU9@0Ogmo
08J6QP1[Jf/0JVYZ0<_;b`2VYZH0YjNW0:ZZZP2YZJT0Z:RX0::RXP2SXj<0102_[jl00`2a/K40[jn_
0:n_[`020:n_[`080:j^[P2a/K40/K6a0;:b/P2_[jl0/[:b0:n_[`2[Zj/20:VYZ@060:b/[02^[Zh0
ZJVY0:j^[P2VYZH0YJFU0P2YZJT07`2XZ:P0Zj^[0;:b/P2_[jl0/[:b0:RXZ02_[jl0Zj^[0:VYZ@2Z
ZZX0[:b/0:f][@2[Zj/0YjNW0:b/[02SXj<0RHV908>3P`1fMWH0L71`07AdM01cLg<0NWYj08f=S@23
Ph<0RXZ:08f=S@2LW9`0WYjN0:FUY@2MWId00P2QXJ40202g]kL0/;2`0;Ng]`31`L40bl_;0<O7a`3D
e=@0d];B8P3oool00200oooo00L0Ng]k0820P026QXH0PH6107inOP2:RXX0QHF50080R8R800l0OGem
08B4Q021PH40QHF50861P@1lO7`0PX:20861P@1oOgl0Ph>308:2PP23Ph<0QhN708R8R01nOWh00P20
P8003`1fMWH0OWin06e]K@1;Bd/0ADE503/k>`0@41007QhN05MGE`1ZJVX0Jf][06MWI`1XJ6P0IVIV
06YZJP0306m_K`0306][J`1_Kfl0Kfm_0080Kfm_0P1cLg<01@1_Kfl0K6a/06a/K01WIfL0Jf][0080
Lg=c00<0KFe]06EUI@1XJ6P00P1]KFd01@1YJFT0J6QX06YZJP1WIfL0J6QX0080IfMW00/0LG5a06m_
K`1VIVH0JFUY07=cL`1aLG40K6a/06YZJP1WIfL0GemO069RHP0205YJFP0>04E5A@1=CDd0EUIF04];
B`1<C4`0FEUI05IFEP1<C4`0Fe]K05IFEP1CDe<0Cdm?05eMG@1_Kfl207=cL`0906m_K`1PH600MgMg
07emO@22PX80P82007inOP21PH40RHV901h0oooo00L0][Jf0;Rh^02f][H0][Jf0;2`/02l_;`0];Bd
0080_;bl00<0/[:b0;Vi^@2d];@00P2i^KT01`2f][H0^KVi0;>c/`2b/[80^;Rh0;Bd]02i^KT00P2e
]KD04P2b/[80/k>c0;Ng]`2SXj<0/[:b09jNWP1aLG40Hf=S05ADE00`<300JVYZ08B4Q02<S8`0SXj>
092@T02CTi<0TI6A09RHV0<0Vi^K00<0VIVI09^KV`2KVi/00P2KVi/03P2MWId0VIVI09NGU`2FUYH0
VYZJ09BDU02HV9P0WIfM09VIV@2GUiL0Ti>C09BDU02GUiL0UIFE0P2DU9@0402EUID0U9BD09>CT`2D
U9@0Ti>C09fMW@2EUID0Ti>C09NGU`2MWId0VIVI09BDU02EUID0U9BD08b<S02ATI4208J6QP0E06][
J`1VIVH0IfMW06UYJ@1_Kfl0MWIf079bLP1YJFT0NGUi07QhN01mOGd0Ogmo08j>SP2?Shl0QhN7092@
T02LW9`0TY:B09JFUP2RXZ80]KFe0080/k>c00<0];Bd0;Vi^@3oool07@3oool01`3Fe]H0dm?C0<S8
b03<c<`0clo?0<g=c@3:b/X00`3=cLd03`3AdM40bl_;0=7Ad@3Bd]80eMGE0=7Ad@3;bl/0d=3@0=;B
dP3:b/X0dM7A0<W9b@35aLD0cLg=0<c<c0020<C4a00:0;Vi^@2GUiL0PH6106UYJ@1HF5P0EEEE0=3@
d02UYJD0WIfM09^KV`80YZJV00<0ZJVY0;:b/P2_[jl01`2_[jl0202[Zj/0YZJV0:VYZ@2YZJT0[Zj^
0:b/[02b/[80Zj^[0P2VYZH04P2[Zj/0[:b/0:RXZ02VYZH0YjNW0:^[Z`2YZJT0ZZZZ0:VYZ@2ZZZX0
[jn_0:ZZZP2WYjL0[:b/0;>c/`2[Zj/0YJFU0:NWY`80ZJVY01d0Y:BT0:JVYP2JVYX0VIVI07IfMP1c
Lg<0KFe]07IfMP27QhL0QXJ607MgM`1mOGd0S8b<08N7Q`2PX:00YjNW0:JVYP2HV9P0RHV909FEU@2R
XZ80]kNg0;2`/02g]kL0cLg=0<W9b@3=cLd0c/k>0<S8b00R0?ooo`00803oool01@1nOWh0Ph>308:2
PP25QHD0PH610080PX:202<0R8R807inOP21PH40QhN70861P@27QhL0QHF508R8R021PH40QXJ608>3
P`25QHD0QhN707emO@1oOgl0Ng]k0861P@23Ph<0Rh^;07inOP25QHD0LW9b04];B`14A4@0>SXj03@d
=00Z:RX02PX:069RHP1VIVH0GUiN06MWI`1ZJVX0Jf][06a/K00306MWI`05071`L01WIfL0Jf][071`
L01/K6`00P1_Kfl02P1ZJVX0IVIV06EUI@1WIfL0KFe]071`L01YJFT0IFEU06MWI`1VIVH2069RHP0/
06EUI@1YJFT0I6AT05eMG@1NGUh0H61P06QXJ01TI6@0HV9R05mOG`1WIfL0JVYZ065QH@1OGel0EUIF
04];B`0l?3`0;bl_03Hf=P13@d<0BTY:05IFEP1UIFD0FUYJ05mOG`1KFe/0EUIF06MWI`1NGUh0De=C
05]KF`1RHV80HF5Q06][J`1EEED0MGEe07]kN`1mOGd0NGUi07IfMP1mOGd0Ph>307moO`29RHTN0?oo
o`80/k>c0P2d];@0102c/k<0^KVi0;:b/P2f][H20;Ng]`0L0;^k^`2b/[80^k^k0;Bd]02l_;`0/[:b
0;^k^`2f][H0^KVi0;Jf]P2b/[80^;Rh0;2`/02i^KT0][Jf0;Rh^02/[:`0];Bd09jNWP1XJ6P0IFEU
05=CD`16ATH0>3Ph02DU9@29RHT0T92@08J6QP80Ti>C00<0V9RH09ZJVP2GUiL00P2GUiL01`2HV9P0
U9BD09RHV02LW9`0UYJF09NGU`2HV9P00`2BTY80102GUiL0VYZJ09RHV02EUID209>CT`0=092@T02=
SHd0TY:B09>CT`2EUID0Shn?08R8R02?Shl0SXj>09BDU02CTi<0TY:B08n?S`0209BDU00P08V9R@28
R8P0O7al07EeM@1[Jf/0Fe]K05aLG01BDU80J6QX07alO01oOgl0IVIV07UiN@24Q8@0P82008R8R01i
NGT0Lg=c07inOP29RHT0Ph>309BDU028R8P0UYJF09ZJVP2UYJD0[Zj^0:ZZZP2/[:`0]KFe0;2`/02k
^k/N0?ooo`0Z0<g=c@3;bl/0b/[:0<[:bP3;bl/0dM7A0<W9b@38b<P0e=CD0=?Cd`3>c/h0cLg=0<k>
cP3:b/X0cLg=0<c<c03?cll0c<c<0=3@d037alL0c/k>0=;BdP3@d=00d];B0<W9b@32`/80^[Zj0;bl
_02OWil0MWIf06a/K01HF5P0AdM703`l?019BDT0X:2P09fMW@2UYJD0YjNW0:JVYP2b/[80[Zj^0`2a
/K40102VYZH0[:b/0;:b/P2[Zj/20:VYZ@0B0:NWY`2SXj<0ZZZZ0:j^[P2a/K40/;2`0:JVYP2YZJT0
ZZZZ0:RXZ02UYJD0YZJV0:b/[02][Jd0Z:RX0:NWY`2SXj<0Zj^[0P2/[:`04P2XZ:P0YjNW0;6a/@2Y
ZJT0XJ6Q09RHV02JVYX0SHf=08b<S029RHT0LW9b075aL@1WIfL0PX:208f=S@1hN7P0Kfm_0861P@80
UiNG00l0Shn?07YjNP25QHD0TY:B09^KV`2MWId0YZJV0;Jf]P2VYZH0[:b/0;Vi^@35aLD0bLW90<S8
b03:b/X00P3>c/hR0?ooo`00803oool02023Ph<0Ng]k08Z:RP25QHD0QXJ608>3P`29RHT0QHF50P1o
Ogl01025QHD0OGem0820P01mOGd207moO`0?08V9R@2:RXX0OWin08F5Q@26QXH0PX:207moO`22PX80
Ogmo07MgM`1hN7P0L71`06UYJ@1>CTh0A4A40080>3Ph00T0=3@d02HV9P0410@0HF5Q05aLG01SHf<0
I6AT06EUI@1ZJVX00`1/K6`00`1`L700Kfm_06a/K00206a/K00A06MWI`1ZJVX0Kfm_06][J`1UIFD0
IVIV06ATI01/K6`0KVi^06e]K@1ZJVX0JFUY06IVIP1OGel0G5aL06EUI@1VIVH00P1YJFT206EUI@08
06QXJ01WIfL0H61P05iNGP1QHF40Hf=S05]KF`13@d<203Xj>P80@T9200<0F5QH05=CD`1?Cdl00`1F
EUH01`14A4@0BTY:04Y:BP1OGel0JFUY05mOG`1VIVH00P1[Jf/0201_Kfl0R8R807UiN@1gMgL0RXZ:
08R8R023Ph<0RXZ:0P25QHDN0?ooo`0Z0;>c/`2_[jl0^;Rh0;Bd]02k^k/0/k>c0;Jf]P2e]KD0];Bd
0;:b/P2k^k/0/k>c0;Rh^02g]kL0^;Rh0;:b/P2k^k/0^;Rh0;:b/P2i^KT0^;Rh0;Bd]02a/K40]KFe
0;Jf]P2_[jl0];Bd0:>SX`2OWil0KFe]065QH@1@D500Bd];0492@P0c<c<0F5QH08j>SP24Q8@0T92@
08j>SP2CTi<0VIVI0`2FUYH0;@2LW9`0UiNG09JFUP2JVYX0UYJF09BDU02EUID0V9RH09>CT`2ATI40
Ti>C092@T02JVYX0UiNG09BDU02ATI40TY:B092@T02<S8`0RXZ:096AT@2@T900SHf=08j>SP2;Rh/0
T92@09FEU@2DU9@0R8R808j>SP2=SHd0Rh^;08>3P`1_Kfl0IFEU05mOG`1MGEd0DU9B06=SH`1`L700
M7Ad07QhN01cLg<0O7al07EeM@0207IfMP0@08B4Q01mOGd0Q8B408J6QP2;Rh/0U9BD09JFUP2QXJ40
Xj>S0:^[Z`2c/k<0[:b/0:j^[P2h^;P0];Bd0;Vi^Ah0oooo01D0alO70<g=c@38b<P0b/[:0<k>cP3;
bl/0alO70<c<c03>c/h0d=3@0<o?c`3@d=00d];B0=CDe03Cdm<0d=3@0<k>cP38b<P0c/k>0=7Ad@39
bLT00P3:b/X04`3=cLd0c<c<0<k>cP37alL0`l?309jNWP1hN7P0I6AT05IFEP1?Cdl0@T9203De=@3K
fm/0Y:BT09fMW@2YZJT0YJFU0:f][@2_[jl00`2YZJT06@2[Zj/0ZJVY0:VYZ@2^[Zh0ZJVY0:b/[02Z
ZZX0YjNW0:>SX`2YZJT0[:b/0:f][@2^[Zh0YZJV0::RXP2QXJ40Xj>S0:6QX@2TY:@0Z:RX0:VYZ@2Q
XJ40WYjN09ZJVP2RXZ800P2VYZH03@2YZJT0WIfM0:VYZ@2SXj<0VYZJ09FEU@24Q8@0OWin07=cL`1R
HV80FUYJ06UYJ@1mOGd00`27QhL0502=SHd0UIFE09FEU@2ATI40UIFE07inOP2FUYH0VYZJ09^KV`2V
YZH0Z:RX0::RXP2g]kL0bLW90;no_`2f][H0a<C40<S8b03:b/X0dM7A8P3oool00200oooo00X0OWin
08F5Q@21PH40QHF508b<S021PH40OGem0861P@28R8P0OGem0P1oOgl01028R8P0RXZ:08Z:RP22PX82
07emO@0308:2PP21PH40R8R80080Q8B40140PH6108R8R025QHD0Q8B4079bLP1jNWX0Cdm?04U9B@0j
>SX0=3@d034a<@0Q8B401@D500T92@1SHf<0IFEU06][J`0206YZJP<0K6a/0P1_Kfl00`1`L700K6a/
06a/K00306a/K00306e]K@1[Jf/0K6a/00<0IfMW0P1VIVH05P1WIfL0J6QX06IVIP1TI6@0GemO069R
HP1HF5P0HV9R05aLG01TI6@0IVIV05eMG@1RHV80Fe]K05QHF01KFe/0Bd];03Ti>@0/;2`0=3@d04Y:
BP1?Cdl2059BDP0:05EEE@1ADE40EEEE06ATI01WIfL0I6AT06a/K01OGel0HV9R06e]K@80JVYZ00L0
Jf][06m_K`1`L700OGem07moO`1nOWh0QHF50080PX:200<0OGem07moO`3oool07@3oool01`2c/k<0
];Bd0;Ng]`2i^KT0_Kfm0;:b/P2f][H00P2g]kL03@2b/[80^;Rh0;:b/P2g]kL0^;Rh0;Ng]`2d];@0
]kNg0;Jf]P2e]KD0/k>c0;bl_02e]KD00P2d];@04P2g]kL0/k>c0;Fe]@2LW9`0ZZZZ06i^KP1TI6@0
Cdm?04Q8B014A4@0<30`01@D501FEUH0Rh^;08Z:RP2BTY80UIFE09BDU0<0UYJF00<0Vi^K09NGU`2L
W9`00`2FUYH01P2DU9@0UYJF09NGU`2CTi<0TY:B092@T080U9BD00/0Ti>C09:BTP2ATI40TY:B08f=
S@2:RXX0RHV908n?S`25QHD0Shn?08R8R002092@T00T08J6QP2>SXh0QXJ608B4Q026QXH0N7Qh06=S
H`19BDT0E5AD05iNGP1OGel0LG5a07IfMP1dM7@0LW9b07IfMP23Ph<0NWYj07MgM`22PX80N7Qh08F5
Q@29RHT0QhN709>CT`2EUID0U9BD0:RXZ02^[Zh0ZJVY0:f][@2e]KD0];Bd0;Vi^@2g]kL0][Jf7P3o
ool05@3=cLd0b/[:0=?Cd`3AdM40c<c<0<W9b@3EeMD0dm?C0<O7a`3=cLd0d];B0<g=c@3:b/X0b<S8
0<G5a@3:b/X0e=CD0=GEe@3=cLd0clo?0<g=c@020<W9b@0?0<_;b`37alL0`<300;Zj^P2f][H0UiNG
07QhN01TI6@0De=C059BDP19BDT0<S8b02XZ:P3Fe]H0WIfM0080X:2P0P2XZ:P30:VYZ@030:n_[`2Y
ZJT0Zj^[00<0ZJVY00H0YjNW0:VYZ@2VYZH0Xj>S0:FUY@2WYjL20:ZZZP80YjNW00H0Y:BT0:6QX@2L
W9`0Vi^K0:6QX@2SXj<20:FUY@0<0::RXP2[Zj/0W9bL09jNWP2RXZ80VIVI0:2PX02HV9P0S8b<07em
O@1EEED0L71`0P1SHf<06@20P800QXJ608>3P`22PX80T92@08R8R01gMgL0O7al0820P025QHD0UYJF
09FEU@2FUYH0YjNW0:RXZ02[Zj/0bl_;0<C4a02m_Kd0alO70<c<c03;bl/0dM7A0=CDe03EeMD08P3o
ool00200oooo02d0S8b<08F5Q@1nOWh0PX:20861P@2:RXX0RHV908:2PP20P800PH6108R8R025QHD0
NWYj07inOP21PH40RHV908N7Q`21PH40QHF507]kN`20P800QHF508J6QP23Ph<0Ogmo0820P023Ph<0
LW9b075aL@16ATH0@D510492@P0i>CT0:RXZ024Q8@0T92@06QXJ06=SH`1OGel0JVYZ06][J`1YJFT0
KFe]071`L01_Kfl00P1WIfL206a/K00:06UYJ@1XJ6P0JVYZ06UYJ@1[Jf/0JFUY06MWI`1TI6@0Hf=S
069RHP<0IfMW01H0I6AT069RHP1NGUh0FUYJ05aLG01OGel0J6QX06][J`1CDe<0EUIF05ADE01EEED0
E5AD04M7A`14A4@0Bd];030`<016ATH0?Cdm03Ph>00n?Sh0Cdm?0P1<C4`0201KFe/0EUIF065QH@1S
Hf<0FUYJ06YZJP1]KFd0HF5Q0`1ZJVX01P1bLW80MWIf07emO@28R8P0QhN708Z:RP80PX:20`25QHDN
0?ooo`090;Jf]P2b/[80/[:b0;Vi^@2g]kL0_;bl0;Jf]P2e]KD0^;Rh0080]KFe01`0];Bd0;:b/P2g
]kL0]kNg0;^k^`2h^;P0/k>c0;Ng]`2b/[80^;Rh0;Fe]@2g]kL0][Jf0;>c/`2g]kL0];Bd0::RXP2U
YJD0IfMW065QH@1HF5P0Bd];03dm?@0`<300;bl_014A4@2:RXX0QhN70`2DU9@02@2FUYH0V9RH09NG
U`2DU9@0UiNG09ZJVP2FUYH0UIFE09BDU00209FEU@0709JFUP2CTi<0TY:B08n?S`2ATI40SXj>09:B
TP02092@T00:08n?S`2;Rh/0RHV908N7Q`28R8P0Q8B408Z:RP2@T900PH6108^;R`80Ph>30280PH61
07EeM@1eMGD0MGEe04e=C@1LG5`0BTY:05EEE@1NGUh0M7Ad071`L01_Kfl0NGUi07AdM025QHD0Ph>3
07inOP27QhL0Rh^;08F5Q@2:RXX0Ti>C09BDU02FUYH0UiNG0:>SX`2/[:`0[jn_0;Fe]@2d];@0^KVi
0;^k^`2e]KD0];Bd7P3oool05`33`l<0b<S80=7Ad@3AdM40dm?C0<g=c@37alL0cLg=0=;BdP3>c/h0
alO70<K6aP3AdM40e=CD0=?Cd`3>c/h0bLW90<_;b`3:b/X0dM7A0=?Cd`3<c<`0b/[:0080c<c<01L0
bl_;0;jn_P2h^;P0WIfM079bLP1ZJVX0Fe]K04m?C`12@T80<c<c038b<P1RHV80W9bL0::RXP2XZ:P0
YjNW0:RXZ02ZZZX0YZJV0:VYZ@2/[:`0/K6a0:j^[P020:VYZ@050:b/[02YZJT0Zj^[0:NWY`2XZ:P0
0`2WYjL00`2XZ:P0YJFU0::RXP020::RXP0G09fMW@2NWYh0X:2P09nOW`2IVIT0WIfM09NGU`2NWYh0
YJFU09nOW`2NWYh0U9BD09FEU@2@T900QhN706EUI@1KFe/0EUIF06EUI@1jNWX0Q8B408:2PP25QHD0
0P27QhL01`2FUYH0RHV909>CT`2FUYH0SHf=09NGU`2IVIT00P2WYjL02`2XZ:P0YjNW0;Zj^P2h^;P0
`L710<C4a03;bl/0dM7A0<o?c`3<c<`0b/[:0280oooo000P0?ooo`0708F5Q@22PX80O7al0861P@1m
OGd0Ogmo0861P@0308>3P`0>08F5Q@28R8P0R8R808>3P`22PX80OWin08B4Q025QHD0PH6108F5Q@29
RHT0PX:208F5Q@27QhL208>3P`0C07emO@1TI6@0HF5Q04m?C`10@400@T9203`l?00g=cL0:BTY02XZ
:P0@41009bLW06IVIP1ZJVX0Kfm_06YZJP1YJFT0L71`06MWI`0306a/K00<06YZJP1^KVh0JVYZ06IV
IP1XJ6P0KFe]06QXJ01YJFT0IfMW06YZJP1UIFD0HF5Q0P1ZJVX02P1TI6@0HV9R061PH01GEeL0DE5A
06][J`1SHf<0E5AD04m?C`1FEUH205EEE@0?04i>CP14A4@0?clo03Hf=P1=CDd0D51@05ADE01OGel0
Fe]K05UIF@1FEUH0De=C059BDP1CDe<0B4Q80080Fe]K0140D51@05ADE01QHF40JVYZ06UYJ@1bLW80
M7Ad07emO@1lO7`0QXJ60861P@1jNWX0PH6108V9R@24Q8@0PH6108:2PP0N0?ooo`80^KVi00X0/;2`
0;Rh^02c/k<0][Jf0;Vi^@2h^;P0][Jf0;6a/@2e]KD0_;bl0`2e]KD07P2g]kL0^KVi0;Bd]02i^KT0
];Bd0;Jf]P2e]KD0^KVi0;Rh^02f][H0];Bd0;6a/@2PX:00UiNG06e]K@1JFUX0FEUI055AD@19BDT0
=CDe03<c<`0Z:RX0JVYZ08Z:RP2@T900UiNG09FEU@2BTY80W9bL09BDU0<0UYJF00`0UIFE09NGU`2B
TY80Ti>C09:BTP2GUiL0TI6A09>CT`2@T900TI6A08b<S02=SHd2096AT@0908b<S02;Rh/0R8R80861
P@1nOWh0R8R808V9R@28R8P0Ogmo0080O7al01D0OGem07MgM`1[Jf/0IFEU05YJFP1FEUH0GemO065Q
H@1[Jf/0Hf=S07IfMP1aLG40L71`075aL@1jNWX0MGEe08J6QP1nOWh0O7al08V9R@25QHD00P2CTi<0
1`2FUYH0UIFE0:6QX@2QXJ40]KFe0;Bd]02f][H00P2g]kL00`2j^[X0/[:b0;Vi^@0N0?ooo`80dM7A
00@0c<c<0=;BdP3@d=00eMGE0P3Bd]801@3<c<`0bLW90<c<c03=cLd0alO70080cLg=00P0e=CD0=3@
d03:b/X0d];B0<[:bP37alL0cLg=0=7Ad@80bLW90140a/K60;no_`2f][H0XJ6Q071`L01PH600IFEU
055AD@19BDT0<c<c03Ph>01EEED0b<S80:2PX02SXj<0Y:BT0:RXZ0020:^[Z`030:b/[02YZJT0ZJVY
0080ZJVY03/0Z:RX0:FUY@2[Zj/0ZJVY0:JVYP2UYJD0YjNW0:2PX02SXj<0Vi^K0:NWY`2SXj<0X:2P
09jNWP2KVi/0VYZJ09>CT`2KVi/0UYJF09^KV`2NWYh0W9bL09:BTP2CTi<0Shn?08J6QP23Ph<0MGEe
079bLP1?Cdl0HV9R061PH01SHf<0I6AT07emO@1lO7`0OGem08Z:RP2;Rh/0UiNG09VIV@2CTi<0W9bL
0:NWY`2PX:00YZJV0:NWY`2XZ:P0YjNW0;>c/`2k^k/0bLW90<_;b`3Fe]H0dm?C0<W9b@3@d=00c<c<
0=7Ad@0R0?ooo`00803oool01025QHD0PH610861P@25QHD208V9R@80QHF501h0PH6108F5Q@25QHD0
QHF508R8R01oOgl0RXZ:08J6QP25QHD0PX:208R8R025QHD0PH610820P023Ph<0RXZ:08>3P`1lO7`0
LW9b06=SH`1OGel0A4A403Ti>@0h>3P0<c<c02h^;P0i>CT0:RXZ01HF5P0:2PX206MWI`80K6a/00D0
JVYZ06a/K01WIfL0K6a/06MWI`0206EUI@0506MWI`1YJFT0Jf][06YZJP1TI6@00P1ZJVX0101OGel0
HV9R05]KF`1TI6@2069RHP08061PH01KFe/0EeMG04a<C01JFUX0CDe=04m?C`19BDT204Q8B00T04E5
A@0g=cL0?Shn04=3@`19BDT0ADE503`l?00k>c/0@T9204A4A01?Cdl0E5AD059BDP1PH600Cdm?05]K
F`1@D500@d=305YJFP1NGUh0De=C05iNGP1[Jf/0LW9b08b<S023Ph<0OGem0861P@25QHD0RHV90861
P@25QHD0PH6107emO@1oOgl0QHF57P3oool20;Vi^@070;>c/`2i^KT0][Jf0;Ng]`2e]KD0^KVi0;:b
/P030;Vi^@0=0;bl_02c/k<0_;bl0;Jf]P2g]kL0/k>c0;bl_02d];@0]KFe0;Rh^02c/k<0^;Rh0;Fe
]@020:f][@0C09RHV025QHD0IVIV05IFEP1HF5P0Bd];0492@P19BDT0>SXj028R8P0=3@d0S8b<09:B
TP2JVYX0UIFE09BDU02GUiL0TI6A09NGU`02096AT@0g09>CT`2DU9@0Ti>C09BDU02BTY80Shn?09FE
U@2ATI40S8b<096AT@25QHD0T92@08V9R@2;Rh/0R8R808>3P`1nOWh0Lg=c07emO@24Q8@0QHF506m_
K`1`L700M7Ad06YZJP1GEeL0Fe]K05QHF01UIFD0GUiN05QHF01NGUh0HV9R05iNGP1^KVh0MWIf07=c
L`1gMgL0IFEU08F5Q@1dM7@0KVi^08b<S020P800OWin08f=S@2DU9@0Ti>C0:2PX02OWil0[Zj^0:f]
[@2e]KD0_;bl0;2`/0020;Vi^@030;:b/P2f][H0^KVi01h0oooo00T0dM7A0=;BdP3;bl/0d=3@0<O7
a`39bLT0c<c<0=7Ad@3=cLd00`3AdM40303=cLd0d=3@0<g=c@38b<P0b/[:0<S8b03=cLd0b/[:0<g=
c@3Bd]80c<c<0<S8b080aLG50140][Jf0:^[Z`25QHD0LW9b06IVIP1YJFT0Cdm?04e=C@1;Bd/0?Shn
02DU9@1iNGT0WIfM0:ZZZP2^[Zh0YZJV0:RXZ0040:JVYP0A0:VYZ@2[Zj/0ZZZZ0:JVYP2UYJD0Xj>S
0:NWY`2YZJT0X:2P0:>SX`2UYJD0X:2P0:BTY02KVi/0WYjN09NGU`2EUID00P2;Rh/0802FUYH0XZ:R
09^KV`26QXH0SHf=08n?S`1jNWX0I6AT06a/K01[Jf/0K6a/06IVIP1/K6`0M7Ad079bLP1fMWH0Ph>3
08:2PP20P800MgMg07alO02ATI40T92@09FEU@2WYjL0T92@09jNWP2`/;00YZJV0:VYZ@2QXJ40YjNW
0P35aLD20<c<c0060<_;b`3AdM40d];B0<g=c@3EeMD0dM7A8P3oool00200oooo00L0QHF508Z:RP26
QXH0Ogmo08F5Q@22PX80PH610080PX:200@0PH6108F5Q@25QHD0RHV90P1nOWh208:2PP0408R8R026
QXH0PH6108J6QP<0QHF500<0Ph>307EeM@1eMGD00P1KFe/01P19BDT0AdM703<c<`0];Bd0<C4a03Lg
=`80:BTY00T04a<C06a/K01[Jf/0IVIV06QXJ01ZJVX0K6a/06i^KP1YJFT00P1ZJVX0301TI6@0Hf=S
06UYJ@1NGUh0GemO065QH@1RHV80I6AT06EUI@1SHf<0I6AT05mOG`80G5aL00H0FEUI051@D01@D500
EUIF04i>CP1BDU8204m?C`0>04a<C019BDT0>3Ph04E5A@0o?cl0BTY:05UIF@1BDU80@D51051@D01G
EeL0Bd];04Y:BP1GEeL206IVIP0;05YJFP1IFET0DE5A05IFEP1BDU80IFEU07QhN01`L700MWIf07Ui
N@1aLG400P20P8001`1jNWX0Ng]k0861P@25QHD0PX:208N7Q`2:RXX00P25QHDN0?ooo`040;Vi^@2l
_;`0^k^k0;6a/@80^KVi00@0]kNg0;Vi^@2e]KD0]kNg0P2i^KT02@2k^k/0/[:b0;Ng]`2i^KT0]KFe
0;Ng]`2k^k/0/k>c0;bl_0020;Bd]00B0;Vi^@2g]kL0[Jf]0:j^[P26QXH0Q8B4069RHP1NGUh0Bd];
04E5A@13@d<0BDU903/k>`0e=CD01PH609FEU@2@T900Ti>C0P2DU9@00`2GUiL0U9BD09FEU@0209:B
TP0;092@T02?Shl0TY:B08j>SP2?Shl0SXj>08f=S@2ATI40Shn?08V9R@2:RXX00P28R8P05P26QXH0
QHF507YjNP1iNGT0MGEe075aL@20P800LW9b06i^KP1]KFd0K6a/05]KF`1OGel0De=C061PH01`L700
IFEU05]KF`1TI6@0IfMW069RHP1[Jf/207UiN@0G07]kN`1iNGT0OWin07EeM@1hN7P0MWIf08F5Q@2>
SXh0RHV909JFUP2GUiL0WinO0;Bd]02`/;00[jn_0;Jf]P2g]kL0]KFe0;Vi^@2j^[X0^;Rh0;Bd]02i
^KT07P3oool0103AdM40cLg=0<k>cP3>c/h20=7Ad@040=?Cd`3AdM40cLg=0=?Cd`80dM7A0P3>c/h0
103De=@0dM7A0<g=c@3:b/X20<o?c`1:0<k>cP3:b/X0b/[:0=7Ad@38b<P0aLG50;2`/02JVYX0RXZ:
06QXJ01SHf<0DE5A04i>CP1?Cdl0DE5A03lo?`0c<c<0I6AT0:BTY02UYJD0YjNW0:b/[02WYjL0Z:RX
0:>SX`2YZJT0Y:BT0:>SX`2TY:@0Z:RX0:BTY02ZZZX0ZJVY0:JVYP2WYjL0Y:BT0:2PX02JVYX0Vi^K
09ZJVP2OWil0W9bL09ZJVP2<S8`0SXj>08B4Q02>SXh0TI6A08:2PP1mOGd0Ogmo07emO@1aLG40I6AT
05iNGP1eMGD0K6a/06MWI`1XJ6P0L71`06ATI01aLG40PH6108J6QP1oOgl0NWYj08V9R@2:RXX0S8b<
08R8R02?Shl0VYZJ08f=S@2FUYH20:JVYP0<0<71`@3;bl/0`/;20<k>cP3EeMD0dm?C0<c<c03AdM40
clo?0<S8b03:b/X0dM7A8P3oool00200oooo00@0QHF508:2PP2:RXX0QHF50P22PX800`21PH40RHV9
08F5Q@0308F5Q@0908:2PP26QXH0PX:208F5Q@29RHT0PX:208J6QP1nOWh0Q8B40080OWin01X0OGem
08>3P`1oOgl0MgMg05eMG@1DE5@0A4A40451@@12@T80>c/k0451@@0j>SX08B4Q01hN7P0=3@d0Jf][
069RHP1UIFD0JVYZ06e]K@1VIVH0G5aL06MWI`1QHF40GemO06ATI080GEeM0280HV9R061PH01RHV80
Fe]K065QH@1LG5`0GEeM05]KF`1PH600GemO05]KF`1FEUH0FEUI04m?C`1DE5@0DU9B03lo?`11@D40
@d=30492@P0k>c/0AdM704=3@`11@D40?3`l05=CD`1FEUH0Cdm?04E5A@1:BTX0CDe=04I6AP1BDU80
E5AD0P1XJ6P02`1RHV80EUIF061PH01FEUH0F5QH06UYJ@1XJ6P0OGem08N7Q`23Ph<0Ng]k0080PH61
00@0QhN708F5Q@25QHD0QXJ60`1mOGd00`21PH40oooo0?ooo`0L0?ooo`80^KVi00P0_;bl0;Bd]02i
^KT0^KVi0;>c/`2k^k/0^KVi0;Fe]@<0^KVi00T0]kNg0;Fe]@2e]KD0]kNg0;Fe]@2k^k/0/k>c0;Zj
^P2b/[800P2g]kL02@2f][H0/[:b0:NWY`25QHD0NWYj069RHP1LG5`0F5QH04Y:BP0204a<C00;03@d
=00/;2`04a<C09JFUP2=SHd0TY:B092@T02GUiL0Ti>C08f=S@2ATI400P2?Shl0102@T900R8R808b<
S02;Rh/208Z:RP0V08N7Q`2?Shl0R8R808N7Q`25QHD0RXZ:08B4Q023Ph<0O7al07emO@1_Kfl0M7Ad
07IfMP1YJFT0IVIV06MWI`1VIVH0GUiN05YJFP1KFe/0FUYJ05UIF@1cLg<0Kfm_06ATI01MGEd0K6a/
06YZJP1XJ6P0Lg=c07AdM02;Rh/0Q8B408:2PP1gMgL0OGem07QhN01iNGT209>CT`0>09NGU`2XZ:P0
[:b/0:b/[02d];@0/[:b0;Fe]@2b/[80^KVi0;^k^`2c/k<0]kNg0;Jf]P2g]kLN0?ooo`80dM7A00P0
cLg=0<[:bP3AdM40dM7A0<o?c`3>c/h0dM7A0<c<c0<0dM7A00D0b/[:0<g=c@3<c<`0bLW90<g=c@02
0<o?c`0P0=3@d03=cLd0e=CD0=CDe037alL0_[jn0:FUY@2@T900QHF506e]K@1XJ6P0EeMG04Y:BP1C
De<0CTi>03dm?@0b<S80OWin0:FUY@2ZZZX0Zj^[0:BTY02XZ:P0YJFU0:b/[02UYJD0YZJV0:VYZ@2T
Y:@0XJ6Q0:VYZ@2MWId209nOW`0[0:2PX02VYZH0WinO09fMW@2NWYh0W9bL09JFUP2EUID0SXj>08N7
Q`1nOWh0RXZ:08F5Q@1oOgl0PH6107UiN@1oOgl0KFe]05mOG`1SHf<0IFEU07IfMP22PX80Lg=c06YZ
JP1^KVh0OGem07]kN`1gMgL0QHF509:BTP2DU9@0Rh^;08B4Q027QhL0P82008f=S@2MWId0YjNW0:b/
[02UYJD0/k>c0;Vi^@020<O7a`80bLW900L0b<S80=7Ad@3?cll0d=3@0=CDe03EeMD0dm?C0280oooo
000P0?ooo`0:08F5Q@29RHT0PX:20861P@29RHT0QXJ60861P@25QHD0PX:20861P@80QHF50`29RHT2
08F5Q@80QXJ601@0PX:208F5Q@25QHD0Ogmo08B4Q028R8P0MGEe06ATI01OGel0Fe]K04E5A@12@T80
=SHf03Ti>@0a<C40;2`/02<S8`0P82003@d=06e]K@80JVYZ0P1VIVH00`1cLg<0Jf][06IVIP03069R
HP0:061PH01MGEd0GemO061PH01KFe/0H61P05iNGP1RHV80G5aL05QHF080Fe]K00L0G5aL05]KF`1B
DU80EUIF04m?C`1:BTX0ATI60080?Shn02H0<S8b03`l?00b<S80<c<c03hn?P1;Bd/0De=C05IFEP1E
EED0CDe=04I6AP0m?Cd0DE5A04m?C`1;Bd/0GUiN05]KF`1JFUX0H61P06QXJ01RHV80HF5Q06UYJ@1`
L700NGUi079bLP1fMWH0Ng]k08N7Q`24Q8@0PH6108:2PP21PH40RHV908Z:RP24Q8@0QHF508:2PQh0
oooo00X0^KVi0;^k^`2i^KT0]kNg0;^k^`2g]kL0/k>c0;Vi^@2e]KD0]kNg0P2i^KT20;^k^`030;Ng
]`2e]KD0^KVi0080^k^k0P2e]KD02P2g]kL0];Bd0;Fe]@2i^KT0[Zj^09bLW027QhL0Ng]k061PH01K
Fe/204m?C`80AdM701P0<C4a02`/;00>3Ph0UYJF096AT@2<S8`0TY:B09>CT`2JVYX0Shn?096AT@2>
SXh0RXZ:08^;R`2:RXX0QXJ608V9R@28R8P0QHF508Z:RP24Q8@0QhN708B4Q021PH4308>3P`0D07in
OP1fMWH0MGEe06i^KP1dM7@0I6AT05]KF`1PH600De=C05eMG@1ADE40De=C05UIF@1PH600KFe]07Ee
M@1ZJVX0JFUY06ATI01QHF43071`L00708J6QP24Q8@0Q8B407]kN`2;Rh/0O7al07inOP0209>CT`04
0:>SX`2ZZZX0/;2`0:b/[080]KFe00P0/[:b0;Vi^@2g]kL0^k^k0;Rh^02f][H0];Bd0;Fe]Ah0oooo
00X0dM7A0<k>cP3AdM40dm?C0<k>cP3:b/X0clo?0=7Ad@3=cLd0dm?C0P3AdM420<k>cP030<W9b@3<
c<`0dM7A0080clo?01d0cLg=0<c<c03:b/X0c/k>0<c<c033`l<0_;bl0:VYZ@2DU9@0OWin06UYJ@1W
IfL0De=C05aLG01DE5@0DU9B03Xj>P0_;bl0MgMg0:JVYP2SXj<0WIfM0:RXZ02][Jd0Xj>S09VIV@2S
Xj<0XJ6Q09nOW`0209fMW@0j09jNWP2OWil0VYZJ09jNWP2MWId0Vi^K09FEU@2FUYH0V9RH09ZJVP2E
UID0U9BD08Z:RP22PX80Q8B408:2PP25QHD0LG5a06a/K01bLW80IVIV06i^KP1PH600JVYZ06][J`1d
M7@0NGUi0820P01ZJVX0MGEe075aL@1iNGT0Ogmo0820P02FUYH0Vi^K09NGU`2@T900RXZ:08f=S@29
RHT0UYJF0:NWY`2ZZZX0^k^k0<W9b@3AdM40alO70<G5a@3:b/X0cLg=0=7Ad@3Cdm<0c/k>0<S8b03;
bl/0b/[:0<g=cB80oooo000P0?ooo`80QHF500L0RHV908:2PP1nOWh0QHF508:2PP1mOGd0RHV90080
QHF500<0PX:20861P@25QHD00P25QHD07@22PX80QHF508J6QP20P800Ng]k0861P@23Ph<0PX:208R8
R01iNGT0HF5Q059BDP1@D500>c/k03Hf=P0g=cL0=SHf03Ph>00^;Rh0:RXZ02LW9`0C4a<0I6AT069R
HP1WIfL0Jf][05mOG`1SHf<0Jf][0080I6AT00<0GUiN05eMG@1PH6000P1IFET0201LG5`0FEUI05aL
G01LG5`0Fe]K05YJFP1KFe/0EUIF0P1JFUX0301@D500De=C04m?C`1BDU80BTY:03`l?00m?Cd0>CTi
04A4A011@D40>CTi03Ph>080?Cdm0100Bd];04m?C`1FEUH0E5AD04i>CP16ATH0>c/k05]KF`1GEeL0
E5AD065QH@1_Kfl0HV9R05IFEP1JFUX0HF5Q0P1_Kfl0201fMWH0R8R808J6QP1mOGd0NWYj08J6QP21
PH40RHV91@25QHD00`26QXH0oooo0?ooo`0L0?ooo`80^KVi00P0^k^k0;Fe]@2g]kL0^KVi0;Fe]@2g
]kL0^k^k0;Fe]@80^KVi00<0]kNg0;Vi^@2i^KT00`2i^KT07P2k^k/0]KFe0;:b/P2i^KT0/k>c0;Bd
]02l_;`0/;2`096AT@1jNWX0N7Qh05YJFP1BDU80DE5A04U9B@1>CTh0@D5103De=@0c<c<04A4A09:B
TP2@T900TY:B09FEU@2<S8`0TY:B09FEU@2@T900S8b<08N7Q`80R8R80P22PX80;@26QXH0PX:208>3
P`23Ph<0QHF508:2PP20P800O7al08:2PP1nOWh0NGUi07IfMP1^KVh0MGEe06e]K@1IFET0Fe]K05EE
E@1MGEd0E5AD059BDP1=CDd0EEEE05YJFP1_Kfl0LG5a07QhN01]KFd0JVYZ065QH@1KFe/0NGUi075a
L@1oOgl0QhN708V9R@1kNg/0Q8B407emO@26QXH0UIFE092@T02WYjL0/[:b0:^[Z`020:j^[P040;Ng
]`2c/k<0^k^k0;Fe]@80^KVi0P2e]KD00`2k^k/0oooo0?ooo`0L0?ooo`80dM7A00P0c/k>0<g=c@3D
e=@0dM7A0<g=c@3De=@0c/k>0<c<c080dM7A00<0dm?C0=7Ad@3AdM400`3AdM403@3?cll0cLg=0=;B
dP3AdM40bl_;0<[:bP3=cLd0[Jf]09nOW`2;Rh/0R8R806a/K01PH6000P1HF5P03@1DE5@0ATI603/k
>`0c<c<0Lg=c0:JVYP2][Jd0ZZZZ0:BTY02UYJD0[Zj^0:6QX@2TY:@00P2LW9`01P2OWil0VYZJ09NG
U`2KVi/0VIVI09RHV080VIVI02l0V9RH09JFUP2@T900Ti>C09FEU@2?Shl0SXj>08:2PP24Q8@0PX:2
07QhN01YJFT0JVYZ06=SH`1UIFD0Fe]K05aLG01JFUX0IVIV07MgM`28R8P0P82007moO`1fMWH0KFe]
06i^KP1bLW80QhN708>3P`2HV9P0VIVI08N7Q`28R8P0W9bL09JFUP2RXZ80YZJV0:b/[035aLD0_[jn
0;Ng]`34a<@0c/k>0<[:bP3?cll0c/k>0<c<c0020=7Ad@80c<c<00<0clo?0?ooo`3oool0803oool0
0200oooo0100OWin08F5Q@22PX80PX:20861P@1lO7`0Ng]k07emO@2:RXX0QHF50861P@23Ph<0PX:2
08J6QP25QHD0QXJ60P25QHD04029RHT0QHF508:2PP21PH40OGem08F5Q@1jNWX0Jf][05]KF`1FEUH0
C4a<03Ph>00n?Sh0?Cdm03<c<`0X:2P201lO7`05024Q8@0C4a<0Jf][069RHP1XJ6P00P1TI6@00`1P
H600FUYJ05aLG00205mOG`0605QHF01IFET0FUYJ05mOG`1KFe/0EUIF0P1BDU802`1KFe/0EUIF05IF
EP1FEUH0Cdm?04a<C019BDT0B4Q804Y:BP0m?Cd0=3@d0080?Cdm01<0@D5102d];@0R8R80=CDe04Q8
B01ADE40Bd];04Q8B016ATH0Cdm?06IVIP1^KVh0DU9B04m?C`1FEUH0Bd];04e=C@1RHV80EeMG0080
EUIF00`0DU9B06UYJ@1lO7`0Ogmo08:2PP1iNGT0PX:207moO`24Q8@0Ogmo08F5Q@22PX8308F5Q@03
08N7Q`25QHD0RHV901h0oooo00H0]kNg0;Vi^@2e]KD0^KVi0;Fe]@2b/[820;Jf]P080;Rh^02d];@0
^KVi0;Rh^02e]KD0^k^k0;Fe]@2h^;P20;Bd]00G0;Ng]`2e]KD0^KVi0;Vi^@2b/[80^[Zj0;Jf]P2P
X:00QHF507alO01[Jf/0EUIF05UIF@1@D500BTY:04=3@`0`<300;2`/02l_;`0I6AT0UYJF08V9R@2<
S8`00P2?Shl03P2:RXX0QhN708>3P`28R8P0QHF507inOP22PX80Ogmo08:2PP1jNWX0N7Qh07IfMP1j
NWX0P8200P1lO7`0701hN7P0M7Ad079bLP1]KFd0Jf][06YZJP1JFUX0DE5A05ADE01GEeL0Fe]K04M7
A`0n?Sh0DE5A05eMG@1UIFD0HV9R06MWI`1]KFd0N7Qh08^;R`21PH40I6AT069RHP1dM7@0K6a/07If
MP28R8P208:2PP0;07QhN01aLG40TY:B09ZJVP2OWil0/K6a0:NWY`2c/k<0Zj^[0;Zj^P2f][H00`2i
^KT01@2e]KD0^KVi0;Zj^P2d];@0^k^k01h0oooo00X0e=CD0=7Ad@3=cLd0dM7A0<g=c@3AdM40e]KF
0=GEe@38b<P0b/[:0P3Bd]80103=cLd0clo?0<c<c039bLT20<[:bP0<0<W9b@3<c<`0dM7A0=;BdP3A
dM40clo?0;no_`2/[:`0T92@08J6QP1cLg<0Jf][0P1MGEd01P1BDU80DE5A03<c<`0e=CD0=SHf07in
OP80X:2P00L0W9bL0::RXP2RXZ80WIfM0:2PX02IVIT0VYZJ0080Ti>C00P0UIFE09:BTP2=SHd0QHF5
08R8R02;Rh/0T92@096AT@80SHf=01`0R8R808F5Q@27QhL0OWin0861P@1aLG40IVIV065QH@1MGEd0
J6QX06MWI`1?Cdl0De=C06MWI`1ZJVX0J6QX06e]K@1mOGd0SXj>09:BTP2GUiL0Jf][061PH01]KFd0
Ph>307moO`2NWYh0V9RH0P2DU9@02`27QhL0VYZJ0:ZZZP2[Zj/0Z:RX0<30`031`L40b<S80<K6aP3?
cll0e=CD00<0dM7A00D0c<c<0=7Ad@3?cll0b/[:0<k>cP0R0?ooo`00803oool00`29RHT0QHF508V9
R@0208J6QP80RXZ:00@0RHV908F5Q@25QHD0RXZ:0P21PH401025QHD0Ogmo08N7Q`21PH4208:2PP0:
07emO@21PH40QhN708B4Q020P800MGEe06IVIP1LG5`0BDU904A4A080=cLg00<0=CDe03Hf=P0Y:BT0
0P0V9RH05@0X:2P05aLG06=SH`1NGUh0GemO06=SH`1NGUh0Hf=S06ATI01LG5`0F5QH05aLG01GEeL0
DU9B055AD@19BDT0D51@04e=C@1@D500EUIF04a<C00205IFEP<0Cdm?0P1:BTX05P1=CDd0<c<c03Xj
>P0n?Sh0<c<c02LW9`0[:b/07QhN04U9B@0o?cl0@D5104=3@`11@D40Bd];06ATI01LG5`0HF5Q05YJ
FP1GEeL0DE5A05aLG01CDe<205IFEP0@04m?C`1OGel0IFEU07IfMP1`L700NWYj07UiN@25QHD0PX:2
07moO`29RHT0PH6108F5Q@29RHT0PH6107moO`80PX:200<0PH6108F5Q@3oool07@3oool01@2g]kL0
]KFe0;^k^`2g]kL0][Jf0080]kNg00X0][Jf0;Vi^@2i^KT0_;bl0;>c/`2h^;P0^k^k0;>c/`2k^k/0
/[:b0P2i^KT0:02g]kL0^;Rh0;Jf]P2e]KD0];Bd0;>c/`2DU9@0Q8B406m_K`1WIfL0Cdm?055AD@1=
CDd0Cdm?03/k>`0e=CD0<30`03De=@0O7al0TI6A08R8R02=SHd0SXj>08V9R@2;Rh/0QhN708>3P`21
PH40Ph>307inOP1jNWX0NGUi07EeM@1iNGT0Lg=c07EeM@1hN7P0MgMg07alO01hN7P207AdM00I06i^
KP1ZJVX0IfMW06][J`1>CTh0De=C05QHF01=CDd0A4A404I6AP0];Bd0De=C05QHF01SHf<0HV9R06=S
H`1/K6`0Ph>307UiN@27QhL0MGEe06YZJP1_Kfl0Ng]k06i^KP0208:2PP0D07AdM01kNg/0NGUi09FE
U@2FUYH0[Zj^0:^[Z`2`/;00[jn_0;6a/@2l_;`0/[:b0;Vi^@2k^k/0]KFe0;Jf]P2i^KT0]KFe0;Ng
]`2i^KTN0?ooo`080<W9b@3<c<`0c/k>0<[:bP3;bl/0a/K60<G5a@37alL20=7Ad@070<g=c@3;bl/0
d];B0<o?c`3@d=00c/k>0<g=c@020=7Ad@0I0=CDe03Bd]80bl_;0<S8b03>c/h0_;bl0::RXP29RHT0
Ogmo07=cL`1JFUX0GEeM05mOG`1CDe<0@D5103Lg=`0d=3@0>SXj07MgM`2VYZH0WinO0:JVYP2RXZ80
WYjN09fMW@0209BDU00309RHV02EUID0SXj>0080TI6A03T0Ti>C08j>SP27QhL0S8b<08R8R02DU9@0
SHf=08R8R025QHD0Q8B407emO@1dM7@0OGem06][J`1FEUH0I6AT065QH@1MGEd0EUIF051@D00d=3@0
Fe]K06ATI01lO7`0L71`07emO@26QXH0R8R808n?S`26QXH0N7Qh07=cL`23Ph<0PX:208Z:RP2FUYH0
UIFE08B4Q02=SHd0SXj>0:FUY@2c/k<0a<C40<S8b031`L40a<C40<g=c@3<c<`0cLg=0=7Ad@3>c/h0
cLg=0=GEe@3AdM40cLg=0=?Cd`3AdM408P3oool00200oooo0P25QHD00`21PH40QXJ607inOP0207em
O@0;07inOP22PX80PH6108F5Q@2:RXX0RHV908J6QP1lO7`0PH6107emO@23Ph<00P26QXH04P29RHT0
PH6108B4Q020P800K6a/05UIF@1@D500BDU904E5A@11@D40>SXj03@d=00X:2P092@T02<S8`0U9BD0
92@T01dM7@80Hf=S00X0K6a/06MWI`1XJ6P0I6AT06QXJ01[Jf/0IfMW06ATI01UIFD0F5QH0P1<C4`0
2@18B4P0CTi>04Q8B018B4P0D51@04a<C018B4P0CTi>04U9B@0204A4A00804=3@`15ADD0<c<c030`
<00c<c<09bLW02HV9P0/;2`203dm?@0305ADE016ATH0CDe=0080@D5101H0H61P05EEE@1KFe/0De=C
04a<C01=CDd0G5aL065QH@1PH600FUYJ065QH@1PH600GEeM07AdM021PH40M7Ad07emO@1oOgl0RXZ:
08F5Q@29RHT0PH610P25QHD01P2:RXX0QHF508V9R@26QXH0PH6108:2PQh0oooo0P2i^KT04@2g]kL0
^k^k0;>c/`2g]kL0][Jf0;Ng]`2i^KT0]kNg0;Vi^@2l_;`0][Jf0;^k^`2a/K40^;Rh0;>c/`2h^;P0
^k^k0080][Jf0140]KFe0;Vi^@2b/[80Y:BT08R8R01lO7`0K6a/069RHP1HF5P0CTi>04];B`0n?Sh0
=cLg038b<P0d=3@0<c<c02LW9`0208Z:RP0?08j>SP2=SHd0S8b<08N7Q`2<S8`0Rh^;08F5Q@24Q8@0
QHF507UiN@1cLg<0KFe]06i^KP1aLG40Jf][0080L71`01T0Lg=c071`L01dM7@0Jf][06QXJ01WIfL0
H61P06IVIP1<C4`0ATI604a<C011@D40?Cdm03hn?P18B4P0EeMG06e]K@1LG5`0JFUY05aLG01SHf<0
QHF507alO025QHD0LG5a0080KVi^0100NWYj07]kN`27QhL0NWYj07inOP1hN7P0Ph>309BDU02ZZZX0
YZJV0:RXZ02_[jl0]kNg0;Bd]02k^k/0/k>c0P2i^KT01P2l_;`0];Bd0;^k^`2k^k/0/k>c0;Vi^Ah0
oooo0P3AdM40903Cdm<0clo?0<o?c`3De=@0eMGE0=CDe03AdM40dm?C0=7Ad@3=cLd0alO70<k>cP3?
cll0d];B0=3@d03Bd]80clo?0<_;b`37alL0cLg=0=3@d039bLT0/K6a09^KV`27QhL0Ng]k06QXJ01M
GEd0EEEE05UIF@14A4@0@D5103Lg=`0j>SX0>c/k07YjNP80W9bL00d0UYJF09bLW02GUiL0V9RH09NG
U`2BTY80Rh^;08j>SP29RHT0Ph>308J6QP1lO7`0QXJ60080PX:202@0RHV90861P@26QXH0RHV908F5
Q@1jNWX0OGem07QhN01jNWX0Jf][051@D01MGEd0E5AD04m?C`17AdL0B4Q804A4A01bLW80Kfm_06MW
I`1dM7@0J6QX08V9R@2FUYH0SXj>09:BTP1kNg/0Q8B408:2PP2>SXh0R8R808f=S@29RHT0Ogmo08J6
QP2WYjL20;:b/P070<71`@2l_;`0c<c<0<K6aP3:b/X0c/k>0<o?c`020=7Ad@030<g=c@3:b/X0c/k>
0080clo?00<0dM7A0?ooo`3oool0803oool00200oooo01/0OWin0861P@20P800OGem0861P@28R8P0
QHF508V9R@22PX80PH6108F5Q@21PH40Ogmo08N7Q`26QXH0PH6108>3P`1oOgl0QXJ607inOP1mOGd0
PH6107moO`1nOWh0KVi^05eMG@1CDe<00`16ATH02@0l?3`0=CDe01dM7@0T92@0:2PX028R8P0`<300
;2`/06m_K`0207emO@0;07alO01oOgl0MGEe075aL@1/K6`0Jf][06YZJP1^KVh0LG5a06e]K@1<C4`0
0P19BDT06@1:BTX0AdM70451@@1:BTX0C4a<04M7A`1;Bd/0AdM703hn?P10@400>CTi038b<P0d=3@0
;bl_028R8P0S8b<0>3Ph034a<@0n?Sh0Bd];04Y:BP0m?Cd0ATI604A4A01LG5`00P1`L7004P1VIVH0
F5QH03dm?@10@400HF5Q061PH01ADE40HV9R06YZJP1lO7`0Ng]k08N7Q`23Ph<0QHF507emO@21PH40
PX:20861P@80QHF500L0PX:20861P@25QHD0QHF508V9R@22PX80PH6101h0oooo0P2g]kL0202e]KD0
]kNg0;Bd]02h^;P0];Bd0;Ng]`2i^KT0/k>c0P2i^KT05@2f][H0^[Zj0;Jf]P2c/k<0][Jf0;6a/@2k
^k/0/k>c0;Ng]`2i^KT0/[:b0;Fe]@2LW9`0QXJ607MgM`1TI6@0Hf=S05aLG01@D500Bd];02`/;002
03De=@0:030`<00n?Sh0;Bd]08f=S@2DU9@0WIfM09JFUP2GUiL0TI6A09:BTP80SXj>00P0RXZ:08b<
S02:RXX0PH61071`L01XJ6P0JVYZ06][J`80JFUY01X0Kfm_06a/K01YJFT0K6a/06EUI@1KFe/0GUiN
05MGE`1:BTX0ATI604U9B@0e=CD0=3@d04A4A010@400EEEE06QXJ01WIfL0G5aL06EUI@1LG5`0OWin
08n?S`24Q8@0P82007=cL`80IFEU0P27QhL03@1eMGD0PH6108Z:RP27QhL0VIVI0;Vi^@2XZ:P0];Bd
0:b/[02g]kL0^KVi0;Ng]`2e]KD00P2i^KT01P2g]kL0^KVi0;Vi^@2k^k/0]KFe0;Vi^Ah0oooo00l0
e=CD0=?Cd`3=cLd0e=CD0<k>cP39bLT0b/[:0<W9b@3AdM40clo?0=7Ad@3Bd]80eMGE0<o?c`37alL0
0P3<c<`0:@3=cLd0clo?0<o?c`3De=@0d];B0<c<c03=cLd0XZ:R08n?S`1mOGd0LG5a06][J`1WIfL0
DE5A05QHF00];Bd0@d=303Ph>00g=cL0AdM706e]K@2LW9`0TY:B09jNWP2EUID0Ti>C09:BTP2IVIT0
UYJF09NGU`2CTi<0T92@08B4Q01iNGT0Ogmo07UiN@1mOGd0O7al07]kN`24Q8@0QHF50080Ng]k02P0
NWYj071`L01[Jf/0NGUi05]KF`1CDe<0EeMG051@D00l?3`0?clo059BDP13@d<0KVi^07EeM@1`L700
KFe]07=cL`1hN7P0UIFE08n?S`1oOgl0NGUi07alO01kNg/0VYZJ09VIV@2<S8`0Rh^;092@T02IVIT0
UIFE0:ZZZP35aLD0];Bd0<K6aP38b<P0dm?C0=7Ad@3Cdm<0c<c<0P3AdM401P3Cdm<0dM7A0=7Ad@3>
c/h0cLg=0=;BdR80oooo000P0?ooo`0908V9R@22PX80R8R808b<S025QHD0QXJ60861P@25QHD0RHV9
0080QHF500L0R8R80861P@22PX80QXJ608V9R@25QHD0OWin0080QHF501d0PH6108:2PP24Q8@0NGUi
05mOG`1GEeL0DE5A04Q8B00i>CT0<C4a03hn?P0^;Rh092@T02DU9@0/;2`08b<S03lo?`1CDe<0LW9b
07MgM`1cLg<0LW9b071`L01iNGT0NWYj07EeM@1^KVh0KFe]06YZJP0206QXJ00906IVIP1EEED0ADE5
04A4A01;Bd/0CTi>0451@@12@T80Bd];0080BDU900d0>c/k03Ti>@15ADD0@41004I6AP0W9bL092@T
02/[:`0e=CD0>CTi03Lg=`14A4@0ATI60080@T9201D0@d=3055AD@1RHV80Hf=S06MWI`1JFUX0De=C
04Y:BP1DE5@0H61P05mOG`1RHV80EeMG065QH@1mOGd0L71`07=cL`1oOgl0QXJ60861P@25QHD00P1m
OGd0201nOWh0QHF508F5Q@22PX80PH6108F5Q@29RHT0RXZ:7P3oool0:02g]kL0]KFe0;^k^`2f][H0
/[:b0;^k^`2c/k<0^KVi0;Ng]`2e]KD0^KVi0;bl_02b/[80]KFe0;Zj^P2f][H0^;Rh0;2`/02i^KT0
]kNg0;Fe]@2d];@0]KFe0;Bd]02BTY80PX:207=cL`1UIFD0EUIF04a<C01KFe/0@T9203De=@0`<300
>c/k034a<@11@D40ADE508j>SP2KVi/209fMW@0;09^KV`2OWil0VIVI09VIV@2ATI40T92@08n?S`2=
SHd0RXZ:07MgM`1^KVh00P1UIFD206UYJ@0c065QH@1WIfL0JFUY06IVIP1WIfL0EUIF05MGE`1OGel0
CTi>059BDP0m?Cd0=3@d03Ph>011@D40CDe=059BDP1UIFD0I6AT05iNGP1LG5`0H61P07QhN029RHT0
RXZ:08^;R`1iNGT0K6a/05mOG`21PH40QhN707]kN`1jNWX0P82008F5Q@2c/k<0ZZZZ0:RXZ02_[jl0
][Jf0;>c/`2k^k/0/[:b0;Jf]P2g]kL0^KVi0;Fe]@2i^KT0]kNg0;Vi^@2k^k/0^;Rh01h0oooo00D0
bLW90<g=c@3>c/h0`l?30<S8b0020<o?c`0V0=7Ad@39bLT0c<c<0=7Ad@3=cLd0c<c<0<g=c@3@d=00
alO70<[:bP3?cll0dM7A0<[:bP3=cLd0b/[:0<W9b@36a/H0Xj>S08n?S`1jNWX0Kfm_065QH@1OGel0
IFEU04Q8B00e=CD0?3`l0410@00f=SH0EEEE06ATI02KVi/0[:b/0:j^[P2][Jd0[Zj^0:VYZ@2NWYh2
09bLW00409^KV`2JVYX0UiNG096AT@80L71`02P0M7Ad07YjNP1gMgL0M7Ad075aL@1nOWh0MgMg07=c
L`1aLG40HV9R07=cL`1LG5`0DE5A05UIF@16ATH0>CTi0451@@1FEUH0BTY:06][J`1kNg/0KFe]06YZ
JP1/K6`0NWYj09fMW@2KVi/0VYZJ08j>SP22PX80MGEe07alO02KVi/0Ti>C08B4Q02?Shl0YjNW0;Vi
^@37alL0b<S80P3<c<`03@38b<P0clo?0<o?c`3AdM40eMGE0=CDe03AdM40c<c<0=7Ad@3Cdm<0dM7A
0<k>cP38b<P08P3oool00200oooo00P0OWin08F5Q@1oOgl0PX:207emO@23Ph<0PH6107moO`80QHF5
00X0PX:20861P@1oOgl0PX:20861P@22PX80QHF50861P@1mOGd0P8200P21PH403P22PX80QhN705]K
F`1CDe<0Bd];0451@@19BDT0>SXj03Ph>00S8b<09BDU02/[:`0W9bL0De=C0P1dM7@01P1lO7`0M7Ad
07QhN01iNGT0Ng]k07AdM0<0MgMg0140LW9b06i^KP1/K6`0JVYZ06UYJ@1_Kfl0Jf][051@D012@T80
@D5104e=C@17AdL0ADE504I6AP0o?cl0=CDe028R8P0203dm?@0P0492@P0R8R8061PH01LG5`0V9RH0
DU9B03Ph>01;Bd/0CDe=055AD@1>CTh0AdM705YJFP1YJFT0MGEe07=cL`1<C4`0DE5A04a<C01>CTh0
DU9B065QH@1HF5P0KVi^07IfMP1cLg<0NWYj07moO`21PH40RHV90861P@25QHD208V9R@0808J6QP1n
OWh0PH6108V9R@25QHD0PX:20861P@25QHDN0?ooo`080;Ng]`2i^KT0/k>c0;Vi^@2g]kL0^;Rh0;Fe
]@2f][H40;Vi^@0D0;>c/`2i^KT0/k>c0;Vi^@2j^[X0/;2`0;>c/`2h^;P0];Bd0;>c/`2e]KD0_Kfm
08R8R01jNWX0K6a/065QH@1RHV80DE5A04m?C`0e=CD303Hf=P0D04e=C@14A4@0Lg=c09nOW`2MWId0
XJ6Q0:2PX02QXJ40W9bL0:6QX@2OWil0V9RH09NGU`2DU9@0T92@08f=S@27QhL0QHF507UiN@1WIfL2
069RHP0C06YZJP1PH600I6AT06EUI@1NGUh0Cdm?03lo?`1MGEd0D51@05MGE`0c<c<09RHV02LW9`0n
?Sh0IFEU059BDP1QHF40J6QX06ATI002069RHP0D07EeM@2;Rh/0TI6A096AT@1cLg<0IfMW06i^KP1g
MgL0NWYj0861P@1lO7`0NGUi09BDU02`/;00Z:RX0::RXP2][Jd0^k^k0;Fe]@2i^KT20;Jf]P080;Ng
]`2c/k<0]kNg0;^k^`2e]KD0^KVi0;Ng]`2i^KTN0?ooo`080=CDe03AdM40d=3@0=7Ad@3De=@0d];B
0<g=c@3EeMD30=7Ad@090=;BdP3@d=00dM7A0<o?c`3AdM40clo?0<_;b`3@d=00d];B0080bl_;04`0
cLg=0;jn_P2EUID0R8R807EeM@1^KVh0IFEU05QHF01LG5`0=cLg03hn?P0o?cl0?3`l04a<C00c<c<0
MWIf0:^[Z`2`/;00[Jf]0;2`/02YZJT0[jn_0:j^[P2ZZZX0X:2P09nOW`2PX:00VIVI09RHV02;Rh/0
NWYj06a/K01VIVH0M7Ad07MgM`1fMWH0Jf][07IfMP1cLg<0K6a/05QHF01EEED0M7Ad059BDP1`L700
>SXj02/[:`0e=CD0IfMW05iNGP1ZJVX0MGEe06MWI`1_Kfl0Hf=S07QhN02;Rh/0W9bL09BDU02<S8`0
NGUi07=cL`28R8P0SXj>09FEU@2@T900UYJF09>CT`2XZ:P0b/[:0;no_`2f][H0a/K60<k>cP3=cLd0
d=3@0P37alL0203:b/X0clo?0=?Cd`3>c/h0c<c<0=7Ad@3Cdm<0dM7A8P3oool00200oooo00P0QHF5
08V9R@25QHD0PH6107moO`25QHD0RXZ:08V9R@80QHF500L0PH6108:2PP21PH40RHV908J6QP25QHD0
RHV90080QHF50P22PX802P21PH40Ng]k06][J`1@D500Cdm?04U9B@12@T80>c/k03Lg=`0X:2P202DU
9@0902@T901;Bd/0LW9b079bLP1^KVh0L71`07=cL`1gMgL0N7Qh0080OGem00L0N7Qh079bLP1`L700
L71`06][J`1XJ6P0L71`0080J6QX01h0JFUY06EUI@1UIFD0CTi>03Xj>P10@400?Shn03dm?@0k>c/0
<c<c02`/;00[:b/0GEeM03dm?@0_;bl05ADE02XZ:P0k>c/0?Shn05EEE@1;Bd/0EeMG0451@@15ADD0
De=C05EEE@1@D500GUiN07EeM@1VIVH204M7A`0>04];B`1HF5P0Kfm_06i^KP1BDU80Lg=c08R8R023
Ph<0Q8B408N7Q`21PH40QXJ60861P@22PX8208F5Q@80RHV900D0PX:20861P@25QHD0PX:20861P@0N
0?ooo`090;Vi^@2k^k/0^KVi0;Vi^@2f][H0^KVi0;bl_02f][H0];Bd0080^KVi00L0^;Rh0;Bd]02k
^k/0]kNg0;Fe]@2g]kL0]KFe00<0^KVi01L0]KFe0;6a/@2PX:00MgMg079bLP1UIFD0F5QH051@D01?
Cdl0?3`l03De=@0b<S80=SHf055AD@2JVYX0XJ6Q09bLW02OWil0Xj>S0:BTY02VYZH0Z:RX0::RXP02
0:6QX@0e09bLW02KVi/0VYZJ09VIV@2GUiL0S8b<08j>SP2:RXX0Q8B40820P01QHF40EeMG05eMG@1I
FET0FUYJ05IFEP1:BTX0?3`l03hn?P1dM7@0BDU903lo?`0T92@0?3`l03dm?@19BDT0EeMG069RHP1_
Kfl0G5aL06UYJ@1`L700MgMg07QhN02>SXh0VYZJ08V9R@1UIFD0Jf][075aL@1eMGD0S8b<08j>SP25
QHD0Xj>S0:NWY`2YZJT0/k>c0;^k^`2b/[80^k^k0;>c/`2i^KT00P2e]KD0102k^k/0]kNg0;Fe]@2g
]kL20;Vi^@030;Ng]`3oool0oooo01`0oooo00X0dM7A0<k>cP3AdM40d];B0=GEe@3AdM40cLg=0<O7
a`3:b/X0dM7A0P3Bd]801P3;bl/0c/k>0<[:bP3<c<`0bLW90<c<c080dM7A00P0d=3@0<W9b@2m_Kd0
]KFe08V9R@1kNg/0JFUY05]KF`80FUYJ00X0@D5103Xj>P0o?cl0@41005MGE`2_[jl0];Bd0;Ng]`2i
^KT0_[jn0P2j^[X01@2d];@0[Jf]0:f][@2d];@0[jn_0080[Zj^02l0[Jf]0:>SX`2IVIT0VYZJ092@
T028R8P0MWIf05]KF`1YJFT0K6a/06MWI`1XJ6P0HV9R051@D011@D40JVYZ06EUI@1NGUh0>CTi02d]
;@14A4@0@D5105mOG`1?Cdl0KFe]079bLP1XJ6P0QXJ607]kN`2=SHd0W9bL0;2`/02PX:00PX:207in
OP1oOgl0SHf=09:BTP2FUYH0Ti>C0;^k^`33`l<0/K6a0;Zj^P37alL0c/k>0<g=c@020<o?c`070=7A
d@3<c<`0c<c<0<k>cP39bLT0cLg=0=?Cd`020=7Ad@030=?Cd`3oool0oooo0200oooo000P0?ooo`0=
07]kN`1oOgl0PH6108Z:RP25QHD0PH6107moO`22PX80PH6108:2PP24Q8@0PX:208>3P`0208:2PP0F
07emO@1oOgl0QHF507inOP25QHD0PH6107alO01jNWX0JFUY05ADE01<C4`0@T9203De=@0a<C40<c<c
024Q8@0R8R809bLW03Xj>P1FEUH0Kfm_07UiN@80M7Ad00L0Lg=c06m_K`1aLG40Jf][06m_K`1hN7P0
LW9b0080Kfm_0300MGEe07UiN@1]KFd0Jf][06QXJ01WIfL0J6QX06][J`1UIFD0AdM703/k>`0o?cl0
>3Ph03Xj>P0];Bd07alO01hN7P1EEED0>SXj05iNGP1KFe/0:b/[02`/;00Y:BT0@T9203lo?`17AdL0
FEUI04];B`1ADE40CTi>05IFEP1BDU80M7Ad071`L017AdL0EeMG05IFEP1>CTh0D51@05iNGP1bLW80
MWIf07MgM`1lO7`0Ogmo08F5Q@22PX8208F5Q@0808J6QP21PH40PX:207inOP21PH40QXJ607inOP22
PX8208F5QAh0oooo0P2f][H02`2g]kL0_;bl0;Bd]02i^KT0][Jf0;Vi^@2g]kL0^KVi0;Zj^P2d];@0
][Jf0080^KVi01/0/k>c0;Jf]P2i^KT0]KFe0;^k^`2f][H0/k>c0;6a/@2KVi/0MGEe06a/K01PH600
Cdm?04a<C01:BTX0<C4a038b<P0e=CD0AdM703Ph>02MWId0Y:BT09bLW02QXJ40X:2P0:6QX@2TY:@0
0P2QXJ409@2XZ:P0WYjN09^KV`2KVi/0WYjN09^KV`2CTi<0TY:B08j>SP2<S8`0RXZ:08R8R020P800
Fe]K05IFEP1IFET0DU9B05ADE012@T80;bl_03Ti>@1]KFd0De=C06][J`1CDe<0<C4a0410@016ATH0
Hf=S069RHP1WIfL0Lg=c065QH@1bLW80LG5a07alO01mOGd00P2FUYH04P1RHV80M7Ad06i^KP1bLW80
Ph>308j>SP28R8P0UiNG0:^[Z`2a/K40/k>c0;Vi^@2e]KD0^KVi0;Fe]@2k^k/0/k>c0;Vi^@80]kNg
00D0^k^k0;>c/`2i^KT0^KVi0;Fe]@0N0?ooo`0=0=KFeP3EeMD0dm?C0<g=c@3:b/X0d];B0=CDe03A
dM40dm?C0=7Ad@3@d=00b/[:0<c<c0020=7Ad@0K0=3@d03De=@0dM7A0=KFeP3?cll0c<c<0<S8b02n
_[h0YjNW0861P@1dM7@0JVYZ05QHF01NGUh0FUYJ038b<P0l?3`0?clo04];B`1=CDd0^;Rh0;:b/P2_
[jl0][Jf0;Vi^@30`<00^k^k0080_kno00H0][Jf0;2`/02_[jl0/;2`0:^[Z`2QXJ4209nOW`0^09ZJ
VP2IVIT0TI6A08B4Q01fMWH0F5QH06IVIP1UIFD0GUiN069RHP1;Bd/0=CDe06QXJ01oOgl0De=C04e=
C@0h>3P0:RXZ05eMG@1IFET0KVi^07inOP1iNGT0MgMg06i^KP25QHD0UYJF08f=S@2[Zj/0YZJV08F5
Q@1jNWX0O7al07emO@2ATI40Zj^[0:NWY`2KVi/0[jn_0<W9b@3?cll0c<c<0=7Ad@3=cLd0dM7A0<c<
c080clo?00<0dM7A0=CDe03Cdm<00P3?cll20=7Ad@030<c<c03oool0oooo0200oooo000P0?ooo`03
08B4Q021PH40PH610080QHF500/0QhN707inOP25QHD0QHF508V9R@26QXH0PX:208J6QP25QHD0RHV9
08Z:RP0208F5Q@0B08:2PP1oOgl0NWYj07QhN01bLW80JFUY04I6AP15ADD0?clo03`l?00g=cL08b<S
02HV9P0];Bd0>CTi06i^KP1`L700LG5a0P1dM7@00`1aLG40Jf][06IVIP0206e]K@0U06IVIP1]KFd0
HF5Q06ATI01YJFT0JVYZ06IVIP1/K6`0Hf=S06ATI01UIFD0IfMW06QXJ01QHF40K6a/04U9B@0a<C40
>3Ph034a<@0V9RH0:2PX02<S8`0[:b/0I6AT05eMG@0i>CT0De=C03hn?P13@d<0Cdm?0451@@12@T80
C4a<03hn?P0i>CT0BTY:061PH00204m?C`070820P013@d<0@d=3051@D01CDe<0E5AD06UYJ@0207al
O00307QhN01oOgl0PX:20080PX:200L0PH6108:2PP25QHD0PX:208F5Q@26QXH0PH610080RHV90`25
QHDN0?ooo`030;Fe]@2b/[80/k>c0080^KVi01l0^k^k0;:b/P2i^KT0]KFe0;^k^`2g]kL0]KFe0;Jf
]P2i^KT0]kNg0;Rh^02d];@0^KVi0;:b/P2i^KT0/K6a0;>c/`2WYjL0VYZJ06a/K01YJFT0Fe]K05AD
E01:BTX0=cLg03Ti>@0g=cL0@d=304U9B@1JFUX0Vi^K00<0XJ6Q0140WIfM09RHV02SXj<0W9bL09RH
V02RXZ80UiNG09JFUP2GUiL0VIVI09NGU`2KVi/0Shn?08j>SP2;Rh/0S8b<08Z:RP0207inOP0405YJ
FP1=CDd0De=C04Q8B080>3Ph00`0<c<c04i>CP22PX80O7al04a<C01UIFD0A4A405UIF@1_Kfl0FEUI
06ATI01YJFT2065QH@0<06EUI@27QhL0LW9b08N7Q`2XZ:P0GemO06UYJ@1aLG40NGUi07YjNP29RHT0
TY:B0P2ZZZX01@2^[Zh0]KFe0;Fe]@2i^KT0/k>c0080^KVi00T0]KFe0;Vi^@2g]kL0/k>c0;^k^`2g
]kL0^KVi0;Fe]@2i^KT07P3oool00`39bLT0c<c<0<o?c`020=7Ad@80c/k>01d0dM7A0<c<c03>c/h0
b/[:0<g=c@3;bl/0dM7A0<W9b@38b<P0b/[:0=7Ad@39bLT0dM7A0<k>cP35aLD0_;bl09jNWP1kNg/0
NGUi06=SH`1IFET0De=C0492@P0m?Cd0?Shn04E5A@13@d<0EUIF0;6a/@030;Jf]P0<0;^k^`2i^KT0
_;bl0;Bd]02i^KT0_;bl0;Ng]`2d];@0/k>c0:n_[`2c/k<0ZZZZ0P2RXZ805@2KVi/0VIVI096AT@20
P800KFe]05ADE01JFUX0Hf=S059BDP0o?cl0?3`l04];B`26QXH0LW9b08J6QP17AdL0IFEU0451@@1O
Gel0NGUi06=SH`0207alO00806i^KP2;Rh/0QHF509>CT`2FUYH0]KFe0:BTY01/K6`208V9R@0;08b<
S02IVIT0VYZJ0:FUY@2j^[X0bLW90<K6aP3:b/X0cLg=0=7Ad@3?cll00P3AdM402@3=cLd0dM7A0<[:
bP3?cll0c/k>0<W9b@3AdM40c<c<0=7Ad@0R0?ooo`00803oool00`29RHT0QHF50861P@0208F5Q@03
08J6QP25QHD0PX:20080OWin0100QHF508V9R@22PX80PX:207emO@1lO7`0OGem07inOP29RHT0R8R8
07EeM@1fMWH0IVIV05mOG`18B4P0>SXj0`0g=cL202<S8`0<01dM7@1GEeL0L71`07AdM01]KFd0JVYZ
06a/K01_Kfl0J6QX05aLG01HF5P0EeMG0P1EEED02@1HF5P0FUYJ05EEE@1JFUX0GEeM06MWI`1]KFd0
Jf][06MWI`0206=SH`0=065QH@1SHf<0LG5a05aLG00l?3`0=CDe02h^;P0W9bL09RHV02<S8`18B4P0
@41007EeM@0205YJFP07034a<@16ATH0EUIF04];B`0m?Cd0CTi>04=3@`0205EEE@0E05YJFP1YJFT0
L71`069RHP1PH600EeMG059BDP1@D500GemO07YjNP22PX80Ph>307moO`22PX80RHV908J6QP21PH40
QHF507emO@26QXH0OWin00H0QHF500<0PX:20?ooo`3oool0703oool00`2g]kL0]KFe0;>c/`020;Vi
^@030;^k^`2e]KD0]KFe0080]kNg00D0^KVi0;Ng]`2e]KD0]KFe0;Ng]`020;Jf]P0A0;Ng]`2k^k/0
^[Zj0:f][@2_[jl0VYZJ09BDU01[Jf/0F5QH05EEE@1?Cdl0CDe=03Lg=`0a<C40;Bd]04=3@`1HF5P0
0`2MWId01P2NWYh0X:2P09ZJVP2CTi<0TI6A092@T080Shn?0`2;Rh/0102BTY80SXj>09BDU02CTi<2
08f=S@80RXZ:00@0PX:207inOP23Ph<0IVIV0P1=CDd0:@0o?cl0=CDe03Lg=`10@400K6a/05UIF@2;
Rh/0FEUI06m_K`15ADD0GemO06m_K`1PH600GemO06i^KP1IFET0Lg=c07]kN`1mOGd0R8R808f=S@1i
NGT0JVYZ07AdM01hN7P0LW9b08B4Q02UYJD0/[:b0:ZZZP2a/K40]KFe0;^k^`2g]kL0/k>c0;^k^`2b
/[80^k^k0;>c/`2i^KT0]KFe0080^KVi00<0]KFe0;Vi^@2i^KT07P3oool00`39bLT0c<c<0<o?c`02
0=7Ad@030<o?c`3<c<`0cLg=0080e=CD00D0dM7A0<W9b@3=cLd0cLg=0=CDe0020=GEe@0C0=CDe03>
c/h0a/K60<K6aP32`/80[jn_09jNWP1gMgL0IFEU069RHP1JFUX0EeMG04=3@`0f=SH0>CTi05aLG01D
E5@0[jn_0;Fe]@020;Zj^P050;Jf]P2d];@0];Bd0;Jf]P2e]KD00P2g]kL0;`2[Zj/0ZZZZ0;2`/02b
/[80[Zj^0:VYZ@2OWil0VIVI09ZJVP2LW9`0V9RH08Z:RP23Ph<0KVi^055AD@1@D500De=C0492@P0i
>CT0ATI606MWI`2;Rh/0KFe]07YjNP1<C4`0IfMW04Q8B01eMGD0KFe]06a/K01bLW80N7Qh06YZJP20
P800Ti>C09FEU@2JVYX0Vi^K07MgM`1]KFd0Ogmo08V9R@2DU9@0XJ6Q0;Ng]`39bLT0^KVi0080b/[:
00D0c/k>0<[:bP3?cll0clo?0=7Ad@020<o?c`050=7Ad@3<c<`0dM7A0=7Ad@3<c<`00P3AdM4R0?oo
o`00803oool01@25QHD0PX:208F5Q@25QHD0PX:20080QHF500<0RHV908J6QP25QHD00P25QHD07`29
RHT0QXJ608B4Q024Q8@0QHF508V9R@1nOWh0Q8B40820P01dM7@0Kfm_069RHP16ATH0AdM703De=@0c
<c<0<S8b02@T900`<300Ogmo075aL@1fMWH0LW9b07=cL`1_Kfl0KFe]06YZJP1TI6@0GemO05MGE`1B
DU800`1?Cdl0201EEED0FEUI05UIF@1JFUX0Fe]K06MWI`1XJ6P0JFUY0P1SHf<05`1OGel0EeMG05UI
F@1PH600ATI602l_;`0W9bL06a/K01hN7P0/;2`0>c/k03Hf=P0h>3P0G5aL05QHF01/K6`0<c<c04Y:
BP1BDU80CTi>04e=C@1?Cdl0FUYJ0080Fe]K01<0Cdm?05eMG@1WIfL0FEUI05eMG@1RHV80Fe]K061P
H023Ph<0NGUi08:2PP20P800R8R80861P@29RHT0PH6108F5Q@29RHT0QXJ60080QHF500<0PX:20861
P@25QHD00P25QHD00`29RHT0oooo0?ooo`0L0?ooo`80^KVi00L0]KFe0;Vi^@2i^KT0^KVi0;Fe]@2k
^k/0]kNg0080]KFe00H0^KVi0;^k^`2k^k/0][Jf0;Fe]@2d];@20;Ng]`070;bl_02c/k<0Y:BT09nO
W`2:RXX0I6AT061PH00204];B`0?04Q8B00a<C40?Cdm04];B`0o?cl0WYjN09bLW02PX:00Vi^K09ZJ
VP2LW9`0UiNG08f=S@26QXH0Ph>30080P82000<0OGem08>3P`25QHD00P25QHD0102:RXX0T92@092@
T02ATI4208Z:RP0H08:2PP1mOGd0OWin07]kN`1LG5`0A4A403Ph>00Z:RX0<30`0451@@1ADE40Fe]K
05QHF01mOGd0Kfm_07UiN@1CDe<0Jf][06a/K01YJFT0HF5Q06UYJ@1oOgl0N7Qh0P1nOWh04P2=SHd0
Ng]k07QhN020P800OGem07EeM@24Q8@0]kNg0:BTY02f][H0/K6a0;Jf]P2g]kL0^k^k0;Fe]@2i^KT0
][Jf0;^k^`80]KFe00<0^KVi0;Ng]`2i^KT00P2i^KT00`2k^k/0oooo0?ooo`0L0?ooo`80dM7A00L0
c<c<0=7Ad@3AdM40dM7A0<c<c03>c/h0b/[:0080c<c<00@0dM7A0<k>cP3?cll0c<c<0P3:b/X04@39
bLT0e=CD0<g=c@2n_[h0][Jf0:JVYP2?Shl0LG5a06=SH`1@D500FEUI059BDP0h>3P0@T9202/[:`0d
=3@0[Zj^0080/K6a00H0[jn_0;6a/@2b/[80[Zj^0::RXP2PX:0309nOW`0609bLW02RXZ80W9bL0:2P
X02QXJ40Y:BT0P2SXj<05`2NWYh0Vi^K09RHV02>SXh0SHf=08^;R`1eMGD0EEEE04];B`0o?cl0<C4a
03lo?`1KFe/0NWYj06][J`2@T900Ng]k07UiN@1JFUX0LG5a08B4Q01aLG40KFe]0080Kfm_01H0RHV9
08f=S@2?Shl0YJFU0;Bd]01iNGT0QhN708b<S022PX80RHV90:2PX037alL0`<300<c<c03:b/X0b<S8
0=?Cd`3>c/h0cLg=0=7Ad@37alL0clo?0P3<c<`00`3AdM40dm?C0=7Ad@020=7Ad@030<k>cP3oool0
oooo0200oooo000P0?ooo`0608F5Q@26QXH0PX:208F5Q@22PX80PH610P25QHD01P26QXH0PH6108F5
Q@22PX80OGem08F5Q@80QXJ60100RXZ:0861P@24Q8@0Ph>307emO@1VIVH0GEeM051@D00n?Sh0=CDe
030`<00a<C40<30`02`/;01cLg<0M7Ad0`1_Kfl04P1cLg<0FEUI04E5A@1JFUX0H61P08j>SP1^KVh0
GEeM06MWI`1jNWX0H61P05aLG01HF5P0DU9B03/k>`10@400GUiN06=SH`80J6QX02<0Hf=S06MWI`1O
Gel0Fe]K05YJFP1DE5@0IVIV01lO7`0L71`05QHF02<S8`0E5AD0MgMg04Q8B00h>3P0De=C04a<C01U
IFD0FEUI05IFEP12@T80C4a<055AD@1;Bd/0Fe]K04m?C`1JFUX0HF5Q06UYJ@12@T80CDe=05EEE@1@
D500IfMW07moO`030820P00708Z:RP22PX80PX:20861P@26QXH0PH6107inOP0208F5Q@0608:2PP25
QHD0QHF508:2PP21PH40PX:27P3oool01P2i^KT0^k^k0;Vi^@2i^KT0]KFe0;Ng]`80^KVi01P0^k^k
0;>c/`2i^KT0^KVi0;Ng]`2i^KT0^k^k0;Jf]P2g]kL0];Bd0;Rh^02g]kL0Z:RX09ZJVP2CTi<0MGEe
05YJFP1>CTh0BDU904I6AP10@400>c/k04I6AP1ADE4209bLW00_09^KV`2MWId0TI6A08F5Q@2;Rh/0
MWIf08b<S01oOgl0NWYj07emO@24Q8@0Ng]k06m_K`1]KFd0JVYZ05iNGP1`L700QhN708f=S@2@T900
TI6A08Z:RP29RHT0PH6107moO`1jNWX0LW9b07UiN@0[:b/0:2PX024Q8@0f=SH0:RXZ08b<S01TI6@0
H61P07emO@1aLG40Ogmo071`L01YJFT0Hf=S06i^KP1TI6@0KFe]07inOP1^KVh00P25QHD04`2DU9@0
Kfm_07emO@1fMWH0N7Qh08Z:RP2TY:@0[jn_0;Bd]02/[:`0]KFe0;Vi^@2d];@0/k>c0;^k^`2c/k<0
]kNg0;Vi^@2e]KD00P2i^KT0102e]KD0^KVi0;>c/`2i^KTN0?ooo`060=7Ad@3?cll0dM7A0=7Ad@3=
cLd0dm?C0P3AdM420<o?c`80dM7A01@0e=CD0=7Ad@3?cll0bl_;0<K6aP3;bl/0bLW90<;2`P2b/[80
[:b/0:6QX@1kNg/0I6AT05aLG01ADE40D51@0410@013@d<0>c/k04E5A@80/;2`03h0[jn_0:f][@2W
YjL0[jn_09VIV@1eMGD0IfMW07=cL`23Ph<0Q8B407]kN`1lO7`0KVi^071`L01_Kfl0Ng]k0:>SX`2O
Wil0YZJV0::RXP2NWYh0W9bL092@T02=SHd0RXZ:08>3P`1jNWX0IFEU02`/;00];Bd0:2PX04i>CP0h
>3P0PX:206=SH`2OWil0QHF509NGU`1eMGD0LG5a07AdM01^KVh0P82006EUI@27QhL0RXZ:08^;R`2P
X:00XJ6Q096AT@2>SXh0VYZJ08b<S02LW9`0/k>c0;Ng]`35aLD0alO70<K6aP34a<@0dM7A0<[:bP<0
clo?00<0e=CD0=7Ad@3<c<`00P3AdM40103<c<`0dM7A0<o?c`3AdM4R0?ooo`00803oool0601nOWh0
QHF508F5Q@22PX80QHF508:2PP21PH40PX:208F5Q@22PX80OWin08:2PP24Q8@0OWin0861P@1oOgl0
QHF508J6QP1oOgl0KFe]05aLG01DE5@0CDe=04];B`80<C4a00D0>CTi01lO7`0P8200@d=303hn?P02
07IfMP0J07=cL`1`L700KVi^06EUI@1ADE40E5AD055AD@0f=SH0A4A404Y:BP0m?Cd0;Bd]03@d=00i
>CT0C4a<05MGE`1>CTh0=CDe061PH01TI6@0IfMW06a/K01]KFd0Hf=S05mOG`1PH60205eMG@0I05]K
F`0g=cL0:BTY01@D500E5AD0>c/k0410@01NGUh0>SXj06UYJ@1@D500RHV9075aL@12@T80EUIF04m?
C`16ATH0BTY:05EEE@1DE5@0De=C05MGE`1`L700HF5Q05UIF@0205=CD`0605EEE@1mOGd0Ogmo07in
OP1jNWX0QHF50P29RHT01025QHD0RHV908:2PP29RHT208F5Q@0608V9R@25QHD0QHF508V9R@25QHD0
RHV97P3oool01`2g]kL0^KVi0;Vi^@2e]KD0^KVi0;Fe]@2g]kL00P2i^KT0202e]KD0]kNg0;Vi^@2f
][H0]kNg0;Vi^@2c/k<0^KVi0P2k^k/0F@2ZZZX0W9bL09:BTP1kNg/0L71`04i>CP19BDT0CTi>02l_
;`0f=SH0AdM7038b<P2RXZ80WYjN09fMW@2KVi/0WYjN09FEU@1hN7P0MGEe07AdM01kNg/0OGem07Ad
M01[Jf/0JVYZ069RHP1TI6@0KVi^07=cL`1ZJVX0FEUI08R8R02:RXX0T92@09>CT`2>SXh0RXZ:08B4
Q021PH40O7al07YjNP1eMGD0@410038b<P0K6a/09BDU04a<C01dM7@0QHF505=CD`2<S8`0JVYZ09NG
U`21PH40IVIV07MgM`1PH600IfMW06e]K@1fMWH0MgMg07]kN`20P800W9bL07alO01aLG40MGEe07Yj
NP1dM7@0[:b/0;>c/`2b/[80Z:RX0;Vi^@2f][H0]kNg0;Fe]@2k^k/0]KFe0;Ng]`2e]KD0^KVi0;^k
^`2e]KD0^KVi0;Ng]`2e]KD0^k^k01h0oooo00L0e=CD0=7Ad@3AdM40cLg=0=7Ad@3=cLd0dm?C0080
dM7A01L0cLg=0=CDe03AdM40c<c<0=CDe03Bd]80d=3@0=7Ad@3>c/h0bl_;0<O7a`2k^k/0[:b/08n?
S`1jNWX0HF5Q05ADE01EEED0=3@d04E5A@1CDe<0Jf][0;:b/P020:f][@0?0:n_[`2d];@0Ti>C08b<
S025QHD0Ph>30;6a/@2OWil0TI6A08^;R`2OWil0QHF50861P@2;Rh/0Lg=c0080MGEe0P2OWil02@2S
Xj<0X:2P09VIV@2GUiL0TI6A08b<S023Ph<0PH6107AdM002038b<P0D01`L700j>SX0D51@0:2PX01o
Ogl0MgMg09BDU01eMGD0R8R806QXJ01jNWX0Ogmo06UYJ@1`L700RHV908J6QP2>SXh0U9BD0:RXZ02G
UiL207emO@0F08N7Q`2IVIT0/;2`0<K6aP38b<P0bLW90<[:bP3AdM40alO70<W9b@3<c<`0c/k>0<g=
c@39bLT0c<c<0=7Ad@3>c/h0c<c<0=7Ad@39bLT0c<c<0<k>cR80oooo000P0?ooo`0608V9R@25QHD0
QHF508J6QP1nOWh0QHF50P22PX806021PH40QXJ608:2PP22PX80QHF508J6QP24Q8@0PH6108:2PP24
Q8@0QXJ6079bLP1VIVH0FUYJ04];B`0j>SX0<c<c038b<P0O7al0;2`/02@T901IFET0M7Ad07=cL`80
Kfm_01<0L71`03lo?`18B4P0:RXZ028R8P0Z:RX0=SHf030`<00_;bl0=CDe02/[:`0R8R80:RXZ01PH
600O7al08b<S02@T900Y:BT0DE5A0080IfMW00@0Hf=S06QXJ01SHf<0Fe]K0P1PH6009P1JFUX0CDe=
01PH600B4Q807QhN02@T900d=3@0IVIV0410@00a<C40EUIF04m?C`2CTi<0PX:205iNGP18B4P0D51@
04E5A@1>CTh0@T9204i>CP1NGUh0OWin06m_K`1SHf<0IVIV05eMG@1HF5P0Ng]k07moO`26QXH0O7al
07inOP22PX80PH6108:2PP21PH40RHV91@25QHD208:2PP030861P@25QHD0oooo01d0oooo00X0]kNg
0;Fe]@2e]KD0^k^k0;>c/`2i^KT0]KFe0;Vi^@2c/k<0^k^k0`2e]KD04`2g]kL0][Jf0;:b/P2i^KT0
^[Zj0;no_`2TY:@0VIVI08B4Q01_Kfl0G5aL04Q8B017AdL0<c<c0492@P0_;bl0=SHf071`L02PX:00
0P2OWil04`2KVi/0PX:20820P01CDe<0DU9B05UIF@1LG5`0F5QH05YJFP1NGUh0CTi>04A4A01=CDd0
>c/k055AD@1:BTX0B4Q806QXJ021PH400P2@T900;02>SXh0S8b<08J6QP1oOgl0PH6107emO@1jNWX0
H61P024Q8@0L71`0:2PX03@d=01NGUh0OWin05aLG01NGUh0Ogmo07emO@2`/;00RXZ:06e]K@1XJ6P0
KVi^06ATI01cLg<0Jf][07MgM`1lO7`0WinO08N7Q`1lO7`0Ph>307MgM`1iNGT0[Zj^0;>c/`2a/K40
[Jf]0;Fe]@2i^KT0]kNg0;Vi^@2g]kL0^k^k1`2i^KT00`2g]kL0^KVi0?ooo`0M0?ooo`030<W9b@3<
c<`0c<c<0080clo?00<0dM7A0<g=c@3AdM400P3?cll20<g=c@0C0<c<c03:b/X0c<c<0<g=c@3AdM40
d=3@0<K6aP2d];@0XZ:R092@T01gMgL0K6a/05IFEP1=CDd0?clo04U9B@0b<S80BDU907=cL`030;Bd
]00C0:n_[`2c/k<0Ti>C06a/K01jNWX0P820079bLP1fMWH0OWin07EeM@1VIVH0HF5Q06QXJ01IFET0
Ng]k06QXJ01OGel0/;2`0:n_[`030::RXP0[09RHV02>SXh0Shn?08b<S026QXH0OGem055AD@0Q8B40
820P03De=@16ATH0Shn?08>3P`1OGel0XZ:R08:2PP2_[jl0W9bL069RHP1_Kfl0L71`07alO01oOgl0
R8R808B4Q02MWId0V9RH09VIV@1nOWh0QhN708>3P`2>SXh0[:b/0<O7a`3<c<`0`L710<O7a`3Fe]H0
dM7A0=?Cd`3AdM40dm?C0<k>cP070=7Ad@030=?Cd`3AdM40oooo0240oooo000P0?ooo`80OWin00X0
PH6108V9R@26QXH0OWin08F5Q@26QXH0PX:208F5Q@26QXH0QHF50`22PX80601nOWh0PH610861P@20
P800M7Ad069RHP19BDT0?Shn034a<@0`<300;Rh^03<c<`0_;bl0<S8b07=cL`1`L700Kfm_07QhN01e
MGD0L71`08V9R@23Ph<0Jf][05YJFP80CDe=02H0CTi>05QHF01EEED0D51@059BDP1>CTh0FEUI06][
J`2<S8`0UIFE07=cL`1RHV80IfMW06ATI01VIVH0I6AT06YZJP1PH600G5aL05]KF`1QHF40EEEE03De
=@0E5AD03@d=01PH600^;Rh0?Shn07QhN00h>3P0D51@0492@P1QHF40S8b<05]KF`1ADE40Cdm?04Y:
BP80Cdm?00d0AdM705MGE`1aLG40J6QX05ADE01SHf<0IVIV07QhN01nOWh0N7Qh07YjNP25QHD0OWin
0080QHF500`0RHV908F5Q@22PX80QHF508:2PP21PH40QHF508:2PP25QHD0QXJ60861P@25QHDN0?oo
o`<0]kNg00P0^k^k0;Ng]`2c/k<0^KVi0;Ng]`2e]KD0^KVi0;Ng]`80]KFe05D0^KVi0;Fe]@2c/k<0
^KVi0;Fe]@2i^KT0YJFU096AT@1cLg<0I6AT04i>CP13@d<0A4A404=3@`0k>c/0@41005UIF@2OWil0
WYjN0::RXP2NWYh0Vi^K08n?S`2>SXh0MGEe05iNGP1IFET0I6AT05mOG`1SHf<0IFEU05iNGP1DE5@0
EUIF061PH01GEeL0LG5a07=cL`1VIVH0NGUi092@T02?Shl0T92@08Z:RP2>SXh0PH6107moO`1nOWh0
PX:206][J`11@D406a/K01HF5P0[:b/0BDU906EUI@2ATI40Cdm?07alO01^KVh0Shn?0:f][@1hN7P0
MGEe06ATI01WIfL0Kfm_071`L01QHF40PX:209NGU`2BTY80NWYj08V9R@1iNGT0SHf=0;:b/P2/[:`0
[Zj^0;Ng]`2`/;00^KVi0;Fe]@2k^k/0]KFe00<0^KVi00L0]kNg0;Vi^@2i^KT0^KVi0;^k^`2c/k<0
^KVi01h0oooo0P3De=@0<`3Cdm<0c/k>0<[:bP3?cll0dM7A0<[:bP3=cLd0dM7A0<[:bP3<c<`0cLg=
0=7Ad@3=cLd0clo?0=;BdP3>c/h0a/K60:n_[`2GUiL0QHF5071`L01KFe/0C4a<04e=C@14A4@0?clo
0410@01DE5@0]KFe0;Ng]`2a/K40Zj^[0:n_[`1iNGT0J6QX05UIF@1@D500EeMG06EUI@1QHF40Hf=S
05]KF`1IFET0B4Q8055AD@1>CTh0@T9203/k>`0a<C40EEEE08^;R`020::RXP040:6QX@2LW9`0U9BD
08b<S080Shn?02D0QXJ6069RHP0c<c<06QXJ01hN7P0o?cl0Jf][09NGU`1hN7P0HF5Q09^KV`2][Jd0
[Zj^0:6QX@1^KVh0Ph>306i^KP1kNg/0P82007QhN02;Rh/0X:2P0:JVYP2@T900VIVI096AT@2EUID0
WinO0<W9b@37alL0c/k>0<[:bP3;bl/0dM7A0<c<c03>c/h0c<c<00<0dM7A00@0dm?C0=7Ad@3AdM40
dM7A0P3?cll00`3AdM40oooo0?ooo`0P0?ooo`00803oool01`29RHT0QXJ60861P@22PX80QHF508V9
R@25QHD00P26QXH03021PH40RHV908F5Q@29RHT0QHF508>3P`26QXH0PH6107inOP1kNg/0Jf][05QH
F080@T9200L0@41002l_;`0Z:RX0:b/[02`/;00b<S80Kfm_0080LW9b01@0KFe]079bLP1cLg<0N7Qh
09NGU`2][Jd0];Bd0;2`/02b/[80ZZZZ09FEU@2][Jd0^;Rh0:RXZ02PX:00UYJF07]kN`1fMWH0LW9b
06e]K@80J6QX00H0Jf][06QXJ01QHF40Hf=S06EUI@1PH60205]KF`0C05YJFP18B4P09bLW00d=3@0W
9bL0:2PX02HV9P0o?cl0AdM703<c<`0Z:RX0BDU9061PH021PH40HV9R05MGE`0m?Cd0AdM705eMG@02
051@D00906YZJP1bLW80DE5A051@D019BDT0MWIf07emO@1nOWh0OGem0080RHV900X0PH6108F5Q@25
QHD0QHF508V9R@22PX80QHF508:2PP21PH40RHV91025QHDN0?ooo`80]kNg00D0/k>c0;Vi^@2i^KT0
]kNg0;Fe]@020;^k^`0A0;>c/`2k^k/0]KFe0;^k^`2g]kL0]KFe0;Ng]`2f][H0/[:b0;6a/@2QXJ40
QhN706MWI`1PH600De=C04E5A@0m?Cd00P0n?Sh0@013@d<0WinO0:2PX02LW9`0WYjN0:6QX@2MWId0
UYJF0:j^[P2MWId0TI6A092@T02;Rh/0QhN708:2PP2FUYH0RHV908J6QP25QHD0PX:2079bLP2:RXX0
S8b<08j>SP2;Rh/0T92@09:BTP2>SXh0RHV908b<S028R8P0PH6107moO`1nOWh0M7Ad05YJFP0_;bl0
4Q8B02l_;`14A4@0CDe=071`L01YJFT0DU9B05IFEP23Ph<0Shn?0:VYZ@1_Kfl0LW9b05mOG`1[Jf/0
MgMg06QXJ01nOWh0Ti>C09fMW@1dM7@0OWin06UYJ@2OWil0[jn_0:j^[P2ZZZX20;Ng]`050;>c/`2i
^KT0^KVi0;Vi^@2k^k/00P2i^KT01`2e]KD0]kNg0;^k^`2e]KD0^KVi0;Fe]@2i^KT07P3oool00`39
bLT0b/[:0<o?c`020=7Ad@030<W9b@3<c<`0clo?0080clo?01<0c/k>0<c<c03>c/h0b/[:0<g=c@3:
b/X0c<c<0<k>cP2n_[h0[Zj^08n?S`1eMGD0JVYZ05=CD`1?Cdl0ADE504U9B@16ATH0C4a<0080]KFe
03d0/;2`0;Jf]P2f][H0[Jf]0::RXP2EUID0HV9R04M7A`14A4@0@d=30451@@1GEeL0EEEE03Lg=`13
@d<0AdM704e=C@1RHV80QXJ608j>SP2HV9P0W9bL0::RXP2OWil0Vi^K09fMW@2JVYX0Ti>C08b<S02?
Shl0RXZ:06i^KP1:BTX0:2PX01<C4`13@d<0GUiN07alO02GUiL0Jf][07moO`2@T900_kno0:j^[P2A
TI40Jf][07QhN01gMgL0QXJ607alO020P800VIVI0:^[Z`2DU9@0SHf=09>CT`2][Jd0^k^k0<G5a@34
a<@0b<S80080bLW900D0clo?0=7Ad@3AdM40dM7A0<k>cP020=7Ad@070<g=c@3Cdm<0c/k>0<c<c03A
dM40c<c<0=7Ad@0R0?ooo`00803oool00`22PX80PH6107inOP0207inOP0:08F5Q@21PH40Ogmo08V9
R@25QHD0QXJ608F5Q@22PX80QXJ608B4Q080PH6100P0RHV9061PH019BDT0?clo0410@00f=SH0;Rh^
02l_;`80;Bd]0100;bl_02XZ:P1`L700Kfm_07EeM@1aLG40Lg=c071`L01bLW80M7Ad071`L01dM7@0
L71`06m_K`1dM7@0Kfm_0P1^KVh0201ZJVX0Kfm_06a/K01XJ6P0Jf][06a/K01_Kfl0LG5a0`1UIFD0
1@1XJ6P0Hf=S05aLG01QHF40IVIV0080Fe]K00L0D51@03`l?00Z:RX03`l?02<S8`0`<3009bLW0080
ADE500H0@D5103Xj>P1BDU80I6AT05mOG`1RHV8204i>CP0A04e=C@1<C4`0BTY:05]KF`1bLW80E5AD
05]KF`18B4P0LG5a07EeM@1bLW80PX:20861P@25QHD0PH6108:2PP25QHD00P29RHT01P22PX80PH61
08F5Q@25QHD0PX:207inOP80QHF500<0RHV90?ooo`3oool0703oool00`2e]KD0/k>c0;Ng]`020;Ng
]`060;Vi^@2e]KD0][Jf0;^k^`2e]KD0^k^k0P2e]KD06P2k^k/0][Jf0;Bd]02e]KD0^KVi09:BTP1o
Ogl0IfMW05aLG01;Bd/0@T920451@@0j>SX0?clo0410@00S8b<0WinO09jNWP2QXJ40WYjN0::RXP2J
VYX0Vi^K0:6QX@2OWil0YJFU0P2OWil01@2VYZH0Vi^K09^KV`2KVi/0TI6A0080Ti>C02l0T92@09FE
U@2ATI40Vi^K09FEU@2>SXh0TY:B08n?S`2>SXh0RXZ:08B4Q026QXH0QHF507UiN@1kNg/0J6QX04Y:
BP0a<C4061PH03hn?P1FEUH0C4a<06i^KP1HF5P0J6QX06ATI020P800TI6A09>CT`28R8P0KFe]06m_
K`1VIVH0IfMW06EUI@2<S8`0WYjN07]kN`25QHD0I6AT0:RXZ02WYjL0Y:BT0;Bd]02g]kL0^KVi0;>c
/`020;Vi^@80]kNg00<0^KVi0;Ng]`2i^KT00P2i^KT0102g]kL0^KVi0;Vi^@2k^k/N0?ooo`030<g=
c@3?cll0e=CD0080e=CD0140dM7A0<g=c@3De=@0c/k>0<c<c03?cll0c<c<0<g=c@3?cll0c<c<0<_;
b`3>c/h0b<S80:6QX@2EUID0M7Ad06QXJ00204e=C@0?04Q8B010@400B4Q804I6AP1dM7@0];Bd0;Jf
]P2c/k<0/[:b0;Bd]02a/K40/;2`0;Jf]P2i^KT0^k^k0080^KVi0140^;Rh0:n_[`2`/;00/;2`0:>S
X`2QXJ40X:2P0:JVYP2TY:@0YZJV0:n_[`2MWId0YJFU0:JVYP2SXj<0VYZJ09RHV00209JFUP0S08N7
Q`22PX80O7al061PH00m?Cd0;2`/01hN7P1JFUX0LG5a079bLP20P800EeMG07moO`2EUID0[Zj^0:b/
[02OWil0TI6A07moO`1dM7@0MGEe06e]K@25QHD0/k>c09jNWP2=SHd0UiNG0:>SX`3=cLd0_Kfm0<o?
c`3;bl/0dm?C0=7Ad@3?cll00P3AdM420<W9b@030=7Ad@3Cdm<0dM7A0080dM7A00@0e=CD0=7Ad@3A
dM40c/k>8P3oool00200oooo00@0RHV908:2PP26QXH0PX:20P25QHD01P2:RXX0PX:208F5Q@25QHD0
RHV908F5Q@80RHV90180QXJ608B4Q021PH40L71`06MWI`1?Cdl0ATI602l_;`0g=cL0:2PX028R8P0W
9bL0;bl_02HV9P0>3Ph0L71`06m_K`1bLW8207MgM`04075aL@1dM7@0M7Ad07AdM080LW9b01<0LG5a
06i^KP1XJ6P0IVIV06QXJ01PH600IFEU06][J`1UIFD0KFe]06][J`1RHV80LG5a07UiN@1dM7@0Jf][
06IVIP1UIFD0Hf=S0080Fe]K01h0F5QH051@D01CDe<0>c/k01/K6`0M7Ad0=SHf03hn?P14A4@0BTY:
04];B`0`<300>SXj03hn?P15ADD0NWYj07MgM`1=CDd0B4Q804A4A01NGUh0DE5A05MGE`1/K6`0Fe]K
065QH@1/K6`0LW9b08Z:RP1gMgL408F5Q@0808V9R@22PX80PH6108F5Q@26QXH0PH6108:2PP21PH42
08V9R@<0QHF57P3oool00`2g]kL0]KFe0;Ng]`030;Fe]@060;bl_02d];@0^KVi0;Vi^@2k^k/0]KFe
0P2k^k/05P2g]kL0][Jf0;Bd]02a/K40V9RH07AdM01SHf<0B4Q8055AD@0i>CT0<30`03`l?011@D40
=cLg01PH602OWil0Vi^K09nOW`2SXj<0X:2P09jNWP2PX:030:6QX@0>0:2PX02QXJ40WYjN09VIV@2F
UYH0V9RH08f=S@2ATI40UYJF08n?S`2FUYH0T92@08f=S@2LW9`209NGU`0b08n?S`2@T900Rh^;08N7
Q`20P800Ph>307emO@1eMGD0Kfm_04i>CP0X:2P0:BTY04U9B@1?Cdl0F5QH05aLG01RHV80EEEE05aL
G01[Jf/0PH6109ZJVP28R8P0KFe]06QXJ01PH600N7Qh06EUI@20P800UiNG08>3P`1fMWH0Ogmo09jN
WP2d];@0WIfM0;Vi^@2e]KD0^KVi0;Fe]@2k^k/0]KFe0;Ng]`2i^KT0^k^k0;>c/`2i^KT0]kNg0;^k
^`2g]kL30;Vi^Ah0oooo00@0bLW90<g=c@3:b/X0cLg=0P3<c<`01P3=cLd0bl_;0=7Ad@3AdM40c/k>
0<c<c080c/k>01H0b/[:0<c<c03;bl/0c/k>09VIV@1jNWX0IfMW059BDP1MGEd0?Cdm03Lg=`1<C4`0
BDU903hn?P2=SHd0];Bd0;:b/P2e]KD0];Bd0;2`/02b/[80];Bd0`2f][H0?02g]kL0]KFe0;Bd]02^
[Zh0]KFe0:j^[P2XZ:P0Zj^[0:NWY`2VYZH0YjNW0:JVYP2XZ:P0[Jf]09bLW02KVi/0W9bL0:2PX02G
UiL0U9BD096AT@2EUID0RHV908B4Q01^KVh0B4Q802XZ:P0/;2`0EUIF05QHF01PH600J6QX061PH01`
L700QhN709BDU02f][H0WinO07YjNP21PH40KFe]0820P01eMGD0O7al0:NWY`2NWYh0RHV9092@T02D
U9@0_kno0;^k^`2l_;`0dM7A0<c<c03AdM40c<c<0<k>cP3=cLd0dm?C0=7Ad@80clo?00@0dM7A0=?C
d`3>c/h0bLW90`3AdM4R0?ooo`00803oool01025QHD0RHV908V9R@29RHT308F5Q@0308V9R@21PH40
QHF50080QHF50140PX:207inOP25QHD0RHV908:2PP1mOGd0G5aL04Y:BP0l?3`0@d=302h^;P0a<C40
<S8b02d];@0T92@0CDe=03lo?`02071`L0<0M7Ad00l0NWYj079bLP1bLW80M7Ad07EeM@1_Kfl0J6QX
05]KF`1JFUX0De=C061PH01JFUX0G5aL06ATI01VIVH00P1WIfL01@1gMgL0Kfm_06YZJP1[Jf/0JFUY
0080Hf=S0P1PH6007`1LG5`0HV9R059BDP19BDT0ADE502l_;`0X:2P0:BTY02d];@0f=SH0=3@d0492
@P0f=SH092@T03hn?P1]KFd0EEEE05QHF01EEED0F5QH03dm?@1:BTX0CTi>05MGE`1aLG40JFUY05EE
E@1_Kfl0IfMW08F5Q@29RHT00`25QHD00`22PX80PH6108V9R@0208F5Q@0608V9R@22PX80PX:20861
P@25QHD0PX:20`25QHDN0?ooo`050;Vi^@2k^k/0^k^k0;Ng]`2e]KD00P2i^KT00`2k^k/0]kNg0;Vi
^@030;Vi^@030;Ng]`2i^KT0]kNg0080]kNg00h0SXj>06a/K01IFET0FEUI0410@016ATH0@T9203Xj
>P0f=SH0De=C02d];@2LW9`0Vi^K0:2PX080XJ6Q00L0Y:BT0:6QX@2PX:00XJ6Q0::RXP2OWil0WYjN
0080TY:B00X0QXJ609FEU@27QhL0RXZ:096AT@2?Shl0TI6A09>CT`2HV9P0U9BD0P2JVYX03P2ATI40
S8b<08b<S025QHD0QXJ607moO`22PX80L71`06UYJ@1LG5`0>SXj030`<00o?cl0B4Q80P1CDe<05@1T
I6@0CDe=04=3@`1XJ6P0Ng]k07moO`2ATI40KVi^07AdM01HF5P0L71`06m_K`1hN7P0VIVI08^;R`1S
Hf<0Vi^K09FEU@2_[jl0/K6a0;Fe]@030;Vi^@080;Ng]`2k^k/0]KFe0;Vi^@2k^k/0]KFe0;Vi^@2c
/k<50;Vi^Ah0oooo00D0dM7A0<k>cP3>c/h0bLW90<c<c0020=7Ad@030<k>cP3Cdm<0dM7A00<0dM7A
01<0e=CD0=7Ad@39bLT0b/[:0;no_`2KVi/0Kfm_06IVIP1JFUX0ATI604];B`13@d<0@41003lo?`1I
FET0GUiN0;2`/02b/[80];Bd0080][Jf00D0/k>c0;Jf]P2g]kL0][Jf0;Fe]@020;Bd]00c0;:b/P2_
[jl0[jn_0:n_[`2SXj<0Z:RX0:VYZ@2UYJD0ZJVY0:b/[02PX:00YJFU0:j^[P2][Jd0XZ:R09jNWP2J
VYX0UiNG09:BTP2?Shl0RXZ:07QhN01bLW80EeMG03<c<`0a<C40EUIF05QHF01]KFd0J6QX07MgM`1N
GUh0H61P0:6QX@21PH40V9RH0;2`/01jNWX0KVi^075aL@28R8P0RHV909jNWP2OWil0QHF509>CT`2[
Zj/0b<S80<?3``30`<00c<c<00<0dM7A00P0dm?C0<k>cP3<c<`0dM7A0<k>cP3=cLd0dM7A0<o?c`D0
dM7A8P3oool00200oooo00<0OWin0861P@25QHD00P25QHD06P22PX80PH6108:2PP21PH40QHF508:2
PP21PH40RHV908F5Q@1oOgl0PX:208V9R@24Q8@0ADE503lo?`0`<300:b/[030`<00U9BD0:BTY02d]
;@0U9BD0>CTi071`L01aLG40L71`0`1dM7@00`1`L700M7Ad075aL@0207AdM00E07EeM@1WIfL0JVYZ
06ATI01GEeL0G5aL05IFEP1LG5`0GUiN065QH@1SHf<0J6QX06MWI`1^KVh0MWIf071`L01aLG40Jf][
06QXJ01SHf<0H61P0080Fe]K0P1CDe<06P14A4@0:b/[00/;2`0N7Qh0;bl_03<c<`0e=CD0=SHf03`l
?00b<S809bLW04E5A@1?Cdl0K6a/059BDP1LG5`0DE5A04Y:BP17AdL0DE5A06i^KP20P800G5aL07al
O01TI6@0JFUY1025QHD00`26QXH0PH6108F5Q@0308F5Q@80RHV90P25QHD01026QXH0QHF508F5Q@25
QHDN0?ooo`80]kNg102i^KT00`2g]kL0^KVi0;>c/`020;Vi^@0D0;Ng]`2k^k/0]kNg0;>c/`2i^KT0
_;bl0;Jf]P1aLG40I6AT04];B`16ATH0AdM703Hf=P0m?Cd0?clo03De=@0Y:BT0Lg=c09bLW02KVi/3
0:6QX@0309nOW`2RXZ80WYjN0080XJ6Q01D0Xj>S09RHV02BTY80Rh^;0861P@28R8P0P82008J6QP29
RHT0SHf=08j>SP2DU9@0UYJF09^KV`2OWil0UYJF09FEU@2@T900SHf=08N7Q`26QXH00P1oOgl0701f
MWH0KFe]05]KF`0l?3`04a<C03@d=016ATH0BDU9051@D01ADE40CDe=04U9B@0k>c/0N7Qh08J6QP20
P800LW9b07YjNP1XJ6P0IVIV06][J`1eMGD0UYJF09^KV`1bLW80Zj^[08f=S@2PX:040;Vi^@030;^k
^`2c/k<0^KVi00<0^KVi00D0^k^k0;Ng]`2e]KD0^KVi0;^k^`030;Vi^Ah0oooo00<0e=CD0=?Cd`3A
dM400`3AdM400`3Cdm<0dM7A0<o?c`020=7Ad@0D0=?Cd`3>c/h0b/[:0=3@d03AdM40c<c<0;:b/P24
Q8@0Kfm_05MGE`1HF5P0Cdm?03hn?P1:BTX0AdM703Ti>@1RHV80NGUi0;2`/02b/[830;Jf]P030;Vi
^@2e]KD0][Jf0080][Jf00T0/[:b0:f][@2QXJ40U9BD09fMW@2PX:00W9bL0:2PX02RXZ800P2WYjL0
2P2/[:`0];Bd0;2`/02ZZZX0X:2P0:BTY02JVYX0UiNG09BDU02BTY8208n?S`0L08:2PP1_Kfl0FEUI
03Xj>P0G5aL0CDe=05=CD`1PH600FEUI06i^KP1FEUH0CDe=08:2PP2HV9P0ZZZZ09:BTP21PH40OGem
06a/K01kNg/0Q8B40::RXP2SXj<0Shn?09BDU02h^;P0];Bd0=OGe`@0dM7A0P3?cll40=7Ad@050<k>
cP39bLT0c<c<0=7Ad@3?cll00`3AdM4R0?ooo`00803oool00`29RHT0QHF508F5Q@0208F5Q@0508V9
R@22PX80QHF508F5Q@22PX800`25QHD09`2:RXX0QHF508V9R@21PH40MgMg0410@00b<S80<C4a02DU
9@0Y:BT0;Rh^02`/;00Q8B40820P00`<301^KVh0KFe]06i^KP1aLG40Lg=c07]kN`1hN7P0MWIf075a
L@1cLg<0GemO03lo?`1lO7`0Lg=c071`L012@T80:BTY04e=C@14A4@0@41005EEE@1RHV80JVYZ06m_
K`02071`L00407MgM`1YJFT0J6QX06IVIP80IFEU01d0H61P05]KF`1FEUH0B4Q804M7A`0g=cL05aLG
01TI6@0S8b<0:2PX03De=@0c<c<0=3@d0492@P0S8b<0>SXj05MGE`1:BTX0GUiN04i>CP11@D40>3Ph
04E5A@1GEeL0JVYZ07emO@1_Kfl0H61P06m_K`0508F5Q@0308V9R@25QHD0QHF500L0QHF500@0RHV9
08F5Q@22PX80PH617P3oool00`2g]kL0]KFe0;Vi^@020;Vi^@040;^k^`2e]KD0^KVi0;Fe]@80^KVi
0180]KFe0;Vi^@2l_;`0];Bd0;^k^`2g]kL0];Bd06ATI01?Cdl0BDU903Ph>00o?cl0?Shn03Xj>P0c
<c<0<C4a00`<302JVYX209^KV`0E0:6QX@2PX:00Y:BT0:>SX`2RXZ80WinO0:2PX02HV9P0QHF509^K
V`2CTi<0UIFE06e]K@1RHV80MgMg07=cL`1hN7P0PX:208f=S@2@T900U9BD0080Vi^K01h0WinO09:B
TP2BTY80SHf=08^;R`28R8P0PH6107moO`1bLW80JFUY06=SH`17AdL07alO02HV9P0i>CT0@410051@
D019BDT0C4a<05MGE`0m?Cd0L71`06m_K`1fMWH0Ng]k071`L01TI6@0GEeM06UYJ@1cLg<209BDU004
09JFUP2>SXh0Xj>S09nOW`@0^KVi00<0^k^k0;Fe]@2i^KT01`2i^KT0102k^k/0^KVi0;Vi^@2g]kLN
0?ooo`030<W9b@3<c<`0dM7A0080dM7A00@0c/k>0<g=c@3AdM40c<c<0P3AdM40303<c<`0dM7A0<g=
c@3:b/X0c/k>0<_;b`2g]kL0KVi^05aLG01CDe<0@41004e=C@80@D5100D0>c/k03Ph>01mOGd0[Zj^
0;:b/P020;Jf]P0A0;Rh^02c/k<0/k>c0;Bd]02c/k<0^;Rh0:j^[P2c/k<0W9bL09VIV@2GUiL0OGem
09:BTP2KVi/0SHf=0:b/[02UYJD00P2WYjL09`2UYJD0[Zj^0:j^[P2YZJT0YJFU0:6QX@2MWId0UiNG
09>CT`2<S8`0Shn?07UiN@1bLW80IVIV0410@00K6a/0=3@d04e=C@1GEeL0Fe]K061PH01DE5@0GUiN
05eMG@2NWYh0R8R809ZJVP1hN7P0PX:206e]K@20P800OWin09FEU@2VYZH0XJ6Q09RHV033`l<0[jn_
0:j^[P040=7Ad@030<k>cP3<c<`0dM7A00L0dM7A00@0c/k>0=7Ad@3AdM40dm?C8P3oool00200oooo
1029RHT01`25QHD0PX:20861P@25QHD0PX:20861P@29RHT00P25QHD0:P1oOgl0QHF508V9R@25QHD0
KVi^03Ph>00S8b<0:2PX02l_;`0^;Rh0;Bd]024Q8@0M7Ad0=SHf03/k>`1`L700KVi^06m_K`1jNWX0
OWin07MgM`1mOGd0MWIf075aL@1_Kfl0MGEe07IfMP1lO7`0NWYj07alO01fMWH0JVYZ065QH@1WIfL0
LG5a06EUI@1PH600IfMW075aL@1bLW80Kfm_07QhN080JVYZ0280KFe]06UYJ@1XJ6P0I6AT05YJFP1D
E5@0C4a<04M7A`12@T804Q8B014A4@0R8R80<30`03Ph>00^;Rh0>CTi03@d=00Z:RX05QHF059BDP1K
Fe/0IFEU04Y:BP1CDe<0BDU904I6AP1DE5@0GemO06e]K@1hN7P0M7Ad06IVIP26QXH0PH610`25QHD0
1029RHT0QHF508:2PP21PH4608F5Q@0408V9R@21PH40QHF508F5QAh0oooo0P2g]kL03@2k^k/0]kNg
0;Fe]@2i^KT0]kNg0;Vi^@2e]KD0/k>c0;^k^`2e]KD0^KVi0;Jf]P2i^KT00P2k^k/05`2QXJ40EUIF
03/k>`13@d<0@D5103hn?P0k>c/0<30`02/[:`0m?Cd0>SXj09^KV`2MWId0WYjN0:NWY`2VYZH0WinO
0:VYZ@2RXZ80WinO09jNWP2WYjL0X:2P00<0XZ:R00P0UiNG08f=S@2:RXX0T92@08j>SP1lO7`0OWin
08j>SP80W9bL02H0Vi^K09nOW`2CTi<0VIVI09BDU02>SXh0S8b<08R8R01nOWh0MgMg06a/K01UIFD0
FUYJ01TI6@0H61P0;bl_03lo?`1:BTX0@T92059BDP18B4P0>CTi028R8P1oOgl0MWIf08j>SP1WIfL0
L71`05iNGP1QHF40M7Ad08:2PP2HV9P0WinO08^;R`1nOWh0^k^k0;>c/`<0^KVi00H0^k^k0;Fe]@2i
^KT0]kNg0;Vi^@2e]KD40;Vi^@040;^k^`2c/k<0^KVi0;Vi^Ah0oooo0P39bLT0:@3>c/h0bLW90<c<
c03AdM40dm?C0=7Ad@3=cLd0clo?0<k>cP3<c<`0dM7A0=CDe03AdM40c/k>0<;2`P2GUiL0HV9R04M7
A`1CDe<0BTY:0410@012@T80<c<c038b<P1EEED0MGEe0;6a/@2f][H0^k^k0;Vi^@2`/;00/[:b0;Jf
]P2d];@0/k>c0;^k^`2g]kL0];Bd0:f][@2/[:`0YZJV0080V9RH0P2OWil06@2;Rh/0PX:209NGU`2Y
ZJT0[jn_0:j^[P2_[jl0ZJVY0:FUY@2^[Zh0X:2P09ZJVP2HV9P0T92@08R8R022PX80N7Qh06e]K@1N
GUh05ADE01`L7012@T80B4Q805IFEP16ATH00P1EEED03`0e=CD0KVi^092@T02:RXX0PX:207]kN`1^
KVh0JFUY07EeM@2BTY80Xj>S0:b/[02PX:00U9BD0:f][@020<o?c`<0dM7A00H0c/k>0<c<c03AdM40
dm?C0=7Ad@3<c<`40=7Ad@040<k>cP3?cll0dM7A0=7AdB80oooo000P0?ooo`80QHF500<0PX:20861
P@22PX800P25QHD03`22PX80QXJ60861P@25QHD0PH6107moO`1nOWh0PH6108:2PP23Ph<0GemO03Hf
=P0l?3`0<30`02`/;002034a<@0801lO7`0R8R80@D51075aL@1bLW80NWYj07QhN01gMgL207IfMP0<
07MgM`1eMGD0Kfm_06e]K@20P800MgMg07alO01gMgL0LW9b07EeM@1[Jf/0HV9R0P1SHf<0301UIFD0
I6AT06MWI`1`L700Lg=c075aL@1bLW80MgMg071`L01[Jf/0JVYZ06IVIP80J6QX01`0EUIF04m?C`17
AdL0>c/k02TY:@0C4a<07alO01PH600V9RH0?3`l034a<@0[:b/0@T9202d];@17AdL0Cdm?075aL@1B
DU80E5AD04];B`13@d<0ATI605mOG`1WIfL0KVi^08F5Q@21PH40RHV91025QHD00`1nOWh0PH6108V9
R@0;08F5QAh0oooo0`2i^KT01`2g]kL0^KVi0;Vi^@2e]KD0^KVi0;Ng]`2c/k<00P2i^KT01P2f][H0
/[:b0;Ng]`2i^KT0_[jn096AT@80CTi>00@0?Cdm03hn?P13@d<0@D510P0^;Rh01P0U9BD0KFe]09ZJ
VP2PX:00WinO0:BTY080YJFU00P0YZJV0:>SX`2PX:00VIVI0:ZZZP2MWId0Z:RX0:NWY`80WinO00T0
TY:B08b<S02:RXX0RXZ:08N7Q`25QHD0T92@09^KV`2OWil00P2LW9`0102OWil0UYJF09>CT`2BTY82
08f=S@0708N7Q`1fMWH0KVi^06ATI01EEED0=SHf01dM7@0202XZ:P0;0492@P1@D500B4Q80492@P1B
DU80>CTi06m_K`1^KVh0VIVI06][J`1bLW800P1SHf<0201/K6`0Ph>309JFUP2GUiL0U9BD09^KV`2k
^k/0]KFe0`2i^KT20;Ng]`030;^k^`2e]KD0^KVi00H0^KVi00<0]KFe0;Vi^@2i^KT07P3oool30=7A
d@0U0=?Cd`3AdM40dM7A0<c<c03AdM40b/[:0<o?c`3AdM40d];B0=CDe03>c/h0dm?C0=7Ad@35aLD0
R8R805YJFP1<C4`0@41004Q8B019BDT0AdM7030`<00e=CD0DE5A071`L02^[Zh0[jn_0;6a/@2j^[X0
^k^k0;bl_02j^[X0/k>c0;Jf]P2i^KT0];Bd0:n_[`020;Fe]@0a0;2`/02WYjL0WIfM0:2PX02LW9`0
V9RH09NGU`2KVi/0Zj^[0;6a/@2`/;00[jn_0:j^[P2ZZZX0X:2P0:BTY02NWYh0W9bL09FEU@29RHT0
OWin07IfMP1ZJVX0G5aL02h^;P0U9BD0>c/k03@d=01UIFD0CTi>04];B`1DE5@0CTi>05UIF@2<S8`0
SXj>09:BTP1]KFd0O7al06UYJ@1hN7P0VYZJ0:FUY@2ZZZX0[Zj^09bLW02][Jd0c/k>0<c<c0030=7A
d@040=CDe03Cdm<0c/k>0<c<c0L0dM7A00<0c<c<0=7Ad@3AdM408P3oool00200oooo0P25QHD01029
RHT0QHF508V9R@25QHD208:2PP0608J6QP1nOWh0PH6108Z:RP22PX80RHV90P25QHD0401TI6@0ATI6
02LW9`0S8b<0:2PX02/[:`0_;bl0;Bd]01`L700E5AD00000075aL@1`L700Kfm_07MgM`1fMWH207Mg
M`0:07QhN01nOWh0OGem071`L01]KFd0L71`07IfMP1jNWX0MGEe06YZJP<0GemO00<0HV9R06IVIP1^
KVh00P1`L700901hN7P0Lg=c06m_K`1`L700MgMg071`L01ZJVX0IFEU06QXJ01WIfL0FUYJ04m?C`1;
Bd/0BDU903lo?`0?3`l06ATI03Ph>00^;Rh0=cLg03Hf=P0_;bl0:RXZ030`<011@D40ATI607EeM@1P
H600@41004E5A@13@d<0G5aL06UYJ@1RHV80D51@06YZJP80PX:20P1nOWh01021PH40QHF508J6QP21
PH4708F5Q@0308:2PP21PH40QHF50080QHF57P3oool20;Vi^@040;^k^`2e]KD0^k^k0;Fe]@80^KVi
00/0^k^k0;>c/`2g]kL0_;bl0;Bd]02g]kL0]KFe0;^k^`2VYZH0NWYj03/k>`0203dm?@0903hn?P11
@D40@41002`/;00O7al01`L709ZJVP2KVi/0WYjN00<0YJFU00D0Y:BT0:JVYP2YZJT0Xj>S09ZJVP02
0::RXP060:ZZZP2WYjL0X:2P09ZJVP2@T900QhN70P29RHT01@27QhL0SXj>09BDU02JVYX0XJ6Q0080
WIfM02<0Vi^K09nOW`2FUYH0Ti>C08b<S02>SXh0RHV907YjNP1^KVh0IVIV05mOG`1=CDd05ADE02LW
9`15ADD0>3Ph04m?C`1<C4`0@41003lo?`1;Bd/0GUiN06a/K02=SHd0OWin065QH@1XJ6P0H61P06QX
J027QhL0U9BD07moO`2ATI40]KFe0;Vi^@030;Ng]`030;Vi^@2g]kL0/k>c00P0^KVi00@0]kNg0;Vi
^@2i^KT0^KVi7P3oool20=7Ad@040<k>cP3<c<`0c/k>0<c<c080dM7A0P3?cll04`3Cdm<0cLg=0<_;
b`39bLT0c<c<0<o?c`2a/K40Ph>30492@P1>CTh0B4Q804U9B@1:BTX0BDU903De=@0V9RH0QhN70:j^
[P2b/[80102k^k/20;Zj^P0V0;Fe]@2[Zj/0/[:b0;jn_P2o_kl0`L710;Fe]@2^[Zh0ZZZZ0:FUY@2M
WId0Vi^K09bLW02IVIT0X:2P0:FUY@2a/K40/;2`0:f][@2b/[80[jn_0:VYZ@2PX:00XJ6Q09jNWP2J
VYX0TY:B07inOP1fMWH0K6a/05iNGP10@4006QXJ03Lg=`17AdL0@T9205YJFP1=CDd204];B`0606][
J`1kNg/0SXj>092@T01_Kfl0NWYj0P1cLg<01`20P800W9bL0:2PX02f][H0`/;20<g=c@3AdM400P3D
e=@0103Cdm<0dM7A0<[:bP3?cll80=7Ad@040=?Cd`3AdM40dM7A0=7AdB80oooo000P0?ooo`80OWin
0P25QHD00`22PX80PH6108V9R@0308V9R@0308:2PP21PH40QXJ60080QHF500h0QXJ607AdM017AdL0
:BTY030`<00d=3@0<30`02d];@0A4A4061PH02<S8`0>3Ph0LG5a07QhN080MGEe00l0MWIf07EeM@1e
MGD0MGEe07IfMP1kNg/0MGEe07=cL`1]KFd0LW9b06e]K@1ZJVX0KFe]06QXJ01SHf<00P1XJ6P306m_
K`0306i^KP1`L700MGEe0080LW9b0200Kfm_075aL@1^KVh0JVYZ06IVIP1SHf<0IVIV05]KF`1=CDd0
A4A403/k>`0J6QX06ATI01hN7P0X:2P0;2`/03lo?`0g=cL0=CDe03Xj>P19BDT0D51@06QXJ01^KVh0
ATI60492@P0o?cl0@41005aLG02:RXX0PX:20861P@@0RHV90P25QHD00`29RHT0QHF508F5Q@0208F5
Q@060861P@25QHD0QHF508F5Q@26QXH0OWin0`25QHDN0?ooo`80]kNg0`2i^KT0202g]kL0^k^k0;Ng
]`2k^k/0]kNg0;Fe]@2g]kL0^k^k0P2i^KT00`2k^k/0ZZZZ06UYJ@0203hn?P0:0492@P10@400?clo
01hN7P0Q8B40;bl_00410@2KVi/0WinO09jNWP80YJFU03P0Y:BT0:FUY@2UYJD0YJFU0:RXZ02SXj<0
XJ6Q09bLW02TY:@0XJ6Q09jNWP2KVi/0Shn?08N7Q`2<S8`0QhN708f=S@2BTY80Vi^K09ZJVP2NWYh0
Xj>S09bLW02MWId0Vi^K09fMW@2EUID0Shn?08f=S@2:RXX0Q8B407EeM@1XJ6P0GUiN055AD@0Q8B40
8R8R034a<@0o?cl0@d=305ADE016ATH0AdM704Q8B01PH600KVi^08N7Q`2CTi<0HF5Q061PH01KFe/0
JVYZ08b<S02WYjL0OWin09^KV`80^k^k0P2g]kL0102e]KD0^KVi0;^k^`2e]KD30;Vi^@060;Ng]`2i
^KT0^KVi0;Vi^@2k^k/0/k>c0`2i^KTN0?ooo`80e=CD0`3AdM40203Cdm<0c/k>0<W9b@3>c/h0bLW9
0<g=c@3Cdm<0clo?0P3AdM40303>c/h0UYJF06YZJP13@d<0B4Q804=3@`16ATH0B4Q802<S8`0V9RH0
=3@d06UYJ@80/K6a00@0/[:b0;bl_02k^k/0^[Zj0`2l_;`0=02h^;P0/k>c0;Jf]P2e]KD0^KVi0;bl
_02e]KD0Zj^[09JFUP2GUiL0V9RH09JFUP2LW9`0Xj>S0;2`/02b/[80][Jf0;:b/P2_[jl0[Jf]0:n_
[`2XZ:P0XZ:R09^KV`2LW9`0UiNG08:2PP1eMGD0Jf][06IVIP1?Cdl09bLW02TY:@16ATH0CTi>05=C
D`1KFe/0AdM704a<C01OGel0M7Ad08>3P`2RXZ80O7al06i^KP1[Jf/0LG5a09nOW`2c/k<0Vi^K08:2
PP2][Jd20<k>cP80bLW900@0c<c<0=7Ad@3>c/h0c<c<0`3AdM40103Cdm<0dM7A0=7Ad@3AdM420<o?
c`<0dM7A8P3oool00200oooo0P29RHT00`25QHD0PX:208F5Q@0408F5Q@0408:2PP25QHD0PX:208F5
Q@80OWin00`0Q8B407alO012@T80<S8b02l_;`0^;Rh0;2`/02l_;`0U9BD06a/K05UIF@1OGel2075a
L@<0MWIf02d0NWYj0820P020P800MWIf07MgM`1nOWh0NGUi07=cL`1nOWh0N7Qh075aL@1UIFD0J6QX
06MWI`1/K6`0Jf][06YZJP1bLW80M7Ad075aL@1cLg<0O7al07=cL`1bLW80Kfm_075aL@1XJ6P0Jf][
06MWI`1UIFD0H61P05YJFP1<C4`0@T9204E5A@0:2PX06QXJ01PH600X:2P0=cLg02h^;P0o?cl0=cLg
03<c<`1;Bd/00P1NGUh0201UIFD0DE5A0492@P0o?cl0BDU906e]K@1bLW80JVYZ4025QHD208V9R@03
08F5Q@22PX80PH6101h0oooo0P2g]kL30;Vi^@030;Fe]@2i^KT0^KVi00<0^KVi0180]KFe0;Vi^@2g
]kL0]kNg0;Zj^P2][Jd0GemO0492@P0n?Sh0@T9203lo?`12@T80<30`02HV9P0j>SX0=cLg09^KV`2O
Wil30:BTY0060:FUY@2XZ:P0Z:RX0:BTY02UYJD0ZJVY0P2QXJ400`2YZJT0XZ:R09jNWP02096AT@0[
08^;R`2>SXh0S8b<08n?S`2LW9`0WIfM09bLW02MWId0YZJV09fMW@2OWil0Vi^K09fMW@2BTY80U9BD
08j>SP2=SHd0QXJ607YjNP1[Jf/0GUiN05YJFP0>3Ph0:2PX02@T900l?3`0AdM704E5A@1EEED0B4Q8
04U9B@1SHf<0MWIf08:2PP2ATI40JVYZ05]KF`1IFET0HV9R08R8R02JVYX0SXj>0;Fe]@0;0;Vi^@06
0;Fe]@2i^KT0^KVi0;Vi^@2k^k/0]kNg0P2i^KT00`2g]kL0oooo0?ooo`0L0?ooo`80bLW90`3AdM40
0`3<c<`0dM7A0=7Ad@030=7Ad@0A0<g=c@3AdM40e=CD0=CDe03@d=00T92@061PH015ADD0B4Q804U9
B@1:BTX0Bd];02/[:`0/;2`0?3`l0492@P2`/;00102j^[X0;02i^KT0]KFe0;Fe]@2j^[X0^k^k0;Fe
]@2^[Zh0/[:b0;Fe]@2/[:`0ZZZZ0:>SX`2OWil0W9bL09VIV@2MWId0YjNW0:n_[`2][Jd0/;2`0;Bd
]02`/;00[Zj^0;2`/02_[jl0ZJVY0:FUY@2SXj<0Vi^K09VIV@2BTY80OGem071`L01VIVH0FEUI014A
4@0e=CD0;Bd]051@D01>CTh0FEUI05]KF`1;Bd/0I6AT0P1oOgl02P2YZJT0PH6107QhN01IFET0M7Ad
09>CT`2KVi/0ZZZZ0;jn_P3<c<`;0=7Ad@060<c<c03AdM40dM7A0=7Ad@3>c/h0bLW90P3AdM400`3C
dm<0oooo0?ooo`0P0?ooo`00803oool00`22PX80QHF50861P@0608F5Q@0D08V9R@26QXH0PH6108F5
Q@29RHT0QHF505=CD`0g=cL0<S8b02TY:@0^;Rh0:b/[02l_;`0R8R809bLW01HF5P1[Jf/0M7Ad07If
MP1aLG4207YjNP0407alO01fMWH0MgMg07]kN`@0MWIf0P1gMgL03@1nOWh0Ng]k07=cL`1XJ6P0Jf][
06i^KP1[Jf/0J6QX071`L01bLW80NGUi07MgM`1mOGd00P1aLG401`1gMgL0M7Ad079bLP1cLg<0K6a/
06UYJ@1SHf<00P1KFe/05@1>CTh0?Cdm02/[:`0U9BD08R8R02h^;P0];Bd0>c/k03Ti>@16ATH0C4a<
04U9B@1KFe/0Cdm?065QH@1:BTX0=cLg03@d=01BDU80GUiN07UiN@0:08F5Q@80RHV900<0QHF508V9
R@22PX800`25QHD01022PX80QHF508F5Q@25QHDN0?ooo`80]KFe00<0/k>c0;Vi^@2i^KT0102i^KT2
0;Ng]`0B0;>c/`2i^KT0]kNg0;Fe]@2CTi<0K6a/04i>CP0m?Cd0@D510410@012@T80;bl_034a<@00
0000TY:B0:2PX02NWYh0Xj>S0P2UYJD0102][Jd0Y:BT0:BTY02UYJD40:BTY00`0:NWY`2UYJD0ZJVY
0:>SX`2OWil0TY:B096AT@2BTY80TI6A09:BTP2KVi/0VYZJ0:NWY`2OWil0Z:RX09jNWP2SXj<0XZ:R
09jNWP2LW9`0WIfM09BDU02ATI40QXJ607moO`1mOGd0J6QX05EEE@0i>CT0<C4a038b<P11@D40@410
04e=C@1@D500EUIF05ADE01NGUh0PX:207inOP2?Shl0JVYZ055AD@19BDT0IfMW07moO`2MWId0/[:b
1`2i^KT02@2e]KD0^KVi0;^k^`2g]kL0]KFe0;^k^`2e]KD0^KVi0;Fe]@050;Vi^Ah0oooo00<0cLg=
0<c<c03?cll01P3AdM402`39bLT0b/[:0<o?c`3AdM40bLW90<c<c02JVYX0PH6105YJFP1BDU80BDU9
0080Bd];00L0;Rh^03@d=01LG5`0Z:RX0;Jf]P2b/[80_[jn0080^KVi00@0_Kfm0;Zj^P2j^[X0^;Rh
102j^[X07`2h^;P0^k^k0;Fe]@2[Zj/0YZJV09nOW`2RXZ80X:2P0:>SX`2][Jd0/[:b0;>c/`2i^KT0
/K6a0;Fe]@2b/[80_Kfm0;:b/P2][Jd0[Zj^0:NWY`2RXZ80WYjN08j>SP2?Shl0OGem06UYJ@1JFUX0
>3Ph03Hf=P0m?Cd00P1>CTh03`1EEED0F5QH05YJFP1KFe/0O7al09>CT`2UYJD0Ti>C06i^KP1CDe<0
J6QX08B4Q02/[:`0^k^k0<S8b0070=7Ad@090<c<c03AdM40c/k>0<W9b@3<c<`0c/k>0<g=c@3AdM40
c<c<00D0dM7A8P3oool00200oooo00<0PX:20861P@25QHD01`25QHD05@26QXH0PH6108F5Q@22PX80
PH6107UiN@15ADD0<S8b02d];@0h>3P0<30`02TY:@0[:b/06a/K0492@P1eMGD0LW9b07EeM@1fMWH0
NWYj07IfMP0207MgM`0F07IfMP1bLW80NWYj0820P01lO7`0MGEe07]kN`1fMWH0L71`075aL@1cLg<0
J6QX069RHP1ZJVX0Kfm_075aL@1_Kfl0KVi^075aL@1fMWH0L71`075aL@80M7Ad01d0Lg=c071`L01e
MGD0M7Ad06a/K01WIfL0GemO05eMG@1=CDd0?clo02@T900N7Qh08b<S02HV9P0/;2`0?3`l03hn?P0c
<c<0A4A405YJFP1KFe/0F5QH06m_K`1IFET0Cdm?0451@@1;Bd/0H61P07inOP0:08F5Q@0508:2PP21
PH40PX:208F5Q@29RHT00`25QHD01029RHT0QHF508F5Q@25QHDN0?ooo`030;Fe]@2c/k<0]KFe00D0
^KVi00@0]KFe0;Vi^@2k^k/0/k>c0P2i^KT01`2g]kL0ZJVY05aLG016ATH0>SXj04Y:BP11@D400P0k
>c/01@0V9RH0:BTY09fMW@2KVi/0Y:BT0080YJFU0P2ZZZX02@2UYJD0Y:BT0:>SX`2UYJD0Z:RX0:NW
Y`2TY:@0Z:RX0:FUY@020:BTY00=0:6QX@2BTY80SHf=09BDU02FUYH0UiNG09RHV02MWId0WYjN0:FU
Y@2SXj<0Y:BT09fMW@020:6QX@0L09bLW02NWYh0VYZJ09>CT`2<S8`0PH6107moO`1YJFT0FEUI03<c
<`0];Bd0<S8b03Lg=`12@T80De=C05ADE01:BTX0FUYJ075aL@1oOgl0O7al08j>SP1cLg<0HV9R04i>
CP1_Kfl0NGUi0:BTY0/0^KVi00D0]kNg0;Vi^@2i^KT0^k^k0;Fe]@020;Vi^@040;^k^`2i^KT0^KVi
0;Vi^Ah0oooo00<0cLg=0<o?c`3<c<`01@3AdM40103<c<`0dM7A0<o?c`3?cll20=7Ad@0@0=?Cd`25
QHD0GEeM04U9B@1;Bd/0C4a<04E5A@14A4@0>c/k02/[:`1GEeL0[Zj^0;:b/P2j^[X0^k^k0;Vi^@80
`L7100@0^KVi0;Zj^P2n_[h0^KVi0P2e]KD0202j^[X0^;Rh0;^k^`2l_;`0^k^k0:VYZ@2OWil0ZJVY
0P2XZ:P09P2WYjL0/;2`0;Rh^02h^;P0^k^k0;Zj^P2k^k/0/k>c0;Bd]02b/[80/;2`0:^[Z`2QXJ40
W9bL09BDU02<S8`0P82006a/K01LG5`0=CDe03Hf=P0l?3`0ATI604m?C`1NGUh0FUYJ05UIF@1oOgl0
OWin08n?S`2DU9@0Shn?06EUI@1MGEd0FUYJ09RHV02YZJT0_kno2`3AdM401@3Cdm<0dM7A0=7Ad@3>
c/h0c<c<0080dM7A00@0c/k>0=7Ad@3AdM40dM7A8P3oool00200oooo00D0RHV908F5Q@21PH40PX:2
0861P@0208F5Q@0408:2PP25QHD0QHF508V9R@80QHF500h0RHV908:2PP1`L700AdM703lo?`0U9BD0
;Bd]038b<P0R8R809bLW03/k>`1bLW80M7Ad079bLP80MWIf00H0L71`07IfMP1eMGD0MgMg07IfMP1b
LW82071`L00507IfMP1gMgL0MgMg06i^KP1lO7`00P1mOGd01P1]KFd0GemO06MWI`1UIFD0J6QX06YZ
JP80Kfm_00L0LW9b07UiN@1iNGT0Lg=c06e]K@1_Kfl0L71`0080Kfm_01T0M7Ad06ATI01OGel0HV9R
05UIF@1<C4`0<S8b02HV9P0T92@08R8R02`/;00g=cL0<S8b02`/;00a<C40HV9R05EEE@1FEUH0FUYJ
04a<C00m?Cd0ADE504M7A`1DE5@0Ogmo00X0QHF500D0RHV908F5Q@29RHT0PX:20861P@0708F5QAh0
oooo00D0]kNg0;Fe]@2g]kL0^KVi0;Ng]`050;Vi^@0A0;^k^`2e]KD0^KVi0;^k^`2e]KD0XZ:R065Q
H@1BDU80=CDe04I6AP15ADD0<S8b03Ti>@13@d<0Kfm_09nOW`2NWYh00P2TY:@0102WYjL0ZZZZ0:BT
Y02UYJD20:BTY0030:6QX@2WYjL0ZZZZ0080Y:BT00H0XJ6Q0:RXZ02RXZ80YJFU09BDU027QhL209:B
TP80V9RH0P2NWYh0102RXZ80YjNW0:2PX02NWYh209nOW`0L09bLW02KVi/0W9bL09ZJVP2;Rh/0Q8B4
08:2PP1cLg<0HV9R0492@P0`<300<C4a038b<P10@400D51@04];B`16ATH0@d=308:2PP1kNg/0O7al
0820P01`L700FEUI05iNGP1UIFD0Lg=c0:n_[`X0^KVi00D0^k^k0;Fe]@2k^k/0^KVi0;Ng]`070;Vi
^Ah0oooo00D0bLW90<c<c03Cdm<0dM7A0=?Cd`050=7Ad@0A0<k>cP3<c<`0dM7A0<k>cP3=cLd0QHF5
06MWI`1=CDd0@T9205IFEP1;Bd/0=cLg04=3@`10@400MGEe0;6a/@2g]kL00P2j^[X02@35aLD0`L71
0;Zj^P2k^k/0^[Zj0;bl_02n_[h0aLG50<71`@020;Zj^P0:0<71`@2e]KD0[Jf]0:FUY@2MWId0Xj>S
0:ZZZP2/[:`0/k>c0;Bd]080^;Rh0280_Kfm0;Fe]@2`/;00/[:b0;Rh^02d];@0/;2`0:n_[`2/[:`0
XJ6Q09NGU`2ATI40QHF506m_K`1OGel0?clo038b<P0h>3P0?Cdm04m?C`1NGUh0EUIF05ADE022PX80
RHV908b<S02@T900W9bL06QXJ01_Kfl0JFUY092@T02d];@0c<c<2P3AdM401@3>c/h0c<c<0<k>cP3A
dM40dm?C00L0dM7A8P3oool00200oooo00P0OWin0861P@25QHD0QXJ60861P@22PX80PH6108J6QPD0
QHF500L0PH61069RHP19BDT0<c<c03Hf=P0i>CT0<30`00809BDU00D09RHV06=SH`1dM7@0Lg=c07Mg
M`0207IfMP0<07YjNP1lO7`0MWIf07IfMP1dM7@0L71`06][J`1_Kfl0Lg=c07MgM`1aLG40Lg=c0P1f
MWH01@1oOgl0LG5a05iNGP1KFe/0HV9R0080GemO02<0K6a/079bLP1cLg<0Lg=c06i^KP1`L700KVi^
071`L01_Kfl0LG5a071`L01[Jf/0JFUY06MWI`1LG5`0FEUI04];B`0c<c<07alO024Q8@0U9BD09RHV
03Xj>P0i>CT0?3`l02h^;P1CDe<0Fe]K0410@00o?cl0ADE502d];@1;Bd/0De=C05ADE00=08F5Q@03
08:2PP29RHT0QHF500L0QHF57P3oool20;Ng]`060;Fe]@2k^k/0/k>c0;Vi^@2g]kL0^k^k1@2i^KT0
3P2g]kL0Zj^[0861P@1BDU80D51@04M7A`10@400>CTi03Hf=P0d=3@0ADE509jNWP2PX:00XJ6Q0P2T
Y:@01`2UYJD0YjNW0:BTY02TY:@0YJFU0:>SX`2PX:000P2RXZ820:BTY00709^KV`2TY:@0Y:BT0:b/
[02IVIT0QhN708^;R`02092@T00U096AT@2IVIT0WYjN0:2PX02TY:@0WIfM0:BTY02KVi/0W9bL09^K
V`2MWId0Vi^K09FEU@2=SHd0R8R807moO`1jNWX0IFEU04A4A00/;2`0<30`03@d=00g=cL0CTi>051@
D01<C4`0?Shn0861P@1nOWh0Jf][06YZJP1TI6@0BDU906ATI01ZJVX0KVi^0;Bd]00=0;Vi^@030;^k
^`2e]KD0^KVi00H0^KVi7P3oool00`3De=@0dm?C0<c<c0020<o?c`030=7Ad@3Cdm<0clo?00D0dM7A
00h0dm?C0<K6aP24Q8@0IfMW05MGE`16ATH0B4Q80451@@0k>c/0?Shn04];B`2][Jd0^KVi0;Bd]080
^[Zj00<0^KVi0;Fe]@2j^[X00`2j^[X01P2o_kl0_Kfm0;bl_02j^[X0^k^k0;:b/P80^[Zj00h0/;2`
09jNWP2PX:00ZJVY0:j^[P2ZZZX0^;Rh0;Bd]02g]kL0]KFe0;Zj^P2h^;P0^k^k0;6a/@80/;2`01/0
[jn_0:VYZ@2XZ:P0V9RH08n?S`27QhL0OWin06ATI015ADD0;Rh^03`l?00j>SX0ATI605ADE01GEeL0
Cdm?07IfMP2FUYH0Shn?07]kN`2/[:`0EEEE06UYJ@1eMGD0Q8B40;6a/@3:b/X03@3AdM400`3>c/h0
c<c<0=7Ad@060=7AdB80oooo000P0?ooo`0308V9R@25QHD0PX:20080QHF500<0QXJ60861P@29RHT0
1@25QHD01021PH40IVIV05mOG`1?Cdl203<c<`0@02h^;P0T92@0:b/[02l_;`0M7Ad0L71`06YZJP1f
MWH0NWYj07alO01aLG40MgMg07=cL`1^KVh0JFUY06IVIP80Jf][00P0JVYZ079bLP1jNWX0M7Ad07Mg
M`1fMWH0NGUi06i^KP80GUiN00P0Fe]K06YZJP1ZJVX0K6a/06YZJP1XJ6P0IFEU06ATI080K6a/01`0
KVi^071`L01_Kfl0LW9b06UYJ@1[Jf/0Hf=S06EUI@1JFUX0DU9B03De=@0R8R805QHF020P800Y:BT0
?3`l03Xj>P0g=cL0=SHf05YJFP1BDU80?Shn024Q8@1KFe/0<S8b03Lg=`1[Jf/0Hf=S0P25QHD00`22
PX80PH6108F5Q@0808F5Q@0308J6QP25QHD0QHF500L0QHF57P3oool0202g]kL0]KFe0;Vi^@2i^KT0
]KFe0;^k^`2c/k<0^k^k1@2i^KT03@2c/k<0XJ6Q08B4Q01KFe/0B4Q804I6AP13@d<0=3@d03Xj>P0k
>c/0820P0:BTY02GUiL00P2UYJD0102WYjL0XJ6Q0:ZZZP2TY:@20:6QX@0<09ZJVP2IVIT0WIfM09^K
V`2SXj<0Z:RX0:2PX02UYJD0Y:BT0:VYZ@2MWId0R8R80P27QhL02@2DU9@0Rh^;09RHV02IVIT0WinO
09^KV`2JVYX0WYjN09VIV@0309^KV`0I09fMW@2EUID0Shn?08Z:RP27QhL0N7Qh06i^KP19BDT0;Rh^
024Q8@0a<C40>CTi05EEE@1>CTh0C4a<04Y:BP1mOGd0MGEe05mOG`13@d<0OGem04A4A01DE5@0Ng]k
07EeM@030;Vi^@030;Ng]`2i^KT0^KVi00L0^KVi00<0^k^k0;Vi^@2i^KT01`2i^KTN0?ooo`050<W9
b@3<c<`0dM7A0=7Ad@3<c<`00P3?cll00`3>c/h0dM7A0=7Ad@030=7Ad@0]0<o?c`2IVIT0Q8B4055A
D@1:BTX0B4Q804m?C`0g=cL0@d=30410@01mOGd0^KVi0;Rh^02k^k/0^KVi0;Fe]@2n_[h0`<300;Zj
^P2m_Kd0^KVi0;^k^`2c/k<0^;Rh0;^k^`2n_[h0][Jf0;Rh^02i^KT0^[Zj0;Bd]02TY:@0Vi^K0:2P
X02RXZ80Z:RX0:6QX@2a/K40/k>c0;jn_P2h^;P0_;bl0;Jf]P2`/;00/K6a0080[jn_01T0[:b/0:BT
Y02GUiL0UiNG08b<S01kNg/0KVi^04a<C00];Bd0:BTY03hn?P14A4@0HF5Q05ADE01FEUH0NWYj08R8
R029RHT0GEeM09VIV@1WIfL0DE5A07YjNP28R8P0YZJV00<0dM7A00<0dm?C0=7Ad@3AdM401`3AdM40
0`3?cll0dM7A0=7Ad@070=7AdB80oooo000P0?ooo`80QHF500T0RHV908F5Q@25QHD0QHF508V9R@25
QHD0PH6108J6QP25QHD00`29RHT03@1oOgl0=cLg03`l?00_;bl0=CDe01/K6`0`<300:RXZ02d];@1H
F5P0GEeM075aL@1gMgL00P1fMWH08@1_Kfl0H61P04U9B@0g=cL0?Cdm05UIF@1:BTX0F5QH06=SH`1c
Lg<0MWIf06m_K`1hN7P0MgMg0861P@1aLG40De=C05EEE@1TI6@0JFUY069RHP1UIFD0EUIF051@D012
@T80?3`l04I6AP1>CTh0De=C05]KF`1ZJVX0I6AT05aLG00206=SH`0A065QH@1HF5P0De=C03Hf=P0a
<C40<30`028R8P0N7Qh0;bl_034a<@0l?3`0<c<c04A4A01?Cdl0B4Q802d];@1BDU800P0d=3@00`1B
DU80LG5a08^;R`0508F5Q@0308V9R@25QHD0QHF500L0QHF500<0RHV908F5Q@25QHD01025QHDN0?oo
o`80^KVi00T0^k^k0;Fe]@2i^KT0^KVi0;^k^`2e]KD0]kNg0;^k^`2e]KD00P2g]kL03P2i^KT0Z:RX
04Y:BP1LG5`0B4Q804];B`0[:b/0@T9203De=@0k>c/0QXJ608B4Q02JVYX0YZJV0P2TY:@0>@2SXj<0
VIVI08V9R@1mOGd0Ph>3096AT@1mOGd0S8b<09:BTP2LW9`0Xj>S09VIV@2UYJD0Y:BT0:f][@2GUiL0
O7al08:2PP24Q8@0Rh^;08V9R@2FUYH0Rh^;08N7Q`1iNGT0MgMg07]kN`1lO7`0Ph>308F5Q@2DU9@0
TY:B08j>SP2BTY80Rh^;08F5Q@1iNGT0LG5a04m?C`13@d<0>c/k02TY:@0Z:RX0AdM704Y:BP1DE5@0
B4Q806e]K@1gMgL0I6AT038b<P1hN7P0CDe=04=3@`1hN7P0UIFE0;bl_0050;Vi^@030;^k^`2e]KD0
^KVi00L0^KVi00<0^k^k0;Fe]@2i^KT0102i^KTN0?ooo`80dM7A00T0c/k>0<c<c03AdM40dM7A0<k>
cP3<c<`0dm?C0<o?c`3<c<`00P39bLT03@3?cll0M7Ad06EUI@1PH600G5aL05QHF00_;bl0C4a<0451
@@2>SXh0UiNG0:f][@2d];@00`2j^[X02@2i^KT0]KFe0;2`/02d];@0a<C40:n_[`2^[Zh0[jn_0;Rh
^0020;2`/00B0;Fe]@2i^KT0^[Zj0:j^[P2JVYX0UIFE09bLW02KVi/0UIFE0:VYZ@2/[:`0ZZZZ0:RX
Z02LW9`0Y:BT0:JVYP2KVi/0Y:BT0P2XZ:P06P2WYjL0[:b/0:FUY@2HV9P0SHf=07moO`1cLg<0EUIF
04M7A`0d=3@0:RXZ038b<P1DE5@0GemO05UIF@1_Kfl0S8b<0861P@1OGel0Ng]k06][J`1DE5@0M7Ad
0;2`/032`/80c<c<1@3AdM400`3>c/h0c<c<0=7Ad@070=7Ad@030<k>cP3<c<`0dM7A00@0dM7A8P3o
ool00200oooo00X0OWin0861P@25QHD0QHF508:2PP21PH40PX:20861P@25QHD0RHV90`25QHD0701D
E5@0Fe]K0492@P0e=CD0;Bd]034a<@0[:b/0;2`/079bLP1OGel0K6a/05UIF@1]KFd0LW9b07IfMP1`
L700A4A403/k>`1OGel0MGEe03Xj>P0T92@0@41004Y:BP0g=cL0BDU9071`L01[Jf/207MgM`0A07Qh
N01fMWH0HF5Q05QHF017AdL0<30`01DE5@0_;bl0L71`05MGE`0_;bl0<30`03Ti>@0h>3P0>CTi0410
@01FEUH00P1SHf<05`1PH600GemO05aLG01FEUH0BDU903lo?`0b<S80=cLg024Q8@0J6QX0<c<c038b
<P0o?cl0@410055AD@1?Cdl0?clo02TY:@1NGUh0Bd];04Q8B01QHF40Lg=c00`0QHF500<0PX:20861
P@25QHD02025QHDN0?ooo`80]kNg0`2i^KT01P2g]kL0^KVi0;Ng]`2e]KD0^k^k0;Fe]@80^KVi01`0
XZ:R09jNWP1JFUX0Cdm?04=3@`17AdL0>SXj03De=@1KFe/0CTi>09bLW01lO7`0WIfM0:>SX`2TY:@0
Xj>S08F5Q@1nOWh0RHV908F5Q@1NGUh0GEeM06][J`1nOWh0Lg=c08^;R`2OWil0UiNG0P2UYJD0:`2X
Z:P0X:2P0861P@1kNg/0M7Ad06=SH`1KFe/0MgMg08n?S`1kNg/0FEUI05]KF`1RHV80JFUY06YZJP1c
Lg<0RXZ:09:BTP2;Rh/0RXZ:08R8R023Ph<0NWYj06YZJP1ADE40A4A404E5A@0/;2`09bLW04I6AP17
AdL0EEEE05=CD`1]KFd0KVi^05YJFP0i>CT0PX:205UIF@19BDT0LW9b09ZJVP2o_kl0302i^KT00`2g
]kL0^KVi0;Vi^@070;Vi^Ah0oooo00<0e=CD0=?Cd`3AdM400P3AdM401P3Cdm<0dM7A0=?Cd`3<c<`0
c/k>0<c<c080dM7A00h0aLG50:>SX`1VIVH0DE5A05=CD`1IFET0=CDe04M7A`1>CTh0F5QH09fMW@2X
Z:P0^;Rh0;jn_P80^[Zj00`0Z:RX0;2`/02PX:00N7Qh06e]K@2?Shl0V9RH09jNWP2/[:`0d=3@0;Fe
]@2h^;P20;^k^`0[0;Bd]02UYJD0Shn?08R8R02QXJ40Ng]k0:FUY@2h^;P0W9bL07QhN01^KVh0QhN7
08>3P`2<S8`0UIFE0:^[Z`2_[jl0YjNW09fMW@2KVi/0VYZJ08j>SP24Q8@0Lg=c055AD@16ATH0B4Q8
02/[:`0^;Rh0Cdm?05IFEP1OGel0JVYZ07moO`1bLW80FUYJ08V9R@1/K6`0F5QH06UYJ@2MWId0`<30
0=WIf@0<0=7Ad@030=?Cd`3AdM40dM7A00L0dM7A8P3oool00200oooo00L0RHV908F5Q@25QHD0QHF5
08V9R@25QHD0RHV90080QHF504/0PX:20861P@25QHD0QHF507AdM01NGUh0De=C04Q8B00R8R80=3@d
02/[:`0E5AD03Ph>06i^KP1_Kfl0GemO07MgM`1dM7@0JVYZ06=SH`1@D500J6QX07alO01>CTh0?Cdm
02l_;`0f=SH0C4a<05UIF@16ATH0EeMG06a/K01gMgL0LW9b07AdM01aLG40EUIF04e=C@10@400MWIf
0492@P1;Bd/0C4a<03hn?P14A4@0@D5103Ph>01?Cdl0=CDe02l_;`17AdL0FEUI05eMG@1SHf<0Fe]K
061PH01GEeL0C4a<03Lg=`0_;bl07QhN00`<300B4Q80=cLg02XZ:P0`<300@D5104I6AP14A4@0C4a<
038b<P14A4@0@T9205ADE01KFe/02P25QHD01@22PX80PH6108F5Q@29RHT0PX:200T0QHF57P3oool0
202g]kL0]KFe0;Vi^@2i^KT0^k^k0;Fe]@2k^k/0]KFe0P2i^KT07`2g]kL0^KVi0;Vi^@2/[:`0OWin
06QXJ01MGEd0<S8b04I6AP0l?3`092@T02DU9@2EUID0UYJF07inOP2PX:00XJ6Q0:2PX02NWYh0PH61
07=cL`1jNWX0N7Qh06UYJ@18B4P0GEeM07EeM@1hN7P0Jf][096AT@2EUID00P2UYJD0:P2VYZH0WIfM
07alO01iNGT0Jf][092@T01?Cdl0De=C07AdM01hN7P0GUiN051@D01FEUH0IVIV05QHF01LG5`0N7Qh
08J6QP27QhL0Rh^;08>3P`25QHD0N7Qh06a/K01?Cdl0A4A402l_;`0F5QH07QhN04Y:BP0n?Sh0BTY:
05YJFP1WIfL0JFUY06IVIP10@400JFUY05IFEP1QHF40LW9b0:n_[`X0^KVi00@0]kNg0;Vi^@2k^k/0
]KFe2@2i^KTN0?ooo`080<W9b@3<c<`0dM7A0=7Ad@3>c/h0c<c<0<k>cP3<c<`20=7Ad@0;0=?Cd`3A
dM40dM7A09ZJVP26QXH0HF5Q05QHF00f=SH0DU9B03Ti>@0a<C400P2MWId02@2KVi/0Xj>S0;Bd]02d
];@0_;bl0;Rh^02EUID0O7al07MgM`0207QhN00705EEE@21PH40UIFE0861P@2NWYh0][Jf0;Bd]002
0;^k^`0Z0;Rh^02WYjL0S8b<08b<S02>SXh0OWin04M7A`20P800NGUi09>CT`1OGel0IFEU061PH01S
Hf<0KVi^08n?S`2VYZH0WinO0:2PX02IVIT0U9BD096AT@1mOGd0LW9b05ADE01;Bd/0>CTi01TI6@0W
9bL0De=C04M7A`1WIfL0Lg=c07emO@1cLg<0Hf=S07emO@1RHV80MGEe07UiN@2/[:`0`l?32P3AdM40
103Cdm<0dM7A0<k>cP3=cLd90=7AdB80oooo000P0?ooo`L0QHF500<0PX:208F5Q@29RHT00`25QHD0
A`3Kfm/0KVi^03Lg=`0Y:BT09BDU02l_;`0l?3`0AdM702PX:01^KVh0EUIF05]KF`1XJ6P0Kfm_06EU
I@1CDe<07AdM014A4@0n?Sh0HV9R06i^KP0F5QH09RHV01hN7P0l?3`0?Cdm05IFEP1`L700MgMg07Ui
N@1eMGD0M7Ad06MWI`1GEeL0@T9203/k>`1`L700;Bd]04U9B@1BDU805ADE018B4P0e=CD08b<S01hN
7P0`<300>c/k04M7A`1?Cdl0GUiN05QHF01?Cdl0EUIF04e=C@0f=SH0<S8b01XJ6P0C4a<05ADE02<S
8`0a<C40=SHf03`l?00n?Sh0CDe=04I6AP0i>CT0BTY:02h^;P1:BTX0HF5Q00X0QHF500D0RHV908F5
Q@25QHD0QHF508V9R@0908F5QAh0oooo2@2i^KT0?@2k^k/0]KFe0;Vi^@2i^KT0inOW07emO@1LG5`0
AdM703Ph>014A4@0CTi>04U9B@0B4Q80WYjN08F5Q@23Ph<0VYZJ0:>SX`2KVi/0Rh^;03dm?@1>CTh0
OGem09:BTP1[Jf/07QhN04=3@`1=CDd0K6a/06YZJP25QHD0V9RH0:FUY@2XZ:P0XZ:R09nOW`29RHT0
MgMg06ATI01UIFD0R8R804M7A`1hN7P0GEeM01lO7`0m?Cd0E5AD03dm?@13@d<0Cdm?069RHP1gMgL0
Ng]k08R8R021PH40NGUi07alO01ZJVX0Cdm?04E5A@0V9RH00P0L71`0300n?Sh0ADE504E5A@1GEeL0
Hf=S06YZJP1QHF40D51@06UYJ@12@T80Kfm_07IfMPX0^KVi00D0^k^k0;Fe]@2i^KT0^KVi0;^k^`09
0;Vi^Ah0oooo2@3AdM40B`3>c/h0c<c<0=7Ad@3AdM40TY:B05mOG`1VIVH0F5QH03Xj>P1BDU80CDe=
03`l?01NGUh0Y:BT09bLW02ZZZX0_;bl0;^k^`2a/K40Y:BT051@D02_[jl0_kno08N7Q`1QHF406ATI
05=CD`26QXH0TY:B09FEU@2/[:`0/[:b0;^k^`2g]kL0/;2`0:RXZ025QHD0OWin079bLP2=SHd0MgMg
06IVIP1aLG40NGUi01`L701mOGd0GEeM0410@01UIFD0MgMg08Z:RP2KVi/0X:2P09ZJVP2?Shl0TI6A
08B4Q01_Kfl0EUIF04Y:BP0W9bL07QhN024Q8@1KFe/0BDU905aLG01ZJVX0O7al075aL@1UIFD0QXJ6
05UIF@1aLG40Ti>C0:VYZ@0:0=7Ad@050<k>cP3<c<`0dM7A0=7Ad@3>c/h02@3AdM4R0?ooo`00803o
ool708F5Q@0308V9R@25QHD0QHF500<0QHF504L0<c<c06a/K01FEUH0?Cdm03Hf=P0b<S80>3Ph04];
B`0l?3`0HV9R05]KF`1QHF40Kfm_06][J`1RHV80FEUI0410@00X:2P051@D010@40061PH0?Shn04I6
AP11@D40Cdm?06EUI@1XJ6P0L71`07=cL`1hN7P0MGEe079bLP1eMGD0Hf=S061PH015ADD0=SHf055A
D@0^;Rh01PH602PX:00H61P09BDU03Ti>@0c<c<0=SHf04E5A@16ATH0ADE505QHF01KFe/0CDe=04M7
A`0k>c/0>CTi030`<00^;Rh06a/K02<S8`0O7al0:BTY02h^;P13@d<0?Shn03Lg=`1=CDd0@T9205eM
G@0m?Cd0D51@07UiN@0A08F5Q@0308:2PP21PH40QHF500@0QHF57P3oool70;Vi^@030;^k^`2i^KT0
^KVi00<0^KVi04L0VIVI0:JVYP1/K6`0Bd];04=3@`16ATH0Bd];05EEE@15ADD0UiNG08>3P`25QHD0
VIVI09jNWP2FUYH0Q8B405QHF00i>CT0?Shn038b<P0^;Rh0IFEU05YJFP1:BTX0HV9R07AdM01jNWX0
WIfM0:>SX`2WYjL0Xj>S09fMW@2HV9P0OWin07QhN01NGUh0GemO07=cL`1ADE408B4Q04];B`0S8b<0
@T9205iNGP0k>c/0BDU9069RHP1ZJVX0KVi^0861P@22PX80LG5a06i^KP1MGEd0CTi>04=3@`0m?Cd0
8R8R02XZ:P0];Bd0?clo04=3@`1OGel0FEUI05MGE`1WIfL0EEEE07]kN`1:BTX0Kfm_09:BTP0B0;Vi
^@030;Ng]`2i^KT0^KVi00<0^KVi7P3oool70=7Ad@030<k>cP3AdM40dM7A00<0dM7A00`0oooo09jN
WP1QHF40ATI60410@01?Cdl0E5AD05aLG01mOGd0Xj>S09FEU@2WYjL20;2`/00b0:RXZ02>SXh0G5aL
05ADE01SHf<0BDU905aLG01XJ6P0EUIF05MGE`1bLW80OGem08V9R@2f][H0_[jn0;Rh^02b/[80Zj^[
09:BTP1jNWX0LW9b06YZJP1mOGd0PH61059BDP12@T80De=C03@d=01FEUH0IfMW03hn?P1VIVH0N7Qh
08:2PP2BTY80UiNG08b<S022PX80PH6106UYJ@1EEED0AdM703Ti>@0O7al0;Rh^03Ti>@1=CDd0GemO
06i^KP1WIfL206][J`050820P01TI6@0IfMW08V9R@2][Jd04P3AdM400`3Cdm<0dM7A0=7Ad@030=7A
dB80oooo000P0?ooo`<0QHF500D0RHV908F5Q@25QHD0QHF508V9R@0208F5Q@0J08:2PP21PH40QHF5
06i^KP0h>3P0<30`02XZ:P0T92@09BDU03Lg=`11@D40A4A405ADE01CDe<0FEUI079bLP1hN7P0PH61
08b<S02WYjL0[:b/0:^[Z`2TY:@0YJFU0:b/[01dM7@205aLG009065QH@1fMWH0LW9b07EeM@1jNWX0
OGem07QhN01aLG40HV9R0080G5aL00h0IVIV08R8R01WIfL0HV9R06m_K`1oOgl0SHf=07emO@1bLW80
NGUi07YjNP1]KFd0Hf=S05eMG@80D51@01<0E5AD04=3@`0g=cL09BDU02<S8`0N7Qh0820P030`<00U
9BD0:RXZ04M7A`19BDT0?Shn05=CD`1EEED0GEeM04M7A`1[Jf/0Rh^;01H0QHF500<0PX:20861P@3o
ool07@3oool30;Vi^@050;^k^`2e]KD0^KVi0;Vi^@2k^k/00`2i^KT0602g]kL0^KVi07IfMP1UIFD0
E5AD0410@00j>SX0>CTi04M7A`1>CTh0J6QX08:2PP1jNWX0PH6109bLW02NWYh0X:2P0:BTY02IVIT0
S8b<08>3P`1hN7P0MWIf07MgM`80M7Ad0240PH6108^;R`2LW9`0WinO0:FUY@2WYjL0YZJV09nOW`2M
WId0SXj>08B4Q01oOgl0OWin08R8R01dM7@0MGEe07MgM`1dM7@0K6a/06=SH`1`L700PX:208>3P`1m
OGd0OWin0820P01cLg<0MGEe075aL@1KFe/0Bd];03Ti>@0h>3P00P0/;2`0300i>CT0<C4a03lo?`1O
Gel0I6AT05QHF01[Jf/0L71`0820P01LG5`0KVi^0;Jf]QL0^KVi00<0]kNg0?ooo`3oool0703oool3
0=7Ad@050<k>cP3<c<`0dM7A0=7Ad@3>c/h00`3AdM405@3Cdm<0dM7A05YJFP1mOGd0GUiN04U9B@1<
C4`0@D5105UIF@1UIFD0SHf=09^KV`2>SXh0Zj^[0;2`/02ZZZX0YJFU09JFUP1MGEd0?clo034a<@02
02TY:@0V02@T901MGEd0Q8B409bLW02][Jd0[jn_0;Vi^@2l_;`0^KVi0:n_[`2[Zj/0YjNW09VIV@2F
UYH0QhN708:2PP1QHF40J6QX071`L01QHF40B4Q802l_;`0m?Cd0Hf=S07=cL`1aLG40MgMg08N7Q`29
RHT0Ph>308J6QP1cLg<0FUYJ04m?C`11@D40@d=302h^;P0e=CD203Lg=`0:05mOG`1eMGD0IFEU069R
HP1iNGT0S8b<079bLP1eMGD0Ph>30<?3`aL0dM7A00<0dm?C0?ooo`3oool0803oool00200oooo0P25
QHD01021PH40QHF508:2PP21PH4308F5Q@0=08:2PP25QHD0QHF508V9R@16ATH0:RXZ02<S8`0Q8B40
8R8R02PX:00Q8B40;Rh^0492@P02059BDP0:05eMG@1[Jf/0JVYZ07=cL`1lO7`0Ogmo08N7Q`2:RXX0
MGEe04];B`80<C4a02l0AdM707=cL`1gMgL0MgMg07]kN`1lO7`0MWIf07YjNP1iNGT0Ogmo07QhN01G
EeL0?3`l02XZ:P0^;Rh0IVIV08Z:RP2@T900SXj>08:2PP1fMWH0KVi^06a/K01XJ6P0Hf=S05EEE@1=
CDd0EUIF04U9B@15ADD0B4Q803@d=00j>SX08R8R01`L700I6AT05QHF02HV9P0[:b/0<C4a04=3@`0m
?Cd0De=C05UIF@1WIfL0Bd];051@D00G08F5Q@0308V9R@25QHD0oooo01d0oooo0P2i^KT0102g]kL0
^KVi0;Vi^@2g]kL50;Vi^@050;Fe]@2i^KT0KFe]05=CD`0h>3P00P0d=3@06P0e=CD0=SHf051@D01X
J6P0MWIf07QhN01mOGd0VIVI09ZJVP2NWYh0Z:RX0:6QX@2UYJD0XJ6Q09RHV01nOWh0L71`06i^KP1a
LG40Rh^;08n?S`2LW9`0Xj>S0:NWY`2TY:@0YjNW0P2TY:@01`2IVIT0O7al06UYJ@1LG5`0IVIV08B4
Q02;Rh/00P2=SHd01`2:RXX0SXj>08Z:RP2=SHd0SXj>08^;R`1oOgl00P1hN7P0501[Jf/0J6QX06AT
I01;Bd/0BTY:02h^;P0Y:BT09BDU02HV9P0i>CT0?3`l055AD@1VIVH0EUIF071`L01cLg<0R8R8061P
H01QHF40_kno5P2i^KT00`2k^k/0]KFe0?ooo`0M0?ooo`80dM7A00@0dm?C0=7Ad@3AdM40dm?C1@3A
dM40403<c<`0clo?05iNGP1aLG40?Cdm0451@@0o?cl0<S8b05ADE01fMWH0S8b<08^;R`27QhL0Y:BT
0:j^[P2k^k/20;Ng]`0X0:VYZ@2TY:@0VIVI09FEU@2IVIT0X:2P09ZJVP2XZ:P0U9BD09fMW@2^[Zh0
];Bd0;Fe]@2j^[X0^;Rh0;:b/P2RXZ80U9BD08B4Q01oOgl0RXZ:09BDU02IVIT0LW9b06i^KP1_Kfl0
NGUi08^;R`2BTY80VIVI09ZJVP2HV9P0TY:B09BDU021PH40NWYj07QhN01VIVH0De=C04Y:BP80;Rh^
00d0;Bd]02l_;`19BDT0DE5A07EeM@1`L700GemO0820P02CTi<0MGEe07YjNP2NWYh0fMWI01H0dM7A
00<0c/k>0<c<c03oool08@3oool00200oooo1025QHD00`29RHT0QHF508F5Q@0208F5Q@0h08V9R@25
QHD0QHF507MgM`1=CDd092@T02DU9@0S8b<0;Bd]03Hf=P0g=cL0>SXj03Ti>@15ADD0D51@04m?C`1c
Lg<0HV9R061PH01^KVh0MGEe071`L019BDT0=SHf03/k>`0o?cl0TI6A07emO@1jNWX0Lg=c07YjNP1e
MGD0O7al07IfMP1hN7P0Ng]k07moO`22PX80R8R807=cL`11@D40;2`/01dM7@0b<S80De=C06=SH`1d
M7@0LW9b06a/K01WIfL0H61P05IFEP16ATH0D51@04e=C@18B4P203lo?`0@02LW9`0O7al07QhN020P
800M7Ad0<30`03Ph>00m?Cd0@D5104Q8B00l?3`0C4a<04E5A@1^KVh0E5AD04i>CQT0QHF57P3oool2
0;Vi^@040;Fe]@2i^KT0^k^k0;Fe]@<0^KVi01@0^k^k0;Fe]@2i^KT0]KFe06m_K`0i>CT0=SHf030`
<00k>c/0BTY:03lo?`1>CTh0FEUI06e]K@1eMGD0MgMg0:6QX@2@T900V9RH0:6QX@80Y:BT03@0Rh^;
07emO@1^KVh0IFEU07UiN@1]KFd0UYJF09ZJVP2VYZH0Xj>S0:f][@2TY:@0YZJV0:NWY`2[Zj/0XJ6Q
09nOW`22PX80EeMG04];B`1BDU80N7Qh08f=S@2EUID0W9bL09VIV@2BTY80TI6A08f=S@23Ph<0M7Ad
06e]K@1cLg<0JVYZ05mOG`1LG5`0>c/k03Hf=P0^;Rh0:b/[02LW9`0l?3`0>c/k04];B`1DE5@0HF5Q
05ADE01_Kfl0K6a/09JFUP1YJFT0H61P6@2i^KTN0?ooo`80dM7A00@0c<c<0=7Ad@3>c/h0c<c<0`3A
dM401P3>c/h0c<c<0=7Ad@3Fe]H0DU9B04a<C080>CTi00X0@D5104Q8B01:BTX0GUiN07UiN@2;Rh/0
QHF50:b/[02`/;00[Zj^0P31`L403@2j^[X0_;bl0:VYZ@2[Zj/0RXZ:07UiN@1ADE40HF5Q09jNWP2a
/K40^[Zj0;jn_P2m_Kd00P2j^[X09`2g]kL0/k>c09bLW025QHD0IFEU05MGE`1OGel0TY:B0<K6aP2i
^KT0]kNg0:ZZZP2QXJ40XZ:R0:2PX02QXJ40UYJF08N7Q`1jNWX0Q8B407IfMP1/K6`0JFUY0492@P15
ADD0<S8b034a<@0Z:RX0@d=303dm?@1CDe<0Hf=S06MWI`1JFUX0Ph>309fMW@2<S8`0N7Qh0:NWY`0I
0=7AdB80oooo000P0?ooo`T0QHF501/0PX:20861P@29RHT0K6a/06][J`0/;2`0<S8b030`<00P8200
<30`02h^;P0b<S80;Bd]03<c<`16ATH0DU9B07EeM@1MGEd0?Cdm03lo?`0j>SX0;Bd]03hn?P1IFET0
UIFE0;Rh^025QHD00P23Ph<0101oOgl0NWYj07IfMP1fMWH207EeM@0907IfMP1gMgL0NWYj08R8R02P
X:00[:b/09RHV01;Bd/092@T00807alO01`0820P03Ti>@0e=CD0=CDe03<c<`11@D40Fe]K05QHF01G
EeL0CTi>04=3@`0o?cl0BDU901dM7@0W9bL0;Rh^02/[:`0C4a<09RHV03/k>`0o?cl0@D510410@01K
Fe/0AdM703`l?01BDU80IVIV3@25QHD00`22PX80PH6108F5Q@0908F5QAh0oooo2P2i^KT02P2g]kL0
^KVi0;2`/02ATI40>CTi0451@@0j>SX0;Rh^04=3@`12@T8204e=C@0E05YJFP1ZJVX0LW9b09fMW@2@
T900OGem08B4Q025QHD0MWIf07alO01`L700OWin08J6QP2=SHd0XJ6Q0:NWY`2UYJD0YZJV0:FUY@2Z
ZZX0Y:BT0080YJFU0100Xj>S0:FUY@2VYZH0YjNW09bLW01lO7`0FUYJ04Y:BP1NGUh0H61P06a/K01n
OWh0MGEe07AdM01]KFd0M7Ad0P1iNGT00`1cLg<0Jf][05iNGP0205QHF00=02HV9P0g=cL0=SHf03De
=@0P8200@410051@D01HF5P0GUiN05UIF@1eMGD0Jf][06i^KP0206a/K0h0^KVi00<0]kNg0;Vi^@2i
^KT0202i^KTN0?ooo`X0dM7A0240dm?C0<o?c`2o_kl0Hf=S03dm?@13@d<0>c/k03@d=019BDT0EEEE
05mOG`1WIfL0P82008:2PP2QXJ40[Zj^09bLW02e]KD0`/;20;no_`2ZZZX0WIfM07moO`1FEUH0=3@d
08V9R@2VYZH0[jn_0;:b/P2j^[X0^k^k0<71`@2j^[X00P2l_;`09P2d];@0/[:b0:2PX01nOWh0DE5A
03Ti>@1HF5P0KVi^09fMW@2KVi/0]KFe0;6a/@2XZ:P0XJ6Q09ZJVP2FUYH0PH6108B4Q01jNWX0KVi^
06IVIP1SHf<0EEEE02<S8`11@D40=SHf03<c<`0/;2`0H61P05iNGP1ZJVX0JFUY05mOG`22PX80PH61
08R8R02JVYX0UYJF3P3AdM400`3Cdm<0dM7A0=7Ad@080=7AdB80oooo000P0?ooo`T0QHF500H0QXJ6
0861P@1nOWh0Q8B403De=@0^;Rh203Ti>@0B03Hf=P0/;2`0;2`/03<c<`0i>CT0>3Ph03hn?P1JFUX0
KFe]09VIV@2@T900LG5a05QHF01fMWH0WinO0:2PX023Ph<0Ogmo1@1jNWX01P1lO7`0MWIf07YjNP20
P800Ogmo07]kN`<0NWYj0100PH6108N7Q`2ZZZX0]KFe0:FUY@29RHT0EEEE03hn?P13@d<0E5AD06MW
I`1PH600EUIF05aLG01FEUH0CTi>0P17AdL0400O7al0=3@d02HV9P0N7Qh0410@01@D500S8b<0?Shn
03@d=010@400AdM705=CD`18B4P0CTi>051@D01jNWX=08F5Q@0308V9R@25QHD0PX:200T0QHF57P3o
ool90;Vi^@0K0;^k^`2c/k<0]KFe0<71`@1^KVh0@D5104I6AP17AdL0@d=30451@@10@400Bd];04m?
C`1@D500GUiN07MgM`2HV9P0]KFe08f=S@28R8P0OGem08F5Q@1mOGd0NWYj08R8R02UYJD0YZJV00@0
ZZZZ00@0[Jf]0:BTY02UYJD0Z:RX0P2WYjL03P2TY:@0Xj>S0:FUY@2WYjL0WinO09JFUP2<S8`0MgMg
0820P01TI6@0IFEU06MWI`1_Kfl0Lg=c0P1`L7005@1jNWX0MWIf06e]K@1PH600GEeM03Hf=P1;Bd/0
;Rh^02l_;`0L71`07alO034a<@1CDe<0D51@05iNGP1LG5`0LG5a06m_K`1/K6`0BDU909NGU`0=0;Vi
^@030;^k^`2e]KD0^KVi00T0^KVi7P3oool90=7Ad@80clo?01T0eMGE0;2`/01jNWX0B4Q804e=C@16
ATH0?clo04Y:BP1@D500FEUI05YJFP1VIVH0MWIf09^KV`2b/[80VIVI06i^KP20P800RXZ:07YjNP19
BDT0BTY:08B4Q02b/[80^[Zj00@0`<3000<0_;bl0;Zj^P2i^KT00P2e]KD0302g]kL0/k>c0;Bd]02b
/[80Z:RX09:BTP1EEED0=SHf034a<@1>CTh0GUiN07moO`80O7al0P1/K6`04`1mOGd0PH6107moO`1a
LG40J6QX06EUI@15ADD0CDe=038b<P0h>3P08R8R02HV9P1ADE40HV9R05iNGP1bLW80GEeM08F5Q@1f
MWH00P1lO7`00`2b/[80dM7A0=7Ad@0;0=7Ad@030<k>cP3<c<`0dM7A00T0dM7A8P3oool00200oooo
0P25QHD01@21PH40RHV908F5Q@25QHD0PX:200D0QHF501X0Ogmo02d];@0h>3P0?clo04Y:BP0h>3P0
>CTi03@d=00e=CD0=3@d03/k>`14A4@0EEEE071`L01bLW80Lg=c079bLP1gMgL0NWYj0820P01fMWH0
LG5a07EeM@1jNWX0MgMg07EeM@80NWYj00<0OGem075aL@1dM7@00P1fMWH02`1lO7`0MgMg07QhN01g
MgL0OGem07MgM`1eMGD0L71`06i^KP1_Kfl0Jf][0080J6QX01T0GemO05iNGP1OGel0F5QH05UIF@1K
Fe/0CDe=04=3@`15ADD0ATI603Hf=P0Q8B407QhN01TI6@0K6a/07alO05aLG011@D40<S8b05IFEP0l
?3`0F5QH04Y:BP1MGEd0Rh^;01T0QHF57P3oool20;Vi^@030;Ng]`2k^k/0]KFe00L0^KVi00P0_;bl
04U9B@1;Bd/0BTY:069RHP1?Cdl0BTY:04E5A@80Bd];00d0De=C05mOG`1fMWH0Vi^K09bLW02PX:00
WIfM0:JVYP2UYJD0Z:RX0:BTY02WYjL0Z:RX0080ZZZZ00H0Z:RX0:ZZZP2[Zj/0[Jf]0::RXP2WYjL2
0:ZZZP0V0:NWY`2TY:@0YJFU0:BTY02XZ:P0XZ:R0:>SX`2LW9`0Vi^K09bLW02DU9@0UiNG09:BTP29
RHT0R8R808B4Q01mOGd0N7Qh07IfMP1WIfL0GemO065QH@1LG5`0@T9202`/;00W9bL07alO028R8P0S
8b<0MGEe05=CD`19BDT0N7Qh05aLG01kNg/0EEEE06ATI02l_;`I0;Vi^Ah0oooo0P3AdM400`3Cdm<0
c/k>0<c<c0070=7Ad@030;Rh^01HF5P0DU9B0080HF5Q01D0De=C04e=C@1?Cdl0EUIF05QHF01[Jf/0
JVYZ0::RXP2a/K40/;2`0;Bd]02g]kL0^[Zj0;Vi^@2e]KD0^[Zj0<G5a@34a<@0`<300<71`@34a<@0
0P31`L420;fm_@0:0<G5a@31`L40`L710;Fe]@2j^[X0^KVi0;Zj^P2g]kL0/;2`0;:b/P80[jn_00@0
[:b/0:^[Z`2/[:`0WinO0P2KVi/209:BTP0308:2PP1gMgL0JVYZ0080KVi^0100GUiN03Xj>P0[:b/0
:2PX020P800R8R80HF5Q06YZJP1BDU80NWYj07IfMP2CTi<0L71`07inOP2KVi/0c<c<6@3AdM4R0?oo
o`00803oool608F5Q@0308V9R@25QHD0QHF500<0QHF501T0VYZJ03lo?`0o?cl0<c<c03dm?@12@T80
>CTi038b<P0`<300;bl_030`<010@400ATI606IVIP1_Kfl0LW9b06e]K@1hN7P0LG5a07AdM020P800
O7al07EeM@1jNWX0Ogmo00<0NWYj00<0Ogmo0820P01jNWX00P20P8000`1fMWH0MGEe07=cL`02071`
L00707MgM`1dM7@0Kfm_06m_K`1dM7@0Jf][06YZJP0206QXJ00506ATI01SHf<0GemO05aLG01>CTh0
0P19BDT04015ADD0;Bd]024Q8@0W9bL08b<S01<C4`0D51@06ATI05=CD`1;Bd/0ADE505MGE`0_;bl0
CTi>04E5A@1jNWXJ08F5QAh0oooo0P2i^KT01P2e]KD0^KVi0;Vi^@2i^KT0^k^k0;Fe]@@0^KVi00P0
b/[:04e=C@1>CTh0C4a<05iNGP1IFET0C4a<04M7A`80ATI60100Bd];05iNGP1`L700U9BD09jNWP2O
Wil0WIfM0:JVYP2RXZ80YjNW0:j^[P2WYjL0Xj>S0:ZZZP2][Jd0YZJV0P2ZZZX01P2][Jd0ZJVY0:FU
Y@2^[Zh0Z:RX0:ZZZP80Y:BT0P2SXj<02@2WYjL0Xj>S09bLW02KVi/0W9bL09FEU@2BTY80TI6A08f=
S@0208J6QP0F0861P@1iNGT0LW9b06][J`1RHV80H61P04=3@`0g=cL0=SHf02d];@0K6a/0820P024Q
8@1cLg<0Hf=S055AD@1eMGD0Cdm?07MgM`0k>c/0SHf=0;no_aT0^KVi7P3oool20=7Ad@060<c<c03A
dM40dM7A0=7Ad@3>c/h0c<c<103AdM406P2c/k<0De=C051@D01WIfL0JVYZ05eMG@1BDU80D51@059B
DP1CDe<0IfMW06i^KP2[Zj/0]KFe0;Jf]P2d];@0^KVi0;Zj^P2m_Kd0aLG50;bl_02f][H0_[jn0<30
`02m_Kd0^[Zj0P30`<00202m_Kd0][Jf0;Vi^@2l_;`0]KFe0<71`@2j^[X0_;bl0P2n_[h08@2i^KT0
/k>c0;2`/02_[jl0ZZZZ0:RXZ02QXJ40WinO09RHV02ATI40TY:B08f=S@22PX80O7al07EeM@1^KVh0
J6QX04e=C@0o?cl0>c/k02d];@0M7Ad09bLW06QXJ01eMGD0HV9R075aL@1`L700QhN707MgM`1nOWh0
Y:BT0=WIf@0I0=7AdB80oooo000P0?ooo`@0QHF500<0PX:20861P@25QHD01@25QHD01P2PX:00<C4a
02h^;P0Y:BT0=3@d03Lg=`80=3@d00T0=SHf03@d=00l?3`0CDe=04m?C`1QHF40J6QX079bLP1dM7@0
0P1gMgL00`1`L700M7Ad07moO`0207YjNP0307MgM`1bLW80MGEe00<0NWYj00H0MWIf071`L01`L700
MWIf075aL@1`L70207AdM00B079bLP1_Kfl0L71`06][J`1SHf<0JVYZ06a/K01XJ6P0Hf=S06ATI01P
H600F5QH051@D01GEeL0De=C04E5A@11@D40<30`0P0X:2P02`0I6AT04Q8B01hN7P0J6QX0EEEE06EU
I@1=CDd0Fe]K02l_;`1LG5`0DU9B0100QHF500<0PX:20861P@25QHD02025QHDN0?ooo`D0^KVi00<0
]kNg0;Vi^@2i^KT0102i^KT01`38b<P0ADE504Y:BP15ADD0DU9B04m?C`1<C4`00P19BDT03P17AdL0
CTi>061PH01ZJVX0Shn?09NGU`2OWil0X:2P0:FUY@2VYZH0XJ6Q0:NWY`2][Jd0YZJV0P2ZZZX00`2W
YjL0Z:RX0:ZZZP030:ZZZP80YjNW00<0Y:BT0:>SX`2RXZ800`2QXJ402`2PX:00W9bL09ZJVP2DU9@0
VYZJ09FEU@2ATI40RXZ:08^;R`25QHD0P8200080N7Qh0180Jf][061PH01PH600B4Q803Lg=`0e=CD0
92@T01/K6`0W9bL0:BTY07IfMP1cLg<0GEeM07emO@1;Bd/0N7Qh03lo?`2e]KD@0;Vi^@030;Ng]`2i
^KT0^KVi00L0^KVi7P3oool50=7Ad@030=?Cd`3AdM40dM7A00@0dM7A00l0_;bl055AD@1JFUX0Fe]K
06ATI01MGEd0FEUI051@D01BDU80CTi>069RHP1VIVH0TY:B0:j^[P2g]kL00P2d];@0202k^k/0^[Zj
0;jn_P35aLD0_Kfm0;Zj^P30`<00`L710P34a<@30<30`0030<71`@35aLD0aLG50080^[Zj00<0_;bl
0;Jf]P2f][H00P2f][H07P2_[jl0[Jf]0;>c/`2_[jl0Y:BT09jNWP2LW9`0UiNG09BDU02>SXh0RXZ:
0861P@1/K6`0KFe]06][J`1@D500>3Ph03`l?00V9RH07QhN02d];@1LG5`0Rh^;069RHP1fMWH0N7Qh
06EUI@2;Rh/0M7Ad0<c<c100dM7A00<0dm?C0=7Ad@3AdM401`3AdM4R0?ooo`00803oool408F5Q@03
08V9R@25QHD0QHF500D0QHF501T0SHf=03`l?00h>3P0>SXj03hn?P11@D40>3Ph03Lg=`0b<S80>SXj
03Ti>@1:BTX0CDe=065QH@1YJFT0LW9b07IfMP1gMgL0N7Qh07]kN`1jNWX0MgMg079bLP1jNWX0O7al
0080NWYj00@0MWIf07YjNP1jNWX0O7al0P1fMWH0101hN7P0OWin07]kN`1hN7P207AdM080Kfm_0140
LG5a06IVIP1UIFD0J6QX06YZJP1TI6@0HV9R05mOG`1UIFD0EUIF04a<C01@D500CDe=04E5A@0Y:BT0
;Rh^01TI6@0201LG5`0901DE5@0S8b<0?3`l04Q8B00m?Cd0Fe]K04E5A@11@D40JFUY0100QHF500<0
RHV908F5Q@25QHD02025QHDN0?ooo`@0^KVi00<0^k^k0;Fe]@2i^KT01@2i^KT04`2k^k/0De=C04U9
B@1<C4`0Cdm?05ADE01:BTX0Bd];04I6AP1>CTh0C4a<06EUI@1`L700S8b<096AT@2OWil0X:2P0:FU
Y@2VYZH00P2UYJD0102ZZZX0YjNW0:ZZZP2/[:`20:JVYP<0ZZZZ00T0[Jf]0:BTY02TY:@0YJFU0:RX
Z02QXJ40Xj>S0:6QX@2RXZ800P2KVi/01@2MWId0TI6A09:BTP2DU9@0TY:B0080RXZ:01D0QHF508R8
R01hN7P0KFe]06m_K`1XJ6P0GemO03/k>`0o?cl09BDU02@T900P82007alO03@d=01IFET0L71`069R
HP1oOgl0G5aL04A4A01iNGT0402i^KT00`2k^k/0]KFe0;Vi^@080;Vi^Ah0oooo103AdM400`3>c/h0
c<c<0=7Ad@050=7Ad@0I0<c<c01NGUh0Bd];05EEE@1FEUH0G5aL051@D01CDe<0Cdm?05QHF01PH600
N7Qh09RHV02ZZZX0[Zj^0;Bd]02e]KD0^k^k0;Zj^P2h^;P0^KVi0<71`@34a<@0`<300;fm_@020;Zj
^P040<71`@30`<00`<300;fm_@80^[Zj00H0^KVi0;Bd]02_[jl0/k>c0;Jf]P2d];@20:n_[`0@0:VY
Z@2WYjL0ZZZZ0:RXZ02OWil0VYZJ09VIV@2FUYH0S8b<0861P@1lO7`0Ng]k06i^KP1TI6@0?Shn04E5
A@80:BTY00X08R8R02PX:01NGUh0PH6107]kN`2=SHd0Ph>305]KF`1nOWh0XZ:R403AdM400`3>c/h0
c<c<0=7Ad@080=7AdB80oooo000P0?ooo``0QHF500D0PX:203De=@0e=CD0?3`l03lo?`0203De=@0G
038b<P10@400?Cdm03`l?011@D40D51@05aLG01VIVH0Kfm_071`L01cLg<0MgMg079bLP1eMGD0Ogmo
07]kN`1eMGD0Ogmo07IfMP1aLG40Ng]k075aL@1`L700101gMgL0301dM7@0Lg=c07QhN01dM7@0LW9b
07EeM@1_Kfl0MWIf07AdM01^KVh0Jf][06IVIP80Hf=S01@0GemO05QHF01EEED0Cdm?04e=C@13@d<0
?clo03Hf=P0U9BD071`L018B4P0;2`/0:RXZ02l_;`0a<C40B4Q804U9B@1MGEd0NWYj05UIFA`0QHF5
7P3oool<0;Vi^@0F0;Fe]@16ATH0Cdm?04i>CP1EEED0Cdm?04a<C018B4P0DU9B04i>CP1CDe<0G5aL
079bLP24Q8@0TI6A09fMW@2NWYh0Xj>S0:FUY@2SXj<0Z:RX0:f][@80Z:RX00@0[Jf]0:FUY@2WYjL0
Zj^[0P2WYjL00`2ZZZX0YJFU0:BTY0020:FUY@0R0:>SX`2WYjL0XJ6Q0:6QX@2NWYh0Vi^K09nOW`2G
UiL0Ti>C09:BTP2@T900S8b<08Z:RP24Q8@0P82007QhN01_Kfl0Jf][06=SH`1MGEd0B4Q803@d=00Y
:BT06QXJ014A4@0`<300>3Ph05=CD`1]KFd0GUiN07]kN`21PH40?3`l09nOWa/0^KVi7P3oool<0=7A
d@0Q0=CDe019BDT0G5aL05UIF@1NGUh0FUYJ05=CD`1DE5@0FUYJ05=CD`1UIFD0MgMg09:BTP2VYZH0
[jn_0;Ng]`2h^;P0_[jn0;^k^`2n_[h0a<C40;fm_@2g]kL0a<C40;fm_@2k^k/0aLG50<30`034a<@0
aLG50<71`@2i^KT0^[Zj0080^k^k00P0_[jn0;Rh^02f][H0];Bd0:^[Z`2_[jl0ZZZZ09nOW`80XJ6Q
0140X:2P09jNWP2HV9P0UIFE08j>SP21PH40NWYj07UiN@1]KFd0Jf][04I6AP0j>SX0:b/[01dM7@0E
5AD0?Cdm04Q8B00207UiN@0507]kN`20P800GemO06MWI`2^[Zh06`3AdM4R0?ooo`00803oool208F5
Q@030861P@22PX80PH6100L0QHF500@0OWin06m_K`0d=3@0<S8b0P0_;bl02`0c<c<0;bl_0410@00j
>SX0?3`l04M7A`1IFET0GEeM06UYJ@1_Kfl0MGEe0080MWIf00<0MGEe07YjNP1mOGd00P1eMGD0101l
O7`0LG5a07IfMP1kNg/207IfMP80MgMg00L0N7Qh07IfMP1fMWH0MgMg075aL@1fMWH0MgMg0080Kfm_
00@0LG5a06MWI`1`L700J6QX0P1SHf<0501WIfL0Hf=S06=SH`1GEeL0AdM704I6AP15ADD0B4Q802HV
9P0R8R8051@D018B4P0G5aL08R8R03hn?P12@T80@D5103`l?01IFET0GemO7@25QHDN0?ooo`80^KVi
00<0]kNg0;Vi^@2g]kL01`2i^KT04@2e]KD0JFUY05=CD`1BDU80AdM704Q8B01:BTX0ATI605EEE@17
AdL0E5AD06ATI01cLg<0P82009:BTP2JVYX0WinO0080YJFU00/0Xj>S0:ZZZP2][Jd0XZ:R0:RXZ02/
[:`0Xj>S0:VYZ@2VYZH0ZZZZ0:FUY@020:BTY0060:JVYP2TY:@0YJFU0:FUY@2TY:@0YZJV0P2NWYh0
1@2KVi/0WIfM092@T02MWId0TY:B0080RXZ:01D0S8b<08J6QP26QXH0Ng]k06YZJP1VIVH0GUiN05aL
G00g=cL0<c<c01`L700I6AT07QhN02LW9`1CDe<0FEUI05QHF01BDU80N7Qh06UYJ@2XZ:P0702i^KTN
0?ooo`80dM7A00<0dm?C0=7Ad@3Cdm<01`3AdM401@3EeMD0?clo061PH01QHF40EEEE0080EeMG01L0
E5AD05UIF@1>CTh0JVYZ07YjNP26QXH0WinO0:b/[02b/[80]KFe0;^k^`2l_;`0_[jn0<30`02m_Kd0
_;bl0<C4a02m_Kd0_[jn0<71`@2j^[X0`L710;^k^`040;Zj^P0;0;bl_02k^k/0^k^k0;Vi^@2][Jd0
/k>c0:n_[`2YZJT0Zj^[0:RXZ02OWil00P2LW9`05@2HV9P0TY:B08b<S021PH40NGUi071`L01VIVH0
G5aL03hn?P0i>CT07AdM01/K6`0U9BD0BTY:05eMG@1UIFD0GEeM07QhN027QhL0Vi^K0;Vi^@0L0=7A
dB80oooo000P0?ooo`<0QHF500<0RHV908F5Q@25QHD01`25QHD04P1VIVH0>3Ph038b<P0];Bd0;bl_
02XZ:P0a<C40=SHf03lo?`16ATH0CDe=05eMG@1PH600JFUY071`L01]KFd0MgMg07IfMP80LW9b00T0
MgMg075aL@1jNWX0Ogmo0820P01kNg/0L71`07emO@1hN7P00`1gMgL00`1hN7P0MgMg075aL@0407Ad
M00K07EeM@1gMgL0Kfm_07AdM01XJ6P0Hf=S05mOG`1NGUh0Hf=S06ATI01DE5@0DU9B051@D00m?Cd0
=3@d020P800F5QH05aLG00`<300A4A408R8R04A4A00i>CT0>c/k03lo?`1TI6@0IfMW01d0QHF57P3o
ool20;Vi^@030;Fe]@2k^k/0]KFe00P0^KVi01h0SXj>05EEE@17AdL0@T9204A4A00o?cl0AdM704Y:
BP1EEED0FEUI06IVIP1mOGd0PX:209:BTP2JVYX0WIfM0:JVYP2TY:@0Xj>S0:NWY`2ZZZX0Xj>S0:JV
YP2][Jd0ZJVY0:NWY`2RXZ80Z:RX0:FUY@2TY:@20:FUY@0G0:JVYP2TY:@0Y:BT0:FUY@2NWYh0XJ6Q
09bLW02NWYh0WinO09BDU02NWYh0TY:B08Z:RP28R8P0QhN708Z:RP27QhL0NWYj06i^KP1XJ6P0F5QH
055AD@0c<c<00P0R8R802@0B4Q806QXJ02PX:01JFUX0De=C05MGE`1CDe<0O7al07EeM@0M0;Vi^Ah0
oooo0P3AdM400`3<c<`0c/k>0<c<c0080=7Ad@0@071`L01MGEd0D51@04];B`1ADE40C4a<05EEE@1H
F5P0GemO06UYJ@1fMWH0TI6A09jNWP2/[:`0/[:b0;Ng]`80^[Zj00H0_[jn0<C4a031`L40_[jn0;Zj
^P2m_Kd20;Jf]P040;no_`2g]kL0^KVi0;Zj^P80^k^k0P2j^[X20;^k^`0N0;:b/P2f][H0[jn_0:^[
Z`2ZZZX0YJFU0:RXZ02OWil0W9bL09ZJVP2NWYh0UiNG092@T024Q8@0MWIf06YZJP1PH600HF5Q03/k
>`0X:2P09BDU01<C4`0R8R80E5AD05iNGP1RHV80Hf=S07YjNP28R8P0X:2P7@3AdM4R0?ooo`00803o
ool=08F5Q@0?0;^k^`1IFET0=SHf03Hf=P0b<S80=SHf02l_;`0];Bd0=SHf03`l?018B4P0FUYJ06=S
H`1ZJVX0KVi^0080MgMg00D0MGEe07UiN@1kNg/0NGUi0820P00207YjNP0507IfMP1jNWX0OGem07Ui
N@1kNg/00`1fMWH207MgM`0E07]kN`1gMgL0N7Qh075aL@1]KFd0Kfm_071`L01_Kfl0K6a/06UYJ@1T
I6@0IfMW05iNGP1OGel0EeMG05UIF@1:BTX0AdM704a<C00n?Sh08B4Q00806ATI00@04a<C01DE5@0Q
8B40EEEE0`12@T80101HF5P0QHF508:2PP21PH4K08F5QAh0oooo3@2i^KT05P3Ph>00HF5Q04U9B@18
B4P0@d=304M7A`11@D40A4A4051@D01HF5P0J6QX07emO@26QXH0TY:B09VIV@2SXj<0YZJV0:BTY02U
YJD0Z:RX0:FUY@2YZJT40:ZZZP030:RXZ02ZZZX0Z:RX00D0YJFU00H0ZJVY09nOW`2SXj<0XJ6Q09ZJ
VP2PX:0209^KV`0=09ZJVP2BTY80Rh^;08b<S024Q8@0R8R80820P01hN7P0JFUY06MWI`1UIFD0DU9B
02l_;`02028R8P0;01TI6@0L71`09bLW06YZJP1FEUH0F5QH05EEE@1gMgL0WIfM0;Vi^@2g]kL06`2i
^KTN0?ooo`d0dM7A00@0UIFE04A4A01>CTh0CDe=0P1;Bd/02P1:BTX0EEEE06IVIP1`L700P82009RH
V02PX:00Zj^[0;>c/`2d];@20;Zj^P040;^k^`2g]kL0^k^k0;Jf]P80`<3000P0`L710<30`02e]KD0
`L710;Ng]`2l_;`0^k^k0;bl_080^k^k00H0][Jf0;:b/P2c/k<0][Jf0;6a/@2f][H20:n_[`0J0:^[
Z`2OWil0Vi^K09RHV02EUID0VYZJ096AT@1mOGd0M7Ad07IfMP1VIVH0E5AD03@d=00T92@09bLW01XJ
6P0P8200EUIF06a/K01DE5@0IVIV07AdM02KVi/0[:b/0=7Ad@3Cdm<K0=7AdB80oooo000P0?ooo`03
08F5Q@22PX80QHF500X0QHF501D0/K6a071`L00b<S80:RXZ02d];@0a<C40=CDe034a<@0d=3@0ADE5
055AD@1MGEd0IFEU06m_K`1ZJVX0KFe]07AdM01hN7P0LW9b07QhN01bLW800P1eMGD01@1fMWH0MgMg
079bLP1fMWH0LG5a0080MWIf00`0N7Qh07MgM`1fMWH0MgMg07QhN01`L700LW9b07EeM@1bLW80Kfm_
071`L01[Jf/206m_K`0=06QXJ01SHf<0I6AT05]KF`1PH600D51@04m?C`13@d<0>SXj03@d=00Q8B40
71`L01HF5P0201dM7@0801PH6010@400Cdm?04Y:BP1HF5P0HV9R08F5Q@29RHTL08F5QAh0oooo3@2i
^KT05@3AdM40RXZ:04M7A`0o?cl0@d=304I6AP18B4P0A4A404U9B@1LG5`0J6QX07emO@29RHT0UYJF
09RHV02NWYh0Y:BT0:FUY@2RXZ80ZZZZ0::RXP020:RXZ080ZZZZ00L0XZ:R0:ZZZP2RXZ80ZZZZ0:BT
Y02VYZH0Y:BT0080YJFU00/0YjNW09nOW`2TY:@0XZ:R09nOW`2KVi/0W9bL09ZJVP2KVi/0U9BD08f=
S@0208Z:RP0E08:2PP25QHD0MGEe06i^KP1PH600FEUI051@D00^;Rh09RHV01lO7`0V9RH092@T02TY
:@1PH600JVYZ05MGE`1WIfL0MGEe0;Vi^@2k^k/0]KFe01/0^KVi7P3oool=0=7Ad@050;2`/01NGUh0
BTY:04a<C01?Cdl00P1@D5003P1;Bd/0GemO071`L01hN7P0TY:B0:BTY02XZ:P0/k>c0;Zj^P2m_Kd0
^KVi0;fm_@30`<00_Kfm0P34a<@20<71`@040;fm_@31`L40_Kfm0<71`@<0^[Zj00L0_;bl0;^k^`2h
^;P0^KVi0;^k^`2e]KD0/[:b0080[jn_01@0[Zj^0:b/[02NWYh0VIVI09^KV`2GUiL0U9BD096AT@25
QHD0M7Ad06e]K@1VIVH0FEUI038b<P0X:2P08b<S02TY:@0V9RH0Fe]K07]kN`80IFEU00D0N7Qh092@
T03AdM40c/k>0<c<c00K0=7AdB80oooo000P0?ooo`0308F5Q@29RHT0QHF500X0QHF500L0RHV90861
P@1@D500>CTi03De=@0a<C40<S8b0080>3Ph00L0=cLg04=3@`1YJFT0IVIV06YZJP1cLg<0MGEe0080
MgMg00/0MWIf07EeM@1iNGT0NWYj075aL@1hN7P0MWIf07EeM@1fMWH0MgMg07QhN00207IfMP80MgMg
101dM7@01P1`L700Kfm_06i^KP1_Kfl0L71`06YZJP80IFEU01@0Hf=S06ATI01UIFD0Fe]K04e=C@1:
BTX0@D5103Xj>P0_;bl092@T01hN7P0G5aL06QXJ014A4@0J6QX0=cLg0451@@12@T80De=C06][Jah0
QHF57P3oool00`2i^KT0^k^k0;Vi^@0:0;Vi^@030;^k^`2^[Zh0GemO0080ATI600`0A4A404I6AP1;
Bd/0BTY:05ADE01VIVH0QXJ608Z:RP2HV9P0W9bL09fMW@2RXZ840:FUY@040:JVYP2RXZ80ZZZZ0:BT
Y0@0YJFU00@0Y:BT0:FUY@2UYJD0Y:BT0P2UYJD0102QXJ40XZ:R09jNWP2MWId209^KV`0H09fMW@2E
UID0TY:B08n?S`2:RXX0Rh^;08N7Q`1oOgl0KVi^06][J`1NGUh0EEEE04I6AP0a<C40:BTY020P800T
92@06QXJ02HV9P1EEED0HV9R05YJFP1]KFd0Ng]k7P2i^KTN0?ooo`030=7Ad@3>c/h0dM7A00X0dM7A
00h0c/k>08:2PP1CDe<0@d=304i>CP1;Bd/0DU9B055AD@1JFUX0K6a/08R8R02GUiL0X:2P0;>c/`80
[jn_00X0][Jf0;^k^`2k^k/0_;bl0;^k^`2j^[X0_kno0<30`02j^[X0_;bl0P2k^k/01@2i^KT0^[Zj
0;bl_02k^k/0^[Zj0080^k^k00@0][Jf0;Bd]02e]KD0/[:b0P2`/;00602[Zj/0Z:RX0:JVYP2PX:00
Vi^K09RHV02BTY80RXZ:07emO@1dM7@0JFUY05eMG@1=CDd0=SHf02/[:`0S8b<0:RXZ01hN7P1EEED0
KFe]06i^KP1eMGD0Rh^;09bLW1h0dM7A8P3oool00200oooo00<0QHF508:2PP25QHD01P25QHD00`22
PX80PH6108F5Q@0208F5Q@0<08:2PP31`L40fm_K071`L00e=CD0>c/k03dm?@0f=SH0>3Ph04Y:BP1C
De<0H61P0P1_Kfl01@1^KVh0MgMg07QhN01eMGD0Lg=c0080MWIf00D0N7Qh079bLP1gMgL0N7Qh07If
MP0207MgM`0807]kN`1gMgL0N7Qh07AdM01gMgL0M7Ad07=cL`1ZJVX2071`L00J06m_K`1cLg<0JFUY
06EUI@1]KFd0Hf=S061PH01KFe/0EEEE05UIF@1<C4`0=cLg034a<@0e=CD0;bl_02@T900J6QX071`L
010@400;2`/0@T9203hn?P10@400ATI605mOG`1XJ6PN08F5QAh0oooo2P2i^KT05`2g]kL0^KVi0;Vi
^@2i^KT0]KFe0=cLg031`L40N7Qh04m?C`1DE5@0CTi>04];B`1EEED0IfMW07UiN@2:RXX0VYZJ09^K
V`2IVIT0X:2P0::RXP2TY:@0Xj>S0080Y:BT00D0YZJV0::RXP2ZZZX0YZJV0:BTY0020:FUY@090:RX
Z02RXZ80YjNW0:6QX@2RXZ80XJ6Q0:FUY@2JVYX0XJ6Q0080Vi^K01X0WYjN09:BTP2BTY80Ti>C08Z:
RP2=SHd0PX:207moO`21PH40K6a/05IFEP1@D500CDe=0451@@0e=CD09BDU02PX:00F5QH0410@04E5
A@1OGel0G5aL065QH@1dM7@0N7Qh0;Fe]Ad0^KVi7P3oool:0=7Ad@0@0=?Cd`3AdM40dM7A0=7Ad@3D
e=@0/;2`05QHF01;Bd/0Fe]K05iNGP1CDe<0FEUI06m_K`21PH40WIfM0:j^[P80[jn_00D0/k>c0;Bd
]02e]KD0^KVi0;bl_0030;Zj^P040;fm_@31`L40^[Zj0;Zj^P80^k^k00<0^;Rh0;Jf]P2h^;P00`2f
][H02@2h^;P0][Jf0;Jf]P2^[Zh0[jn_0:VYZ@2TY:@0ZZZZ09nOW`0209bLW00D09NGU`2@T900SXj>
079bLP1UIFD0GemO05QHF013@d<0>c/k02XZ:P0/;2`05aLG014A4@1?Cdl0JFUY07=cL`1lO7`0UIFE
0::RXP3<c<`M0=7AdB80oooo000P0?ooo`0308F5Q@29RHT0QHF500H0QHF500<0RHV908F5Q@25QHD0
0P25QHD207inOP0?09BDU02QXJ40=cLg02l_;`0d=3@0>SXj03hn?P14A4@0FUYJ05eMG@1TI6@0IfMW
06YZJP1^KVh0K6a/0080LG5a00@0M7Ad07MgM`1dM7@0Lg=c0P1gMgL00`1eMGD0LW9b06i^KP0206m_
K`0407AdM01bLW80JFUY06YZJP<0Kfm_00D0L71`06i^KP1]KFd0JFUY06QXJ00206ATI00>06QXJ01K
Fe/0IVIV05UIF@11@D40@41003`l?00f=SH0?Cdm01lO7`0M7Ad04A4A00`<301>CTh203hn?P0604=3
@`1TI6@0K6a/07YjNP1nOWh0PH617025QHDN0?ooo`030;Vi^@2k^k/0^KVi00H0^KVi00<0^k^k0;Fe
]@2i^KT00P2i^KT05`2e]KD0^k^k0<G5a@33`l<0DE5A04E5A@1>CTh0D51@05EEE@1PH600Ng]k08F5
Q@2FUYH0UiNG09RHV02OWil0XJ6Q0:BTY02PX:00Xj>S0:BTY02UYJD0Xj>S00@0YJFU00P0XZ:R0:>S
X`2RXZ80YJFU0:6QX@2MWId0XJ6Q0:2PX0<0Vi^K00@0VYZJ09^KV`2EUID0T92@0P2?Shl0502=SHd0
Ogmo08R8R01hN7P0I6AT05]KF`1@D500BDU904i>CP0];Bd0:BTY01XJ6P0C4a<0>CTi05aLG01KFe/0
EeMG06m_K`1]KFd0VIVI0P2g]kLL0;Vi^Ah0oooo00<0dM7A0<k>cP3AdM401P3AdM400`3>c/h0c<c<
0=7Ad@020=7Ad@0G0=GEe@3MgMd0clo?08J6QP1OGel0D51@05mOG`1JFUX0JFUY07]kN`2EUID0YZJV
0;:b/P2e]KD0/k>c0;Vi^@2o_kl0_Kfm0;Rh^02l_;`0^[Zj0;^k^`2n_[h00P2k^k/02P2j^[X0^k^k
0;no_`2n_[h0_kno0;^k^`2f][H0^[Zj0;no_`2f][H40:n_[`0K0:b/[02XZ:P0Xj>S0::RXP2QXJ40
U9BD08n?S`2@T900OGem079bLP1RHV80De=C055AD@1?Cdl0=3@d02`/;00M7Ad05ADE03@d=01[Jf/0
IFEU071`L01iNGT0QHF50;Fe]@3De=@0dm?C01`0dM7A8P3oool00200oooo4025QHD04`22PX80[Zj^
02TY:@1;Bd/0>c/k0492@P17AdL0B4Q805MGE`1QHF40L71`06i^KP1_Kfl0L71`07IfMP1gMgL0N7Qh
06m_K`1bLW80101gMgL0201kNg/0MGEe07MgM`1iNGT0Kfm_06i^KP1`L700MGEe0`1_Kfl02P1`L700
Kfm_06YZJP1]KFd0K6a/06MWI`1SHf<0H61P05IFEP1DE5@205=CD`0B04Q8B014A4@0>c/k02d];@0[
:b/07QhN010@400E5AD0>CTi02@T9015ADD0B4Q804Y:BP1GEeL0IfMW0861P@29RHT0Rh^;7025QHDN
0?oooa00^KVi00h0]KFe0=[JfP12@T80Fe]K04Y:BP1GEeL0FEUI06=SH`1kNg/0R8R809JFUP2CTi<0
Vi^K09nOW`80X:2P00D0Xj>S09nOW`2SXj<0YJFU0::RXP020:FUY@080:RXZ02VYZH0X:2P0:BTY02O
Wil0WYjN09nOW`2QXJ4309^KV`0?09bLW02KVi/0VIVI09ZJVP2DU9@0T92@08n?S`29RHT0Q8B407mo
O`1kNg/0O7al06=SH`1KFe/0D51@0080@d=300`09BDU01XJ6P0N7Qh0>CTi02XZ:P1OGel0GUiN05UI
F@1]KFd0P8200:f][@2e]KDM0;Vi^Ah0oooo403AdM403`3De=@0Zj^[05YJFP1NGUh0BTY:06IVIP1S
Hf<0NWYj09VIV@2TY:@0YjNW0:JVYP2_[jl0^;Rh0;:b/P020;>c/`040;Vi^@2n_[h0^k^k0;Jf]P80
^k^k00L0^;Rh0;Zj^P2d];@0/[:b0;Fe]@2j^[X0^;Rh00<0[jn_0180/;2`0:n_[`2_[jl0[Zj^0:f]
[@2RXZ80Xj>S0::RXP2LW9`0UIFE09VIV@2@T900R8R806UYJ@1PH600EEEE04e=C@1CDe<2020P8003
02<S8`0e=CD0?Shn0080IFEU00H0Kfm_08n?S`2/[:`0a/K60<[:bP37alLL0=7AdB80oooo000P0?oo
oa00QHF500d0PX:20820P00j>SX09bLW03Ph>00l?3`0AdM704Q8B01JFUX0G5aL05iNGP1ZJVX0L71`
0080K6a/00<0KFe]07IfMP1cLg<01@1`L7001`1cLg<0KVi^06QXJ01ZJVX0Kfm_06ATI01ZJVX00P1^
KVh06P1_Kfl0KVi^06m_K`1_Kfl0KFe]069RHP1XJ6P0I6AT06=SH`1QHF40GUiN04i>CP1<C4`0ADE5
03/k>`0c<c<0=CDe03Lg=`0d=3@0<c<c02d];@0d=3@09RHV0410@01?Cdl0F5QH0P1MGEd00`1NGUh0
RHV907inOP0M08F5QAh0oooo402i^KT01P2e]KD0`L7104=3@`12@T80EeMG04m?C`80Hf=S00`0Ng]k
08J6QP2>SXh0UiNG09^KV`2IVIT0WYjN09bLW02VYZH0XJ6Q09jNWP2OWil40:>SX`0709nOW`2LW9`0
XJ6Q0:2PX02GUiL0V9RH0:2PX00209^KV`0>09ZJVP2KVi/0Vi^K09^KV`2@T900UIFE08n?S`2;Rh/0
RHV908F5Q@1bLW80MWIf06e]K@1JFUX2051@D00?04];B`14A4@0BTY:038b<P0e=CD0;bl_055AD@1W
IfL0IFEU06QXJ01gMgL0PH610;Fe]@2b/[80_kno01`0^KVi7P3oool@0=7Ad@040=CDe02m_Kd0@D51
05YJFP80IFEU00h0Kfm_07YjNP2DU9@0XZ:R0;2`/02a/K40[jn_0;>c/`2h^;P0_Kfm0;Rh^02g]kL0
^;Rh0;Vi^@@0_[jn00P0^;Rh0;^k^`2o_kl0][Jf0;:b/P2c/k<0][Jf0;2`/080[jn_01h0/;2`0:n_
[`2ZZZX0ZZZZ0:VYZ@2QXJ40W9bL09VIV@2=SHd0RHV908Z:RP1mOGd0IfMW061PH01KFe/0CTi>04Y:
BP1=CDd0:BTY030`<00h>3P0HV9R071`L01VIVH0MWIf092@T02l_;`0b/[:0=7Ad@3IfMTL0=7AdB80
oooo000P0?oooa00QHF500X0PX:208B4Q00l?3`0;Bd]030`<00[:b/0=SHf0410@01:BTX0FEUI0P1Q
HF405@1ZJVX0IfMW07=cL`1[Jf/0Lg=c06i^KP1[Jf/0L71`07AdM01gMgL0M7Ad06YZJP1]KFd0Kfm_
06QXJ01PH600IVIV06MWI`1_Kfl0K6a/06EUI@0206ATI00805mOG`1SHf<0H61P061PH01OGel0EeMG
055AD@1DE5@2051@D00E04];B`18B4P0=CDe02d];@0[:b/0:RXZ02LW9`0R8R80@41005IFEP0l?3`0
CDe=05mOG`1KFe/0QhN708F5Q@1nOWh0PH6108F5Q@29RHT0Rh^;00d0QHF500<0RHV908^;R`25QHD0
2P25QHDN0?oooa00^KVi01D0]KFe0<30`01>CTh0@d=304E5A@17AdL0FEUI05mOG`1fMWH0QHF508V9
R@2@T900V9RH09JFUP2OWil0V9RH0:FUY@2MWId0WYjN09nOW`2QXJ400P2RXZ8209bLW00809fMW@2I
VIT0UIFE09RHV02GUiL0Vi^K09ZJVP2GUiL209JFUP0309BDU02FUYH0S8b<0080SHf=00<0QHF50861
P@1nOWh00P1cLg<04P1YJFT0GemO04];B`14A4@0@T9203lo?`0e=CD0<S8b04=3@`1HF5P0B4Q8061P
H01dM7@0L71`08Z:RP2BTY80]KFe0;Ng]`80^KVi00<0_;bl0;Vi^@2i^KT0302i^KT00`2l_;`0^KVi
0;Vi^@090;Vi^Ah0oooo403AdM40503De=@0/;2`04=3@`1BDU80E5AD061PH01eMGD0Ng]k09VIV@2U
YJD0XZ:R0:n_[`2c/k<0]kNg0;2`/02d];@0^[Zj0;Bd]02i^KT0^;Rh0P2f][H0;02c/k<0_;bl0;Bd
]02b/[80[jn_0;Bd]02_[jl0]KFe0:n_[`2^[Zh0/K6a0;>c/`2a/K40];Bd0:b/[02VYZH0Y:BT0:6Q
X@2MWId0V9RH096AT@23Ph<0Ogmo071`L01PH600Cdm?055AD@1=CDd0C4a<0410@00f=SH0De=C0492
@P1FEUH0NGUi07EeM@2<S8`0SHf=09bLW03EeMD0dm?C0=7Ad@3?cll0c<c<3@3AdM400`3?cll0c<c<
0=7Ad@0:0=7AdB80oooo000P0?oooa40QHF500/0UiNG07MgM`15ADD0;bl_0451@@0h>3P0=SHf03hn
?P1?Cdl0I6AT06MWI`0205mOG`0506IVIP1aLG40Kfm_06a/K01^KVh00`1UIFD04`1SHf<0Fe]K05UI
F@1NGUh0GEeM05QHF01EEED0CDe=055AD@1BDU80De=C055AD@1EEED0ATI604i>CP1:BTX0CTi>04Q8
B01:BTX00P1@D5004@1:BTX0?Cdm03De=@16ATH0>3Ph03hn?P18B4P0;Bd]04U9B@11@D40>3Ph0410
@019BDT0Cdm?069RHP24Q8@0Ph>30080QHF500<0OWin08F5Q@25QHD02@25QHD00`29RHT0QHF508F5
Q@0?08F5QAh0oooo4@2i^KT02`32`/80VIVI04I6AP10@400FEUI04];B`1FEUH0IVIV07alO029RHT0
S8b<0080SHf=00D0UYJF09bLW02JVYX0VIVI09jNWP0309NGU`0909JFUP2BTY80TY:B092@T02<S8`0
QXJ608F5Q@23Ph<0QXJ60080Ph>301l0PX:208B4Q01kNg/0PH6107UiN@1oOgl0MgMg07AdM01hN7P0
Lg=c06UYJ@1PH600FUYJ05eMG@1<C4`0DE5A05IFEP10@400EUIF04e=C@1CDe<0HV9R061PH01/K6`0
Ph>309NGU`2ATI40]KFe0;Vi^@2e]KD0_kno00X0^KVi00<0^k^k0;Fe]@2i^KT03`2i^KTN0?oooa40
dM7A00P0a<C407=cL`0g=cL0D51@065QH@1GEeL0LG5a092@T080XJ6Q00P0Vi^K0:NWY`2[Zj/0]KFe
0:j^[P2][Jd0/[:b0;Bd]080/k>c00/0];Bd0;:b/P2c/k<0];Bd0:^[Z`2RXZ80XJ6Q0:2PX02YZJT0
YjNW0:>SX`020:6QX@0N09nOW`2RXZ80WinO09ZJVP2MWId0Ti>C096AT@2:RXX0Ogmo07MgM`1aLG40
KVi^061PH01?Cdl0Fe]K059BDP18B4P0De=C059BDP1[Jf/0Kfm_07=cL`2@T900W9bL0:2PX02MWId0
c<c<0=7Ad@3EeMD0fMWI2P3AdM400`3>c/h0c<c<0=7Ad@0?0=7AdB80oooo000P0?oooa80QHF500L0
Xj>S069RHP0m?Cd0=3@d03hn?P14A4@0@T920080>c/k00D0DU9B06=SH`1cLg<0KVi^06UYJ@0206EU
I@0V06IVIP1KFe/0EUIF05EEE@1UIFD0IVIV05]KF`1JFUX0EEEE04m?C`1>CTh0C4a<055AD@1:BTX0
AdM704I6AP10@400?Shn04E5A@18B4P0A4A404Y:BP11@D40B4Q805MGE`1DE5@0F5QH05IFEP10@400
?clo03hn?P1:BTX0ATI602<S8`0o?cl0De=C05EEE@1:BTX206=SH`03061PH025QHD0QHF500<0QHF5
00<0PX:20861P@25QHD03025QHD00`29RHT0Rh^;08F5Q@0:08F5QAh0oooo4P2i^KT03P2VYZH0Kfm_
04i>CP1;Bd/0EeMG05QHF01PH600J6QX079bLP28R8P0RXZ:09BDU02BTY80VIVI0P2GUiL01P2HV9P0
SXj>08^;R`2;Rh/0TY:B096AT@80QXJ60280Ph>307alO01jNWX0MgMg07UiN@1dM7@0MWIf079bLP1`
L700JFUY06m_K`1`L700KVi^075aL@1WIfL0Kfm_07=cL`1_Kfl0KVi^06EUI@1HF5P0EUIF051@D01N
GUh0F5QH0492@P1IFET0Hf=S06MWI`1NGUh0LW9b08V9R@21PH40];Bd1@2i^KT00`2g]kL0^KVi0;Vi
^@0<0;Vi^@030;bl_02i^KT0^KVi00T0^KVi7P3ooolB0=7Ad@0>069RHP1DE5@0CTi>05aLG01RHV80
IFEU07EeM@2BTY80Xj>S0;:b/P2OWil0XJ6Q0:BTY02`/;020;>c/`0K0;:b/P2][Jd0Zj^[0;6a/@2/
[:`0W9bL09fMW@2OWil0UYJF09ZJVP2?Shl0SXj>09NGU`27QhL0VYZJ08R8R02EUID0QhN708j>SP27
QhL0RHV908F5Q@1mOGd0RHV907inOP1aLG40KVi^0080GEeM0P1LG5`02`1VIVH0Cdm?061PH01aLG40
IVIV06ATI01`L700OWin0:6QX@2j^[X0b/[:00D0dM7A00<0dm?C0=7Ad@3AdM402`3AdM400`3?cll0
c<c<0=7Ad@0:0=7AdB80oooo000P0?oooa80QHF500`0_Kfm0=gMg@2>SXh0D51@03Hf=P0d=3@0>CTi
03`l?01EEED0G5aL079bLP1^KVh206][J`0<06IVIP1NGUh0EeMG05aLG01OGel0FUYJ059BDP1NGUh0
EEEE04];B`1ADE40B4Q80P1=CDd0700j>SX0B4Q804E5A@15ADD0=CDe04E5A@10@400@T9203dm?@11
@D40AdM703@d=00/;2`0>3Ph03/k>`10@400AdM704Q8B00c<c<0:BTY03dm?@1<C4`0@D510492@P1B
DU80Jf][05UIF@1]KFd308F5Q@0408:2PP25QHD0QHF508V9R@/0QHF500@0PX:20861P@25QHD0OWin
3025QHDN0?oooa80^KVi03T0e]KF0;Zj^P24Q8@0Fe]K04e=C@1BDU80G5aL05iNGP1bLW80MGEe08n?
S`2EUID0VYZJ09RHV02CTi<0Shn?08b<S027QhL0RHV90861P@22PX80Shn?0820P01jNWX0O7al06m_
K`1eMGD0Lg=c06=SH`1dM7@0IVIV06][J`1IFET0Hf=S069RHP1VIVH0HF5Q06ATI01WIfL0EUIF05UI
F@1SHf<0GemO06=SH`1RHV80FUYJ04];B`1:BTX0G5aL04e=C@1ADE40HV9R06i^KP1bLW80Ph>308:2
PP2BTY801@2i^KT00`2k^k/0]KFe0;Vi^@0:0;Vi^@040;Ng]`2i^KT0]KFe0;no_`/0^KVi7P3ooolB
0=7Ad@0D0:VYZ@1<C4`0?clo055AD@1EEED0Kfm_06][J`23Ph<0Q8B4092@T02JVYX0Z:RX0:j^[P2]
[Jd0YjNW0:^[Z`2ZZZX0WIfM09^KV`2HV9P20:BTY00>09>CT`2HV9P0SXj>08V9R@26QXH0Q8B40820
P02<S8`0OGem07UiN@1dM7@0KFe]07inOP1fMWH207YjNP0C07IfMP1ZJVX0Ogmo07moO`1iNGT0Lg=c
06QXJ01MGEd0E5AD06IVIP1YJFT0ATI605mOG`1eMGD0OWin07AdM02FUYH0YjNW09bLW0050=7Ad@03
0<k>cP3<c<`0dM7A00X0dM7A00@0dm?C0=7Ad@3EeMD0fMWI2`3AdM4R0?ooo`00803oool608F5Q@03
08:2PP21PH40PH6100X0QHF500`0T92@07moO`1BDU80EeMG04M7A`1aLG40K6a/05eMG@1ADE40DU9B
05aLG01VIVH2065QH@0405iNGP1OGel0E5AD04i>CP80FEUI00X0D51@05QHF01?Cdl0C4a<04Y:BP12
@T80CDe=05MGE`1CDe<0AdM70P1EEED05`1BDU80CDe=055AD@1>CTh0AdM7055AD@15ADD0>SXj04A4
A017AdL0@41004M7A`0n?Sh0ADE50451@@0n?Sh0?Cdm04U9B@1XJ6P0LW9b05mOG`1mOGd0JFUY00<0
QHF500<0SHf=08F5Q@25QHD03025QHD00`29RHT0QHF508F5Q@0=08F5QAh0oooo1`2i^KT20;Ng]`X0
^KVi00L0_kno0:f][@1^KVh0IfMW05EEE@1gMgL0IfMW0080MWIf00<0QhN7096AT@2GUiL00P2ATI40
102:RXX0RHV90820P01lO7`20861P@0807alO020P800Lg=c075aL@1/K6`0IVIV06e]K@1`L70206QX
J00I06m_K`1WIfL0KVi^06=SH`1]KFd0Hf=S065QH@1XJ6P0GUiN059BDP1KFe/0GemO05aLG01PH600
F5QH05eMG@1@D500DE5A05MGE`1PH600L71`07AdM01jNWX0UYJF06i^KP030;Vi^@030;^k^`2i^KT0
^KVi00`0^KVi00<0^k^k0;Fe]@2i^KT03@2i^KTN0?ooo`L0dM7A0P3Cdm<:0=7Ad@0I0<W9b@2<S8`0
L71`05mOG`1IFET0IfMW05]KF`1mOGd0Vi^K0:ZZZP2g]kL0[jn_0:VYZ@2XZ:P0WYjN09^KV`2CTi<0
Vi^K09VIV@2CTi<0UIFE08j>SP24Q8@0PX:207moO`0207EeM@0=07]kN`1/K6`0MWIf07MgM`1QHF40
OWin06IVIP1fMWH0IVIV06i^KP1`L700G5aL065QH@0206UYJ@0706EUI@1[Jf/0H61P069RHP1ADE40
G5aL06UYJ@02071`L00406YZJP29RHT0V9RH09>CT`<0dM7A00<0c<c<0=7Ad@3AdM40303AdM400`3>
c/h0c<c<0=7Ad@0=0=7AdB80oooo000P0?ooo`80QHF500D0PH6108F5Q@25QHD0QHF508V9R@0=08F5
Q@0e0=kNgP1bLW80ATI604U9B@0a<C40?Shn04U9B@14A4@0GEeM061PH01KFe/0G5aL05eMG@1LG5`0
De=C05ADE01<C4`0AdM704a<C01@D500CDe=059BDP1=CDd0?Cdm04Q8B010@400?clo04];B`19BDT0
?3`l04M7A`18B4P0A4A403@d=00n?Sh0BDU903Ti>@12@T80=CDe02XZ:P0T92@09bLW02/[:`0];Bd0
;2`/030`<00c<c<0F5QH06YZJP1^KVh0HV9R05QHF01<C4`01025QHD00`1nOWh0QHF508F5Q@0L08F5
QAh0oooo0P2i^KT01@2g]kL0^KVi0;Vi^@2i^KT0^k^k0080]KFe2`2i^KT0=P3UiND0OGem06=SH`1T
I6@0GEeM075aL@1hN7P0L71`08N7Q`29RHT0Rh^;08b<S028R8P0QhN707moO`1nOWh0LG5a079bLP1j
NWX0MgMg07EeM@1dM7@0KFe]065QH@1XJ6P0JVYZ05mOG`1`L700IfMW05eMG@1ZJVX0G5aL06IVIP1H
F5P0HV9R06EUI@1LG5`0Hf=S04a<C019BDT0ATI604U9B@1:BTX0Cdm?04Q8B01<C4`0CTi>065QH@1]
KFd0Lg=c08R8R026QXH0Jf][09nOW`<0^KVi00<0]KFe0;Vi^@2i^KT0702i^KTN0?ooo`80dM7A00D0
dm?C0=7Ad@3AdM40dM7A0<k>cP020<c<c0/0dM7A00d0Ti>C051@D01fMWH0JFUY08^;R`2IVIT0Ti>C
09RHV02RXZ80WinO0:NWY`2TY:@0X:2P0080UiNG02L0S8b<08^;R`2?Shl0UiNG08R8R026QXH0QhN7
07AdM01eMGD0MWIf08N7Q`1eMGD0QhN706e]K@1hN7P0NGUi07EeM@1ZJVX0MgMg07EeM@1fMWH0L71`
06e]K@1GEeL0HF5Q05eMG@1QHF40GemO069RHP1LG5`0GEeM069RHP1TI6@0J6QX07YjNP2?Shl0Y:BT
0;Ng]`2^[Zh00`3AdM400`3EeMD0dM7A0=7Ad@0L0=7AdB80oooo000P0?oooa@0QHF500<0OWin0?;b
lP2>SXh00P1EEED00`1QHF40IVIV06][J`0206QXJ00/05iNGP1CDe<0D51@05UIF@1DE5@0GEeM05AD
E01ADE40AdM7059BDP16ATH0?3`l03/k>`14A4@0CDe=02@T900b<S80<30`0492@P1;Bd/0AdM702h^
;P0m?Cd0A4A402`/;00J6QX0=CDe034a<@0g=cL0?Cdm04E5A@17AdL0@D5103Lg=`0k>c/0ADE506EU
I@1QHF40JFUY03Hf=P0j>SX0@d=306][J`2;Rh/508F5Q@0308:2PP21PH40QHF501X0QHF57P3oool2
0;Vi^@030;Fe]@2i^KT0^KVi00l0^KVi00H0]KFe0?KfmP23Ph<0KFe]069RHP1cLg<207YjNP0=0820
P02?Shl0R8R80820P01mOGd0Q8B407YjNP1nOWh0LW9b07=cL`1[Jf/0M7Ad06a/K003069RHP0N06=S
H`10@400Fe]K055AD@1XJ6P0HV9R06=SH`1ADE40IFEU05QHF016ATH0?clo05ADE01=CDd0DE5A051@
D01CDe<0D51@05EEE@19BDT0CDe=05ADE01LG5`0Jf][07emO@1WIfL0Ogmo06i^KP1IFET0_;bl1P2i
^KT00`2g]kL0^KVi0;Vi^@0I0;Vi^Ah0oooo0P3AdM400`3<c<`0dM7A0=7Ad@0?0=7Ad@0;0=GEe@2=
SHd0A4A406][J`1]KFd0M7Ad07]kN`1mOGd0Rh^;09jNWP2EUID00P2JVYX0:@2GUiL0RXZ:08B4Q020
P800Ogmo0861P@27QhL0OGem07inOP1bLW80MWIf06][J`1EEED0Ph>306EUI@24Q8@0J6QX071`L01Y
JFT0NGUi06ATI01>CTh0HF5Q06ATI01NGUh0G5aL05MGE`1@D500CDe=05QHF01<C4`0EeMG05IFEP1H
F5P0M7Ad08N7Q`1nOWh0^k^k08V9R@1iNGT0c<c<00H0dM7A00<0dm?C0=7Ad@3AdM406@3AdM4R0?oo
o`00803ooolF08F5Q@0F0<K6aP1GEeL0Fe]K05aLG018B4P0@D5104e=C@1NGUh0GemO04i>CP12@T80
B4Q804];B`1ADE40ADE504A4A01:BTX0C4a<04Y:BP1HF5P0<30`03De=@80AdM700T0@41002h^;P0k
>c/0=SHf03<c<`0_;bl0<C4a03Lg=`0b<S800P0];Bd01P0c<c<0;Rh^02l_;`0b<S80?3`l04Y:BP80
@T9200/0ATI606UYJ@0];Bd0ATI6065QH@1IFET0Rh^;07inOP21PH40QHF508:2PP0408F5Q@0608V9
R@2;Rh/0QHF508F5Q@29RHT0Rh^;1@25QHD00`29RHT0QHF508F5Q@0>08F5QAh0oooo5P2i^KT05@3I
fMT0LG5a061PH01[Jf/0GUiN06=SH`1iNGT0R8R808^;R`1gMgL0Jf][06i^KP1]KFd0Lg=c06QXJ01U
IFD0JVYZ06a/K01YJFT0LG5a04Y:BP02069RHP0406e]K@1CDe<0B4Q805YJFP80CDe=01D0ADE504Q8
B019BDT0@T920451@@18B4P0AdM704E5A@19BDT0B4Q804e=C@1IFET0GEeM06ATI01WIfL0Ph>306i^
KP1kNg/0LW9b06a/K026QXH00P2g]kL30;Vi^@050;Fe]@2i^KT0]KFe0;Vi^@2l_;`00`2i^KT00`2l
_;`0^KVi0;Vi^@030;Vi^@040;^k^`2e]KD0^KVi0;no_`d0^KVi7P3ooolF0=7Ad@0[0:BTY01EEED0
HV9R05iNGP1[Jf/0QHF50:6QX@2MWId0W9bL0861P@2:RXX0PX:208N7Q`1oOgl0MGEe07emO@1lO7`0
MWIf07AdM01`L700Fe]K08>3P`1WIfL0OGem051@D01PH600IfMW05MGE`1OGel0D51@05=CD`1;Bd/0
BDU904Y:BP1IFET0DE5A05=CD`1GEeL0DU9B05ADE01MGEd0KVi^07UiN@0208Z:RP070:BTY02DU9@0
MgMg075aL@1jNWX0e=CD0=?Cd`030=7Ad@050<c<c03AdM40c<c<0<o?c`3<c<`00P3AdM400`3?cll0
c<c<0=7Ad@040=7Ad@040<k>cP3<c<`0dM7A0=WIf@d0dM7A8P3oool00200oooo5P25QHD08P1nOWh0
oooo02@T900j>SX0GemO05aLG01<C4`0KFe]06UYJ@1JFUX0BTY:04a<C00l?3`0ATI604A4A011@D40
BDU904A4A011@D40?Shn0410@00l?3`0@d=302`/;00Z:RX0?3`l03Lg=`0a<C40<S8b03@d=00/;2`0
:RXZ028R8P0P820202DU9@0B02d];@0o?cl0?Shn03Lg=`1MGEd0IVIV07alO01hN7P0F5QH04A4A01=
CDd0?3`l05iNGP29RHT0S8b<0861P@25QHD0RHV91025QHD01@1nOWh0QHF508F5Q@25QHD0OWin01L0
QHF57P3ooolF0;Vi^@040;Fe]@3oool0ADE506][J`<0L71`01D0T92@08Z:RP1mOGd0IFEU06YZJP1P
H600K6a/06ATI01MGEd0JFUY06ATI01UIFD0GUiN05eMG@1@D500G5aL04I6AP19BDT0D51@04a<C01;
Bd/00P19BDT04P10@400?clo03Lg=`0d=3@0>3Ph03/k>`14A4@0D51@04e=C@1:BTX0KFe]07=cL`1f
MWH0N7Qh07alO01OGel0I6AT05eMG@80M7Ad00X0^k^k0;>c/`2i^KT0^k^k0;Fe]@2i^KT0]KFe0;Vi
^@2e]KD0_kno0P2i^KT00`2e]KD0_kno0;Vi^@0E0;Vi^Ah0oooo5P3AdM40:P3EeMD0PH6105eMG@2K
Vi/0L71`07MgM`28R8P0V9RH08n?S`1gMgL0N7Qh07=cL`1kNg/0OGem071`L01eMGD0NGUi071`L01e
MGD0MgMg05iNGP1UIFD0Hf=S05IFEP1IFET0IVIV04i>CP1IFET0EUIF051@D019BDT0C4a<04=3@`11
@D40A4A404Y:BP1DE5@0F5QH04a<C01GEeL0LW9b06QXJ080IVIV0100S8b<06EUI@1mOGd0Kfm_0::R
XP1cLg<0aLG50<o?c`3AdM40c/k>0<c<c03AdM40c<c<0=7Ad@3EeMD0fMWI0P3AdM400`3EeMD0fMWI
0=7Ad@0E0=7AdB80oooo000P0?oooaH0QHF500d0PX:20861P@2CTi<092@T020P800h>3P0Bd];06MW
I`1YJFT0Fe]K03Ph>01;Bd/0DE5A0080G5aL0P10@4001@1>CTh0@D5104M7A`16ATH0>CTi0080BDU9
01/09RHV01TI6@0b<S80AdM703`l?00U9BD0;Rh^02`/;00W9bL0820P01dM7@0L71`08b<S02/[:`1<
C4`0I6AT04U9B@1TI6@0CDe=02h^;P0/;2`0EeMG03De=@1NGUh0E5AD07inOP29RHT00P25QHD00`22
PX80PH6108V9R@0908F5Q@0308:2PP21PH40QHF500D0QHF500<0RHV908^;R`25QHD02P25QHDN0?oo
oaL0^KVi0180]kNg08^;R`0h>3P0EUIF06QXJ01dM7@0SXj>092@T020P800FEUI06e]K@1XJ6P0Lg=c
06i^KP1JFUX0HV9R06UYJ@1PH60205mOG`0<04i>CP1TI6@0G5aL03De=@0d=3@0DE5A059BDP1<C4`0
>CTi04A4A00m?Cd0>3Ph0`0^;Rh0400h>3P0@d=3061PH01SHf<0IfMW0820P01bLW80IfMW06YZJP1a
LG40DU9B07inOP0o?cl0Zj^[0<71`@2e]KD20;Vi^@030;Ng]`2i^KT0^KVi00T0^KVi00<0]kNg0;Vi
^@2i^KT01@2i^KT00`2l_;`0^KVi0;Vi^@090;Vi^Ah0oooo5`3AdM400`3Cdm<0>SXj04M7A`02092@
T00T08j>SP2QXJ40V9RH07YjNP1^KVh0QHF506UYJ@1eMGD0IfMW06ATI01mOGd0KVi^07AdM01ZJVX0
GUiN06=SH`1^KVh0FEUI03De=@1DE5@0HF5Q05UIF@19BDT0@T92059BDP11@D40?Cdm03@d=00h>3P0
>CTi04];B`1KFe/0JFUY05EEE@21PH40SXj>0P29RHT0202LW9`0L71`06YZJP2=SHd0L71`0<S8b03F
e]H0c<c<0P3AdM400`3Cdm<0clo?0=7Ad@090=7Ad@030=?Cd`3AdM40dM7A00@0dM7A00<0clo?0<c<
c03AdM402P3AdM4R0?ooo`00803oool408F5Q@0308:2PP21PH40QHF500l0QHF50300RHV908F5Q@30
`<00Jf][030`<00Z:RX0=SHf04i>CP1VIVH0IFEU04M7A`0f=SH0D51@03@d=00n?Sh0@d=3034a<@0j
>SX0>CTi03Lg=`1;Bd/0ADE503Lg=`19BDT0EEEE04E5A@0`<3007alO03De=@0j>SX0=cLg03Ti>@18
B4P0A4A40492@P1@D500E5AD05=CD`1=CDd0EEEE06][J`17AdL0BTY:03<c<`0_;bl0De=C06IVIP1e
MGD408F5Q@0408V9R@2?Shl0PX:207YjNP<0QHF500<0RHV908^;R`25QHD00`25QHD00`29RHT0QHF5
08^;R`0508F5Q@0307inOP25QHD0QHF500X0QHF57P3oool50;Vi^@030;Ng]`2i^KT0^KVi00h0^KVi
0340^k^k0;Fe]@3Shn<0Lg=c0451@@1=CDd0GUiN0820P02ATI40QXJ6065QH@1DE5@0LW9b05iNGP1W
IfL0HV9R04m?C`1NGUh0DE5A05UIF@1UIFD0F5QH05ADE01PH600HV9R04M7A`10@400>c/k05EEE@1:
BTX0@T9204Y:BP1?Cdl0B4Q804M7A`1<C4`0CDe=05IFEP1IFET0KFe]07]kN`1^KVh0NWYj05ADE01<
C4`0KVi^07IfMP1ADE40Ph>300@0^KVi00<0_[jn0;Fe]@2c/k<0102i^KT00`2l_;`0^KVi0;Vi^@02
0;Vi^@030;^k^`2e]KD0_;bl00D0^KVi00<0]KFe0;no_`2i^KT02P2i^KTN0?ooo`D0dM7A00<0dm?C
0=7Ad@3AdM403P3AdM407`3>c/h0c<c<0:2PX015ADD0CDe=06][J`28R8P0ZJVY0:BTY01iNGT0Hf=S
07=cL`22PX80OWin08>3P`1YJFT0IFEU07QhN01PH600Kfm_06i^KP1NGUh0IFEU069RHP1?Cdl0?Shn
04A4A01DE5@0IfMW04Y:BP18B4P00P1:BTX0400i>CT0?clo03`l?00n?Sh0CDe=06ATI01mOGd0Jf][
09:BTP29RHT0FUYJ06a/K01kNg/0Jf][05YJFP28R8P30=7Ad@040<o?c`39bLT0cLg=0=SHf0<0dM7A
00<0clo?0<c<c03AdM400`3AdM400`3>c/h0c<c<0<c<c0050=7Ad@030=GEe@3IfMT0dM7A00X0dM7A
8P3oool00200oooo1025QHD00`29RHT0QHF508F5Q@0A08F5Q@0A0::RXP31`L40Kfm_04U9B@0`<300
:RXZ03Lg=`1ZJVX0E5AD03@d=00g=cL0BTY:03Xj>P0f=SH0<C4a02/[:`0h>3P00P0k>c/203Xj>P0U
04i>CP1<C4`0AdM70410@01=CDd0>SXj0451@@16ATH0@T9203Lg=`16ATH0FUYJ06MWI`1RHV80GEeM
06YZJP1UIFD0DE5A04A4A00h>3P0BDU904m?C`11@D40MgMg08^;R`29RHT0T92@08:2PP25QHD0PX:2
08F5Q@2?Shl0PX:208V9R@2;Rh/0QHF507inOP0;08F5Q@0308V9R@25QHD0QHF500`0QHF57P3oool4
0;Vi^@030;^k^`2e]KD0^KVi0140^KVi0100b<S80<[:bP1_Kfl0EUIF04];B`1QHF40Kfm_092@T01Y
JFT0DE5A05YJFP1PH600EeMG05EEE@1<C4`0AdM70P1DE5@01P1FEUH0FEUI05EEE@1WIfL0HV9R05]K
F`80DU9B0240AdM7055AD@1CDe<0De=C04];B`1KFe/0GEeM06ATI01[Jf/0KFe]071`L01jNWX0QhN7
06a/K01NGUh0Hf=S059BDP1RHV80JFUY07QhN02i^KT0_;bl0;Vi^@2g]kL0^KVi0;fm_@2n_[h0]KFe
0;Vi^@2l_;`0^KVi0;Fe]@2o_kl01P2i^KT00`2o_kl0^KVi0;Vi^@0@0;Vi^Ah0oooo103AdM400`3>
c/h0c<c<0=7Ad@0A0=7Ad@0@0;bl_01bLW80ADE505ADE01PH600W9bL0:2PX02LW9`0EUIF06QXJ01j
NWX0HF5Q06QXJ01QHF40FUYJ05eMG@80Hf=S01H0JFUY06IVIP1QHF40Kfm_065QH@1OGel0CTi>055A
D@16ATH0FEUI059BDP1CDe<0F5QH05mOG`1BDU80F5QH05iNGP1/K6`0LG5a07QhN02JVYX0QhN70P1Y
JFT04@1EEED0NGUi07emO@1`L700clo?0<[:bP3AdM40d];B0=7Ad@3Jf]X0bLW90<g=c@3?cll0c<c<
0=7Ad@3EeMD0fMWI00H0dM7A00D0fMWI0=7Ad@3AdM40dM7A0<o?c`0>0=7AdB80oooo000P0?oooaH0
QHF502D0O7al0861P@22PX80PH610;fm_@2c/k<0D51@04I6AP1CDe<0DU9B05QHF022PX80Fe]K03Xj
>P17AdL0@T9205=CD`1;Bd/0:RXZ02HV9P0/;2`0>CTi03@d=017AdL0G5aL075aL@2?Shl0WIfM08R8
R023Ph<0OWin07=cL`25QHD0Ti>C06YZJP1CDe<0<S8b0080?Shn00H0<C4a0451@@1CDe<0F5QH04i>
CP19BDT208F5Q@0308V9R@2;Rh/0OWin0080QHF500L0OWin08F5Q@22PX80PH6108V9R@2@T900Rh^;
01/0QHF57P3ooolF0;Vi^@0B0;Fe]@2m_Kd0^KVi0;Ng]`3Fe]H0/;2`065QH@1PH600K6a/06i^KP1k
Ng/0UIFE06IVIP1KFe/0IVIV05UIF@1/K6`0EUIF0P13@d<05`1<C4`0De=C04Y:BP1OGel0MWIf06m_
K`25QHD0UiNG07alO01`L700N7Qh079bLP1oOgl0QhN707YjNP1lO7`0IFEU06i^KP1MGEd0DE5A05=C
D`1BDU80FUYJ0080IfMW00`0MWIf0;no_`2i^KT0_;bl0;Fe]@2o_kl0^KVi0;Fe]@2o_kl0^KVi0;Ng
]`2i^KT20;bl_1/0^KVi7P3ooolF0=7Ad@0k0=KFeP3Kfm/0dM7A0=?Cd`2YZJT0H61P051@D01dM7@0
NGUi08:2PP2ATI40NWYj055AD@1YJFT0N7Qh06ATI01[Jf/0Cdm?05IFEP1GEeL0JFUY05UIF@1UIFD0
NGUi07IfMP1_Kfl0Hf=S05iNGP19BDT0ATI605UIF@1QHF40JFUY05mOG`1nOWh0RHV908B4Q02:RXX0
JVYZ06ATI01DE5@0CTi>05UIF@1[Jf/0Lg=c07MgM`3IfMT0clo?0<c<c03EeMD0fMWI0=7Ad@3EeMD0
fMWI0=7Ad@3Cdm<0clo?0<[:bP3<c<`06`3AdM4R0?ooo`00803ooolF08F5Q@0D08V9R@25QHD0RHV9
08V9R@2;Rh/0];Bd0>o_k`0o?cl0;2`/030`<01CDe<0JFUY08N7Q`1PH600Cdm?05MGE`1=CDd0GEeM
06UYJ@10@40203Lg=`0M03@d=01KFe/0IFEU03/k>`12@T80KFe]07alO028R8P0SXj>07moO`1CDe<0
?clo03`l?010@400ADE503/k>`0`<300;bl_04a<C01>CTh0B4Q805=CD`2FUYH0QHF508:2PP1jNWX0
QHF508:2PP21PH400P25QHD00`22PX80QHF508F5Q@0207inOP0308F5Q@22PX80PH6101T0QHF57P3o
oolF0;Vi^@0L0;^k^`2e]KD0^k^k0;Fe]@2l_;`0d];B0<W9b@1JFUX0De=C065QH@1fMWH0QhN709ZJ
VP1cLg<0GUiN06m_K`1RHV80Kfm_06IVIP1=CDd0AdM704a<C01;Bd/0IfMW07inOP1UIFD0PX:209ZJ
VP80V9RH01D0UiNG09>CT`1nOWh0PH6107AdM01bLW80IFEU05ADE01>CTh0Bd];05MGE`1KFe/0J6QX
07AdM01]KFd0_kno0;Vi^@2c/k<0_kno0;Vi^@2g]kL0102i^KT20;Fe]@040;^k^`2o_kl0^KVi0;Ng
]aT0^KVi7P3ooolF0=7Ad@0V0<k>cP3<c<`0c/k>0<[:bP3<c<`0[jn_04Y:BP1ZJVX0Kfm_09FEU@2I
VIT0T92@07alO01]KFd0HF5Q075aL@1WIfL0Kfm_0492@P14A4@0EUIF051@D01TI6@0L71`07emO@2:
RXX0alO70:^[Z`2BTY80SXj>0861P@26QXH0UiNG0;6a/@2JVYX0RHV9071`L01SHf<205YJFP0;05QH
F01ZJVX0MGEe08>3P`1BDU80fMWI0=7Ad@3Hf=P0fMWI0=7Ad@3Cdm<0103AdM401P3<c<`0eMGE0=gM
g@3IfMT0dM7A0=?CdaT0dM7A8P3oool00200oooo6@25QHD0:`22PX80Rh^;08F5Q@2:RXX0Ogmo04A4
A00i>CT0=SHf04Q8B01]KFd0LG5a08:2PP1mOGd0SXj>08Z:RP2@T900cLg=0=GEe@3^k^h0a/K608f=
S@27QhL0TY:B07MgM`1bLW80Lg=c065QH@11@D40@410055AD@11@D40@T9203dm?@0h>3P0<S8b04Y:
BP1PH600Cdm?03lo?`29RHT0e]KF08F5Q@29RHT00`25QHD04029RHT0PH6108F5Q@25QHD0RHV908:2
PP21PH40RHV908^;R`25QHD0QXJ60861P@22PX80PH6108V9R@2;Rh/E08F5QAh0oooo6@2i^KT0602e
]KD0`/;20;Vi^@2l_;`0Ph>305YJFP1?Cdl0H61P07emO@2>SXh0NWYj08B4Q020P800Q8B407moO`2F
UYH0V9RH07EeM@2GUiL0NWYj08V9R@2EUID0TY:B07YjNP80UYJF00T0Ti>C08F5Q@27QhL0Q8B406e]
K@1YJFT0GEeM05IFEP1?Cdl00P1NGUh02`1SHf<0GUiN07AdM02?Shl0MGEe0;bl_02i^KT0]KFe0;Vi
^@2k^k/0/k>c0080^KVi00`0^k^k0;Fe]@2g]kL0^KVi0;bl_02i^KT0^k^k0;>c/`2i^KT0]kNg0;Vi
^@2l_;`E0;Vi^Ah0oooo6@3AdM420=CDe0080=7Ad@3=cLd0BTY:05YJFP1/K6`0Rh^;0:j^[P2OWil2
06m_K`0<06IVIP1UIFD0GEeM07alO00];Bd0000000@4100@4100Kfm_07inOP1bLW80MGEe0P2QXJ42
0:f][@0D0<;2`P2EUID0Q8B407inOP1WIfL0J6QX05]KF`1VIVH0CDe=06UYJ@1dM7@0Lg=c02DU9@1e
MGD0cLg=0=7Ad@3<c<`0dM7A0<k>cP3?cll20=7Ad@060<k>cP3=cLd0dm?C0<o?c`3<c<`0dM7A0P3?
cll0103AdM40dm?C0<o?c`3<c<`E0=7AdB80oooo000P0?oooa40QHF500<0RHV908F5Q@25QHD01@25
QHD0:P22PX80Rh^;08F5Q@25QHD0hn?S0>3Ph01HF5P0<C4a03Hf=P10@400O7al07moO`2=SHd0LG5a
07UiN@1cLg<0K6a/05EEE@1OGel0JFUY07moO`2;Rh/0MgMg07IfMP1ZJVX0D51@05aLG01QHF40DU9B
04Q8B012@T80=CDe04U9B@1CDe<0L71`06YZJP1KFe/0GEeM0:JVYP1nOWh0PX:20861P@H0QHF500H0
PX:20861P@25QHD0RHV908F5Q@1nOWh208F5Q@0508V9R@25QHD0RHV908F5Q@1nOWh01`25QHD01P29
RHT0QHF508V9R@2;Rh/0PX:20861P@T0QHF57P3ooolI0;Vi^@0B0;Fe]@32`/80^KVi0;Vi^@3`l?00
WinO061PH01HF5P0H61P07EeM@2?Shl0SXj>0:>SX`29RHT0XJ6Q08F5Q@2MWId0UIFE0P2WYjL0602S
Xj<0ZZZZ09NGU`2OWil0V9RH08Z:RP2DU9@0RXZ:06i^KP1aLG40IFEU05IFEP1SHf<0GemO06m_K`1R
HV80KVi^071`L01jNWX0HF5Q0;no_`2g]kL0_kno0;Fe]@<0^KVi00D0]KFe0;Vi^@2g]kL0^KVi0;^k
^`020;Fe]@050;no_`2i^KT0^k^k0;Fe]@2k^k/00P2e]KD00`2o_kl0^KVi0;Vi^@070;Vi^@030;bl
_02i^KT0]kNg00T0^KVi7P3ooolA0=7Ad@030<o?c`3AdM40dM7A00D0dM7A0P3De=@20=7Ad@0609JF
UP0O7al0A4A407UiN@2BTY80ZZZZ0P2>SXh04@2ATI40UYJF0:ZZZP2CTi<0];Bd0<_;b`3IfMT0b<S8
0:j^[P2SXj<0X:2P0:j^[P2VYZH0Zj^[0:NWY`2BTY80PX:20080NGUi00d0KVi^06e]K@1OGel0F5QH
055AD@1]KFd0NWYj04e=C@1SHf<0fMWI0=?Cd`3IfMT0c<c<00<0dM7A00l0c<c<0=7Ad@3Cdm<0dM7A
0<k>cP3<c<`0eMGE0=WIf@3AdM40c/k>0<c<c03>c/h0c<c<0=GEe@3IfMT01P3AdM401P3?cll0dM7A
0<o?c`3<c<`0dM7A0=?Cd`T0dM7A8P3oool00200oooo4@25QHD00`1nOWh0QHF508F5Q@0408F5Q@0?
08^;R`22PX80T92@08^;R`29RHT0QHF509bLW03_knl0Ogmo04=3@`0n?Sh0EeMG05EEE@1RHV80Jf][
0080MGEe01H0P82008J6QP28R8P0PX:207AdM01gMgL0Lg=c06MWI`1aLG40JFUY04m?C`17AdL0=cLg
04I6AP19BDT0Bd];061PH01VIVH0F5QH04a<C01GEeL0[Zj^0P25QHD02026QXH0PH6108F5Q@29RHT0
Rh^;08V9R@2;Rh/0PX:22025QHD00`29RHT0Rh^;08F5Q@0408F5Q@0508V9R@25QHD0QHF508F5Q@29
RHT00P25QHD00`1nOWh0RHV908n?S`0:08F5QAh0oooo4@2i^KT00`2e]KD0^KVi0;Vi^@040;Vi^@04
0;bl_02e]KD0`/;20;bl_080^KVi00T0`l?30>CTi01fMWH0G5aL06UYJ@29RHT0Shn?09bLW02JVYX0
0P2MWId07`2YZJT0WYjN0:BTY02VYZH0XZ:R0:ZZZP2SXj<0VIVI0:2PX02?Shl0QHF506m_K`1VIVH0
KFe]05mOG`1KFe/0IVIV079bLP1_Kfl0M7Ad07]kN`1oOgl0Ph>30;Vi^@2k^k/0/k>c0;Fe]@2i^KT0
_;bl0;Vi^@2l_;`00P2i^KT00`2e]KD0^KVi0;Vi^@050;Vi^@030;bl_02i^KT0^KVi00X0^KVi00@0
]KFe0;no_`2n_[h0]KFe2@2i^KTN0?oooa40dM7A00<0eMGE0=7Ad@3AdM40103AdM40303<c<`0e=CD
0=?Cd`3<c<`0clo?0=7Ad@32`/80K6a/03hn?P1_Kfl0S8b<0:j^[P80_[jn00@0]KFe0;2`/02`/;00
/K6a0P2RXZ805@2YZJT0_Kfm0;^k^`2f][H0/K6a0:n_[`2<S8`0YZJV07moO`29RHT0NGUi06m_K`1W
IfL0I6AT06][J`1jNWX0QhN708j>SP17AdL0R8R80=7Ad@020<o?c`050<c<c03?cll0c<c<0<o?c`3<
c<`00P3AdM400`3<c<`0dM7A0=7Ad@040=7Ad@030<o?c`3<c<`0dM7A00@0dM7A00D0clo?0=7Ad@3A
dM40dM7A0<o?c`020=7Ad@040=GEe@3GemL0bLW90<c<c0T0dM7A8P3oool00200oooo4025QHD00`29
RHT0Rh^;08F5Q@0908F5Q@0`08:2PP2?Shl0QHF508:2PP2;Rh/0QHF50<k>cP3Lg=`0N7Qh03lo?`0n
?Sh0DE5A06UYJ@20P800MGEe07alO020P800PX:207emO@1dM7@0G5aL051@D01QHF40SHf=07emO@25
QHD0Shn?069RHP1DE5@0RXZ:0=;BdP39bLT0U9BD08^;R`25QHD0RHV908^;R`25QHD0OWin08F5Q@29
RHT0Rh^;08V9R@25QHD0OWin08F5Q@1lO7`0PH610`25QHD01P1nOWh0QHF508V9R@2;Rh/0T92@08V9
R@80T92@00`0Rh^;08F5Q@25QHD0QHF508V9R@2;Rh/0QHF508:2PP29RHT0QHF508f=S@2;Rh/408F5
Q@0307inOP25QHD0QHF50080QHF57P3ooolA0;Vi^@030;bl_02i^KT0^KVi00T0^KVi0200_[jn0;Fe
]@2e]KD0`/;20;Vi^@3Ogml0TI6A0820P01iNGT0PX:209>CT`2LW9`0YJFU09^KV`2WYjL0Xj>S0:2P
X02CTi<0RHV907QhN01kNg/0QXJ608f=S@1/K6`0NWYj09>CT`1gMgL0OWin09BDU02[Zj/0SXj>08Z:
RP<0^KVi00<0_;bl0;Vi^@2e]KD00P2i^KT01`2l_;`0^k^k0;Fe]@2e]KD0_kno0;Fe]@2m_Kd00P2i
^KT20;Fe]@060;no_`2i^KT0_;bl0;bl_02i^KT0`/;20P2l_;`40;Vi^@030;bl_02i^KT0]KFe0080
_kno00<0`L710;Vi^@2i^KT00`2i^KT00`2e]KD0_kno0;Vi^@020;Vi^Ah0oooo403AdM400`3?cll0
c<c<0=7Ad@0:0=7Ad@0_0<W9b@3<c<`0e=CD0=CDe03AdM40WIfM01lO7`1TI6@0YjNW0<K6aP34a<@0
`<300:b/[02][Jd0]KFe0:ZZZP2CTi<0RHV907]kN`25QHD0TI6A09ZJVP1IFET0E5AD069RHP1_Kfl0
N7Qh0:JVYP2@T900EEEE03Xj>P21PH40alO70=7Ad@3?cll0c<c<0=7Ad@3EeMD0dM7A0<o?c`3<c<`0
c/k>0<c<c03EeMD0fMWI0=KFeP3Kfm/00P3AdM402P3<c<`0eMGE0=WIf@3?cll0c<c<0<[:bP3?cll0
dm?C0<[:bP3<c<`30=7Ad@080<o?c`3<c<`0dM7A0=CDe03GemL0fMWI0=GEe@37alL40=7Ad@030=GE
e@3IfMT0dM7A0080dM7A8P3oool00200oooo3`25QHD00`22PX80NWYj08F5Q@0:08F5Q@0408V9R@25
QHD0QHF507inOP80QHF50P29RHT20<k>cP0J08>3P`1FEUH0D51@04a<C01QHF40JVYZ075aL@2?Shl0
WYjN0;2`/02QXJ40VYZJ08F5Q@2?Shl0IFEU04M7A`1ADE40Ogmo0:BTY02@T900PX:208V9R@22PX80
PH6108F5Q@1nOWh308F5Q@080861P@1nOWh0PX:20861P@25QHD0PX:20861P@29RHT408F5Q@0408:2
PP21PH40OWin08F5Q@<0OWin00H0O7al0861P@29RHT0PH6108F5Q@1nOWh208F5Q@0507YjNP1nOWh0
QHF507inOP22PX802@25QHDN0?oooa00^KVi00<0/k>c0;no_`2i^KT02@2i^KT01@2k^k/0_kno0;Vi
^@2e]KD0_kno00<0^KVi0100gmoO0:>SX`2=SHd0Q8B408J6QP2ATI40VYZJ09nOW`2QXJ40[Jf]0:>S
X`2_[jl0WIfM09^KV`24Q8@0[Jf]0P21PH401@2<S8`0W9bL08F5Q@2HV9P0Zj^[0080_kno00@0_Kfm
0;Vi^@2e]KD0_kno0P2i^KT0102g]kL0]KFe0;no_`2g]kL20;Vi^@030;Ng]`2k^k/0]KFe00@0^KVi
00<0]kNg0;Fe]@2o_kl0102k^k/0302m_Kd0^KVi0;Ng]`2i^KT0]KFe0;no_`2i^KT0/k>c0;^k^`2o
_kl0]KFe0;no_`T0^KVi7P3oool@0=7Ad@030=SHf03IfMT0dM7A00T0dM7A00H0c/k>0=WIf@3AdM40
eMGE0=WIf@3AdM420<o?c`0M09fMW@1;Bd/0KVi^09nOW`2/[:`0c<c<0<G5a@2m_Kd0_[jn0:ZZZP2;
Rh/0OGem079bLP1cLg<0MgMg09ZJVP27QhL0Zj^[0;Vi^@2KVi/0GUiN09BDU036a/H0emOG0=WIf@3K
fm/0dM7A0=GEe@3IfMT00P3AdM40103Cdm<0eMGE0=WIf@3Cdm<20=7Ad@030=?Cd`3>c/h0c<c<00@0
dM7A00<0dm?C0=GEe@3IfMT00`3MgMd03@3Ng]h0fm_K0<o?c`3Cdm<0dM7A0=GEe@3IfMT0dM7A0=SH
f03MgMd0fMWI0=GEe@3IfMT02@3AdM4R0?ooo`00803oool?08F5Q@80RHV900<0Rh^;08F5Q@25QHD0
2`25QHD06@22PX80PH6108F5Q@22PX80N7Qh0861P@25QHD0_Kfm0;no_`2i^KT0XZ:R08n?S`2:RXX0
PX:2071`L01EEED0DE5A065QH@1aLG40JFUY06m_K`2JVYX0^KVi0;:b/P2TY:@00P25QHD01P22PX80
RHV908n?S`29RHT0T92@08^;R`<0QHF500<0PX:207inOP25QHD00P25QHD01029RHT0QHF508:2PP21
PH4208V9R@0408F5Q@29RHT0RHV908^;R`@0QHF500H0RHV908F5Q@1nOWh0Rh^;08V9R@2;Rh/608F5
Q@0308f=S@25QHD0QHF500@0QHF500<0Rh^;08F5Q@25QHD07P3oool?0;Vi^@030;^k^`2e]KD0_;bl
00h0^KVi01h0]kNg0;Vi^@2e]KD0/k>c0;fm_@2i^KT0e]KF0:JVYP2`/;00V9RH09fMW@2WYjL0WYjN
0:>SX`2MWId0X:2P0:>SX`2RXZ80VIVI09bLW02/[:`0XJ6Q09>CT`2LW9`0[jn_0;Vi^@2e]KD0_kno
0<C4a02e]KD20;bl_0<0^KVi00l0]KFe0;Ng]`2i^KT0]KFe0;Vi^@2k^k/0]KFe0;Vi^@2g]kL0^KVi
0;bl_02i^KT0^k^k0;Fe]@2l_;`0102i^KT00`2k^k/0]KFe0;Fe]@020;Vi^@040;bl_02i^KT0^KVi
0;Fe]@<0^KVi00<0^k^k0;Vi^@2i^KT0102i^KT00`2l_;`0^KVi0;Vi^@0N0?ooo`l0dM7A00<0c/k>
0<[:bP3<c<`03P3AdM407@3Cdm<0dM7A0=CDe03IfMT0fm_K0=7Ad@2YZJT0HV9R07QhN01cLg<0U9BD
0:BTY02][Jd0^KVi0=7Ad@3Jf]X0clo?0;Rh^02d];@0/k>c09ZJVP1RHV80GUiN07inOP33`l<0dM7A
0=CDe03GemL0dM7A0080b/[:01<0c<c<0=7Ad@3AdM40dM7A0<g=c@3De=@0dM7A0<c<c03AdM40c/k>
0<c<c03AdM40dm?C0<o?c`3=cLd0dM7A0<k>cP3:b/X0c<c<00@0dM7A00H0c/k>0<c<c03EeMD0alO7
0<o?c`3<c<`20=7Ad@050<c<c03AdM40dM7A0=7Ad@3<c<`01P3AdM400`3<c<`0dM7A0=7Ad@0R0?oo
o`00803oool@08F5Q@0307inOP22PX80QHF500P0QHF50P29RHT208F5Q@0508V9R@22PX80PH6107in
OP29RHT00`25QHD01`29RHT0SHf=09JFUP2@T900UiNG08Z:RP2PX:000P2WYjL03@2MWId0Y:BT0:f]
[@2RXZ80T92@08V9R@25QHD0RHV908^;R`25QHD0OWin08:2PP2;Rh/00P1nOWh01P22PX80PH6108V9
R@2;Rh/0SHf=08n?S`80QHF50P29RHT0202;Rh/0SHf=08^;R`1lO7`0QHF508:2PP21PH40OWin2025
QHD01021PH40OWin08V9R@2;Rh/208F5Q@0408V9R@2;Rh/0QHF507inOPT0QHF57P3oool@0;Vi^@03
0;Fe]@2o_kl0^KVi00T0^KVi00T0_;bl0;Vi^@2i^KT0^k^k0;Fe]@2g]kL0]KFe0;Ng]`2e]KD00P2i
^KT0702k^k/0]kNg0;no_`2e]KD0^;Rh0:^[Z`2n_[h0/K6a0:NWY`2QXJ40ZZZZ0;>c/`2YZJT0Y:BT
0;6a/@2e]KD0^KVi0;bl_02i^KT0]KFe0;^k^`32`/80]KFe0;^k^`2o_kl0]kNg0;Vi^@2l_;`20;^k
^`0=0;Fe]@2i^KT0^KVi0;Vi^@2l_;`0^k^k0;Vi^@2e]KD0_kno0;Vi^@2g]kL0]KFe0;no_`070;Vi
^@040;fm_@2e]KD0_kno0;bl_0<0^KVi00<0_;bl0;Vi^@2e]KD01P2i^KT00`2o_kl0^KVi0;Vi^@0N
0?oooa00dM7A00<0eMGE0=WIf@3AdM40203AdM402P3?cll0cLg=0=7Ad@3AdM40c/k>0<g=c@3Cdm<0
eMGE0<W9b@3<c<`20=7Ad@0K0<k>cP37alL0_kno0;^k^`2f][H0]kNg0:f][@2ATI40Q8B408b<S02E
UID0Shn?09:BTP2UYJD0`<300<c<c03?cll0c<c<0=7Ad@3EeMD0g=cL0=CDe03EeMD0gMgM0=WIf@3C
dm<0clo?0080c<c<00<0aLG50<c<c03AdM400P3?cll20<c<c0070<O7a`3Fe]H0fMWI0=7Ad@3Cdm<0
eMGE0=WIf@070=7Ad@040=_Kf`3EeMD0emOG0<c<c080dM7A00@0clo?0<c<c03AdM40eMGE1P3AdM40
0`3IfMT0dM7A0=7Ad@0R0?ooo`00803ooolA08F5Q@0308V9R@25QHD0QHF500L0QHF500D0OWin08V9
R@25QHD0QHF508:2PP0208F5Q@0808:2PP2;Rh/0QHF508F5Q@22PX80PH6107YjNP25QHD208V9R@03
0861P@29RHT0RHV90080RHV900@0PX:208^;R`22PX80PH610P25QHD03@1nOWh0QHF508V9R@2;Rh/0
PX:208^;R`25QHD0PX:208V9R@2;Rh/0PX:2092@T01nOWh00`25QHD207inOP0508F5Q@22PX80RHV9
08:2PP21PH401`25QHD00`29RHT0Rh^;08F5Q@0308F5Q@0808:2PP2;Rh/0QHF508:2PP1jNWX0RHV9
092@T02;Rh/608F5Q@0308^;R`22PX80PH6101h0oooo4@2i^KT00`2k^k/0^KVi0;Vi^@070;Vi^@03
0;Fe]@31`L40^KVi00<0^KVi00<0]KFe0;Vi^@2l_;`00`2i^KT01`2g]kL0/k>c0;no_`2i^KT0_;bl
0;Ng]`2k^k/00`2g]kL0102b/[80`/;20;Vi^@2g]kL20;Vi^@060;Fe]@2o_kl0^KVi0;bl_02e]KD0
`/;2102i^KT0102e]KD0`/;20;Fe]@2o_kl20;Vi^@80]KFe00L0_kno0;Fe]@32`/80^KVi0;>c/`2i
^KT0]KFe00H0^KVi00L0_;bl0;Vi^@2i^KT0]KFe0;Vi^@2e]KD0`/;20080^KVi00@0/k>c0;no_`2l
_;`0_;bl1P2i^KT00`2l_;`0^KVi0;Ng]`0N0?oooa40dM7A00<0c/k>0=7Ad@3AdM401`3AdM400`3E
eMD0e]KF0=7Ad@030=7Ad@030<c<c03AdM40c<c<00<0dM7A00L0dm?C0=SHf03IfMT0clo?0<g=c@3C
dm<0c/k>00<0bLW900@0clo?0=CDe03AdM40dm?C0P3AdM40103EeMD0fMWI0<o?c`3<c<`20=CDe080
dM7A00H0clo?0<O7a`3De=@0dm?C0=GEe@3IfMT20=7Ad@80eMGE00L0fMWI0=CDe03EeMD0dM7A0<o?
c`3AdM40c<c<00D0dM7A00H0clo?0<c<c03AdM40dM7A0<c<c03AdM420=CDe080dM7A00@0f=SH0=OG
e`3:b/X0c<c<1P3AdM400`3<c<`0dM7A0=?Cd`0R0?ooo`00803oool>08F5Q@0708V9R@2;Rh/0QHF5
08:2PP25QHD0PX:20861P@0808F5Q@0608:2PP25QHD0Rh^;08F5Q@1nOWh0O7al0P25QHD01029RHT0
PX:208F5Q@21PH4208F5Q@0608:2PP2;Rh/0OWin08V9R@2;Rh/0PX:20P25QHD01P21PH40QHF508F5
Q@25QHD0RHV907inOP80QHF500`0OWin08:2PP2;Rh/0PX:208F5Q@29RHT0Rh^;08V9R@1lO7`0QHF5
092@T02;Rh/208F5Q@0508^;R`25QHD0QHF508F5Q@29RHT00P25QHD04P22PX80Shn?08F5Q@29RHT0
Rh^;07inOP29RHT0Rh^;07inOP2@T900Shn?08F5Q@29RHT0Rh^;08F5Q@22PX80QHF507inOPD0QHF5
00D0RHV908^;R`25QHD0OWin08F5Q@0N0?ooo`l0^KVi00H0_;bl0;Vi^@2i^KT0_kno0;Vi^@2g]kL9
0;Vi^@050;Ng]`2l_;`0^KVi0;Fe]@2k^k/00P2i^KT0102k^k/0]KFe0;Ng]`2m_Kd20;Vi^@050;Fe
]@32`/80]KFe0;no_`2l_;`00P2i^KT00`2e]KD0]kNg0;Vi^@020;Vi^@070;^k^`2e]KD0_kno0;Vi
^@2e]KD0^k^k0<;2`P020;Vi^@050;Fe]@2l_;`0^k^k0;Fe]@2m_Kd00P2l_;`00`2i^KT0_Kfm0;bl
_0060;Vi^@0>0;Fe]@34a<@0]KFe0;Vi^@2l_;`0]KFe0;no_`2l_;`0]KFe0;bl_02n_[h0]KFe0;Vi
^@2l_;`30;Vi^@030;:b/P2o_kl0^KVi00@0^KVi00@0_;bl0;Vi^@2e]KD0_kno7P3oool>0=7Ad@07
0<o?c`3<c<`0dM7A0=7Ad@3IfMT0dM7A0=?Cd`090=7Ad@050=;BdP3<c<`0dM7A0=GEe@3Ng]h00P3A
dM40103>c/h0cLg=0=;BdP3Kfm/20=7Ad@80e=CD00<0eMGE0=OGe`3<c<`00P3AdM400`3<c<`0dm?C
0=7Ad@020=7Ad@070<k>cP3EeMD0fMWI0=7Ad@3EeMD0g=cL0=CDe0020=7Ad@0:0<[:bP3<c<`0c/k>
0=KFeP3Jf]X0b/[:0<c<c03AdM40f][J0<c<c0<0dM7A0140clo?0=7Ad@3AdM40e=CD0=7Ad@3<c<`0
clo?0<c<c03EeMD0emOG0<c<c03EeMD0b/[:0<W9b@3<c<`0clo?0<c<c0040=7Ad@030=WIf@3AdM40
dM7A0080dM7A00D0clo?0<c<c03AdM40eMGE0=WIf@0R0?ooo`00803oool>08F5Q@0307inOP25QHD0
QHF50080RHV900<0Shn?08F5Q@25QHD01`25QHD00`29RHT0OWin08F5Q@0208F5Q@0708V9R@25QHD0
QHF508F5Q@26QXH0NWYj08F5Q@0208V9R@0807YjNP29RHT0QHF507inOP25QHD0SHf=08^;R`29RHT5
08F5Q@090861P@29RHT0Rh^;08F5Q@1nOWh0QHF508V9R@25QHD0OWin0080QHF500H0RHV907inOP1l
O7`0PH6108F5Q@1nOWh208F5Q@0908:2PP25QHD0PX:208^;R`25QHD0PX:208^;R`25QHD0NWYj0080
QHF500@0OWin08F5Q@25QHD0OWin0P25QHD0101nOWh0QHF50861P@29RHT608F5Q@0308:2PP1nOWh0
Rh^;00<0QHF57P3oool>0;Vi^@070;Fe]@2o_kl0^KVi0;^k^`2i^KT0_[jn0;Fe]@080;Vi^@030;^k
^`2b/[80_kno0080^KVi00l0^k^k0;Vi^@2i^KT0^KVi0;^k^`2`/;00]KFe0;Vi^@2l_;`0/k>c0;no
_`2i^KT0]KFe0;no_`2k^k/00P2i^KT00`2e]KD0^KVi0;Vi^@020;Vi^@070;Ng]`2i^KT0_;bl0;Vi
^@2e]KD0_kno0;^k^`020;Fe]@090;no_`2i^KT0^k^k0;:b/P2k^k/0_Kfm0;Vi^@2b/[80_kno0080
^KVi01D0]kNg0;Vi^@2l_;`0^KVi0;Fe]@32`/80^KVi0;>c/`2o_kl0^KVi0;Fe]@2o_kl0^KVi0;^k
^`2o_kl0^KVi0;Fe]@2o_kl0]kNg0;^k^`2e]KD01P2i^KT00`2c/k<0`/;20;Vi^@020;Vi^Ah0oooo
3P3AdM401`3EeMD0fMWI0=7Ad@3>c/h0clo?0<W9b@3<c<`0203AdM400`3>c/h0dM7A0=WIf@020=7A
d@0B0<k>cP3AdM40dM7A0=7Ad@3?cll0dm?C0<c<c03?cll0cLg=0=SHf03GemL0dM7A0=GEe@3IfMT0
c<c<0<O7a`3?cll0c<c<103AdM403`3Cdm<0clo?0<c<c03AdM40eMGE0=WIf@3>c/h0c<c<0=GEe@3I
fMT0dM7A0<k>cP3AdM40g]kN0=_Kf`020=7Ad@070=WIf@3AdM40dM7A0=;BdP3AdM40c<c<0=7Ad@02
0=CDe00?0=7Ad@3Hf=P0fMWI0=7Ad@3EeMD0fMWI0=7Ad@3MgMd0fMWI0=7Ad@3EeMD0fMWI0=?Cd`3>
c/h0c<c<00H0dM7A00<0emOG0=CDe03AdM400P3AdM4R0?ooo`00803ooolA08F5Q@0308V9R@1nOWh0
QHF500T0QHF500<0PH6108F5Q@25QHD01P25QHD03@26QXH0OWin08F5Q@1nOWh0RHV908:2PP1nOWh0
Rh^;08F5Q@29RHT0PX:20861P@1nOWh00P25QHD01@29RHT0Rh^;08:2PP21PH40OWin0080RHV900H0
PH6108V9R@29RHT0Rh^;08F5Q@29RHT208^;R`0508F5Q@29RHT0QHF508F5Q@2;Rh/00P25QHD02029
RHT0OWin08J6QP29RHT0Rh^;07inOP25QHD0RHV90P25QHD01029RHT0Rh^;08V9R@2;Rh/208V9R@08
0861P@25QHD0QHF508F5Q@29RHT0Rh^;08F5Q@29RHT308F5Q@0608V9R@1nOWh0QHF508F5Q@22PX80
OWin7P3ooolB0;Vi^@030;Fe]@2o_kl0^KVi00P0^KVi00<0]kNg0;Vi^@2i^KT01P2i^KT0202k^k/0
/k>c0;Vi^@2e]KD0`L710;Fe]@2c/k<0_;bl0`2i^KT00`2m_Kd0]KFe0;Vi^@020;Vi^@070;bl_02i
^KT0/k>c0;Fe]@2o_kl0_;bl0;Ng]`020;Vi^@030;bl_02i^KT0^KVi0080_;bl00D0^KVi0;^k^`2e
]KD0^KVi0;bl_0020;Vi^@090;^k^`2b/[80`<300;no_`2l_;`0]KFe0;no_`2i^KT0]KFe0080^KVi
00H0_;bl0;Vi^@2l_;`0^KVi0;bl_02g]kL20;Vi^@030;Fe]@2i^KT0_;bl00D0^KVi00<0^k^k0;:b
/P2o_kl00P2i^KT00`2g]kL0oooo0?ooo`0L0?oooa40dM7A00<0clo?0=GEe@3IfMT02@3AdM400`3C
dm<0dM7A0=7Ad@060=7Ad@80clo?00/0dM7A0=GEe@3Fe]H0cLg=0=OGe`3<c<`0dM7A0<o?c`3AdM40
fm_K0=GEe@020=7Ad@080<o?c`3<c<`0dM7A0<o?c`3EeMD0emOG0<g=c@3Cdm<20<o?c`030<c<c03A
dM40clo?0080c<c<00D0dM7A0<k>cP3<c<`0dM7A0<c<c0020=7Ad@0A0<k>cP3AdM40e]KF0=OGe`3<
c<`0eMGE0=WIf@3?cll0c<c<0=7Ad@3?cll0c<c<0<o?c`3<c<`0clo?0<g=c@3Cdm<00P3AdM401@3<
c<`0clo?0<c<c03AdM40clo?00<0dM7A00<0c/k>0=7Ad@3IfMT00P3AdM400`3De=@0oooo0?ooo`0P
0?ooo`00803ooolA08F5Q@0307inOP29RHT0Rh^;00T0QHF500H0RHV908^;R`25QHD0PX:20861P@22
PX8308F5Q@80RHV900T0Rh^;08F5Q@25QHD0RHV907inOP25QHD0PX:207inOP2?Shl01025QHD03`1n
OWh0QHF508V9R@25QHD0PX:207YjNP2=SHd0Rh^;08:2PP1nOWh0QHF508:2PP1nOWh0RHV908^;R`02
08F5Q@0308:2PP21PH40QHF500@0QHF500h0RHV908:2PP1nOWh0PH6108F5Q@1nOWh0PH6108F5Q@1n
OWh0QHF508:2PP2;Rh/0OWin08V9R@<0QHF500D0Rh^;07inOP25QHD0QHF507inOP0608F5Q@030861
P@2=SHd0Shn?01h0oooo4@2i^KT00`2e]KD0^KVi0;bl_0090;Vi^@050;Fe]@2l_;`0^KVi0;Vi^@2g
]kL0102i^KT00`2k^k/0]kNg0;bl_0020;Vi^@070;^k^`2b/[80_kno0;Vi^@2c/k<0a<C40;Fe]@03
0;Vi^@080;Fe]@2o_kl0^k^k0;Fe]@2i^KT0/k>c0<71`@2i^KT20;Fe]@030;no_`2i^KT0/k>c0080
`/;20`2i^KT00`2g]kL0_kno0;Vi^@030;Vi^@0?0;^k^`2i^KT0_Kfm0;Ng]`2i^KT0]KFe0;Ng]`2i
^KT0]KFe0;no_`2e]KD0`/;20;Fe]@31`L40]KFe0080^KVi00D0_;bl0;Fe]@2o_kl0^KVi0;Fe]@06
0;Vi^@030;Ng]`2k^k/0^k^k01h0oooo4@3AdM400`3EeMD0clo?0<c<c0090=7Ad@050<[:bP3<c<`0
dM7A0=7Ad@3Cdm<0103AdM400`3>c/h0bLW90<c<c0020=7Ad@070<k>cP3AdM40fMWI0=7Ad@3GemL0
dM7A0<c<c0030=7Ad@0?0=GEe@3IfMT0c/k>0<c<c03AdM40f=SH0=GEe@37alL0e=CD0=GEe@3IfMT0
dM7A0=OGe`3EeMD0e=CD00<0dM7A00<0dm?C0=WIf@3AdM400`3AdM402P3>c/h0dM7A0=cLg03Cdm<0
dM7A0=GEe@3Cdm<0dM7A0=GEe@3IfMT20=CDe0030=GEe@3Fe]H0c<c<0080dM7A00D0c<c<0=GEe@3I
fMT0dM7A0=GEe@060=7Ad@030=?Cd`3<c<`0aLG50280oooo000P0?oooa80QHF500<0OWin08:2PP21
PH401P25QHD01P22PX80QHF507inOP22PX80PH6108V9R@80PX:20P25QHD01P29RHT0T92@08^;R`25
QHD0PX:20861P@80QHF500L0PX:208F5Q@1nOWh0RHV908^;R`22PX80Rh^;00@0QHF500@0Rh^;08f=
S@2;Rh/0O7al0P25QHD02021PH40PX:208F5Q@1nOWh0SHf=08F5Q@22PX80PH610P29RHT02025QHD0
Rh^;08:2PP21PH40PX:208F5Q@2=SHd0Shn?0P25QHD00`22PX80QHF508F5Q@0208F5Q@0307inOP25
QHD0QHF500D0QHF500<0PX:20861P@25QHD02025QHD00`1nOWh0QHF50?ooo`0M0?oooa80^KVi00<0
]KFe0;no_`2g]kL01`2i^KT01P2g]kL0]KFe0;no_`2g]kL0^k^k0;Fe]@@0^KVi0P2l_;`00`2o_kl0
^KVi0;Ng]`040;Vi^@050;:b/P2o_kl0_;bl0;Vi^@2l_;`0102i^KT01`2l_;`0^k^k0;Vi^@2e]KD0
_Kfm0;Vi^@2g]kL00P2i^KT0402b/[80`L710;no_`2i^KT0]kNg0;^k^`2e]KD0]kNg0;bl_02i^KT0
]kNg0;Vi^@2g]kL0`L710;^k^`2e]KD20;Vi^@060;Fe]@2i^KT0^KVi0;Vi^@2e]KD0_kno1@2i^KT0
0`2o_kl0^KVi0;Ng]`080;Vi^@80]KFe00<0_kno0?ooo`3oool0703ooolB0=7Ad@030=GEe@3IfMT0
dm?C00L0dM7A00H0d];B0=GEe@3IfMT0dm?C0<k>cP3=cLd30=7Ad@060<o?c`3:b/X0c<c<0=WIf@3A
dM40dm?C1@3AdM40103GemL0c<c<0=7Ad@3<c<`40=7Ad@80c<c<00D0alO70=KFeP3Jf]X0dM7A0=?C
d`030=7Ad@0?0=GEe@3IfMT0dM7A0=?Cd`3>c/h0b/[:0=;BdP3<c<`0dM7A0=?Cd`3AdM40d];B0=GE
e@35aLD0c<c<0080dM7A00H0c<c<0=7Ad@3AdM40dM7A0=GEe@3IfMT50=7Ad@030=WIf@3AdM40dm?C
00P0dM7A00<0c<c<0=GEe@3IfMT08P3oool00200oooo3`25QHD02029RHT0Rh^;08V9R@25QHD0PX:2
0861P@22PX80PH610`25QHD03@29RHT0Rh^;08F5Q@25QHD0OWin08F5Q@1lO7`0PH6108J6QP1lO7`0
PH6108V9R@1nOWh00`25QHD00`22PX80PH6108F5Q@0207inOP0308F5Q@29RHT0Rh^;0080QHF50P29
RHT00`21PH40RHV908F5Q@0508F5Q@<0OWin00P0QHF508V9R@25QHD0RHV908F5Q@1nOWh0PX:208F5
Q@@0OWin0P29RHT01@2;Rh/0QHF508:2PP1jNWX0Rh^;0080QHF500<0RHV908n?S`25QHD01025QHD0
1@1nOWh0PH6108:2PP21PH40OWin00<0QHF500D0OWin08F5Q@1nOWh0QHF507inOP0208F5QAh0oooo
402i^KT01`2l_;`0^KVi0;Vi^@2i^KT0]kNg0;Vi^@2g]kL0102i^KT01`2l_;`0^KVi0;Vi^@2e]KD0
_kno0;Fe]@2m_Kd00P2k^k/0102m_Kd0^k^k0;:b/P2o_kl30;Vi^@0<0;Ng]`2i^KT0]KFe0;^k^`2o
_kl0^KVi0;bl_02i^KT0_kno0;Vi^@2l_;`0]kNg0P2i^KT00`2o_kl0^KVi0;Vi^@020;Vi^@<0^k^k
00@0_kno0;Vi^@2i^KT0^k^k0P2e]KD00`2o_kl0^KVi0;Fe]@030;^k^`030;no_`2i^KT0_;bl0080
^KVi00<0/k>c0<;2`P2i^KT00P2i^KT00`2n_[h0]KFe0;Vi^@030;Vi^@060;Fe]@2g]kL0^KVi0;Ng
]`2e]KD0_kno0P2i^KT01`2e]KD0_kno0;Fe]@2o_kl0]KFe0;no_`2i^KT07P3oool?0=7Ad@030<o?
c`3<c<`0clo?0080dM7A00<0dm?C0=7Ad@3Cdm<00`3AdM403P3?cll0c<c<0=7Ad@3AdM40eMGE0=WI
f@3Fe]H0fm_K0<o?c`3Ng]h0fm_K0<k>cP3AdM40fMWI0`3AdM403`3Cdm<0dM7A0=GEe@3MgMd0fMWI
0<o?c`3<c<`0dM7A0=WIf@3?cll0cLg=0=?Cd`3?cll0dM7A0=WIf@040=7Ad@<0gMgM00T0fMWI0<o?
c`3AdM40c/k>0<c<c03EeMD0fMWI0=7Ad@3EeMD00`3MgMd00`3GemL0clo?0<c<c0020=7Ad@070=SH
f03De=@0dM7A0=7Ad@3?cll0bLW90<c<c0040=7Ad@060=GEe@3Cdm<0dM7A0=?Cd`3EeMD0fMWI0P3A
dM401`3EeMD0fMWI0=GEe@3IfMT0eMGE0=WIf@3AdM408P3oool00200oooo3`25QHD01`22PX80Rh^;
07inOP2;Rh/0RHV908F5Q@29RHT01025QHD0201nOWh0QHF508F5Q@25QHD0PX:20861P@29RHT0QHF5
0`29RHT00`2;Rh/0RHV908^;R`0208F5Q@0308V9R@25QHD0QHF50080QHF50P29RHT0102;Rh/0QHF5
08:2PP1jNWX308V9R@T0QHF50P29RHT01@2;Rh/0QHF508F5Q@25QHD0RHV900D0QHF500D0PX:208V9
R@2;Rh/0QHF508V9R@0408F5Q@0307inOP25QHD0QHF500<0QHF500P0RHV908^;R`21PH40QXJ60861
P@25QHD0RHV908F5Q@80RHV900<0PH6108F5Q@25QHD00`25QHDN0?ooo`l0^KVi00P0]KFe0<;2`P2e
]KD0_;bl0;^k^`2e]KD0^k^k0;Fe]@<0^KVi00<0]KFe0;no_`2i^KT00P2i^KT00`2g]kL0^k^k0;Fe
]@020;^k^`040;Fe]@2l_;`0^KVi0;bl_080^KVi00<0^k^k0;Fe]@2i^KT0102i^KT02032`/80^KVi
0;Vi^@2c/k<0`L710;Fe]@2i^KT0_kno2P2i^KT01@2l_;`0^KVi0;Vi^@2i^KT0^k^k00D0^KVi00L0
]KFe0;Vi^@32`/80^KVi0;^k^`2e]KD0_kno0080^KVi00<0]KFe0;no_`2i^KT0102i^KT0102l_;`0
/k>c0;^k^`2c/k<40;Vi^@030;bl_02g]kL0^KVi00@0^KVi7P3oool?0=7Ad@80e=CD00H0eMGE0<c<
c03>c/h0c<c<0<k>cP3<c<`30=7Ad@030=GEe@3IfMT0dM7A0080dM7A00<0dm?C0<k>cP3<c<`00P3>
c/h0103:b/X0c<c<0<o?c`3<c<`20=7Ad@030<k>cP3<c<`0dM7A0080dM7A0P3?cll0203De=@0dM7A
0=7Ad@3Hf=P0e]KF0<[:bP3?cll0fMWI203AdM420<o?c`050<c<c03AdM40dM7A0=7Ad@3>c/h01@3A
dM401`3De=@0clo?0=CDe03AdM40c/k>0<c<c03IfMT00P3AdM400`3EeMD0fMWI0=7Ad@030=7Ad@03
0<o?c`3<c<`0clo?0080clo?00H0dM7A0<o?c`3AdM40clo?0<g=c@3Cdm<50=7AdB80oooo003o0?oo
ol<0oooo003o0?oool<0oooo003o0?oool<0oooo003o0?oool<0oooo003o0?oool<0oooo001O0?oo
o`900000R03oool2@00008P0oooo0T00001=0?ooo`00H@3oool00d000000oooo0?ooo`270?ooo`03
@000003oool0oooo08L0oooo00=000000?ooo`3oool0BP3oool00440oooo1D0000020?ooo`03@000
003oool0oooo0080oooo00=000000?ooo`3oool01@3oool3@0000080oooo0T0000030?ooo`=00000
1@3oool00d000000oooo0?ooo`1R0?ooo`=000000`3oool3@0000080oooo00=000000?ooo`3oool0
1@3oool3@0000080oooo0T0000030?ooo`=000001@3oool00d000000oooo0?ooo`1R0?ooo`900000
103oool00d000000oooo0?ooo`020?ooo`03@000003oool0oooo00D0oooo0d0000020?ooo`900000
0`3oool3@00000D0oooo00=000000?ooo`3oool0A03oool004<0oooo00M000000?ooo`3oool0oooo
@000003ooom000000080oooo00=000000?oood0000001@3oool01T000000oooo0?oood000000oooo
@00000@0oooo00A000000?ooo`3ooom00000JP3oool00d000000oooo0?ooo`040?ooo`06@000003o
ool0oooo@000003ooom000001@3oool01T000000oooo0?oood000000oooo@00000@0oooo00A00000
0?ooo`3ooom00000K03oool01T000000oooo0?oood000000oooo@0000080oooo00=000000?oood00
00001@3oool01T000000oooo0?oood000000oooo@00000@0oooo00A000000?ooo`3ooom00000C03o
ool004<0oooo00M000000?ooo`3oool0oooo@000003ooom000000080oooo00=000000?oood000000
1@3oool01D000000oooo0?oood000000oooo00=000000P3oool014000000oooo0?oood00001[0?oo
o`04@000003oool0oooo0?ooo`A0000000@0oooo@000003ooom000001@3oool01D000000oooo0?oo
od000000oooo00=000000P3oool014000000oooo0?oood00001[0?ooo`07@000003oool0oooo0?oo
od000000oooo@00000020?ooo`03@000003ooom0000000D0oooo00E000000?ooo`3ooom000000?oo
o`03@0000080oooo00A000000?ooo`3ooom00000C03oool004<0oooo00=000000?ooo`3oool00P3o
ool01d000000oooo0?ooo`3ooom000000?oood0000001P3oool3@00000040?oood0000100000@000
00<0oooo0d00001[0?ooo`07@000003oool0oooo0?oood000000oooo@00000020?ooo`03@000003o
oom0000000H0oooo0d000000103ooom00000@000040000030?ooo`=00000K03oool01T000000oooo
0?oood000000oooo@0000080oooo00=000000?oood0000001P3oool3@00000040?oood0000100000
@00000<0oooo0d00001<0?ooo`00@`3oool01d000000oooo0?ooo`3ooom000000?oood0000000P3o
ool00d000000oooo@00000080?ooo`03@000003oool0oooo0780oooo00=000000?oood0000000`3o
ool2@0000080oooo00=000000?oood000000203oool00d000000oooo0?ooo`1b0?ooo`03@000003o
oom000000080oooo00=000000?oood0000000P3oool00d000000oooo@00000080?ooo`03@000003o
ool0oooo05@0oooo00120?ooo`900000103oool00d000000oooo0?ooo`020?ooo`03@000003oool0
oooo00H0oooo0T00001e0?ooo`03@000003oool0oooo00<0oooo00E000000?ooo`3oool0oooo@000
00080?ooo`900000M@3oool00d000000oooo0?ooo`020?ooo`03@000003oool0oooo0080oooo00=0
00000?ooo`3oool01P3oool2@00005H0oooo003o0?oool<0oooo003o0?oool<0oooo003o0?oool<0
oooo003o0?oool<0oooo003o0?oool<0oooo003o0?oool<0oooo003o0?oool<0oooo003o0?oool<0
oooo003o0?oool<0oooo003o0?oool<0oooo003o0?oool<0oooo003o0?oool<0oooo003o0?oool<0
oooo003o0?oool<0oooo003o0?oool<0oooo003o0?oool<0oooo003o0?oool<0oooo003o0?oool<0
oooo000P0?ooo`0:09fMW@2NWYh0XJ6Q09NGU`2NWYh0VIVI09^KV`2YZJT0WinO07IfMP80Rh^;00<0
S8b<08N7Q`2<S8`00`2<S8`02P2DU9@0=3@d0:j^[P2BTY80Ogmo08J6QP2<S8`0QhN707]kN`2=SHd2
08R8R00807alO022PX80S8b<08N7Q`2?Shl0Q8B408N7Q`26QXH208N7Q`0507MgM`2@T900QhN708N7
Q`2CTi<01@2=SHd01P28R8P0PX:208N7Q`2<S8`0T92@08:2PP<0QhN701D0QXJ608N7Q`27QhL0R8R8
08N7Q`24Q8@0RHV908N7Q`28R8P0QhN708J6QP2VYZH0Z:RX04=3@`2LW9`0PX:208b<S027QhL0O7al
08:2PP2:RXX01026QXH01P2ATI40RXZ:08F5Q@2=SHd0UiNG09FEU@80T92@0100QXJ609JFUP21PH40
QHF507QhN01oOgl0QHF50820P01mOGd0Zj^[09:BTP1NGUh0WinO0:JVYP2UYJD0UiNG7P3oool02P2L
W9`0WIfM0:6QX@2FUYH0WIfM09VIV@2KVi/0ZJVY09nOW`1fMWH208^;R`0308b<S027QhL0S8b<00<0
S8b<00X0U9BD03<c<`2_[jl0TY:B07moO`26QXH0S8b<08N7Q`1kNg/0SHf=0P28R8P0201lO7`0PX:2
08b<S027QhL0Shn?08B4Q027QhL0QXJ60P27QhL01@1gMgL0T92@08N7Q`27QhL0Ti>C00D0SHf=00H0
R8R80861P@27QhL0S8b<092@T021PH4308N7Q`0E08J6QP27QhL0QhN708R8R027QhL0Q8B408V9R@27
QhL0R8R808N7Q`26QXH0YZJV0:RXZ012@T80WIfM08:2PP2<S8`0QhN707alO022PX80RXZ:00@0QXJ6
00H0TI6A08Z:RP25QHD0SHf=09NGU`2EUID2092@T00@08J6QP2FUYH0PH6108F5Q@1hN7P0Ogmo08F5
Q@20P800OGem0:b/[02BTY80GEeM09nOW`2VYZH0YJFU09JFUQh0oooo00X0LW9b07=cL`1fMWH0L71`
07=cL`1aLG40LW9b07QhN01cLg<0GemO0`1VIVH00`1UIFD0IVIV06IVIP0206IVIP0:06i^KP0h>3P0
Kfm_06QXJ01PH600HV9R06ATI01SHf<0G5aL06EUI@80Hf=S00P0GEeM05mOG`1TI6@0Hf=S06MWI`1R
HV80Hf=S069RHP80Hf=S00D0Fe]K06IVIP1SHf<0Hf=S06UYJ@0506MWI`0606ATI01QHF40Hf=S06EU
I@1XJ6P0HF5Q0`1SHf<00`1RHV80Hf=S06=SH`0206=SH`03065QH@1TI6@0Hf=S0080Hf=S00/0HV9R
079bLP1fMWH0@41006QXJ01OGel0I6AT06=SH`1MGEd0GemO06=SH`04069RHP0606QXJ01UIFD0HV9R
06IVIP1/K6`0Jf][0P1YJFT0401TI6@0Jf][061PH01RHV80FUYJ05eMG@1PH600GUiN05aLG01dM7@0
Jf][04m?C`1/K6`0MWIf07MgM`1`L70R0?ooo`00803oool0302MWId0WinO09nOW`2NWYh0XJ6Q09VI
V@2EUID0Xj>S09NGU`24Q8@0NGUi08^;R`@0S8b<01<0Rh^;08b<S02[Zj/0?Shn09bLW02@T900PH61
08F5Q@23Ph<0QhN70861P@28R8P0S8b<08N7Q`22PX80PH6108>3P`2<S8`0Shn?00<0QhN701H0P820
08Z:RP1oOgl0PX:208f=S@28R8P0SHf=092@T02<S8`0Rh^;08f=S@2CTi<0QHF508f=S@22PX80RXZ:
08f=S@27QhL0RXZ:08F5Q@27QhL0QXJ61027QhL208J6QP0908>3P`27QhL0QhN708N7Q`2FUYH0/;2`
04=3@`1`L700YJFU0080QhN700D0O7al08:2PP26QXH0QXJ608^;R`0208J6QP0608n?S`27QhL0S8b<
08N7Q`2EUID0TY:B0P2ATI40102@T900S8b<0820P026QXH207inOP0:07emO@25QHD0Shn?09:BTP1k
Ng/0MgMg08b<S02VYZH0XJ6Q09fMWAh0oooo00/0W9bL0:2PX02HV9P0VYZJ0:FUY@2RXZ80Vi^K0:2P
X02LW9`0TI6A08F5Q@0208b<S00308V9R@2<S8`0S8b<0080Rh^;0180WIfM04Q8B02[Zj/0TI6A0820
P025QHD0PX:20820P01nOWh0QXJ608V9R@27QhL0QHF508R8R023Ph<0RHV908n?S`25QHD208J6QP05
07]kN`23Ph<0Ph>308>3P`29RHT00P28R8P0202;Rh/0R8R808F5Q@26QXH0Shn?08>3P`2=SHd0QHF5
0P28R8P01P24Q8@0Rh^;08J6QP27QhL0QXJ608N7Q`80R8R80P27QhL04@26QXH0OWin08R8R026QXH0
QhN708b<S02OWil0D51@06UYJ@2FUYH0RXZ:08N7Q`1lO7`0PX:208>3P`20P800RHV90080R8R800H0
Shn?08F5Q@2<S8`0QhN708n?S`2=SHd208Z:RP0@092@T02<S8`0P82008J6QP23Ph<0R8R808:2PP28
R8P0YjNW0:^[Z`1bLW80L71`08b<S02VYZH0WIfM09VIVAh0oooo00/0LW9b07EeM@1ZJVX0KVi^07]k
N`1nOWh0MgMg075aL@1gMgL0Ng]k06m_K`0206MWI`0306=SH`1VIVH0IVIV0080IFEU0180I6AT051@
D01lO7`0J6QX061PH01RHV80GUiN05QHF01KFe/0GUiN061PH01SHf<0IVIV06YZJP1PH600HF5Q06QX
J01PH602069RHP0705MGE`1HF5P0IVIV061PH01OGel0Hf=S05mOG`02065QH@0705eMG@1LG5`0I6AT
05mOG`1WIfL0IVIV069RHP0205iNGP0406IVIP1TI6@0Hf=S069RHP@0Hf=S0180I6AT069RHP1IFET0
Hf=S069RHP1SHf<0G5aL061PH01FEUH0ADE505UIF@1WIfL0Hf=S05eMG@1OGel0GEeM05UIF@1QHF42
06EUI@0606QXJ01PH600IVIV06=SH`1QHF40HV9R0P1OGel0401YJFT0IVIV061PH01RHV80IVIV06][
J`1SHf<0IVIV08V9R@2;Rh/0DU9B05=CD`1RHV80MWIf06m_K`1^KVhR0?ooo`00803oool0102MWId0
WinO09fMW@2MWId20:>SX`0V09fMW@2LW9`0XZ:R09VIV@22PX80MWIf08^;R`2<S8`0RXZ:08f=S@2;
Rh/0R8R80:NWY`1^KVh0CTi>0;^k^`29RHT0Q8B407inOP26QXH0QhN708:2PP27QhL0QXJ608R8R026
QXH0OGem08J6QP2HV9P0Q8B408J6QP23Ph<0Ogmo0861P@24Q8@0PX:208N7Q`2=SHd208^;R`0=08f=
S@24Q8@0QhN708f=S@27QhL0SXj>08N7Q`2;Rh/0R8R808N7Q`28R8P0RXZ:08:2PP0608N7Q`0308F5
Q@22PX80QhN700<0QhN70140UYJF0861P@1BDU80EEEE0:^[Z`27QhL0PX:20820P01mOGd0PX:208b<
S022PX80SXj>08n?S`26QXH0S8b<08J6QP0208b<S00<08n?S`2<S8`0Shn?08N7Q`23Ph<0Q8B408N7
Q`24Q8@0PH6108V9R@2IVIT0YJFU0P1cLg<01022PX80Zj^[0:>SX`2GUiLN0?ooo`0<09^KV`2LW9`0
W9bL09fMW@2NWYh0Vi^K09VIV@2LW9`0XJ6Q0::RXP2FUYH0Q8B40P2;Rh/05@28R8P0Rh^;08^;R`26
QXH0Y:BT08V9R@1:BTX0V9RH08J6QP25QHD0NGUi08>3P`2:RXX0RHV908Z:RP26QXH0R8R808J6QP1m
OGd0P82009:BTP0208J6QP0F0820P01nOWh0PX:207YjNP1iNGT0Ogmo08>3P`28R8P0RHV908^;R`24
Q8@0QhN708V9R@24Q8@0RXZ:08B4Q02>SXh0Shn?08j>SP2;Rh/0SXj>08F5Q@80QhN700@0R8R808N7
Q`27QhL0QhN70P26QXH208N7Q`0E08R8R027QhL0S8b<09:BTP2DU9@0FEUI08f=S@20P800OWin08N7
Q`20P800PX:208b<S01nOWh0RXZ:08n?S`29RHT0SXj>08R8R02>SXh0S8b<00<0TY:B00T0QXJ608>3
P`25QHD0R8R808F5Q@24Q8@0UYJF09RHV02LW9`00P1lO7`01023Ph<0Y:BT0:BTY02KVi/N0?ooo`0<
071`L01_Kfl0LW9b07AdM01_Kfl0Jf][06i^KP1cLg<0MWIf07inOP23Ph<0L71`0P1UIFD08@1RHV80
I6AT06EUI@1QHF40Kfm_08B4Q00j>SX0B4Q8061PH01SHf<0EUIF05eMG@1WIfL0JFUY06IVIP1RHV80
Hf=S069RHP1MGEd0F5QH069RHP1UIFD0HV9R05aLG01NGUh0H61P059BDP1CDe<0EEEE05MGE`1PH600
HF5Q06ATI00206=SH`05061PH01NGUh0H61P05iNGP1YJFT00P1^KVh01@1WIfL0Jf][06IVIP1SHf<0
I6AT00D0Hf=S00<0IfMW06=SH`1SHf<00P1SHf<00`1LG5`0P8200:VYZ@0204Q8B00805QHF01KFe/0
J6QX065QH@1OGel0I6AT05YJFP1PH60206MWI`0F06UYJ@1WIfL0JFUY06IVIP1/K6`0L71`06a/K01T
I6@0HV9R06=SH`1TI6@0Hf=S06ATI01fMWH0JVYZ06UYJ@1ZJVX0IFEU061PH01^KVh0N7Qh07IfMR80
oooo000P0?ooo`0I09fMW@2NWYh0Y:BT09nOW`2NWYh0XZ:R09VIV@2WYjL0W9bL09^KV`2GUiL0WinO
09FEU@1gMgL0QHF508R8R022PX80RXZ:08f=S@2YZJT0SHf=05UIF@2FUYH0QhN707UiN@0208:2PP03
08N7Q`1lO7`0SHf=0080QhN70P21PH401@27QhL0Ph>308R8R023Ph<0Rh^;00<0P8200P1iNGT01P25
QHD0S8b<0820P028R8P0QhN708n?S`80QhN700h0Rh^;096AT@2CTi<0QhN709^KV`2<S8`0Q8B4092@
T02:RXX0T92@08F5Q@2<S8`0QhN708B4Q0<0QhN700T0Ph>308^;R`23Ph<0S8b<0:FUY@2YZJT0@T92
08^;R`2EUID01P27QhL0602:RXX0QhN708f=S@26QXH0Rh^;09FEU@2>SXh0Shn?08^;R`2<S8`0QhN7
0861P@2EUID0T92@09BDU02;Rh/0Vi^K06a/K02OWil0LG5a0861P@2QXJ40TI6A09^KVah0oooo01T0
W9bL09nOW`2PX:00X:2P09nOW`2MWId0UiNG0:RXZ02OWil0XZ:R09^KV`2TY:@0Vi^K08N7Q`2;Rh/0
S8b<08F5Q@2=SHd0T92@0:j^[P2DU9@0GemO09NGU`29RHT0Ng]k0080PX:200<0RXZ:0820P029RHT0
0P27QhL03`24Q8@0R8R808^;R`20P800PH6107moO`2;Rh/0Q8B408^;R`28R8P0P82007alO025QHD0
RHV907]kN`0207emO@0308Z:RP27QhL0QhN70080RHV900d0S8b<08B4Q02GUiL0Shn?08>3P`2>SXh0
RHV908j>SP26QXH0SXj>08b<S027QhL0R8R80080S8b<00T0QXJ608j>SP26QXH0RHV909FEU@2QXJ40
DU9B08j>SP2<S8`00P2;Rh/00`27QhL0QHF508N7Q`0208b<S00<08Z:RP2@T900RHV908f=S@2EUID0
SXj>08n?S`2>SXh0S8b<08f=S@23Ph<0V9RH0P2UYJD02@2JVYX0YjNW07EeM@2YZJT0Kfm_07inOP2Y
ZJT0W9bL09jNWP0N0?ooo`05079bLP1eMGD0LG5a07MgM`1eMGD00P1_Kfl04@1iNGT0N7Qh07emO@1f
MWH0Ng]k07MgM`1eMGD0Jf][06YZJP1VIVH0J6QX06a/K01kNg/0MWIf05IFEP1YJFT0IVIV00<0GemO
0140IfMW065QH@1PH600HV9R06=SH`1UIFD0JVYZ06QXJ01KFe/0FEUI05]KF`1TI6@0IFEU06e]K@1Z
JVX0IFEU05mOG`02061PH00E05MGE`1CDe<0De=C05mOG`1SHf<0I6AT069RHP1LG5`0HF5Q05iNGP1X
J6P0Jf][065QH@1UIFD0I6AT06EUI@1TI6@0JFUY06YZJP1UIFD0I6AT0080JVYZ00T0IFEU06UYJ@1U
IFD0HF5Q05]KF`1]KFd0FUYJ06=SH`1MGEd00P1ZJVX0101SHf<0H61P06=SH`1ZJVX206QXJ00F06a/
K01XJ6P0J6QX06a/K01XJ6P0JFUY06][J`1VIVH0Jf][06ATI01_Kfl0R8R808>3P`1nOWh0Ogmo06IV
IP1lO7`0F5QH05YJFP1oOgl0OGem07EeMB80oooo000P0?ooo`0K09fMW@2PX:00XZ:R0:6QX@2OWil0
X:2P09nOW`2KVi/0XZ:R09nOW`2SXj<0XJ6Q09RHV028R8P0O7al08B4Q028R8P0RHV908f=S@2LW9`0
ZZZZ071`L01eMGD0S8b<07alO021PH40OGem0080QhN700X0R8R808N7Q`22PX80QhN708b<S022PX80
R8R808>3P`21PH40SHf=0P27QhL02P26QXH0Ph>307emO@1iNGT0QhN708B4Q01kNg/0RHV908:2PP2=
SHd308N7Q`0408f=S@2:RXX0TI6A08^;R`80S8b<01l0RHV908f=S@25QHD0SHf=08V9R@28R8P0QhN7
08n?S`28R8P0QhN708^;R`27QhL0Q8B408b<S02UYJD0Q8B405eMG@21PH40Shn?08Z:RP26QXH0Q8B4
08Z:RP2=SHd0RXZ:08^;R`2=SHd0RHV908f=S@2ATI40U9BD0080Shn?00l0QhN708Z:RP23Ph<0WinO
0:RXZ02NWYh0Xj>S09BDU02ATI40Y:BT06UYJ@2>SXh0XZ:R09fMW@2HV9P07P3oool0:@2LW9`0X:2P
0:6QX@2MWId0VYZJ09nOW`2SXj<0VYZJ09fMW@2HV9P0XZ:R0:FUY@2IVIT0UiNG08b<S028R8P0Rh^;
08f=S@2>SXh0TI6A0:2PX027QhL0Rh^;08j>SP20P800QhN70820P024Q8@0QhN708b<S027QhL0OWin
0820P029RHT0OWin08:2PP23Ph<0P82008b<S027QhL0R8R80080QXJ600P0QhN707inOP1oOgl0P820
07alO02=SHd0Ph>308V9R@<0QhN700`0RHV908N7Q`2BTY80PX:208R8R02>SXh0RHV908f=S@2:RXX0
T92@08Z:RP2;Rh/208b<S00@08J6QP25QHD0RXZ:08B4Q026QXH0RHV909FEU@2CTi<0Ng]k07emO@2=
SHd0Rh^;08V9R@27QhL0S8b<08j>SP80SHf=00D0SXj>08V9R@2>SXh0SHf=092@T00208n?S`0?08N7
Q`22PX80NWYj09^KV`2TY:@0WYjN08n?S`1nOWh0PX:20:RXZ01[Jf/0V9RH0:BTY02KVi/0VIVI01h0
oooo00l0LW9b07AdM01dM7@0Kfm_06e]K@1cLg<0NWYj071`L01_Kfl0JVYZ07EeM@1jNWX0Lg=c07mo
O`1iNGT00P1YJFT04@1ZJVX0J6QX05iNGP1XJ6P0P82007QhN01YJFT0I6AT06QXJ01QHF40G5aL06=S
H`1WIfL0I6AT05]KF`1HF5P0H61P0080FUYJ00<0H61P05eMG@1SHf<00`1SHf<02@1VIVH0K6a/069R
HP1EEED0Fe]K05aLG01XJ6P0HF5Q061PH00306=SH`0>061PH01RHV80JVYZ05UIF@1QHF40J6QX06EU
I@1VIVH0JVYZ06a/K01VIVH0J6QX06YZJP1TI6@2065QH@0<069RHP1PH600IFEU065QH@1KFe/0OWin
07QhN01GEeL0IFEU06IVIP1WIfL0IFEU0P1XJ6P01`1YJFT0JVYZ06QXJ01UIFD0J6QX06=SH`1VIVH0
0P1YJFT03`1UIFD0F5QH05EEE@1XJ6P0L71`07AdM01FEUH0C4a<05EEE@1hN7P0FUYJ07EeM@1hN7P0
LG5a079bLP0R0?ooo`00803oool02@2MWId0Xj>S09fMW@2EUID0Xj>S09NGU`2VYZH0Vi^K09NGU`02
0:6QX@0L09fMW@2SXj<0WIfM08j>SP20P800O7al08Z:RP29RHT0S8b<09^KV`2WYjL0MGEe08B4Q026
QXH0Ph>307emO@21PH40Ph>308N7Q`28R8P0PX:207emO@22PX80QhN708>3P`27QhL0OGem096AT@80
QhN700h0QXJ608N7Q`29RHT0N7Qh07EeM@28R8P0O7al08V9R@1mOGd0RXZ:08J6QP2?Shl0QhN708R8
R080RXZ:00T0QhN708b<S02;Rh/0Rh^;08b<S02;Rh/0TI6A08^;R`29RHT00P2;Rh/308R8R00808N7
Q`29RHT0QhN708Z:RP2[Zj/0Rh^;06][J`2=SHd208^;R`0808N7Q`2?Shl0T92@08f=S@2;Rh/0SXj>
08V9R@2BTY8308n?S`0@08J6QP2<S8`0PH6108j>SP2XZ:P0TI6A0:VYZ@2CTi<0QXJ608^;R`2JVYX0
N7Qh0:ZZZP2MWId0Xj>S09FEUAh0oooo01P0W9bL0:JVYP2UYJD0UiNG0:JVYP2IVIT0XJ6Q09ZJVP2H
V9P0Y:BT0:JVYP2IVIT0XZ:R0:2PX02MWId0VYZJ08^;R`2?Shl0T92@09>CT`2HV9P0Y:BT07moO`27
QhL208Z:RP0L08>3P`27QhL0PX:20820P01oOgl0OWin07YjNP1fMWH0Ng]k07moO`22PX80NWYj08n?
S`28R8P0S8b<08^;R`2<S8`0Shn?0861P@1kNg/0R8R807inOP28R8P0N7Qh08B4Q01lO7`0RXZ:08N7
Q`80R8R80P24Q8@01`29RHT0QXJ608J6QP27QhL0QHF508f=S@2:RXX00P26QXH00`28R8P0QHF508N7
Q`0208N7Q`0708J6QP27QhL0QXJ609bLW02FUYH0U9BD08V9R@0208J6QP0808B4Q02>SXh0Shn?08f=
S@2:RXX0SHf=08V9R@2EUID209:BTP0A08n?S`20P800PH6106m_K`24Q8@0/K6a09BDU02TY:@0T92@
08N7Q`2=SHd0Shn?06e]K@2a/K40W9bL0:BTY02HV9P07P3oool04P1bLW80NWYj07inOP1bLW80NWYj
079bLP1`L700LW9b075aL@1iNGT0O7al06i^KP1eMGD0N7Qh08:2PP2:RXX0MWIf06i^KP80L71`0180
JFUY079bLP1/K6`0IVIV06UYJ@1[Jf/0IfMW06QXJ01NGUh0F5QH05IFEP1JFUX0F5QH04e=C@1@D500
FEUI05YJFP1GEeL206=SH`<0JVYZ01X0KFe]06UYJ@1PH600HF5Q05mOG`1QHF40EEEE05YJFP1DE5@0
GUiN069RHP1SHf<0HV9R05eMG@1NGUh0HF5Q05eMG@1NGUh0GemO05aLG01SHf<0I6AT061PH01OGel0
HF5Q05mOG`<0HV9R00L0GemO06=SH`1NGUh0H61P07]kN`2BTY80H61P0080GUiN00P0GemO06IVIP1W
IfL0IfMW06ATI01VIVH0IFEU06i^KP80K6a/00H0JFUY05YJFP1GEeL0A4A405MGE`1oOgl206m_K`80
IFEU00L0J6QX05aLG01>CTh0OWin079bLP1hN7P0M7Ad0280oooo000P0?ooo`0=09fMW@2SXj<0XZ:R
09^KV`2UYJD0UiNG0:6QX@2IVIT0VYZJ0:BTY02SXj<0XJ6Q09jNWP020:6QX@0:09VIV@29RHT0QHF5
08j>SP2?Shl0SXj>09nOW`2HV9P0MWIf0;Jf]P80QXJ600D0P82008:2PP21PH40P82007UiN@0407em
O@050861P@1mOGd0S8b<08f=S@2>SXh00P2:RXX00`2?Shl0PH6107IfMP020861P@0D08>3P`1oOgl0
QHF507moO`27QhL0R8R808b<S028R8P0SHf=08:2PP28R8P0RHV908N7Q`2>SXh0SHf=08Z:RP27QhL0
SHf=08V9R@22PX8508R8R00>08f=S@21PH40T92@0:n_[`2PX:00QhN708V9R@28R8P0QhN708^;R`2A
TI40SXj>08V9R@2=SHd4092@T00A08Z:RP22PX80LW9b07EeM@2CTi<0Y:BT08Z:RP2=SHd0T92@08F5
Q@2JVYX0PX:207]kN`2e]KD0VYZJ0:BTY02LW9`07P3oool03@2LW9`0WinO09fMW@2JVYX0Z:RX09VI
V@2VYZH0VYZJ09JFUP2PX:00Vi^K0:6QX@2OWil00P2QXJ402P2IVIT0UIFE09BDU02FUYH0UiNG09>C
T`2JVYX0Vi^K08J6QP2KVi/208F5Q@0>07inOP1oOgl0PH610861P@1cLg<0M7Ad07emO@21PH40OGem
07moO`1kNg/0R8R808V9R@2<S8`208Z:RP0B08n?S`21PH40MgMg07moO`1kNg/0OGem07]kN`25QHD0
Ng]k0820P01lO7`0PX:20820P026QXH0OWin0820P022PX80P8200P29RHT01@26QXH0OGem08F5Q@27
QhL0OWin00@0P82002@0PH6108V9R@1mOGd0Q8B409ZJVP2IVIT0QXJ608N7Q`28R8P0QhN708V9R@2>
SXh0SHf=08V9R@2<S8`0Ti>C09BDU02=SHd0RXZ:0820P01hN7P0HV9R07=cL`2FUYH0X:2P07YjNP1_
Kfl0RXZ:07alO02EUID0PX:207UiN@2e]KD0V9RH0:2PX02HV9PN0?ooo`0=079bLP1`L700Kfm_079b
LP1jNWX0M7Ad07alO01cLg<0K6a/071`L01[Jf/0MWIf07EeM@0207IfMP0307=cL`1kNg/0NWYj0080
M7Ad00D0LG5a06UYJ@1eMGD0MGEe05=CD`02065QH@0>05aLG01KFe/0GemO05mOG`1ADE40Cdm?05aL
G01PH600G5aL05YJFP1IFET0GUiN061PH01TI6@206EUI@0406QXJ01QHF40G5aL05]KF`80EUIF00`0
F5QH065QH@1GEeL0EEEE051@D01FEUH0EeMG05aLG01JFUX0EeMG05UIF@1HF5P205mOG`0505iNGP1D
E5@0FUYJ061PH01IFET0101GEeL01P1IFET0GemO05]KF`1EEED0FEUI06UYJ@80HF5Q0P1SHf<00`1R
HV80I6AT06IVIP0206EUI@0806e]K@1^KVh0I6AT065QH@1HF5P0De=C03hn?P1CDe<206YZJP0;051@
D00i>CT0GemO05ADE01VIVH0HF5Q05YJFP1iNGT0L71`06m_K`1^KVh08P3oool00200oooo00L0WIfM
0::RXP2SXj<0WIfM0:6QX@2IVIT0Xj>S0080WYjN00<0V9RH09^KV`2QXJ400P2UYJD01@2QXJ40VIVI
0:6QX@2=SHd0SXj>0080TY:B01@0SXj>09VIV@2;Rh/0KFe]092@T029RHT0P82007emO@22PX80OGem
07]kN`1cLg<0Ph>307emO@21PH40O7al07UiN@1lO7`0SHf=08n?S`80RXZ:00@0SHf=08V9R@1kNg/0
MWIf0P21PH402P1fMWH0QHF507alO01mOGd0NWYj08:2PP1lO7`0QXJ607inOP26QXH208:2PP0608N7
Q`2:RXX0QXJ608:2PP26QXH0QhN70`22PX80302;Rh/0Ogmo08:2PP27QhL0Ogmo0861P@2DU9@0TI6A
08F5Q@1cLg<0MGEe09VIV@80TY:B01P0SHf=08^;R`2?Shl0TY:B096AT@27QhL0QXJ606QXJ025QHD0
NGUi07AdM026QXH0WinO08F5Q@1cLg<0R8R8096AT@26QXH0OGem08n?S`2SXj<0WIfM09ZJVP2MWIdN
0?ooo`0D09bLW02UYJD0YJFU0::RXP2TY:@0UiNG09jNWP2KVi/0Y:BT09jNWP2LW9`0WIfM0::RXP2S
Xj<0XJ6Q09NGU`2TY:@0UiNG0:2PX02QXJ420:JVYP0C0:FUY@2HV9P0RHV908F5Q@28R8P0PX:20820
P022PX80Ng]k07moO`1jNWX0R8R808:2PP2;Rh/0RXZ:08:2PP1mOGd0QhN708j>SP0208Z:RP80Rh^;
00h0PX:207]kN`25QHD0Rh^;07inOP27QhL0PX:208>3P`1lO7`0Ogmo07=cL`1gMgL0K6a/07QhN080
MGEe00L0MgMg07UiN@1dM7@0M7Ad07QhN01eMGD0Lg=c0080MWIf0180Q8B407alO021PH40Ph>307Qh
N01lO7`0R8R807=cL`2<S8`0Jf][05YJFP1kNg/0Q8B408^;R`27QhL0QHF508f=S@2>SXh208Z:RP0@
08>3P`1DE5@0JFUY079bLP1hN7P0Ogmo092@T01oOgl0NGUi08>3P`2JVYX0Shn?07IfMP2EUID0[Zj^
09fMW@80Vi^K7P3oool0301bLW80Ng]k07QhN01kNg/0NGUi071`L01_Kfl0LG5a07alO01iNGT0Lg=c
06i^KP80M7Ad01P0MWIf071`L01iNGT0NWYj08F5Q@23Ph<0RXZ:08f=S@22PX80OWin07UiN@1HF5P0
HV9R06=SH`1QHF40GemO05UIF@1QHF40H61P06EUI@1SHf<0KFe]071`L01YJFT205aLG00406IVIP1U
IFD0IFEU06ATI080J6QX00D0HF5Q06ATI01]KFd0Hf=S069RHP0206EUI@0505eMG@1IFET0CTi>04Y:
BP13@d<00`1;Bd/01`19BDT0B4Q804I6AP19BDT0Bd];04M7A`19BDT00P1=CDd205UIF@0>05iNGP1K
Fe/0EEEE05IFEP1EEED0>c/k06a/K01<C4`0;Rh^03dm?@1CDe<0GUiN05eMG@1LG5`206ATI00D05mO
G`1XJ6P0GUiN03@d=00e=CD0D51@05]KF`1CDe<0EeMG05]KF`1RHV80Fe]K07IfMP1_Kfl0EEEE075a
L@20P800M7Ad079bLP1_KflR0?ooo`00803oool0;P2SXj<0X:2P09NGU`2TY:@0WinO0:BTY02PX:00
WYjN09JFUP2PX:00WinO09bLW02NWYh0Vi^K0:FUY@2HV9P0YJFU09ZJVP2IVIT0WYjN0::RXP2MWId0
Xj>S09NGU`2LW9`0HV9R05eMG@2HV9P0OWin08Z:RP22PX80PH6107]kN`1lO7`0LW9b08F5Q@24Q8@0
Ph>307QhN024Q8@0QhN708f=S@2;Rh/0T92@08Z:RP27QhL207inOP0308>3P`27QhL0QhN700<0QhN7
00`0PX:208>3P`2:RXX0P82007emO@20P800N7Qh07emO@21PH40PX:207emO@1nOWh20861P@<0QhN7
01l0OGem08>3P`2;Rh/0OGem08^;R`21PH40PX:208>3P`2ATI40RXZ:08B4Q00h>3P0HF5Q071`L021
PH40T92@079bLP1[Jf/0E5AD061PH01bLW80MgMg09BDU01eMGD0YJFU06UYJ@22PX80Shn?096AT@2H
V9P0O7al0080QhN700@0ZZZZ0:>SX`2SXj<0Xj>S7P3oool07P2IVIT0VYZJ09NGU`2QXJ40V9RH09^K
V`2LW9`0WYjN09VIV@2PX:00Y:BT0:>SX`2OWil0WYjN0:RXZ02IVIT0YjNW09ZJVP2GUiL0WYjN0:6Q
X@2IVIT0YJFU09VIV@2KVi/0Hf=S05eMG@2;Rh/0JFUY08Z:RP80PH610140Ogmo08B4Q01hN7P0QHF5
08B4Q023Ph<0N7Qh08B4Q028R8P0RHV908F5Q@2=SHd0RHV908^;R`23Ph<0PH6108>3P`0308Z:RP80
QhN700<0QHF508>3P`2;Rh/00P27QhL0102;Rh/0Ogmo08:2PP25QHD208V9R@0308B4Q022PX80PH61
0080RXZ:0200QhN708>3P`20P800R8R807inOP2<S8`0QHF508V9R@21PH40RXZ:08J6QP27QhL0Kfm_
06YZJP1PH600HV9R079bLP1EEED0C4a<05IFEP1RHV80Ng]k07MgM`2>SXh0KVi^0;Jf]P1hN7P0PH61
08Z:RP2BTY80ZZZZ07EeM@80TI6A00@0Z:RX09fMW@2LW9`0XZ:R7P3oool0101XJ6P0K6a/071`L01b
LW8206YZJP0H06m_K`1dM7@0M7Ad07AdM01lO7`0OGem07EeM@1gMgL0NWYj07=cL`1iNGT0LW9b071`
L01dM7@0Lg=c06i^KP1hN7P0Lg=c075aL@1EEED0BTY:059BDP0o?cl0HF5Q0P1NGUh00`1QHF40IfMW
05iNGP03061PH00;05YJFP1OGel0Hf=S061PH01LG5`0HV9R06=SH`1ZJVX0IVIV069RHP1PH6000`1V
IVH206=SH`0>06EUI@1PH600IFEU06UYJ@1/K6`0KFe]06ATI01SHf<0I6AT06YZJP1_Kfl0IVIV061P
H01OGel206MWI`0506=SH`1WIfL0G5aL061PH01NGUh00P1UIFD07`1[Jf/0GEeM05iNGP1NGUh0IfMW
08j>SP1JFUX0>SXj02d];@0h>3P0:BTY028R8P13@d<0BDU905aLG01CDe<0G5aL04e=C@28R8P0JFUY
05eMG@1OGel0JFUY08>3P`1EEED0M7Ad06i^KP1cLg<0KFe]06][J`1eMGD08P3oool00200oooo02P0
VIVI09NGU`2QXJ40VIVI0:2PX02KVi/0UiNG0:2PX02OWil0VYZJ0:FUY@2MWId0Xj>S0:2PX02RXZ80
XJ6Q09fMW@2SXj<0Vi^K09fMW@2IVIT0WIfM0:6QX@2MWId0Vi^K06UYJ@1[Jf/0GEeM08>3P`1cLg<0
Vi^K08:2PP1mOGd0QHF507=cL`22PX80Ogmo08R8R01kNg/0PH610P27QhL02@28R8P0Rh^;08j>SP2?
Shl0Ph>308:2PP1nOWh0QhN708^;R`0408N7Q`0>08:2PP20P800RXZ:08N7Q`2;Rh/0PH610820P024
Q8@0QXJ608F5Q@26QXH0QhN707YjNP2?Shl308N7Q`0T08>3P`2;Rh/0OGem08b<S021PH40SXj>0861
P@27QhL0PX:208^;R`29RHT0M7Ad065QH@1IFET0A4A405iNGP1ZJVX0H61P06QXJ01]KFd0KVi^07em
O@1lO7`0];Bd05iNGP2:RXX0U9BD0:6QX@2MWId0Lg=c0;:b/P1mOGd0X:2P09fMW@2KVi/0YjNW7P3o
ool0;02SXj<0Vi^K0:6QX@2KVi/0Xj>S0:BTY02IVIT0WIfM0:2PX02OWil0YJFU09VIV@2RXZ80WinO
0:2PX02QXJ40Vi^K0::RXP2OWil0Y:BT09ZJVP2KVi/0WIfM09NGU`2IVIT0JVYZ07moO`1QHF40NGUi
06=SH`2;Rh/0PX:207alO022PX80LG5a08B4Q01lO7`0QHF507emO@23Ph<0QhN708J6QP28R8P0RHV9
0P2<S8`01@23Ph<0QHF50861P@24Q8@0R8R800@0QhN700L0QHF507moO`23Ph<0PH6108R8R025QHD0
R8R80080Ph>300D0OGem0861P@2:RXX0Ng]k08f=S@0308N7Q`0:0820P02;Rh/0OGem08b<S01mOGd0
RHV908F5Q@2;Rh/0OWin0861P@80Ogmo00H0RXZ:0861P@0m?Cd0ADE5069RHP1MGEd206m_K`0@06QX
J01]KFd0OGem0;Fe]@1@D500N7Qh08n?S`2NWYh0UIFE06m_K`2i^KT0TY:B0:j^[P2PX:00WIfM0:RX
Z1h0oooo02P0P82007IfMP1fMWH0M7Ad07YjNP1oOgl0LW9b071`L01gMgL0N7Qh07MgM`1^KVh0MGEe
07=cL`1bLW80MWIf075aL@1eMGD0NGUi07emO@1cLg<0LG5a06i^KP1[Jf/0Kfm_05]KF`1bLW80CDe=
04i>CP0m?Cd0De=C05mOG`1JFUX0GEeM05ADE01QHF40F5QH05eMG@1OGel0HF5Q0P1RHV802@1SHf<0
HF5Q06ATI01SHf<0HF5Q06EUI@1RHV80GEeM061PH00406=SH`0=06EUI@1MGEd0F5QH05YJFP1PH600
IFEU06YZJP1OGel0G5aL05EEE@1JFUX0IVIV05eMG@0406=SH`0T05aLG01TI6@0GEeM06ATI01JFUX0
GemO06EUI@1WIfL0FUYJ05IFEP1EEED0K6a/08^;R`22PX80;Bd]020P8010@400@d=305EEE@1@D500
AdM703lo?`1LG5`0MWIf03Xj>P18B4P0H61P06MWI`1SHf<0EEEE08:2PP21PH40QHF507MgM`1dM7@0
NGUi8P3oool00200oooo00d0Xj>S0:6QX@2MWId0WIfM0:NWY`2MWId0WinO09bLW02MWId0Xj>S0:6Q
X@2HV9P0XJ6Q0080WIfM00H0XJ6Q09NGU`2TY:@0XJ6Q09jNWP2KVi/209fMW@0A09VIV@2KVi/0LG5a
0861P@1IFET0J6QX055AD@1XJ6P0[:b/08J6QP1nOWh0NGUi07inOP20P800PH6107moO`24Q8@01027
QhL0102?Shl0Rh^;08N7Q`27QhL208:2PP<0QhN700@0QXJ608N7Q`27QhL0Ng]k0P23Ph<01@2;Rh/0
Ph>308N7Q`1mOGd0P8200080Ph>302X0QhN70820P02<S8`0QhN708J6QP27QhL0RXZ:08N7Q`1mOGd0
QhN70861P@2;Rh/0PX:208N7Q`22PX80PH6107UiN@25QHD0L71`06UYJ@1GEeL0DE5A05eMG@1]KFd0
IFEU06][J`1YJFT0MgMg07alO02SXj<0GEeM07]kN`2@T900WinO08J6QP24Q8@0[Jf]09^KV`2NWYh0
Z:RX09^KV`2NWYhN0?ooo`0A09^KV`2QXJ40W9bL09VIV@2WYjL0VIVI0:2PX02TY:@0W9bL0::RXP2T
Y:@0VIVI09nOW`2TY:@0XZ:R0:BTY02GUiL00P2QXJ404@2KVi/0V9RH09bLW02OWil0W9bL09^KV`1e
MGD0Q8B4069RHP1XJ6P0BTY:04e=C@27QhL0PX:207inOP1jNWX0O7al0080PH6100<0NWYj08>3P`27
QhL00`27QhL02P2>SXh0R8R808B4Q027QhL0QHF508R8R02:RXX0QhN708R8R026QXH208N7Q`0O07em
O@25QHD0Ph>308^;R`20P800PH6107moO`1nOWh0Ph>308F5Q@24Q8@0OWin08j>SP28R8P0QXJ608N7
Q`2;Rh/0RXZ:07inOP25QHD0Ogmo08f=S@1nOWh0P82007inOP21PH40Lg=c06MWI`1<C4`0@D5104Q8
B00205mOG`0;075aL@1WIfL0JFUY06UYJ@20P800Ng]k09RHV01HF5P0Ogmo08b<S02XZ:P00P25QHD0
1P2b/[80Vi^K0:>SX`2XZ:P0Xj>S09nOWah0oooo0240Jf][07IfMP1bLW80KVi^07QhN01^KVh0MgMg
07moO`1bLW80MGEe07UiN@1cLg<0LG5a07emO@1kNg/0NGUi075aL@1cLg<0MWIf071`L01_Kfl0LW9b
07IfMP1eMGD0LW9b069RHP1UIFD0F5QH04a<C00f=SH08B4Q03/k>`1KFe/00P1LG5`01@1JFUX0GemO
05eMG@1GEeL0GEeM0080Hf=S0P1RHV801`1VIVH0HF5Q05mOG`1SHf<0IFEU06QXJ01VIVH01@1SHf<0
3@1PH600HV9R061PH01TI6@0G5aL05YJFP1PH600FUYJ061PH01RHV80GEeM05]KF`1VIVH00`1SHf<0
901UIFD0IVIV05iNGP1NGUh0GEeM06EUI@1KFe/0F5QH05]KF`1NGUh0DE5A03<c<`0L71`04Q8B02l_
;`1@D500ADE505=CD`1=CDd0Bd];04e=C@1SHf<0F5QH05iNGP18B4P0GEeM05mOG`1hN7P0HF5Q06AT
I01lO7`0LW9b07YjNP1iNGT0OWin07EeMB80oooo000P0?ooo`0=09^KV`2NWYh0WYjN09^KV`2WYjL0
UiNG0:NWY`2KVi/0UiNG0:NWY`2MWId0Xj>S09NGU`020:6QX@0I09fMW@2OWil0XJ6Q09fMW@2SXj<0
UiNG09^KV`2PX:00XJ6Q09bLW01mOGd0R8R806MWI`15ADD0D51@04U9B@1EEED0`l?307UiN@26QXH0
Ogmo08J6QP22PX80OGem08:2PP0408N7Q`0308^;R`27QhL0QhN70080QhN700P0Ph>308N7Q`27QhL0
S8b<08>3P`2;Rh/0QhN707inOP80Ph>300<0QhN708>3P`21PH400P21PH4408>3P`0X08N7Q`2<S8`0
PH6108V9R@2;Rh/0QhN707inOP21PH40Q8B408N7Q`1lO7`0QXJ607UiN@20P800Kfm_05UIF@1EEED0
Fe]K06EUI@1LG5`0GEeM065QH@1aLG40J6QX07AdM01lO7`0PX:207emO@1ZJVX0PH610820P02?Shl0
QXJ609>CT`2[Zj/0V9RH0:2PX02TY:@0XZ:R09^KVah0oooo00L0Xj>S09nOW`2KVi/0W9bL0:NWY`2G
UiL0YjNW0080UYJF00@0YjNW09VIV@2RXZ80VIVI0P2QXJ401@2IVIT0W9bL0:FUY@2IVIT0XZ:R0080
VYZJ00h0WYjN0:BTY02LW9`0Ph>309bLW025QHD0Cdm?04Y:BP19BDT0@T9209^KV`1dM7@0QHF507If
MP80PH6100<0P82008B4Q027QhL00`27QhL00`29RHT0QhN708N7Q`0208N7Q`080820P021PH40PH61
08V9R@1oOgl0R8R808N7Q`1nOWh208>3P`0608B4Q020P800P82007emO@23Ph<0QHF50P23Ph<0:@24
Q8@0QHF508V9R@1mOGd0PX:208j>SP27QhL0OWin0820P023Ph<0Q8B407MgM`22PX80Lg=c07EeM@1T
I6@0BDU904I6AP1KFe/0Kfm_06IVIP1ZJVX0GEeM06][J`1ZJVX0NWYj08>3P`28R8P0NWYj05mOG`1m
OGd0Ng]k09>CT`20P800UYJF0;Bd]02MWId0WinO0:FUY@2MWId0UYJF01h0oooo00d0OWin07EeM@1`
L700M7Ad07QhN01`L700N7Qh06a/K01`L700N7Qh06i^KP1eMGD0Lg=c0080MWIf00H0KVi^071`L01j
NWX0KVi^07EeM@1dM7@2075aL@0?07UiN@1cLg<0K6a/08>3P`20P800C4a<03Lg=`0i>CT07QhN0451
@@1BDU80GemO051@D01HF5P0GUiN0080HF5Q101SHf<00`1RHV80Hf=S06=SH`0206=SH`0805aLG01J
FUX0FUYJ061PH01KFe/0H61P06=SH`1NGUh2061PH00405eMG@1LG5`0GEeM05YJFP80HV9R0P1PH600
0`1QHF40GUiN061PH00205UIF@0T06MWI`1SHf<0GUiN05eMG@1OGel0GEeM05ADE01LG5`0DE5A04a<
C013@d<0:b/[02XZ:P13@d<0EUIF05=CD`1HF5P0?clo04Q8B01?Cdl0G5aL069RHP1VIVH0EUIF0451
@@1FEUH0De=C06YZJP1KFe/0KFe]08:2PP1gMgL0Lg=c07QhN01_Kfl0K6a/8P3oool00200oooo02T0
Xj>S0:2PX02JVYX0VYZJ0:VYZ@2KVi/0XJ6Q09FEU@2HV9P0XJ6Q0::RXP2MWId0XJ6Q09fMW@2RXZ80
WYjN09fMW@2WYjL0Xj>S09jNWP2KVi/0WinO09RHV02RXZ80WYjN08>3P`2YZJT0MGEe04U9B@1JFUX0
ATI603Ph>018B4P0^k^k08F5Q@22PX80Ng]k08B4Q01mOGd0Q8B408b<S00308N7Q`0308>3P`27QhL0
QhN70080QhN70P22PX801@27QhL0Ph>308>3P`27QhL0Rh^;0080PX:200<0Ng]k08>3P`27QhL00P21
PH404P20P800QXJ60861P@21PH40Ph>30861P@2?Shl0OGem08N7Q`26QXH0SHf=08:2PP1mOGd0Ph>3
0861P@1mOGd0O7al07QhN080Kfm_00h0Bd];069RHP1QHF40Fe]K06a/K01aLG40F5QH06][J`1gMgL0
J6QX08F5Q@28R8P0MWIf07]kN`80MgMg00T0Jf][09JFUP2UYJD0WinO09jNWP2HV9P0WIfM0:FUY@2G
UiL07P3oool03P2KVi/0W9bL09jNWP2HV9P0Z:RX09nOW`2UYJD0UiNG09VIV@2NWYh0XJ6Q09bLW02Q
XJ40VIVI0P2KVi/06@2LW9`0YZJV0::RXP2OWil0VIVI0:BTY02NWYh0XJ6Q09fMW@1oOgl0ZZZZ07=c
L`14A4@0E5AD04E5A@0g=cL0=CDe08V9R@1lO7`0QhN70820P024Q8@0Ng]k08:2PP29RHT00`27QhL0
0`20P800QhN708N7Q`0208N7Q`0P08F5Q@28R8P0RXZ:08>3P`20P800Q8B408R8R025QHD0R8R807]k
N`1nOWh0Q8B408:2PP23Ph<0OWin08B4Q020P800OGem08:2PP1nOWh0SHf=07emO@2;Rh/0PX:208V9
R@25QHD0P82008B4Q020P800NWYj07IfMP1aLG4206QXJ00I04=3@`1VIVH0KFe]05]KF`1WIfL0MGEe
05eMG@1/K6`0Ng]k06QXJ01mOGd0Ng]k06a/K024Q8@0RHV908>3P`1ZJVX0S8b<0;6a/@2XZ:P0WYjN
09NGU`2KVi/0YJFU09^KV`0N0?ooo`0B06][J`1_Kfl0MgMg071`L01gMgL0NGUi07]kN`1bLW80Lg=c
075aL@1fMWH0LW9b07IfMP1^KVh0Jf][071`L01bLW80MWIf0P1eMGD05@1_Kfl0Ng]k07UiN@1cLg<0
LW9b061PH01gMgL0FUYJ03/k>`0j>SX0=3@d02XZ:P0B4Q80;Bd]055AD@1UIFD0HV9R05mOG`1IFET0
G5aL061PH00306=SH`0305aLG01SHf<0Hf=S0080Hf=S0200IFEU06QXJ01VIVH0H61P05aLG01MGEd0
H61P06EUI@1XJ6P0G5aL05QHF01NGUh0H61P069RHP1LG5`0GUiN05eMG@1IFET0GEeM05YJFP1SHf<0
GemO06QXJ01KFe/0H61P06EUI@1RHV80HF5Q05eMG@1GEeL0DU9B04m?C`80BDU901D0;Rh^04a<C01H
F5P0@d=304I6AP1GEeL0BTY:04e=C@1KFe/0C4a<055AD@1<C4`0BDU906QXJ01bLW80JVYZ05=CD`1L
G5`0Ph>307inOP1dM7@00P1_Kfl207MgMb80oooo000P0?ooo`0Z09fMW@2SXj<0Vi^K0:6QX@2MWId0
Vi^K09nOW`2NWYh0XZ:R0:FUY@2IVIT0YJFU09VIV@2QXJ40V9RH0:FUY@2JVYX0Vi^K0:6QX@2IVIT0
XJ6Q09bLW02VYZH0WIfM09RHV02BTY80S8b<08B4Q01SHf<0Fe]K04E5A@0i>CT0<30`02`/;012@T80
Q8B4071`L02=SHd0OGem0861P@2;Rh/0Ph>30`27QhL04@1nOWh0QhN708^;R`1nOWh0Ph>308N7Q`1o
Ogl0OGem08B4Q029RHT0QhN708V9R@1nOWh0Ogmo0820P021PH40Ogmo0080Ph>300<0QXJ607alO021
PH400P21PH409`28R8P0QhN707YjNP1gMgL0S8b<07emO@1dM7@0LG5a07AdM01YJFT0I6AT05mOG`15
ADD0CDe=06e]K@1eMGD0J6QX04m?C`1_Kfl0JFUY06i^KP1cLg<0JVYZ05QHF01[Jf/0N7Qh07MgM`2:
RXX0PX:209RHV02>SXh0VYZJ09VIV@2ATI40X:2P0:BTY02KVi/0YjNW09fMW@0N0?ooo`0G09^KV`2U
YJD0W9bL0:FUY@2LW9`0V9RH0:2PX02SXj<0WIfM0:>SX`2IVIT0YZJV09VIV@2UYJD0VIVI0:NWY`2J
VYX0Vi^K0:6QX@2MWId0WYjN09NGU`2RXZ800P2IVIT04@2JVYX0Shn?08R8R01UIFD0Fe]K0410@00g
=cL0<S8b02h^;P0a<C40Q8B406i^KP2:RXX0Ng]k0820P028R8P0P82000@0PH6103h0Q8B408R8R01n
OWh0Ph>308Z:RP21PH40OWin0861P@25QHD0PH6108N7Q`21PH40O7al07]kN`1nOWh0OGem07moO`1l
O7`0PH6107UiN@1nOWh0O7al07MgM`21PH40Q8B407AdM01`L700Ph>307YjNP1cLg<0L71`075aL@1V
IVH0FUYJ04e=C@0a<C40@D5107EeM@1dM7@0IFEU05UIF@20P800LW9b06UYJ@1]KFd0L71`061PH01[
Jf/0NGUi07MgM`2=SHd0Ph>308Z:RP2GUiL0YjNW0:2PX02=SHd0W9bL0:FUY@2KVi/0YjNW0:2PX1h0
oooo02X0Kfm_07YjNP1cLg<0NWYj079bLP1^KVh0MWIf07alO01_Kfl0M7Ad07=cL`1hN7P0Lg=c07Yj
NP1cLg<0NGUi079bLP1cLg<0MWIf07QhN01`L700Jf][075aL@1^KVh0LW9b07UiN@1]KFd0K6a/059B
DP13@d<0<30`02XZ:P0X:2P092@T014A4@1NGUh0DU9B05mOG`1IFET0GUiN061PH01LG5`305YJFP08
069RHP1MGEd0H61P05iNGP1PH600IVIV065QH@1NGUh205aLG00505YJFP1RHV80HV9R05YJFP1FEUH0
0P1JFUX02`1IFET0EEEE05YJFP1HF5P0FEUI05IFEP1@D500EeMG05iNGP1BDU80CTi>0080EeMG00h0
EUIF05=CD`1BDU80BDU903/k>`0[:b/061PH02HV9P1EEED0Cdm?04Q8B01?Cdl0IVIV05YJFP80Bd];
00<0F5QH04m?C`1=CDd00P1GEeL02P1TI6@0H61P05ADE01cLg<0P82007QhN01UIFD0K6a/07MgM`1c
Lg<207QhN280oooo000P0?ooo`0O09^KV`2QXJ40Vi^K0:6QX@2EUID0Xj>S09fMW@2QXJ40WYjN0:NW
Y`2IVIT0Y:BT09^KV`2QXJ40WinO0:NWY`2MWId0W9bL0::RXP2QXJ40UiNG09^KV`2OWil0WYjN09JF
UP2MWId0Q8B409fMW@1<C4`0EeMG03lo?`0203/k>`09030`<00T92@0e=CD07alO020P800PX:20861
P@26QXH0Q8B400<0Ph>300<0OWin08N7Q`23Ph<00P23Ph<02027QhL0Q8B407moO`1mOGd0Ph>308B4
Q02;Rh/0Ph>30`1mOGd00`1lO7`0N7Qh07]kN`0208>3P`0N07QhN01oOgl0MGEe08J6QP20P800MWIf
07emO@1kNg/0OGem07UiN@1`L700Kfm_05MGE`1FEUH0Cdm?0451@@1?Cdl0IfMW06ATI01WIfL0J6QX
07=cL`1XJ6P0Jf][07EeM@1^KVh0Lg=c06UYJ@1cLg<0QHF50P22PX802025QHD0Rh^;09>CT`2OWil0
UYJF09FEU@2SXj<0Vi^K0P2QXJ4N0?ooo`80WIfM00@0XJ6Q0:FUY@2DU9@0YZJV0P2TY:@07@2LW9`0
YZJV09RHV02PX:00UYJF09ZJVP2IVIT0YZJV0:2PX02RXZ80X:2P0:6QX@2IVIT0W9bL09nOW`2NWYh0
Ti>C09NGU`1jNWX0UiNG04=3@`1GEeL0?Cdm03Ti>@0n?Sh0=3@d02HV9P2DU9@0MgMg0080OGem00<0
Ogmo08:2PP20P8000`23Ph<07@1nOWh0RXZ:08>3P`20P800Ph>308B4Q023Ph<0PH6107inOP1oOgl0
P82008N7Q`20P800OWin0820P01oOgl0O7al07MgM`1eMGD0Ng]k07moO`1gMgL0PX:207QhN027QhL0
OGem07=cL`1jNWX0NGUi0080M7Ad0200Kfm_06a/K01:BTX0AdM704A4A011@D40EUIF07UiN@1WIfL0
HV9R06QXJ01fMWH0IFEU05YJFP1ZJVX0Hf=S07=cL`1iNGT0Lg=c08^;R`29RHT0Ph>308R8R02QXJ40
UiNG09^KV`2PX:00Xj>S0:VYZ@2QXJ40YJFU0:6QXAh0oooo00`0MGEe06m_K`1lO7`0Ng]k06i^KP1j
NWX0OGem07UiN@1`L700MWIf071`L01aLG4206a/K00706e]K@1fMWH0N7Qh07alO01cLg<0MWIf07Ad
M00207=cL`0>07AdM01ZJVX0J6QX05MGE`1XJ6P0=cLg0451@@0_;bl0:b/[030`<00[:b/07QhN02@T
901CDe<205MGE`0305YJFP1KFe/0Fe]K00<0H61P00T0GUiN06IVIP1PH600G5aL061PH01MGEd0GemO
065QH@1NGUh00P1JFUX0401MGEd0G5aL05mOG`1QHF40GemO05]KF`1GEeL0DE5A059BDP1JFUX0EeMG
065QH@1KFe/0HF5Q05UIF@1DE5@205MGE`0R04m?C`1BDU80DU9B04e=C@0_;bl0:BTY02/[:`0b<S80
@d=3069RHP1=CDd0A4A404a<C01FEUH0B4Q803De=@13@d<0?clo05ADE01UIFD0E5AD06MWI`1XJ6P0
H61P06IVIP26QXH0LG5a06e]K@1mOGd0PH6107moO`1lO7`0Ng]k07IfMR80oooo000P0?ooo`0=09fM
W@2QXJ40YJFU0:6QX@2IVIT0WIfM0:BTY02UYJD0V9RH0:6QX@2LW9`0XZ:R09jNWP0209^KV`0709jN
WP2QXJ40Y:BT09jNWP2UYJD0V9RH09bLW00209fMW@0B09RHV02@T900OGem09RHV011@D40EeMG03lo
?`0i>CT0?clo03<c<`0P8200:2PX0=WIf@1iNGT0QXJ607YjNP21PH40Q8B40`23Ph<208N7Q`0307in
OP23Ph<0Ph>300<0Ph>302/0OGem07moO`23Ph<0QHF50861P@22PX80OWin07moO`1mOGd0MWIf07Mg
M`1jNWX0Ogmo07MgM`23Ph<0O7al07inOP28R8P0KFe]07emO@1hN7P0Kfm_07emO@1]KFd0G5aL05MG
E`0e=CD0GUiN051@D01GEeL0IFEU06ATI01WIfL0I6AT07emO@1TI6@0HF5Q06i^KP1UIFD0M7Ad07Mg
M`1nOWh0PH610080PX:200H0T92@09fMW@2HV9P0W9bL0:2PX02QXJ4209jNWP030:6QX@2WYjL0oooo
01d0oooo00@0Vi^K0:FUY@2SXj<0XJ6Q0P2NWYh02`2MWId0Xj>S09fMW@2NWYh0UiNG0:2PX02RXZ80
XJ6Q0:>SX`2OWil0VYZJ0080WYjN01L0YJFU09VIV@2OWil0WinO09bLW02MWId0UIFE0820P02JVYX0
@T9205MGE`10@400>SXj03lo?`0c<c<07alO01hN7P2PX:00N7Qh08V9R@1mOGd0PH6108B4Q00308>3
P`0308N7Q`2:RXX0OWin00<0Ph>300T0Q8B408>3P`1nOWh0PH6108F5Q@24Q8@0OGem07inOP1kNg/0
0P1lO7`0;P1eMGD0NGUi07]kN`1lO7`0Lg=c07YjNP1gMgL0N7Qh08B4Q01[Jf/0NGUi07AdM01YJFT0
MGEe06QXJ01?Cdl0BDU902`/;01EEED0EeMG06=SH`1VIVH0HF5Q06UYJ@1TI6@0OGem06YZJP1bLW80
OGem07EeM@1mOGd0NWYj08R8R02;Rh/0Ph>308:2PP2EUID0Ti>C09RHV02SXj<0XZ:R0:BTY02OWil0
Vi^K09ZJVP2SXj<N0?ooo`0E06m_K`1jNWX0M7Ad07IfMP1iNGT0M7Ad06i^KP1dM7@0N7Qh075aL@1[
Jf/0Lg=c07]kN`1lO7`0OWin07EeM@1/K6`0KVi^07AdM01gMgL0Lg=c0080MWIf0100LW9b07QhN01c
Lg<0IVIV071`L011@D40@T9203De=@0];Bd0;Rh^02LW9`0H61P02PX:030`<01HF5P0Hf=S0P1NGUh4
061PH00306=SH`1VIVH0GUiN00<0H61P00P0HF5Q061PH01NGUh0H61P06=SH`1NGUh0FEUI05YJFP80
F5QH0240FUYJ05MGE`1JFUX0Fe]K05MGE`1ADE40D51@05ADE01BDU80G5aL051@D01EEED0DU9B04Y:
BP1>CTh0BTY:03@d=00Z:RX071`L03@d=016ATH0D51@04];B`15ADD0CDe=04Q8B01HF5P0EEEE065Q
H@1UIFD0Hf=S061PH01KFe/00P1ZJVX0301PH600GemO06e]K@1RHV80Kfm_07YjNP1fMWH0NGUi07Ee
M@1`L700K6a/07=cLb80oooo000P0?ooo`0W09VIV@2QXJ40ZJVY09jNWP2UYJD0W9bL09fMW@2NWYh0
Vi^K0:2PX02NWYh0VIVI0:6QX@2RXZ80YJFU09fMW@2GUiL0X:2P09VIV@2SXj<0X:2P0:6QX@2JVYX0
Vi^K09fMW@2DU9@0QXJ608^;R`1;Bd/0CTi>04Q8B011@D40>SXj02`/;00P82009bLW0<S8b01iNGT0
QXJ600<0PX:200<0RHV907inOP27QhL00P27QhL208>3P`0607moO`27QhL0PH6108F5Q@1mOGd0Ph>3
0P21PH400`1kNg/0Ph>307emO@0207emO@0Y07YjNP1gMgL0MgMg07UiN@1gMgL0Ng]k08B4Q01^KVh0
MgMg07=cL`1hN7P0MgMg06ATI01bLW80HF5Q05aLG01DE5@0?Cdm05ADE01<C4`0JFUY061PH01SHf<0
JVYZ06i^KP1cLg<0MWIf06EUI@1hN7P0PH6106UYJ@1iNGT0PH6108:2PP21PH40S8b<08n?S`2RXZ80
UYJF09nOW`2LW9`00P2NWYh00`2IVIT0XJ6Q0:6QX@0N0?ooo`0l0:>SX`2VYZH0YjNW09^KV`2SXj<0
WinO0:>SX`2NWYh0UYJF09nOW`2TY:@0W9bL09^KV`2MWId0Xj>S0:2PX02JVYX0X:2P09ZJVP2MWId0
W9bL0:BTY02MWId0VYZJ09^KV`2ATI40RHV908R8R016ATH0BTY:04=3@`15ADD0?Cdm02XZ:P0O7al0
:RXZ0=CDe01hN7P0Q8B40861P@22PX80PH6108Z:RP21PH40RXZ:08B4Q021PH40P82008>3P`1lO7`0
Q8B407moO`23Ph<0O7al08:2PP1oOgl0OWin07IfMP1oOgl0O7al0P1mOGd02P1gMgL0MWIf079bLP1b
LW80LG5a07]kN`29RHT0LW9b06e]K@1UIFD206i^KP0R05]KF`1UIFD0DE5A059BDP1<C4`0@T9205]K
F`17AdL0I6AT05]KF`1OGel0IVIV079bLP1fMWH0MgMg06][J`1hN7P0RXZ:07=cL`1jNWX0R8R808>3
P`21PH40Ti>C09ZJVP2ZZZX0Xj>S0:VYZ@2TY:@0WinO09^KV`2GUiL0Y:BT0:FUYAh0oooo01T0P820
07alO01fMWH0L71`07AdM01hN7P0O7al07AdM01/K6`0Lg=c07alO01eMGD0K6a/06m_K`1dM7@0N7Qh
07AdM01eMGD0Lg=c06i^KP1_Kfl0NGUi07EeM@1bLW80Kfm_0080JVYZ0240Hf=S03dm?@0e=CD0<C4a
03Lg=`0`<3007alO01LG5`0P8200P82005QHF01LG5`0GUiN05mOG`1NGUh0IFEU069RHP1VIVH0GEeM
05YJFP1LG5`0H61P05YJFP1NGUh0G5aL05iNGP1KFe/0GUiN05]KF`1IFET0DU9B05QHF01JFUX00P1L
G5`00`1FEUH0EEEE051@D00204i>CP0705UIF@1UIFD0FUYJ04I6AP11@D40B4Q804U9B@0203hn?P0L
030`<00g=cL0;bl_03Lg=`15ADD0<30`0410@011@D40@T9204I6AP1EEED0EUIF05QHF01EEED0EUIF
06UYJ@1NGUh0FUYJ06MWI`1PH600GUiN06m_K`1fMWH0Ogmo0820P021PH40Ogmo07EeM@80L71`00<0
NGUi07]kN`3oool08@3oool00200oooo02d0XJ6Q09jNWP2RXZ80X:2P0:6QX@2WYjL0WIfM0:>SX`2K
Vi/0Xj>S0:6QX@2HV9P0WYjN0:>SX`2NWYh0XZ:R09fMW@2QXJ40WIfM0:6QX@2MWId0WYjN0:6QX@2G
UiL0V9RH09BDU025QHD0Lg=c05eMG@1:BTX0@T92055AD@0f=SH0<c<c024Q8@0d=3@0EeMG0;^k^`25
QHD0PX:207alO021PH40SHf=07inOP27QhL00`23Ph<03@21PH40P8200861P@23Ph<0QXJ607emO@20
P800Ogmo07MgM`21PH40M7Ad08B4Q021PH400P1jNWX0;@1bLW80M7Ad06QXJ01hN7P0P82007QhN01U
IFD0LG5a07=cL`1dM7@0JVYZ05QHF01RHV80CDe=05ADE013@d<0EUIF059BDP1CDe<0Hf=S05aLG01Q
HF40Hf=S07QhN01UIFD0N7Qh06i^KP1iNGT0NWYj07EeM@2:RXX0PH6108:2PP2:RXX0TI6A09RHV02U
YJD0X:2P09fMW@2QXJ40YJFU09fMW@2LW9`0YJFU09jNWP0N0?ooo`0<0:6QX@2KVi/0X:2P09bLW02M
WId0Xj>S09VIV@2RXZ80VYZJ0:NWY`2TY:@0VIVI0P2TY:@07`2NWYh0WIfM09^KV`2UYJD0VIVI0:FU
Y@2TY:@0WYjN0:6QX@2JVYX0VIVI09JFUP23Ph<0Hf=S055AD@1<C4`0@T9205=CD`0i>CT0=SHf02DU
9@0j>SX0AdM709:BTP28R8P0Q8B407moO`21PH40SHf=07inOP24Q8@00`23Ph<0=`20P800PX:208:2
PP1oOgl0QHF507inOP1oOgl0OWin07IfMP23Ph<0MGEe0820P023Ph<0O7al07YjNP1`L700LW9b069R
HP1^KVh0RXZ:07QhN01FEUH0I6AT06m_K`1`L700IFEU051@D01HF5P0@d=304Q8B01CDe<0Hf=S065Q
H@1VIVH0N7Qh061PH01VIVH0IFEU07QhN01OGel0Jf][06QXJ01iNGT0Kfm_06IVIP2;Rh/0P82008:2
PP2@T900Vi^K0:6QX@2][Jd0Y:BT09bLW02IVIT00P2RXZ800`2KVi/0YjNW09^KV`0N0?ooo`0W07If
MP1`L700LW9b071`L01_Kfl0Lg=c06i^KP1eMGD0LW9b07]kN`1iNGT0Lg=c07alO01hN7P0M7Ad06m_
K`1aLG40NWYj06i^KP1kNg/0OGem07AdM01fMWH0M7Ad079bLP1`L700HV9R0492@P0j>SX0?Cdm03<c
<`0m?Cd0;Rh^02`/;00P8200;Bd]01lO7`0k>c/0Hf=S0080HF5Q00@0GUiN06EUI@1NGUh0GEeM0`1P
H600;P1MGEd0HF5Q061PH01IFET0H61P05iNGP1MGEd0Fe]K05MGE`1QHF40EeMG05UIF@1QHF40GEeM
05UIF@1BDU80De=C04E5A@18B4P0JVYZ05QHF00h>3P0?clo04i>CP1=CDd0AdM703Ph>00i>CT0;2`/
02/[:`1;Bd/0DE5A059BDP1KFe/0IFEU04a<C01>CTh0C4a<05ADE013@d<0@T9204U9B@1GEeL0AdM7
0410@01RHV8205iNGP0<06a/K01eMGD0Ng]k0820P01kNg/0LW9b06UYJ@1dM7@0Ng]k075aL@1iNGT0
L71`8P3oool00200oooo00@0XJ6Q09fMW@2MWId0XJ6Q0P2MWId20:6QX@0<0:FUY@2QXJ40XJ6Q0:6Q
X@2HV9P0YjNW09^KV`2JVYX0Vi^K09VIV@2HV9P0XJ6Q0P2MWId0202SXj<0W9bL096AT@2HV9P0JFUY
07=cL`1>CTh0CDe=0P1<C4`03`0a<C40?3`l03Ti>@0/;2`05QHF0>SXj01mOGd0QXJ608>3P`1oOgl0
Q8B407]kN`21PH40Ng]k0861P@0208>3P`040861P@1oOgl0Ogmo07emO@80PH610P1jNWX09`1gMgL0
Ogmo07YjNP1gMgL0NGUi06e]K@1^KVh0HF5Q06e]K@20P800K6a/065QH@1WIfL0Kfm_06UYJ@1DE5@0
@T9205=CD`1SHf<0BTY:04e=C@1HF5P0EUIF059BDP1/K6`0Kfm_05iNGP1PH600GEeM07]kN`1SHf<0
NWYj07emO@1hN7P0M7Ad0861P@2?Shl0PH6109BDU002096AT@0:09VIV@2UYJD0XJ6Q09NGU`2UYJD0
XJ6Q09fMW@2QXJ40YjNW0:6QXAh0oooo00T0XJ6Q09VIV@2MWId0XJ6Q0:BTY02RXZ80Y:BT0:6QX@2V
YZH00`2QXJ40702IVIT0YZJV09nOW`2NWYh0WIfM09^KV`2IVIT0YJFU09^KV`2IVIT0YZJV0::RXP2B
TY80V9RH05iNGP1YJFT0CTi>04Q8B016ATH0ADE502d];@0k>c/0?clo02d];@0C4a<0inOW0861P@24
Q8@20820P00:08B4Q01kNg/0P82007]kN`20P800Ogmo07inOP1mOGd0OWin0820P080OWin00H0Ogmo
07alO01eMGD0LW9b07YjNP1fMWH207MgM`0A06][J`1ZJVX0GUiN06IVIP21PH40FEUI051@D01QHF40
IFEU05eMG@1<C4`0>SXj051@D01VIVH0BTY:04m?C`1EEED00P1=CDd06`1/K6`0L71`05eMG@1PH600
JFUY08:2PP1OGel0MWIf071`L01]KFd0MWIf07QhN027QhL0PX:209bLW02/[:`0Xj>S09VIV@2ZZZX0
Y:BT09VIV@2XZ:P0XJ6Q09VIV@2NWYh0Xj>S0:6QX@0N0?ooo`0907IfMP1^KVh0Lg=c07IfMP1mOGd0
Ng]k07UiN@1fMWH0N7Qh00<0MWIf00D0Lg=c07MgM`1iNGT0MgMg07EeM@0207=cL`0H07]kN`1aLG40
KFe]07UiN@1lO7`0KVi^06m_K`16ATH0BDU90410@00c<c<0;bl_02d];@0R8R80:RXZ03<c<`0R8R80
3@d=07inOP1PH600GEeM05aLG01OGel0H61P101LG5`0?@1JFUX0F5QH05UIF@1LG5`0GemO05iNGP1I
FET0G5aL05eMG@1ADE40D51@05ADE01EEED0EeMG05IFEP1>CTh0C4a<04E5A@14A4@0Fe]K03@d=00b
<S80@D510410@00j>SX0=3@d02LW9`0g=cL0BDU903Ti>@0l?3`0>CTi034a<@0e=CD0BTY:04m?C`15
ADD0ATI605MGE`1NGUh0ATI604m?C`13@d<0B4Q805QHF01?Cdl0FEUI061PH01eMGD0T92@08>3P`1`
L700OWin07UiN@1dM7@0NWYj07IfMP1^KVh0LG5a07=cL`1fMWH08P3oool00200oooo00L0XJ6Q09^K
V`2GUiL0YjNW0:6QX@2NWYh0YJFU0080WYjN00@0YJFU0:6QX@2QXJ40WIfM0P2RXZ8309jNWP0309ZJ
VP2UYJD0UiNG00<0XJ6Q01@0TY:B08j>SP1QHF40KVi^05IFEP1;Bd/0BTY:03Lg=`0d=3@0@T9204=3
@`0Y:BT08R8R0>3Ph01jNWX0Rh^;07inOP27QhL0PH6107moO`<0P82000P0OGem07YjNP25QHD0Ogmo
0861P@1oOgl0OGem08J6QP80MWIf0340MgMg07YjNP1dM7@0N7Qh07MgM`1_Kfl0HF5Q06UYJ@1XJ6P0
O7al05eMG@1QHF40H61P06=SH`1JFUX0E5AD04I6AP1ADE40KVi^04a<C01CDe<0Cdm?069RHP1?Cdl0
I6AT06UYJ@1UIFD0LG5a069RHP1_Kfl0Hf=S06m_K`1YJFT0MgMg08J6QP1dM7@0QXJ608n?S`2CTi<0
Y:BT09^KV`2DU9@0Y:BT0:6QX@2UYJD0XJ6Q09jNWP2OWil0Vi^K0080XJ6Q7P3oool02P2QXJ40WinO
09NGU`2WYjL0XJ6Q09^KV`2SXj<0Vi^K09jNWP2SXj<20:6QX@80X:2P00L0WIfM09^KV`2NWYh0XZ:R
09ZJVP2UYJD0UYJF0080YJFU00H0XJ6Q096AT@27QhL0FEUI06QXJ01CDe<204e=C@0c03De=@0_;bl0
@d=304I6AP0W9bL09BDU0>k^kP1jNWX0Shn?07]kN`24Q8@0PH6107moO`24Q8@0OGem0861P@1nOWh0
MWIf0861P@1oOgl0N7Qh07MgM`1hN7P0Ph>3075aL@1dM7@0MgMg07]kN`1aLG40LW9b07=cL`1YJFT0
FEUI069RHP1ZJVX0N7Qh059BDP1NGUh0GemO065QH@1DE5@0BTY:04M7A`1EEED0Lg=c05IFEP1MGEd0
CTi>06][J`1LG5`0JFUY0080IFEU01P0P820075aL@1bLW80HF5Q06][J`1YJFT0MGEe08b<S027QhL0
U9BD09ZJVP2PX:00Xj>S09ZJVP2FUYH0XJ6Q09VIV@2RXZ80Y:BT09^KV`2PX:00XJ6Q0:FUY@2QXJ4N
0?ooo`0807IfMP1iNGT0L71`07QhN01fMWH0L71`07AdM01`L70207AdM080MWIf00T0N7Qh07=cL`1_
Kfl0L71`07AdM01kNg/0LW9b07MgM`1`L7000P1kNg/04P1fMWH0K6a/05mOG`16ATH0BDU90410@00l
?3`0?Cdm02LW9`0Q8B40<30`03@d=00M7Ad0820P08j>SP1LG5`0JFUY05QHF0<0GUiN03H0I6AT05]K
F`1PH600GUiN05EEE@1JFUX0GEeM051@D01ADE40De=C05]KF`1ADE40E5AD05QHF01KFe/0DU9B04m?
C`1@D500BDU903dm?@12@T80CTi>055AD@0h>3P0@d=304I6AP14A4@0>c/k02l_;`0h>3P0?clo05=C
D`1:BTX0C4a<03Ti>@1BDU80Cdm?04i>CP16ATH0Bd];06QXJ01OGel0E5AD04Q8B01:BTX0CDe=051@
D01WIfL0LW9b07AdM01fMWH0O7al075aL@1`L702075aL@0806UYJ@1dM7@0NGUi071`L01gMgL0O7al
07]kN`1fMWHR0?ooo`00803oool0102QXJ40WYjN09^KV`2QXJ4209jNWP030:FUY@2MWId0XJ6Q00<0
XJ6Q00T0WYjN09ZJVP2NWYh0XJ6Q09fMW@2NWYh0VYZJ0::RXP2LW9`00P2RXZ80202QXJ40TY:B08>3
P`1OGel0HV9R05YJFP1=CDd0Cdm?0P0h>3P0=01?Cdl0>CTi02XZ:P0T92@0i^KV07YjNP2:RXX0QXJ6
08B4Q021PH40N7Qh08>3P`1nOWh0OGem07moO`1jNWX0OGem0861P@1gMgL0NWYj07alO01iNGT0OGem
07QhN01gMgL0NWYj07=cL`1dM7@0KVi^06UYJ@1NGUh0HF5Q07IfMP1SHf<0EeMG06IVIP1HF5P0HF5Q
04Q8B01;Bd/0CDe=051@D01[Jf/0IFEU05QHF01GEeL0GUiN05eMG@1VIVH0EEEE06YZJP24Q8@206i^
KP0>05aLG01YJFT0GEeM07=cL`2DU9@0PX:208b<S02HV9P0UiNG096AT@2PX:00Ti>C09fMW@2OWil2
0:6QX@0509ZJVP2QXJ40XJ6Q0:BTY02UYJD07P3oool0102QXJ40Vi^K09nOW`2UYJD209^KV`040:FU
Y@2PX:00XJ6Q0:BTY080XJ6Q00h0Vi^K09fMW@2NWYh0Y:BT0::RXP2NWYh0VYZJ0:2PX02KVi/0XJ6Q
09fMW@2KVi/0TI6A08:2PP80GemO0180EUIF04];B`1>CTh0>SXj03hn?P1JFUX0?Cdm02HV9P0R8R80
i>CT07YjNP27QhL0PX:208N7Q`22PX80M7Ad07QhN01mOGd207MgM`0M07IfMP1hN7P0NGUi07IfMP1g
MgL0Ng]k07=cL`1gMgL0LW9b07=cL`1dM7@0L71`07AdM01ZJVX0IVIV05eMG@1PH600MgMg065QH@1:
BTX0GEeM055AD@1IFET0?Shn059BDP1?Cdl0DE5A06MWI`1TI6@00P1OGel07@1PH600FEUI06MWI`1@
D500JVYZ08B4Q01cLg<0N7Qh061PH01ZJVX0I6AT07=cL`2DU9@0PX:208^;R`2YZJT0YZJV09VIV@2P
X:00Ti>C09jNWP2TY:@0YZJV0:6QX@2JVYX0WIfM09ZJVP2NWYh0Xj>S01h0oooo00@0MWIf071`L01i
NGT0Ng]k0P1`L700101gMgL0N7Qh07IfMP1iNGT207IfMP06071`L01eMGD0M7Ad07UiN@1kNg/0M7Ad
0P1bLW800`1aLG40Lg=c06m_K`0206e]K@0Q06=SH`1?Cdl0AdM70410@00f=SH0>3Ph030`<00c<c<0
AdM7034a<@0I6AT061PH07alO01KFe/0GEeM05]KF`1SHf<0H61P05ADE01?Cdl0FUYJ05=CD`1ADE40
EEEE05=CD`1ADE40EEEE05ADE01HF5P0Cdm?05=CD`1?Cdl0DE5A0080D51@00<0E5AD04a<C019BDT0
0P16ATH0201DE5@0ATI602h^;P0k>c/0=SHf03Ti>@0Y:BT0@D510P0l?3`08@13@d<0BDU904e=C@1;
Bd/0ADE503hn?P1:BTX0>3Ph04a<C01KFe/0FUYJ061PH01>CTh0CDe=055AD@1BDU80IFEU05iNGP1R
HV80QHF508B4Q01gMgL0Lg=c06e]K@1dM7@0Ng]k07alO01fMWH0LW9b06m_K`1/K6`0KVi^07AdM00R
0?ooo`00803oool02P2QXJ40WIfM09jNWP2UYJD0WIfM09ZJVP2UYJD0XJ6Q09jNWP2UYJD20:6QX@<0
WIfM0P2QXJ4209ZJVP0D09jNWP2QXJ40VIVI09jNWP2RXZ80S8b<07MgM`1TI6@0JFUY05IFEP1<C4`0
Cdm?03@d=01;Bd/0@d=303De=@0_;bl08B4Q0>GUi@1nOWh20861P@0?07moO`28R8P0MgMg07=cL`1h
N7P0MgMg07alO01gMgL0M7Ad07emO@1jNWX0M7Ad07YjNP1dM7@0OGem0080LG5a0380LW9b07UiN@1_
Kfl0KVi^06ATI01LG5`0JFUY06YZJP1HF5P0EEEE05ADE01CDe<0B4Q8051@D011@D40DU9B05IFEP1]
KFd0IFEU065QH@1ADE40FUYJ05EEE@1NGUh0HV9R061PH028R8P0NGUi06m_K`1RHV80MgMg061PH01g
MgL0RXZ:0861P@2FUYH0Vi^K09RHV02OWil0X:2P09VIV@2MWId0YJFU09jNWP2UYJD0WIfM09^KV`2L
W9`0XJ6Q09jNWQh0oooo00X0XJ6Q0:2PX02KVi/0Xj>S0:2PX02MWId0YJFU0:6QX@2NWYh0Xj>S0P2Q
XJ420:2PX0030::RXP2TY:@0XJ6Q0080VYZJ04l0WYjN0:BTY02JVYX0W9bL0:BTY02?Shl0Kfm_05QH
F01WIfL0FUYJ04a<C01?Cdl0<S8b04a<C010@400;Rh^02l_;`0R8R80i^KV07moO`23Ph<0QhN707al
O025QHD0Ng]k07MgM`1fMWH0M7Ad07]kN`1fMWH0LG5a07UiN@1gMgL0LW9b07AdM01aLG40O7al079b
LP1^KVh0KFe]07EeM@1/K6`0Jf][06ATI01JFUX0Jf][06UYJ@1>CTh0De=C051@D01<C4`0?Shn04U9
B@0i>CT0BDU905ADE01cLg<0JFUY06=SH`1JFUX0Fe]K05=CD`1EEED0HV9R05iNGP21PH40MgMg06YZ
JP1MGEd0Ogmo06ATI021PH40TI6A0861P@2LW9`0X:2P092@T02FUYH0X:2P0080WYjN00P0YZJV09^K
V`2SXj<0X:2P0:6QX@2MWId0YJFU09jNWQh0oooo00P0MWIf07QhN01`L700M7Ad07QhN01eMGD0MgMg
07IfMP80M7Ad0P1fMWH207QhN00307]kN`1iNGT0MWIf0080LW9b02T0M7Ad07UiN@1cLg<0L71`07Ui
N@1_Kfl0DE5A03hn?P1=CDd0B4Q803Ti>@0j>SX09RHV03Hf=P0];Bd07QhN024Q8@0J6QX0Ogmo05mO
G`1QHF40IVIV05QHF01MGEd0H61P05aLG01FEUH0De=C05QHF01EEED0DE5A05EEE@1DE5@0De=C051@
D01ADE40F5QH05EEE@1?Cdl0Bd];059BDP0204e=C@0?04];B`12@T80Cdm?04];B`0e=CD0?3`l03Lg
=`0b<S809bLW034a<@0T92@0;Bd]03Xj>P1CDe<0D51@0080Bd];01d0@d=303`l?00f=SH0AdM704A4
A01CDe<0EEEE04a<C014A4@0H61P055AD@1SHf<0JFUY05iNGP1cLg<0MGEe069RHP1VIVH0Lg=c07Ui
N@1eMGD0N7Qh071`L01dM7@0N7Qh07alO01eMGD0Ng]k07AdM00R0?ooo`00803oool20:6QX@0709fM
W@2NWYh0XZ:R0:6QX@2NWYh0XJ6Q09fMW@020:6QX@0309jNWP2UYJD0XJ6Q0080XJ6Q01l0WYjN0:6Q
X@2JVYX0Vi^K0:JVYP2JVYX0Xj>S09jNWP2FUYH0Fe]K06MWI`1TI6@0GUiN055AD@14A4@0>SXj04m?
C`0i>CT0<30`03@d=00T92@0h>3P07UiN@2:RXX0QHF507YjNP1oOgl0R8R807=cL`1jNWX0MGEe0080
MgMg00/0M7Ad079bLP1kNg/0LG5a07AdM01hN7P0MgMg06i^KP1bLW80KFe]07=cL`0206m_K`0406QX
J01LG5`0LG5a05eMG@80D51@0280CTi>04U9B@1<C4`0Bd];0451@@1<C4`0EUIF06YZJP1]KFd0H61P
05QHF01NGUh0C4a<05EEE@1JFUX0KVi^07=cL`1eMGD0MgMg06QXJ01eMGD0Lg=c0861P@2;Rh/0QXJ6
09jNWP2OWil0UYJF09FEU@2HV9P0YjNW09ZJVP2UYJD0WIfM1@2QXJ400`2JVYX0oooo0?ooo`0L0?oo
o`80XJ6Q00/0X:2P09jNWP2MWId0XJ6Q09jNWP2JVYX0X:2P0:BTY02QXJ40Vi^K0:>SX`030:6QX@0I
09^KV`2QXJ40VYZJ09VIV@2QXJ40UYJF0:FUY@2OWil0UiNG05IFEP1PH600GUiN05QHF01;Bd/0?clo
03Lg=`1@D500>CTi02l_;`0h>3P09RHV0>KViP1dM7@0Q8B408:2PP0207UiN@0508:2PP1cLg<0MWIf
07EeM@1cLg<00P1bLW80=@1^KVh0MWIf06a/K01_Kfl0MWIf07EeM@1YJFT0KVi^06a/K01`L700Jf][
06i^KP1QHF40FUYJ075aL@1JFUX0C4a<04];B`1:BTX0ADE504i>CP1@D500?clo04e=C@1FEUH0IFEU
06MWI`1MGEd0F5QH06ATI01>CTh0EEEE05=CD`1bLW80NGUi06i^KP1gMgL0MWIf07moO`1ZJVX0PH61
08^;R`2:RXX0YJFU09fMW@2OWil0X:2P09RHV02SXj<0WIfM0:FUY@2PX:00Y:BT0080XJ6Q0P2TY:@0
0`2JVYX0oooo0?ooo`0L0?ooo`80MWIf00/0N7Qh07AdM01_Kfl0MWIf07AdM01/K6`0N7Qh07UiN@1f
MWH0L71`07AdM00307IfMP0c071`L01fMWH0LW9b06m_K`1`L700K6a/07YjNP1eMGD0LW9b04Q8B015
ADD0@T9203hn?P0b<S80:b/[02PX:00i>CT0:b/[02<S8`0[:b/07alO08>3P`1CDe<0FUYJ05eMG@1J
FUX0E5AD05UIF@1GEeL0EEEE05MGE`1BDU80D51@05=CD`1=CDd0DE5A04a<C01=CDd0De=C059BDP1:
BTX0CTi>04m?C`1>CTh0C4a<051@D013@d<0@T9204m?C`12@T80=cLg0080<c<c0280<30`03`l?00n
?Sh0;Bd]03Ph>00l?3`0@D5104I6AP13@d<0A4A404e=C@0o?cl0?Shn03De=@1EEED0FUYJ04Y:BP1G
EeL0Hf=S069RHP17AdL0FUYJ069RHP1XJ6P0N7Qh06m_K`1lO7`0OWin06m_K`1cLg<0MGEe07MgM`1h
N7P0NGUi0P1fMWH207UiN@03079bLP3oool0oooo0200oooo000P0?ooo`0@0::RXP2QXJ40WYjN09jN
WP2MWId0XZ:R0:>SX`2TY:@0Vi^K0:6QX@2MWId0Xj>S09jNWP2JVYX0XJ6Q09NGU`80XJ6Q01L0WIfM
0:6QX@2NWYh0WIfM0:BTY02IVIT0LG5a06][J`1QHF40G5aL04m?C`1EEED0>c/k05=CD`0g=cL0>CTi
01dM7@0/;2`0:RXZ0=oOg`1`L700Ph>307emO@0207YjNP0;07AdM01iNGT0MgMg07AdM01/K6`0LW9b
06m_K`1bLW80JFUY06ATI01YJFT00P1]KFd05P1^KVh0JFUY06UYJ@1YJFT0HF5Q06ATI01JFUX0IfMW
04Y:BP18B4P0ATI604M7A`1DE5@0D51@030`<00l?3`0EeMG05eMG@1DE5@0Fe]K06QXJ01iNGT2075a
L@070492@P18B4P0H61P06UYJ@1TI6@0S8b<07IfMP0306QXJ00<09ZJVP2<S8`0V9RH08^;R`2BTY80
WIfM09bLW02WYjL0UiNG0:NWY`2QXJ40WYjN0`2QXJ400`2OWil0XJ6Q09fMW@0N0?ooo`0@09fMW@2Q
XJ40WYjN09^KV`2LW9`0WIfM09^KV`2NWYh0XJ6Q0:FUY@2IVIT0XZ:R09jNWP2JVYX0Y:BT09ZJVP80
YJFU01L0XZ:R0:BTY02KVi/0VIVI0:2PX02HV9P0JFUY06=SH`1LG5`0FEUI04e=C@1?Cdl0>SXj05MG
E`0e=CD0<C4a01XJ6P0[:b/0:RXZ0=kNgP1`L700Ph>30820P00207MgM`0>075aL@1bLW80MGEe075a
L@1/K6`0Kfm_06][J`1`L700Jf][06MWI`1YJFT0JVYZ06QXJ01]KFd206IVIP0a06UYJ@1LG5`0GUiN
05=CD`1RHV80AdM704=3@`10@400B4Q805=CD`1@D500:b/[034a<@1BDU80Hf=S05eMG@1OGel0IFEU
071`L01YJFT0Lg=c05EEE@1BDU80J6QX06a/K01QHF40Q8B407MgM`1QHF40H61P06QXJ02KVi/0S8b<
0:JVYP2HV9P0UIFE09jNWP2MWId0[:b/09FEU@2SXj<0XJ6Q09^KV`2QXJ40Y:BT0:6QX@2PX:00YJFU
0:2PX00N0?ooo`0@06m_K`1fMWH0M7Ad071`L01bLW80KVi^06][J`1^KVh0O7al07]kN`1^KVh0MGEe
07AdM01bLW80NGUi07AdM0<0Ng]k01H0NGUi071`L01^KVh0LG5a071`L01?Cdl0BDU904A4A012@T80
>c/k03<c<`0/;2`0@41002LW9`0N7Qh04a<C01hN7P0M7Ad0Ng]k05EEE@1MGEd0H61P0P1FEUH03P1A
DE40CTi>059BDP1BDU80D51@04i>CP1<C4`0D51@055AD@1?Cdl0CDe=04];B`17AdL0Cdm?0P19BDT0
2@1=CDd0@D510410@00j>SX0@T9203Hf=P0_;bl0:RXZ03Hf=P0203Xj>P0H01dM7@0J6QX0=CDe04Y:
BP1<C4`0B4Q804I6AP17AdL0ADE505MGE`1EEED0AdM7055AD@1@D500A4A405=CD`1GEeL0A4A404=3
@`1<C4`0IfMW06ATI020P800NGUi0P1bLW80301dM7@0OGem06i^KP1cLg<0MWIf071`L01fMWH0NGUi
07IfMP1gMgL0Ng]k07QhN280oooo000P0?ooo`0509fMW@2QXJ40WIfM09ZJVP2PX:000P2KVi/02P2M
WId0XJ6Q0:6QX@2KVi/0WIfM0:2PX02IVIT0YjNW09VIV@2UYJD209jNWP0:0:6QX@2PX:00WinO09NG
U`2PX:00Jf][075aL@1FEUH0FEUI04e=C@80@d=301X0D51@03@d=00];Bd092@T02`/;00^;Rh0b/[:
07UiN@1mOGd0Ogmo07QhN01fMWH0N7Qh071`L01^KVh0M7Ad071`L01XJ6P0KFe]06m_K`1`L700J6QX
06ATI01`L700JFUY07AdM080JFUY01/0HF5Q061PH01QHF40D51@06i^KP13@d<0=cLg059BDP16ATH0
AdM703/k>`0c<c<092@T05aLG01=CDd0IFEU055AD@1VIVH0Lg=c06EUI@1oOgl0D51@05MGE`1WIfL0
Kfm_061PH025QHD00P1YJFT03@1OGel0Ng]k092@T02?Shl0WIfM09:BTP2SXj<0VIVI09bLW02WYjL0
UiNG0:FUY@2QXJ400P2MWId01@2WYjL0WYjN09jNWP2UYJD0XJ6Q01h0oooo00P0XZ:R0:BTY02PX:00
WIfM0:>SX`2RXZ80Xj>S0:BTY080XJ6Q00L0WinO09fMW@2LW9`0V9RH0:JVYP2IVIT0YZJV00<0Vi^K
01<0W9bL0:>SX`2IVIT0WinO05mOG`1/K6`0De=C059BDP17AdL0@D5103lo?`1=CDd0<S8b02`/;00U
9BD0;bl_030`<03:b/X0Lg=c0080NGUi02d0M7Ad079bLP1gMgL0Lg=c06][J`1_Kfl0KFe]06EUI@1W
IfL0J6QX06ATI01QHF40GUiN06][J`1YJFT0JVYZ06IVIP1YJFT0G5aL05]KF`1QHF40CTi>06i^KP14
A4@0<S8b051@D015ADD0@T92030`<00[:b/08B4Q06][J`1=CDd0GUiN04e=C@1PH600LG5a06][J`23
Ph<0DE5A05iNGP1bLW80L71`06=SH`29RHT00P1QHF40501KFe/0PX:209jNWP2KVi/0XJ6Q08n?S`2Q
XJ40X:2P0:6QX@2WYjL0VIVI0:JVYP2QXJ40X:2P09^KV`2SXj<0Vi^K09jNWP2SXj<0XJ6Q7P3oool0
201kNg/0NGUi07QhN01eMGD0NWYj07emO@1nOWh0OGem0P1fMWH01`1iNGT0Lg=c071`L01`L700MgMg
07=cL`1hN7P00P1`L700401]KFd0L71`07YjNP1bLW80Lg=c04M7A`1?Cdl0@41003Ti>@0b<S80;Rh^
02`/;00d=3@09RHV020P800M7Ad202DU9@03079bLP1ADE40EEEE0080De=C02`0D51@05IFEP1GEeL0
CDe=04a<C01?Cdl0B4Q804M7A`16ATH0?clo04=3@`11@D40BTY:04e=C@14A4@0BDU904e=C@11@D40
@41004I6AP0j>SX0CDe=03Lg=`0T92@0>3Ph03<c<`0];Bd06a/K01`L700F5QH0EEEE03Ph>00m?Cd0
=SHf03hn?P1=CDd0EUIF05mOG`13@d<0C4a<05YJFP1@D500CTi>061PH080@d=300P0@D51065QH@1g
MgL0MgMg07AdM01XJ6P0LW9b07YjNP80N7Qh00L0M7Ad07QhN01fMWH0N7Qh075aL@1cLg<0L71`0080
M7Ad00<0MWIf0?ooo`3oool0803oool00200oooo0P2QXJ404P2UYJD0VYZJ0::RXP2QXJ40Y:BT0::R
XP2NWYh0YJFU0:6QX@2LW9`0WIfM09NGU`2SXj<0X:2P0:6QX@2SXj<0VYZJ0:2PX0<0WIfM01l0Vi^K
06a/K01/K6`0DE5A05UIF@17AdL0@d=30410@016ATH0:RXZ02h^;P0X:2P0;Bd]02h^;P34a<@0N7Qh
07UiN@1bLW80N7Qh075aL@1kNg/0LG5a06m_K`1/K6`0L71`06ATI01PH600Hf=S05aLG01WIfL0HF5Q
0080IfMW00/0J6QX06=SH`1WIfL0H61P05UIF@1OGel0EeMG06a/K00o?cl0<C4a05EEE@0203Lg=`0O
030`<00i>CT0=CDe06UYJ@1@D500EEEE05QHF01?Cdl0OWin07IfMP1ZJVX0HF5Q05aLG01[Jf/0IVIV
07]kN`1fMWH0GEeM06m_K`1LG5`0MgMg09JFUP2[Zj/0Q8B409JFUP2HV9P0YjNW09bLW02QXJ40WIfM
0:FUY@020:6QX@0609^KV`2QXJ40WIfM09ZJVP2UYJD0WYjN7P3oool20:6QX@0A0:>SX`2JVYX0X:2P
09ZJVP2NWYh0WIfM09^KV`2SXj<0XJ6Q09nOW`2SXj<0UiNG09nOW`2LW9`0WIfM0::RXP2JVYX00P2S
Xj<309^KV`04065QH@1SHf<0B4Q805EEE@80ADE500D0@T9204A4A00U9BD0:RXZ02LW9`0202d];@09
0<C4a01hN7P0N7Qh07UiN@1jNWX0M7Ad07inOP1dM7@0MgMg0080MGEe01d0JVYZ065QH@1LG5`0FUYJ
061PH01MGEd0HV9R05iNGP1XJ6P0G5aL05iNGP1KFe/0EEEE05QHF01@D500JVYZ03Xj>P0^;Rh0De=C
03<c<`0_;bl0:b/[03Ph>00o?cl0IfMW05MGE`1HF5P0FUYJ04i>CP0207QhN00E06IVIP1LG5`0GEeM
06MWI`1SHf<0P82007moO`1LG5`0LG5a06=SH`21PH40U9BD0;Fe]@2;Rh/0Ti>C09fMW@2XZ:P0Xj>S
0:FUY@2PX:00YJFU0080XJ6Q00H0WinO0:FUY@2PX:00VYZJ0:FUY@2KVi/N0?ooo`80MWIf00/0M7Ad
079bLP1bLW80K6a/06i^KP1_Kfl0L71`07AdM01fMWH0N7Qh07alO003071`L00506m_K`1eMGD0LW9b
07YjNP1lO7`00P1aLG407P1bLW80ATI604A4A00d=3@0?3`l03De=@0f=SH0<S8b02l_;`0J6QX071`L
01dM7@0Q8B40820P06m_K`1GEeL0F5QH05mOG`1KFe/0FEUI05iNGP1IFET0GemO05eMG@1KFe/0EEEE
04Y:BP0o?cl0@D5103lo?`80@T9201X0?Cdm04];B`0o?cl0?Cdm0410@00m?Cd0>c/k03Lg=`17AdL0
;2`/028R8P0f=SH09BDU01dM7@0L71`0:2PX03Ph>015ADD0AdM70492@P13@d<0>3Ph04];B`1HF5P0
B4Q804=3@`80AdM70140ATI605iNGP1QHF40B4Q805ADE01ADE40Hf=S06ATI024Q8@0KVi^06QXJ01f
MWH0NGUi07emO@1jNWX0N7Qh07MgM`0207IfMP0607UiN@1kNg/0N7Qh079bLP1gMgL0L71`8P3oool0
0200oooo0280XZ:R0:FUY@2KVi/0WinO0:FUY@2HV9P0XJ6Q09fMW@2NWYh0YJFU0:6QX@2MWId0YjNW
09nOW`2GUiL0X:2P09^KV`2WYjL0VYZJ0::RXP2QXJ40WIfM09nOW`2FUYH0J6QX05mOG`1?Cdl0EEEE
04Y:BP1EEED0=CDe04E5A@0H61P0>CTi0P0Y:BT00`0o?cl0];Bd08F5Q@0207UiN@0507QhN01eMGD0
LW9b07MgM`1cLg<00P1dM7@02P1/K6`0HV9R05aLG01LG5`0GUiN061PH01OGel0G5aL069RHP1UIFD2
05aLG00W05]KF`1CDe<0De=C06QXJ00a<C40>CTi055AD@0b<S80:BTY02l_;`1BDU80<30`06UYJ@1J
FUX0DE5A05=CD`1EEED0MGEe07moO`1ZJVX0IVIV05ADE01TI6@0EeMG09ZJVP1fMWH0G5aL06m_K`1e
MGD0PH610:2PX02JVYX0SHf=096AT@2IVIT0Y:BT0:FUY@2NWYh0YJFU0080XJ6Q00L0WYjN0:FUY@2Q
XJ40XJ6Q09fMW@2NWYh0WIfM01h0oooo02/0WIfM0:>SX`2IVIT0V9RH0:FUY@2LW9`0YJFU0::RXP2K
Vi/0YJFU0:6QX@2IVIT0Xj>S0:2PX02KVi/0X:2P09^KV`2WYjL0VYZJ0:2PX02JVYX0VIVI09fMW@2B
TY80IVIV05aLG01<C4`0De=C04Y:BP1IFET0=cLg04A4A00F5QH0=SHf02`/;00X:2P0@T920;no_`2?
Shl0SHf=08J6QP2:RXX0RHV90080P82000L0NWYj07UiN@1lO7`0MWIf075aL@1]KFd0F5QH00<0G5aL
0P1GEeL0;P1OGel0Fe]K05MGE`1IFET0DU9B051@D01SHf<0:b/[03Hf=P1BDU80;2`/02DU9@0/;2`0
FEUI03<c<`1ZJVX0FUYJ055AD@1>CTh0DU9B07IfMP20P800M7Ad07QhN01PH600JVYZ04];B`2@T900
MWIf05]KF`1[Jf/0NWYj08V9R@2l_;`0Z:RX08n?S`2LW9`0WIfM0:FUY@2SXj<0Vi^K0:>SX`2TY:@0
XJ6Q09^KV`2SXj<20:6QX@030:2PX02NWYh0VIVI01h0oooo00H0Kfm_07AdM01_Kfl0JVYZ07MgM`1f
MWH207]kN`0:071`L01gMgL0MWIf06i^KP1cLg<0MgMg07IfMP1dM7@0Lg=c07QhN080LW9b0240K6a/
06i^KP1bLW80JFUY051@D015ADD0>c/k03`l?00h>3P0@d=302d];@0`<3004A4A02@T900R8R807AdM
038b<P1iNGT0KVi^07MgM`1_Kfl0M7Ad07EeM@1ZJVX0IVIV061PH01NGUh0HF5Q061PH01RHV80H61P
03hn?P11@D400P10@400<00l?3`0=SHf0410@011@D40?3`l0410@00l?3`0=cLg0451@@0P82009bLW
03Ti>@0O7al06QXJ01hN7P12@T80:BTY04Q8B012@T80?Cdm03De=@0k>c/0D51@05]KF`1PH600J6QX
05ADE01BDU80;bl_05EEE@1FEUH0AdM704Y:BP1LG5`0J6QX09JFUP21PH40KVi^07YjNP1fMWH0MgMg
07AdM01`L700M7Ad07UiN@1fMWH0L71`07AdM080MWIf00<0N7Qh07AdM01^KVh08P3oool00200oooo
00T0WIfM09jNWP2NWYh0VIVI0:6QX@2JVYX0YJFU0:6QX@2MWId00P2QXJ403`2HV9P0YJFU09jNWP2P
X:00WIfM09JFUP2YZJT0XJ6Q09VIV@2LW9`0WYjN09bLW023Ph<0JFUY05iNGP02055AD@0K0451@@1:
BTX0ATI603<c<`0M7Ad0>SXj030`<00X:2P0K6a/0:JVYP26QXH0T92@08N7Q`24Q8@0QhN70861P@1l
O7`0LW9b07YjNP1iNGT0M7Ad079bLP1[Jf/0F5QH055AD@1FEUH0GemO0080Fe]K01P0EEEE061PH01K
Fe/0FEUI059BDP18B4P0Hf=S03@d=014A4@0EEEE02l_;`0W9bL0>3Ph05mOG`0Z:RX0GUiN069RHP1<
C4`0CTi>05UIF@1/K6`0RXZ:07UiN@1dM7@2065QH@0?05mOG`20P800MGEe06QXJ01YJFT0RHV909FE
U@2m_Kd0SXj>09>CT`2VYZH0YjNW09ZJVP2UYJD0VIVI0080Y:BT00P0XZ:R0:6QX@2QXJ40WYjN0:FU
Y@2QXJ40WIfM09^KVah0oooo01D0XZ:R09jNWP2PX:00Xj>S0:JVYP2JVYX0YJFU0:6QX@2RXZ80Y:BT
0:6QX@2IVIT0YjNW09jNWP2QXJ40Xj>S09NGU`2XZ:P0XJ6Q09ZJVP2KVi/00P2OWil01P1jNWX0GemO
05QHF01?Cdl0D51@03`l?080@d=303<0<S8b01/K6`0l?3`0<C4a02PX:01mOGd0bLW909:BTP2HV9P0
RXZ:08J6QP27QhL0R8R808V9R@1kNg/0PH6107inOP1hN7P0MWIf075aL@1YJFT0EeMG059BDP1IFET0
Fe]K05eMG@1@D500FEUI05]KF`1IFET0DE5A04A4A01LG5`0=CDe04a<C01PH600:b/[02HV9P0k>c/0
IFEU02`/;01JFUX0GUiN04Y:BP1<C4`0FEUI06YZJP24Q8@0NGUi07AdM01TI6@00P1UIFD06026QXH0
K6a/06MWI`1`L700U9BD092@T02n_[h0Rh^;08R8R02OWil0Z:RX09fMW@2UYJD0UiNG0:2PX02NWYh0
WIfM0:6QX@2TY:@0Vi^K0:>SX`2QXJ40X:2P0:6QXAh0oooo01X0Ng]k07AdM01hN7P0P82007alO01b
LW80MgMg07IfMP1kNg/0NGUi07IfMP1cLg<0NGUi07AdM01gMgL0O7al075aL@1gMgL0MWIf07=cL`1a
LG40MGEe07IfMP1HF5P0@T9203lo?`80?3`l00d0:RXZ02/[:`0`<3009BDU01HF5P0Z:RX09RHV01hN
7P1MGEd0UiNG079bLP1dM7@0J6QX0080I6AT01l0Jf][06m_K`1SHf<0I6AT069RHP1LG5`0FUYJ05UI
F@1MGEd0AdM703Xj>P0m?Cd0@T9204I6AP0g=cL0>SXj0492@P11@D40?3`l030`<00k>c/0;Bd]03hn
?P1<C4`07AdM01`L700[:b/0AdM702HV9P0j>SX0?clo0080=cLg00H0?clo04M7A`1FEUH0F5QH05EE
E@1ADE4204i>CP0;05eMG@18B4P0CTi>05QHF01^KVh0GemO07emO@1VIVH0G5aL06a/K01iNGT00P1g
MgL02`1`L700LG5a06i^KP1_Kfl0MWIf07UiN@1`L700M7Ad07IfMP1hN7P0O7al0280oooo000P0?oo
o`080::RXP2QXJ40YjNW09jNWP2QXJ40Xj>S09fMW@2WYjL20:6QX@0909jNWP2MWId0YjNW09jNWP2U
YJD0WYjN09^KV`2UYJD0XJ6Q0080WIfM03T0X:2P09jNWP1cLg<0HF5Q05mOG`1>CTh0D51@04M7A`10
@400C4a<01hN7P0];Bd0>SXj02/[:`1NGUh0Ph>308b<S02;Rh/0SHf=08:2PP2>SXh0Ogmo08f=S@24
Q8@0OWin07moO`1fMWH0NWYj07=cL`1dM7@0JFUY05QHF01CDe<0BTY:05UIF@1JFUX0FEUI05=CD`1N
GUh0EEEE04a<C00k>c/0@41005iNGP0l?3`0KVi^02TY:@0N7Qh0:b/[06a/K011@D40GEeM06e]K@12
@T80HV9R04a<C01YJFT00P21PH403`1fMWH0Hf=S04M7A`1RHV80Lg=c06QXJ01hN7P0MWIf0820P02Y
ZJT0UiNG08b<S02JVYX0WinO0:FUY@0209fMW@0;0:6QX@2MWId0WIfM09ZJVP2RXZ80YJFU09fMW@2Q
XJ40WYjN0:FUY@2QXJ407P3oool00`2MWId0XJ6Q0:JVYP0209^KV`030::RXP2KVi/0Xj>S0080XJ6Q
00h0Vi^K09VIV@2VYZH0Vi^K0:FUY@2KVi/0VYZJ0:RXZ02MWId0VIVI09fMW@2PX:00WYjN07=cL`80
FUYJ01d0BTY:04];B`1;Bd/0@41004a<C00K6a/0:b/[03hn?P0[:b/0Ng]k0<_;b`2`/;00UIFE092@
T027QhL0U9BD08N7Q`2@T900QhN708>3P`2:RXX0O7al07moO`1gMgL0NGUi079bLP1YJFT0J6QX055A
D@0205ADE00E05YJFP1EEED0Fe]K059BDP17AdL0=SHf03@d=01HF5P0@410075aL@0V9RH06a/K02HV
9P1TI6@0Bd];05UIF@1bLW80ADE506][J`1DE5@0JFUY0080QhN700d0Q8B4071`L011@D40JFUY075a
L@1PH600LW9b07alO01nOWh0`L710::RXP20P800W9bL0080ZZZZ00<0X:2P09bLW02QXJ400P2TY:@0
202MWId0X:2P0:>SX`2PX:00Y:BT09^KV`2SXj<0XJ6Q7P3oool0201_Kfl0MWIf07MgM`1`L700KFe]
07EeM@1aLG40Lg=c0P1fMWH03P1`L700KVi^07MgM`1`L700MgMg071`L01bLW80NWYj06m_K`1]KFd0
Lg=c07EeM@1dM7@0GEeM0P11@D405`0g=cL0=CDe03`l?00`<300=SHf01@D500N7Qh0;Rh^020P801Z
JVX0^[Zj09>CT`1dM7@0Jf][06QXJ01aLG40Jf][06a/K01WIfL0IVIV06i^KP1RHV80HF5Q0080GEeM
02l0G5aL05iNGP1PH600@d=303Xj>P0h>3P0@d=30410@00o?cl0>SXj038b<P0V9RH071`L03Xj>P0d
=3@0CTi>01/K6`0B4Q805QHF03Ti>@13@d<0>SXj059BDP0i>CT0De=C04E5A@19BDT0HV9R06EUI@1/
K6`0H61P030`<01@D500CDe=0410@01<C4`0GEeM05QHF02BTY80Ng]k05QHF01bLW80PH6107emO@1h
N7P0LW9b07IfMP0207emO@0807EeM@1bLW80M7Ad07QhN01iNGT0L71`07AdM01fMWHR0?ooo`00803o
ool0202QXJ40WIfM0:6QX@2MWId0YjNW0:6QX@2KVi/0WIfM0P2QXJ401`2MWId0WinO09fMW@2MWId0
VYZJ0:6QX@2MWId00P2QXJ400`2NWYh0VIVI09BDU00207alO00F069RHP1CDe<0AdM70410@019BDT0
@d=302TY:@0V9RH0>SXj02h^;P1KFe/0SXj>08F5Q@2CTi<0TI6A09FEU@2@T900Shn?08N7Q`29RHT0
PX:208F5Q@80QhN700T0PH6107emO@1kNg/0MWIf07=cL`1[Jf/0I6AT04Y:BP0l?3`00P1BDU80:01?
Cdl0CTi>04Q8B00e=CD0<30`07emO@0i>CT0IVIV01/K6`0Q8B40=3@d04Y:BP1YJFT0D51@05]KF`1G
EeL0D51@075aL@1OGel0M7Ad08R8R02>SXh0MGEe04Y:BP1/K6`0GemO079bLP2:RXX0Ng]k06m_K`2T
Y:@0XZ:R09JFUP2KVi/0W9bL09VIV@2UYJD0VYZJ0:FUY@2NWYh20:6QX@80WIfM00D0WYjN0:FUY@2Q
XJ40WYjN0:FUY@0N0?ooo`0^0:6QX@2PX:00XJ6Q09VIV@2SXj<0XJ6Q09nOW`2TY:@0YJFU0:6QX@2I
VIT0W9bL09fMW@2PX:00WIfM0:BTY02RXZ80Y:BT0:6QX@2KVi/0UYJF09>CT`1hN7P0M7Ad05eMG@1@
D500B4Q804=3@`1;Bd/0@D5102HV9P0U9BD0>SXj02/[:`1/K6`0TY:B08>3P`2@T900SXj>09:BTP2A
TI40T92@08b<S02CTi<0QhN708>3P`80QhN703<0OWin07QhN01oOgl0NGUi07IfMP1aLG40Jf][05EE
E@15ADD0CDe=04i>CP1<C4`0Bd];04A4A00c<c<0<C4a07]kN`15ADD0Kfm_01dM7@0L71`0<c<c05UI
F@1cLg<0JFUY061PH01OGel0Cdm?06YZJP1RHV80M7Ad08:2PP26QXH0Ng]k04m?C`1ZJVX0FEUI06][
J`2>SXh0QXJ607QhN02EUID0X:2P0:JVYP2UYJD0X:2P09VIV@2VYZH0VYZJ0:FUY@2KVi/00P2TY:@0
1`2PX:00XZ:R09jNWP2SXj<0XJ6Q09^KV`2SXj<07P3oool0501fMWH0N7Qh07IfMP1^KVh0Lg=c07If
MP1iNGT0OGem07YjNP1fMWH0KVi^071`L01cLg<0N7Qh07EeM@1iNGT0Ng]k07UiN@1fMWH0L71`0P1]
KFd04P1KFe/0DU9B0451@@0l?3`0>CTi03De=@0g=cL0;Rh^01`L700K6a/0:2PX01dM7@1GEeL0K6a/
05mOG`1VIVH0IFEU06MWI`80JVYZ0100K6a/07=cL`1XJ6P0GemO06=SH`1TI6@0Fe]K05EEE@1QHF40
G5aL05YJFP1IFET0EUIF04a<C00n?Sh0=3@d0P0f=SH09`0d=3@0<30`02HV9P0U9BD0Bd];04=3@`1@
D50071`L014A4@0U9BD0BDU905=CD`1NGUh0BDU904e=C@0j>SX0ADE504Y:BP1BDU80E5AD05UIF@1R
HV80ADE504Q8B00m?Cd0AdM706ATI01YJFT0HF5Q05QHF01`L700QHF507moO`1gMgL0Lg=c07QhN01b
LW80MgMg071`L00207UiN@0707QhN01kNg/0M7Ad07AdM01fMWH0L71`07AdM00R0?ooo`00803oool0
3@2SXj<0YjNW0:FUY@2KVi/0XJ6Q09fMW@2WYjL0WYjN0:FUY@2NWYh0W9bL09jNWP2KVi/00P2NWYh0
5P2QXJ40YjNW0:6QX@2YZJT0VIVI09ZJVP2>SXh0OGem06a/K01NGUh0Cdm?04U9B@0k>c/0BDU904M7
A`0K6a/0<30`03De=@0o?cl0XZ:R09:BTP27QhL208f=S@0=09FEU@2HV9P0RXZ:092@T02HV9P0PX:2
08F5Q@27QhL0R8R80861P@1lO7`0N7Qh07UiN@0207AdM00T06][J`1MGEd0BTY:03`l?01ADE40CDe=
04A4A01;Bd/0=cLg02<S8`1`L700MGEe030`<00R8R80=3@d020P801OGel0@d=304M7A`1WIfL0GemO
05QHF01OGel0Jf][08Z:RP1XJ6P0W9bL08Z:RP10@400K6a/05iNGP1_Kfl0O7al08R8R01jNWX0V9RH
0P2OWil0102SXj<0WIfM0:6QX@2NWYh20:6QX@0809ZJVP2UYJD0WYjN0::RXP2UYJD0VYZJ0::RXP2N
WYh20:6QXAh0oooo00T0Vi^K0:>SX`2SXj<0WinO0:FUY@2IVIT0Xj>S09^KV`2SXj<00P2KVi/09`2O
Wil0Vi^K09^KV`2KVi/0WIfM0:>SX`2QXJ40Y:BT09NGU`2HV9P0RHV907QhN01VIVH0GUiN04e=C@16
ATH0=SHf04=3@`15ADD06ATI02h^;P0f=SH0AdM70=;BdP2@T900RXZ:092@T02=SHd0UIFE09>CT`24
Q8@0QhN709BDU022PX80QHF508J6QP28R8P0QHF508J6QP0207alO080MWIf01l0LG5a06QXJ01EEED0
@T9204i>CP1;Bd/0@D5104Q8B00e=CD07alO06EUI@1lO7`0;bl_03@d=01EEED0:2PX05aLG00j>SX0
@D5105mOG`1MGEd0GemO06ATI01[Jf/0QhN706EUI@2DU9@0TY:B04E5A@1/K6`0HV9R0080MgMg01D0
NGUi075aL@2ZZZX0ZJVY09^KV`2OWil0Vi^K0:6QX@2NWYh0XJ6Q0:BTY02JVYX0YJFU09^KV`2MWId0
Xj>S09ZJVP2PX:00Vi^K0:6QX@2TY:@07P3oool03@1[Jf/0Lg=c07AdM01iNGT0Ng]k06i^KP1cLg<0
L71`07AdM01`L700LG5a07EeM@1bLW800`1`L7000`1cLg<0MWIf079bLP02071`L00G06ATI01JFUX0
Bd];04I6AP0j>SX0<c<c02HV9P0/;2`0;bl_01@D500O7al09bLW03Ti>@2WYjL0IVIV06YZJP1/K6`0
IfMW06][J`1VIVH0GUiN05]KF`1WIfL00`1RHV801@1SHf<0IVIV06a/K01OGel0GUiN00@0FEUI01@0
C4a<03Ti>@0f=SH0=SHf02h^;P0b<S809RHV01HF5P0e=CD0G5aL02HV9P0o?cl0Fe]K02HV9P0j>SX0
8R8R02l_;`0l?3`0@D5104e=C@80C4a<01T0F5QH04Q8B01MGEd0Kfm_04=3@`1;Bd/0C4a<05YJFP1?
Cdl0BTY:04e=C@22PX80OGem06e]K@1`L700Kfm_07IfMP1dM7@0MWIf07UiN@1bLW80MgMg071`L01_
Kfl0M7Ad0080LW9b00<0L71`07IfMP1iNGT08P3oool00200oooo00<0W9bL0:FUY@2UYJD00P2QXJ40
2`2IVIT0XZ:R0:6QX@2QXJ40WIfM09ZJVP2NWYh0X:2P0:6QX@2MWId0W9bL0080XJ6Q0180WYjN09JF
UP2LW9`0Ph>308J6QP1KFe/0De=C05EEE@13@d<0?Cdm04=3@`0_;bl09BDU03/k>`0m?Cd0RXZ:08N7
Q`2?Shl208f=S@0308Z:RP2BTY80TI6A0080RXZ:03<0TI6A08V9R@28R8P0RHV908f=S@22PX80RHV9
07UiN@1gMgL0NWYj07MgM`1dM7@0Jf][05iNGP1:BTX0>SXj0410@01<C4`0>c/k02`/;00Z:RX0CDe=
08Z:RP0l?3`0IfMW02XZ:P1?Cdl0>c/k04Q8B01GEeL0Cdm?06EUI@1WIfL0ATI607]kN`20P800JFUY
08V9R@2=SHd0JFUY055AD@1aLG40MGEe06UYJ@24Q8@0PH610:2PX02>SXh0Xj>S09nOW`2IVIT00P2N
WYh01`2UYJD0WYjN0:6QX@2NWYh0XJ6Q09ZJVP2UYJD00P2MWId30:6QXAh0oooo00<0WinO0:NWY`2U
YJD00P2QXJ402@2IVIT0X:2P0:6QX@2TY:@0X:2P09fMW@2NWYh0Xj>S0:6QX@020::RXP0D0:FUY@2Q
XJ40X:2P092@T02FUYH0Ng]k0820P01FEUH0Bd];04m?C`11@D40?Cdm04E5A@0Z:RX08R8R0451@@17
AdL0a/K60;Vi^@2ATI4208f=S@0>08N7Q`2<S8`0RHV908:2PP27QhL0RHV90861P@1lO7`0PH6108V9
R@1mOGd0PX:207IfMP1dM7@207QhN00f07IfMP1aLG40IFEU05eMG@13@d<0>SXj04Q8B00h>3P0:RXZ
02TY:@1;Bd/0O7al04A4A01/K6`0;Bd]05YJFP19BDT0Bd];05IFEP1@D500GemO06MWI`0n?Sh0KFe]
0861P@1WIfL0QHF507YjNP1`L700Cdm?06MWI`1dM7@0IFEU0820P028R8P0/k>c092@T02QXJ40XZ:R
09VIV@2NWYh0Vi^K0:FUY@2KVi/0XJ6Q09jNWP2QXJ40WIfM0:FUY@2PX:00XZ:R0:6QX@2TY:@0XJ6Q
7P3oool00`1fMWH0NGUi07MgM`0207IfMP80Lg=c00X0MWIf07UiN@1hN7P0MGEe07AdM01jNWX0MWIf
07]kN`1lO7`0NWYj0P1fMWH04@1WIfL0JFUY05QHF01LG5`0@d=303<c<`0f=SH0<30`02l_;`0c<c<0
71`L01TI6@0b<S80>SXj0:n_[`2PX:00JVYZ0080IfMW00X0HV9R061PH01LG5`0FUYJ061PH01LG5`0
FEUI055AD@1GEeL0H61P0P1IFET0>P1GEeL0De=C05IFEP1IFET0FUYJ05UIF@1BDU80FEUI03`l?00W
9bL0<C4a02PX:00N7Qh07alO02l_;`13@d<0@T9205ADE00X:2P0Bd];0410@00k>c/0@D5103`l?00o
?cl0BDU902XZ:P0o?cl0EeMG04e=C@1GEeL0ATI6061PH00i>CT0@D51055AD@17AdL0EUIF06MWI`2;
Rh/0KFe]079bLP1gMgL0LG5a07AdM01`L700MgMg071`L01fMWH0M7Ad07IfMP1eMGD0MgMg07QhN01k
Ng/0MWIf07UiN@1fMWHR0?ooo`00803oool00`2MWId0XJ6Q0:FUY@020:6QX@0309ZJVP2QXJ40WYjN
0080XZ:R0100XJ6Q09fMW@2NWYh0WYjN0:6QX@2RXZ80Y:BT0::RXP2MWId0SHf=08j>SP25QHD0N7Qh
05]KF`1@D500B4Q80`13@d<03P0_;bl0:2PX02l_;`2SXj<0R8R808b<S02:RXX0SHf=08n?S`27QhL0
QXJ608B4Q028R8P0QHF50P27QhL0>023Ph<0PX:208N7Q`21PH40R8R807inOP1hN7P0NGUi07=cL`1h
N7P0LG5a06QXJ01UIFD0ATI603Ph>00m?Cd0>CTi02d];@0[:b/0?Shn065QH@1hN7P0GEeM059BDP1;
Bd/0AdM7030`<01ZJVX0CTi>05aLG01CDe<0E5AD061PH01WIfL0M7Ad07emO@24Q8@0QHF505UIF@1Z
JVX0IFEU06ATI027QhL0SHf=092@T02NWYh0V9RH09nOW`2IVIT0WIfM09ZJVP2UYJD0VIVI0:BTY02J
VYX0XZ:R1P2QXJ400`2NWYh0oooo0?ooo`0L0?ooo`030::RXP2TY:@0YJFU0080XJ6Q00<0VYZJ0:BT
Y02NWYh00P2MWId0102QXJ40XZ:R09jNWP2NWYh209^KV`0C09jNWP2MWId0X:2P08n?S`27QhL0OWin
06i^KP1@D500Bd];04=3@`0l?3`0@D5104=3@`0Z:RX0:2PX02/[:`3;bl/0^k^k092@T00208J6QP06
08V9R@24Q8@0Ogmo07EeM@1gMgL0Lg=c0P1dM7@307MgM`0g079bLP1oOgl0NWYj07alO01oOgl0MGEe
07QhN01aLG40K6a/06i^KP1IFET0CDe=0492@P0g=cL0;Rh^02`/;00l?3`0EEEE079bLP1MGEd0IFEU
06MWI`1BDU80;bl_06][J`1FEUH0HF5Q04];B`1CDe<0Hf=S06YZJP1`L700OGem08^;R`2@T900IFEU
07inOP1YJFT0GemO08F5Q@2=SHd0U9BD0:2PX02RXZ80WinO09VIV@2PX:00WIfM0:FUY@2GUiL0X:2P
09ZJVP2PX:00XJ6Q0:BTY0020:6QX@030:BTY02QXJ40Vi^K01h0oooo00<0Ng]k07UiN@1gMgL00P1f
MWH00`1bLW80NGUi07AdM00206m_K`0Q07IfMP1kNg/0M7Ad07AdM01]KFd0Jf][06i^KP1_Kfl0N7Qh
06m_K`1OGel0FUYJ04e=C@0j>SX0=SHf02h^;P0Y:BT0;bl_034a<@0K6a/07QhN01`L702NWYh0Xj>S
06][J`1OGel0G5aL05mOG`1NGUh0F5QH04];B`19BDT0ATI60080ADE50P1=CDd02019BDT0B4Q805AD
E01GEeL0GemO069RHP1IFET0EeMG0P1DE5@205QHF00X04i>CP0e=CD0:BTY02DU9@0R8R809bLW02d]
;@1:BTX0@D5105mOG`1PH600BDU902DU9@1;Bd/0B4Q804Y:BP0a<C40?Shn04Q8B01?Cdl0CTi>05UI
F@1XJ6P0L71`05IFEP1YJFT0D51@04=3@`1IFET0HV9R06m_K`1fMWH0OGem07=cL`1aLG40N7Qh07Ee
M@1gMgL0L71`075aL@80LW9b00L0MWIf07UiN@1fMWH0MWIf07UiN@1fMWH0L71`0280oooo000P0?oo
o`050:6QX@2NWYh0XJ6Q0:6QX@2NWYh00P2QXJ400`2MWId0VYZJ0:6QX@020:6QX@0O09fMW@2JVYX0
WIfM09bLW02QXJ40WIfM0::RXP2ATI40PX:208B4Q01XJ6P0FUYJ05ADE014A4@0=SHf04M7A`0m?Cd0
;Rh^03Lg=`1eMGD0SHf=08N7Q`2>SXh0Q8B408N7Q`29RHT0PX:207]kN`1eMGD0MWIf07=cL`0307Mg
M`050820P01dM7@0O7al0861P@1jNWX00P1nOWh0:P1cLg<0MgMg075aL@1[Jf/0J6QX06IVIP1?Cdl0
<S8b03<c<`0[:b/08B4Q03De=@1FEUH0QhN704A4A02LW9`0BDU906IVIP0c<c<0GemO06i^KP1DE5@0
C4a<06EUI@1CDe<0HF5Q07alO01^KVh0RHV909RHV01QHF40KFe]06QXJ01VIVH0OWin08f=S@2ATI40
YJFU09VIV@2PX:00WYjN0:FUY@80WIfM00<0XJ6Q09fMW@2JVYX00P2QXJ400`2NWYh0YJFU0:6QX@02
0:6QX@0309fMW@3oool0oooo01`0oooo00T0XJ6Q09^KV`2TY:@0XJ6Q09^KV`2QXJ40Y:BT0:2PX02M
WId00P2TY:@06@2QXJ40X:2P09ZJVP2MWId0WYjN0:FUY@2RXZ80WIfM08j>SP21PH40PX:206EUI@1H
F5P0De=C04I6AP0e=CD0A4A403/k>`0_;bl0?3`l0<;2`P3De=@0S8b<096AT@24Q8@00P27QhL01@1m
OGd0LW9b06i^KP1/K6`0IVIV0080JFUY00H0Jf][07IfMP1]KFd0MGEe07]kN`1aLG4207inOP0407=c
L`1hN7P0LG5a06a/K080IFEU0280EeMG03Lg=`0a<C40:BTY01hN7P0`<300DU9B08J6QP0h>3P0U9BD
04];B`1_Kfl0Bd];05IFEP1ZJVX0FEUI04m?C`1]KFd0EeMG065QH@21PH40KVi^07emO@2?Shl0L71`
06m_K`1YJFT0Kfm_08F5Q@2>SXh0TI6A0:VYZ@2HV9P0XJ6Q0P2SXj<01@2PX:00Vi^K0:6QX@2TY:@0
VYZJ0080Y:BT00<0Vi^K0:>SX`2QXJ400P2QXJ400`2PX:00oooo0?ooo`0L0?ooo`0907IfMP1`L700
NGUi07IfMP1`L700MWIf07UiN@1hN7P0MGEe0080NGUi00D0MWIf07QhN01bLW80M7Ad07IfMP0207]k
N`0?06m_K`1ZJVX0Hf=S061PH01>CTh0ADE503`l?00h>3P0:2PX02l_;`0Z:RX08R8R02l_;`2l_;`0
_[jn0080JVYZ00L0HV9R06=SH`1QHF40F5QH04m?C`1=CDd0B4Q800<0@D5103L0A4A404e=C@1;Bd/0
Cdm?05ADE01<C4`0Fe]K05aLG01GEeL0F5QH05ADE01ADE40BDU904Y:BP1<C4`0<C4a02@T900N7Qh0
51@D01dM7@0d=3@0EUIF02<S8`1GEeL0?clo05IFEP1BDU80<c<c04Q8B016ATH0?Shn059BDP14A4@0
BDU905iNGP1@D500CDe=05eMG@1OGel0DU9B04m?C`1IFET0HV9R06ATI01]KFd0NWYj071`L01eMGD0
O7al07AdM01hN7P0LG5a07IfMP1mOGd0LW9b0080NGUi00<0L71`07AdM01fMWH00P1fMWH00`1hN7P0
oooo0?ooo`0P0?ooo`00803oool01P2QXJ40VYZJ09jNWP2QXJ40WYjN0:FUY@80XJ6Q00@0VYZJ0:FU
Y@2QXJ40WYjN0P2QXJ404P2JVYX0X:2P09bLW02MWId0TI6A08J6QP24Q8@0LW9b05iNGP1<C4`0ATI6
04E5A@0e=CD0?Shn02`/;00h>3P0S8b<08B4Q0<0QhN703/0Q8B406][J`1gMgL0H61P05YJFP1HF5P0
EEEE06MWI`1bLW80KVi^05YJFP1FEUH0FEUI05ADE01VIVH0S8b<07inOP22PX80OWin07=cL`1gMgL0
JVYZ06][J`1TI6@0H61P05]KF`0k>c/07QhN020P800O7al0CDe=02LW9`1SHf<0>c/k0:>SX`1?Cdl0
R8R804a<C01FEUH0J6QX04M7A`1SHf<0DE5A079bLP1TI6@0O7al07inOP2=SHd0D51@06UYJ@1`L700
M7Ad08N7Q`2_[jl0W9bL09^KV`2DU9@0YZJV09bLW00209jNWP040:FUY@2JVYX0YJFU0::RXP80XJ6Q
00H0WYjN0:6QX@2QXJ40WYjN0:FUY@2NWYhN0?ooo`060:6QX@2JVYX0Vi^K0:6QX@2NWYh0Xj>S0P2Q
XJ400`2JVYX0YJFU0:6QX@0209^KV`0C0:6QX@2JVYX0Xj>S0:>SX`2MWId0TI6A08J6QP2:RXX0J6QX
055AD@18B4P0@d=30492@P0`<300?Cdm02h^;P0k>c/0d=3@0<71`@0208N7Q`80QXJ600X0G5aL05]K
F`1FEUH0IVIV08F5Q@1YJFT0KFe]0820P02:RXX0HV9R0P1SHf<0?01KFe/0GEeM07YjNP1kNg/0Ogmo
07inOP1cLg<0MgMg06i^KP1]KFd0I6AT06=SH`1NGUh0BTY:01hN7P0O7al07QhN04Y:BP0N7Qh0MWIf
03/k>`2DU9@0AdM708:2PP1GEeL0GUiN07=cL`11@D40H61P05]KF`1^KVh0I6AT07]kN`1iNGT0SXj>
04m?C`1JFUX0HV9R07AdM021PH40/k>c0:JVYP2NWYh0Ti>C0:^[Z`2TY:@0Vi^K09nOW`2UYJD0VYZJ
0:FUY@2MWId0XJ6Q0:BTY02KVi/0XJ6Q0:BTY02KVi/0YJFU09^KVah0oooo00@0MWIf079bLP1`L700
MWIf0P1dM7@207IfMP0H079bLP1gMgL0MWIf071`L01]KFd0MWIf079bLP1jNWX0OGem07=cL`1]KFd0
IfMW06][J`19BDT0>CTi03Lg=`0a<C40;Bd]028R8P0/;2`09RHV02/[:`2j^[X0[Jf]0`1RHV806`1U
IFD0>c/k02d];@0m?Cd0EUIF08R8R01PH600EEEE06MWI`1kNg/0D51@05ADE01ADE40B4Q803Xj>P13
@d<0EUIF05UIF@1MGEd0EeMG05QHF01GEeL0De=C04];B`1<C4`0BDU904];B`0201LG5`0801DE5@0]
;Bd03`l?06UYJ@0a<C40De=C03De=@1DE5@204i>CP0<05UIF@0_;bl0@d=304];B`1:BTX0Bd];05AD
E01BDU80I6AT04=3@`0f=SH0?Shn0P1CDe<0501kNg/0Ogmo07EeM@1]KFd0OGem07moO`1`L700MGEe
07MgM`1bLW80MgMg06m_K`1fMWH0NGUi071`L01fMWH0NGUi071`L01gMgL0L71`8P3oool00200oooo
01l0XZ:R0:6QX@2QXJ40WYjN0:6QX@2NWYh0YJFU09jNWP2QXJ40WYjN0::RXP2NWYh0WIfM0::RXP2M
WId0YjNW0:6QX@2GUiL0Q8B408b<S01kNg/0J6QX05eMG@1ADE40BDU903/k>`11@D408R8R038b<P1R
HV80`l?30080QhN701D0Ph>308J6QP27QhL0C4a<06YZJP1VIVH0HV9R07QhN01YJFT0LG5a06ATI01e
MGD0HV9R05eMG@1iNGT0Cdm?05UIF@1KFe/0P8200861P@1nOWh00P1hN7P00`1^KVh0Jf][06UYJ@02
069RHP0Q05=CD`0J6QX0:BTY018B4P0g=cL0?Shn07inOP12@T80NWYj06e]K@1NGUh0LW9b03lo?`1I
FET0F5QH061PH01;Bd/0MGEe06QXJ01eMGD0MWIf09NGU`1DE5@0FUYJ06a/K01XJ6P0Q8B40<;2`P2Q
XJ40UYJF09NGU`2][Jd0XJ6Q0080WIfM00@0XJ6Q09fMW@2NWYh0WIfM0P2QXJ401P2MWId0XJ6Q0:6Q
X@2MWId0XJ6Q09fMWAh0oooo00`0WIfM0:6QX@2QXJ40WYjN0:6QX@2NWYh0Xj>S09^KV`2QXJ40WYjN
09fMW@2KVi/209fMW@0C09VIV@2VYZH0XJ6Q09NGU`1mOGd0OWin06EUI@1BDU80DE5A04a<C012@T80
=cLg0492@P0P8200:b/[07=cL`3Ng]h0RHV908b<S00208J6QP0g08B4Q017AdL0IFEU06IVIP1PH600
De=C059BDP1WIfL0De=C05ADE01?Cdl0CDe=07IfMP1DE5@0FUYJ04m?C`1nOWh0PX:207inOP1kNg/0
OWin06i^KP1[Jf/0KFe]06IVIP1WIfL0Fe]K02@T900^;Rh04a<C034a<@13@d<0JFUY0492@P1hN7P0
LW9b06=SH`2@T900EEEE055AD@1IFET0JVYZ04M7A`1`L700IfMW07AdM01`L700TI6A05ADE01SHf<0
MGEe06MWI`1oOgl0`l?30:>SX`0209FEU@0@0:j^[P2QXJ40Y:BT0::RXP2TY:@0X:2P09jNWP2RXZ80
Y:BT0:6QX@2PX:00Y:BT0:6QX@2RXZ80Y:BT0:2PX1h0oooo00D0Kfm_07IfMP1fMWH0M7Ad07IfMP02
07AdM00l071`L01fMWH0M7Ad06m_K`1`L700M7Ad06m_K`1^KVh0MgMg07IfMP1`L700G5aL05ADE00m
?Cd0<C4a03De=@0g=cL0:RXZ02HV9P0b<S805QHF01TI6@1JFUX0V9RH06MWI`1ZJVX0IFEU069RHP1O
Gel0>SXj04I6AP1;Bd/0ADE5020P800/;2`0@T9202l_;`0Q8B40:BTY02`/;01?Cdl0ADE504A4A00_
;bl0FEUI05iNGP1KFe/0GUiN069RHP1BDU80D51@05=CD`1@D500DU9B04];B`0W9bL09RHV00l?3`0K
6a/0=CDe0P0i>CT02@1=CDd0FUYJ04];B`23Ph<0EeMG03Hf=P14A4@0De=C03@d=00204];B`0:055A
D@1=CDd0GemO04Q8B01BDU80FUYJ04Y:BP1EEED0OGem07IfMP80KFe]0100Ng]k07IfMP1mOGd0Ng]k
07UiN@1hN7P0M7Ad07]kN`1iNGT0MWIf07QhN01iNGT0MWIf07]kN`1iNGT0N7Qh8P3oool00200oooo
00H0WIfM0:6QX@2QXJ40VYZJ0::RXP2QXJ4209jNWP0H0:FUY@2JVYX0WYjN09jNWP2QXJ40VYZJ09fM
W@2UYJD0WYjN09bLW01mOGd0O7al069RHP1QHF40CDe=04U9B@17AdL0=CDe02d];@0a<C409bLW0:NW
Y`2;Rh/0RXZ:0P27QhL04`26QXH0OGem055AD@18B4P0EeMG05eMG@1@D500EUIF069RHP1<C4`0AdM7
04U9B@1>CTh0@D5105EEE@19BDT0?clo09BDU02EUID00P1mOGd0;01hN7P0Lg=c06IVIP1_Kfl0JFUY
06YZJP1EEED0:RXZ01@D500E5AD0=3@d0410@021PH40JVYZ03Ti>@2SXj<0Bd];09nOW`1WIfL0>SXj
065QH@1;Bd/0GemO06i^KP1XJ6P0HF5Q08Z:RP2=SHd0J6QX05QHF01dM7@0GemO08F5Q@2d];@0VYZJ
09bLW02JVYX0WinO0:VYZ@2NWYh0YJFU09jNWP2UYJD0WIfM1@2QXJ4209jNWP030:FUY@2QXJ40oooo
01d0oooo00X0XZ:R0:BTY02TY:@0VYZJ0:2PX02QXJ40WYjN09^KV`2UYJD0VYZJ0P2NWYh0102TY:@0
WIfM09fMW@2VYZH209^KV`0>07UiN@1hN7P0FUYJ05eMG@18B4P0@41004I6AP0e=CD09RHV02h^;P0Y
:BT0g=cL0;2`/02;Rh/208F5Q@0C08J6QP1MGEd0?3`l03Hf=P0m?Cd0ADE504=3@`15ADD0Cdm?03dm
?@0i>CT0>SXj0451@@0^;Rh0>3Ph03De=@0^;Rh0L71`08R8R00207emO@0/07AdM01fMWH0JFUY06m_
K`1/K6`0L71`05QHF00c<c<051@D018B4P0e=CD0?Shn071`L01gMgL0=cLg08n?S`16ATH0Ti>C07em
O@1KFe/0LG5a04Q8B01PH600Jf][06=SH`1EEED0PX:209:BTP1eMGD0IfMW07inOP1WIfL0S8b<0;Fe
]@2HV9P0VYZJ0:6QX@2OWil0Y:BT09^KV`2SXj<0Vi^K0:>SX`2PX:050:6QX@80Vi^K00<0Xj>S0:6Q
X@3oool07@3oool00`1kNg/0NGUi07UiN@02079bLP0507IfMP1dM7@0L71`07MgM`1bLW800P1dM7@0
501iNGT0MGEe07AdM01hN7P0L71`075aL@1OGel0FEUI04=3@`15ADD0=SHf02XZ:P0a<C40:2PX01PH
600Q8B40820P0;2`/02CTi<0IVIV0P1PH6003@1RHV80:b/[028R8P0J6QX05QHF01hN7P0X:2P09BDU
02PX:00S8b<07alO01`L700S8b<00P0A4A40100H61P05QHF02d];@1CDe<205aLG00/05=CD`1JFUX0
DU9B055AD@1BDU80EeMG04M7A`0d=3@0410@00`<300T92@0:2PX03`l?01PH600:b/[04Y:BP0g=cL0
FEUI07IfMP1WIfL0GUiN03De=@16ATH0AdM704A4A00e=CD0De=C06QXJ01UIFD0G5aL069RHP1EEED0
IfMW07IfMP1]KFd0L71`07]kN`1cLg<0LW9b071`L01dM7@0L71`07AdM01hN7P507IfMP80L71`00<0
M7Ad07IfMP3oool08@3oool00200oooo0P2RXZ802P2UYJD0WIfM09ZJVP2RXZ80XJ6Q09ZJVP2NWYh0
XJ6Q09ZJVP2QXJ4309jNWP080::RXP2MWId0X:2P08>3P`1cLg<0F5QH05UIF@14A4@203/k>`0>03Hf
=P0a<C40=SHf030`<02<S8`0R8R808n?S`28R8P0PX:208J6QP1[Jf/0?Shn03Ti>@15ADD204Q8B00B
055AD@1KFe/0?clo04E5A@12@T80AdM703/k>`1LG5`0@T9203Ti>@1WIfL0Ph>307emO@1jNWX0N7Qh
07YjNP1ZJVX0JFUY0P1^KVh08@1MGEd0?3`l01HF5P0A4A406ATI03Hf=P1VIVH0SXj>0492@P1DE5@0
NGUi0:b/[02;Rh/0Kfm_03`l?01MGEd0H61P06UYJ@1SHf<0De=C09:BTP20P800Ph>305=CD`24Q8@0
IFEU09fMW@2NWYh0UiNG09bLW02WYjL0Vi^K0::RXP020:6QX@0<09fMW@2QXJ40WYjN0:6QX@2NWYh0
YJFU0:6QX@2NWYh0XJ6Q09ZJVP2UYJD0XJ6Q7P3oool209fMW@0M0:>SX`2PX:00WIfM0:2PX02QXJ40
WIfM09jNWP2QXJ40WIfM0:BTY02NWYh0Vi^K09jNWP2PX:00VIVI09nOW`1nOWh0L71`059BDP1?Cdl0
>SXj03<c<`0j>SX0<c<c03@d=00k>c/0=3@d0<;2`P25QHD00P2<S8`05@25QHD0QXJ6092@T01NGUh0
DU9B05eMG@1EEED0CDe=05aLG01]KFd0C4a<059BDP1IFET0F5QH055AD@2<S8`0P8200861P@2CTi<0
Shn?07emO@0207MgM`0307]kN`1^KVh0KFe]0080KVi^02l0HF5Q04E5A@0M7Ad04a<C01LG5`0^;Rh0
GemO08:2PP1CDe<0E5AD06m_K`2NWYh0QHF50861P@12@T80FUYJ06QXJ01YJFT0HV9R059BDP2BTY80
NWYj08N7Q`1CDe<0P82006IVIP2][Jd0/[:b09BDU02IVIT0Xj>S09fMW@2RXZ80XJ6Q0:BTY02PX:00
Y:BT09^KV`2QXJ40Vi^K0:>SX`2QXJ40Vi^K0:6QX@2JVYX0YJFU0:6QX@0N0?ooo`80Kfm_02<0M7Ad
07QhN01eMGD0LW9b07IfMP1eMGD0M7Ad07IfMP1eMGD0NGUi07AdM01`L700M7Ad079bLP1^KVh0Lg=c
05mOG`1EEED0?Shn03De=@0W9bL08R8R02XZ:P0T92@0:b/[02h^;P0[:b/0ZJVY061PH01SHf<0JVYZ
06IVIP1RHV80QhN706MWI`0205MGE`0Q04U9B@0o?cl0C4a<05aLG016ATH0B4Q805ADE01>CTh0Cdm?
08F5Q@2BTY80VYZJ08V9R@1/K6`0G5aL05IFEP1GEeL0FUYJ05MGE`1CDe<0DE5A051@D01>CTh0?clo
024Q8@0A4A403@d=01TI6@0i>CT0C4a<05EEE@0j>SX0B4Q80080FUYJ0180Lg=c03dm?@12@T80D51@
04Y:BP17AdL0?Shn061PH01ADE40IfMW04E5A@1FEUH0Cdm?0820P02:RXX0K6a/06e]K@1cLg<207Ee
M@0>07IfMP1iNGT0N7Qh07UiN@1`L700MWIf071`L01dM7@0MWIf071`L01fMWH0LW9b07MgM`1fMWHR
0?ooo`00803oool01`2MWId0VYZJ0:FUY@2NWYh0XJ6Q09fMW@2QXJ400P2JVYX01P2UYJD0WIfM0:6Q
X@2MWId0VIVI0:>SX`80VYZJ00H0X:2P07inOP1]KFd0DE5A04Y:BP19BDT203Ti>@06038b<P0i>CT0
=CDe03dm?@28R8P0S8b<0`2:RXX0>P23Ph<0R8R806MWI`1FEUH0C4a<04=3@`1ADE40B4Q805iNGP1?
Cdl0BTY:04];B`18B4P0C4a<075aL@1^KVh0LW9b07QhN01mOGd0OWin07UiN@1gMgL0NWYj075aL@1_
Kfl0JFUY06i^KP1TI6@0AdM702DU9@0G5aL03@d=051@D01?Cdl0Kfm_07AdM00l?3`0OWin08N7Q`2U
YJD0S8b<04E5A@1MGEd0Fe]K05iNGP1/K6`0HF5Q07YjNP1`L700RXZ:055AD@1eMGD0IFEU0<G5a@2P
X:00V9RH09NGU`2ZZZX209fMW@0:0:FUY@2QXJ40XJ6Q0:6QX@2MWId0WYjN0:6QX@2NWYh0YJFU09fM
W@@0XJ6Q7P3oool01`2RXZ80WIfM0:FUY@2KVi/0XJ6Q0::RXP2TY:@00P2JVYX0:@2UYJD0X:2P0:BT
Y02PX:00VYZJ0:BTY02MWId0V9RH09jNWP1jNWX0I6AT04Q8B011@D40ATI603dm?@0f=SH0<30`03Ph
>00e=CD0?Shn08B4Q02;Rh/0S8b<08J6QP29RHT0QHF509FEU@23Ph<0UYJF09jNWP2ATI40Y:BT09JF
UP2IVIT0UIFE0:JVYP2GUiL0SHf=08V9R@2LW9`0Ph>30080P82000<0PH6107inOP1lO7`00P1iNGT0
8`1`L700LW9b06e]K@1]KFd0I6AT04m?C`0];Bd07AdM00d=3@1FEUH0ATI605aLG01RHV80>3Ph07Ee
M@1bLW80SXj>08F5Q@1>CTh0L71`061PH01FEUH0IVIV06YZJP1oOgl0I6AT08Z:RP1CDe<0LW9b05YJ
FP31`L40XZ:R09RHV02GUiL0[:b/0080XZ:R00h0YJFU0:6QX@2QXJ40XJ6Q0:2PX02KVi/0XJ6Q09jN
WP2SXj<0X:2P0:BTY02QXJ40Y:BT0:6QXAh0oooo00L0Ng]k07EeM@1gMgL0L71`07IfMP1kNg/0NGUi
0080LW9b00d0MgMg07QhN01iNGT0N7Qh07=cL`1hN7P0MGEe071`L01aLG40Fe]K04Q8B00e=CD0;2`/
0080<c<c04409RHV02<S8`0W9bL09RHV02h^;P1OGel0IFEU06QXJ01OGel0Hf=S06ATI01eMGD0OWin
0:NWY`2h^;P0[Zj^0;bl_02_[jl0WinO0:ZZZP34a<@0[Zj^0::RXP2GUiL0Shn?071`L01ZJVX0I6AT
061PH01MGEd0GUiN05aLG01GEeL0DU9B05QHF01CDe<0D51@04];B`15ADD0;bl_01`L700:2PX0>c/k
02TY:@0];Bd0=cLg02`/;014A4@0>3Ph04i>CP1JFUX0CTi>065QH@1<C4`0=cLg04=3@`1EEED0FUYJ
0451@@1SHf<0BDU904m?C`0l?3`0MWIf07EeM@0206m_K`0407alO01kNg/0Ng]k07MgM`<0MWIf00<0
N7Qh071`L01fMWH00P1dM7@01@1hN7P0NGUi07IfMP1iNGT0MWIf0280oooo000P0?ooo`0309jNWP2U
YJD0XZ:R0080XZ:R00T0XJ6Q09fMW@2WYjL0WIfM0:6QX@2JVYX0XJ6Q09jNWP2JVYX00P2MWId02@2P
X:00UiNG06EUI@1IFET0ADE504a<C00a<C40>c/k03De=@0203Lg=`0?03Hf=P3IfMT0R8R808n?S`2;
Rh/0RXZ:08N7Q`2@T900SXj>08f=S@2ATI40SHf=096AT@2?Shl0Ph>300<0QhN700T0PH6107moO`1i
NGT0QHF507YjNP2:RXX0QhN707AdM021PH400P1jNWX0:@1cLg<0LG5a071`L01cLg<0HF5Q06ATI01D
E5@0>c/k01lO7`0R8R805aLG04e=C@1CDe<0GUiN05ADE00n?Sh0G5aL08N7Q`2JVYX0QhN7061PH01V
IVH0IFEU04a<C01UIFD0Cdm?0820P02CTi<0HV9R06QXJ01_Kfl0_kno0:BTY02>SXh0]KFe09jNWP2U
YJD0XJ6Q0:FUY@2NWYh0XJ6Q0080WIfM00H0WYjN0:FUY@2QXJ40XJ6Q09jNWP2RXZ820:6QX@0309fM
W@3oool0oooo01`0oooo00<0WYjN0:FUY@2MWId00P2MWId02@2QXJ40W9bL0:>SX`2PX:00Y:BT09ZJ
VP2TY:@0WYjN09ZJVP0209fMW@0:09nOW`2KVi/0Fe]K04I6AP0i>CT0BTY:038b<P0i>CT0=SHf03/k
>`80=cLg00h0jNWY08J6QP2<S8`0SHf=08V9R@26QXH0TY:B096AT@2=SHd0SXj>08Z:RP2>SXh0Rh^;
07moO`<0QhN702L0Ph>308F5Q@1lO7`0QHF507YjNP2>SXh0QhN707YjNP20P800MWIf07QhN01dM7@0
LG5a06i^KP1dM7@0JFUY06QXJ01GEeL0@D5102HV9P0Z:RX05ADE04=3@`14A4@0CTi>04U9B@15ADD0
DU9B07QhN02?Shl0Ph>305EEE@1VIVH0I6AT04];B`1ZJVX0DE5A0861P@28R8P00P1TI6@02`1ZJVX0
_[jn09bLW02:RXX0/K6a09nOW`2SXj<0XJ6Q0:FUY@2KVi/0XJ6Q0080XZ:R00H0Vi^K0:>SX`2QXJ40
XJ6Q09^KV`2MWId20:6QX@030:2PX03oool0oooo01`0oooo00<0M7Ad07MgM`1_Kfl00P1_Kfl02P1f
MWH0LW9b07=cL`1hN7P0NGUi079bLP1iNGT0M7Ad079bLP1dM7@207=cL`0507MgM`11@D40:RXZ02DU
9@0e=CD00`0X:2P04P0];Bd0:2PX02TY:@2BTY80HF5Q06ATI01YJFT0IFEU06=SH`1ZJVX0Jf][06MW
I`1UIFD0Hf=S06EUI@1RHV80GEeM06=SH`80HV9R00h0HF5Q06EUI@1NGUh0HF5Q05]KF`1YJFT0Hf=S
065QH@1KFe/0E5AD05IFEP1HF5P0E5AD04m?C`80EUIF01D0D51@04M7A`0j>SX0:2PX02HV9P0>3Ph0
9BDU02HV9P0W9bL0<30`03Xj>P0d=3@0A4A405UIF@1JFUX0?3`l04m?C`17AdL0>SXj04i>CP0n?Sh0
0P1GEeL03@1BDU80ATI604];B`1fMWH0JFUY06ATI01gMgL0MGEe07AdM01fMWH0MgMg071`L01fMWH0
0P1kNg/01P1`L700M7Ad07IfMP1fMWH0L71`06m_K`80MWIf00<0N7Qh0?ooo`3oool0803oool00200
oooo00@0WIfM09jNWP2JVYX0WYjN0P2QXJ401P2LW9`0WYjN0:6QX@2QXJ40WIfM0:6QX@80WIfM0180
VYZJ09fMW@2MWId0RXZ:05=CD`1;Bd/0ADE503Ti>@13@d<0:RXZ02TY:@0n?Sh0>CTi02`/;03gmoL0
R8R808n?S`2>SXh208V9R@0i08Z:RP2=SHd0SHf=08f=S@2;Rh/0SXj>08F5Q@27QhL0OWin096AT@1n
OWh0QHF508N7Q`1kNg/0Q8B40861P@2;Rh/0QhN708J6QP1lO7`0LG5a07YjNP1gMgL0Kfm_071`L01_
Kfl0KVi^069RHP1PH600AdM702LW9`0K6a/07alO04];B`1<C4`0CTi>061PH010@400De=C08>3P`1i
NGT0Shn?07]kN`1NGUh0JFUY04=3@`1iNGT0De=C07YjNP2GUiL0JFUY05IFEP2EUID0UiNG0:FUY@2;
Rh/0ZZZZ00@0XJ6Q00P0WIfM09jNWP2UYJD0XJ6Q09ZJVP2UYJD0WYjN0:FUY@80WIfM0`2QXJ4N0?oo
o`040::RXP2NWYh0WIfM09jNWP80Y:BT0P2OWil20:6QX@040:2PX02TY:@0X:2P0:2PX0<0WIfM01<0
NWYj04e=C@17AdL0ADE503@d=00o?cl0:BTY02PX:00j>SX0>CTi02XZ:P3alO40QXJ608n?S`2>SXh0
Rh^;08f=S@29RHT0SXj>0080SHf=0240RXZ:08f=S@22PX80Q8B407QhN02:RXX0N7Qh0820P023Ph<0
NWYj08:2PP23Ph<0Shn?08>3P`27QhL0RHV907UiN@1oOgl0MWIf071`L01cLg<0KVi^06YZJP1PH600
G5aL04Y:BP0Z:RX06ATI01lO7`1=CDd0DU9B05=CD`1XJ6P00P15ADD0801jNWX0JFUY07EeM@27QhL0
MGEe06QXJ011@D40N7Qh05aLG022PX80TY:B06UYJ@1CDe<0XZ:R0:VYZ@2UYJD0U9BD0;2`/02QXJ40
Y:BT0:6QX@2TY:@0X:2P09jNWP2SXj<0XJ6Q09ZJVP2UYJD0Vi^K0:>SX`2PX:00XZ:R0`2QXJ4N0?oo
o`0407]kN`1dM7@0MGEe07AdM080NGUi00H0N7Qh07EeM@1fMWH0MWIf07QhN01iNGT207QhN00507Ee
M@1dM7@0Lg=c051@D00m?Cd00P0e=CD02@0T92@0;2`/01lO7`0M7Ad09BDU02XZ:P0N7Qh0PH61065Q
H@0206MWI`0406QXJ01[Jf/0IFEU06QXJ080IfMW03X0I6AT06IVIP1NGUh0GUiN05ADE01NGUh0EEEE
05QHF01LG5`0FUYJ05eMG@1QHF40J6QX05]KF`1TI6@0Kfm_069RHP1QHF40EeMG05EEE@1GEeL0D51@
04a<C018B4P0@D5103hn?P0W9bL04a<C01LG5`0g=cL0?Shn0410@01@D500>c/k02LW9`19BDT0?3`l
03dm?@1]KFd0Jf][04U9B@0b<S80D51@04i>CP1NGUh0GemO059BDP10@400MgMg0820P01dM7@0MWIf
07moO`1fMWH0NGUi07IfMP1iNGT0N7Qh0P1dM7@01`1fMWH0LW9b07MgM`1`L700M7Ad07QhN01kNg/0
0`1fMWHR0?ooo`00803oool0102QXJ40WIfM09fMW@2MWId30:6QX@0309fMW@2UYJD0XJ6Q0080XJ6Q
01<0WYjN0::RXP2QXJ40WIfM09>CT`1dM7@0GUiN0451@@18B4P0?Shn03@d=00c<c<0<30`03Ph>00^
;Rh0GEeM0;Vi^@28R8P0T92@00@0SHf=03P0Rh^;08j>SP2=SHd0Rh^;08N7Q`1mOGd0PH6107YjNP2=
SHd0O7al0861P@24Q8@0PH610820P028R8P0QXJ607moO`27QhL0Ogmo07inOP1lO7`0MgMg075aL@1d
M7@0JFUY06i^KP1WIfL0EUIF04e=C@0c<c<07AdM02XZ:P1>CTh0@d=305eMG@1?Cdl0F5QH04m?C`1=
CDd0W9bL07emO@1dM7@0Ng]k06MWI`13@d<0IVIV06UYJ@1hN7P0UYJF06m_K`1ADE40^;Rh07emO@2l
_;`0XJ6Q09fMW@<0XJ6Q00<0WYjN0:FUY@2MWId00P2QXJ401P2MWId0WYjN09jNWP2UYJD0XJ6Q09jN
WP<0XJ6Q7P3oool01@2QXJ40X:2P0:2PX02RXZ80Y:BT0080XJ6Q00<0X:2P0:>SX`2QXJ400P2QXJ40
502KVi/0WIfM0:6QX@2RXZ80TI6A06e]K@1DE5@0?Shn04A4A012@T80=3@d038b<P0d=3@0>c/k02/[
:`1_Kfl0fMWI08R8R02ATI40SXj>0P2=SHd0302BTY80RXZ:08f=S@2=SHd0S8b<08F5Q@1dM7@0LW9b
06][J`1oOgl0LG5a07YjNP80O7al00D0Ogmo08N7Q`23Ph<0RXZ:08f=S@0207YjNP0U07emO@1fMWH0
L71`07AdM01YJFT0KVi^06][J`1HF5P0BTY:03Hf=P0S8b<0;bl_04U9B@0l?3`0EeMG04M7A`1BDU80
CDe=03lo?`2>SXh0Ti>C06e]K@1[Jf/0KVi^04U9B@1TI6@0HV9R07IfMP2FUYH0Lg=c05MGE`35aLD0
OGem0;Ng]`2YZJT0YjNW0:BTY0020:6QX@0;09^KV`2SXj<0X:2P0:BTY02QXJ40X:2P09jNWP2KVi/0
YJFU0:6QX@2KVi/00`2QXJ4N0?ooo`0507IfMP1hN7P0N7Qh07]kN`1iNGT00P1fMWH00`1hN7P0M7Ad
07IfMP0207IfMP0D071`L01_Kfl0MWIf07]kN`1/K6`0De=C03`l?00`<300;bl_03Hf=P0W9bL09RHV
02XZ:P0];Bd07AdM05YJFP2JVYX0Hf=S06UYJ@1XJ6P206MWI`0j06m_K`1TI6@0IVIV06MWI`1XJ6P0
H61P051@D018B4P0A4A404i>CP1;Bd/0DU9B05=CD`1GEeL0Fe]K061PH01LG5`0KVi^06YZJP1GEeL0
F5QH05eMG@1FEUH0DU9B05EEE@1?Cdl0DE5A05ADE014A4@0=cLg030`<00Q8B409bLW02h^;P0V9RH0
=cLg02d];@0h>3P0=CDe024Q8@1BDU80N7Qh04Y:BP13@d<0E5AD0410@012@T80@D51055AD@1UIFD0
FUYJ04a<C028R8P0GEeM07MgM`1oOgl0PH6107UiN@80MWIf00/0L71`07AdM01hN7P0NGUi07IfMP1h
N7P0M7Ad071`L01gMgL0MWIf071`L00307IfMR80oooo000P0?ooo`030::RXP2UYJD0XJ6Q0080XJ6Q
01X0WYjN0:FUY@2NWYh0YJFU0:6QX@2NWYh0YJFU09fMW@2IVIT0YjNW09jNWP2GUiL0IVIV05ADE013
@d<0?3`l0451@@0e=CD0;Bd]03/k>`0g=cL09RHV0<30`028R8P0RXZ:092@T0<0SHf=00<0TI6A08V9
R@2?Shl00P2=SHd0:P22PX80NGUi07YjNP1XJ6P0OWin07QhN01lO7`0P82007emO@24Q8@0Ph>308N7
Q`2?Shl0QhN707moO`1hN7P0QHF507=cL`1bLW80LG5a06UYJ@1_Kfl0KVi^05eMG@1?Cdl0=cLg024Q
8@0?3`l0ATI60410@01IFET0>c/k06EUI@18B4P0<S8b0:n_[`1[Jf/0Ng]k096AT@1TI6@0F5QH055A
D@80J6QX00L0WIfM07UiN@1VIVH0WYjN08N7Q`2QXJ40_kno00@0XJ6Q00<0VYZJ0:FUY@2QXJ400`2Q
XJ4209fMW@80XJ6Q00@0VYZJ0:6QX@2QXJ40XJ6Q7P3oool00`2MWId0Xj>S0:6QX@020:6QX@0J09^K
V`2SXj<0Vi^K0:FUY@2QXJ40Vi^K0:>SX`2PX:00VYZJ0:JVYP2KVi/0VIVI06MWI`17AdL0>SXj03Hf
=P0i>CT0<C4a02/[:`0i>CT0=cLg02DU9@3Lg=`0YjNW08^;R`2ATI4308f=S@0308j>SP28R8P0Shn?
0080SHf=00T0PH61079bLP1lO7`0J6QX07QhN01bLW80MGEe07]kN`1hN7P00P20P800:024Q8@0RXZ:
08N7Q`23Ph<0OGem08^;R`1hN7P0MWIf07=cL`1YJFT0Kfm_06e]K@1KFe/0De=C03Xj>P0Q8B4030`<
03hn?P0l?3`0F5QH03Hf=P1QHF40CDe=030`<02ZZZX0F5QH06QXJ02RXZ80I6AT05eMG@1HF5P0J6QX
069RHP2HV9P0Ng]k07QhN02XZ:P0RHV909nOW`2d];@40:6QX@0309ZJVP2UYJD0XJ6Q00<0XJ6Q00D0
X:2P0::RXP2TY:@0XJ6Q09ZJVP030:6QXAh0oooo00<0Kfm_07AdM01fMWH00P1fMWH0401`L700M7Ad
071`L01gMgL0MWIf071`L01dM7@0N7Qh07=cL`1gMgL0L71`07AdM01GEeL0;Bd]02PX:00T92@202<S
8`0801hN7P0V9RH0:BTY01`L702GUiL0RXZ:06IVIP1YJFT306MWI`0306EUI@1TI6@0IfMW0080IfMW
00D0HF5Q055AD@1MGEd0D51@055AD@0204m?C`0/05ADE01CDe<0FEUI05YJFP1NGUh0GemO069RHP1V
IVH0HF5Q06YZJP1MGEd0FUYJ05MGE`1?Cdl0DE5A051@D013@d<0A4A4034a<@0L71`01`L702<S8`0Y
:BT0>SXj02HV9P0n?Sh0>c/k02@T901QHF40<c<c03dm?@1lO7`0BDU904a<C016ATH0BDU90451@@1R
HV80GUiN06][J`1gMgL0J6QX06][J`1bLW8407IfMP03079bLP1gMgL0MWIf00<0MWIf00D0N7Qh07]k
N`1iNGT0MWIf079bLP0307IfMR80oooo000P0?ooo`0309fMW@2QXJ40XJ6Q0080XJ6Q00D0WIfM09jN
WP2QXJ40XJ6Q09jNWP030:6QX@0F09bLW02QXJ40WIfM09BDU01PH600@T9203dm?@0j>SX0;Bd]03`l
?00^;Rh0=SHf02XZ:P0V9RH0m?Cd08J6QP2:RXX0Ti>C08Z:RP2DU9@0S8b<08R8R080RXZ:00h0Ti>C
06i^KP1eMGD0NGUi07EeM@1XJ6P0C4a<06MWI`21PH40GemO08Z:RP27QhL0Q8B408b<S0<0QhN700@0
OWin0820P01gMgL0MgMg0P1_Kfl07@1YJFT0KVi^05YJFP1=CDd0@d=302@T900?3`l0;Rh^0410@019
BDT0@D5105UIF@0j>SX0BDU905MGE`1jNWX0Q8B407moO`1@D500IFEU04=3@`1[Jf/0GUiN09FEU@1m
OGd0V9RH06IVIP2h^;P0LG5a00D0XJ6Q00<0WIfM0:6QX@2QXJ401`2QXJ40102MWId0XJ6Q09jNWP2U
YJDN0?ooo`030::RXP2TY:@0XJ6Q0080XJ6Q02l0X:2P09jNWP2QXJ40Y:BT09^KV`2QXJ40Y:BT0:6Q
X@2OWil0YJFU0:2PX02BTY80EEEE03Xj>P0e=CD0=cLg02TY:@0h>3P0<30`03Ph>00V9RH08b<S0?Ge
m@25QHD0R8R8096AT@27QhL0U9BD096AT@2;Rh/0S8b<08V9R@2CTi<0GUiN05=CD`28R8P0Ogmo06i^
KP0o?cl0AdM707MgM`1?Cdl0Lg=c07inOP21PH40Shn?08f=S@0208N7Q`0608>3P`1oOgl0MWIf07Qh
N01`L700LW9b0P1]KFd0701NGUh0BTY:04A4A00X:2P0410@02/[:`0j>SX0@T9203dm?@1HF5P0>3Ph
04e=C@1>CTh0HV9R08^;R`1dM7@0EUIF069RHP0l?3`0H61P05MGE`2IVIT0OGem0:f][@1ZJVX0/K6a
06][J`2d];@40:6QX@030:2PX02TY:@0XJ6Q00L0XJ6Q00@0X:2P0:6QX@2KVi/0Xj>S7P3oool00`1k
Ng/0NGUi07IfMP0207IfMP0A07QhN01dM7@0MWIf07UiN@1`L700MWIf07UiN@1fMWH0N7Qh07YjNP1h
N7P0Jf][0492@P0X:2P08b<S02LW9`0M7Ad00P0U9BD0100Z:RX06QXJ01PH6027QhL2065QH@0F06MW
I`1RHV80Jf][06m_K`1YJFT0J6QX06ATI01ZJVX0?Shn02@T901`L700IVIV05UIF@0X:2P06QXJ04a<
C00_;bl0?3`l055AD@1JFUX0J6QX06YZJP80I6AT02@0IfMW05eMG@1GEeL0FUYJ05EEE@1HF5P0De=C
051@D019BDT0=cLg03Hf=P0V9RH03`l?01/K6`0S8b<0:2PX02XZ:P0j>SX0:BTY03`l?00/;2`0<S8b
06ATI018B4P0BDU904E5A@0Z:RX0>CTi03Xj>P1ZJVX0G5aL08V9R@1FEUH0LG5a04m?C`2>SXh407If
MP0307QhN01iNGT0MWIf00L0MWIf00@0N7Qh07IfMP1`L700M7Ad8P3oool00200oooo102MWId01`2Q
XJ40WYjN0:FUY@2QXJ40WYjN0:FUY@2MWId00P2QXJ405P2WYjL0XJ6Q09fMW@1mOGd0@T9204A4A00_
;bl0>c/k03Xj>P0];Bd0>3Ph020P800U9BD0JFUY0;bl_02;Rh/0SHf=09NGU`2=SHd0R8R8092@T027
QhL208Z:RP0A09RHV022PX80Shn?08R8R020P800NGUi06i^KP1fMWH0Ng]k07AdM01RHV80Kfm_08Z:
RP2@T900RXZ:08F5Q@27QhL00`1oOgl08P1gMgL0M7Ad07=cL`1XJ6P0H61P05aLG01FEUH0BTY:0410
@0071`L05QHF0492@P0o?cl0Bd];02h^;P0d=3@0ATI601`L702[Zj/0H61P07alO00l?3`0JFUY04E5
A@1IFET0I6AT08F5Q@2DU9@0QHF506i^KP24Q8@0`/;209ZJVP2UYJD30:6QX@0409fMW@2QXJ40WYjN
0:FUY@H0XJ6Q00@0WIfM0:FUY@2QXJ40XJ6Q7P3oool20::RXP0P0:2PX02RXZ80Y:BT09^KV`2SXj<0
XJ6Q09jNWP2UYJD0X:2P0:BTY02QXJ40Xj>S0:6QX@2PX:00O7al03dm?@0n?Sh09bLW03<c<`0j>SX0
;bl_03Xj>P0O7al08R8R07=cL`3>c/h0Rh^;08Z:RP2DU9@0Shn?092@T02EUID208b<S00D08V9R@2F
UYH0P82009>CT`2ATI40QXJ60861P@1hN7P0Ng]k07UiN@1cLg<0KVi^07alO02?Shl0TI6A08^;R`26
QXH0QhN708B4Q01oOgl207YjNP0Q07QhN01fMWH0JVYZ05mOG`1JFUX0E5AD04Q8B011@D4020P801DE
5@11@D40@d=304i>CP0];Bd0<c<c04I6AP0M7Ad0YjNW05MGE`23Ph<0>c/k06UYJ@18B4P0GemO06AT
I025QHD0UIFE08F5Q@1eMGD0UIFE0<k>cP2JVYX0YJFU00<0XJ6Q00H0X:2P0:BTY02KVi/0Xj>S0:6Q
X@2TY:@40:6QX@040:2PX02UYJD0XJ6Q0:6QXAh0oooo0P1kNg/0;`1hN7P0Ng]k07UiN@1`L700M7Ad
07IfMP1dM7@0MgMg07QhN01iNGT0MWIf07=cL`1fMWH0N7Qh065QH@0g=cL0:b/[01PH600O7al0:b/[
02HV9P0/;2`05aLG01PH601BDU80R8R806EUI@1RHV80J6QX06][J`1aLG40L71`06a/K01XJ6P0I6AT
06UYJ@1OGel0KFe]075aL@1YJFT0J6QX06=SH`1NGUh0EUIF05EEE@1MGEd0Hf=S0080IfMW02P0IVIV
06ATI01SHf<0IfMW05iNGP1GEeL0GEeM05aLG01JFUX0De=C04Q8B013@d<0?Shn03Hf=P0d=3@020P8
00l?3`0[:b/0<C4a03Ti>@0R8R80:2PX038b<P0J6QX0G5aL03/k>`1PH600=cLg04Y:BP0l?3`0B4Q8
04M7A`1LG5`0IfMW065QH@1PH600MgMg08n?S`1bLW80MgMg0`1fMWH01P1hN7P0NGUi071`L01dM7@0
MWIf07UiN@@0MWIf00@0N7Qh07MgM`1fMWH0MWIf8P3oool00200oooo0P2QXJ400`2NWYh0YJFU09jN
WP020:6QX@1C09jNWP2JVYX0YJFU0:6QX@2MWId0YjNW0::RXP2UYJD0WYjN07UiN@0g=cL0A4A4038b
<P0d=3@0>3Ph03Lg=`0j>SX07AdM02/[:`2h^;P0QhN708j>SP2=SHd0Shn?092@T02?Shl0TI6A08j>
SP25QHD0QhN709^KV`26QXH0SXj>08R8R023Ph<0Q8B407MgM`1cLg<0NWYj07MgM`1aLG40NWYj08F5
Q@2@T900SHf=08B4Q02:RXX0QHF507inOP1hN7P0OGem07AdM01gMgL0Jf][06=SH`1JFUX0De=C04U9
B@0n?Sh04a<C01hN7P0n?Sh092@T061PH00b<S80;Bd]04A4A00f=SH0KFe]06m_K`25QHD0EUIF051@
D01NGUh0CTi>061PH02BTY80UiNG07YjNP2?Shl0Vi^K0:FUY@2MWId0102QXJ400`2RXZ80YJFU09fM
W@0;0:6QXAh0oooo0P2QXJ404`2KVi/0Xj>S09^KV`2QXJ40Y:BT09^KV`2MWId0YJFU0:6QX@2IVIT0
Xj>S0:2PX02SXj<0Vi^K07=cL`0_;bl0@D5103Hf=P0i>CT00P0h>3P05P0m?Cd06a/K02`/;03Ogml0
Zj^[09:BTP2DU9@0UIFE096AT@2?Shl0TI6A08j>SP26QXH0Q8B409VIV@2<S8`0U9BD08f=S@23Ph<0
QHF507YjNP1fMWH207MgM`0/075aL@1nOWh0RHV9092@T02>SXh0Q8B408^;R`26QXH0Ph>307emO@1o
Ogl0MWIf07UiN@1_Kfl0Jf][05aLG01CDe<0BDU903dm?@0E5AD071`L03lo?`0N7Qh0EEEE03De=@0Z
:RX0?clo03hn?P1aLG40IVIV08F5Q@1JFUX0EUIF061PH01ADE40G5aL08V9R@2GUiL0MGEe096AT@2g
]kL0^;Rh0:2PX02TY:@30:6QX@0409fMW@2SXj<0X:2P0:BTY0L0XJ6Q00<0Y:BT0:6QX@2QXJ407P3o
ool207IfMP0:071`L01dM7@0L71`07IfMP1iNGT0L71`07EeM@1gMgL0MWIf06i^KP80Lg=c00@0M7Ad
071`L01IFET0:RXZ0P0^;Rh05@0];Bd0:2PX02XZ:P0_;bl05ADE020P802RXZ80T92@06a/K01bLW80
L71`06YZJP1XJ6P0JFUY06QXJ01TI6@0GUiN06][J`1^KVh0L71`06a/K002069RHP0?05mOG`1JFUX0
EUIF05QHF01DE5@0GUiN06ATI01VIVH0IfMW06=SH`1VIVH0I6AT06IVIP1QHF40GUiN0080FUYJ01l0
EUIF05QHF017AdL0?clo03Ph>00];Bd05QHF018B4P0Y:BT04Q8B030`<00];Bd0820P02TY:@0f=SH0
BTY:0451@@1JFUX0CTi>04E5A@19BDT0@41003hn?P1DE5@0J6QX05=CD`1YJFT0UIFE08j>SP1hN7P0
NGUi00<0MWIf00@0Kfm_07AdM01hN7P0NGUi1`1fMWH00`1iNGT0MWIf07IfMP0R0?ooo`00803oool2
0:6QX@0409fMW@2QXJ40WIfM0:6QX@80WYjN01P0VYZJ0::RXP2UYJD0W9bL09jNWP2MWId0XJ6Q09VI
V@1HF5P0?3`l02/[:`0i>CT0=3@d03Ti>@0j>SX0>3Ph02HV9P0L71`0oooo08Z:RP2?Shl0V9RH092@
T02?Shl2092@T00T08n?S`28R8P0PX:2096AT@2>SXh0UYJF08n?S`26QXH0PX:207EeM@1cLg<0O7al
07=cL`1jNWX0P82008V9R@28R8P0SXj>08R8R024Q8@0QhN708J6QP1nOWh0N7Qh07EeM@1iNGT0Lg=c
06e]K@1GEeL0De=C04e=C@12@T808b<S01PH600d=3@0>SXj0P12@T80400^;Rh0?clo03Ti>@1TI6@0
Kfm_07YjNP1gMgL0>3Ph06=SH`1=CDd0GemO092@T02;Rh/0Hf=S0:^[Z`2n_[h209jNWP80XZ:R00@0
YJFU0:6QX@2JVYX0YJFU1`2QXJ400`2NWYh0YJFU0:6QX@020:6QXAh0oooo0P2QXJ40102PX:00Y:BT
0:2PX02TY:@209^KV`0309ZJVP2PX:00Xj>S0080WinO02P0XZ:R0:BTY02HV9P0@d=302XZ:P0W9bL0
<C4a030`<00h>3P0>c/k03Lg=`0R8R806a/K0?Ogm`2<S8`0T92@09JFUP2@T900Shn?092@T02ATI40
T92@08f=S@2;Rh/0TY:B08J6QP2ATI40Rh^;08R8R024Q8@0L71`06YZJP1jNWX0L71`07UiN@25QHD0
TI6A08j>SP2?Shl0SHf=0`26QXH08P23Ph<0OGem07EeM@1iNGT0MGEe075aL@1IFET0De=C04m?C`17
AdL0:b/[01PH600a<C40@T9204Q8B010@400;Bd]0451@@0e=CD0GUiN06a/K01bLW80QhN703lo?`1M
GEd0B4Q805iNGP2RXZ80Ti>C05YJFP2NWYh0_kno09jNWP2KVi/209fMW@040:>SX`2QXJ40WIfM0:FU
Y@L0XJ6Q00<0Vi^K0:>SX`2QXJ400P2QXJ4N0?ooo`80MWIf00@0N7Qh07UiN@1hN7P0NGUi0P1`L702
079bLP0C07AdM01hN7P0MGEe07]kN`1iNGT0L71`02d];@0J6QX06a/K01`L700Q8B409bLW02XZ:P0W
9bL05QHF018B4P1oOgl0IfMW06QXJ00206UYJ@0L06QXJ01YJFT0JVYZ06YZJP1]KFd0KVi^06YZJP1M
GEd0IFEU06=SH`1WIfL0I6AT059BDP19BDT0EUIF051@D01HF5P0Hf=S06i^KP1[Jf/0J6QX06][J`1U
IFD0HF5Q069RHP1WIfL0HF5Q05QHF080FEUI00P0F5QH04M7A`0o?cl0?Cdm03/k>`0/;2`0410@01hN
7P80=SHf00P0;Rh^02DU9@0_;bl092@T03Ti>@17AdL0B4Q8071`L080?Cdm00T0<c<c0451@@1iNGT0
KVi^0451@@1OGel0P82007AdM01`L7000P1_Kfl0101dM7@0MWIf07EeM@1gMgL707IfMP03071`L01d
M7@0MWIf0080MWIf8P3oool00200oooo0P2RXZ820:6QX@0309jNWP2UYJD0WIfM00<0WIfM00<0WYjN
0:FUY@2JVYX00P2QXJ40302GUiL0=3@d03Xj>P0X:2P0@41003@d=00h>3P0=cLg01DE5@0N7Qh0:BTY
0?3`l080Shn?0P2@T9004@2?Shl0T92@092@T02@T900TI6A08b<S025QHD0S8b<08j>SP28R8P0Rh^;
07moO`1iNGT0JFUY07UiN@1cLg<0OWin0080QhN702H0R8R808f=S@2@T900PX:208V9R@24Q8@0QhN7
07MgM`1jNWX0M7Ad07MgM`1^KVh0F5QH05ADE01;Bd/0B4Q8030`<00T92@08b<S03lo?`0k>c/0@d=3
04E5A@0g=cL0>CTi06ATI01ZJVX0KVi^09JFUP0a<C40EEEE04Y:BP1OGel0V9RH09NGU`1]KFd0WYjN
0:FUY@@0WIfM0P2QXJ400`2MWId0XJ6Q0:6QX@020:6QX@060:FUY@2QXJ40XJ6Q0:6QX@2JVYX0XZ:R
0`2QXJ4N0?ooo`80WIfM0P2QXJ402@2KVi/0Xj>S0:2PX02RXZ80X:2P0::RXP2NWYh0Xj>S09ZJVP02
0:6QX@0?09NGU`0_;bl0=cLg02DU9@14A4@0>SXj03/k>`0g=cL04A4A01hN7P0[:b/0o?cl096AT@2E
UID0U9BD0080Shn?00H0T92@08n?S`2?Shl0TI6A08n?S`26QXH208^;R`0`08F5Q@24Q8@0MWIf07If
MP1[Jf/0Ng]k07MgM`25QHD0TY:B08j>SP28R8P0S8b<08n?S`22PX80Rh^;08J6QP27QhL0N7Qh07em
O@1hN7P0NGUi06i^KP1PH600Fe]K04i>CP18B4P0<C4a02LW9`0T92@0>CTi03De=@0o?cl0B4Q803`l
?00k>c/0JVYZ06i^KP1_Kfl0W9bL03Lg=`1EEED0AdM705aLG02;Rh/0SXj>0820P038b<P0^;Rh0P2P
X:020::RXP040:BTY02QXJ40X:2P0:BTY0<0XJ6Q00H0Xj>S0:6QX@2QXJ40XJ6Q09ZJVP2PX:030:6Q
XAh0oooo0P1_Kfl207IfMP06071`L01dM7@0N7Qh07]kN`1hN7P0Ng]k0P1dM7@04`1bLW80MWIf07If
MP1`L700<30`02/[:`0K6a/0<S8b02l_;`0];Bd0:2PX00X:2P0F5QH08B4Q09>CT`1ZJVX0L71`06i^
KP1WIfL00P1XJ6P206MWI`0:06UYJ@1[Jf/0I6AT06EUI@1SHf<0H61P05]KF`1CDe<0EeMG05ADE080
Fe]K01H0IFEU071`L01[Jf/0Hf=S06ATI01WIfL0HV9R06MWI`1TI6@0Hf=S05]KF`1PH600G5aL05YJ
FP1BDU80DE5A04a<C00n?Sh0=cLg02TY:@0M7Ad06QXJ0P0R8R801@0Y:BT0=cLg034a<@0^;Rh0BTY:
0080Cdm?00X0LG5a03/k>`0n?Sh0<c<c03hn?P1ADE40G5aL079bLP2WYjL0SXj>0P1hN7P207]kN`04
07UiN@1fMWH0N7Qh07UiN@<0MWIf00@0M7Ad07IfMP1fMWH0MWIf0P1bLW8307IfMR80oooo000P0?oo
o`80WIfM00<0XJ6Q09jNWP2QXJ40102QXJ40102NWYh0XJ6Q09jNWP2QXJ420::RXP0>09bLW00/;2`0
=cLg038b<P10@400=CDe03Ti>@0j>SX05aLG028R8P1nOWh0X:2P08f=S@2GUiL308n?S`0:09FEU@2>
SXh0SXj>096AT@2@T900R8R808N7Q`24Q8@0R8R807inOP80MgMg02/0Lg=c07inOP1iNGT0PX:208j>
SP2;Rh/0Q8B408Z:RP2DU9@0PX:208N7Q`26QXH0QhN707MgM`1nOWh0NWYj07AdM01_Kfl0JFUY05IF
EP1:BTX0BDU903dm?@0>3Ph0;Bd]02DU9@18B4P0@T9204a<C015ADD0=cLg065QH@1lO7`0Jf][0:2P
X00b<S80I6AT03Hf=P1/K6`0Y:BT08n?S`26QXH0_[jn0100XJ6Q0P2MWId00`2QXJ40WYjN0:FUY@0N
0?ooo`80XZ:R00@0XJ6Q09^KV`2QXJ40Y:BT0`2QXJ40102KVi/0XJ6Q09jNWP2QXJ4209fMW@0>09^K
V`0/;2`0=CDe03De=@14A4@0=3@d03Lg=`0i>CT06ATI024Q8@2`/;00f][J08j>SP2EUID308n?S`05
09VIV@2FUYH0UYJF096AT@2@T9000P2=SHd01024Q8@0SHf=08:2PP1gMgL207=cL`0C0861P@20P800
R8R8092@T02>SXh0QhN708^;R`2GUiL0QhN708Z:RP26QXH0R8R807MgM`1mOGd0Ng]k07IfMP1_Kfl0
J6QX05QHF00204U9B@0F0492@P0=3@d0:RXZ028R8P15ADD0AdM704U9B@17AdL0>SXj05mOG`1oOgl0
M7Ad0:2PX00_;bl0JFUY03Lg=`1[Jf/0YZJV09^KV`2:RXX0`L710:BTY0/0XJ6Q00T0Y:BT0:6QX@2Q
XJ40XJ6Q0:2PX02RXZ80XJ6Q09^KV`2SXj<07P3oool207]kN`0407IfMP1`L700MWIf07UiN@<0MWIf
00@0L71`07IfMP1dM7@0MWIf0P1_Kfl0201aLG40=CDe02/[:`0Z:RX0<S8b02HV9P0W9bL0:RXZ0P0H
61P0102FUYH0]KFe06QXJ01ZJVX306UYJ@0B079bLP1eMGD0MGEe06YZJP1YJFT0KFe]06a/K01RHV80
KFe]06EUI@1JFUX0De=C05IFEP1PH600Hf=S06MWI`1XJ6P0JFUY0P1VIVH00`1^KVh0JVYZ06MWI`02
06=SH`80Fe]K01d0GEeM05UIF@1CDe<0CTi>04I6AP0h>3P0=SHf03Lg=`092@T06QXJ01LG5`0/;2`0
=SHf02l_;`0g=cL0;bl_03hn?P1HF5P0Fe]K06a/K00_;bl0Cdm?02h^;P17AdL0Jf][07EeM@1XJ6P0
Ph>307UiN@0;07IfMP0907UiN@1fMWH0MWIf07IfMP1hN7P0Ng]k07IfMP1`L700M7Ad0280oooo000P
0?ooo`0309jNWP2QXJ40YJFU00H0XJ6Q0140WIfM09ZJVP2UYJD0XJ6Q09fMW@2QXJ40?Shn04=3@`0l
?3`0Bd];03De=@0h>3P0>SXj01XJ6P0[:b/0inOW08f=S@02096AT@0709BDU02EUID0UIFE08V9R@2?
Shl0T92@09>CT`0308n?S`0=096AT@27QhL0T92@08R8R01oOgl0LW9b07=cL`20P800OWin08:2PP2=
SHd0SXj>09FEU@0208j>SP0A08V9R@2:RXX0SXj>08N7Q`23Ph<0QHF507UiN@1jNWX0Lg=c06IVIP1^
KVh0C4a<04Q8B00o?cl09RHV02d];@0`<3000P12@T803018B4P0@41004];B`1OGel0PX:206i^KP29
RHT0De=C04E5A@0`<300JVYZ08N7Q`80[Zj^2P2QXJ4209fMW@030:6QX@2MWId0WYjN00<0XJ6Q00@0
WYjN0:6QX@2QXJ40XJ6Q7P3oool00`2NWYh0Y:BT0:FUY@060:6QX@0D0::RXP2MWId0YJFU0:6QX@2R
XZ80Y:BT02LW9`0[:b/0=SHf04Q8B00d=3@0=CDe03Xj>P0K6a/0;bl_0?gmo@2@T900Ti>C09JFUP2@
T90209VIV@0408V9R@2?Shl0TI6A09RHV0<0Shn?00D0TI6A08J6QP2@T900SHf=08J6QP0207=cL`80
Ph>300L0Q8B408^;R`2>SXh0V9RH08n?S`2CTi<0SXj>0080RHV900h0RXZ:08J6QP26QXH0O7al07]k
N`1cLg<0JFUY06e]K@1>CTh0Bd];03lo?`0Y:BT0;bl_02h^;P80@D5100l0C4a<03lo?`1CDe<0Kfm_
08R8R01[Jf/0OGem04e=C@13@d<0;Bd]06UYJ@2?Shl0/K6a0;Jf]P2VYZH01`2QXJ402`2TY:@0XJ6Q
0:2PX02RXZ80Y:BT0:2PX02NWYh0XJ6Q0:BTY02QXJ40Vi^K00<0XJ6Q7P3oool00`1dM7@0NGUi07Mg
M`0607IfMP0D07]kN`1eMGD0MgMg07IfMP1kNg/0NGUi01PH600C4a<092@T02h^;P0V9RH09BDU02XZ
:P0F5QH09BDU09fMW@1YJFT0Jf][06m_K`1VIVH2079bLP0406MWI`1YJFT0JVYZ079bLP<0JFUY00T0
JVYZ06ATI01YJFT0KFe]06UYJ@1JFUX0EUIF069RHP1TI6@00P1RHV80701WIfL0Kfm_06][J`1_Kfl0
KVi^06EUI@1QHF40J6QX06IVIP1TI6@0GemO05eMG@1GEeL0DU9B051@D010@400?Cdm030`<00R8R80
8b<S01lO7`0];Bd0;2`/03Ti>@0_;bl0@d=305UIF@1NGUh204e=C@0803dm?@0d=3@08b<S04A4A01V
IVH0MgMg08F5Q@1lO7`707IfMP0;07UiN@1fMWH0N7Qh07]kN`1iNGT0N7Qh07AdM01fMWH0NGUi07If
MP1`L7000`1fMWHR0?ooo`00803oool00`2NWYh0YJFU0:6QX@070:6QX@0:09ZJVP2UYJD0XJ6Q09jN
WP2UYJD071`L03hn?P0a<C40CDe=03Lg=`80=3@d00`09RHV024Q8@2l_;`0RXZ:09BDU02@T900Shn?
09FEU@2?Shl0T92@08j>SP2ATI4209FEU@0J08j>SP29RHT0T92@08b<S02?Shl0Rh^;08Z:RP1bLW80
Lg=c08Z:RP22PX80QhN708J6QP2@T900TI6A09FEU@2?Shl0Rh^;08Z:RP2CTi<0RXZ:08B4Q027QhL0
PH6107QhN01_Kfl206YZJP0F059BDP19BDT0?3`l028R8P0Y:BT0;bl_03hn?P0m?Cd0B4Q804A4A017
AdL0QhN706m_K`1^KVh0NWYj06MWI`0f=SH0@D5105QHF02@T900_[jn0:VYZ@X0XJ6Q00D0WYjN0:FU
Y@2NWYh0XJ6Q09fMW@030:6QX@0409fMW@2QXJ40XJ6Q0:6QXAh0oooo00<0WYjN0:FUY@2TY:@01@2Q
XJ407`2TY:@0XJ6Q09ZJVP2UYJD0XJ6Q09^KV`2SXj<071`L0492@P0a<C40D51@03Xj>P0f=SH0<S8b
02LW9`0Q8B40h^;R08j>SP2GUiL0T92@08n?S`2IVIT0Rh^;08f=S@2?Shl0TI6A09:BTP2IVIT0UYJF
08f=S@2@T9000P2?Shl01P25QHD0Q8B4079bLP1cLg<0QhN708:2PP80Rh^;00d0TI6A08j>SP2DU9@0
Shn?08J6QP24Q8@0UYJF08Z:RP24Q8@0QhN708F5Q@1nOWh0LW9b0080K6a/01H0E5AD04Y:BP0l?3`0
8R8R02HV9P0^;Rh0?3`l03Xj>P18B4P0ATI604E5A@29RHT0N7Qh06i^KP1hN7P0L71`03dm?@1:BTX0
HF5Q08^;R`37alL0/K6a2P2QXJ401P2KVi/0Xj>S09^KV`2QXJ40X:2P0:BTY080XJ6Q00@0X:2P0:6Q
X@2QXJ40XJ6Q7P3oool00`1dM7@0MgMg07UiN@0507IfMP0C07UiN@1fMWH0LW9b07MgM`1fMWH0L71`
07AdM00/;2`0=SHf02DU9@0h>3P0;bl_02XZ:P0S8b<0820P01PH602TY:@0Jf][06i^KP0206QXJ00<
079bLP1TI6@0IFEU06UYJ@1ZJVX0IfMW079bLP1eMGD0K6a/06QXJ01/K6`0J6QX0P1NGUh01@1HF5P0
EUIF05eMG@1OGel0J6QX0080JFUY01@0I6AT06YZJP1XJ6P0GemO05iNGP1_Kfl0IVIV069RHP1SHf<0
IVIV06=SH`1HF5P0E5AD059BDP14A4@0>c/k02l_;`0J6QX06ATI020P80809bLW00h0=CDe03Hf=P0_
;bl0Fe]K05aLG01@D500E5AD05eMG@0k>c/0@D5104Y:BP1IFET0R8R808:2PPX0MWIf00H0L71`07Ad
M01`L700MWIf07QhN01iNGT207IfMP0407QhN01fMWH0MWIf07IfMR80oooo000P0?ooo`0509fMW@2Q
XJ40YJFU09jNWP2UYJD00P2QXJ40102NWYh0XJ6Q0:6QX@2MWId20:6QX@0>09fMW@2NWYh07alO04];
B`0`<300>3Ph04=3@`0g=cL092@T03De=@0d=3@0SXj>08Z:RP2DU9@208n?S`0609JFUP2?Shl0T92@
092@T02?Shl0SHf=0P2FUYH03@2?Shl0T92@092@T02HV9P0R8R808V9R@1^KVh0LG5a08N7Q`26QXH0
R8R808b<S02>SXh00P2@T9008P2DU9@0QHF508j>SP2<S8`0Rh^;08N7Q`28R8P0QHF507emO@1hN7P0
KFe]06YZJP1MGEd0B4Q803lo?`0Y:BT09BDU02h^;P0`<300A4A404Y:BP0n?Sh0?3`l0:ZZZP1VIVH0
IfMW071`L022PX80;2`/05eMG@1DE5@0TY:B0<k>cP2WYjL:0:6QX@0509fMW@2QXJ40WIfM09jNWP2U
YJD01`2QXJ4N0?ooo`050::RXP2TY:@0Xj>S09^KV`2SXj<00P2QXJ40502KVi/0XJ6Q0:6QX@2PX:00
Y:BT0:6QX@2PX:00WYjN01/K6`1=CDd0=CDe03Hf=P0m?Cd0=cLg028R8P0d=3@0?clo0;:b/P2=SHd0
U9BD0P2?Shl02@2>SXh0Rh^;092@T02@T900Shn?08R8R02BTY80SXj>08^;R`02096AT@0609:BTP2=
SHd0Ti>C07EeM@1dM7@0QHF50P24Q8@09P27QhL0Rh^;08f=S@2=SHd0TI6A08J6QP2DU9@0SHf=08J6
QP25QHD0R8R808B4Q01lO7`0OWin06e]K@1[Jf/0HF5Q04m?C`16ATH0;Bd]02PX:00_;bl0;Rh^0492
@P17AdL0>SXj03De=@2ZZZX0Jf][06=SH`1/K6`0Ogmo02PX:01IFET0EUIF092@T03>c/h0Z:RX2P2Q
XJ401@2PX:00Y:BT0:2PX02KVi/0Xj>S00L0XJ6Q7P3oool01@1kNg/0NGUi07AdM01`L700M7Ad0080
MWIf01@0L71`07IfMP1fMWH0N7Qh07UiN@1fMWH0N7Qh07AdM00W9bL0>c/k02h^;P0T92@0:2PX02XZ
:P0I6AT092@T03Lg=`2DU9@0JFUY06YZJP80JFUY00<0HF5Q06ATI01XJ6P00P1YJFT0101QHF40IVIV
065QH@1TI6@206YZJP0:06ATI01/K6`0Lg=c065QH@1KFe/0GEeM05iNGP1LG5`0GUiN065QH@80I6AT
0280IfMW06IVIP1aLG40J6QX05iNGP1PH600Hf=S065QH@1LG5`0Hf=S059BDP1@D500Cdm?04A4A00k
>c/09RHV024Q8@0R8R807alO02d];@0b<S80:2PX02<S8`1WIfL0E5AD04M7A`1<C4`0EeMG02DU9@0l
?3`0@41005aLG023Ph<0NGUi2P1fMWH01@1hN7P0NGUi07QhN01`L700M7Ad00L0MWIf8P3oool00200
oooo00P0XZ:R0:FUY@2QXJ40VYZJ0:FUY@2NWYh0YJFU09ZJVPD0XJ6Q00h0YJFU075aL@0_;bl0Cdm?
03Ph>00e=CD0>c/k02`/;00X:2P0=SHf09:BTP24Q8@0UIFE08j>SP80Shn?01L0UIFE08V9R@2?Shl0
TI6A08^;R`28R8P0U9BD092@T02EUID0T92@08Z:RP2CTi<0Shn?096AT@1gMgL0KFe]07moO`22PX80
RXZ:07inOP2GUiL0T92@09BDU00208b<S00O096AT@28R8P0RXZ:08N7Q`28R8P0QXJ607alO022PX80
LW9b06YZJP1NGUh0EUIF0410@00_;bl07QhN034a<@0];Bd0?Shn03lo?`10@400?Cdm09^KV`1YJFT0
KVi^04a<C02^[Zh06QXJ061PH01WIfL0Q8B40=KFeP0=0:6QX@0309jNWP2MWId0XJ6Q00L0XJ6Q7P3o
ool0202MWId0Xj>S0:BTY02JVYX0YJFU09^KV`2SXj<0VYZJ1@2QXJ403P2SXj<0EeMG01/K6`16ATH0
=3@d03`l?00n?Sh0:BTY02HV9P0g=cL0aLG508J6QP2EUID0TY:B0P2?Shl0>@2IVIT0SHf=08n?S`2A
TI40R8R808>3P`2<S8`0RXZ:09>CT`2ATI40Q8B409JFUP2?Shl0TI6A07]kN`1aLG40Ng]k07UiN@24
Q8@0MGEe08f=S@2>SXh0U9BD08b<S029RHT0SXj>08:2PP29RHT0QhN708R8R026QXH0OGem08:2PP1e
MGD0Kfm_05mOG`1HF5P0@d=3034a<@0M7Ad0;bl_02d];@0l?3`0@D510410@012@T80Vi^K05mOG`1^
KVh0?Shn09nOW`0H61P0F5QH06][J`2;Rh/0f][J0:FUY@0<0:6QX@0309^KV`2PX:00Y:BT00L0XJ6Q
7P3oool0201_Kfl0M7Ad07UiN@1bLW80MgMg071`L01dM7@0LW9b1@1fMWH03P1dM7@0=3@d018B4P0[
:b/09RHV038b<P0^;Rh071`L01/K6`0W9bL0YJFU06EUI@1[Jf/0KFe]0P1YJFT06`1bLW80K6a/06UY
J@1ZJVX0HV9R05eMG@1OGel0HF5Q06QXJ01ZJVX0GUiN06i^KP1YJFT0JVYZ06=SH`1JFUX0EEEE051@
D01JFUX0D51@05]KF`1TI6@0JVYZ06IVIP1SHf<0I6AT05aLG00406=SH`0J05iNGP1OGel0FUYJ05QH
F019BDT0ATI603Ph>00X:2P05QHF020P800Q8B409bLW038b<P0`<300=CDe05iNGP10@400D51@02PX
:01JFUX071`L03@d=01>CTh0I6AT08b<S01jNWX<07IfMP03071`L01hN7P0NGUi00L0MWIf8P3oool0
0200oooo00<0WIfM0:6QX@2NWYh00P2QXJ400`2JVYX0YJFU09fMW@050:6QX@040:FUY@0f=SH0DE5A
03`l?080;bl_01h0?Shn028R8P0h>3P0=SHf0=gMg@24Q8@0W9bL08n?S`2EUID0RHV909NGU`2>SXh0
S8b<096AT@20P800Shn?08b<S02=SHd0UIFE09JFUP23Ph<0U9BD08j>SP2ATI40OGem06YZJP1dM7@0
OWin0861P@22PX8208b<S00408Z:RP2<S8`0R8R8096AT@80R8R801`0RHV908R8R025QHD0PH6107Mg
M`1_Kfl0KVi^06=SH`1FEUH0ATI603<c<`0J6QX0820P03<c<`0j>SX0B4Q803lo?`13@d<0TI6A06EU
I@1]KFd0:RXZ0;fm_@0O7al0AdM707IfMP29RHT0a/K60P2QXJ400`2NWYh0YJFU0:6QX@080:6QX@03
09ZJVP2QXJ40XJ6Q00L0XJ6Q7P3oool0202RXZ80Y:BT09^KV`2QXJ40Y:BT09ZJVP2UYJD0X:2P1@2Q
XJ408@2UYJD0:2PX059BDP1:BTX0;bl_030`<00k>c/0820P03Ti>@0j>SX0hN7Q07inOP2JVYX0Shn?
09VIV@2=SHd0Ti>C08^;R`29RHT0Rh^;07AdM025QHD0RHV908N7Q`2?Shl0TY:B08B4Q02DU9@0Shn?
096AT@1mOGd0J6QX075aL@0207]kN`0908:2PP2BTY80Rh^;08J6QP21PH40OGem08J6QP22PX80QXJ6
0080R8R801X0Q8B408>3P`1eMGD0M7Ad06i^KP1WIfL0FEUI04U9B@0d=3@06a/K01hN7P0_;bl0>SXj
04M7A`11@D40@T9209:BTP1UIFD0Jf][02<S8`2][Jd0820P04U9B@1_Kfl0WIfM0=CDe080XJ6Q00<0
Vi^K0:>SX`2QXJ40202QXJ400`2JVYX0XJ6Q0:6QX@070:6QXAh0oooo00P0Ng]k07UiN@1`L700MWIf
07UiN@1bLW80MgMg07QhN0D0MWIf0380MgMg02@T9013@d<0ADE502DU9@0V9RH0:BTY01TI6@0Z:RX0
;Rh^08>3P`1IFET0JVYZ06QXJ01bLW80K6a/06MWI`1TI6@0Hf=S061PH01?Cdl0F5QH061PH01NGUh0
HV9R06MWI`1TI6@0Jf][06UYJ@1ZJVX0H61P051@D01ADE40EEEE05ADE01OGel0K6a/06=SH`1NGUh0
EUIF05ADE01HF5P0G5aL061PH01RHV80I6AT065QH@1RHV80EeMG05]KF`80DU9B00/0B4Q803`l?00Y
:BT05aLG01<C4`0N7Qh0:BTY03<c<`0b<S80<C4a05aLG00204a<C00701dM7@1IFET0:2PX03@d=014
A4@0Ng]k09>CT`0207IfMP03071`L01dM7@0MWIf00P0MWIf00<0LW9b07IfMP1fMWH01`1fMWHR0?oo
o`00803oool20:6QX@0909fMW@2QXJ40XJ6Q0:6QX@2MWId0XJ6Q0:FUY@2JVYX0XJ6Q0080WIfM00h0
YZJV00P8201XJ6P0<c<c04];B`17AdL06QXJ03hn?P0o?cl0d];B06MWI`2RXZ80UiNG08j>SP80Shn?
03T0QXJ607emO@1cLg<0O7al09RHV01hN7P0U9BD08J6QP2MWId0S8b<0861P@2IVIT0Shn?092@T01e
MGD0JVYZ07=cL`1eMGD0R8R807=cL`2DU9@0Ng]k07UiN@1dM7@0JVYZ07MgM`20P800N7Qh07moO`2B
TY80PX:207UiN@21PH40MgMg06i^KP1SHf<0F5QH04i>CP0j>SX0<C4a024Q8@0T92@0:BTY03lo?`1@
D500?Cdm07YjNP1_Kfl0De=C034a<@32`/809RHV03Lg=`2DU9@0];Bd0<30`02JVYX01@2QXJ400`2M
WId0XJ6Q0:6QX@070:6QX@0309fMW@2QXJ40XJ6Q00@0XJ6Q7P3oool20:6QX@090:2PX02TY:@0XJ6Q
0:6QX@2PX:00Y:BT0:>SX`2JVYX0Y:BT0080XZ:R00h0Zj^[014A4@1ZJVX0;2`/04E5A@16ATH05QHF
03lo?`13@d<0e=CD05mOG`2PX:00VIVI08j>SP80Shn?0100P82006m_K`1HF5P0EeMG07AdM01XJ6P0
Q8B407QhN02FUYH0SXj>08>3P`2JVYX0T92@096AT@1jNWX0Kfm_0P1/K6`09`2=SHd0NGUi09>CT`1d
M7@0JVYZ065QH@1CDe<0G5aL06e]K@1/K6`0Lg=c08f=S@22PX80M7Ad07IfMP1bLW80KFe]06EUI@1J
FUX0DE5A03Lg=`0b<S809bLW02TY:@0X:2P0?3`l04a<C00m?Cd0N7Qh06ATI01<C4`0<C4a0<[:bP0R
8R80=3@d09NGU`2_[jl0a/K609jNWP050:6QX@030:2PX02TY:@0XJ6Q00L0XJ6Q00<0X:2P0:BTY02Q
XJ40102QXJ4N0?ooo`80MWIf00T0N7Qh07UiN@1fMWH0MWIf07QhN01iNGT0M7Ad079bLP1iNGT00P1k
Ng/03P1oOgl0;Bd]04M7A`0Q8B40;Bd]038b<P0@4100;Rh^034a<@1nOWh0@T9206][J`1^KVh0J6QX
0P1YJFT0601JFUX0B4Q802d];@0R8R80=3@d0451@@1=CDd0C4a<06ATI01YJFT0Hf=S06e]K@1[Jf/0
JVYZ06ATI01IFET0BDU904Q8B01WIfL0GUiN06IVIP1ADE40@d=303Xj>P80;Bd]01l0?Cdm04E5A@19
BDT0GUiN05mOG`1BDU80CTi>055AD@1BDU80CTi>04I6AP11@D40:2PX02LW9`0U9BD08R8R01`L700Y
:BT0<C4a02h^;P1<C4`0?Shn03Lg=`0[:b/0O7al02<S8`0V9RH0H61P06i^KP29RHT0NGUi00D0MWIf
00<0N7Qh07UiN@1fMWH01`1fMWH00`1hN7P0NGUi07IfMP0407IfMR80oooo000P0?ooo`0:0::RXP2U
YJD0XJ6Q0:6QX@2NWYh0YJFU09jNWP2UYJD0XJ6Q09fMW@<0XJ6Q01`0L71`0410@01ADE40;Rh^04=3
@`1<C4`06QXJ04m?C`1eMGD0Rh^;05QHF02VYZH0TY:B09BDU02?Shl0R8R806IVIP1hN7P0OWin05eM
G@16ATH0IFEU08N7Q`1aLG40QXJ60;:b/P28R8P0WIfM0P2@T900301mOGd0Kfm_071`L01SHf<0S8b<
0492@P1mOGd0QHF508B4Q012@T80@d=3075aL@80IVIV01`0Lg=c09FEU@27QhL0NGUi07YjNP1bLW80
Lg=c06=SH`1KFe/0CDe=03Xj>P0a<C40>3Ph01/K6`0S8b<0?Cdm04Q8B01=CDd0JVYZ06][J`1;Bd/0
=3@d0<O7a`0S8b<0B4Q8096AT@2g]kL0];Bd302QXJ400`2NWYh0YJFU0:6QX@080:6QXAh0oooo00/0
WIfM0:>SX`2QXJ40XJ6Q09^KV`2SXj<0Vi^K0:>SX`2TY:@0X:2P0:BTY0020:6QX@0L04i>CP0Y:BT0
DU9B02XZ:P0o?cl0BDU901`L701EEED0Z:RX0;>c/`1CDe<0YZJV08j>SP2@T900Shn?08>3P`19BDT0
EeMG07]kN`1dM7@0?3`l04A4A01iNGT0H61P06QXJ02EUID0QHF509^KV`80T92@02/0O7al079bLP1d
M7@0HV9R07moO`0Y:BT0CTi>05]KF`2>SXh0@410034a<@1MGEd0EeMG059BDP1NGUh0P82007QhN01c
Lg<0NGUi06m_K`1`L700HF5Q05UIF@1:BTX0?clo038b<P0n?Sh07AdM024Q8@0m?Cd0ATI604m?C`1_
Kfl0KFe]04];B`0b<S80a/K602DU9@1CDe<0YJFU0<K6aP2h^;P0WIfM00/0XJ6Q00<0Vi^K0:>SX`2Q
XJ40202QXJ4N0?ooo`0;06m_K`1dM7@0MWIf07IfMP1`L700M7Ad071`L01dM7@0NGUi07QhN01iNGT0
0P1fMWH0700W9bL06a/K03dm?@0P8200:RXZ034a<@0J6QX0?3`l09VIV@2CTi<0@d=306i^KP1TI6@0
IVIV06UYJ@1MGEd092@T02HV9P1FEUH0JFUY02LW9`0F5QH0AdM703Ti>@0`<300CDe=061PH01/K6`2
06UYJ@0[05mOG`1KFe/0F5QH04U9B@1;Bd/04A4A00h>3P0O7al0KVi^03Hf=P0I6AT0<30`038b<P0/
;2`0<S8b04I6AP1;Bd/0DE5A05QHF01@D500DE5A04U9B@13@d<0=cLg03@d=00X:2P0<S8b01PH600F
5QH0;Bd]034a<@0k>c/0CTi>04m?C`0k>c/0:BTY07=cL`0[:b/0ATI607MgM`2;Rh/0PH61071`L00;
07IfMP03071`L01dM7@0MWIf00P0MWIf8P3oool00200oooo00L0WIfM0:6QX@2QXJ40XJ6Q09fMW@2Q
XJ40WIfM0080XJ6Q03D0WYjN0:FUY@2QXJ40XJ6Q03@d=01TI6@0?clo03Lg=`0S8b<0B4Q801lO7`0X
:2P0m?Cd071`L01YJFT0XJ6Q092@T02;Rh/0RXZ:07emO@1QHF40P82008N7Q`0l?3`0@d=303dm?@1[
Jf/0NWYj069RHP2MWId0QXJ609bLW02@T900Rh^;08>3P`1dM7@0IFEU05iNGP1bLW80CDe=02l_;`2/
[:`0@d=305=CD`0m?Cd0J6QX03hn?P12@T80DU9B07inOP2<S8`0N7Qh07moO`0206m_K`0D06UYJ@1D
E5@0C4a<03Lg=`0c<c<0:BTY00h>3P0O7al0@d=303<c<`1NGUh0JVYZ06ATI017AdL0?Shn0:b/[00R
8R80Ng]k08F5Q@3>c/h:0:6QX@0509jNWP2UYJD0XJ6Q09fMW@2NWYh02@2QXJ4N0?ooo`0;0::RXP2T
Y:@0XJ6Q0:6QX@2PX:00Y:BT0:2PX02TY:@0XJ6Q09^KV`2SXj<00P2QXJ404`0/;2`0J6QX04Q8B00m
?Cd08R8R04];B`0O7al08b<S0>GUi@1cLg<0KFe]0:FUY@2DU9@0Rh^;0820P01^KVh0De=C09NGU`2]
[Jd00P0d=3@0<`0i>CT0G5aL075aL@1UIFD0UIFE07=cL`2LW9`0T92@08N7Q`1oOgl0M7Ad069RHP1C
De<0I6AT05eMG@0i>CT0^k^k03/k>`0j>SX0?clo06m_K`0h>3P0BDU904Q8B01ZJVX0O7al075aL@1k
Ng/0KVi^06a/K01YJFT0E5AD04];B`0e=CD0<S8b02@T900:2PX071`L04A4A00`<300EeMG06][J`1P
H600@4100492@P2`/;006a/K07inOP2DU9@0emOG0:VYZ@090:6QX@0509^KV`2SXj<0XJ6Q0:2PX02N
WYh02@2QXJ4N0?ooo`0;07]kN`1iNGT0MWIf07IfMP1hN7P0NGUi07QhN01iNGT0MWIf071`L01dM7@0
0P1fMWH0B00^;Rh0DE5A0410@00f=SH06ATI03Hf=P0K6a/051@D07=cL`1IFET0EeMG07=cL`1^KVh0
IfMW05QHF018B4P0=cLg07YjNP2EUID0:BTY020P800V9RH0=3@d04U9B@1=CDd0Fe]K04I6AP1^KVh0
JFUY065QH@1MGEd0FEUI04I6AP0h>3P0?3`l05UIF@0e=CD0PH6102`/;00L71`0<c<c051@D00X:2P0
?Shn02`/;00f=SH0B4Q804e=C@1EEED0DU9B04e=C@1?Cdl0@T9203Xj>P0X:2P092@T01LG5`061PH0
4A4A03<c<`0Q8B40=SHf04U9B@11@D40;Bd]03Ph>01]KFd06ATI05IFEP1]KFd0Shn?07moO`T0MWIf
00D0L71`07AdM01fMWH0N7Qh07AdM00907IfMR80oooo000P0?ooo`L0XJ6Q00<0WYjN0:6QX@2MWId0
0`2QXJ40A`0o?cl0=3@d03Ph>00l?3`08B4Q0451@@0c<c<0=3@d0=SHf01UIFD0KVi^09bLW02FUYH0
R8R807QhN01XJ6P0<30`0:n_[`2QXJ40=CDe06YZJP0820P0=cLg07EeM@1`L700Ogmo096AT@2GUiL0
T92@08N7Q`22PX80MgMg05=CD`1JFUX0D51@07QhN019BDT0HF5Q028R8P2?Shl02PX:07QhN00g=cL0
6a/K04i>CP1`L700N7Qh07EeM@24Q8@0Lg=c06=SH`1^KVh0FEUI04];B`0i>CT0=SHf01LG5`0C4a<0
71`L04i>CP0a<C40Hf=S05MGE`1OGel0Cdm?04E5A@2PX:0071`L08N7Q`21PH40alO700X0XJ6Q00D0
WIfM0:6QX@2QXJ40XJ6Q09fMW@090:6QXAh0oooo1`2QXJ40102KVi/0XJ6Q0:2PX02TY:@20:6QX@0A
07QhN01;Bd/0;2`/034a<@0N7Qh0?Shn03Lg=`18B4P0lo?c065QH@1UIFD0V9RH08n?S`21PH40KFe]
05IFEP0Q8B400P24Q8@08`0^;Rh0S8b<00T92@0/;2`0FUYJ05eMG@1`L700QhN709ZJVP2@T900R8R8
08:2PP1iNGT0F5QH05aLG01;Bd/0JVYZ05UIF@1JFUX05ADE09nOW`0820P0G5aL030`<00B4Q80>c/k
06IVIP1/K6`0IFEU07UiN@1_Kfl0GUiN06EUI@1GEeL0C4a<0080=cLg00l05ADE018B4P0M7Ad0@d=3
034a<@1XJ6P0E5AD05IFEP1@D500ATI60:2PX00K6a/0QHF507YjNP3De=@02P2QXJ401@2PX:00Y:BT
0:6QX@2QXJ40X:2P00T0XJ6Q7P3oool707IfMP04071`L01fMWH0N7Qh07UiN@80MWIf0380W9bL059B
DP0L71`07AdM01HF5P0[:b/0;bl_04E5A@2NWYh0C4a<04A4A01UIFD0H61P05]KF`1;Bd/0=CDe00h>
3P0];Bd0@D5102/[:`1mOGd02PX:01TI6@0U9BD0<c<c0410@01FEUH0Kfm_06UYJ@1VIVH0HV9R05iN
GP1;Bd/0AdM703@d=00m?Cd0EEEE03Hf=P0C4a<0M7Ad00T92@0R8R808B4Q00`<300I6AT0>c/k03lo
?`0l?3`0C4a<051@D080A4A400L0@D5103`l?00X:2P0:RXZ014A4@0>3Ph05ADE00809BDU00X0B4Q8
03Xj>P0f=SH0?Shn03Lg=`1SHf<07alO055AD@1>CTh0TY:B2P1fMWH01@1hN7P0NGUi07IfMP1fMWH0
N7Qh00T0MWIf8P3oool00200oooo1`2QXJ400`2MWId0XJ6Q0:6QX@030:6QX@0o0<?3``0n?Sh0>CTi
030`<00/;2`0?Cdm04A4A01LG5`0/;2`069RHP1_Kfl0V9RH08n?S`1jNWX0KVi^05QHF00o?cl0F5QH
04=3@`0X:2P0BDU9030`<00h>3P0GUiN06e]K@1jNWX0QhN7096AT@2EUID0R8R808:2PP1lO7`0GUiN
05MGE`1?Cdl0E5AD05aLG01MGEd07QhN03Ph>00T92@0=CDe03hn?P0h>3P0>SXj06UYJ@1VIVH0IFEU
07]kN`1bLW80H61P05iNGP1KFe/0@D510410@00b<S808b<S01HF5P0Z:RX0<c<c03Xj>P1PH600EUIF
0080CTi>00H0Bd];09NGU`0S8b<0MgMg07YjNP2^[ZhA0:6QX@0309jNWP2UYJD0XJ6Q00@0XJ6Q7P3o
ool70:6QX@030:2PX02QXJ40XJ6Q00<0XJ6Q04L0Ph>3038b<P12@T80=cLg038b<P0m?Cd0AdM706YZ
JP2j^[X0EeMG06][J`2IVIT0T92@07AdM01TI6@0DE5A03lo?`1GEeL0:2PX01<C4`0/;2`09RHV03dm
?@1ZJVX0MWIf08f=S@2HV9P0T92@09:BTP28R8P0PH6107emO@1VIVH0HF5Q05YJFP1EEED0C4a<05]K
F`0B4Q809BDU01HF5P0d=3@0<c<c02d];@14A4@0JVYZ06=SH`1OGel0LG5a06e]K@1MGEd0FEUI05=C
D`0i>CT0@D5103<c<`0V9RH06ATI02l_;`0b<S80=SHf05eMG@1EEED0C4a<04E5A@1>CTh0W9bL02PX
:01oOgl0NWYj0;jn_P0A0:6QX@0309^KV`2SXj<0XJ6Q00@0XJ6Q7P3oool707IfMP0307QhN01fMWH0
MWIf00<0MWIf01/09RHV02`/;00n?Sh0<C4a02`/;00];Bd0=CDe05EEE@1iNGT0?Shn04e=C@1ZJVX0
J6QX05=CD`16ATH0?3`l034a<@0g=cL020P8000000051@D06a/K03De=@1@D500F5QH071`L01fMWH0
0P1WIfL0:P1UIFD0HF5Q05mOG`1HF5P0DU9B04m?C`0o?cl0:b/[0492@P0<30`020P800/;2`0Q8B40
7AdM01hN7P0g=cL0ATI604A4A00o?cl0ATI604a<C016ATH0?clo03Ph>00V9RH0<C4a02LW9`0R8R80
5QHF02DU9@0Q8B408b<S03/k>`0l?3`0=SHf02`/;00n?Sh0IfMW02l_;`1HF5P0E5AD08j>SQ40MWIf
00<0L71`07AdM01fMWH0101fMWHR0?ooo`00803oool30:6QX@0509fMW@2QXJ40XJ6Q0:6QX@2MWId0
0P2QXJ40402NWYh0YJFU0:6QX@0l?3`0DU9B038b<P0c<c<0?clo02d];@1FEUH0L71`07emO@1aLG40
JFUY09fMW@2;Rh/208F5Q@0V071`L01<C4`0?3`l03De=@0h>3P0?Cdm03`l?01DE5@0N7Qh08B4Q02E
UID0TI6A09BDU02@T900SHf=08:2PP24Q8@0Lg=c06IVIP1aLG40GemO06YZJP18B4P0De=C05QHF01;
Bd/0?Cdm03Xj>P1BDU80IfMW06=SH`1PH600I6AT06i^KP1RHV80HF5Q069RHP1>CTh203Ph>00@02d]
;@0_;bl07QhN02d];@0/;2`0;Bd]06=SH`1/K6`0@T9204I6AP1XJ6P0R8R803<c<`1eMGD0XZ:R09ZJ
VQH0XJ6Q00<0WYjN0:FUY@3oool07@3oool30:6QX@050:2PX02TY:@0XJ6Q0:6QX@2PX:000P2QXJ40
502KVi/0Xj>S0:6QX@1GEeL0@D5102HV9P0^;Rh0>SXj02TY:@1IFET0NWYj07EeM@1XJ6P0Hf=S09VI
V@2=SHd0S8b<09BDU029RHT0RXZ:0P28R8P02@2;Rh/0TY:B09RHV01gMgL0PX:208>3P`2BTY80UiNG
09>CT`0208n?S`0D08V9R@2:RXX0Lg=c069RHP1^KVh0GemO07MgM`1`L700J6QX06MWI`1VIVH0K6a/
07emO@2<S8`0Rh^;0861P@1nOWh0NGUi07MgM`1SHf<205iNGP0;055AD@0j>SX0>SXj02TY:@0Z:RX0
7AdM02d];@0c<c<0;Rh^061PH01^KVh00P14A4@01P1_Kfl0SHf=03De=@1jNWX0_kno0:>SXaH0XJ6Q
00<0Vi^K0:>SX`3oool07@3oool307IfMP0507QhN01iNGT0MWIf07IfMP1hN7P00P1fMWH0301`L700
M7Ad07IfMP1LG5`092@T01LG5`0P82008b<S01`L700o?cl0EeMG04U9B@80ADE500L0I6AT06QXJ01]
KFd0N7Qh07alO02LW9`0YjNW0080Zj^[01h0/K6a0;Zj^P1dM7@0HV9R05]KF`1TI6@0LW9b06UYJ@1W
IfL0Jf][06a/K01[Jf/0FEUI04U9B@1?Cdl0BDU9065QH@1iNGT0GemO05UIF@1TI6@0NGUi09BDU02@
T900Ogmo07MgM`1fMWH0JFUY05eMG@1<C4`204=3@`0C0451@@0a<C40;Bd]01`L700K6a/05QHF020P
800/;2`08b<S03/k>`1>CTh0=cLg038b<P1CDe<0Hf=S03@d=01FEUH0U9BD07moO`0F07IfMP03071`
L01dM7@0oooo0240oooo000P0?ooo`80XJ6Q00@0YJFU0:6QX@2NWYh0YJFU0`2QXJ407@2NWYh0XJ6Q
0:6QX@2VYZH051@D051@D00S8b<0<C4a030`<00N7Qh0DU9B06YZJP1iNGT0KVi^061PH02RXZ80PX:2
09NGU`2EUID0Rh^;08N7Q`1oOgl0NWYj06=SH`1WIfL0KVi^06MWI`2QXJ40Ph>30080T92@00T0Ti>C
08V9R@2ATI40Rh^;08N7Q`1^KVh0IVIV05UIF@1@D5000P1ZJVX08027QhL0J6QX06EUI@1TI6@0JFUY
06i^KP1hN7P0NWYj07=cL`1^KVh0IfMW07=cL`1LG5`0FEUI05ADE013@d<0>SXj03De=@0O7al0820P
02@T900P8200?Cdm04m?C`1ZJVX0B4Q804E5A@1ZJVX0U9BD03<c<`1kNg/0bLW95`2QXJ400`2MWId0
XJ6Q0?ooo`0M0?ooo`80XJ6Q00@0Xj>S0:6QX@2KVi/0Xj>S0`2QXJ40B`2KVi/0XJ6Q0:BTY02[Zj/0
30`<03hn?P0M7Ad0;2`/02d];@0P8200Bd];05eMG@1aLG40Jf][05]KF`2UYJD0OWin09:BTP2FUYH0
SXj>09BDU02@T900TY:B06][J`1FEUH0CDe=04M7A`2EUID0TY:B0:6QX@2GUiL0VYZJ08f=S@2ATI40
SHf=08Z:RP1hN7P0L71`05MGE`0o?cl0D51@04e=C@2>SXh0TI6A09:BTP2?Shl0RXZ:0820P023Ph<0
P82007IfMP1]KFd0HF5Q06UYJ@1LG5`0EEEE04e=C@14A4@0>3Ph03Xj>P0P82007alO028R8P0J6QX0
>SXj04m?C`1OGel0@T9204E5A@1/K6`0VYZJ03Ti>@22PX80dm?C09fMW@0F0:6QX@030:2PX02TY:@0
oooo01d0oooo0P1fMWH0101dM7@0MWIf071`L01dM7@307IfMP0B071`L01fMWH0NGUi07moO`0A4A40
7QhN01@D500L71`07AdM01`L700[:b/0=3@d04I6AP1:BTX0@D51075aL@1KFe/0Hf=S0P1/K6`03@1f
MWH0NGUi0820P01KFe/0=3@d01hN7P0K6a/0FEUI07EeM@1nOWh0LW9b07EeM@1/K6`00P1ZJVX0:01Y
JFT0IFEU061PH012@T8092@T02<S8`0P8200JFUY08^;R`2@T900SHf=07moO`1]KFd0J6QX06=SH`1J
FUX0DU9B04=3@`14A4@0ATI603`l?00e=CD0=SHf02TY:@0`<3006QXJ01HF5P0G5aL0410@02HV9P0d
=3@0=cLg030`<00c<c<0Cdm?06a/K00k>c/0G5aL08^;R`1`L70F07IfMP0307QhN01iNGT0oooo0240
oooo000P0?ooo`@0XJ6Q00<0WIfM0:6QX@2QXJ400P2QXJ407@2MWId0XJ6Q0:6QX@2OWil00P820451
@@0Q8B40;bl_03Hf=P0/;2`0CDe=05ADE01[Jf/0Kfm_065QH@2ZZZX0OWin08Z:RP2IVIT0VYZJ092@
T02;Rh/0HV9R06UYJ@1FEUH0EeMG06=SH`22PX80QXJ60080UIFE01T0VYZJ08V9R@2ATI40Shn?08b<
S021PH40LW9b05ADE00m?Cd0>SXj04A4A01lO7`0YZJV08j>SP2BTY80Ph>307IfMP20P800MGEe07Ad
M01UIFD0EUIF065QH@1NGUh0DE5A0080CDe=0100:b/[03<c<`0O7al09RHV020P800k>c/0?clo04e=
C@1LG5`0BTY:03hn?P1VIVH0UIFE04];B`1aLG40g=cL6@2QXJ4N0?ooo`80XJ6Q00@0Y:BT0:6QX@2P
X:00Y:BT0`2QXJ402P2PX:00Y:BT0:6QX@2CTi<0000003`l?00O7al0;bl_03Ti>@0];Bd205MGE`0n
06=SH`1TI6@0GEeM0:>SX`1nOWh0Q8B408^;R`2DU9@0T92@08F5Q@16ATH0@d=30451@@1>CTh0X:2P
0;Bd]02EUID0VIVI09RHV02JVYX0RHV9096AT@2@T900Shn?08F5Q@22PX80K6a/05ADE00m?Cd0>SXj
05]KF`1nOWh0Ng]k08V9R@27QhL0NWYj08B4Q01dM7@0KVi^05aLG019BDT0I6AT05QHF01<C4`0B4Q8
04Y:BP0W9bL0:b/[01/K6`0W9bL08B4Q0410@01<C4`0EEEE065QH@1=CDd0?Cdm069RHP2;Rh/0CTi>
07]kN`3Ti>@I0:6QXAh0oooo0P1fMWH0101iNGT0MWIf07QhN01iNGT307IfMP0Q07QhN01iNGT0MWIf
06=SH`0A4A409BDU01LG5`0R8R80:b/[02HV9P13@d<0?Shn03dm?@0o?cl0@T9206EUI@1NGUh0FUYJ
05MGE`1UIFD0J6QX05iNGP0S8b<05aLG028R8P0b<S80Xj>S0:6QX@1gMgL0L71`075aL@1^KVh0IfMW
0080JVYZ02L0K6a/06UYJ@1`L700Jf][05UIF@0b<S808R8R024Q8@0d=3@0B4Q805]KF`1VIVH0H61P
06=SH`1FEUH0CTi>0410@00^;Rh0BTY:03hn?P0g=cL0<S8b03De=@0K6a/06ATI01<C4`0M7Ad06ATI
034a<@10@400@T9204M7A`0l?3`0;bl_04A4A01DE5@0ATI605eMG@2CTi<06@1fMWHR0?ooo`00803o
ool90:6QX@0K09jNWP2UYJD0YZJV06IVIP000000<30`034a<@0b<S809RHV03@d=01<C4`0BTY:051@
D01/K6`0IVIV0:FUY@2:RXX0GUiN08Z:RP2EUID0PX:206YZJP1LG5`0LG5a06QXJ01;Bd/0RHV90080
Rh^;00@0Shn?09FEU@2?Shl0Shn?0P2@T9001@2ATI40RHV908J6QP1gMgL0FUYJ0080=CDe00P0ATI6
05MGE`1fMWH0KVi^08>3P`1iNGT0MWIf06YZJP80Jf][01H0H61P069RHP1KFe/0BTY:04Q8B01=CDd0
@T9201@D500e=CD0;Bd]02HV9P0U9BD0FEUI055AD@1JFUX0Bd];0492@P1^KVh0I6AT05EEE@2XZ:P0
`/;23@2QXJ400`2NWYh0YJFU0:6QX@090:6QXAh0oooo2@2QXJ402`2KVi/0Xj>S0:^[Z`1CDe<010@4
03<c<`0d=3@0>CTi02DU9@0d=3@0Bd];0080ADE500/0GEeM05mOG`2TY:@0SXj>05=CD`1[Jf/0LW9b
05YJFP10@400?clo07UiN@020:RXZ00O0:^[Z`2LW9`0UiNG09VIV@2HV9P0Shn?08^;R`2@T900Shn?
096AT@2;Rh/0RXZ:08V9R@24Q8@0MWIf07QhN01ADE40A4A404m?C`16ATH0DU9B05IFEP1EEED0BTY:
04i>CP1GEeL0I6AT06=SH`1OGel0C4a<04Q8B00204e=C@0?01HF5P0e=CD0=CDe02`/;00Q8B40D51@
05=CD`1JFUX0B4Q80492@P1eMGD0GUiN0451@@2][Jd0fm_K00d0XJ6Q00<0Vi^K0:>SX`2QXJ402@2Q
XJ4N0?ooo`T0MWIf00l0L71`07AdM01oOgl0>3Ph01hN7P0X:2P0:RXZ02l_;`0J6QX0:2PX038b<P0]
;Bd0:2PX03@d=00n?Sh00P1[Jf/07P0k>c/0<c<c03@d=00S8b<0410@01`L701LG5`0ZJVY0<O7a`2C
Ti<0Ogmo07UiN@1gMgL0LG5a06QXJ01TI6@0J6QX06MWI`1YJFT0J6QX06YZJP1fMWH0RXZ:09FEU@2C
Ti<0ADE5020P800G5aL04A4A018B4P808b<S00@07QhN024Q8@0a<C40CTi>0P1;Bd/04`0l?3`0=cLg
03Ph>012@T8051@D02HV9P0];Bd09RHV01@D500^;Rh0?3`l03lo?`0d=3@0<c<c05UIF@0o?cl08b<S
07=cL`2OWil03@1fMWH00`1`L700M7Ad07IfMP0907IfMR80oooo000P0?ooo`T0XJ6Q00/0VYZJ0:FU
Y@2XZ:P0AdM702d];@0e=CD0ADE503Hf=P0/;2`0=cLg04A4A00204M7A`0=05]KF`1OGel0W9bL096A
T@1QHF40IFEU05mOG`1RHV80IFEU06=SH`1/K6`0Rh^;08n?S`0509FEU@0[08R8R02?Shl0UIFE08j>
SP2?Shl0S8b<08^;R`2=SHd0QXJ607UiN@1^KVh0BDU903Xj>P1;Bd/0>CTi04Q8B01PH600Fe]K06MW
I`1MGEd0FUYJ06UYJ@1RHV80G5aL04Y:BP1<C4`0DE5A03<c<`0^;Rh0;2`/02PX:00F5QH07AdM05mO
G`1DE5@0ADE505eMG@13@d<0LW9b04A4A01TI6@0bLW90:f][@0=0:6QX@0309fMW@2QXJ40WYjN00T0
XJ6Q7P3oool90:6QX@0K09ZJVP2UYJD0Y:BT0451@@0B4Q80=3@d04a<C00m?Cd0<S8b03@d=012@T80
A4A404Q8B01JFUX0FEUI0:6QX@2ATI40Ng]k09:BTP1_Kfl0H61P07inOP2][Jd0^KVi0:n_[`2IVIT0
V9RH00@0U9BD02/0RHV908n?S`2IVIT0UYJF09NGU`2?Shl0T92@09:BTP2:RXX0Ph>308F5Q@2;Rh/0
T92@0:2PX01YJFT0EUIF05EEE@1CDe<0K6a/07=cL`1[Jf/0Kfm_06MWI`1MGEd0BTY:04e=C@1FEUH0
:b/[02d];@0a<C409BDU018B4P0K6a/0GemO05EEE@10@400FUYJ04U9B@1dM7@0?3`l06EUI@3UiND0
^k^k00d0XJ6Q00<0X:2P0:BTY02KVi/02@2QXJ4N0?ooo`T0MWIf01/0LW9b07MgM`1cLg<0?Shn00@4
100V9RH0>c/k03<c<`0/;2`09BDU02`/;00_;bl0=3@d03`l?00j>SX0Kfm_06MWI`1hN7P0T92@069R
HP17AdL0LG5a0;Jf]P2n_[h0UYJF07MgM`1aLG40101]KFd0:`1WIfL0JFUY079bLP1eMGD0M7Ad06a/
K01]KFd0KVi^06YZJP1[Jf/0MgMg0:6QX@2d];@0^;Rh07YjNP1<C4`0=CDe03Lg=`1ADE40IFEU05aL
G01DE5@0DE5A04M7A`0j>SX0>c/k0492@P0I6AT08b<S02LW9`0H61P02`/;014A4@0k>c/0?Shn02/[
:`0m?Cd0?3`l05ADE00[:b/0BDU90::RXP2;Rh/03@1fMWH00`1hN7P0NGUi071`L00907IfMR80oooo
000P0?ooo`80XJ6Q00D0YJFU09fMW@2QXJ40XJ6Q09jNWP050:6QX@0J05eMG@0n?Sh0?clo06i^KP0o
?cl0=cLg03Xj>P13@d<0@T9204I6AP1RHV80Cdm?0:6QX@2>SXh0Rh^;08b<S02FUYH0SXj>09FEU@2>
SXh0Shn?09NGU`2JVYX0UIFE092@T02JVYX209FEU@0308Z:RP2DU9@0Vi^K0080Shn?02H0RHV9092@
T02?Shl0T92@08Z:RP24Q8@0PX:208N7Q`26QXH0OGem08b<S01nOWh0Lg=c079bLP1cLg<0Jf][079b
LP1SHf<0EUIF04U9B@1FEUH0E5AD04E5A@0U9BD06a/K01hN7P0H61P06a/K0:2PX00o?cl0>3Ph08b<
S012@T80WinO038b<P2PX:00eMGE09ZJVQT0XJ6Q7P3oool20:6QX@050:>SX`2PX:00Y:BT0:6QX@2K
Vi/01@2QXJ40501EEED0=SHf0451@@1hN7P0@d=303Lg=`0n?Sh0ADE50451@@14A4@0HF5Q04i>CP2P
X:00Shn?08f=S@2<S8`0UYJF08j>SP2IVIT0UYJF0P2?Shl02@2FUYH0U9BD08f=S@2FUYH0UIFE09BD
U02;Rh/0TI6A09NGU`0208^;R`0V08f=S@2ATI40T92@096AT@2>SXh0QXJ608:2PP27QhL0QHF507al
O02=SHd0NGUi07=cL`1_Kfl0L71`06YZJP1`L700IVIV05iNGP1<C4`0EEEE05=CD`1:BTX0;Bd]01dM
7@0Q8B406a/K01hN7P2UYJD0B4Q803dm?@28R8P0@D5109RHV00b<S80[Jf]0>_[j`2NWYhI0:6QXAh0
oooo0P1fMWH01@1dM7@0N7Qh07UiN@1fMWH0L71`00D0MWIf00d0AdM7028R8P0a<C40EUIF03Ph>00Z
:RX0<S8b03<c<`0^;Rh0;bl_0492@P0j>SX0JVYZ0080J6QX00/0IfMW06a/K01XJ6P0LW9b07EeM@1Y
JFT0Hf=S06YZJP1]KFd0IFEU06YZJP0206a/K00306QXJ01VIVH0JVYZ0080I6AT00/0K6a/06YZJP1[
Jf/0JVYZ06a/K01VIVH0HV9R06=SH`1PH600G5aL06IVIP0205IFEP80D51@0P1?Cdl00`1>CTh0CDe=
03dm?@0303`l?00?02XZ:P0H61P06QXJ01HF5P0H61P0I6AT04=3@`0d=3@0DU9B03Lg=`1KFe/0;bl_
07QhN02TY:@0NGUi01T0MWIf8P3oool00200oooo1P2QXJ400`2MWId0XJ6Q0:6QX@030:6QX@0405aL
G019BDT0@D51061PH080A4A40P0m?Cd04@0o?cl0@41005eMG@1CDe<0Z:RX09>CT`2?Shl0S8b<09:B
TP2?Shl0U9BD09^KV`2>SXh0Rh^;09ZJVP2EUID0Shn?00<0UIFE00<0Shn?08j>SP2EUID00P2>SXh0
0`2?Shl0T92@08j>SP02096AT@0908V9R@22PX80QhN708F5Q@23Ph<0PX:207YjNP1dM7@0LW9b0080
KVi^01D0Jf][06=SH`1DE5@0Cdm?05UIF@1=CDd0=SHf02DU9@0[:b/08b<S01<C4`0M7Ad0Z:RX04Y:
BP10@400QXJ60492@P2?Shl0?3`l0>3Ph02/[:`06P2QXJ4N0?ooo`80XJ6Q00H0Y:BT0:6QX@2QXJ40
XJ6Q0:2PX02TY:@40:6QX@0806MWI`1@D500BDU905eMG@0m?Cd0AdM703lo?`0m?Cd203`l?00@05MG
E`1?Cdl0W9bL08j>SP2<S8`0Rh^;08j>SP2@T900TI6A09NGU`2BTY80Shn?09ZJVP2DU9@0Ti>C09RH
V080U9BD00P0Ti>C09JFUP2IVIT0TY:B09JFUP2;Rh/0T92@08Z:RP80Rh^;0240R8R808:2PP26QXH0
Q8B408N7Q`22PX80O7al07=cL`1eMGD0LW9b075aL@1]KFd0J6QX051@D01<C4`0G5aL04i>CP0c<c<0
7QhN02/[:`0V9RH04a<C01XJ6P2XZ:P0BTY:04A4A02@T900ATI608B4Q00f=SH0no_k0<?3``2MWId0
6@2QXJ4N0?ooo`80MWIf00H0NGUi07IfMP1fMWH0MWIf07QhN01iNGT407IfMP0J06=SH`0o?cl0?3`l
03`l?00Z:RX0>3Ph034a<@0/;2`0:RXZ02TY:@0f=SH0=cLg05aLG01PH600I6AT06EUI@1SHf<0JVYZ
06IVIP1ZJVX0L71`06e]K@1^KVh0KFe]06m_K`1aLG4206e]K@0806m_K`1dM7@0LW9b071`L01eMGD0
I6AT06QXJ01SHf<2065QH@0Q06EUI@1QHF40HV9R065QH@1VIVH0GemO05eMG@1FEUH0FUYJ05MGE`1F
EUH0De=C055AD@0k>c/0>3Ph04E5A@0k>c/08b<S01<C4`0P82007alO00l?3`0A4A40H61P03`l?00i
>CT0IFEU03`l?01:BTX0:b/[0:ZZZP2EUID0L71`01T0MWIf8P3oool00200oooo102QXJ400`2NWYh0
YJFU0:6QX@050:6QX@0407inOP0o?cl0@T9204M7A`80BTY:0100@d=303/k>`11@D40>c/k065QH@1E
EED0VIVI08b<S02EUID0S8b<08f=S@2@T900SXj>09JFUP2KVi/0Shn?0P2EUID00`2@T900UIFE09ZJ
VP0309FEU@0608n?S`2FUYH0UYJF08n?S`2:RXX0T92@0P2=SHd07`2:RXX0QhN708N7Q`1nOWh0RXZ:
0861P@1jNWX0Lg=c07UiN@1_Kfl0LG5a06=SH`1QHF40Fe]K04m?C`1DE5@0Bd];03<c<`0U9BD0=3@d
01PH600D51@0:2PX07alO01dM7@0A4A407inOP16ATH0EEEE07]kN`3GemL0402QXJ400`2NWYh0YJFU
0:6QX@080:6QXAh0oooo102QXJ400`2KVi/0Xj>S0:6QX@050:6QX@0K092@T00n?Sh0>c/k03hn?P13
@d<0B4Q80410@00k>c/0@T9203dm?@1VIVH0GEeM09^KV`26QXH0T92@08b<S02>SXh0T92@08j>SP2B
TY80UiNG09>CT`2HV9P0U9BD08f=S@2?Shl0UYJF00<0U9BD00H0Rh^;08j>SP2>SXh0Shn?08F5Q@2<
S8`208f=S@0P08V9R@24Q8@0QhN707YjNP22PX80OGem07YjNP1bLW80N7Qh071`L01bLW80GemO05YJ
FP1LG5`0EEEE05ADE017AdL0;Rh^02DU9@0f=SH05aLG01<C4`0[:b/0MgMg07AdM01GEeL0R8R804Q8
B01=CDd0PH610?knoP2TY:@?0:6QX@0309^KV`2SXj<0XJ6Q00P0XJ6Q7P3oool407IfMP03071`L01d
M7@0MWIf00D0MWIf00H0Ogmo02`/;00U9BD092@T02/[:`0b<S8202`/;00C034a<@0^;Rh0B4Q804Y:
BP1XJ6P0Fe]K06=SH`1VIVH0J6QX06UYJ@1XJ6P0IVIV06YZJP1_Kfl0LG5a06e]K@1UIFD0Hf=S06YZ
JP0306e]K@0606ATI01QHF40HF5Q06UYJ@1OGel0Hf=S0P1WIfL00`1SHf<0GUiN06=SH`0205QHF008
05UIF@1LG5`0EUIF05QHF01EEED0E5AD04A4A00o?cl204I6AP0A03dm?@0c<c<08B4Q01hN7P0X:2P0
4Q8B00d=3@0P8200@d=305=CD`1DE5@0HV9R03dm?@0_;bl0GemO0;Jf]P1iNGT03`1fMWH00`1`L700
M7Ad07IfMP0807IfMR80oooo000P0?ooo`@0XJ6Q00<0WIfM0:6QX@2QXJ401@2QXJ40102RXZ80Bd];
03Lg=`17AdL204U9B@0@03hn?P0o?cl0?Cdm04M7A`1KFe/0JFUY08n?S`2<S8`0UIFE08b<S02ATI40
T92@08n?S`2CTi<0UIFE092@T080UIFE00@0Rh^;09FEU@2EUID0Shn?0P2EUID02@29RHT0Shn?08n?
S`2?Shl0R8R808b<S028R8P0SHf=08R8R00208N7Q`0A07MgM`20P800PH6107inOP1dM7@0MWIf071`
L01bLW80I6AT05]KF`1MGEd0FUYJ051@D017AdL0:2PX03De=@0M7Ad00P0J6QX01`0S8b<0L71`0861
P@1:BTX0PH6105IFEP0l?3`00P2o_kl@0:6QX@0309fMW@2QXJ40XJ6Q00P0XJ6Q7P3oool40:6QX@03
0:2PX02TY:@0XJ6Q00D0XJ6Q0140ZJVY04a<C00k>c/0BTY:04m?C`1>CTh0@D510410@00m?Cd0BDU9
05aLG01[Jf/0Rh^;08R8R02FUYH0SHf=09BDU002092@T00609RHV02IVIT0SHf=08n?S`2DU9@0Rh^;
0P2HV9P0102;Rh/0U9BD09BDU029RHT208n?S`06092@T02>SXh0U9BD08^;R`2=SHd0R8R80P27QhL0
2@1gMgL0OWin07emO@1kNg/0MWIf07MgM`1_Kfl0LW9b06QXJ00205]KF`0A05YJFP1CDe<0B4Q802LW
9`0f=SH06a/K01LG5`0J6QX08R8R06e]K@1lO7`0@D5107IfMP1GEeL0@4100=3@d03Bd]80402QXJ40
0`2PX:00Y:BT0:6QX@080:6QXAh0oooo101fMWH00`1hN7P0NGUi07IfMP0507IfMP0C0861P@0h>3P0
<30`03Ph>00m?Cd0?3`l038b<P0`<300;Bd]03Hf=P10@400C4a<05YJFP1MGEd0JVYZ06MWI`1]KFd0
JFUY06YZJP02079bLP0406EUI@1SHf<0KFe]06QXJ080LG5a00@0I6AT06e]K@1]KFd0IfMW0P1YJFT0
1P1[Jf/0KVi^079bLP1YJFT0IfMW06ATI080Hf=S00<0Fe]K05YJFP1HF5P00`1IFET05P1BDU80De=C
05=CD`15ADD0@T9204=3@`11@D40=cLg01hN7P0X:2P04a<C010@400D51@05QHF0410@01>CTh0;Rh^
04I6AP15ADD0=CDe08Z:RP2FUYH@07IfMP0307QhN01iNGT0MWIf00P0MWIf8P3oool00200oooo302Q
XJ403P2^[Zh0=CDe04A4A01>CTh0Bd];0451@@0j>SX0@D5104];B`14A4@0EeMG06][J`23Ph<0TI6A
0P2BTY80202ATI40UIFE092@T02EUID0VYZJ08n?S`2:RXX0VYZJ0P2?Shl01P2GUiL0Ti>C09BDU02F
UYH0T92@08j>SP80T92@0280SHf=09FEU@28R8P0SHf=08F5Q@22PX80QhN707moO`1hN7P0OGem07Yj
NP1fMWH0MgMg06m_K`1bLW80Hf=S05]KF`1JFUX0GEeM04U9B@1=CDd0;2`/02d];@0J6QX05ADE00l?
3`14A4@0DU9B06e]K@1@D500OWin05iNGP0o?cl0d=3@702QXJ4N0?ooo``0XJ6Q01T0[Zj^03Ph>010
@400De=C04i>CP0n?Sh0>CTi03lo?`1@D500BDU905MGE`1YJFT0PH6108j>SP2?Shl0T92@08n?S`2B
TY80T92@09:BTP2FUYH0Ti>C08f=S@2FUYH0Ti>C0080Shn?02X0U9BD08f=S@2>SXh0SHf=08n?S`2A
TI40T92@08Z:RP2BTY80R8R808f=S@23Ph<0QHF508J6QP23Ph<0P82008:2PP1lO7`0M7Ad07IfMP1_
Kfl0LW9b05mOG`1KFe/0FUYJ05eMG@14A4@0BDU902l_;`0];Bd061PH01@D500>3Ph0C4a<05YJFP1Q
HF40BTY:08:2PP1TI6@0GemO0?ooo`2d];@K0:6QXAh0oooo301fMWH03`1lO7`0;Bd]02`/;00m?Cd0
>SXj02/[:`0Z:RX0;2`/03dm?@0i>CT0?Cdm04I6AP1GEeL0H61P06=SH`0206IVIP0506MWI`1YJFT0
IfMW06YZJP1_Kfl00P1ZJVX0;@1_Kfl0J6QX06=SH`1]KFd0HV9R065QH@1UIFD0JFUY06YZJP1YJFT0
Hf=S06MWI`1UIFD0IfMW05mOG`1VIVH0HV9R06IVIP1UIFD0Hf=S05eMG@1EEED0EUIF05=CD`1DE5@0
A4A404E5A@13@d<0A4A4038b<P0c<c<0:2PX024Q8@0B4Q803Ph>00T92@0h>3P0@D5103Ph>00e=CD0
Fe]K04m?C`1VIVH0_kno08j>SP0K07IfMR80oooo000P0?ooo`80XJ6Q00<0YJFU09jNWP2UYJD01`2Q
XJ400`2XZ:P0;2`/03lo?`030451@@0@04=3@`11@D40@41004M7A`1QHF40Jf][07YjNP2@T900SXj>
08n?S`2BTY80Shn?096AT@2JVYX0UIFE08Z:RP80VYZJ00@0Rh^;09BDU02ATI40Ti>C0P2?Shl2092@
T080Shn?00D0TI6A092@T02:RXX0RXZ:08V9R@0208N7Q`0407MgM`2?Shl0MGEe07=cL`80N7Qh01@0
Lg=c06i^KP1QHF40De=C05MGE`1<C4`0CDe=04=3@`0/;2`092@T018B4P0D51@08B4Q06YZJP1<C4`0
DE5A04=3@`22PX80K6a/0<[:bQd0XJ6Q7P3oool20:6QX@030:>SX`2KVi/0Xj>S00L0XJ6Q01h0Y:BT
059BDP0g=cL0>3Ph03dm?@0l?3`0@D5103dm?@13@d<0CTi>065QH@1[Jf/0PH61092@T02>SXh0Shn?
09FEU@2?Shl0TI6A09ZJVP2DU9@0Rh^;09^KV`2FUYH0Rh^;092@T02=SHd0UiNG08^;R`2?Shl2096A
T@0=092@T02?Shl0TI6A092@T024Q8@0RHV908n?S`25QHD0QhN707MgM`2?Shl0MGEe07=cL`0207Qh
N00E07IfMP1`L700I6AT059BDP1ADE40BDU904m?C`19BDT0:RXZ024Q8@0B4Q805ADE028R8P1`L700
Cdm?05=CD`15ADD0PX:206m_K`3Ng]h0[Zj^01`0XJ6Q7P3oool207IfMP0307AdM01`L700M7Ad00L0
MWIf01h0Lg=c065QH@0U9BD092@T02TY:@0W9bL0;Rh^02TY:@0e=CD0?Cdm0492@P1:BTX0GemO06AT
I01UIFD0IfMW06i^KP1XJ6P0JFUY06i^KP1]KFd0J6QX06m_K`1ZJVX0J6QX06IVIP1UIFD0LG5a06AT
I01XJ6P306YZJP<0JFUY00T0GUiN06EUI@1]KFd0H61P06=SH`1KFe/0IFEU05UIF@1FEUH00P1GEeL0
5@1JFUX0EUIF04m?C`0o?cl0>CTi03Hf=P0l?3`0?Cdm01hN7P0G5aL03Ph>010@400I6AT0B4Q803/k
>`0m?Cd0=CDe05EEE@1CDe<0Vi^K08J6QP0L07IfMR80oooo000P0?ooo`<0XJ6Q00<0WIfM0:6QX@2Q
XJ401`2QXJ403`0H61P0>c/k03dm?@0f=SH0@41003Ti>@13@d<0Bd];04e=C@1TI6@0IFEU07]kN`2<
S8`0SXj>096AT@0208j>SP0<096AT@2EUID0UIFE092@T02DU9@0UIFE08n?S`2>SXh0RXZ:09JFUP2:
RXX0Shn?0`2@T9000`2?Shl0T92@08Z:RP0408f=S@0K08:2PP1nOWh0QhN707UiN@1cLg<0MgMg07=c
L`1mOGd0KVi^06a/K01GEeL0F5QH04e=C@13@d<0ATI602HV9P0K6a/06QXJ00h>3P0M7Ad0Ng]k04I6
AP1;Bd/0B4Q808R8R01jNWX0`/;201d0XJ6Q7P3oool20:6QX@030:BTY02PX:00Y:BT00P0XJ6Q01h0
61PH03Hf=P0m?Cd0=3@d03hn?P0e=CD0@41004a<C01?Cdl0Jf][06UYJ@1oOgl0Shn?08j>SP2BTY80
RXZ:08j>SP2ATI40TY:B08n?S`2=SHd0T92@09RHV02CTi<0UYJF08f=S@2ATI40SXj>092@T02ATI43
092@T00Q096AT@24Q8@0RXZ:08n?S`2=SHd0T92@08F5Q@23Ph<0S8b<07alO01cLg<0MgMg071`L01j
NWX0KVi^071`L01CDe<0G5aL05=CD`11@D40?clo024Q8@0H61P06ATI00d=3@0K6a/0P82004Y:BP18
B4P0A4A408^;R`26QXH0e=CD01d0XJ6Q7P3oool207IfMP0307UiN@1hN7P0NGUi00P0MWIf0P0V9RH0
2P0/;2`092@T02XZ:P0T92@0;2`/03Hf=P0k>c/0Cdm?04e=C@1LG5`206EUI@0@06YZJP1QHF40J6QX
06YZJP1WIfL0Hf=S06EUI@1VIVH0LG5a06m_K`1dM7@0Jf][06EUI@1/K6`0Jf][06YZJP80JFUY0P1Z
JVX01@1NGUh0Hf=S06YZJP1WIfL0K6a/0080IVIV01T0JFUY061PH01FEUH0F5QH055AD@1FEUH0DU9B
05MGE`0m?Cd0AdM704A4A00a<C40:BTY01HF5P0@41004Q8B00X:2P0A4A40D51@03Xj>P0b<S80<30`
05]KF`1XJ6P0V9RH01d0MWIf8P3oool00200oooo3@2QXJ405P0O7al08b<S03Ti>@0j>SX0?3`l03Xj
>P0k>c/0@d=305MGE`1RHV80JVYZ08>3P`2:RXX0SXj>09>CT`29RHT0SXj>092@T02FUYH0RXZ:09JF
UP2>SXh209FEU@0808n?S`2EUID0RXZ:09JFUP2:RXX0TI6A08n?S`2ATI42092@T00308F5Q@2@T900
R8R80080RXZ:00H0QhN708J6QP27QhL0NWYj07AdM01gMgL307=cL`0D06QXJ01IFET0E5AD05IFEP16
ATH0>c/k02DU9@0H61P07alO014A4@0L71`0P82005EEE@0g=cL0EeMG07alO02EUID0XJ6Q09jNWP2U
YJDK0:6QXAh0oooo3@2QXJ405P0l?3`0>3Ph03/k>`0l?3`0?clo03dm?@0l?3`0?clo05=CD`1OGel0
IfMW08B4Q02=SHd0SXj>09>CT`2;Rh/0SXj>092@T02HV9P0SHf=09RHV02FUYH209BDU00808^;R`2D
U9@0Shn?09FEU@2=SHd0TI6A08n?S`2ATI42092@T00@08N7Q`2EUID0Rh^;08N7Q`28R8P0Q8B408J6
QP27QhL0MWIf07AdM01gMgL0MWIf079bLP1`L700Hf=S05aLG080DU9B0100BTY:03hn?P0U9BD061PH
01lO7`0B4Q807AdM08B4Q01OGel0>c/k05YJFP20P800UiNG0;Jf]P2KVi/0Xj>S6`2QXJ4N0?ooo`d0
MWIf00@0HF5Q0451@@0^;Rh0;Rh^0P0_;bl02@0/;2`0:BTY03Lg=`0o?cl0ATI605aLG01UIFD0IVIV
06UYJ@0306QXJ004071`L01ZJVX0L71`07AdM080KFe]00L0I6AT06e]K@1]KFd0K6a/06YZJP1YJFT0
J6QX00<0JFUY00<0IfMW071`L01YJFT00P1RHV800`1NGUh0HV9R06=SH`0205MGE`0H05QHF01JFUX0
De=C055AD@16ATH0B4Q803`l?00j>SX0?3`l038b<P0K6a/04a<C01LG5`0?3`l05ADE055AD@1>CTh0
<S8b0492@P1GEeL0IfMW092@T01`L700M7Ad6`1fMWHR0?ooo`00803oool00`2QXJ40WYjN0:6QX@0:
0:6QX@0E06a/K00C4a<0<30`03Ti>@0n?Sh0?clo03hn?P0j>SX0EeMG06EUI@1ZJVX0Ogmo096AT@28
R8P0SXj>092@T02DU9@0Shn?09FEU@2?Shl0UIFE0080VYZJ0100Shn?092@T02EUID0Shn?09BDU02?
Shl0TI6A08n?S`2@T900TI6A092@T028R8P0TI6A08Z:RP2<S8`0QHF50P27QhL04021PH40OWin07Ee
M@1cLg<0N7Qh06i^KP1_Kfl0JFUY069RHP1>CTh0D51@04M7A`0k>c/09BDU01`L700K6a/201lO7`08
07IfMP1ZJVX0?3`l06EUI@1jNWX0VYZJ0:6QX@2MWIdL0:6QXAh0oooo00<0XJ6Q09^KV`2QXJ402P2Q
XJ405@29RHT08b<S030`<00e=CD0>c/k03hn?P0o?cl0>SXj05IFEP1XJ6P0LG5a08>3P`2DU9@0S8b<
08Z:RP2<S8`0TI6A092@T02CTi<0S8b<09>CT`0209JFUP0808^;R`2=SHd0Ti>C08^;R`2ATI40Rh^;
096AT@2@T902096AT@06092@T028R8P0SXj>08J6QP2<S8`0Q8B40P27QhL02@1nOWh0OGem07YjNP1e
MGD0N7Qh06m_K`1/K6`0JVYZ05iNGP0204i>CP0@0451@@0f=SH09BDU01`L700K6a/08B4Q02<S8`1a
LG40IFEU03lo?`1aLG40R8R80:VYZ@2QXJ40X:2P0:BTY1/0XJ6Q7P3oool00`1fMWH0L71`07IfMP0:
07IfMP0E08N7Q`0h>3P09BDU02@T900X:2P0;2`/030`<00[:b/0>CTi04Y:BP1DE5@0GemO06YZJP1X
J6P0HF5Q069RHP1XJ6P0Jf][06QXJ01VIVH0J6QX0080JVYZ00H0I6AT06EUI@1XJ6P0I6AT06IVIP1T
I6@306YZJP80JFUY0P1UIFD00`1PH600IfMW065QH@0206=SH`0K05]KF`1LG5`0GemO05UIF@1HF5P0
De=C04i>CP1@D500@d=303dm?@0h>3P0;2`/02HV9P0L71`05QHF01@D500J6QX071`L03hn?P12@T80
=cLg05IFEP1XJ6P0O7al07IfMP1hN7P0NGUi01/0MWIf8P3oool00200oooo00<0XJ6Q09fMW@2QXJ40
2P2QXJ40402MWId061PH03Hf=P0a<C40@D5103Xj>P12@T80?Shn05=CD`1LG5`0NWYj08B4Q027QhL0
SXj>08f=S@2;Rh/2092@T00508n?S`2@T900UYJF09FEU@2GUiL00P2?Shl00`2@T900Shn?092@T002
08n?S`03096AT@2@T900T92@00<0SHf=01d0R8R808f=S@27QhL0QhN708R8R01lO7`0PH6107YjNP1f
MWH0N7Qh071`L01_Kfl0I6AT05iNGP1?Cdl0Bd];03lo?`0d=3@0:BTY01hN7P0J6QX08b<S01DE5@1c
Lg<0G5aL04Y:BP1aLG40RHV90;:b/P0N0:6QXAh0oooo00<0XJ6Q0:2PX02QXJ402P2QXJ401P2PX:00
7QhN04=3@`0h>3P0ADE503Xj>P80@D5100@0EEEE05MGE`1dM7@0SHf=0P2:RXX0102ATI40Shn?09>C
T`2@T90208n?S`80V9RH00<0Ti>C08b<S02?Shl00P2?Shl2092@T00408n?S`2ATI40T92@096AT@80
RXZ:01h0SHf=08R8R02;Rh/0QHF508N7Q`28R8P0O7al0861P@1fMWH0M7Ad07QhN01`L700Lg=c06AT
I01LG5`0C4a<04Q8B00l?3`0<C4a02XZ:P0O7al06QXJ02<S8`0D51@0L71`05IFEP15ADD0LW9b08j>
SP35aLDN0:6QXAh0oooo00<0MWIf07QhN01fMWH02P1fMWH07@1hN7P0<c<c03lo?`0a<C40=3@d02/[
:`0^;Rh0<C4a03dm?@0h>3P0BTY:06][J`1TI6@0HF5Q06][J`1/K6`0KFe]06UYJ@1XJ6P0IfMW071`
L01aLG40IfMW06IVIP1YJFT0IfMW06QXJ01YJFT0Jf][00<0JFUY00@0JVYZ06=SH`1SHf<0IfMW0P1T
I6@01@1PH600HV9R06=SH`1MGEd0GUiN0080E5AD01@0F5QH05ADE01HF5P0Bd];0492@P0h>3P0=3@d
02`/;00S8b<07alO01PH600D51@06ATI00h>3P11@D40=cLg034a<@1>CTh0Hf=S096ATAh0MWIf8P3o
ool00200oooo00<0XJ6Q09jNWP2QXJ401P2QXJ400`2NWYh0YJFU0:6QX@020:6QX@0H0:j^[P1[Jf/0
=3@d01dM7@11@D40ATI60451@@1;Bd/0HV9R079bLP2:RXX0UiNG08R8R027QhL0Ti>C092@T02?Shl0
S8b<09>CT`2?Shl0TI6A08n?S`2EUID0T92@0P2?Shl2092@T00>08b<S02@T900R8R808f=S@2@T900
SHf=08B4Q02=SHd0QhN708J6QP27QhL0NWYj07emO@21PH4207QhN00D06YZJP1gMgL0IVIV069RHP1<
C4`0ADE503hn?P11@D40;2`/02TY:@0N7Qh0820P00l?3`0<30`0G5aL04A4A01SHf<0LG5a09jNWP30
`<0N0:6QXAh0oooo00<0XJ6Q09^KV`2QXJ401P2QXJ400`2KVi/0Xj>S0:6QX@020:6QX@0J0:j^[P2@
T900Rh^;03Xj>P0m?Cd0A4A404I6AP1;Bd/0G5aL075aL@26QXH0Ti>C08R8R027QhL0Ti>C09BDU02C
Ti<0RXZ:092@T02?Shl0TI6A092@T02CTi<0SHf=092@T02?Shl2092@T00;08n?S`2CTi<0R8R808f=
S@2CTi<0SHf=0820P028R8P0Ph>308J6QP28R8P00`1mOGd05`1kNg/0N7Qh06ATI01eMGD0H61P05iN
GP1;Bd/0?Shn03Hf=P0o?cl0;Bd]02LW9`0M7Ad0820P00l?3`0<30`0KFe]03hn?P1QHF40L71`0:ZZ
ZP3Bd]80Y:BT01d0XJ6Q7P3oool00`1fMWH0L71`07IfMP0607IfMP03071`L01dM7@0MWIf0080MWIf
00/0O7al09FEU@2k^k/0CDe=02/[:`0b<S80=cLg03De=@0k>c/0CTi>05QHF00306=SH`0606UYJ@1^
KVh0KFe]06EUI@1WIfL0JFUY0P1ZJVX00`1XJ6P0IFEU06YZJP0306UYJ@0906][J`1]KFd0IFEU06MW
I`1]KFd0IfMW05eMG@1NGUh0GemO0080Hf=S01X0H61P05]KF`1HF5P0GUiN05MGE`18B4P0De=C04=3
@`15ADD0>CTi02TY:@0R8R80;Bd]02@T900L71`05ADE01LG5`0<30`02@T905IFEP0[:b/0@T9204a<
C01jNWX0UYJF07UiNAd0MWIf8P3oool00200oooo00<0XJ6Q09fMW@2QXJ401P2QXJ400`2MWId0XJ6Q
0:6QX@020:6QX@80Z:RX01D0VYZJ01hN7P17AdL0>c/k04e=C@17AdL0GemO06m_K`23Ph<0T92@08J6
QP2@T900SHf=08n?S`2ATI40Shn?092@T02DU9@0T92@08f=S@2EUID00P2@T9002@2<S8`0Rh^;09>C
T`2@T900TY:B08f=S@2:RXX0SXj>08f=S@0308N7Q`0508J6QP27QhL0Ng]k07alO01nOWh00P1hN7P0
5P1ZJVX0Kfm_06][J`1HF5P0Bd];0492@P0m?Cd0@41003Ti>@0X:2P07alO01DE5@0>3Ph0GEeM04i>
CP14A4@0L71`07emO@2[Zj/0[Jf]0::RXP2UYJDL0:6QXAh0oooo00<0XJ6Q0:2PX02QXJ401P2QXJ40
0`2PX:00Y:BT0:6QX@020:6QX@0G0:BTY02OWil0XZ:R03De=@13@d<0>CTi04U9B@17AdL0H61P06i^
KP25QHD0SHf=07emO@2;Rh/0RHV908Z:RP29RHT0Rh^;08j>SP2BTY80TI6A08Z:RP2BTY800P2@T900
2`29RHT0QhN708b<S02:RXX0S8b<08Z:RP29RHT0QXJ608>3P`24Q8@0QhN70080QXJ600@0QhN707Ui
N@1jNWX0OWin0P1eMGD05P1]KFd0Kfm_071`L01KFe/0@d=30451@@10@400@T9203hn?P0V9RH07alO
01@D500=3@d0Q8B404U9B@11@D40MGEe09:BTP3:b/X0^KVi09fMW@2SXj<L0:6QXAh0oooo00<0MWIf
07QhN01fMWH01P1fMWH00`1hN7P0NGUi07IfMP0207IfMP0G07=cL`1]KFd0Ogmo059BDP0^;Rh0:2PX
034a<@0d=3@0@d=304Y:BP1NGUh0H61P05EEE@1OGel0H61P065QH@1MGEd0HV9R06EUI@1YJFT0JVYZ
06=SH`1WIfL00P1YJFT01@1TI6@0HF5Q065QH@1PH600HF5Q0080Hf=S00@0Fe]K05QHF01NGUh0Hf=S
0`1RHV8205UIF@0I05aLG01DE5@0EEEE05EEE@1ADE40EeMG04Q8B00^;Rh0<C4a038b<P0a<C40<c<c
01/K6`0G5aL03Ph>00T92@1dM7@0<c<c02l_;`1BDU80MGEe09^KV`29RHT0Kfm_07AdM00L07IfMR80
oooo000P0?oooa00XJ6Q01<0[Zj^04I6AP1>CTh0DE5A03Lg=`1KFe/0EUIF06][J`26QXH0Rh^;08B4
Q029RHT0QhN7092@T02:RXX0T92@08R8R02@T900UYJF00@0T92@00<0S8b<08^;R`2@T9000P27QhL0
0`2CTi<0T92@08:2PP0208N7Q`0308R8R027QhL0QhN70080PH6101X0NGUi07inOP1gMgL0MWIf06EU
I@1fMWH0K6a/05QHF01:BTX0AdM703/k>`0f=SH0@41001<C4`0F5QH06ATI03Ti>@1=CDd0AdM7051@
D01cLg<0UiNG0;bl_02UYJD0YZJV09ZJVQ`0XJ6Q7P3oool@0:6QX@0E0:j^[P1JFUX0AdM705aLG00n
?Sh0GemO05eMG@1/K6`0Q8B408Z:RP28R8P0SXj>08J6QP2>SXh0SHf=09FEU@2;Rh/0S8b<09:BTP2@
T900Ti>C0080T92@0140Shn?08V9R@2DU9@0Rh^;08B4Q02?Shl0SXj>08>3P`27QhL0QXJ608R8R027
QhL0QXJ607emO@1oOgl0NWYj07emO@0207AdM00405aLG01_Kfl0IfMW055AD@80Bd];00l0?Cdm03<c
<`0j>SX05QHF01@D500H61P0Bd];059BDP17AdL0EUIF07emO@2PX:00a/K60:ZZZP2^[Zh07@2QXJ4N
0?oooa00MWIf01D0O7al06MWI`0[:b/0BTY:03@d=015ADD0AdM704];B`1JFUX0HF5Q06IVIP1YJFT0
HV9R06EUI@1ZJVX0Kfm_06UYJ@1SHf<0IfMW06UYJ@1]KFd00P1YJFT01`1[Jf/0I6AT06i^KP1YJFT0
GemO06ATI01UIFD00P1SHf<0201RHV80Hf=S06=SH`1RHV80FUYJ05eMG@1LG5`0Fe]K0P1CDe<01010
@400BTY:04M7A`0j>SX203/k>`0@02l_;`0S8b<09RHV01DE5@0<30`04A4A0492@P0h>3P0=cLg04=3
@`1KFe/0L71`08Z:RP1mOGd0Ph>307alO1`0MWIf8P3oool00200oooo402QXJ40202^[Zh0Fe]K03De
=@1:BTX0ATI606=SH`1EEED0Jf][0P22PX80202?Shl0SXj>08J6QP2?Shl0Rh^;09^KV`26QXH0SXj>
1@2ATI401`2EUID0SHf=08n?S`2=SHd0QhN708F5Q@2=SHd01027QhL05P28R8P0QhN707QhN023Ph<0
OWin07QhN01gMgL0L71`05aLG01]KFd0GemO05ADE018B4P0A4A40451@@0h>3P0?3`l02l_;`0O7al0
;bl_03Hf=P1NGUh205YJFP0507alO02;Rh/0bl_;0:JVYP2XZ:P07@2QXJ4N0?oooa00XJ6Q01@0[Zj^
055AD@10@400@D5103lo?`1VIVH0EUIF06a/K024Q8@0OGem08N7Q`2;Rh/0QXJ608f=S@25QHD0UiNG
08F5Q@2=SHd0Shn?08j>SP<0Rh^;01P0TY:B08R8R026QXH0Ph>308B4Q01lO7`0R8R808>3P`27QhL0
QXJ608N7Q`28R8P0QhN707EeM@1mOGd0Ng]k07EeM@1gMgL0Kfm_05]KF`1YJFT0EUIF04Y:BP12@T82
03dm?@0?03Xj>P0o?cl0;Bd]02TY:@0m?Cd0>c/k06ATI01PH600JVYZ08j>SP2CTi<0bl_;0:j^[P2V
YZH0WIfM01`0XJ6Q7P3oool@07IfMP0A07alO013@d<0=cLg02DU9@0Z:RX0AdM703lo?`1;Bd/0GEeM
05EEE@1IFET0HF5Q069RHP1TI6@0GEeM06QXJ01RHV800P1VIVH0301UIFD0HF5Q065QH@1QHF40IfMW
061PH01KFe/0F5QH05iNGP1DE5@0GemO05eMG@<0HV9R0P1SHf<0701GEeL0EUIF05QHF01EEED0EeMG
055AD@16ATH0B4Q803Ti>@0b<S80;Bd]02LW9`0Z:RX0;Rh^030`<00S8b<0:2PX03Lg=`0/;2`0BDU9
04Y:BP1HF5P0Kfm_06][J`24Q8@0Ph>307IfMP1`L70L07IfMR80oooo000P0?oooa00XJ6Q00/0[Zj^
04M7A`0O7al0@T9204A4A01?Cdl0GEeM06][J`1lO7`0RHV908F5Q@0208b<S00309FEU@27QhL0Ti>C
0080RXZ:01D0SHf=092@T02=SHd0T92@08B4Q02EUID0RXZ:08N7Q`20P800QXJ60820P02?Shl0QhN7
08>3P`24Q8@0RXZ:08B4Q027QhL0MgMg0820P01lO7`00P1cLg<06@1ZJVX0IfMW065QH@1KFe/0CDe=
04A4A00e=CD0?Shn03Lg=`0i>CT0=SHf02@T901VIVH0<c<c05QHF01nOWh0G5aL096AT@2NWYh0XJ6Q
0:RXZ02UYJD0XJ6Q0:JVYP2JVYX03@2QXJ400`2VYZH0VYZJ0:6QX@0:0:6QXAh0oooo402QXJ40402^
[Zh0@D5102<S8`0n?Sh0@D5104I6AP1CDe<0IVIV075aL@22PX80Q8B408F5Q@28R8P0Shn?08V9R@2A
TI4208N7Q`0@08F5Q@2>SXh0SHf=09>CT`23Ph<0SHf=08N7Q`25QHD0NWYj07]kN`1hN7P0RXZ:08N7
Q`20P800O7al08>3P`80Ng]k01h0KVi^07YjNP1gMgL0KFe]06YZJP1NGUh0H61P05mOG`1HF5P0CDe=
04Q8B00d=3@0>SXj03<c<`0e=CD0=SHf028R8P1fMWH0Bd];061PH026QXH0JFUY09fMW@35aLD0_[jn
0:BTY02SXj<0XJ6Q0:^[Z`2NWYh=0:6QX@030:^[Z`2NWYh0XJ6Q00X0XJ6Q7P3oool@07IfMP0G07al
O00n?Sh092@T02XZ:P0];Bd0:RXZ038b<P12@T80ATI605IFEP1MGEd0FUYJ05mOG`1QHF40IVIV06EU
I@1QHF40H61P05aLG01UIFD0IfMW06e]K@1QHF400`1PH600:01FEUH0DE5A05ADE01NGUh0Hf=S05aL
G01EEED0F5QH05ADE01ADE40C4a<05ADE01CDe<0C4a<04Q8B00n?Sh0@d=304A4A010@400>c/k03Xj
>P0X:2P09bLW02<S8`0T92@09RHV01TI6@1JFUX0CTi>04M7A`1PH600EeMG075aL@2TY:@0VYZJ07=c
L`1dM7@0MWIf07moO`1iNGT=07IfMP0307moO`1iNGT0MWIf00X0MWIf8P3oool00200oooo4@2QXJ40
102>SXh08B4Q02d];@18B4P204U9B@0<05iNGP1oOgl0Q8B408N7Q`1fMWH0PX:208N7Q`2BTY80QXJ6
08N7Q`2;Rh/0QXJ60`28R8P308>3P`0S07inOP1dM7@0NWYj07IfMP1nOWh0N7Qh07]kN`1gMgL0N7Qh
07AdM01jNWX0LG5a07IfMP1aLG40JFUY075aL@1QHF40Fe]K05UIF@1?Cdl0C4a<04A4A00i>CT0C4a<
0451@@0e=CD0@T9204];B`1LG5`0C4a<06YZJP2>SXh0RXZ:09ZJVP2SXj<00P2QXJ400`2XZ:P0XJ6Q
0:6QX@090:6QX@0309fMW@2QXJ40XJ6Q00l0XJ6Q7P3ooolA0:6QX@0B09ZJVP0/;2`0@D5104U9B@1:
BTX0Bd];05EEE@1cLg<0NWYj08V9R@1hN7P0O7al0820P02<S8`0QhN708R8R029RHT0PX:20`20P800
2P1jNWX0M7Ad07=cL`1dM7@0K6a/075aL@1ZJVX0Jf][06QXJ01^KVh206][J`0N06UYJ@1WIfL0HV9R
06QXJ01SHf<0Fe]K06QXJ01KFe/0F5QH05MGE`17AdL0@41004M7A`0k>c/0D51@04e=C@0e=CD0CTi>
05EEE@1GEeL0ATI606i^KP2?Shl0SXj>0;>c/`2o_kl0Y:BT0:6QX@2TY:@0WIfM2P2QXJ400`2PX:00
Y:BT0:6QX@0?0:6QXAh0oooo4@1fMWH03P1oOgl0>c/k0451@@0b<S80>3Ph03Lg=`0e=CD0@d=304a<
C01SHf<0FUYJ05EEE@1GEeL0GemO0P1TI6@00`1QHF40GEeM05MGE`0205MGE`04059BDP19BDT0B4Q8
04i>CP80Bd];01L0ADE503lo?`10@400ATI604E5A@13@d<0ADE503Xj>P0m?Cd0@41003hn?P0h>3P0
@T9203lo?`10@400?Shn02l_;`0W9bL0>CTi02h^;P0l?3`0@d=302HV9P0204A4A00;03Ti>@0`<300
D51@061PH01VIVH0TI6A09VIV@1iNGT0MWIf07=cL`1`L7002P1fMWH00`1hN7P0NGUi07IfMP0?07If
MR80oooo000P0?oooa80XJ6Q00h0:b/[02d];@0i>CT0CDe=04a<C01IFET0GUiN07QhN022PX80Rh^;
07inOP23Ph<0QXJ608>3P`80R8R802T0QHF508:2PP1kNg/0R8R808N7Q`1/K6`0MgMg07UiN@1VIVH0
MgMg06=SH`1WIfL0NWYj05eMG@1iNGT0GEeM079bLP1UIFD0Kfm_06=SH`1VIVH0HF5Q05eMG@1ZJVX0
I6AT051@D01DE5@0ADE50410@012@T80De=C05ADE00`<300CDe=06EUI@1GEeL0CDe=06UYJ@1oOgl0
QHF50<W9b@050:6QX@0309jNWP2UYJD0XJ6Q00`0XJ6Q00<0YZJV09ZJVP2QXJ402P2QXJ4N0?oooa80
XJ6Q00/0Fe]K0410@00o?cl0Bd];04a<C01NGUh0FUYJ06MWI`1ZJVX0NWYj07inOP0208^;R`0U07in
OP20P800P82007inOP1fMWH0KFe]07QhN023Ph<0JVYZ075aL@1bLW80GEeM06a/K01IFET0GEeM07=c
L`1CDe<0Jf][051@D01QHF40EeMG06=SH`1IFET0Fe]K05UIF@1DE5@0HV9R06QXJ01EEED0GEeM05AD
E011@D40@d=305QHF01JFUX0=cLg0410@00206=SH`0605UIF@1_Kfl0T92@08F5Q@3;bl/0YJFU102Q
XJ400`2KVi/0Xj>S0:6QX@0<0:6QX@030:^[Z`2NWYh0XJ6Q00X0XJ6Q7P3ooolB07IfMP0>07QhN017
AdL0=3@d03<c<`0g=cL0ATI603dm?@0i>CT0=SHf04U9B@1KFe/0K6a/06QXJ01IFET305MGE`0504e=
C@15ADD0BTY:05]KF`1@D5000P1>CTh08P0o?cl0ADE503/k>`0m?Cd0C4a<03Lg=`10@400<c<c03Lg
=`0d=3@0?Cdm03Xj>P0i>CT0?3`l03Hf=P10@400D51@04E5A@1=CDd0C4a<038b<P0c<c<0@D5104M7
A`0c<c<08B4Q04=3@`1ADE40C4a<059BDP1aLG40GemO08F5Q@1jNWX407IfMP03071`L01dM7@0MWIf
00`0MWIf00<0Ogmo07UiN@1fMWH02P1fMWHR0?ooo`00803ooolB0:6QX@0h06EUI@0b<S806QXJ03lo
?`0m?Cd0H61P04M7A`1gMgL0LG5a08b<S022PX80QhN70861P@22PX80Ng]k0820P01jNWX0MWIf07=c
L`1hN7P0PH6107=cL`1WIfL0LW9b065QH@1ZJVX0GEeM05iNGP1PH600I6AT06IVIP1>CTh0F5QH04e=
C@1[Jf/0D51@05eMG@1NGUh0EeMG04e=C@1PH600FEUI05iNGP1ADE40BDU904];B`0m?Cd0Cdm?04Y:
BP16ATH0G5aL05]KF`1ZJVX0MWIf06a/K02j^[X30:6QX@0409jNWP2QXJ40XJ6Q09fMW@/0XJ6Q00@0
WYjN0:FUY@2QXJ40Z:RX302QXJ4N0?oooa80XJ6Q01<0Rh^;08n?S`1=CDd0D51@03`l?01HF5P0?Shn
06m_K`1dM7@0U9BD08n?S`2:RXX0OWin07moO`1gMgL0MWIf06a/K01aLG40L71`0080MGEe00/0JVYZ
061PH01UIFD0F5QH069RHP1FEUH0F5QH059BDP1GEeL0HF5Q04E5A@0204a<C00906ATI019BDT0De=C
05IFEP1CDe<0@d=304];B`19BDT0EEEE0080BTY:00`0DU9B03Xj>P11@D40ADE505aLG01SHf<0EUIF
06i^KP2@T900IfMW0<_;b`2n_[h20:6QX@0509^KV`2QXJ40XJ6Q0:2PX02TY:@02P2QXJ401@2KVi/0
Xj>S0:6QX@2TY:@0WIfM00/0XJ6Q7P3ooolB07IfMP0<09:BTP33`l<0KVi^04U9B@0/;2`0=SHf02PX
:014A4@0EEEE06][J`1`L700IVIV0P1KFe/0:`1EEED0Cdm?04E5A@1?Cdl0DE5A059BDP1:BTX0BDU9
04=3@`0o?cl0?3`l0410@00l?3`0?Shn030`<00g=cL0@D5102l_;`0];Bd0>3Ph0410@00b<S80=3@d
03Ph>00k>c/0:BTY02<S8`0Y:BT0=CDe038b<P0i>CT0@d=302TY:@0S8b<0<30`059BDP1:BTX0>c/k
055AD@1hN7P0B4Q809:BTP2JVYX00P1fMWH01@1`L700MWIf07IfMP1hN7P0NGUi00X0MWIf00D0L71`
07AdM01fMWH0Lg=c071`L00;07IfMR80oooo000P0?ooo`H0XJ6Q00<0WYjN0:FUY@2UYJD02P2QXJ40
4`2EUID0:b/[04a<C015ADD0CTi>05]KF`1TI6@0IFEU08f=S@1oOgl0SHf=08:2PP1lO7`0Ng]k07Ad
M01bLW80IfMW07QhN01iNGT00P1]KFd2069RHP0P05eMG@1QHF40D51@051@D01TI6@0EUIF05MGE`1M
GEd0AdM706YZJP1?Cdl0FUYJ04m?C`1FEUH0Fe]K03Lg=`1@D500FEUI05=CD`17AdL0EeMG04A4A016
ATH0@D5104i>CP1FEUH0HF5Q06m_K`1[Jf/0MgMg07moO`2o_kl30:6QX@030::RXP2QXJ40XJ6Q00`0
XJ6Q00<0WIfM0:6QX@2QXJ403@2QXJ4N0?ooo`H0XJ6Q00<0Vi^K0:>SX`2SXj<02P2QXJ403P2MWId0
;Rh^04m?C`1CDe<0F5QH07UiN@28R8P0KVi^08V9R@1_Kfl0Ogmo07]kN`1eMGD0Lg=c0P1_Kfl01@1N
GUh0K6a/07EeM@1XJ6P0Hf=S0080GUiN00`0F5QH05eMG@19BDT0Cdm?06][J`1OGel0De=C069RHP1C
De<0KFe]05IFEP1LG5`205MGE`08065QH@0i>CT0Cdm?05]KF`1GEeL0ADE505UIF@13@d<204U9B@08
059BDP1DE5@0IFEU08N7Q`2;Rh/0Ogmo09:BTP3Jf]X30:6QX@030:VYZ@2QXJ40XJ6Q00`0XJ6Q00<0
X:2P0:BTY02QXJ403@2QXJ4N0?ooo`H0MWIf00<0L71`07AdM01dM7@02P1fMWH0301kNg/0>CTi0410
@01;Bd/0AdM7071`L01kNg/0EeMG05YJFP14A4@0D51@05EEE@80D51@02T0CTi>04m?C`11@D40ADE5
055AD@1:BTX0@D5104E5A@13@d<0?Shn0451@@0b<S80?3`l059BDP1=CDd0>c/k04e=C@19BDT0D51@
04E5A@17AdL0ATI60410@01;Bd/0<C4a03Ph>013@d<0@T9203<c<`13@d<0<S8b03Ti>@0l?3`0?Cdm
03Xj>P1:BTX0LW9b07alO01PH600NGUi0:2PX00307IfMP030861P@1fMWH0MWIf00`0MWIf00<0N7Qh
07UiN@1fMWH03@1fMWHR0?ooo`00803oool20:6QX@050:FUY@2QXJ40XJ6Q0:6QX@2MWId03@2QXJ40
2@1;Bd/06a/K065QH@1;Bd/0MWIf07EeM@1YJFT0P8200861P@0207alO00Z07MgM`1lO7`0JFUY079b
LP1MGEd0L71`06][J`1`L700HV9R05iNGP1YJFT0Cdm?05IFEP1GEeL0IVIV05iNGP1WIfL0BDU906=S
H`1EEED0MGEe03`l?01PH600EEEE069RHP1ADE40B4Q80451@@1:BTX0@41004A4A015ADD0@T9204M7
A`14A4@0D51@06ATI01/K6`0QXJ6061PH021PH40g]kN102QXJ400`2XZ:P0XJ6Q0:6QX@0L0:6QXAh0
oooo0P2QXJ401@2SXj<0XJ6Q0:6QX@2QXJ40X:2P0080Y:BT2`2QXJ406@29RHT0=CDe05mOG`1=CDd0
Hf=S061PH01KFe/0Lg=c07alO01iNGT0LW9b06e]K@1gMgL0I6AT06YZJP1FEUH0JVYZ05mOG`1SHf<0
G5aL05IFEP1XJ6P0CTi>04e=C@1DE5@00P1IFET02`1QHF40B4Q805]KF`1@D500Ng]k03Lg=`1DE5@0
C4a<06=SH`18B4P0@d=30080?clo00h0<C4a03Hf=P0j>SX0=cLg03lo?`0l?3`0Bd];07MgM`2:RXX0
Xj>S065QH@1hN7P0g=cL0;Bd]0<0XJ6Q00<0Y:BT0:6QX@2QXJ40702QXJ4N0?ooo`80MWIf00D0M7Ad
07IfMP1fMWH0MWIf07QhN00207UiN@/0MWIf00d0ZJVY04Y:BP13@d<0?3`l03<c<`0e=CD0>CTi04E5
A@1EEED0EUIF04a<C01:BTX0DU9B0080AdM702L0?Shn04M7A`0l?3`0?clo0410@00l?3`0BTY:03`l
?00b<S80?3`l03Hf=P0j>SX0@D5103Lg=`0j>SX0>3Ph05MGE`0Y:BT0<C4a038b<P17AdL0;Rh^030`
<00^;Rh092@T01PH600L71`08R8R020P800W9bL09RHV034a<@1SHf<0N7Qh08F5Q@1;Bd/0Cdm?08N7
Q`2>SXh00`1fMWH00`1cLg<0MWIf07IfMP0L07IfMR80oooo000P0?oooa@0XJ6Q00P0Z:RX03Hf=P0V
9RH0BDU906m_K`1SHf<0IfMW07EeM@80NGUi02`0IfMW07=cL`1eMGD0K6a/06MWI`1NGUh0IfMW05YJ
FP1UIFD0JVYZ05IFEP1SHf<0AdM7065QH@1HF5P0?clo06e]K@17AdL0JFUY055AD@1GEeL0C4a<04m?
C`1IFET0<30`04Y:BP14A4@0ATI604=3@`16ATH0?Cdm04A4A011@D40>3Ph04Y:BP17AdL0L71`07Mg
M`1nOWh0Bd];08^;R`1SHf<0alO709ZJVPD0XJ6Q00<0WYjN0:FUY@2QXJ406P2QXJ4N0?ooo`80XJ6Q
00<0Y:BT0:6QX@2QXJ403`2QXJ409@2TY:@0OGem05UIF@1@D500Ogmo07=cL`1fMWH0RXZ:08F5Q@1j
NWX0Hf=S06UYJ@1[Jf/0IVIV06ATI01PH600JFUY05QHF01NGUh0J6QX04i>CP1HF5P0>c/k05mOG`1N
GUh0=3@d05eMG@0l?3`0GemO05MGE`1FEUH0?clo04=3@`1NGUh0:RXZ03Hf=P0l?3`00P0o?cl03`1;
Bd/0AdM705=CD`16ATH0>c/k04e=C@1@D500UIFE08b<S02?Shl0=SHf06QXJ01FEUH0lo?c09jNWP05
0:6QX@0309^KV`2SXj<0XJ6Q01X0XJ6Q7P3oool207IfMP0307UiN@1fMWH0MWIf00l0MWIf03H0Lg=c
0:f][@1eMGD0A4A406=SH`1PH600HV9R079bLP1XJ6P0Fe]K04U9B@15ADD0ATI604Q8B017AdL0Bd];
04m?C`11@D40?clo04Y:BP0e=CD0=SHf02HV9P12@T80BDU901dM7@0c<c<092@T03`l?014A4@0?clo
02@T900Z:RX0ATI601`L700E5AD09bLW02PX:00/;2`0>CTi03dm?@17AdL0>3Ph02l_;`0j>SX0@T92
08:2PP1`L700LG5a01`L700];Bd0=CDe0;^k^`1iNGT507IfMP03071`L01dM7@0MWIf01X0MWIf8P3o
ool00200oooo5P2QXJ40:@1UIFD05aLG06QXJ011@D40GEeM07QhN028R8P0MGEe06i^KP1?Cdl0JVYZ
05eMG@1aLG40FUYJ051@D01WIfL0H61P059BDP1DE5@0DE5A04I6AP1NGUh0BDU905IFEP0f=SH0De=C
04Q8B010@400Bd];03/k>`0n?Sh0>3Ph03dm?@0f=SH0@d=30410@011@D40?clo03dm?@15ADD0DU9B
0080Fe]K00/0P82007AdM01`L700GemO06a/K01RHV80RHV90::RXP2UYJD0XJ6Q09jNWP040:6QX@06
0:JVYP2JVYX0XJ6Q0:6QX@2VYZH0VYZJ1@2QXJ400`2MWId0XJ6Q0:6QX@0>0:6QXAh0oooo5P2QXJ40
?02CTi<07alO07moO`1ADE40HV9R079bLP1nOWh0L71`06UYJ@18B4P0GUiN05IFEP1]KFd0F5QH04Y:
BP1SHf<0GUiN051@D01BDU80FEUI0451@@1<C4`0BTY:04i>CP0k>c/0CDe=0492@P0o?cl0AdM703Ti
>@0l?3`0>c/k0451@@0d=3@0>c/k0410@00n?Sh0>SXj03/k>`19BDT0GEeM05YJFP1DE5@0O7al0820
P01;Bd/0C4a<07alO01^KVh0]kNg09fMW@2SXj<0XJ6Q09^KV`2QXJ40Y:BT0:6QX@2TY:@0Zj^[09jN
WP80XJ6Q00<0Zj^[09jNWP2QXJ40102QXJ40102PX:00Y:BT0:6QX@2MWId=0:6QXAh0oooo5P1fMWH0
3`2NWYh0:RXZ06YZJP1=CDd0BDU904Q8B01>CTh0Cdm?04a<C00d=3@0>CTi03Xj>P1:BTX0@D5103@d
=0020492@P0903/k>`0m?Cd0BTY:02/[:`0X:2P0>SXj03De=@0b<S80<30`0080;Bd]0200;bl_02PX
:00Z:RX0;bl_034a<@0U9BD09RHV02h^;P0Z:RX09bLW02XZ:P0i>CT0Bd];03lo?`0h>3P0DE5A06IV
IP0I6AT0;Bd]06EUI@1IFET0Y:BT06m_K`1dM7@0MWIf071`L01fMWH0NGUi07IfMP1iNGT0Ogmo07Ui
N@80MWIf00<0Ogmo07UiN@1fMWH0101fMWH0101hN7P0NGUi07IfMP1`L70=07IfMR80oooo000P0?oo
oaH0XJ6Q03H0Z:RX01dM7@10@400PH61061PH01WIfL0KFe]07=cL`1ZJVX0@D5106QXJ01BDU80HV9R
05IFEP1=CDd0IFEU05eMG@1=CDd0Cdm?061PH00e=CD0HF5Q04U9B@0o?cl0>CTi069RHP0d=3@0@d=3
04A4A00j>SX0=SHf03Ti>@0`<300;Bd]03Lg=`0h>3P0@T9204e=C@0h>3P0BTY:06QXJ01DE5@0L71`
06ATI01[Jf/0ATI607UiN@1?Cdl0^[Zj0:JVYP2CTi<0YJFU0:6QX@2MWId40:6QX@050:RXZ02QXJ40
XJ6Q0:6QX@2XZ:P05`2QXJ4N0?oooaH0XJ6Q01h0Y:BT06a/K00a<C40K6a/071`L01cLg<0J6QX07Ui
N@1aLG40@T9206UYJ@1ADE40FEUI04i>CP18B4P0Hf=S05YJFP19BDT0B4Q805YJFP0c<c<0I6AT04Y:
BP0i>CT0;Rh^06ATI00d=3@0?Shn0492@P0j>SX203De=@0L02XZ:P0W9bL0=3@d038b<P0n?Sh0De=C
03lo?`1;Bd/0MgMg06UYJ@2IVIT0RHV906YZJP16ATH0OWin04M7A`35aLD0gmoO09ZJVP2UYJD0XJ6Q
0:2PX02TY:@0XJ6Q0:BTY02QXJ40Y:BT09fMW@80XJ6Q00<0Y:BT09fMW@2QXJ405@2QXJ4N0?oooaH0
MWIf01X0Lg=c0:f][@0H61P0>CTi05iNGP1KFe/0ATI605mOG`1KFe/0>CTi04];B`0m?Cd0>3Ph03De
=@0d=3@0@d=303lo?`0d=3@0<C4a03/k>`0Y:BT0ATI603Ph>00T92@06a/K04E5A@80:BTY0200;Rh^
02`/;00V9RH092@T01/K6`0H61P08b<S01lO7`0Y:BT0@41003De=@0g=cL0HF5Q05mOG`2<S8`0P820
04e=C@0f=SH0FUYJ02l_;`27QhL0_kno07UiN@1gMgL0MWIf07QhN01iNGT0MWIf07UiN@1fMWH0Lg=c
071`L080MWIf00<0Lg=c071`L01fMWH05@1fMWHR0?ooo`00803ooolF0:6QX@0c09jNWP2UYJD01PH6
03Ph>01eMGD0Kfm_06e]K@21PH40JVYZ0410@01CDe<0KVi^04a<C01KFe/0CDe=04Y:BP1VIVH0CTi>
05eMG@1GEeL0>SXj05]KF`1CDe<0?Cdm020P801<C4`0@D5105IFEP0c<c<0;Bd]0492@P0`<300:b/[
02HV9P0Y:BT0:RXZ0410@01?Cdl0FEUI05IFEP1cLg<0NWYj06a/K01ADE40KVi^04i>CP1HF5P0L71`
0=GEe@2XZ:P0WIfM0080XJ6Q00<0WYjN0:FUY@2VYZH02@2QXJ400`2NWYh0YJFU0:6QX@050:6QX@03
0:JVYP2JVYX0XJ6Q00X0XJ6Q7P3ooolF0:6QX@0Q09^KV`2SXj<0>SXj03@d=01EEED0G5aL06EUI@22
PX80K6a/0410@01:BTX0JVYZ05=CD`1VIVH0Fe]K04Y:BP1OGel0DE5A05UIF@1JFUX0?3`l05]KF`1E
EED0ADE5020P800n?Sh0>3Ph069RHP0i>CT0:2PX03lo?`0`<300:RXZ00<09BDU01@0>c/k04U9B@1Q
HF40MGEe079bLP22PX80IfMW03<c<`1=CDd0E5AD055AD@1dM7@0o_kn0:^[Z`2KVi/0Y:BT0:6QX@2K
Vi/0Xj>S0:^[Z`T0XJ6Q00<0Vi^K0:>SX`2QXJ401@2QXJ400`2[Zj/0WYjN0:6QX@0:0:6QXAh0oooo
5P1fMWH0>01`L700M7Ad06IVIP0Q8B407alO034a<@12@T80GemO05ADE00g=cL0;bl_04Q8B014A4@0
E5AD051@D00f=SH0?Cdm0410@00l?3`0@d=3038b<P0n?Sh0@41003/k>`0J6QX07QhN02@T901>CTh0
<C4a01/K6`0[:b/09BDU01lO7`0K6a/061PH01LG5`0T92@0;Bd]04];B`1/K6`0CTi>06ATI016ATH0
4A4A01`L7016ATH0<c<c05MGE`2h^;P0O7al079bLP1iNGT0MWIf071`L01dM7@0Ogmo2@1fMWH00`1`
L700M7Ad07IfMP0507IfMP0307moO`1iNGT0MWIf00X0MWIf8P3oool00200oooo102QXJ400`2NWYh0
YJFU0:6QX@0?0:6QX@0`09fMW@2QXJ40=CDe01@D5014A4@0EEEE07MgM`28R8P0Ng]k03lo?`13@d<0
J6QX069RHP1NGUh0H61P04A4A01@D500G5aL04m?C`1DE5@0De=C04];B`1:BTX0BDU9030`<00k>c/0
<c<c04A4A019BDT0=CDe04=3@`0e=CD0@d=302TY:@0g=cL0>c/k04A4A01:BTX0IFEU071`L01<C4`0
OGem055AD@0_;bl0Hf=S06EUI@1ADE40/[:b102QXJ40102VYZH0UYJF09jNWP2/[:`30:6QX@030:JV
YP2JVYX0XJ6Q00<0XJ6Q00<0WIfM0:6QX@2JVYX01@2QXJ400`2XZ:P0XJ6Q0:6QX@0:0:6QXAh0oooo
102QXJ400`2KVi/0Xj>S0:6QX@0?0:6QX@090:2PX02TY:@0EEEE02h^;P15ADD0AdM706UYJ@1hN7P0
NGUi0080A4A402H0HF5Q061PH01=CDd0De=C0410@018B4P0DU9B04e=C@1:BTX0EEEE059BDP14A4@0
CTi>0451@@1>CTh0=CDe03Ti>@10@400>SXj04Y:BP0i>CT0E5AD03/k>`17AdL0EUIF069RHP1QHF40
Lg=c07QhN01PH600M7Ad04=3@`0V9RH0Fe]K06UYJ@1SHf<0l?3`0<[:bP<0XJ6Q00@0Zj^[09fMW@2N
WYh0YJFU0`2QXJ400`2[Zj/0WYjN0:6QX@030:6QX@030:2PX02TY:@0WYjN00D0XJ6Q00<0Y:BT09fM
W@2QXJ402P2QXJ4N0?ooo`@0MWIf00<0L71`07AdM01fMWH03`1fMWH0501hN7P0NGUi075aL@14A4@0
<C4a02HV9P0k>c/0B4Q805MGE`10@400=cLg03`l?015ADD0:RXZ038b<P0`<300;Bd]038b<P0f=SH0
;Rh^0P11@D40400];Bd0?clo0492@P18B4P0:BTY01hN7P0Y:BT0<30`03Xj>P0`<300BTY:03/k>`11
@D40E5AD05eMG@1GEeL305YJFP0804U9B@0/;2`06QXJ03Lg=`1?Cdl0FUYJ0<S8b02XZ:P307IfMP04
07moO`1kNg/0M7Ad075aL@<0MWIf00<0Ogmo07UiN@1fMWH00`1fMWH00`1hN7P0NGUi07UiN@0507If
MP0307=cL`1`L700MWIf00X0MWIf8P3oool00200oooo102QXJ400`2MWId0XJ6Q0:6QX@0A0:6QX@0?
08:2PP0Q8B409bLW04A4A01?Cdl0Ogmo07UiN@1fMWH0:b/[05ADE01UIFD0ATI6051@D010@400@T92
0080BDU902T0Cdm?05MGE`17AdL0AdM705MGE`16ATH0BDU9038b<P1@D500=CDe051@D014A4@0?Shn
04];B`16ATH0CTi>05iNGP1>CTh0GEeM07IfMP1NGUh0Fe]K06QXJ00k>c/0C4a<05eMG@1OGel0^[Zj
09ZJVP2VYZH0WinO09jNWP2[Zj/0WYjN0:^[Z`2FUYH0WYjN0:JVYP2JVYX0XJ6Q0:RXZ00;0:6QX@03
0:JVYP2QXJ40XJ6Q00`0XJ6Q7P3oool40:6QX@030:2PX02TY:@0XJ6Q0140XJ6Q00/0UIFE05IFEP19
BDT0D51@04U9B@1QHF40GUiN07UiN@0e=CD0CDe=05YJFP0204a<C00^03Ti>@0l?3`0@41004A4A01>
CTh0E5AD0410@013@d<0Fe]K04a<C01?Cdl0>3Ph069RHP0l?3`0EeMG04m?C`15ADD0CDe=04Y:BP1X
J6P0OWin06EUI@1]KFd0TY:B06][J`1:BTX0GUiN02l_;`1>CTh0LW9b05QHF03WinL0d];B0:^[Z`2X
Z:P0Vi^K0:f][@2KVi/0Z:RX09fMW@2NWYh0Zj^[09jNWP2QXJ40Y:BT09fMW@H0XJ6Q00D0WIfM0:6Q
X@2QXJ40XJ6Q0:^[Z`0>0:6QXAh0oooo101fMWH00`1hN7P0NGUi07IfMP0A07IfMP0F08B4Q020P800
F5QH04E5A@0_;bl0:BTY02d];@1LG5`0=cLg034a<@0f=SH0?Shn03<c<`0W9bL0:2PX02LW9`0^;Rh0
=cLg03Ti>@0/;2`0;bl_04M7A`80@41002<0<C4a05ADE00c<c<0@d=30492@P0i>CT0>3Ph03/k>`1O
Gel0Lg=c05eMG@1LG5`0NWYj05]KF`0_;bl0?3`l01hN7P0l?3`0GUiN03Xj>P2h^;P0^KVi07moO`23
Ph<0L71`07emO@1`L700N7Qh07]kN`1dM7@0Ogmo07UiN@1fMWH0Lg=c071`L00607IfMP05071`L01f
MWH0MWIf07IfMP1oOgl03P1fMWHR0?ooo`00803ooolF0:6QX@80YJFU00D0WYjN0:FUY@1UIFD0:2PX
02d];@0206IVIP0T075aL@1fMWH0Cdm?03@d=017AdL0GemO04m?C`19BDT0?Shn04A4A00m?Cd0EUIF
03Xj>P1RHV80MGEe05ADE021PH40Hf=S0410@00i>CT0CDe=059BDP1NGUh0KFe]05iNGP1dM7@0FEUI
05IFEP1MGEd0C4a<04I6AP0o?cl0EUIF061PH01?Cdl0EUIF0P2QXJ400`2VYZH0VYZJ0:RXZ0020:6Q
X@070:RXZ02QXJ40WYjN0:FUY@2VYZH0WinO09ZJVP0K0:6QXAh0oooo5P2QXJ4209jNWP0i09^KV`2S
Xj<0Rh^;065QH@0i>CT0J6QX06][J`1dM7@0MGEe06UYJ@17AdL0?clo05eMG@1ADE40D51@04e=C@0m
?Cd0<S8b04Y:BP0g=cL0HF5Q07QhN01MGEd0Y:BT09JFUP1dM7@0K6a/08>3P`1lO7`0PH6109ZJVP2D
U9@0QhN7059BDP0n?Sh0Bd];04Q8B00l?3`0ADE5071`L01hN7P0E5AD05EEE@3Cdm<0WIfM0:^[Z`2N
WYh0Y:BT09fMW@2QXJ40Y:BT09fMW@2KVi/0Xj>S0:^[Z`2XZ:P0WYjN01/0XJ6Q7P3ooolF07IfMP0e
06e]K@1^KVh0L71`07AdM02BTY80QXJ603Xj>P19BDT0DE5A05ADE01CDe<0JFUY04Y:BP0Z:RX0@D51
03`l?013@d<0ADE502HV9P0L71`0:RXZ02TY:@0o?cl0De=C04e=C@2;Rh/0UYJF08R8R01mOGd0Rh^;
07inOP1hN7P0TI6A09RHV01_Kfl0>c/k01dM7@0Z:RX0<S8b02@T900i>CT0HF5Q06MWI`13@d<0?Shn
0;Bd]01`L700Ogmo07UiN@1cLg<0L71`07IfMP1cLg<00P1`L700101dM7@0Ogmo08>3P`1iNGTK07If
MR80oooo000P0?oooaH0XJ6Q00h0WIfM0:6QX@2MWId0YZJV09ZJVP1^KVh09RHV05=CD`1>CTh0OWin
08b<S01dM7@0C4a<055AD@80EUIF02<0DE5A05eMG@0`<300;Bd]055AD@0g=cL0GUiN079bLP1MGEd0
Lg=c0:RXZ01lO7`0Jf][07YjNP1/K6`0IVIV079bLP1kNg/0Jf][059BDP1<C4`0Cdm?03/k>`10@400
Cdm?06i^KP1EEED0IFEU08n?S`2QXJ40WYjN0:b/[02QXJ40WYjN0:FUY@020:6QX@0309jNWP2QXJ40
XJ6Q0080Z:RX00<0XJ6Q09jNWP2UYJD06@2QXJ4N0?oooaH0XJ6Q03<0X:2P0:BTY02PX:00[Zj^09jN
WP2>SXh0S8b<055AD@0m?Cd0IfMW08Z:RP1mOGd0IfMW05mOG`1SHf<0GEeM05QHF01/K6`0DU9B03Hf
=P1EEED0=cLg05aLG025QHD0J6QX06EUI@2;Rh/0NGUi07YjNP2FUYH0TI6A07inOP1ZJVX0Fe]K05=C
D`0o?cl0B4Q804i>CP0b<S80>SXj05aLG01kNg/0De=C06EUI@3Jf]X0WIfM09^KV`2UYJD0WIfM09^K
V`2SXj<00P2QXJ40202KVi/0XJ6Q0:BTY02TY:@0WinO09fMW@2KVi/0Xj>S6@2QXJ4N0?oooaH0MWIf
0240N7Qh07UiN@1hN7P0Ph>307UiN@2=SHd0bl_;03Ti>@0O7al0<S8b05aLG01SHf<0JFUY05=CD`1A
DE40C4a<04M7A`1JFUX0GEeM03<c<`0m?Cd0:RXZ03`l?01ZJVX0EeMG03Xj>P15ADD0FEUI06UYJ@24
Q8@0RHV9079bLP17AdL00P0Z:RX02P0T92@0=3@d03Lg=`0Q8B409BDU04e=C@1MGEd0?3`l04Y:BP3=
cLd2071`L004075aL@1`L700L71`07AdM080MWIf00D0L71`07IfMP1iNGT0Lg=c06e]K@02071`L003
07AdM01fMWH0MWIf01L0MWIf8P3oool00200oooo6@2QXJ406@2^[Zh0VYZJ0:6QX@2KVi/061PH03/k
>`1/K6`0N7Qh08j>SP27QhL0HV9R06EUI@1EEED0J6QX05aLG01[Jf/0<S8b04=3@`0N7Qh0>SXj06a/
K01NGUh0I6AT07YjNP1oOgl00P1nOWh0401[Jf/0Shn?05]KF`1JFUX0FEUI04A4A01@D500?clo05AD
E01;Bd/0EUIF05mOG`2VYZH0BTY:0:6QX@2GUiL30:6QX@0@09fMW@2UYJD0XJ6Q0:6QX@2MWId0WYjN
0:FUY@2VYZH0VYZJ0:6QX@2JVYX0YJFU09jNWP2UYJD0YZJV09ZJVQD0XJ6Q7P3ooolI0:6QX@0H0:j^
[P2JVYX0XJ6Q09nOW`0l?3`0?Cdm06][J`1YJFT0Ng]k08n?S`1mOGd0RXZ:07MgM`2JVYX0SXj>09:B
TP2IVIT0c<c<0:VYZ@2_[jl0VYZJ07alO02@T900Vi^K0P26QXH00`1dM7@0Bd];06a/K00204a<C00A
051@D00n?Sh0BTY:03Ti>@1JFUX0JFUY05iNGP1KFe/0gmoO0<71`@3EeMD0VIVI0:6QX@2TY:@0XJ6Q
0:2PX02UYJD00P2QXJ40302PX:00WYjN0:>SX`2[Zj/0WYjN0:6QX@2JVYX0YJFU09^KV`2SXj<0Zj^[
09jNWQD0XJ6Q7P3ooolI07IfMP0H07alO01dM7@0MWIf07UiN@1HF5P0<c<c04M7A`0j>SX0ADE506a/
K01aLG40Ph>307IfMP2HV9P0Shn?08b<S03:b/X0oooo0??cl`3Ng]h0U9BD07QhN02>SXh0QXJ60P1X
J6P05P1?Cdl08B4Q034a<@0b<S80;bl_03@d=00[:b/0<C4a02HV9P17AdL0I6AT04];B`0l?3`0_kno
0>g]k@2e]KD0M7Ad07IfMP1iNGT0MWIf07QhN01gMgL207IfMP0<07QhN01dM7@0M7Ad07moO`1iNGT0
MWIf079bLP1gMgL0L71`07AdM01oOgl0NGUi5@1fMWHR0?ooo`00803ooolA0:6QX@030:JVYP2QXJ40
XJ6Q00D0XJ6Q01l0[Zj^09ZJVP2QXJ40XJ6Q03`l?00T92@09BDU05mOG`25QHD0SXj>07alO024Q8@0
Jf][08R8R01nOWh0TI6A08J6QP2QXJ40WYjN08b<S02=SHd0MgMg0861P@26QXH0M7Ad07EeM@1VIVH0
GUiN079bLP15ADD0Fe]K00<0De=C00P0DE5A05YJFP1FEUH0LG5a07inOP2XZ:P0WYjN0:FUY@H0XJ6Q
00H0WYjN0:FUY@2QXJ40WIfM0:6QX@2XZ:P20:6QX@0509fMW@2QXJ40WIfM0:6QX@2XZ:P01`2QXJ40
1P2VYZH0XJ6Q0:JVYP2JVYX0WYjN0:FUY@T0XJ6Q7P3ooolA0:6QX@030:^[Z`2QXJ40XJ6Q00D0XJ6Q
02`0[Zj^09ZJVP2QXJ40XJ6Q07MgM`2IVIT0>CTi051@D01dM7@0N7Qh09:BTP2NWYh0QHF509NGU`25
QHD0YJFU0861P@2:RXX0Ph>307alO02GUiL0RHV908b<S02;Rh/0L71`065QH@1GEeL0G5aL07IfMP0l
?3`0E5AD04U9B@1DE5@0HV9R07AdM020P800Hf=S07moO`3@d=00i>CT09NGU`2SXj<0WIfM0:BTY0<0
XJ6Q00D0Y:BT09^KV`2SXj<0XJ6Q0:2PX0020:BTY00509fMW@2QXJ40X:2P0:BTY02PX:000P2TY:@0
0`2MWId0XJ6Q0:6QX@040:6QX@060:^[Z`2QXJ40Zj^[09jNWP2KVi/0Xj>S2@2QXJ4N0?oooa40MWIf
00<0Ogmo07IfMP1fMWH01@1fMWH0;01lO7`0M7Ad07IfMP1fMWH0WinO0=WIf@12@T80;2`/03lo?`10
@400Ng]k08F5Q@1jNWX0MWIf06QXJ022PX80Fe]K04i>CP1;Bd/0D51@07IfMP1gMgL0Kfm_06YZJP1C
De<0>3Ph03Xj>P17AdL0EEEE02/[:`0h>3P0;Bd]0410@01CDe<0LG5a07QhN01CDe<0I6AT0=7Ad@32
`/80Jf][07AdM01`L700NGUi0`1fMWH03`1iNGT0L71`07AdM01fMWH0N7Qh07UiN@1cLg<0L71`07If
MP1hN7P0NGUi07QhN01iNGT0Lg=c071`L00607IfMP0607moO`1fMWH0Ogmo07UiN@1`L700M7Ad2@1f
MWHR0?ooo`00803ooolA0:6QX@030:RXZ02QXJ40XJ6Q00@0XJ6Q00h0VYZJ0:j^[P2OWil0VYZJ0:JV
YP2QXJ40TY:B01lO7`0T92@0HF5Q075aL@28R8P0UIFE08f=S@<0SXj>01H0Ph>308j>SP22PX80PH61
09VIV@25QHD0QXJ608:2PP1lO7`0EUIF07IfMP1CDe<0IFEU04];B`1SHf<0HV9R06=SH`1NGUh0J6QX
065QH@1^KVh0MGEe0P2QXJ40202JVYX0YJFU0:6QX@2VYZH0VYZJ0:JVYP2JVYX0WYjN202QXJ400`2V
YZH0VYZJ0:6QX@040:6QX@050:JVYP2QXJ40XJ6Q0:6QX@2VYZH00P2QXJ400`2XZ:P0YZJV09JFUP0:
0:6QXAh0oooo4@2QXJ400`2TY:@0XJ6Q0:6QX@040:6QX@0?09jNWP2^[Zh0Y:BT09jNWP2[Zj/0XJ6Q
0:>SX`1_Kfl0DE5A065QH@1SHf<0Ng]k08:2PP1oOgl0RXZ:0080Ti>C0280RXZ:0:>SX`2EUID0SHf=
09RHV022PX80Ph>307]kN`1jNWX0FEUI06ATI01:BTX0DU9B0492@P1XJ6P0K6a/07YjNP1dM7@0LG5a
05UIF@1]KFd0cLg=0<[:bP2QXJ40VYZJ0:FUY@2TY:@0Zj^[09jNWP2[Zj/0WYjN09^KV`2QXJ40Y:BT
1P2QXJ400`2[Zj/0WYjN0:6QX@040:6QX@050:^[Z`2QXJ40XJ6Q0:6QX@2[Zj/00P2QXJ40102TY:@0
YZJV09fMW@2TY:@90:6QXAh0oooo4@1fMWH00`1cLg<0MWIf07IfMP0407IfMP0?07UiN@1lO7`0OGem
07UiN@1oOgl0MWIf08V9R@2][Jd0JFUY04A4A00j>SX0CTi>04a<C01ADE40H61P0080KVi^0280KFe]
08J6QP1mOGd0Lg=c06a/K01PH600GemO05EEE@1KFe/0Bd];03`l?00b<S80;2`/02h^;P1=CDd0De=C
06UYJ@1VIVH0EeMG03dm?@1>CTh0eMGE0:RXZ01fMWH0LW9b07MgM`1iNGT0Ogmo07UiN@1oOgl0NGUi
071`L01fMWH0NGUi1P1fMWH00`1oOgl0NGUi07IfMP0407IfMP0507moO`1fMWH0MWIf07IfMP1oOgl0
0P1fMWH0101cLg<0NWYj07]kN`1iNGT907IfMR80oooo000P0?oooa00XJ6Q00<0YZJV09ZJVP2QXJ40
2@2QXJ40;P2NWYh0UYJF0:6QX@2^[Zh0VYZJ0:6QX@1CDe<0A4A404U9B@1mOGd0XJ6Q092@T02LW9`0
Q8B408j>SP29RHT0Q8B406ATI01ZJVX0FEUI06m_K`1ZJVX0OGem03<c<`1ZJVX0KFe]05IFEP1RHV80
UIFE08^;R`1HF5P0HV9R09^KV`2JVYX0XJ6Q0:JVYP2JVYX0XJ6Q0:RXZ02QXJ40YZJV09ZJVP2MWId0
XJ6Q0:RXZ02QXJ420:FUY@<0XJ6Q00H0Z:RX0:6QX@2VYZH0VYZJ09nOW`2VYZH209nOW`0<09ZJVP2Q
XJ40XJ6Q0:6QX@2VYZH0VYZJ0:6QX@2^[Zh0YZJV0:6QX@2RXZ80VYZJ102QXJ400`2XZ:P0XJ6Q0:6Q
X@020:6QXAh0oooo402QXJ400`2[Zj/0WYjN0:6QX@090:6QX@0Q09^KV`2MWId0Y:BT0:j^[P2JVYX0
XJ6Q08B4Q02o_kl0J6QX06=SH`20P800MWIf09FEU@2>SXh0UIFE08b<S02?Shl0MGEe07moO`1/K6`0
MWIf069RHP1nOWh0GUiN09fMW@2NWYh0Ogmo06m_K`2>SXh0[:b/0;Jf]P3<c<`0c/k>0080XJ6Q00P0
Zj^[09jNWP2QXJ40Y:BT0:6QX@2[Zj/0WYjN0:2PX080Y:BT00<0WIfM09jNWP2NWYh00P2QXJ420:BT
Y00809fMW@2[Zj/0WYjN0:RXZ02[Zj/0Y:BT0:RXZ02NWYh30:6QX@070:^[Z`2NWYh0XJ6Q0:j^[P2V
YZH0WIfM0:FUY@050:6QX@030:BTY02MWId0XJ6Q0080XJ6Q7P3oool@07IfMP0307moO`1iNGT0MWIf
00T0MWIf01/0L71`07]kN`1iNGT0O7al07AdM01fMWH0VYZJ0?7al@1ZJVX0<c<c03`l?010@400I6AT
075aL@1`L700Jf][07=cL`1ZJVX0LG5a06=SH`1IFET0@T9205aLG01aLG40UIFE09JFUP23Ph<00P1L
G5`04`2DU9@0e=CD0>OWi`2e]KD0O7al07IfMP1oOgl0NGUi07IfMP1cLg<0MWIf07moO`1iNGT0N7Qh
07UiN@1cLg<0L71`06e]K@1^KVh00P1fMWH02P1iNGT0Lg=c071`L01oOgl0NGUi08>3P`1oOgl0OGem
08>3P`1iNGT307IfMP0607moO`1iNGT0MWIf07alO01jNWX0L71`0P1lO7`407IfMP0307=cL`1`L700
MWIf0080MWIf8P3oool00200oooo3`2QXJ400`2NWYh0[:b/0:6QX@0:0:6QX@0409fMW@2QXJ40XJ6Q
0:RXZ080XJ6Q0P2VYZH205=CD`0J04i>CP1fMWH0P82009jNWP2JVYX0T92@09VIV@24Q8@0OWin065Q
H@1OGel0Fe]K07emO@1WIfL0JFUY07emO@2>SXh0N7Qh0820P02EUID0[Zj^0:JVYP2NWYh0YJFU0:6Q
X@2XZ:P30:6QX@080:FUY@2XZ:P0WYjN0:FUY@2QXJ40WYjN0:FUY@2MWId40:6QX@0409jNWP2UYJD0
Z:RX0:6QX@<0Z:RX0P2UYJD0102VYZH0YJFU0:6QX@2XZ:P20:6QX@050:b/[02XZ:P0XJ6Q0:RXZ02N
WYh02@2QXJ4N0?ooo`l0XJ6Q00<0Vi^K0:FUY@2MWId02P2QXJ401P2PX:00WIfM0:6QX@2TY:@0WIfM
0:6QX@80Zj^[01d0Q8B40;:b/P1^KVh0K6a/06i^KP20P800Rh^;08N7Q`2GUiL0V9RH0:ZZZP2GUiL0
Ti>C08V9R@2VYZH0O7al079bLP1VIVH0NWYj08V9R@38b<P0^[Zj0;Jf]P2VYZH0UiNG09jNWP2QXJ40
Y:BT09fMW@020:6QX@090:>SX`2TY:@0UiNG0:>SX`2QXJ40Vi^K0:>SX`2PX:00Y:BT00<0XJ6Q00@0
Vi^K0:>SX`2TY:@0WIfM0`2OWil03@2JVYX0WYjN0:^[Z`2SXj<0XJ6Q0:BTY02MWId0XJ6Q0:FUY@2O
Wil0WIfM0:BTY02GUiL02@2QXJ4N0?ooo`l0MWIf00<0L71`075aL@1`L7002P1fMWH01P1hN7P0L71`
07IfMP1cLg<0L71`07IfMP80Ogmo01d0VYZJ0=?Cd`1aLG40AdM70492@P11@D40EeMG05aLG01ZJVX0
PH6109nOW`2PX:00VIVI08j>SP2EUID0Lg=c05]KF`0g=cL0ATI607=cL`35aLD0WinO08J6QP1jNWX0
Jf][06i^KP1fMWH0Lg=c071`L00207IfMP0907AdM01cLg<0Jf][07AdM01fMWH0L71`07AdM01hN7P0
NGUi00<0MWIf00@0L71`07AdM01cLg<0L71`0`1]KFd03@1XJ6P0KVi^07moO`1dM7@0MWIf07=cL`1`
L700MWIf075aL@1]KFd0L71`07=cL`1[Jf/02@1fMWHR0?ooo`00803oool?0:6QX@0309fMW@2VYZH0
VYZJ00d0XJ6Q0100WYjN0:FUY@2QXJ40[Zj^0:VYZ@2UYJD0XJ6Q06EUI@1MGEd0I6AT075aL@25QHD0
P82009bLW028R8P0UIFE0P2IVIT01`29RHT0S8b<08b<S01jNWX0Hf=S075aL@20P8000P2QXJ401P2^
[Zh0YZJV09JFUP2VYZH0WinO09ZJVP<0XJ6Q00<0WYjN0::RXP2QXJ400P2QXJ402P2MWId0XJ6Q09jN
WP2UYJD0YZJV09NGU`2QXJ40WIfM0:JVYP2JVYX40:6QX@0609fMW@2QXJ40Z:RX09ZJVP2VYZH0VYZJ
1P2QXJ400`2RXZ80XJ6Q0:6QX@040:6QX@0309ZJVP2QXJ40XJ6Q01h0oooo3`2QXJ400`2PX:00[Zj^
09jNWP0=0:6QX@0Q09^KV`2SXj<0XJ6Q0:j^[P2OWil0WYjN0:6QX@2;Rh/0ZJVY0::RXP2YZJT0YZJV
09>CT`2][Jd0Ph>307MgM`1eMGD0Ph>308F5Q@26QXH0Rh^;09ZJVP2^[Zh0_[jn0;Ng]`2YZJT0XJ6Q
0:j^[P2VYZH0V9RH0:j^[P2XZ:P0WYjN00<0XJ6Q00l0WYjN09fMW@2QXJ40Y:BT0:6QX@2PX:00Y:BT
09^KV`2SXj<0Zj^[09VIV@2QXJ40X:2P0:j^[P2NWYh0102QXJ401P2PX:00Y:BT0:BTY02QXJ40Zj^[
09jNWP80XJ6Q00D0Y:BT0:6QX@2QXJ40XJ6Q0:VYZ@060:6QX@0309jNWP2QXJ40XJ6Q01h0oooo3`1f
MWH00`1hN7P0Ph>307UiN@0=07IfMP0N071`L01dM7@0MWIf07alO01[Jf/0KVi^07IfMP2BTY80_Kfm
0:j^[P2XZ:P0TI6A07emO@28R8P0GUiN03lo?`0i>CT0CTi>05mOG`1MGEd0I6AT08f=S@2m_Kd0aLG5
0:n_[`1oOgl0MWIf07alO01jNWX0MGEe0P23Ph<04`1iNGT0MWIf07IfMP1fMWH0M7Ad06m_K`1fMWH0
NGUi07IfMP1hN7P0NGUi071`L01dM7@0Ogmo07AdM01fMWH0N7Qh08>3P`1iNGT0101fMWH01P1hN7P0
NGUi07=cL`1lO7`0Ogmo07UiN@80MWIf00D0NGUi07IfMP1fMWH0MWIf0861P@0607IfMP0307UiN@1f
MWH0MWIf0280oooo000P0?oooa00XJ6Q00<0Z:RX09jNWP2QXJ40202QXJ402@2VYZH0UiNG0:6QX@2Q
XJ40WIfM09jNWP2UYJD0Z:RX09fMW@030:6QX@0709fMW@2RXZ80SXj>09FEU@2>SXh0W9bL07inOP02
07IfMP0=08:2PP29RHT0MWIf08:2PP2EUID0WIfM0:6QX@2VYZH0VYZJ0:6QX@2XZ:P0[Zj^09ZJVP02
0:RXZ00609jNWP2UYJD0YZJV09ZJVP2RXZ80UYJF0P2QXJ420:JVYP0809ZJVP2RXZ80VYZJ0:FUY@2Q
XJ40WYjN0:FUY@2XZ:P80:6QX@040:FUY@2XZ:P0YZJV09ZJVP80XJ6Q00@0YZJV09ZJVP2QXJ40Z:RX
2@2QXJ4N0?oooa00XJ6Q00<0Y:BT09NGU`2QXJ40202QXJ402P2[Zj/0VIVI0:6QX@2QXJ40X:2P09jN
WP2SXj<0Y:BT0::RXP2TY:@20:6QX@0P0:2PX02/[:`0WIfM0:BTY02QXJ40[:b/09NGU`2RXZ80ZJVY
0:f][@2f][H0YZJV0:f][@2a/K40YjNW0:BTY02[Zj/0WYjN0:6QX@2TY:@0ZJVY09ZJVP2TY:@0WinO
09NGU`2SXj<0Zj^[09jNWP2YZJT0X:2P0:BTY02QXJ420:^[Z`0909jNWP2YZJT0XJ6Q09jNWP2MWId0
Vi^K0:>SX`2TY:@0WIfM00L0XJ6Q00@0WYjN0:BTY02VYZH0WYjN0P2QXJ40102[Zj/0WYjN0:6QX@2T
Y:@60:6QX@0309fMW@2QXJ40XJ6Q01h0oooo401fMWH00`1cLg<0Jf][07IfMP0807IfMP0507moO`1d
M7@0MWIf07IfMP1hN7P00P1dM7@00`1cLg<0Ng]k07UiN@0207IfMP0407QhN025QHD0PX:208F5Q@80
R8R801X0RHV909fMW@2VYZH0X:2P0:RXZ02SXj<0XJ6Q09BDU021PH40NGUi07moO`1iNGT0MWIf07=c
L`1fMWH0M7Ad07=cL`1]KFd0Jf][07AdM01oOgl0NGUi0861P@1nOWh0NGUi07IfMP80Ogmo00@0NGUi
0861P@1lO7`0KFe]0P1`L7000`1dM7@0Lg=c071`L00707IfMP0406i^KP1cLg<0NWYj07UiN@80MWIf
00@0Ogmo07UiN@1fMWH0Lg=c1P1fMWH00`1`L700MWIf07IfMP0R0?ooo`00803ooolA0:6QX@0309fM
W@2QXJ40XJ6Q00L0XJ6Q00D0Z:RX09fMW@2QXJ40XJ6Q09jNWP020:6QX@0;09jNWP2JVYX0XJ6Q0:6Q
X@2NWYh0YJFU0:b/[02QXJ40YZJV09NGU`2UYJD0102MWId0102^[Zh0VYZJ09jNWP2UYJD20:6QX@0=
0:RXZ02QXJ40YZJV09ZJVP2^[Zh0VYZJ0:6QX@2NWYh0YZJV09ZJVP2^[Zh0WinO0:RXZ0030:6QX@80
Z:RX00D0XJ6Q0:j^[P2GUiL0WYjN0:FUY@070:6QX@030:JVYP2JVYX0XJ6Q00<0XJ6Q00P0[Zj^09ZJ
VP2QXJ40WYjN0:b/[02VYZH0WinO09ZJVPH0XJ6Q00<0VYZJ09jNWP2UYJD07P3ooolA0:6QX@030:2P
X02QXJ40XJ6Q00L0XJ6Q00T0Y:BT09^KV`2QXJ40XJ6Q09^KV`2QXJ40Y:BT09^KV`2NWYh00P2QXJ40
202KVi/0Xj>S0:FUY@2MWId0Zj^[09VIV@2SXj<0X:2P0`2RXZ80102`/;00VYZJ09^KV`2SXj<20:6Q
X@0;0:BTY02MWId0Zj^[09jNWP2^[Zh0VYZJ0:6QX@2KVi/0Zj^[0:6QX@2^[Zh00P2TY:@00`2MWId0
XJ6Q0:6QX@020:BTY00709fMW@2^[Zh0U9BD09^KV`2UYJD0XJ6Q0:BTY0050:6QX@0>0:^[Z`2NWYh0
XJ6Q0:6QX@2TY:@0XJ6Q0:j^[P2JVYX0XJ6Q09^KV`2UYJD0YZJV0:RXZ02NWYh60:6QX@0309jNWP2K
Vi/0Xj>S01h0oooo4@1fMWH00`1hN7P0MWIf07IfMP0707IfMP0907=cL`1bLW80MWIf07IfMP1`L700
MWIf07UiN@1`L700NGUi0080MWIf00D0L71`07AdM01aLG40L71`07moO`0207AdM00807QhN01kNg/0
Ng]k07]kN`1oOgl0M7Ad071`L01dM7@207IfMP0907=cL`1`L700Ogmo07UiN@1lO7`0M7Ad07IfMP1`
L700Ogmo0080O7al00<0OGem07=cL`1`L7000P1fMWH207=cL`07071`L01lO7`0KVi^071`L01gMgL0
MWIf07UiN@0507IfMP0>07moO`1iNGT0MWIf07IfMP1iNGT0MWIf07alO01dM7@0MWIf071`L01aLG40
NWYj08>3P`1iNGT607IfMP0307UiN@1`L700M7Ad0280oooo000P0?ooo`h0XJ6Q00L0YZJV09ZJVP2Q
XJ40WYjN0:6QX@2NWYh0YJFU00P0XJ6Q00H0WYjN0:^[Z`2JVYX0XJ6Q0:RXZ02UYJD20:6QX@0409fM
W@2NWYh0Zj^[0:FUY@80XJ6Q00H0[Zj^09ZJVP2XZ:P0YZJV09ZJVP2NWYh20:6QX@060:FUY@2QXJ40
XJ6Q0:6QX@2MWId0Z:RX0P2QXJ403`2XZ:P0[Zj^09ZJVP2NWYh0XJ6Q0:JVYP2JVYX0WIfM0:FUY@2[
Zj/0WinO09ZJVP2QXJ40Zj^[09ZJVP030:6QX@0E0:JVYP2QXJ40XJ6Q0:j^[P2FUYH0XJ6Q0:JVYP2J
VYX0Z:RX0:JVYP2JVYX0Z:RX09nOW`2FUYH0XJ6Q0:JVYP2JVYX0XJ6Q09jNWP2QXJ40Z:RX00D0XJ6Q
00D0YZJV09ZJVP2QXJ40Z:RX0:6QX@0N0?ooo`h0XJ6Q00L0Zj^[09jNWP2QXJ40Vi^K09fMW@2KVi/0
Xj>S00P0XJ6Q00H0Vi^K0:f][@2NWYh0XJ6Q0:BTY02JVYX20:6QX@040:2PX02NWYh0[Jf]09jNWP80
XJ6Q00T0[Zj^09ZJVP2TY:@0YZJV09jNWP2KVi/0XJ6Q0:BTY02SXj<00`2QXJ403@2PX:00Y:BT09fM
W@2QXJ40Y:BT0:VYZ@2JVYX0Vi^K0:6QX@2^[Zh0WYjN0:2PX02NWYh00P2XZ:P0102NWYh0XJ6Q0:RX
Z02NWYh30:6QX@0F0:^[Z`2QXJ40XJ6Q0:j^[P2HV9P0Y:BT0:^[Z`2NWYh0Y:BT0:JVYP2NWYh0Y:BT
0:RXZ02MWId0Y:BT0:^[Z`2NWYh0XJ6Q09^KV`2QXJ40YZJV09fMW@@0XJ6Q00D0Zj^[09jNWP2QXJ40
Y:BT09fMW@0N0?ooo`h0MWIf00<0Ogmo07UiN@1fMWH00`1`L7000`1dM7@0MWIf07IfMP0607IfMP06
071`L01mOGd0NGUi07IfMP1cLg<0J6QX0P1fMWH0101hN7P0M7Ad07emO@1^KVh207IfMP0907alO01d
M7@0Lg=c07YjNP1iNGT0L71`07IfMP1iNGT0M7Ad00<0MWIf01<0N7Qh07=cL`1`L700MWIf07=cL`1f
MWH0M7Ad071`L01fMWH0Ph>307UiN@1hN7P0KFe]07QhN023Ph<0NGUi07IfMP1hN7P0NGUi00<0MWIf
01<0Ogmo07IfMP1fMWH0O7al07EeM@1iNGT0Ogmo07UiN@1cLg<0NWYj07UiN@1cLg<0Ph>307]kN`1i
NGT0Ogmo07UiN@1fMWH0L71`0080MWIf00<0L71`07IfMP1fMWH00P1fMWH01@1oOgl0NGUi07IfMP1c
Lg<0L71`0280oooo000P0?ooo`h0XJ6Q00H0Z:RX0:6QX@2QXJ40WIfM0:JVYP2FUYH90:6QX@0309fM
W@2XZ:P0XJ6Q0080XJ6Q0140WIfM0:6QX@2QXJ40XJ6Q09ZJVP2/[:`0XJ6Q0:JVYP2GUiL0[:b/0:JV
YP2QXJ40Z:RX0:6QX@2RXZ80VYZJ0:JVYP050:6QX@090:FUY@2VYZH0VYZJ0:6QX@2XZ:P0XJ6Q09fM
W@2QXJ40Z:RX0080XJ6Q00H0WIfM0:RXZ02UYJD0YJFU0:6QX@2XZ:P20:6QX@0909jNWP2[Zj/0WYjN
09ZJVP2QXJ40[Zj^09ZJVP2QXJ40[:b/0080XJ6Q00@0Z:RX0:6QX@2QXJ40Z:RX0P2QXJ40102XZ:P0
XJ6Q0:FUY@2MWId60:6QX@0309jNWP2b/[80VYZJ00<0XJ6Q7P3oool>0:6QX@070:BTY02MWId0XJ6Q
0:2PX02[Zj/0WIfM0:BTY0080:6QX@030:2PX02VYZH0WIfM0080XJ6Q0180X:2P0:6QX@2QXJ40XJ6Q
09ZJVP2XZ:P0Y:BT0:^[Z`2IVIT0YJFU0:JVYP2QXJ40Y:BT09fMW@2YZJT0XJ6Q0:^[Z`2TY:@40:6Q
X@070:>SX`2[Zj/0WYjN0:6QX@2TY:@0WIfM0:2PX0020:BTY00P09fMW@2QXJ40X:2P0:JVYP2JVYX0
WYjN0:6QX@2VYZH0WIfM0:6QX@2KVi/0[Jf]09^KV`2NWYh0XJ6Q0:j^[P2JVYX0XJ6Q0:FUY@2MWId0
XJ6Q0:BTY02MWId0XJ6Q09nOW`2MWId0XJ6Q0:BTY02MWId0Xj>S0:2PX02TY:@50:6QX@0309^KV`2_
[jl0VYZJ00<0XJ6Q7P3oool>07IfMP0707=cL`1`L700MWIf07QhN01oOgl0Ng]k07UiN@0807IfMP03
07QhN01fMWH0L71`0080MWIf0180N7Qh07IfMP1fMWH0MWIf079bLP1dM7@0NGUi07moO`1dM7@0LG5a
07YjNP1fMWH0Lg=c071`L021PH40O7al07moO`1iNGT407IfMP0?07AdM01oOgl0NGUi07IfMP1cLg<0
L71`07QhN01iNGT0Lg=c071`L01fMWH0N7Qh07IfMP1XJ6P0KVi^0080MWIf01P0L71`07IfMP1`L700
OGem071`L01iNGT0MWIf07alO01dM7@0MWIf075aL@1`L700MWIf07=cL`1`L700MWIf06e]K@1`L700
MWIf07=cL`1`L700M7Ad07QhN01iNGT507IfMP03071`L01jNWX0M7Ad00<0MWIf8P3oool00200oooo
4@2QXJ400`2VYZH0Z:RX0:6QX@090:6QX@030:FUY@2QXJ40XJ6Q00H0XJ6Q00d0VYZJ0::RXP2QXJ40
Z:RX09fMW@2NWYh0/[:b09ZJVP2QXJ40YZJV09jNWP2UYJD0Z:RX0080XJ6Q00P0YZJV09ZJVP2NWYh0
YJFU0:RXZ02VYZH0UiNG0:FUY@80YZJV00<0VYZJ0:6QX@2VYZH00P2JVYX01@2QXJ40WIfM0:6QX@2Q
XJ40VYZJ0080XJ6Q00P0WIfM0:RXZ02JVYX0YZJV09ZJVP2XZ:P0XJ6Q0:JVYP80XJ6Q00L0YZJV09ZJ
VP2VYZH0VYZJ0:JVYP2GUiL0YJFU00<0XJ6Q00@0YZJV09ZJVP2QXJ40YZJV0`2QXJ401P2MWId0Z:RX
0:6QX@2QXJ40WYjN0::RXQh0oooo4@2QXJ400`2[Zj/0Y:BT09fMW@090:6QX@030:>SX`2QXJ40XJ6Q
00H0XJ6Q00d0VYZJ0:2PX02QXJ40Y:BT09^KV`2NWYh0[jn_09jNWP2QXJ40Zj^[09^KV`2NWYh0Y:BT
0080XJ6Q00P0Zj^[09jNWP2KVi/0YJFU0:BTY02VYZH0VIVI0:>SX`80Zj^[00<0WYjN0:6QX@2[Zj/0
0P2NWYh01@2QXJ40X:2P0:BTY02QXJ40WYjN0080XJ6Q0140X:2P0:JVYP2EUID0YZJV09jNWP2TY:@0
WIfM0:^[Z`2TY:@0XJ6Q0:^[Z`2NWYh0Zj^[09jNWP2[Zj/0VIVI0:>SX`020:6QX@050:BTY02[Zj/0
WYjN0:6QX@2[Zj/00`2QXJ401P2PX:00YZJV09fMW@2QXJ40Vi^K09fMWAh0oooo4@1fMWH00`1oOgl0
Lg=c071`L00907IfMP0307AdM01fMWH0MWIf00H0MWIf0P1bLW802`1fMWH0Lg=c079bLP1dM7@0NWYj
07UiN@1fMWH0Ogmo071`L01^KVh0Lg=c0080MWIf00H0Ogmo07UiN@1`L700MgMg07=cL`1jNWX207Ad
M080Ogmo00<0NGUi07IfMP1oOgl00P1iNGT01@1fMWH0N7Qh07UiN@1fMWH0NGUi0080MWIf00l0N7Qh
07IfMP1]KFd0NWYj07UiN@1cLg<0L71`07moO`1iNGT0MWIf07moO`1iNGT0Ogmo07UiN@1oOgl00P1d
M7@207IfMP0507UiN@1oOgl0NGUi07IfMP1oOgl00`1fMWH01P1hN7P0MWIf071`L01fMWH0L71`06m_
Kb80oooo000P0?oooa40XJ6Q00<0Z:RX0:JVYP2JVYX02@2QXJ401P2VYZH0VYZJ0:6QX@2NWYh0YJFU
09jNWP<0XJ6Q0P2MWId02@2JVYX0XJ6Q0:6QX@2MWId0Z:RX0:6QX@2NWYh0/[:b09JFUP040:6QX@0?
0:RXZ02QXJ40WIfM0:6QX@2NWYh0[:b/0::RXP2JVYX0[Zj^0:RXZ02QXJ40WYjN0;:b/P2GUiL0VYZJ
0080XJ6Q00<0WYjN0:FUY@2QXJ40102QXJ403P2MWId0WYjN0::RXP2UYJD0XJ6Q0:RXZ02UYJD0XJ6Q
0:RXZ02QXJ40[Zj^09ZJVP2XZ:P0WIfM0`2QXJ401@2JVYX0Z:RX0:6QX@2QXJ40Z:RX00H0XJ6Q00<0
YJFU0::RXP2FUYH07P3ooolA0:6QX@030:BTY02[Zj/0WYjN00T0XJ6Q00H0[Zj^09jNWP2QXJ40Vi^K
0:>SX`2KVi/30:6QX@030:2PX02RXZ80WYjN0080XJ6Q00L0X:2P0:JVYP2MWId0Vi^K0:n_[`2HV9P0
Y:BT00<0XJ6Q00D0Y:BT09fMW@2PX:00Y:BT09^KV`020:FUY@080:6QX@2^[Zh0Y:BT09fMW@2KVi/0
[jn_09BDU02JVYX20:6QX@0309^KV`2SXj<0WIfM00@0XJ6Q00l0X:2P09^KV`2HV9P0Xj>S0:6QX@2T
Y:@0Xj>S0:6QX@2TY:@0WIfM0:j^[P2JVYX0Y:BT09^KV`2TY:@00P2QXJ401@2NWYh0Y:BT09fMW@2Q
XJ40Y:BT00H0XJ6Q00<0Xj>S0:VYZ@2PX:007P3ooolA07IfMP0307=cL`1oOgl0NGUi00T0MWIf00H0
Ph>307UiN@1fMWH0L71`07AdM01`L70307IfMP0307QhN01kNg/0NGUi0080MWIf00L0N7Qh07IfMP1`
L700L71`07YjNP1eMGD0NGUi00<0MWIf00H0Lg=c071`L01hN7P0NGUi071`L01aLG4307alO00607=c
L`1`L700L71`07YjNP1^KVh0M7Ad0P1fMWH00`1`L700M7Ad071`L00407IfMP0?07QhN01`L700JFUY
07AdM01fMWH0Lg=c07AdM01fMWH0Lg=c071`L01lO7`0M7Ad07=cL`1bLW80NGUi0080MWIf00D0NGUi
07=cL`1`L700MWIf07=cL`0607IfMP0307AdM021PH40OWin0280oooo000P0?oooa80XJ6Q00<0Z:RX
09jNWP2UYJD01P2QXJ401P2NWYh0Zj^[0:RXZ02NWYh0YJFU09fMW@80WYjN0P2QXJ401P2VYZH0WinO
09ZJVP2QXJ40WYjN0:FUY@80XJ6Q00L0WYjN0:6QX@2XZ:P0YZJV09ZJVP2NWYh0VYZJ00@0XJ6Q01P0
VYZJ0::RXP2JVYX0YJFU0:^[Z`2QXJ40YJFU09jNWP2QXJ40Z:RX0::RXP2QXJ40WYjN0:FUY@2MWId0
YZJV0:^[Z`2JVYX0WYjN0:FUY@2NWYh0Zj^[0::RXP2FUYH20:6QX@0309jNWP2QXJ40XJ6Q0080XJ6Q
00<0Z:RX0:6QX@2QXJ401@2QXJ400`2NWYh0YJFU0:6QX@080:6QX@030:RXZ02QXJ40oooo01d0oooo
4P2QXJ400`2TY:@0UiNG0:>SX`060:6QX@0809^KV`2][Jd0Y:BT09NGU`2SXj<0X:2P09jNWP2KVi/2
0:6QX@060:^[Z`2XZ:P0WYjN09fMW@2KVi/0Xj>S0P2QXJ401`2KVi/0XJ6Q0:JVYP2VYZH0WYjN09^K
V`2NWYh0102QXJ40702NWYh0ZJVY0:6QX@2NWYh0Z:RX0:6QX@2SXj<0Vi^K0:6QX@2VYZH0YJFU09fM
W@2KVi/0Xj>S0:2PX02^[Zh0[Jf]09jNWP2KVi/0Xj>S09^KV`2][Jd0YJFU0:2PX02TY:@0XJ6Q09^K
V`2TY:@30:6QX@030:BTY02MWId0XJ6Q00@0XJ6Q00<0WIfM09^KV`2SXj<0202QXJ420:BTY00309fM
W@3oool0oooo01`0oooo4P1fMWH00`1cLg<0Jf][07AdM00607IfMP08071`L01mOGd0Lg=c06][J`1d
M7@0N7Qh07AdM01`L70207IfMP0307moO`23Ph<0NGUi0080L71`00@0M7Ad07IfMP1fMWH0L71`0P1f
MWH0101jNWX0NGUi071`L01iNGT407IfMP0807UiN@21PH40O7al06e]K@1hN7P0MWIf07AdM01`L702
07IfMP0B07alO01`L700L71`07AdM01hN7P0Ph>307emO@1iNGT0L71`07AdM01`L700OGem07alO01n
OWh0NGUi07IfMP1`L700NGUi0`1fMWH00`1cLg<0L71`07IfMP0407IfMP80L71`00<0M7Ad07IfMP1f
MWH01P1fMWH00`1iNGT0Lg=c071`L00R0?ooo`00803oool?0:6QX@080:JVYP2JVYX0YZJV0:6QX@2N
WYh0YJFU09jNWP2UYJD30:6QX@060:JVYP2JVYX0XJ6Q0:6QX@2XZ:P0XJ6Q0P2UYJD01@2JVYX0YJFU
0:FUY@2MWId0Z:RX00<0XJ6Q00<0WYjN0:FUY@2QXJ400P2XZ:P00`2QXJ40YZJV09ZJVP020:6QX@04
0:JVYP2GUiL0YJFU0:JVYPH0XJ6Q0`2XZ:P0202QXJ40YZJV0:6QX@2MWId0XJ6Q0:RXZ02NWYh0XJ6Q
102XZ:P20:JVYP0509ZJVP2QXJ40WYjN0:b/[02JVYX00P2QXJ400`2VYZH0UYJF0:6QX@040:6QX@05
0:RXZ02UYJD0WYjN0:FUY@2XZ:P00`2QXJ401@2XZ:P0XJ6Q0:RXZ02QXJ40Z:RX0080XJ6Q7P3oool?
0:6QX@080:^[Z`2NWYh0Zj^[0:6QX@2KVi/0Xj>S09^KV`2SXj<30:6QX@060:^[Z`2NWYh0XJ6Q0:6Q
X@2TY:@0WIfM0P2NWYh209ZJVP0409jNWP2PX:00YZJV09fMW@80XJ6Q0100Vi^K0:>SX`2QXJ40Y:BT
09nOW`2MWId0Zj^[09jNWP2QXJ40WIfM0:^[Z`2IVIT0Xj>S0:^[Z`2QXJ40WIfM102QXJ4309nOW`04
09fMW@2[Zj/0XJ6Q0:2PX080Y:BT00<0UiNG0:6QX@2TY:@00`2OWil01`2VYZH0Zj^[09jNWP2QXJ40
Vi^K0:FUY@2JVYX00P2QXJ400`2[Zj/0WIfM0:BTY0040:6QX@060:BTY02SXj<0Vi^K0:>SX`2TY:@0
WIfM0P2QXJ401`2TY:@0WIfM0:BTY02MWId0Y:BT09fMW@2QXJ407P3oool?07IfMP0807moO`1iNGT0
Ogmo07IfMP1`L700M7Ad071`L01dM7@307IfMP0>07moO`1iNGT0MWIf07IfMP1cLg<0L71`06e]K@1^
KVh0LW9b06QXJ01^KVh0N7Qh07IfMP1`L70207IfMP0;071`L01dM7@0MWIf07=cL`1]KFd0L71`07mo
O`1iNGT0MWIf071`L01oOgl00P1dM7@00`1oOgl0MWIf071`L00407IfMP<0KFe]00T0L71`07moO`1f
MWH0N7Qh07UiN@1cLg<0Jf][07IfMP1cLg<00`1]KFd01`1jNWX0Ogmo07UiN@1fMWH0L71`075aL@1d
M7@00P1fMWH00`1oOgl0Ng]k07UiN@0407IfMP0607=cL`1dM7@0L71`07AdM01cLg<0L71`0P1fMWH0
1`1cLg<0L71`07=cL`1`L700Lg=c071`L01fMWH08P3oool00200oooo3`2QXJ401`2^[Zh0VYZJ0:RX
Z02JVYX0WIfM0:6QX@2MWId0102QXJ40202XZ:P0XJ6Q0:6QX@2QXJ40WYjN0:FUY@2MWId0XJ6Q0P2M
WId0102VYZH0VYZJ0:JVYP2JVYX20:6QX@0309fMW@2QXJ40XJ6Q0080XJ6Q0P2VYZH01@2JVYX0XJ6Q
09jNWP2/[:`0WIfM0080YZJV2@2QXJ420:JVYP0509ZJVP2QXJ40XJ6Q0:6QX@2MWId01@2QXJ401@2^
[Zh0YZJV09ZJVP2QXJ40WIfM00@0XJ6Q00<0Z:RX0:6QX@2QXJ400`2QXJ402`2VYZH0VYZJ0:FUY@2J
VYX0YJFU0:6QX@2VYZH0XJ6Q0:JVYP2GUiL0YJFU00D0XJ6Q7P3oool?0:6QX@080:j^[P2JVYX0Y:BT
09jNWP2PX:00Y:BT0:2PX02TY:@30:6QX@080:BTY02MWId0XJ6Q0:6QX@2KVi/0Xj>S0:2PX02TY:@2
0:2PX0040:j^[P2NWYh0Zj^[09jNWP80XJ6Q00<0X:2P0:BTY02QXJ400P2QXJ420:^[Z`0809ZJVP2Q
XJ40Vi^K0:FUY@2KVi/0[Zj^0:^[Z`2MWId80:6QX@80Zj^[00D0WYjN0:6QX@2QXJ40XJ6Q0:2PX005
0:6QX@070:j^[P2[Zj/0VYZJ0:6QX@2PX:00Y:BT09fMW@020:6QX@030:BTY02MWId0XJ6Q00<0XJ6Q
00/0Zj^[09jNWP2UYJD0VYZJ0:FUY@2QXJ40Zj^[0:6QX@2[Zj/0VIVI0:>SX`050:6QXAh0oooo3`1f
MWH0201lO7`0M7Ad07=cL`1iNGT0N7Qh07UiN@1hN7P0NGUi0`1fMWH0201cLg<0L71`07IfMP1fMWH0
L71`07AdM01hN7P0NGUi0P1hN7P01023Ph<0NGUi07moO`1iNGT207IfMP0307QhN01iNGT0MWIf0080
MWIf0P1oOgl0201dM7@0MWIf071`L01aLG40LW9b08>3P`1oOgl0L71`201fMWH207moO`0507UiN@1f
MWH0MWIf07IfMP1hN7P01@1fMWH01`1lO7`0Ogmo07AdM01fMWH0N7Qh07UiN@1`L7000P1fMWH00`1c
Lg<0L71`07IfMP0307IfMP0907moO`1iNGT0MgMg079bLP1gMgL0MWIf07moO`1fMWH0Ogmo0080M7Ad
1@1fMWHR0?ooo`00o`3oooo30?ooo`00o`3oooo30?ooo`00o`3oooo30?ooo`00o`3oooo30?ooo`00
o`3oooo30?ooo`00F@3oool2@00008/0oooo0T00002;0?ooo`900000C@3oool005/0oooo00=00000
0?ooo`3oool0RP3oool00d000000oooo0?ooo`2:0?ooo`03@000003oool0oooo04X0oooo00190?oo
o`03@000003oool0oooo00<0oooo0d0000020?ooo`9000000`3oool3@00000D0oooo00=000000?oo
o`3oool0J`3oool2@00000@0oooo00=000000?ooo`3oool0103oool3@0000080oooo0T0000030?oo
o`=000001@3oool00d000000oooo0?ooo`1T0?ooo`E0000000@0oooo@0000400001000000`3oool0
0d000000oooo0?ooo`050?ooo`=000000P3oool2@00000<0oooo0d0000050?ooo`03@000003oool0
oooo04@0oooo00180?ooo`03@000003ooom0000000<0oooo00I000000?ooo`3ooom000000?oood00
00040?ooo`04@000003oool0oooo@00007<0oooo00=000000?oood0000000P3oool00d000000oooo
@00000040?ooo`06@000003oool0oooo@000003ooom00000103oool014000000oooo0?oood00001^
0?ooo`05@000003oool0oooo0?oood000000103oool00d000000oooo@00000050?ooo`06@000003o
ool0oooo@000003ooom00000103oool014000000oooo0?oood00001<0?ooo`00B03oool00d000000
oooo@00000030?ooo`05@000003oool0oooo@000003oool00d0000020?ooo`04@000003oool0oooo
@00007<0oooo00=000000?oood0000000P3oool00d000000oooo@00000040?ooo`05@000003oool0
oooo@000003oool00d0000020?ooo`04@000003oool0oooo@00006h0oooo00=000000?ooo`3oool0
0P3oool01d000000oooo0?ooo`3ooom000000?oood0000001@3oool01D000000oooo0?oood000000
oooo00=000000P3oool014000000oooo0?oood00001<0?ooo`00B03oool00d000000oooo@0000004
0?ooo`=0000000@0oooo@0000400001000000`3oool3@00007<0oooo0T0000030?ooo`03@000003o
oom0000000D0oooo0d000000103ooom00000@000040000030?ooo`=00000KP3oool00d000000oooo
0?ooo`020?ooo`07@000003oool0oooo0?oood000000oooo@00000060?ooo`=0000000@0oooo@000
0400001000000`3oool3@00004`0oooo00180?ooo`03@000003ooom0000000H0oooo00=000000?oo
o`3oool0N`3oool00d000000oooo0?ooo`020?ooo`03@000003ooom0000000L0oooo00=000000?oo
o`3oool0MP3oool01d000000oooo0?ooo`3ooom000000?oood0000000P3oool00d000000oooo@000
00080?ooo`03@000003oool0oooo05@0oooo00190?ooo`03@000003oool0oooo00@0oooo0T00001n
0?ooo`9000000`3oool00d000000oooo0?ooo`050?ooo`900000M`3oool2@00000@0oooo00=00000
0?ooo`3oool00P3oool00d000000oooo0?ooo`060?ooo`900000EP3oool00?l0oooo``3oool00?l0
oooo``3oool00?l0oooo``3oool00?l0oooo``3oool00?l0oooo``3oool00?l0oooo``3oool00?l0
oooo``3oool00?l0oooo``3oool00?l0oooo``3oool00?l0oooo``3oool00?l0oooo``3oool00?l0
oooo``3oool00?l0oooo``3oool00?l0oooo``3oool00?l0oooo``3oool00?l0oooo``3oool00?l0
oooo``3oool00=d0oooo0T00003S0?ooo`00g`3oool00d000000oooo0?ooo`3P0?ooo`00d@3oool2
@00000030?oood0000100000009000000P3oool00d000000oooo0?ooo`03@00000040?oood000010
0000@00000<0oooo0T00003I0?ooo`00d@3oool01d000000oooo0?ooo`3ooom000000?oood000000
0P3oool00d000000oooo@00000020?ooo`04@000003oool0oooo@00000<0oooo00=000000?ooo`3o
ool0f@3oool00=80oooo0d0000020?ooo`06@000003oool0oooo@000003ooom000000P3oool01400
0000oooo0?oood0000030?ooo`=00000f@3oool00=80oooo00A000000?oood000000oooo14000003
0?ooo`=000000P3oool014000000oooo0?ooo`3oool3@0000=T0oooo003C0?ooo`03@000003oool0
oooo00`0oooo00=000000?ooo`3oool0g@3oool00=80oooo0T00000=0?ooo`900000g`3oool00?l0
oooo``3oool00?l0oooo``3oool00001\
\>"],
  ImageRangeCache->{{{0, 449}, {294.313, 0}} -> {-0.178538, -0.0492293, 
  0.00747679, 0.00747679}, {{23.875, 149.25}, {287.688, 
  162.313}} -> {-39.4226, -10.476, 1.19477, 1.19477}, {{161.75, 287.188}, {
  287.688, 162.313}} -> {-204.189, -10.476, 1.19477, 1.19477}, {{299.688, 
  425.063}, {287.688, 162.313}} -> {-368.956, -10.476, 1.19477, 1.19477}, {{
  23.875, 149.25}, {149.75, 24.375}} -> {-39.4226, -175.28, 1.19477, 
  1.19477}, {{161.75, 287.188}, {149.75, 24.375}} -> {-204.189, -175.28, 
  1.19477, 1.19477}, {{299.688, 425.063}, {149.75, 
  24.375}} -> {-368.956, -175.28, 1.19477, 1.19477}}]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
  StyleBox["\t",
    FontFamily->"Times New Roman",
    FontSize->10.5],
  StyleBox[
  "After setting a mouse cursor on a following image, twice clicking the left \
side button of mouse animates the facial changes depending on the lighting \
angles. This is only effective on the ",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"],
  StyleBox["Mathematica",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox[" notebook.",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell[CellGroupData[{

Cell["Do[Show[GraphicsArray[{cAngleG[[i]]}]],{i,rotation}];", "Input",
  CellLabel->"In[40]:="],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0238095 0.952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0238095 0.97619 0.97619 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00751202 0.0192308 0.00751202 [
[.5 1.0125 -17 0 ]
[.5 1.0125 17 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
69.000000 12.812500 moveto
(deg) show
87.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(.) show
93.000000 12.812500 moveto
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
128 string
128 128 8 [128 0 0 128 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
9D9EA7A1979E999BA9949F768B8B8C94878C8C8C8CB39434
AE927F867D8C877B8D8886887C828C878F8A848786878788
77908787938D8D8D8D8D8D888F82878C9082878787878687
8787888784898786888786A6A88A439C828C877C82828A86
86868686918A858D97889590908696858185787F8582807D
AB925E9FAAA6A597
9D9FA29F9EA19995A3A09784798B8C908C8C8C8B8CA0AB3E
9C90818581838781888C87878281838C8F87878787808A8C
7F828D888D8E908C8B8D93858D8D828A8D87878A85878687
878787878686838D87878796B09D4370A587877C82828686
8B8686868F878C87958D929191908C8B80867E7E7D82858F
927B778CB5A6A19D
9D9F9F9D9DA3A39D9CA3A29982768B8C8C8A8D8B888FA76E
4EBB8984817E86878287888688867D8698878486837F8187
8482878D8B888B8D84878D87878E878B888784888A828787
87878787878582878787878796A5815255AB878287807D82
8C82888E8F868C868C8B8C8F8C8F878A8384878481858999
A5737382ADABA397
9B9B9DA097A19B96A39B9DA29F85867D828D878B888B97B0
467096878179828787878D8787867C7F918B87877E877B7E
817E7B828C8D878B8787888787878B91888D8A8D88878489
878287888787878887878787878CA5A94A56A68187868184
838182878F878F878F8C908E908C8F8288848C81987E8E98
81A1737DAE9CA3A3
9D9E9DA49F9EA299A7A19C9B979F958D778588828A848DA9
8D59968788798282877C878D8787818187878388838B807D
8080797985888C8088878F8787878B9193878D9B8C84908A
9084858C8784878B8787838B83878CA5A9428B958A878787
87878B878A878D868B8D958E8F8B8C8787819590948B8B9B
6C9F7181B5A1919B
9DA099A2A19FA09F9BA6A29FA3A198A0887C848889878D9C
AA70758C8A7C817D878780888782878C82838883818D8787
8786837D798087847B89828D888787878D8A8A918B8C8C89
8D8B858D898887888F88878B878A848CA5845D81998F8A86
848A8A8D8A8B8D898D8C91948F8F87868A839FA89E80A394
91A4698EABA29D98
9DA3999D95A397A69BA197A1A19DA3A19D8E807C8A8B898C
9BA775848F86837D8183868788827D82877E83877D91878A
87868789787D75887C897D8A88868F87888A908A878C8B8B
8C8D8B918B898B888B888888878989878AAB8B6B778D8B8B
878F8A908D8B8E8992868F8F8F868C7A818EA891A96E9386
8B9A78AAA69DA395
9DA3A4A29BA597A199A39AA4A3A19EA5A1A19989858F8E8F
8E9F987663B686868082828180797D7D7D7D7D817D8C8D8B
8E8A8A8F8187768181837F857E7F87888C888B8D82888987
8E828D8A878D8988828888888886888D8190AFA071878988
878B8A918E898D90908690908A8272807593A48A8D919085
9A827BB5A79AA49C
9DA299A39DA199A39E9C9E989BA1A59EA5A199A18D978E92
928E998B556D9089807D82827D7B73837D7F817C797C8D8C
8F8A8A8D89847B76818176857E7C7D7A827C82867E868282
877E8A86828687878282828B7F8582877F8194919B857375
999288928D8B8F92918F87866885797874869F8573818891
867D8FA3A59D9A9D
9B9E9F9DA7A19B999E9BA49E9D9BA799A1A997A798A59A9D
A79E9E9DA1706974A975798B7E8075817E888B898378878D
8B91888D8A87877A83877F877E86817C797B737772757B75
78747B75787D767977787D80758A808078827C788C917662
6E43BF83918C8C8D7C747C7C6F81817A6E8187878A7B73AE
886BAF98ABA09E95
A3A0A797A49FA4A09E9E96A09F9C9E9C9BA598A59AA5999E
A29DA397A49C625D987E7D8A82817B7C728085848378848E
878D8B908A87877E7E838787828787878283808A807D8078
7D7F81827D7E8183818787877D87838B7D8B81828283918A
84388361708190726B6854607277947A75A569828F759198
7C8787AA9AA3A3A3
9997A3A199A09B97A0A29F9AA59DA399A0A2A19DA3A19B9D
999DA19DA29B696B5D8379739B827D857385827F887B818E
8787888B8E878F83827E878B8787878787827F808A878B81
807D8486858687827A8F87878783838B7D8C818E87818782
8B8999746159445E6A5F60686D6E7D857CB45E8A9462A19D
73B27DA0979D9BA7
A3A19C9D9DA79D9F9C9C9DA3A198A1A19D9DA197A4A5A19E
9B9D9D999F9B71815968835168AC867E79847E80817F848D
878787878F838B8787828287878787868787877B83838B83
87857D8083838786808C8786877B8A877D87818B87828782
81798385706957515D5C6D656B6977757CA35D7B906B9F86
84AD9B9E94A89B9E
9B9EA19E9BA797A79BA997A79DA397A7A1A19D9FA1A19DA3
979BA0A1979C7D88674577504955C37986797F86827D828D
878787878B8687878787838787878C838B87877E83838783
818781818383837F83878C81897F8B877E818487877C8679
806F6C59555B655C5D56617168747C77827D6A8180868F86
93AB98A096A4A29B
A3A09F9A9AA99BA195A798A1A29DA1A19DA29E9DA79BA39E
9B9F98A29A9E83A975495E5A463848BB8579827B847D8488
8C878787838B8787878782827E878383878B8782827B8387
818181808681818383818F7D877E868D827D83817F7D7C78
6F6F574B62615B6C7158586B7768856F88767B7777996B96
A59F9E98A19DA597
9C9EA39F9BA79BA49BA99D9B9DA19DA2A197A398A1A09D9F
A19DA39A999B83A4735B40604436294BC17986798A7D7D8C
878787878283878B878387878383858487878783877F7D81
8480887F837D8179897F898387838187857A837D777C7777
605149677260477672725E65656877737F708E81987C7C90
A79CA09E9C9BA79A
9DA3989BA19D9B9F9E9EA2A599A599A0A198A59A9BA2A199
A19CA69D9E98928C84634A5B4539302C42C784708D7D8189
8B83878787877E878B7E83877E7F7D84898786897E7F8081
7F7D8383867C8176818188877A8C778C7D7471746969645F
454D466D75684F6F697B6E736A586B7978778A8298868E9A
9991A0A49D9BA79D
9BA1A59BA195A39DA1999EA799A49BA6A19FA79D9C99A2A1
979B9F9E9D969D849D4C5C573F3B3B302428D47C80828187
86848383838B7E878383838781847F7D8384808B837D7D7D
7C7F787B8383787A7F75868076807D7B7D79706F6557564F
414F5E676467687368686B756E7369747385828285988B93
9F9695A39D9BA1A1
9DA19EA5A1999DA4A59C98A19CA29E9D9B9B9EA1A49E9EA5
989C9D9D9E98907D984159573F393F33202028D979867A85
81848383838787877E8383838183837D7F837B8581827E7F
7D7F76777A7F7776837C7E886D7C7D786F7D6D5C4E57355E
50576E656467647D6461616E657477727E818282909E9D98
9CA0A19EA59EA1A7
99A197A99EA59C9D9EA29BA09E99A1A6A2A59D97A0A199A3
A0A19A9B9E9D94868B4B594E48413A2C201E27C879868281
8282897E877E878783837F878381857D83817D817B837D7D
7D7A7A77777977747B846E77737878776472615C32543D54
4C696F60636A6E73767065788169797F8182818C8F8FA296
9F9C9E9EA599A1A1
A19E99A2A0A1A79DA3999BA3A1989E99A39EA29DA19D9DA1
9D9EA1979E989485735D594A4251363321253457BB858287
7C818D7E87838383838180817F83867D807F7F7781748481
7A767A727468787E807865717369746A58624D544F435652
5363665C61637865787C6E797A758A8181828A91988DA5A0
9DA1A59D9E9CA59E
A19D97A2999EA2A0A197A1A1A19D9D9FA599A09BA4A197A4
A599A49B9D989A7C6455604A4E4C333B29333624CD8A828C
7B81897F84857F84858181807F7E83847A7F817D777F7683
7C7977706C6E6E8B825E696E6E61605D4E684748595B5C51
6D6F696160578E5976628662747B818181868BA39897A6A5
95A1A1A199A3A19D
A19DA19DA19D9DA1A199A5A1A1A1989DA79B9A9B99A998A1
9D9DA39C95919869734E554D4C4C313C393A2C16E87D8686
837F847B81877B818383817F827F7D81817A7D7A777F7A77
79776D6E616D80826C61676F695C544253634A4D4F585652
6C6F695E605D7B637A647D7874818F8081949191999BA5A1
97A5A19D9EA1A7A1
A19BA197A7A19EA59EA19EA5A1A19D99A2A29E9E9EA19AA5
97A1A1A197928E616E564F4B4A37344243392922E07A8B7C
7E87817F807F80807D7A857F7B817F7D86768076777A7478
77736F6169687C725D6160635A485446516E4C534A4F624F
64696A6571626F636F6969778674867C8F93A49B94A0A4A1
A5A19E9F9D9BA1A1
A19EA59BA19E9EA59D9EA1A1A1A19EA19A9EA19D9EA59AA2
9CA2A2A19C92835F625A504D4F38384F39282A24E67A8A79
8684817883857E7D7F7A7D817A777A7C797D7478777A7374
6E6F695E6176635D5766586148554B4D506B65584A575E5D
6655716A846E6E5C69765D7394828C8B989791A093A29D9F
A1A19AA1A4A1A4A5
A19DA19EA59D9AA5A19D9EA5A1A19DA19D9DA1A19AA59A9E
A1999EA29B8C776469564C4C4F344B4335202F21E57E8178
817F8877738578777C77747D777A747A747D74717172796F
6E6E645C696A58525554534850524152566D65615B515A55
5E62696088796F62777860778A8196959B989FA0999D9DA5
9EA59D9B9A9CA19E
A1A1A19D9EA2A19EA1A79DA1A19EA5A1A1A1A19EA1A19A9B
A69AA39EA1965B67645E4251443A4F3930273424E0798A7D
857A7F88737F7A7577777472757B71747877776E726D736F
6F65685C715D504E504E494C4B43414C566A6D606C585E4C
555A716E73757768756B73818B869E949F969598A7A19AA5
9DA1A1A19AA1A19A
A19EA2A59A9EA59D9B9EA1A7A19AA5A19EA2A19EA79E9E9E
9D97A5979F8E5F66585945533648483D22262F2DDC718778
867D76817A747D7471787170706C6F6F7973756C6F696D6D
6A6561615A5752494F504A484B45484F51626D6F61695245
53566D687C76767668696D918687A19893A898A19AA59DA1
A19EA5A19D9DA79A
A2A19D9E9E9DA2A3A4A19BA19DA39EA59AA197A1A19D9DA1
9E9DA4999D716B615C4F45553B5337391D222C2ADF708379
7D7A7A74797477746C726F726E6964696D6D756E69696961
64645A674A484653475450303C45575D545B687973717142
48606369648C76686869689A8C988B9F929D9CA797A4A7A1
9EA1A1A19E9FA19D
9DA1A19D9AA09B9B9DA1A1A19B9DA0A599A799A59EA59EA1
A09F97A0916B7156594D48434350342D242A2C2ECA797D7E
7F78767870746E7470686D6F657068647069657469696160
615F506E4337524F46473B3324595C4D6551667379657F50
57675B6F608569695F6C7B908F9D9298A3999CA7979DA5A1
9D9DA79EA19EA5A1
A1A19EA59AA2A1A4A2A59EA5A19C9DA197A3A0A1A3A19AA0
9D9D9D9B7C6C6C5159474C4340462A2E282E2D2EC4787981
7278717B71746F6C70646063665C67616767666863676059
5F57576C3F31555237373039354F695055584F7E78766A61
5C6B62667B765D6F5C727796AB84969B98A79CA19D9AA5A1
A19BA19DA19AA59E
A2A59D9B9FA598A19D9E9EA5A19DA79E9F97A09BA7A19AA2
A19D9F9672685F4F554A475535451839292D293FB4857981
7978757277777374746C625C555C5E605F5C6262655C5C5B
534E53683139514632292F523054695A51535575777F6A66
546456579A765C6F757681A09A8D91A099A4A59EA59DA1A1
9EA5A1A1A19D9E9D
9D9EA29E99A19AA5A19D9DA1A198A59D9EA09D96A99EA199
9C9E9C8376695E5151414C4A46331D3A302B286CA686907F
878487817C7F727A7974726B5A5851565F5B5A5B55605B59
524C48633444552D2F27385F2A535E624C4E596C718A7974
61614B5F80756869896495BD8E93A69BA79AA599A4A1A4A2
A1A19EA5A1A19D9B
A2A199A79EA1A39DA7A1A1A19E9DA79E9EA59E9BA59AA19D
9DA09E7367615F4E504744404C1E2D3A2B2D5E838C8B8D8D
828E7F8D84857E7F767A73746B6958534A59595A59535E55
4C4F3B405E3C6E1F291E2B6C413B5D6D42624C6972818176
6347656273687876806CA9978C9A9F98A59D9DA19D9B9D9A
A2A59DA1A19EA5A1
9D9EA0A19D9CA197A4A1A7A19D97A4A19AA29E9EA59D9B9B
979A95825E635549445048403C1E3B37298662858F958C8F
898F838D8A8A81877F7F747174756964524551535D505951
4B4930347A288928212F194B702A636A486E5760757C9582
6B4558696D647C77757EAF908FA39DA59DA799A5A19EA2A1
9AA2A5A1A19DA1A1
A19DA1A19DA7A19B9D9CA1A19D9F9DA79D9AA19DA1A1A19E
99947C7C576253474049434329263A2E5BBD8E859391958F
908F8789828D858787817D7B7476736B644A5A3C52524F4E
483F35307D3966491B21344A6943505B5750715F6D74888E
754A4F6C5F728A7B6F7DA4A2969B9CA599A59AA59E9EA1A1
9D9D9EA5A1A19EA5
A3A79EA59BA19DA79EA2A59E9C9E9BA79E9EA1A7A19BA999
9A8E7D6C5A5E4F493B493B471B30353FA28C92878D8D958A
988A9098828A858788817C787D7974746B5D644A3C514D44
4B343723707530802234205F438047675F585F6B598A689C
8A404C6C5E6F7C887A81989F9FA39DA6A19EA1A19A9EA59E
A2A59AA2A59EA1A1
9CA59AA5A1A199A2A19DA19D9A9EA09EA19D9CA1A1999E96
9C83865B5F5355433D43382F253B3D8A878B8F8D8D8A9286
918A8A91898288898D8289797E777A77746B645E4A3A404C
3B392C2A4D8A3C57672A4F3B485F574F6567467B5B806989
8D693E5171756984818EA08EA39F99A59E9EA59EA19D9EA1
9AA59D9D9EA1A1A1
9DA19AA5A1A19AA19EA2A2A2A19D9EA19EA1A2A4A2A59D8D
8E85785B575048434343242F282FA3888C888A8D8F878683
84888587877C83828781887E7E78797378716A686546383D
39392D2B3E61784B5D524B4730616A4E5C5354607767747D
848544596A6564878DAE909E989F99A99D9AA599A4A59AA2
A1A1A1A19DA1A19E
A19EA1A1A19EA1A19D9D9AA1A1A19DA19A9D9CA19D9EA291
8284685A4B544436473D222E37758D878E88848789827B7D
7576737777737780747C817A877E7E7377716F6B68664F32
33392B213556874F449C496633425F6E544C655382617C6E
899853616D68667E8DBA91A599A09E9EA59D9DA19DA19AA1
A19EA5A1A1A1A19D
A19AA5A19EA1A1A1A1A19AA5A1A1A1A19D9A9DA2A79A9B8B
89875C5551494F343C2E2C2F3CE18B8B8D8B878780606C7E
71726B6B6B6B5C6D6A6D8C7E7D837E7873746F6969645A48
242D291C2E4C726F3B72705D6047495B65594F5C76736884
7591765B765F74898AA0A4A198A3A4A39DA49F9EA5A19D9E
A59D9EA5A19EA5A1
A19AA59EA19EA5A1A1A19AA5A19EA1A7A19AA09C9DA39186
84725E4C4B4645353E2C2B388C848787878B846B77605A83
585567726E515A565954668C817E827E7377746A6B64605B
3B221E201F4D27BC633BA34F886A4C56684763516972647C
7E8D865069707487AF8C9C9B94A69C9D9E9EA59AA59EA2A1
A19EA1A19E9EA59E
A2A19EA19EA19EA59EA2A19EA29E9DA2A29DA7A197A7848C
7B685D5139493B4122322D62C3878783868B874C6A66627C
786971647558625D794F595B9B80817E7878736E6B696262
53371A2912373E827E427A6D5E8D723F5958604B66756875
769787545A6C6884C298A19697ADA19B9D9DA19D9EA19DA1
A19DA1A19D9DA19D
9DA19DA19AA2A19E9E9EA59A9E9EA19D9A9DA59E9CA27D7C
62614D493647352D312745A78B8A8787866C7D5148575D63
5056624C473A494E4155493F6794957D7D787873666F696A
55502A1415344056816A39A34B8A9F673A614B5F546E6861
8A8D836858745F85B4A39A9C9A9FA9A19EA59EA59DA1A1A1
A1A1A19EA59EA5A1
A2A2A2A59D9AA2A19AA19EA19AA19EA29E9EA29DA0988373
5859443B433B363136309B8C888F888286636B3E39454859
48515B3F453D42473B5C42394967837D7A78767A6A696E6E
5D543C161119364D668E42547959AC8B6F3C5D6054696353
92808F835384659D9E9C979CA79BA2A2A1A19DA19EA5A19E
A5A19EA1A19AA5A1
9D9A9EA59EA19DA19AA59AA59DA19D9D99A39A9AA0927E6D
514A49393B393239353DE6888C8A8A8A83828867564C4352
51485E4F4A424B484C716E7278787D7E7977767A716F696E
64624725170D50364F6F743C7E4B87A58C455D5B4F5E6C61
7A709C8A517565C5A0989897AA9D9D9AA5A1A1A19DA19EA1
9EA59DA19EA1A1A1
A2A19DA19DA19EA59DA19AA59EA2A5A199A1A09B97848663
49433F4039293B3733859D878B898A858C85938D958C8B82
957D878D917F88827E857B8083757D827A77787671746966
6B694D341518473D5E4A7C33506E5F988A725950575A5468
69779C8A577557CD9891A09DA7A1A19AA5A19EA2A2A59DA1
9DA1A1A19DA1A19E
9EA59EA2A2A2A19DA7A19DA19AA19EA59A9D9DA0976C6559
454C313B2D35373736D98B888F8B8A8790858E8D918D918D
8F8387878775817F79857A8A7E8774817A7A7D7371707361
6469543B1F22174E4D535E543E6D5C879A87606655654C65
4F80899362686FBFA4918EB59EA5A19AA59EA19D9DA19EA5
A1A19EA2A5A1A19D
9D9EA19A9EA1A19C9EA5A1A19DA19DA19D9A9D9D8A83534B
4539432A37293E392CF788888F8E89898A8E8D8D8D8B8E8D
85877E917E7A85877B84818B7687867C717A7A776F706F6E
62636047271B1F424B4C4E6040495383798F7B5E4B694379
537A759769569597A5978BAAA1A1A19DA19D9EA5A1A19AA5
9EA59D9DA1A1A1A1
A19DA19D9DA1A1A19D9EA5A1A1A19EA2A2A19D93746F5E41
483E34333730382E5DB98A88908D8D8D8D888B8E8D8B878D
7D817A8D7C75818481808886847F877F7E7C77777174696E
675E564D331D2A324E435D4F58334F4D9C7D747B4F674366
697870966F51B87DBC91A19DA1A1A1A19EA59DA1A1A19D9E
9EA5A19EA5A1A1A1
A2A5A1A1A1A19EA59E9EA5A19EA59D9D99A79E9766595443
3C41352D313B3726C088888A908D8D8D918D898F8D8D8280
797A687E786F7C807D848387848F877F788572737271696F
6E5D5D4F37210F274640593B653A4832AF6B7B9146645851
6868739D79669E87A196BFA1A1A1A1A19AA5A1A1A1A1A19D
9DA1A19AA5A1A1A1
9DA1A1A1A1A19D9EA19DA19EA1A1A1A19CA19D946051423D
3A2D3C2E35362A26F4868A8A938A948C888D8A8A936E75A8
7975684C677B815F8A87848C7F8787877E807D77776F6F69
6E5E5A4D43240F212E404941594A3A49577A847F71506543
6B5E7B957D9866B871B6A1A1A1A1A1A19DA1A1A1A1A1A1A1
A1A1A19DA1A19EA5
A2A2A59EA2A5A19DA19EA2A19EA5A1A1A1A19E8C4F4D4042
31322D36392C253DDC858B8890858E9885908A8C94665A89
877C6D494F62745160808E91878787877F877D7275737169
68695A524632091823384246425B334C21B566709141693D
5C66728E8F9A66A0A1A19EA5A1A1A1A19EA5A1A1A19EA5A1
A1A1A19EA2A59DA1
9D9DA19D9DA19EA5A19A9EA59DA1A19DA7A19D7D423F442F
3B3A2D383A202569BC8B8B8D978D889087898A8A98828F88
8880796E767A7B74626F8A90878A85877F7F877F77747368
60685C564A40071C16423F4B2E6034461CAB607C8D3C6945
59646F8594856E84C2A19AA5A1A1A1A19DA19EA5A19DA1A1
A1A1A19D9AA5A1A1
A1A1A19EA59EA1A19EA19AA5A19DA799A2A59E79373C4432
3438373A331D2BB8878E898D8F908F918E8D85879B868E95
8883847773787A77717A8590878D848A857E7F787D74776B
63605A53493E13071E3E246032572D44366D6F858156505E
4E606392977A8F9BA5A19DA1A1A1A19EA2A59DA1A1A1A1A1
A1A1A1A19DA1A1A1
A1A1A19DA19DA19E9EA59AA2A59C9EA19DA199583C452B39
34393A381A261CFF8A8F8B98908F90908F908882918E9696
8F86827573787C737A808988878E88848786877E78757973
6D6457534D42230818343A42424E2E3F39646F7A83773863
4D5F67908B63ABBE9EA59EA2A2A5A19D9AA5A1A1A1A1A1A1
A1A19EA5A1A1A1A1
A2A2A5A1A19EA59D9DA19D9D9EA59AA5A1A197343A392840
34383715231E29F08F8F8790908F90909090918C858C8E97
888B7F79697979737E878788898D908289848787777A7477
6E7058544B48300924233F3B4342453739646A6E88963155
4A5F6B98976D9EA59DA19D9D9DA1A1A19DA1A1A1A19EA5A1
A1A19AA2A5A1A1A1
9D9DA1A19EA1A1A1A1A1A19EA19EA19EA2A29C2C37333240
35393A171B227EA08D978E8F8F8F958E8E8991908887849A
887E777773777E79828E8B848A8A948287868687777E7A74
6F6F69564A493D0E0E2D254842344C4537617C6B81A03264
366C54A48F86BEA1A1A1A1A1A1A1A1A1A1A1A1A1A19DA1A1
A1A19D9DA1A19EA5
A2A2A2A59DA1A1A1A1A19E9EA2A1A19A9EA182363B2E3F3D
3636221B158C80899295898F95899696968F9090908D8395
907F7C6F737D7D7F868E8B8F89829785908287837E7B7776
6F6A6A614545451F192E31394F344C43385F8D6A7F983D56
336D579FA394A9A1A1A1A1A1A1A1A19EA5A19EA2A5A19EA5
9EA5A1A1A1A19DA1
9EA19AA5A1A1A1A1A19EA19D9AA5A19D9DA13E433C234B35
383A1A2B22E78D9191948F9595898F9093898F8F8F918796
90887F727383807E828D8E958C8E8E898A8E8C878385797A
7372666E4C483F2E262D3042424848404B5F826E75895345
306A6987AEAEA1A1A1A1A1A1A1A1A19DA1A19D9DA1A19D9E
A1A1A19EA5A1A1A1
9EA59DA1A1A1A1A1A19DA1A19AA5A1A19EA51C3E31274D37
3434262162BC8A94908F95958F908E91958E958E89908C90
8F8B8A72737E8A82878690918C958F8B8A93878A84878178
6F776A6A52493C3422292F3E3D50484447876F6E6E7A6736
41586C90BEA9A1A1A1A1A1A1A1A1A1A1A1A19EA59EA5A19D
A1A1A19DA1A1A1A1
9DA19EA59EA5A1A19EA5A1A19DA1A1A19D9E1F4B302F3843
37243534AA8E8A948F8F96968F90908F8D9496968F909088
9888896E71778786888C8E908C9094858E8C898B8788857D
786F6D6A5D483F3429252E3044494A3E3CAA66677570822C
5D546292CEA7A1A1A1A1A1A1A1A1A1A1A1A19DA19DA19EA5
A1A1A1A1A1A1A1A1
A2A59DA19AA59EA59AA5A1A1A1A1A19EA5712F4F383F353B
2C2836929384958E8F8F8F95898F918B8890949095908A8B
938F91776D767F828A7E97908A948C8C9188868A8788867C
8270726A5E56403A2F1E312D3E553F403D9B696E6F4CAE1A
60676184D6A1A1A1A1A1A1A1A1A1A1A1A1A1A1A19EA59DA1
A1A1A1A1A1A1A1A1
9DA1A19EA1A19AA59DA1A1A1A1A1A19AA536513C2F552F3E
223836DD95849C8F95898F978E8C91808F8A8C8D9596838E
948E917D6A79747E81828C8C8C8A8C889188868889888581
777F6F6E63564639331A20333A4F483F4391656D732ABD1F
47767C89C6A1A19EA5A1A1A1A1A1A1A1A1A1A1A19AA5A1A1
A1A1A1A1A1A1A1A1
A1A1A19AA5A19D9EA5A1A19EA2A2A2A1A117863544413D33
1D5568957D95998E968F8F8D8E8A8C7E7887928D8E958590
998F9176707079757B88928987867F818386808C87928686
7A81706D655A49433327112B344E464D388E71557326C326
368581A0BBA1A19DA1A1A1A19EA5A1A1A1A1A1A19DA1A1A1
9EA5A1A1A1A1A1A1
A1A1A19DA1A1A19DA19EA59AA19D9DA1A60868334B3C471A
3E3FD26785A2978E8F8F8C867D737C98786C94869D8C8188
998F90756A6773758873947B8079746A778073787F928279
8181776E63584E3D3A312124294B3F503D7A6F536031C226
379477B4C09AA1A1A1A1A1A19DA1A1A1A1A1A1A1A1A1A1A1
9DA1A1A1A1A1A1A1
A2A5A1A1A19EA59EA59DA19DA1A1A1A17040512E43364C1A
4F758B587BA692948F887F66787E5D466571877186B28886
9D90907D6F6170638C427D858A8442437166656673958779
7A797273635B4D443A31381B234B3D484D6A6B4B5C34C723
48916EB7B4A1A1A1A1A1A1A1A1A1A1A1A1A1A19EA5A1A1A1
A1A1A1A1A1A1A1A1
9DA1A1A1A19DA19DA1A1A19EA5A1A1A134643F372345481F
28F4706975A1908B8A7D5E6180873C433D666B7A629D8696
9C908B837466655E724D2FAC8143533D683E7E42527E8C78
7F796F6F69544C483733290E1F4F43335E6A64475F3EAC22
7B8576CEA1A1A1A1A1A1A1A1A1A1A1A19EA5A19D9EA5A1A1
A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A19EA5A19DA1A1A1A63F34383C21494133
34D8656E859C968878684A30AFA1356A08773775707F9195
979087827770535A50784961D3228F0A7837961B4E707875
847873636E594B40393617131C2B4E3163575F4F5945A01C
87818DC7A1A1A1A1A1A1A1A1A1A1A1A19DA1A1A19DA1A1A1
A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A19DA1A1A1A1A1A169C33E39302C413D44
5CB0626F82988F7A6E582E3F584328493054385E6D7A8796
919588827C795E574F545C5D7B1E3824353E44383A696665
7B7872605E5B4143403223162A2A333A60564E4E654B9723
777AB4AEA1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1
9EA5A1A1A1A1A1A1
A1A1A1A19EA5A1A19EA5A1A1A1A1A12A975E343347383642
7A96646F819A8A7D6D582E3C3F302D333E58596971838293
90908882827C6A5E5D504C466A3A2C2D2830365651585E66
6F6F6769594C3C423D3A2C1B2D272939625B4844655E892F
737ECBA9A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1
9DA1A1A1A1A1A1A1
A1A1A1A19DA1A1A19DA1A1A19EA5A1373C5232333F392D56
707D7169849D8B8585705E4C3C35383D3C4A547884959188
94908D8284837366715F6A485753584B3D3A3D5267636064
6E6B6261624E3846382D2F1E2D352C2D636C42466D688833
75A2B29AA1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1
A1A1A1A1A1A19EA5
A1A19EA5A19EA5A1A1A1A19EA1A1A69214502331304D1E52
6A796E6084A28297958B85877F7A63676E6B67A18390908C
9389918B878A6E6659506A6A7C8768656469726E787A736E
6763735C5954433F3A351F202432203D4F6A4845786A9433
7BC9B4A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1
A1A1A1A1A1A19DA1
A1A19DA1A19DA1A1A1A1A19DA1A19FBA0241212F36462C4D
546B6F617CAA7E8A999A8E908B626956577163828695958B
9A89918F8C8D8172543D3A44597CA68E9283817680757465
566F615E514D4D3D2B331F2620203B3F4D5C4A3E7C66954B
71DCA1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1A1A1A19EA5A666EC003031322649344C
4A506C6679A58A5E8A9589826A5C71684B6D898B8B8F958F
8F8F9090918B8986775A35353C4657766E838879766A6B6B
6068625B4A484D384214352D261D2559515A4B42776E6455
A8C2A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A19EA5A1A1A1A1
A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1A1A1A19AA5A847742D3545362C393744
47475B5F889C9161655F676265636C8B8F8F959595959595
888F958E8F8A8C8B8D86796E5D493A4B39485B605B675D5A
696C625C4A4C5132332E2C2816171D5F54455D4379724464
C9ADA1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A19DA19EA5A1A1
A1A1A1A1A1A1A1A1
A1A1A1A19EA5A1A19EA5A19DA1A14F2C3332603B35393346
43495B558BA28C8F8773645E758F9B959595959595959495
899595958F90908F908D83878882868665564F4D51666863
6D6363595054523E282D1E1715151C853C4080376D88337F
DCA1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A19DA1A1A1
A1A1A1A1A1A1A1A1
A1A19EA59DA1A19EA1A1A1A1A1A15D243E3F6E3F37413A43
4246624F8AA18E8B8C96908E958E8F979A9595909A959595
8A949B8F8F9589908F908A84908287867D8C7C7E7372736B
726063564956543F45251B1E18251BA03F388C42509F32A0
D59AA1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1
A1A19DA1A1A1A19DA1A1A1A1A1A15C154941604444413D3D
3F405D5379A8938F8C92968F949B8E8B9A95958F95959595
8F8E958E8E8F8F908E9191898D82878583827D7A74726E6E
6B6763544F594D4436252B2313181DA84A408642428F3CE0
ACA1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1
A1A1A1A1A19EA5A1A1A1A1A1A1A17E0E3F42474A4A3D433B
413B61556E998C958C8D95908E969B8F95959590959A9595
95958F96968F8F8A908D8D8A8A87877E8A81827A73796F71
636F615B4F544B3D332534181415287C74447E4644557BD7
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A19EA5A1A1A1
A1A1A1A1A1A1A1A1
A1A1A1A1A19DA1A1A1A1A1A1A1A1A20C4B374749493E3E3F
3D475B696B8F8C958C9190908F939590959A958B95958F9B
9595898F8F908F888C888D88848787778081827E74767072
64645B5D5A50473A28351D1A1A142370814A81564E3CBFBF
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A19DA1A1A1A1
A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1AE0A35444E4B414A3A41
4B44576B6F8391929291919590959A8F8A979A8F8F979390
9496908E9090908D95888D858D82877F787D7E7A76776F72
636B5B5A5D494D3D2C2D1A150F0F44526D507E5E6A3FD0A1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1AE1455483D4C42433E47
34525E686684918E918E90909095958F958F9590938B9496
8A8E90908F90918C908C838A8E84877F8978827879776F72
5C70575A504941373D21140E1F0C5F4D534C86677A8CB5A1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1
A1A19EA59EA5A1A1A1A1A1A1A1A1A81A2C3F4141413F4341
4047616B6C7A908E8F92908F919A958A9A909A8B94919390
8F8F90908F8F8F91908A8A89858787778F757E737878736E
617053574C4D43332C24121421126A4C5143826C73CAA1A1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1
A1A19DA19DA1A1A1A1A1A1A1A1A1A192183B3D36403B3943
4B4D6465787B8C8E918E988E919595909496958F8E8A9696
8A8F909090908F908A8D8D8D828D827E8779797377737D6E
6C6357584D43462C261B1A0E1D147B464B48887A82C2A1A1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A81F23393A3C3C3A3B
4357626A78838A8E9389958E90968A968E9595958F958A94
968A918F919090908590888A888A8786877A7E7477737373
6867595456463B2325181F111C1A805537577C95ACA19EA5
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1
A19EA5A1A1A1A1A1A1A1A1A1A1A1A1A16C1330393E3C3F3E
3A57656A787F91888E9093948F958F959A909A8F90958F90
948F918F908F919088918A8C87858787817E7D7573786E6F
695D624E50473B23251C1B1F1F14766A3C657A9AC1A19DA1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1
A19DA1A1A1A1A1A1A1A1A1A1A1A1A1A19D183631413C3A42
3E535C7A8284878E8D8B9090908F9096958A978F8F908F90
908F8F91908F908D8D8D888D868787887C817D7A7678706F
645B5E4F4B3F3426291E1A23150E735C4A7189B2A9A1A1A1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1401D283E444139
40545E6C82928B888D938F93948F8F96978F8F968A8E908F
90908C958D91918D90858E848787878084807A767D6E7474
59615454413B3032232518160D2B7848527484D49EA5A1A1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1
A19EA5A1A1A1A1A1A1A1A19EA5A1A1A1A1AE6B341D494146
414B6272738A978887938B908F8C938F91908F95908F8F91
90908C90888D8D908D848D878786877A7D817D78786A7766
625E4C453E412C2B291E200F0C6B5C4463719EC09DA1A1A1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1
A19DA1A1A1A1A1A1A1A1A19DA1A1A1A1A1A8A89A1E2D473B
4D475F6F78839086908D938F918F909490908D9590908C95
8B9390928D8D8A8E8D8787878886877B7C7E7E78786A6F6B
58574B423D40391F281F150E5D4F4E44707DABAD9EA2A5A1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1AE46114E51
375B566B78868B8489878E908A908890968D909090908C8D
8B908787938790828787888787878181797E7A777665766C
58514A473B36403F131619394D6747507397BCA59AA69AA1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1AE5B1D354A
4663556B7882828F8E86888F8B9B868E918D919191919585
8D8F8D8785908D8787878788868778837E787977705C6D5F
5452484441383C2F2F1F2F365E505A5A7C8BCBA696A8A1A1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1AE474F1F42
444F5D6B757C89858C8C809587938A8A8D8F908D90849586
8A87808680898F8783848A84868777807C7378736A67615B
4D5444353E37392A36246633584D7E5C919EA1A89EA5A1A6
9AA1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A69AA1A1A1A1A1
A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A8585B0C3C
55385D646B7E817F878980928A8A8D8C838A8D8E91878C87
83827B7F7E828982838083798280718073736D70605E605E
4F50403D3C36483131416A44575A7F757FCBA5A19DA69AA8
A1A1A1A1A1A1A1A1A1A1A19EA5A1A1A1A1A8A1A1A1A1A1A1
A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A18E57212D
4849495E637F8487768282879286878B8683888888838386
837E747A767C7E787B7778746F7A717671696A71615B594F
4C5644394C41354C424B5C4C6A5D8E8A9AA3A1A1A1A8A1A1
A1A1A1A1A1A1A1A1A1A1A19DA1A1A1A1A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1612B2D
394D4C595E5E78828B7E8583868388888579827B88876C79
777966776375677A5D795D725D656F636661615D6A645054
455240425354302F4D65574D69717F85C9A1A1A1A1A1A19E
A5A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A69AA1A1A1A1A1
A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A16532
1A3F3D605F4777718C82818781827B807A7B767378817374
6772616A5D6A5E6064664E58674D6B505D5E5B574D60595E
5155494B3D4F4A3A465C5B6A76756CBAA1A1A19EA5A1A19D
A1A1A1A1A1A1A1A1A1A1A1A1A19EA5A1A1A8A1A1A1A1A1A1
A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A19EA59EA5A1A1A1A1A1A1A1A1A1A1A1A195
2B4C454E625B64658D7F8D8D827C7B7472766778796D6D76
62625D615075506456575D47526A4F5A4F565B5B37505953
4754574446414E4856616F6B777C7FBFA1A1A1A29AA1A1A1
A1A1A1A1A1A1A1A1A1A1A1A1A19DA1A1A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1
A1A19EA5A1A1A19DA19DA1A1A1A1A1A1A1A1A1A1A1A1A1A1
4B1B614B5476756980817B7C7C777C6972735D706B706270
5E694F565751665E6749635550753C605562545148414A40
4453454247445055646C8660815DDEA1A1A1A1A8A1A1A1A1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1
A1A19DA1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1
A83626494E6F636775797B796773756C67715E675A656A5D
56634761583B3F6D47695157574C4F59304A5C444643463D
444441384A47704B777E4B8B638CC79AA1A1A1A1A1A19EA5
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1
A1A83947426C5E7690847B7E63636B666B6B615F61615A62
5843684D49672A4A574A50564743423D3D3A4F3A414A4340
414A544E4D5E6F81705D487E4EE0A8A1A1A19EA5A19EA1A1
A1A1A1A1A1A1A1A1A1A1A1A19EA5A1A69AA1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1
A1A165175A68415D78887E756E4F6A5D71675A5067605267
5451465E495456365348404B3F3B3E383D363A4340413F3D
4553525B5B80745A705F6C6289AAA2A5A19EA1A19EA1A1A6
9AA1A1A1A69AA1A1A1A1A1A19DA1A1A8A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1
A1A1A81D20408160676D90736A416852626A564D655D4D63
4F60356149483F39623443443F3A3639302D363738424D38
4A66685470646B4D46794FBAA69B93A5A19DA1A19DA1A1A8
A1A1A1A1A8A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1
A1A19EA53E0638756F6D90816A40536E4C675B4D4A664E47
5D573A5B53493D204C4156333E2D42302B262E292A404F59
5654737A6C516E654E5870D5A8A89DA1A19EA5A69AA1A1A1
A1A1A1A1A1A1A19EA5A1A1A1A1A1A1A1A1A69AA1A1A1A1A1
A1A1A1A1A1A1A1A1
A1A1A1A1A19EA5A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1
A1A19DA1A8351444557783887B3F4368624F5E6044505C48
4F54534B4A5C49303B33444939354335432933373B444A65
70754C7D512F63656551B2A1A1A1A1A1A6969EACA1A1A1A1
A69AA1A1A1A1A19DA1A69AA1A1A1A1A1A1A8A1A1A1A1A1A1
A1A1A1A1A1A1A1A1
A1A1A1A1A19DA1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1
A1A1A1A1A1822127444F5A7F79762B546559465040424950
494F574747615746493250353D50443E4B464A4E5E4E5D76
5E805B683B4C5D585FBA9AA69F9A9EAB9EAB969EA5A69AA1
A8A1A1A1A1A1A1A1A1A8A1A1A1A1A69AA1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1
A1A1A69AA1A1742A364A4A6263864E3351695243522F4244
504B53385E506A4A584C423A3F594D564D55586E6C614F6F
654E3E535857576C91A1A1A8AE9F96A8A2A1A19DA1A8A1A1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A8A1A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1
A1A1A5A5A19EA565282D58666671764F3463475F4F493E38
443D563A62507554816340394F4D525E6D5E557459565D4C
46403F56604F56BCA1A1A69AA8A8A1A1A8A19EA5A1A69F9A
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1
A1A19DA1A19DA69A6E2621534E7E8C744C47515656515D4A
302D51375E66725D73A87C6B7E7A6C66727B756B524C4F3B
40514F6E55658FA8A19EACA19EA2A5A1A19EA1A1A1A8A8A1
9EA5A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1
A1A1A1A1A1A1AE9AA19B45183B6C788E874B626555685C63
6B32431E3A5A6C5E647A7F7E8A7E6B8F5B5A615944503F54
4B50565FA64AA1A697A1A1A19D9AA5A1A19D9EA5A1A69AA1
9AA5A19EA5A69AA1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A69AA1A1
A1A1A1A1A1A1AE9AA1A1A83C24255F858E857C846B887E6E
9186A19E8C948D77818674759F665E72455B46535353515A
5655717EA89EA5A5A1A1A1A1A19DA19EA5A19DA1A1A8A1A1
9DA1A19DA1A8A1A1A1A1A1A1A1A1A69AA1A69A9EA5A1A1A1
A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A8A1A1A1
A1A1A1A1A69AAE9F9AA69AA1921F2461719A88958D8E8E87
8E838E82818F998586827C56717653654B633862635E6861
6E7D75A1A19AA59DA1A69AA69AA19EA1A1A1A1A1A1A1A1A1
A69AA1A1A1A1A1A1A69AA1A1A1A6A1A1A1A8A696A1A1A1A1
A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1
A1A1A1A1A8A1A8A8A1A8A19EAC9A3D422F6377A08F918E8E
8B8AA48C8C89877F7E898560575060684B74476466597E82
5F8EA1A1A19DA69AA1A8A1A5A5A1A29AA69AA1A19EA5A69A
A8A1A1A1A69AA1A1A8A1A1A1A1A8A1A1A69FA697A5A1A1A1
A1A1A69AA1A1A1A1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A69AA1A1A1
A1A1A1A1A1A1A1A1A19EAB96A1AE9AA1533C44497DA19093
9C848E89847C646A596F6A7D6A336A6D56626D958B58629B
9AA1A1A69AA1A8A1A1A69A9DA1A1A8A1A5A5A1A19DA1A8A1
A69AA69FA69F9F9AA1A1A1A1A69AA1A1AEA6A1A29AA1A1A1
A1A1A8A1A1A1A1A1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A19EACA1A1A1A1
A1A1A1A1A1A1A1A1A19DA8A1A1A8A1A1A69AA653534E7690
809E9A90998B847E615F5B7D8267697D8E786C8095AEA69E
A5A1A1A8A1A1A19EA5A89EA5A1A19EA59DA1A1A1A1A19EA5
A8A1A8A8A8A8A5A5A697A5A1A8A1A19EACA8A1A89EA5A1A1
A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A19DA69AA1A1A1
A1A1A1A1A1A1A1A1A1A1A1A1A19EA5A1AE97A9A5A1655D76
647185809C8688959999898C898C7A63718095A1A1AEA696
A69F9F9AA1A1A19D9EA2A1A1A1A19DA19EA5A697A5A19DA6
9AA1A1A1A1A19DA1A8A29AA69AA1A19DA1A1A1A1A29AA1A1
A1A1A1A1A69AA1A1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A89EA5A1A1
A1A1A1A1A1A1A1A1A697A5A1A19D9EA5A89D9DA1A1A19D9D
A28E958E9C947E76768289767D82959DA1A69F9AA1A8AE9A
A8A8A89EA5A69AA1A296A1A1A69AA69AA29AA5A1A19EA5A8
A1A1A1A1A1A1A1A1A1A5A5A8A69AA1A1A1A69AA1A8A1A1A1
A1A1A1A1A8A1A1A1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A19DA1A1A1
A1A1A1A1A1A1A1A1A89DA1A1A19EA1A19EAB9AA1A19EA59E
ACA1A697A5A19D9D9D9DAE9AA19EA5A1A1A8A8A1A69AAE9A
A1A19EA69AAE9F9AA8A1A1A1A8A1A8A1AE979EA59EA1A1A1
A1A1A1A1A1A69AA1A19DA1A1AE9AA1A19EACA69F9AA1A1A1
A1A1A1A1A69A9EA5
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A69AA1
A1A1A1A1A1A1A1A1A1A1A1A1A19DA1A69BA1A1A19EA1A1A2
9AA1A8A29AA1A69AA1A1A5A5A19DA1A1A19EA5A6A1A1AE9F
9AA19DA5A5A8A5A5A69AA1A1A1A69AA1A89D9DA19DA1A1A6
97A5A1A1A1AE9AA1A69AA19EACA1A1A19DA1A5B29AA1A1A1
A1A1A1A1A8A1A29A
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A69AA19EACA19E
A5A1A1A1A1A1A1A1A1A1A19EAB9AA1A8A5A5A1A19D9EAB9E
A5A1A1AE9AA1A8A69A9EA1A19EA5A1A1A19DA1A8A1A1A8AE
9AA19EA1A69A9DA1A5AB9F9AA1A5AB9AA1A1A1A69AA1A1AE
96A1A1A69AA8A69AA8A69F96A1A69AA1A19EA1A8A1A1A1A1
A1A1A69AA1A1A8A1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A8A1A19DA1A696
A1A1A1A1A1A1A1A1A1A1A19DA8A1A1A19DA1A1A1A19AAC9D
A1A697ACA69AA1A8A1A29AA696A1A1A1A1A19EA5A69AA1A8
A1A19DA1A8A1A1A19DA8A5A5A19DA8A1A19EAB9EAB9AA1AE
9AA19EACA1A1A8A1A1A8A8A1A1A8A19EA59DA1A1A1A1A1A1
A19EB29AA1A1A1A1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A69AA8A1
A1A1A1A1A1A1A1A1A1A19EA5A1A1A1A1A1A1A1A1A19AA2A5
A1A89D9EB29F9AA1A69EA5A8A1A1A1A69A9E9EA5A8A697A5
A69AA69AA1A69AA69AA19DA1A1A69AA1A19DA89AACA69AA8
A1A696A1A1A69AA69AA1A697A5A1A19DA1A69AA1A69AA1A1
A19DA8A1A1A19EA2
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A8A1A69A
A1A1A1A1A1A1A1A1A1A19DA69AA19EA59EA5A1A1A19D9DA6
9AA1A19DA8A8A19EB296A1A1A1A1A1A8A19D9DA19EACA29A
AE9AA8A19EB297B29AA1A19EA5A8A1A1A1A1A19DA69EA2A5
A1A89EA5A1A8A1AE9AA1A89DA1A1A1A69AA8A1A1A8A1A1A1
A1A1A1A19EA5A296
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A89E
A5A1A1A1A1A1A1A19EAB9AA89EA59D9E9EA5A1A1A69F9AA8
A19EA5A1A1A19EA1A8A69A9EAB9AA1A1A1A1A69AA29AA5AB
A19EA59EA1A8A2A1A19EA59DA697AB9A9EA59EABA1A296A1
A19EA1A1A1A1A1A8A1A1A1A1A1A1A1A8A19EA5A1A1A1A1A1
A1A1A1A19DA1A8A1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A19D
A1A1A1A1A1A1A1A19DA8A1A1A29AA6969AAB9F9AA5B29AA1
A19DA1A1A1A1A29F9AA8A19DAE9AA1A1A1A1A8A6A1A19DA8
A1A29F9B9F9AA8A1A19AA5A6A19DA8A69B9F9BA1A1A8A1A1
A1A29F9AA1A1A19EA5A1A1A1A1A1A69AA19DA1A69AA1A1A1
A69AA69AA1A69AA1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A69AA69AA19E
A59EA5A1A1A1A1A69AA1A1A1A8A1A5A59AACA5A59DA8A1A1
A1A19EA5A1A1A8A8A1A69AA1A8A1A697A5A69FA1A1A1A1A1
A1A8A8A8A8A1A69AA19DA1A89EA5A1A8A8A8A8A69AA69AA1
9EACAE9AA1A1A696A1A1A1A1A1A1A89EA59EA5A8A1A1A1A1
A8A1A8A1A1A8A1A1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1AE9AA8A69A9D
A19DA1A1A1A1A1A8A1A1A1A19EA59DA19DA19DA69AA69AA1
A1A19DA1A1A1A1A1A6A69AA1A19EAC9DA6A6A1A1A1A1A1A1
A1A1A1A1A1A6A69F9AA1A1A19DA1A1A1A1A1A1AE9FA69AA1
9DA1A8A1A1A1A8A1A1A1A1A1A1A69A9AA59AA5A1A69AA1A6
97A5A1A1A1A1A1A1
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[40]:=",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`004`3oool209fMW@80WYjN0P2WYjL20:6QX@80UiNG
0P2NWYh209VIV@80Vi^K00<0ZJVY09BDU02DU9@00P2OWil207IfMP@0Rh^;0P2<S8`209BDU080QhN7
202<S8`20;>c/`80U9BD0P0d=3@00`2^[Zh0TY:B09:BTP0207moO`80QXJ60P1mOGd208b<S080QhN7
0P1kNg/208f=S@80R8R80P26QXH208R8R080O7al0P22PX8208b<S080QhN700<0Shn?08Z:RP2:RXX0
0P24Q8@208N7Q`80QXJ61027QhL208R8R080MgMg0P2@T90408N7Q`80Ti>C2`2=SHd208R8R080Shn?
0P22PX8208N7Q`80S8b<0P2@T90208:2PPP0QhN70P26QXH508N7Q`80R8R80P27QhL208B4Q080RHV9
0P27QhL208J6QP80R8R80P27QhL208J6QP80YZJV0P2XZ:P208Z:RP80@d=30P2LW9`00`22PX80S8b<
08b<S00208N7Q`80O7al1022PX8208Z:RPX0QXJ60P2ATI4208Z:RP80QHF50P2=SHd00`2GUiL0R8R8
08R8R00209FEU@@0T92@0P26QXH209JFUP80QHF50P21PH4208F5Q@80N7Qh0P1oOgl208F5Q@80PX:2
0P20P80207emO@030:^[Z`2BTY80TY:B0080GUiN0P2OWil20:ZZZP80YZJV0P2UYJD209NGUaD0oooo
000C0?ooo`80WIfM0P2NWYh20:NWY`80XJ6Q0P2GUiL209jNWP80VIVI0P2KVi/00`2YZJT0U9BD09BD
U00209nOW`80MWIf102;Rh/208b<S080U9BD0P27QhL808b<S080/k>c0P2DU9@203@d=0030:j^[P2B
TY80TY:B0080Ogmo0P26QXH207emO@80S8b<0P27QhL207]kN`80SHf=0P28R8P208J6QP80R8R80P1l
O7`208:2PP80S8b<0P27QhL00`2?Shl0RXZ:08Z:RP0208B4Q080QhN70P26QXH408N7Q`80R8R80P1g
MgL2092@T0@0QhN70P2CTi<;08f=S@80R8R80P2?Shl208:2PP80QhN70P2<S8`2092@T080PX:22027
QhL208J6QPD0QhN70P28R8P208N7Q`80Q8B40P29RHT208N7Q`80QXJ60P28R8P208N7Q`80QXJ60P2V
YZH20:RXZ080RXZ:0P13@d<209bLW00308:2PP2<S8`0S8b<0080QhN70P1lO7`408:2PP80RXZ:2P26
QXH2096AT@80RXZ:0P25QHD208f=S@0309NGU`28R8P0R8R80080UIFE102@T90208J6QP80UYJF0P25
QHD20861P@80QHF50P1hN7P207moO`80QHF50P22PX820820P080OGem00<0Zj^[09:BTP2BTY800P1N
GUh209nOW`80ZZZZ0P2VYZH20:FUY@80UiNG5@3oool001<0oooo0P2MWId209nOW`80XZ:R0P2OWil2
09jNWP80XJ6Q0P2IVIT209FEU@030:>SX`2PX:00X:2P0080UiNG0P24Q8@207UiN@80Rh^;0P2<S8`2
092@T0H0S8b<0P2;Rh/208b<S080X:2P0P2[Zj/203hn?P0309bLW02@T900T92@0080PH610P25QHD2
0861P@80Ph>30P27QhL20861P@80R8R80P2<S8`408N7Q`80PX:20P21PH4208>3P`80S8b<00<0Shn?
08N7Q`27QhL01P27QhL20820P080RXZ:0P2<S8`207moO`80PX:20P2=SHd208R8R080SHf=0P2>SXh2
092@T080S8b<00<0Rh^;08f=S@2=SHd00P2CTi<208F5Q@@0SHf=0P22PX8208Z:RP80SHf=1027QhL2
08Z:RP80QHF50P27QhL208J6QPT0QhN71026QXH208>3P`80SHf=1P27QhL209JFUP80/;2`0P2MWId2
04=3@`80L71`00<0YJFU08N7Q`27QhL00P27QhL207alO0@0PX:21026QXH208^;R`H0QXJ60P2?Shl2
08N7Q`80S8b<0P27QhL00`2EUID0SHf=08f=S@0209:BTP@0TI6A0P2@T90208b<S080Rh^;0P20P802
08J6QP@0OWin0P1mOGd208:2PP80QHF50P2?Shl00`2BTY80Ng]k07]kN`0207MgM`80S8b<0P2e]KD2
0:JVYP80XJ6Q0P2MWIdE0?ooo`004`3oool209fMW@80WinO0P2RXZ8209nOW`80WYjN0P2QXJ4209VI
V@80UIFE00<0Xj>S0:2PX02PX:000P2GUiL208B4Q080NGUi0P2;Rh/208b<S080T92@1P2<S8`208^;
R`80S8b<0P2PX:020:^[Z`80?Shn00<0W9bL092@T02@T9000P21PH4208F5Q@80PH610P23Ph<208N7
Q`80PH610P28R8P208b<S0@0QhN70P22PX820861P@80Ph>30P2<S8`00`2?Shl0QhN708N7Q`0608N7
Q`80P8200P2:RXX208b<S080Ogmo0P22PX8208f=S@80R8R80P2=SHd208j>SP80T92@0P2<S8`00`2;
Rh/0SHf=08f=S@0209>CT`80QHF5102=SHd208:2PP80RXZ:0P2=SHd408N7Q`80RXZ:0P25QHD208N7
Q`80QXJ62@27QhL408J6QP80Ph>30P2=SHd608N7Q`80UYJF0P2`/;0209fMW@80@d=30P1`L7000`2U
YJD0QhN708N7Q`0208N7Q`80O7al1022PX8408J6QP80Rh^;1P26QXH208n?S`80QhN70P2<S8`208N7
Q`0309FEU@2=SHd0SHf=0080TY:B102ATI42092@T080S8b<0P2;Rh/20820P080QXJ6101nOWh207em
O@80PX:20P25QHD208n?S`0309:BTP1kNg/0Ng]k0080MgMg0P2<S8`20;Fe]@80YZJV0P2QXJ4209fM
WAD0oooo000C0?ooo`80WIfM102OWil409fMW@@0Xj>S0P2MWId00`2LW9`0Xj>S0:>SX`020::RXP80
VIVI0P22PX8207IfMP80Rh^;102<S8`208Z:RP80SHf=0P2;Rh/208R8R080Shn?0P2WYjL206i^KP03
04i>CP2k^k/0^k^k0080RHV90P24Q8@20861P@80OWin0P26QXH208N7Q`80PX:20P27QhL208R8R080
QXJ60P28R8P208J6QP80OGem0P26QXH00`2HV9P0QhN708N7Q`0208B4Q080QXJ60P23Ph<207moO`80
PH610P27QhL208B4Q080PX:20P27QhL208f=S@80Rh^;0P28R8P208^;R`80SHf=00<0Q8B408N7Q`27
QhL00P2=SHd408N7Q`80SXj>0P27QhL208^;R`80R8R80P27QhL208B4Q080R8R80P2:RXX208:2PPd0
QhN70P25QHD208:2PPX0QhN70P2FUYH20:FUY@80PH610P1BDU800`1EEED0Zj^[0:^[Z`0208N7Q`80
PX:20P27QhL20820P080OGem0P22PX8208b<S080PX:20P28R8P208j>SP80Shn?0P26QXH208b<S080
QXJ600<0S8b<08^;R`2;Rh/00P2<S8`208n?S`80S8b<0P2?Shl208N7Q`80RXZ:0P23Ph<208B4Q080
QhN70P24Q8@20861P@80QHF50P29RHT209VIV@030:FUY@1cLg<0Lg=c0080Lg=c0P22PX820:f][@80
Zj^[0P2SXj<209NGUaD0oooo000C0?ooo`80WIfM102OWil409fMW@@0Xj>S0P2MWId00`2LW9`0Xj>S
0:>SX`020::RXP80VIVI0P22PX8207IfMP80Rh^;102<S8`208Z:RP80SHf=0P2;Rh/208R8R080Shn?
0P2WYjL206i^KP0304i>CP2k^k/0^k^k0080RHV90P24Q8@20861P@80OWin0P26QXH208N7Q`80PX:2
0P27QhL208R8R080QXJ60P28R8P208J6QP80OGem0P26QXH00`2HV9P0QhN708N7Q`0208B4Q080QXJ6
0P23Ph<207moO`80PH610P27QhL208B4Q080PX:20P27QhL208f=S@80Rh^;0P28R8P208^;R`80SHf=
00<0Q8B408N7Q`27QhL00P2=SHd408N7Q`80SXj>0P27QhL208^;R`80R8R80P27QhL208B4Q080R8R8
0P2:RXX208:2PPd0QhN70P25QHD208:2PPX0QhN70P2FUYH20:FUY@80PH610P1BDU800`1EEED0Zj^[
0:^[Z`0208N7Q`80PX:20P27QhL20820P080OGem0P22PX8208b<S080PX:20P28R8P208j>SP80Shn?
0P26QXH208b<S080QXJ600<0S8b<08^;R`2;Rh/00P2<S8`208n?S`80S8b<0P2?Shl208N7Q`80RXZ:
0P23Ph<208B4Q080QhN70P24Q8@20861P@80QHF50P29RHT209VIV@030:FUY@1cLg<0Lg=c0080Lg=c
0P22PX820:f][@80Zj^[0P2SXj<209NGUaD0oooo000C0?ooo`@0Vi^K0P2MWId20:2PX080UiNG0P2Q
XJ4209^KV`80UYJF00<0Xj>S09^KV`2KVi/00P2MWId20::RXP80WinO0P25QHD208J6QP80OGem0P22
PX8208f=S@80QhN70P2;Rh/208R8R080Rh^;0P2GUiL20;2`/00304I6AP1`L700L71`0080UYJF0P27
QhL20861P@80NGUi0P22PX8608N7Q`80SHf=1027QhL208J6QP80O7al0P1oOgl00`2ATI40Rh^;08^;
R`0408N7Q`80OWin0P27QhL207]kN`80OWin0P21PH4207inOP80Ng]k0P22PX8208b<S080SHf=0P27
QhL208^;R`<0QhN70P28R8P608N7Q`80Rh^;0P2ATI4208R8R080SHf=0P2:RXX208f=S@80R8R80P27
QhL208B4Q080RHV900<0QhN708:2PP22PX800P27QhL208R8R0H0QhN70P28R8P:08N7Q`80S8b<0P2U
YJD20:VYZ@0304Y:BP1FEUH0EUIF0080YZJV0P21PH4208N7Q`80QXJ60P21PH4208B4Q080Ph>30P21
PH4208:2PP80QhN70P2?Shl208N7Q`80Shn?0P27QhL00`2?Shl0S8b<08b<S002092@T080SXj>0P2@
T90208b<S080Shn?0P22PX8208R8R080Q8B40P2<S8`20861P@80V9RH0P1nOWh208j>SP80V9RH00<0
PH610:6QX@2QXJ400P1cLg<207emO@80[Zj^0P2LW9`40:>SXaD0oooo000C0?ooo`@0Vi^K0P2MWId2
0:2PX080UiNG0P2QXJ4209^KV`80UYJF00<0Xj>S09^KV`2KVi/00P2MWId20::RXP80WinO0P25QHD2
08J6QP80OGem0P22PX8208f=S@80QhN70P2;Rh/208R8R080Rh^;0P2GUiL20;2`/00304I6AP1`L700
L71`0080UYJF0P27QhL20861P@80NGUi0P22PX8608N7Q`80SHf=1027QhL208J6QP80O7al0P1oOgl0
0`2ATI40Rh^;08^;R`0408N7Q`80OWin0P27QhL207]kN`80OWin0P21PH4207inOP80Ng]k0P22PX82
08b<S080SHf=0P27QhL208^;R`<0QhN70P28R8P608N7Q`80Rh^;0P2ATI4208R8R080SHf=0P2:RXX2
08f=S@80R8R80P27QhL208B4Q080RHV900<0QhN708:2PP22PX800P27QhL208R8R0H0QhN70P28R8P:
08N7Q`80S8b<0P2UYJD20:VYZ@0304Y:BP1FEUH0EUIF0080YZJV0P21PH4208N7Q`80QXJ60P21PH42
08B4Q080Ph>30P21PH4208:2PP80QhN70P2?Shl208N7Q`80Shn?0P27QhL00`2?Shl0S8b<08b<S002
092@T080SXj>0P2@T90208b<S080Shn?0P22PX8208R8R080Q8B40P2<S8`20861P@80V9RH0P1nOWh2
08j>SP80V9RH00<0PH610:6QX@2QXJ400P1cLg<207emO@80[Zj^0P2LW9`40:>SXaD0oooo000C0?oo
o`80WIfM0P2NWYh209fMW@80Y:BT0P2OWil209jNWP80XZ:R0P2IVIT00`2WYjL0XJ6Q0:6QX@0209bL
W080Vi^K0P2GUiL209nOW`80UIFE0P2=SHd207MgM`80QHF50P28R8P208:2PP80RXZ:0P24Q8@208f=
S@80ZJVY00<0SHf=05UIF@1IFET00P2FUYH208N7Q`80R8R80P1iNGT408:2PP80QhN70P1lO7`208N7
Q`80SHf=1027QhL40861P@<0QhN70P23Ph<208R8R080Ph>30P2;Rh/20820P080OGem1020P80407Ui
N@80QHF50P28R8P208b<S080P82000<0R8R808N7Q`27QhL00P2?Shl608N7Q`80Rh^;0P2ATI4209>C
T`80QhN70P2=SHd209^KV`80S8b<0P24Q8@2092@T080RXZ:00<0T92@08B4Q024Q8@00P25QHD208b<
S080QhN70P24Q8@208N7Q`80Rh^;1027QhL208>3P`80Rh^;0P23Ph<208N7Q`80S8b<0P2UYJD00`2Y
ZJT0@T920492@P0208^;R`80UIFE0P2:RXX:08N7Q`80Rh^;0P27QhL208Z:RP80QhN70P2=SHd208J6
QP0308^;R`2=SHd0SHf=0080UIFE0P2>SXh208n?S`80Rh^;0P2<S8`408N7Q`80PH610P2EUID2092@
T080U9BD102;Rh/209^KV`0306a/K02OWil0WinO0080LG5a0P21PH420;Fe]@80XJ6Q0P2ATI4209^K
VaD0oooo000C0?ooo`80WIfM0P2NWYh209fMW@80Y:BT0P2OWil209jNWP80XZ:R0P2IVIT00`2WYjL0
XJ6Q0:6QX@0209bLW080Vi^K0P2GUiL209nOW`80UIFE0P2=SHd207MgM`80QHF50P28R8P208:2PP80
RXZ:0P24Q8@208f=S@80ZJVY00<0SHf=05UIF@1IFET00P2FUYH208N7Q`80R8R80P1iNGT408:2PP80
QhN70P1lO7`208N7Q`80SHf=1027QhL40861P@<0QhN70P23Ph<208R8R080Ph>30P2;Rh/20820P080
OGem1020P80407UiN@80QHF50P28R8P208b<S080P82000<0R8R808N7Q`27QhL00P2?Shl608N7Q`80
Rh^;0P2ATI4209>CT`80QhN70P2=SHd209^KV`80S8b<0P24Q8@2092@T080RXZ:00<0T92@08B4Q024
Q8@00P25QHD208b<S080QhN70P24Q8@208N7Q`80Rh^;1027QhL208>3P`80Rh^;0P23Ph<208N7Q`80
S8b<0P2UYJD00`2YZJT0@T920492@P0208^;R`80UIFE0P2:RXX:08N7Q`80Rh^;0P27QhL208Z:RP80
QhN70P2=SHd208J6QP0308^;R`2=SHd0SHf=0080UIFE0P2>SXh208n?S`80Rh^;0P2<S8`408N7Q`80
PH610P2EUID2092@T080U9BD102;Rh/209^KV`0306a/K02OWil0WinO0080LG5a0P21PH420;Fe]@80
XJ6Q0P2ATI4209^KVaD0oooo000C0?ooo`80WIfM0P2PX:0209VIV@80XZ:R0P2QXJ4209nOW`80X:2P
0P2OWil00`2KVi/0YZJV0:JVYP020::RXP80WinO0P2SXj<20:6QX@80V9RH0P2PX:0208R8R080O7al
0P24Q8@208R8R080RHV90P27QhL208f=S@80W9bL00<0ZZZZ071`L01`L7000P1eMGD208b<S080RXZ:
0P1lO7`20861P@80OGem1027QhL20820P080R8R80P27QhL208:2PP80QhN70P2<S8`00`22PX80Ph>3
08>3P`0208R8R080Ph>30P21PH4208f=S@H0QhN70P26QXH208>3P`80OGem0P1iNGT20820P080QhN7
0P24Q8@00`1kNg/0RHV908V9R@0208:2PP80SHf=0P28R8P608N7Q`80SHf=102:RXX2096AT@80Rh^;
102<S8`208V9R@0308f=S@2;Rh/0Rh^;0080QHF50P2=SHd208V9R@80R8R80P27QhL208R8R080Shn?
0P28R8P208N7Q`80Rh^;0P27QhL208Z:RP80Q8B40P2<S8`00`2UYJD0Q8B408B4Q00205eMG@80PH61
0P2IVIT208n?S`80RXZ:0P26QXH208B4Q0@0RXZ:0P2=SHd208Z:RP80Rh^;0P2=SHd208V9R@0308f=
S@2<S8`0S8b<0080TI6A0P2DU9@408n?S`80QhN70P26QXH208Z:RP80Ph>30P2OWil20:RXZ080WYjN
0P20P8020:>SX`80U9BD00<0TI6A0:BTY02TY:@00P1YJFT208j>SP80Zj^[0P2RXZ8209fMW@80V9RH
5@3oool001<0oooo0P2MWId20:2PX080VIVI0P2RXZ820:6QX@80WinO0P2PX:0209nOW`0309^KV`2V
YZH0YZJV0080XZ:R0P2OWil20:>SX`80XJ6Q0P2HV9P20:2PX080R8R80P1lO7`208B4Q080R8R80P29
RHT208N7Q`80SHf=0P2LW9`00`2ZZZX0L71`071`L00207EeM@80S8b<0P2:RXX207alO080PH610P1m
OGd408N7Q`80P8200P28R8P208N7Q`80PX:20P27QhL208b<S00308:2PP23Ph<0Ph>30080R8R80P23
Ph<20861P@80SHf=1P27QhL208J6QP80Ph>30P1mOGd207UiN@80P8200P27QhL208B4Q00307]kN`29
RHT0RHV90080PX:20P2=SHd208R8R0H0QhN70P2=SHd408Z:RP80TI6A0P2;Rh/408b<S080RHV900<0
SHf=08^;R`2;Rh/00P25QHD208f=S@80RHV90P28R8P208N7Q`80R8R80P2?Shl208R8R080QhN70P2;
Rh/208N7Q`80RXZ:0P24Q8@208b<S0030:FUY@24Q8@0Q8B40080GEeM0P21PH4209VIV@80Shn?0P2:
RXX208J6QP80Q8B4102:RXX208f=S@80RXZ:0P2;Rh/208f=S@80RHV900<0SHf=08b<S02<S8`00P2A
TI4209BDU0@0Shn?0P27QhL208J6QP80RXZ:0P23Ph<209nOW`80Z:RX0P2NWYh20820P080Xj>S0P2D
U9@00`2ATI40Y:BT0:BTY00206UYJ@80SXj>0P2[Zj/20::RXP80WIfM0P2HV9PE0?ooo`004`3oool2
09fMW@80Xj>S0P2IVIT209fMW@80UIFE0P2SXj<209NGU`80YZJV00<0Vi^K0:6QX@2QXJ400P2GUiL4
0:6QX@80WIfM0P2SXj<20:6QX@80WIfM0P2>SXh20820P080O7al0P2:RXX208^;R`80RHV90P2<S8`0
0`2KVi/0YjNW0:NWY`0207EeM@80Q8B40P2?Shl208J6QP80Ph>30P1mOGd20861P@80Ph>30P26QXH2
08N7Q`80R8R80P22PX8207emO@80PX:200<0QhN707inOP1nOWh00P23Ph<208N7Q`80OGem0P2ATI42
08N7Q`80RXZ:0P27QhL208J6QP80QhN70P29RHT207QhN080OGem0P1eMGD208R8R00307alO029RHT0
RHV90080OGem0P2:RXX208R8R080QXJ60P2?Shl208N7Q`80R8R80P2:RXX2092@T080RXZ:0P27QhL2
08b<S0@0Rh^;00<0S8b<08f=S@2=SHd00P2;Rh/2096AT@80Rh^;0P29RHT208^;R`80R8R80P2;Rh/6
08R8R080QhN71029RHT208N7Q`0308Z:RP2[Zj/0Zj^[0080Rh^;0P1[Jf/207MgM`80SHf=102;Rh/2
08N7Q`80Shn?0P2:RXX2092@T080SHf=0P2;Rh/208j>SP80RHV900<0TY:B08J6QP26QXH01P2?Shl2
08J6QP80S8b<0P1jNWX20861P@80SXj>0P2XZ:P2096AT@80ZJVY0P1^KVh209>CT`80QXJ600<0Rh^;
09ZJVP2JVYX00P1hN7P20:ZZZP80YZJV0P2MWId20:>SX`80UIFE5@3oool001<0oooo0P2MWId20:>S
X`80VIVI0P2MWId209FEU@80Xj>S0P2GUiL20:JVYP0309^KV`2QXJ40XJ6Q0080UiNG102QXJ4209fM
W@80Xj>S0P2QXJ4209fMW@80SXj>0P20P80207alO080RXZ:0P2;Rh/208V9R@80S8b<00<0Vi^K0:NW
Y`2WYjL00P1eMGD208B4Q080Shn?0P26QXH208>3P`80OGem0P21PH4208>3P`80QXJ60P27QhL208R8
R080PX:20P1mOGd208:2PP0308N7Q`1nOWh0OWin0080Ph>30P27QhL207emO@80TI6A0P27QhL208Z:
RP80QhN70P26QXH208N7Q`80RHV90P1hN7P207emO@80MGEe0P28R8P00`1lO7`0RHV908V9R@0207em
O@80RXZ:0P28R8P208J6QP80Shn?0P27QhL208R8R080RXZ:0P2@T90208Z:RP80QhN70P2<S8`408^;
R`0308b<S02=SHd0SHf=0080Rh^;0P2ATI4208^;R`80RHV90P2;Rh/208R8R080Rh^;1P28R8P208N7
Q`@0RHV90P27QhL00`2:RXX0Zj^[0:^[Z`0208^;R`80Jf][0P1gMgL208f=S@@0Rh^;0P27QhL208n?
S`80RXZ:0P2@T90208f=S@80Rh^;0P2>SXh208V9R@0309:BTP26QXH0QXJ600H0Shn?0P26QXH208b<
S080NWYj0P21PH4208j>SP80Z:RX0P2ATI420:VYZ@80KVi^0P2CTi<208J6QP0308^;R`2JVYX0VYZJ
0080N7Qh0P2ZZZX20:JVYP80WIfM0P2SXj<209FEUAD0oooo000C0?ooo`80WIfM0P2SXj<20:BTY080
XZ:R0P2KVi/20:FUY@80UiNG0P2QXJ400`2IVIT0Xj>S0:>SX`0209ZJVP80Y:BT0P2SXj<20:6QX@80
WYjN0P2UYJD40:6QX@80VIVI0P29RHT208F5Q@80Shn?0P2>SXh208n?S`0308j>SP2OWil0WinO0080
V9RH0P1fMWH206=SH`80][Jf1026QXH20820P0@0PX:20P21PH420820P080NGUi2@1mOGd20861P@80
OGem0P2<S8`208f=S@80Rh^;0P2>SXh408Z:RP80Shn?0P21PH4208N7Q`80MWIf0`21PH4208>3P`80
Ogmo0P25QHD207inOP80Ogmo0P27QhL208R8R080S8b<0P28R8P208^;R`80SHf=0P22PX8208R8R080
RHV90P27QhL00`2>SXh0PX:208:2PP0208f=S@80RXZ:0P27QhL208f=S@80RHV90P28R8P208:2PPP0
R8R80P26QXH208R8R080SHf=00<0PH61092@T02@T9000P2_[jl20:2PX080LG5a0P27QhL208V9R@80
R8R80P27QhL208^;R`80RXZ:0P2ATI4208j>SP80RHV90P2=SHd3092@T080QXJ6102@T90208Z:RP80
PX:20P1bLW820820P080MGEe0P2CTi<20:BTY080RXZ:0P2=SHd2096AT@80T92@0P25QHD00`2JVYX0
PX:208:2PP0207]kN`80]KFe0P2WYjL209ZJVP80Y:BT0P2LW9`E0?ooo`004`3oool209fMW@80Xj>S
0P2TY:@20::RXP80Vi^K0P2UYJD209NGU`80XJ6Q00<0VIVI0:>SX`2SXj<00P2JVYX20:BTY080Xj>S
0P2QXJ4209jNWP80YJFU102QXJ4209VIV@80RHV90P25QHD208n?S`80SXj>0P2?Shl00`2>SXh0WinO
09nOW`0209RHV080MWIf0P1SHf<20;Jf]P@0QXJ60P20P80408:2PP80PH610P20P80207UiN@T0OGem
0P21PH4207emO@80S8b<0P2=SHd208^;R`80SXj>102:RXX208n?S`80PH610P27QhL207IfMP<0PH61
0P23Ph<207moO`80QHF50P1nOWh207moO`80QhN70P28R8P208b<S080R8R80P2;Rh/208f=S@80PX:2
0P28R8P208V9R@80QhN700<0SXj>08:2PP22PX800P2=SHd208Z:RP80QhN70P2=SHd208V9R@80R8R8
0P22PX8808R8R080QXJ60P28R8P208f=S@030861P@2@T900T92@0080[jn_0P2PX:02075aL@80QhN7
0P29RHT208R8R080QhN70P2;Rh/208Z:RP80TI6A0P2>SXh208V9R@80SHf=0`2@T90208J6QP@0T92@
0P2:RXX208:2PP80LW9b0P20P80207EeM@80Ti>C0P2TY:@208Z:RP80SHf=0P2ATI42092@T080QHF5
00<0VYZJ08:2PP22PX800P1kNg/20;Fe]@80YjNW0P2JVYX20:BTY080W9bL5@3oool001<0oooo0P2M
WId20::RXP80VIVI0P2SXj<209fMW@80XJ6Q0P2IVIT20:>SX`0309jNWP2LW9`0W9bL0080WYjN0P2H
V9P209^KV`80XJ6Q0P2UYJD209jNWP80YJFU0P2QXJ4209VIV@80XJ6Q0P2=SHd209NGU`80SXj>0`2B
TY8208j>SP80VIVI0P2;Rh/205EEE@80KFe]0P2@T90208V9R@80P8200P1mOGd408:2PP80OGem0P1k
Ng/207=cL`80Ph>300<0OGem07moO`1oOgl00P21PH4207alO080NGUi0P1lO7`208f=S@80S8b<0P2?
Shl408Z:RP80SHf=0P29RHT208B4Q080Ng]k0P1fMWH30861P@80MWIf0P25QHD207inOP80O7al0P1m
OGd207YjNP80PX:20P1lO7`208:2PP80QXJ60P1nOWh208J6QP@0PX:200<0QhN707inOP1nOWh00P2:
RXX208J6QP80PX:20P26QXH408N7Q`H0PX:20P2;Rh/207moO`80QHF50P22PX8208N7Q`0307moO`21
PH40PH610080U9BD0P2ATI4209^KV`80QHF50P1cLg<207EeM@80VIVI0P2BTY8208R8R080TY:B0P2=
SHd208^;R`80Shn?0P2BTY800`2ATI40Shn?08n?S`0208N7Q`80QXJ60P1XJ6P208F5Q@80NGUi0P1h
N7P207AdM080QXJ60P2OWil208F5Q@80Lg=c0P21PH4208R8R080TI6A00<0QXJ607emO@1mOGd00P2?
Shl20:>SX`80YJFU0P2MWId209ZJVP80WIfM5@3oool001<0oooo0P2KVi/209jNWP80WinO0P2MWId2
0:NWY`80XJ6Q0P2KVi/209VIV@0309jNWP2KVi/0Vi^K0080Y:BT0P2NWYh209fMW@80Vi^K0P2WYjL2
09VIV@80XJ6Q0P2YZJT209NGU`80YjNW0P2HV9P20:FUY@80VYZJ0P2MWId00`2WYjL0WYjN09jNWP02
09jNWP80WIfM0P2QXJ42071`L080JFUY0P1dM7@20:VYZ@80MGEe0P1iNGT208^;R`80OWin0P20P802
07EeM@80PH6100<0OWin08R8R028R8P00P2;Rh/208V9R@80Ph>30P1hN7P208N7Q`80SHf=0P2;Rh/2
096AT@80R8R80P2=SHd208Z:RP@0QhN70P1jNWX00`23Ph<0QhN708N7Q`0207moO`80QhN70P1nOWh2
08J6QP80PH610P1lO7`207UiN@80Ng]k0P1cLg<207MgM`80LW9b0P1eMGD207]kN`80MGEe00<0N7Qh
07AdM01dM7@00P1kNg/207EeM@80N7Qh0P1mOGd207IfMP80NGUi0P1gMgL207QhN080OGem0P20P802
07EeM@80RXZ:1020P8000`1hN7P0PX:208:2PP0207alO080N7Qh0P2<S8`2096AT@80MWIf0P1RHV82
06i^KP80@d=30P2o_kl208>3P`80TI6A102<S8`208f=S@0307alO01dM7@0M7Ad00@0O7al0P1_Kfl4
0861P@80NWYj0P1^KVh20861P@@0QhN70P2:RXX207]kN`80Lg=c0P2^[Zh00`28R8P0Jf][06][J`02
0:n_[`80V9RH0P2[Zj/20:2PX080WYjN0P2EUIDE0?ooo`004`3oool209^KV`80WYjN0P2OWil209fM
W@80YjNW0P2QXJ4209^KV`80VIVI00<0WYjN09^KV`2KVi/00P2TY:@209jNWP80WIfM0P2KVi/20:NW
Y`80VIVI0P2QXJ420:VYZ@80UiNG0P2WYjL209RHV080YJFU0P2JVYX209fMW@030:NWY`2NWYh0WYjN
0080WYjN0P2MWId20:6QX@80L71`0P1YJFT207AdM080ZJVY0P1eMGD207UiN@80Rh^;0P1nOWh20820
P080MGEe0P21PH400`1nOWh0R8R808R8R00208^;R`80RHV90P23Ph<207QhN080QhN70P2=SHd208^;
R`80TI6A0P28R8P208f=S@80RXZ:1027QhL207YjNP0308>3P`27QhL0QhN70080Ogmo0P27QhL207in
OP80QXJ60P21PH4207alO080NGUi0P1kNg/207=cL`80MgMg0P1bLW8207EeM@80Ng]k0P1eMGD00`1h
N7P0M7Ad07AdM00207]kN`80MGEe0P1hN7P207emO@80MWIf0P1iNGT207MgM`80N7Qh0P1mOGd20820
P080MGEe0P2:RXX40820P00307QhN022PX80PX:20080O7al0P1hN7P208b<S080TI6A0P1fMWH2069R
HP80KVi^0P13@d<20;no_`80Ph>30P2ATI4408b<S080SHf=00<0O7al07AdM01dM7@0101lO7`206m_
K`@0PH610P1jNWX206i^KP80PH611027QhL208Z:RP80Ng]k0P1cLg<20:j^[P0308R8R01[Jf/0Jf][
0080[jn_0P2HV9P20:^[Z`80X:2P0P2NWYh209FEUAD0oooo000C0?ooo`80Xj>S0P2PX:020:NWY`80
UiNG0P2TY:@209nOW`80Y:BT0P2PX:0309jNWP80UYJF0P2PX:0209nOW`80W9bL0P2NWYh209bLW080
Vi^K0P2UYJD209RHV080YJFU0P2JVYX20:FUY@80VIVI0P2NWYh00`2RXZ80WIfM09fMW@020:>SX`80
UiNG0P2TY:@209bLW080HV9R0P1MGEd209RHV080OWin0P1mOGd208Z:RP80PX:20P21PH4207]kN`80
O7al00<0LW9b0820P020P8000P25QHD208B4Q080Ph>30P1hN7P208B4Q080SXj>0P27QhL208f=S@80
Rh^;0P2@T90208Z:RP@0QhN70`1nOWh208>3P`@0QhN70P22PX8608N7Q`80PX:20P23Ph<20820P080
RXZ:0P20P80207emO@80P8200P1hN7P00`1mOGd0Ogmo07moO`020861P@80PX:20P1mOGd207inOP80
PH610P23Ph<20861P@H0QhN70P1mOGd208N7Q`80Ph>30P2;Rh/00`1mOGd0Rh^;08^;R`020861P@@0
PX:20P23Ph<2096AT@80RXZ:0P24Q8@203Ph>080Ph>30P1QHF42071`L080PH610P2@T902079bLP03
06][J`1XJ6P0J6QX0080E5AD0P1PH602079bLP80MgMg0P2DU9@207YjNP80MGEe0P2UYJD206UYJ@80
PX:20P2?Shl207EeM@80TI6A0P2HV9P00`1lO7`0QhN708N7Q`0208N7Q`80ZZZZ0P2JVYX60:>SXaD0
oooo000C0?ooo`80Xj>S0P2PX:020:NWY`80UiNG0P2TY:@209nOW`80Y:BT0P2PX:0309jNWP80UYJF
0P2PX:0209nOW`80W9bL0P2NWYh209bLW080Vi^K0P2UYJD209RHV080YJFU0P2JVYX20:FUY@80VIVI
0P2NWYh00`2RXZ80WIfM09fMW@020:>SX`80UiNG0P2TY:@209bLW080HV9R0P1MGEd209RHV080OWin
0P1mOGd208Z:RP80PX:20P21PH4207]kN`80O7al00<0LW9b0820P020P8000P25QHD208B4Q080Ph>3
0P1hN7P208B4Q080SXj>0P27QhL208f=S@80Rh^;0P2@T90208Z:RP@0QhN70`1nOWh208>3P`@0QhN7
0P22PX8608N7Q`80PX:20P23Ph<20820P080RXZ:0P20P80207emO@80P8200P1hN7P00`1mOGd0Ogmo
07moO`020861P@80PX:20P1mOGd207inOP80PH610P23Ph<20861P@H0QhN70P1mOGd208N7Q`80Ph>3
0P2;Rh/00`1mOGd0Rh^;08^;R`020861P@@0PX:20P23Ph<2096AT@80RXZ:0P24Q8@203Ph>080Ph>3
0P1QHF42071`L080PH610P2@T902079bLP0306][J`1XJ6P0J6QX0080E5AD0P1PH602079bLP80MgMg
0P2DU9@207YjNP80MGEe0P2UYJD206UYJ@80PX:20P2?Shl207EeM@80TI6A0P2HV9P00`1lO7`0QhN7
08N7Q`0208N7Q`80ZZZZ0P2JVYX60:>SXaD0oooo000C0?ooo`80VIVI0P2GUiL20:>SX`80XJ6Q0P2I
VIT20:2PX080Vi^K0P2GUiL00`2PX:00XZ:R0::RXP0209nOW`80VYZJ0P2UYJD209fMW@80Xj>S0P2I
VIT20:2PX080XZ:R0P2QXJ4209fMW@80Xj>S0P2QXJ4209^KV`80WIfM00<0VIVI09fMW@2MWId00P2Q
XJ4209fMW@80XZ:R0P2KVi/206UYJ@80Jf][0P1MGEd208>3P`80NGUi0P1cLg<209^KV`80PX:20P1m
OGd208F5Q@0307=cL`25QHD0QHF50080PX:20P1oOgl208R8R080Ng]k0P21PH4208j>SP@0QhN70P28
R8P208^;R`80SXj>0P27QhL208n?S`80Ph>300<0PX:207inOP1nOWh00P27QhL208^;R`X0QhN70P22
PX8207moO`80P8200P2:RXX208N7Q`80Rh^;0P21PH400`20P800OGem07emO@0208B4Q080QXJ60P25
QHD208J6QP80QhN70P22PX8207YjNP80Shn?1P27QhL408>3P`80Rh^;00<0OGem08b<S02<S8`00P21
PH4208j>SP80QhN70P21PH4208N7Q`80PX:20P2;Rh/208V9R@80VIVI0P1dM7@2065QH@80FEUI0P14
A4@205iNGP0306YZJP1OGel0GemO0080H61P0P1XJ6P206e]K@80KVi^0P1mOGd208F5Q@80O7al0P2d
];@205iNGP80RXZ:0P2DU9@2069RHP80XJ6Q0P2MWId00`1cLg<0/[:b0;:b/P0207emO@80X:2P0P2G
UiL209fMW@80Vi^K0P2WYjLE0?ooo`004`3oool209VIV@80UiNG0P2SXj<20:6QX@80VIVI0P2PX:02
09^KV`80UiNG00<0X:2P0::RXP2RXZ800P2OWil209ZJVP80YJFU0P2MWId20:>SX`80VIVI0P2PX:02
0::RXP80XJ6Q0P2MWId20:>SX`80XJ6Q0P2KVi/209fMW@0309VIV@2MWId0WIfM0080XJ6Q0P2MWId2
0::RXP80Vi^K0P1YJFT206][J`80GEeM0P23Ph<207UiN@80Lg=c0P2KVi/208:2PP80OGem0P25QHD0
0`1cLg<0QHF508F5Q@0208:2PP80Ogmo0P28R8P207]kN`80PH610P2>SXh408N7Q`80R8R80P2;Rh/2
08j>SP80QhN70P2?Shl208>3P`0308:2PP1nOWh0OWin0080QhN70P2;Rh/:08N7Q`80PX:20P1oOgl2
0820P080RXZ:0P27QhL208^;R`80PH6100<0P82007emO@1mOGd00P24Q8@208J6QP80QHF50P26QXH2
08N7Q`80PX:20P1jNWX208n?S`H0QhN71023Ph<208^;R`0307emO@2<S8`0S8b<0080PH610P2>SXh2
08N7Q`80PH610P27QhL208:2PP80Rh^;0P29RHT209VIV@80M7Ad0P1QHF4205UIF@80A4A40P1NGUh0
0`1ZJVX0GemO05mOG`02061PH080J6QX0P1]KFd206i^KP80OGem0P25QHD207alO080];Bd0P1NGUh2
08Z:RP80U9BD0P1RHV820:6QX@80WIfM00<0Lg=c0;:b/P2b/[800P1mOGd20:2PX080UiNG0P2MWId2
09^KV`80YjNW5@3oool001<0oooo0P2SXj<20:6QX@80W9bL102MWId20:NWY`80WIfM0P2OWil309bL
W080WIfM0P2SXj<20:6QX@80V9RH102QXJ4409fMW@80XJ6Q0P2GUiL20:BTY080YJFU0P2QXJ4209jN
WP0309^KV`2MWId0WIfM0080WIfM0P2IVIT209nOW`80Vi^K0P1aLG420861P@80FEUI0P1XJ6P208>3
P`80DE5A0P1XJ6P20:b/[080QXJ60P1nOWh00`1iNGT0Q8B408B4Q00207inOP80P8200P21PH4207mo
O`80Q8B40P2=SHd808N7Q`80Shn?0P23Ph<208^;R`<0QhN71022PX8808N7Q`80QXJ61P27QhL207]k
N`@0Ph>30P2;Rh/208>3P`0308N7Q`25QHD0QHF50080OGem0P20P80408>3P`80QhN70P26QXH20820
P080S8b<0P27QhL208J6QP80QhN70P1kNg/208Z:RP80QhN700<0OGem08N7Q`27QhL00P21PH4208^;
R`80QhN70P22PX8208N7Q`80PX:20P21PH4207UiN@80Ph>30P25QHD2071`L080JFUY0P1GEeL2055A
D@0305eMG@1LG5`0G5aL0080KFe]0P1UIFD206][J`80JFUY0P1gMgL207EeM@80O7al0P2SXj<205eM
G@80Ng]k0P2@T90206][J`80WinO0P26QXH00`24Q8@0[Jf]0:f][@0209^KV`80WYjN0P2DU9@20:RX
Z080Vi^K0P2NWYhE0?ooo`004`3oool20:>SX`80XJ6Q0P2LW9`409fMW@80YjNW0P2MWId209nOW`<0
W9bL0P2MWId20:>SX`80XJ6Q0P2HV9P40:6QX@@0WIfM0P2QXJ4209NGU`80Y:BT0P2UYJD20:6QX@80
WYjN00<0Vi^K09fMW@2MWId00P2MWId209VIV@80WinO0P2KVi/2075aL@80PH610P1IFET206QXJ080
Ph>30P1ADE4206QXJ080[:b/0P26QXH207inOP0307UiN@24Q8@0Q8B40080OWin0P20P8020861P@80
Ogmo0P24Q8@208f=S@P0QhN70P2?Shl208>3P`80Rh^;0`27QhL408:2PPP0QhN70P26QXH608N7Q`80
Ng]k1023Ph<208^;R`80Ph>300<0QhN708F5Q@25QHD00P1mOGd20820P0@0Ph>30P27QhL208J6QP80
P8200P2<S8`208N7Q`80QXJ60P27QhL207]kN`80RXZ:0P27QhL00`1mOGd0QhN708N7Q`020861P@80
Rh^;0P27QhL208:2PP80QhN70P22PX820861P@80NGUi0P23Ph<208F5Q@80L71`0P1YJFT205MGE`80
DE5A00<0GEeM05aLG01LG5`00P1]KFd206EUI@80Jf][0P1YJFT207MgM`80MGEe0P1lO7`20:>SX`80
GEeM0P1kNg/2092@T080Jf][0P2OWil208J6QP0308B4Q02][Jd0[Jf]0080Vi^K0P2NWYh209BDU080
Z:RX0P2KVi/209jNWQD0oooo000C0?ooo`80Vi^K0P2NWYh20:6QX@80WYjN0P2KVi/20:NWY`80UiNG
0P2WYjL00`2KVi/0ZJVY0:VYZ@0209NGU`80YjNW0P2MWId20:>SX`80UiNG0P2WYjL40:6QX@80WIfM
0P2OWil40:6QX@80WIfM0P2SXj<00`2GUiL0Vi^K09^KV`020:2PX080XJ6Q0P2GUiL209bLW080OGem
0P28R8P206MWI`80ADE50P1gMgL2051@D080BDU90P1EEED20<?3``80NGUi00<0QXJ607UiN@1iNGT0
0P1oOgl208J6QP80PX:20P1mOGd208:2PP80SHf=2027QhL208^;R`80QXJ61`27QhL208>3P`H0QhN7
0P2<S8`208>3P`80Rh^;1027QhL207inOP@0Ph>30P27QhL208>3P`030861P@27QhL0QhN700@0PH61
1P23Ph<207moO`80Ph>30P27QhL208b<S080PH610P29RHT207moO`80Rh^;0P27QhL00`1nOWh0PH61
0861P@0208B4Q0@0QhN70P1lO7`208J6QP80NGUi0P20P80206m_K`80K6a/0P1IFET205EEE@80Fe]K
0P1UIFD205aLG00305eMG@1FEUH0EUIF0080HF5Q0P1aLG4206QXJ080M7Ad0P1lO7`207MgM`80PX:2
0P1mOGd206YZJP80PH610P20P80208J6QP80Shn?0P26QXH00`2CTi<0Zj^[0:^[Z`0209RHV080X:2P
0P2FUYH20:BTY080XZ:R0P2KVi/E0?ooo`004`3oool209^KV`80WYjN0P2QXJ4209jNWP80Vi^K0P2W
YjL209NGU`80YjNW00<0Vi^K0:VYZ@2YZJT00P2GUiL20:NWY`80WIfM0P2SXj<209NGU`80YjNW102Q
XJ4209fMW@80WinO102QXJ4209fMW@80Xj>S00<0UiNG09^KV`2KVi/00P2PX:020:6QX@80UiNG0P2L
W9`207emO@80R8R80P1WIfL204E5A@80MgMg0P1@D50204U9B@80EEEE0P33`l<207UiN@0308J6QP1i
NGT0NGUi0080Ogmo0P26QXH208:2PP80OGem0P22PX8208f=S@P0QhN70P2;Rh/208J6QPL0QhN70P23
Ph<608N7Q`80S8b<0P23Ph<208^;R`@0QhN70P1nOWh408>3P`80QhN70P23Ph<00`21PH40QhN708N7
Q`040861P@H0Ph>30P1oOgl208>3P`80QhN70P2<S8`20861P@80RHV90P1oOgl208^;R`80QhN700<0
OWin0861P@21PH400P24Q8@408N7Q`80O7al0P26QXH207UiN@80P8200P1_Kfl206a/K080FEUI0P1E
EED205]KF`80IFEU0P1LG5`00`1MGEd0EUIF05IFEP02065QH@80LG5a0P1XJ6P207AdM080O7al0P1g
MgL208:2PP80OGem0P1ZJVX20861P@80P8200P26QXH208n?S`80QXJ600<0Ti>C0:^[Z`2[Zj/00P2H
V9P20:2PX080UYJF0P2TY:@20::RXP80Vi^K5@3oool001<0oooo0P2SXj<20:2PX080WinO102JVYX2
0:VYZ@80Vi^K0P2QXJ400`2EUID0YjNW0:NWY`0209RHV080XJ6Q0P2RXZ8209fMW@@0XJ6Q0P2MWId2
0::RXP80WYjN0P2MWId20:NWY`80Vi^K0P2SXj<209jNWP0309^KV`2OWil0WinO0080V9RH0P2RXZ82
09ZJVP80WYjN0P23Ph<20:VYZ@80MGEe0P19BDT205iNGP80FUYJ0P16ATH203Ph>080B4Q80P2k^k/0
0`25QHD0NGUi07UiN@0208:2PP80Ng]k0P24Q8@207emO@80Q8B40P28R8P208b<S0H0QhN70P23Ph<2
08^;R`L0QhN71022PX8207inOP80QhN71023Ph<208N7Q`80Rh^;0P27QhL408:2PP80Ng]k0P23Ph<2
08N7Q`D0PH610P20P80208J6QP@0PH611023Ph<20861P@80Shn?0P1mOGd208N7Q`80OWin0P26QXH2
08f=S@0308:2PP1mOGd0OGem0080Ph>30P21PH4207moO`80OGem0P1lO7`207QhN0@0Kfm_0P1GEeL2
04];B`80HV9R0P1QHF4205]KF`80K6a/00<0LG5a05QHF01HF5P00P1HF5P206][J`80MgMg0P1XJ6P2
08F5Q@80Kfm_0P28R8P207IfMP80Ng]k101gMgL209VIV@80Jf][0P2FUYH00`2UYJD0WinO09nOW`02
09jNWP80V9RH0P2QXJ4209fMW@80YJFU0P2GUiLE0?ooo`004`3oool20:>SX`80X:2P0P2OWil409ZJ
VP80ZJVY0P2KVi/20:6QX@0309FEU@2WYjL0YjNW0080V9RH0P2QXJ420::RXP80WIfM102QXJ4209fM
W@80XZ:R0P2NWYh209fMW@80YjNW0P2KVi/20:>SX`80WYjN00<0Vi^K09nOW`2OWil00P2HV9P20::R
XP80VYZJ0P2NWYh208>3P`80ZJVY0P1eMGD204U9B@80GUiN0P1JFUX204I6AP80>3Ph0P18B4P20;^k
^`0308F5Q@1iNGT0NGUi0080PX:20P1kNg/208B4Q080OGem0P24Q8@208R8R080S8b<1P27QhL208>3
P`80Rh^;1`27QhL408:2PP80OWin0P27QhL408>3P`80QhN70P2;Rh/208N7Q`@0PX:20P1kNg/208>3
P`80QhN71@21PH420820P080QXJ61021PH4408>3P`80PH610P2?Shl207emO@80QhN70P1nOWh208J6
QP80SHf=00<0PX:207emO@1mOGd00P23Ph<20861P@80Ogmo0P1mOGd207alO080N7Qh101_Kfl205MG
E`80Bd];0P1RHV82065QH@80Fe]K0P1/K6`00`1aLG40F5QH05QHF00205QHF080Jf][0P1gMgL206QX
J080QHF50P1_Kfl208R8R080MWIf0P1kNg/407MgM`80VIVI0P1[Jf/209JFUP030:FUY@2OWil0WinO
0080WYjN0P2HV9P20:6QX@80WIfM0P2UYJD209NGUaD0oooo000C0?ooo`80W9bL0P2NWYh20:>SX`80
WinO0P2KVi/20:NWY`80Vi^K0P2TY:@00`2KVi/0ZJVY0:VYZ@0209fMW@80Vi^K0P2MWId20:6QX@80
WIfM0P2RXZ820:6QX@80UiNG0P2SXj<209RHV080XJ6Q0P2PX:0209fMW@80WinO00<0XJ6Q09fMW@2M
WId00P2SXj<209ZJVP80VIVI0P2KVi/208>3P`80Y:BT0P1cLg<205]KF`80@4100P1PH60204A4A080
=SHf0P0Y:BT204];B`030<71`@1iNGT0NGUi0080QXJ60P1iNGT208Z:RP@0OGem0P2<S8`808N7Q`80
PX:20P23Ph<208N7Q`80Rh^;00<0QhN708>3P`23Ph<01027QhL408>3P`80QHF50P24Q8@608N7Q`80
Ph>30P27QhL207moO`80OGem0P21PH400`24Q8@0P8200820P00208R8R080Ogmo0P23Ph<207emO@80
PH610P1iNGT208V9R@80Ogmo0P29RHT208>3P`80QhN70P23Ph<20861P@80QhN700<0QHF507YjNP1j
NWX00P23Ph<207emO@80MgMg0P1lO7`407MgM`80H61P0P1ADE4204U9B@80IfMW0P1bLW82061PH080
AdM70P1fMWH3079bLP80GUiN101UIFD206QXJ080MgMg0P1cLg<207moO`80L71`0P2>SXh20861P@80
V9RH101lO7`2092@T0030:NWY`2LW9`0W9bL0080X:2P0P2NWYh209bLW080Vi^K0P2WYjL209ZJVQD0
oooo000C0?ooo`80W9bL0P2NWYh20:>SX`80WinO0P2KVi/20:NWY`80Vi^K0P2TY:@00`2KVi/0ZJVY
0:VYZ@0209fMW@80Vi^K0P2MWId20:6QX@80WIfM0P2RXZ820:6QX@80UiNG0P2SXj<209RHV080XJ6Q
0P2PX:0209fMW@80WinO00<0XJ6Q09fMW@2MWId00P2SXj<209ZJVP80VIVI0P2KVi/208>3P`80Y:BT
0P1cLg<205]KF`80@4100P1PH60204A4A080=SHf0P0Y:BT204];B`030<71`@1iNGT0NGUi0080QXJ6
0P1iNGT208Z:RP@0OGem0P2<S8`808N7Q`80PX:20P23Ph<208N7Q`80Rh^;00<0QhN708>3P`23Ph<0
1027QhL408>3P`80QHF50P24Q8@608N7Q`80Ph>30P27QhL207moO`80OGem0P21PH400`24Q8@0P820
0820P00208R8R080Ogmo0P23Ph<207emO@80PH610P1iNGT208V9R@80Ogmo0P29RHT208>3P`80QhN7
0P23Ph<20861P@80QhN700<0QHF507YjNP1jNWX00P23Ph<207emO@80MgMg0P1lO7`407MgM`80H61P
0P1ADE4204U9B@80IfMW0P1bLW82061PH080AdM70P1fMWH3079bLP80GUiN101UIFD206QXJ080MgMg
0P1cLg<207moO`80L71`0P2>SXh20861P@80V9RH101lO7`2092@T0030:NWY`2LW9`0W9bL0080X:2P
0P2NWYh209bLW080Vi^K0P2WYjL209ZJVQD0oooo000C0?ooo`80WIfM0P2SXj<209RHV080Vi^K0P2Q
XJ4209fMW@80Vi^K0P2OWil309jNWP80XZ:R0P2UYJD209VIV@80YJFU0P2IVIT20:2PX080XJ6Q0P2H
V9P20:FUY@80VYZJ0P2KVi/20::RXP80XJ6Q0P2IVIT00`2QXJ40W9bL09bLW0020:JVYP80WIfM0P2N
WYh209RHV080TY:B0P2<S8`208B4Q080Hf=S0P1:BTX205]KF`80ADE50P0i>CT2030`<080;2`/00<0
@T920<O7a`37alL00P24Q8@2071`L080SHf=0P1mOGd20861P@80RHV90P2;Rh/208>3P`P0QhN70P1n
OWh208N7Q`0308^;R`1nOWh0OWin0080Ph>30P27QhL207inOP80Ogmo0P1mOGd208B4Q080RHV90P27
QhL208J6QP80RHV90P1nOWh207moO`80P8200P21PH400`1oOgl0OGem07emO@0408>3P`80QXJ60P1l
O7`20861P@80MWIf1021PH4208R8R080QhN70P1jNWX208b<S080MgMg0P2<S8`00`1mOGd0M7Ad07Ad
M002075aL@80M7Ad101YJFT206ATI080GemO0P15ADD204e=C@80ATI60P1]KFd207EeM@80J6QX0P1?
Cdl206m_K`0306UYJ@1kNg/0Ng]k0080KVi^0P1cLg<206YZJP80F5QH0P1[Jf/207UiN@80N7Qh0P1g
MgL208Z:RP80PX:20P2HV9P208J6QP80SXj>0P2JVYX00`2IVIT0TI6A096AT@020:2PX080Y:BT0P2M
WId209^KV`80YjNW0P2MWIdE0?ooo`004`3oool209fMW@80Xj>S0P2HV9P209^KV`80XJ6Q0P2MWId2
09^KV`80WinO0`2NWYh20::RXP80YJFU0P2IVIT20:FUY@80VIVI0P2PX:020:6QX@80V9RH0P2UYJD2
09ZJVP80Vi^K0P2RXZ820:6QX@80VIVI00<0XJ6Q09bLW02LW9`00P2VYZH209fMW@80WYjN0P2HV9P2
09:BTP80S8b<0P24Q8@206=SH`80BTY:0P1KFe/204E5A@80>CTi0P0`<30202`/;0030492@P37alL0
alO70080Q8B40P1`L70208f=S@80OGem0P21PH4208V9R@80Rh^;0P23Ph<808N7Q`80OWin0P27QhL0
0`2;Rh/0OWin07inOP0208>3P`80QhN70P1nOWh207moO`80OGem0P24Q8@208V9R@80QhN70P26QXH2
08V9R@80OWin0P1oOgl20820P080PH6100<0Ogmo07emO@1mOGd01023Ph<208J6QP80O7al0P21PH42
07IfMP@0PH610P28R8P208N7Q`80NWYj0P2<S8`207MgM`80S8b<00<0OGem07AdM01dM7@00P1aLG42
07AdM0@0JFUY0P1TI6@205mOG`80ADE50P1=CDd204I6AP80KFe]0P1eMGD206QXJ080Cdm?0P1_Kfl0
0`1YJFT0Ng]k07]kN`0206i^KP80Lg=c0P1ZJVX205QHF080Jf][0P1iNGT207QhN080MgMg0P2:RXX2
08:2PP80V9RH0P26QXH208j>SP80VYZJ00<0VIVI096AT@2ATI400P2PX:020:BTY080WIfM0P2KVi/2
0:NWY`80WIfM5@3oool001<0oooo0P2KVi/20:6QX@80YJFU0P2KVi/20:6QX@80UIFE0P2SXj<209fM
W@030:6QX@2IVIT0VIVI0080WYjN0P2WYjL209VIV@80Y:BT0P2KVi/20:JVYP80XJ6Q0P2OWil20:NW
Y`80WIfM0P2LW9`209VIV@80XZ:R0P2QXJ400`2GUiL0Vi^K09^KV`0209nOW`80WYjN0P2MWId209JF
UP80WIfM0P24Q8@209fMW@80C4a<0P1LG5`205MGE`80?clo100k>c/2030`<00302@T900X:2P0:2PX
0080e=CD0P1lO7`20820P080PX:20P21PH4208N7Q`80QXJ60P24Q8@608>3P`80Rh^;0P1nOWh208N7
Q`D0Ph>30P27QhL20861P@80Q8B40P1oOgl207emO@80Ph>30P24Q8@20820P080Rh^;0P23Ph<607em
O@0307alO01oOgl0Ogmo0080N7Qh0P1kNg/408>3P`80N7Qh0P1jNWX207moO`80MGEe0P26QXH20820
P080MWIf0P20P80207emO@80Ng]k00<0OGem07UiN@1iNGT00P1`L70206m_K`80IFEU0P1GEeL205IF
EP80Cdm?0P11@D4204m?C`80GUiN0P1WIfL206ATI080IfMW0P1XJ6P207=cL`<0J6QX0P1[Jf/207Ee
M@80KVi^0P1cLg<206UYJ@80M7Ad0P1cLg<208F5Q@@0PX:20P25QHD209RHV080Rh^;0P2CTi<00`2O
Wil0UYJF09JFUP0209FEU@80Xj>S0P2MWId209^KV`@0XJ6Q5@3oool001<0oooo0P2KVi/20:6QX@80
YJFU0P2KVi/20:6QX@80UIFE0P2SXj<209fMW@030:6QX@2IVIT0VIVI0080WYjN0P2WYjL209VIV@80
Y:BT0P2KVi/20:JVYP80XJ6Q0P2OWil20:NWY`80WIfM0P2LW9`209VIV@80XZ:R0P2QXJ400`2GUiL0
Vi^K09^KV`0209nOW`80WYjN0P2MWId209JFUP80WIfM0P24Q8@209fMW@80C4a<0P1LG5`205MGE`80
?clo100k>c/2030`<00302@T900X:2P0:2PX0080e=CD0P1lO7`20820P080PX:20P21PH4208N7Q`80
QXJ60P24Q8@608>3P`80Rh^;0P1nOWh208N7Q`D0Ph>30P27QhL20861P@80Q8B40P1oOgl207emO@80
Ph>30P24Q8@20820P080Rh^;0P23Ph<607emO@0307alO01oOgl0Ogmo0080N7Qh0P1kNg/408>3P`80
N7Qh0P1jNWX207moO`80MGEe0P26QXH20820P080MWIf0P20P80207emO@80Ng]k00<0OGem07UiN@1i
NGT00P1`L70206m_K`80IFEU0P1GEeL205IFEP80Cdm?0P11@D4204m?C`80GUiN0P1WIfL206ATI080
IfMW0P1XJ6P207=cL`<0J6QX0P1[Jf/207EeM@80KVi^0P1cLg<206UYJ@80M7Ad0P1cLg<208F5Q@@0
PX:20P25QHD209RHV080Rh^;0P2CTi<00`2OWil0UYJF09JFUP0209FEU@80Xj>S0P2MWId209^KV`@0
XJ6Q5@3oool001<0oooo0P2MWId20:6QX@80WYjN0P2UYJD20:6QX@80VIVI0P2MWId20:BTY0030:FU
Y@2LW9`0W9bL0080V9RH0P2QXJ4209bLW080XZ:R0P2NWYh209fMW@@0Vi^K0P2NWYh20:6QX@80Y:BT
102NWYh20:FUY@0309RHV02LW9`0W9bL00@0WIfM0P2NWYh209RHV080T92@0P1mOGd209RHV080@D51
0P1IFET205MGE`80?clo0P0i>CT203lo?`80<c<c0`0P820202PX:080fMWI0P1iNGT208J6QP80NWYj
0P25QHD20861P@80Q8B41P23Ph<608N7Q`0307inOP23Ph<0Ph>300@0Ph>30P21PH4408>3P`80OGem
0P1oOgl208>3P`80Ng]k0P25QHD20861P@80PX:20P1nOWh207moO`0307emO@1oOgl0Ogmo0080MWIf
0P1gMgL207YjNP80Ogmo0P1gMgL207IfMP80Ph>30P1lO7`207inOP80R8R80P1]KFd207alO080OGem
0P1hN7P00`1_Kfl0OGem07emO@0206e]K@80G5aL0P1>CTh205MGE`80=CDe0P1NGUh2051@D080EeMG
0P1^KVh206EUI@80I6AT0P1WIfL206ATI080OGem00<0I6AT065QH@1QHF400P1QHF4206i^KP80IFEU
0P1dM7@207MgM`80LW9b0P1nOWh20861P@@0PX:20P2@T90209jNWP80WIfM0P2HV9P00`2LW9`0X:2P
0:2PX0020:6QX@80WYjN0P2UYJD209jNWP80XJ6Q0P2WYjLE0?ooo`004`3oool209fMW@80XJ6Q0P2N
WYh20:FUY@80XJ6Q0P2IVIT209fMW@80Y:BT00<0YJFU09bLW02LW9`00P2HV9P20:6QX@80W9bL0P2R
XZ8209jNWP80WIfM102KVi/209jNWP80XJ6Q0P2TY:@409jNWP80YJFU00<0V9RH09bLW02LW9`0102M
WId209jNWP80V9RH0P2@T90207emO@80V9RH0P11@D4205UIF@80EeMG0P0o?cl203Ti>@80?clo0P0c
<c<3020P8080:2PX0P3IfMT207UiN@80QXJ60P1jNWX208F5Q@80PH610P24Q8@608>3P`H0QhN700<0
OWin08>3P`23Ph<01023Ph<20861P@@0Ph>30P1mOGd207moO`80Ph>30P1kNg/208F5Q@80PH610P22
PX8207inOP80Ogmo00<0OGem07moO`1oOgl00P1fMWH207MgM`80NWYj0P1oOgl207MgM`80MWIf0P23
Ph<207alO080OWin0P28R8P206e]K@80O7al0P1mOGd207QhN00306m_K`1mOGd0OGem0080KFe]0P1L
G5`204i>CP80EeMG0P0e=CD205iNGP80D51@0P1GEeL206i^KP80IFEU0P1TI6@206MWI`80I6AT0P1m
OGd00`1TI6@0HF5Q065QH@02065QH@80KVi^0P1UIFD207AdM080MgMg0P1bLW8207inOP80PH611022
PX82092@T080WYjN0P2MWId209RHV00309bLW02PX:00X:2P0080XJ6Q0P2NWYh20:FUY@80WYjN0P2Q
XJ420:NWYaD0oooo000C0?ooo`80VIVI0P2QXJ4209NGU`80ZJVY0P2NWYh20:FUY@80W9bL0P2MWId0
0`2NWYh0XZ:R0::RXP0209^KV`80X:2P0P2NWYh209VIV@80XJ6Q0P2VYZH20::RXP80YJFU0P2MWId2
09NGU`80X:2P0P2QXJ4209VIV@80Xj>S00<0X:2P0:6QX@2QXJ400P2JVYX209^KV`80WYjN0P2MWId2
09BDU080QXJ60P2;Rh/204];B`80FEUI0P1>CTh204Q8B080@D510P0j>SX202`/;003020P800N7Qh0
7QhN00809bLW0P38b<P207UiN@80QXJ60P22PX820861P@@0PX:20P29RHT207inOP80QhN70P1nOWh4
08N7Q`<0Ph>30P1oOgl208N7Q`80Ph>30P21PH4208F5Q@80OGem0P23Ph<20861P@80OGem0P21PH42
07]kN`80Ph>31@1mOGd407YjNP@0MgMg0P1iNGT207MgM`80M7Ad0P1kNg/208B4Q080KVi^0P1gMgL2
07=cL`@0N7Qh0P1gMgL00`1TI6@0LW9b079bLP02065QH@80G5aL0P0b<S8205ADE080?Cdm0P1DE5@2
04a<C080JFUY0P1_Kfl2061PH080Hf=S0P1ZJVX206i^KP80Lg=c00<0MWIf071`L01`L7000P1UIFD2
07QhN080PH610P1YJFT207UiN@80Ogmo0P21PH4208:2PP80PH610P2<S8`408n?S`80XZ:R0P2FUYH0
0`2OWil0W9bL09bLW00409jNWP80YJFU0P2IVIT40:6QXAD0oooo000C0?ooo`80VIVI0P2QXJ4209NG
U`80ZJVY0P2NWYh20:FUY@80W9bL0P2MWId00`2NWYh0XZ:R0::RXP0209^KV`80X:2P0P2NWYh209VI
V@80XJ6Q0P2VYZH20::RXP80YJFU0P2MWId209NGU`80X:2P0P2QXJ4209VIV@80Xj>S00<0X:2P0:6Q
X@2QXJ400P2JVYX209^KV`80WYjN0P2MWId209BDU080QXJ60P2;Rh/204];B`80FEUI0P1>CTh204Q8
B080@D510P0j>SX202`/;003020P800N7Qh07QhN00809bLW0P38b<P207UiN@80QXJ60P22PX820861
P@@0PX:20P29RHT207inOP80QhN70P1nOWh408N7Q`<0Ph>30P1oOgl208N7Q`80Ph>30P21PH4208F5
Q@80OGem0P23Ph<20861P@80OGem0P21PH4207]kN`80Ph>31@1mOGd407YjNP@0MgMg0P1iNGT207Mg
M`80M7Ad0P1kNg/208B4Q080KVi^0P1gMgL207=cL`@0N7Qh0P1gMgL00`1TI6@0LW9b079bLP02065Q
H@80G5aL0P0b<S8205ADE080?Cdm0P1DE5@204a<C080JFUY0P1_Kfl2061PH080Hf=S0P1ZJVX206i^
KP80Lg=c00<0MWIf071`L01`L7000P1UIFD207QhN080PH610P1YJFT207UiN@80Ogmo0P21PH4208:2
PP80PH610P2<S8`408n?S`80XZ:R0P2FUYH00`2OWil0W9bL09bLW00409jNWP80YJFU0P2IVIT40:6Q
XAD0oooo000C0?ooo`80XJ6Q0P2NWYh209VIV@80XZ:R0P2PX:020:6QX@80YjNW0P2MWId00`2SXj<0
VIVI09VIV@0209^KV`80Xj>S0P2QXJ4209RHV080WYjN0P2IVIT20:>SX`80WYjN0P2RXZ8209fMW@80
XJ6Q102MWId20:6QX@0309fMW@2NWYh0WYjN0080XJ6Q0P2GUiL209jNWP80V9RH0P2DU9@208F5Q@80
Lg=c0P1MGEd205UIF@80BTY:0P12@T82055AD@80=SHf0P0c<c<00`0Q8B409BDU02DU9@0203@d=080
EeMG0P2k^k/208F5Q@80PX:20P27QhL207alO080PH610P2=SHd207inOP80QhN71`23Ph<20861P@80
P8200P21PH4207moO`80Ph>30P26QXH207emO@80P820101oOgl207MgM`80PH610P1dM7@208B4Q080
PH6100<0NWYj07IfMP1fMWH00P1jNWX2079bLP80M7Ad0P1XJ6P207QhN080OWin0P20P80207QhN080
IFEU0P1aLG4207=cL`80JFUY0P1dM7@206YZJP0305QHF01RHV80HV9R0080CDe=0P1DE5@204m?C`80
@d=30P1FEUH2059BDP80De=C0P1SHf<206IVIP80G5aL0P1QHF4206=SH`80N7Qh0P1UIFD00`1hN7P0
O7al07alO00206i^KP80NGUi0P1jNWX207EeM@80RXZ:1021PH4208:2PP80RXZ:0P2ATI4209RHV080
SHf=0P2UYJD20:2PX00309fMW@2QXJ40XJ6Q0080YJFU0P2MWId209jNWP80W9bL0P2UYJD209jNWQD0
oooo000C0?ooo`80XJ6Q0P2NWYh209VIV@80XZ:R0P2PX:020:6QX@80YjNW0P2MWId00`2SXj<0VIVI
09VIV@0209^KV`80Xj>S0P2QXJ4209RHV080WYjN0P2IVIT20:>SX`80WYjN0P2RXZ8209fMW@80XJ6Q
102MWId20:6QX@0309fMW@2NWYh0WYjN0080XJ6Q0P2GUiL209jNWP80V9RH0P2DU9@208F5Q@80Lg=c
0P1MGEd205UIF@80BTY:0P12@T82055AD@80=SHf0P0c<c<00`0Q8B409BDU02DU9@0203@d=080EeMG
0P2k^k/208F5Q@80PX:20P27QhL207alO080PH610P2=SHd207inOP80QhN71`23Ph<20861P@80P820
0P21PH4207moO`80Ph>30P26QXH207emO@80P820101oOgl207MgM`80PH610P1dM7@208B4Q080PH61
00<0NWYj07IfMP1fMWH00P1jNWX2079bLP80M7Ad0P1XJ6P207QhN080OWin0P20P80207QhN080IFEU
0P1aLG4207=cL`80JFUY0P1dM7@206YZJP0305QHF01RHV80HV9R0080CDe=0P1DE5@204m?C`80@d=3
0P1FEUH2059BDP80De=C0P1SHf<206IVIP80G5aL0P1QHF4206=SH`80N7Qh0P1UIFD00`1hN7P0O7al
07alO00206i^KP80NGUi0P1jNWX207EeM@80RXZ:1021PH4208:2PP80RXZ:0P2ATI4209RHV080SHf=
0P2UYJD20:2PX00309fMW@2QXJ40XJ6Q0080YJFU0P2MWId209jNWP80W9bL0P2UYJD209jNWQD0oooo
000C0?ooo`80XJ6Q0P2MWId209NGU`80XZ:R0P2IVIT209jNWP80XZ:R0P2PX:000`2QXJ40UiNG09NG
U`060:6QX@@0WIfM0P2OWil20:FUY@80VIVI0P2PX:0209^KV`80Y:BT0P2QXJ4209NGU`80Y:BT00<0
YJFU09VIV@2IVIT00P2TY:@209^KV`80WIfM0P2HV9P209ZJVP80O7al0P1TI6@205EEE@80H61P0P1:
BTX204i>CP80C4a<0P0c<c<203/k>`0302TY:@0c<c<0<c<c0080=SHf0P0T92@20<g=c@80RXZ:0P22
PX8208b<S080Ng]k0P21PH4208V9R@80Ogmo0P24Q8@208F5Q@80Ogmo0P24Q8@00`25QHD0PH610861
P@020861P@80P8200P1oOgl207inOP80Ph>30P24Q8@207YjNP80Ogmo0P21PH4207emO@80MgMg0P1o
Ogl207IfMP80Ph>300<0O7al07UiN@1iNGT00P1gMgL2071`L080K6a/101^KVh208^;R`80PX:20P1N
GUh206UYJ@@0KVi^0P1QHF42061PH080GEeM00<0CTi>06QXJ01XJ6P00P17AdL204Q8B080FEUI0P1K
Fe/205aLG080DE5A0P1]KFd206m_K`80JFUY0P1QHF42061PH080EeMG0P2>SXh205UIF@0307IfMP1R
HV80HV9R0080QXJ60P1RHV8207AdM080Ng]k1P21PH4208J6QP80Rh^;0P2SXj<209RHV080UiNG0P2V
YZH20:FUY@0309FEU@2QXJ40XJ6Q00@0XJ6Q0P2IVIT20:>SX`80XJ6Q0P2MWIdE0?ooo`004`3oool2
0:6QX@80WIfM0P2GUiL20::RXP80VIVI0P2NWYh20::RXP80X:2P00<0XJ6Q09NGU`2GUiL01P2QXJ44
09fMW@80WinO0P2UYJD209VIV@80X:2P0P2KVi/20:BTY080XJ6Q0P2GUiL20:BTY0030:FUY@2IVIT0
VIVI0080Y:BT0P2KVi/209fMW@80V9RH0P2JVYX207alO080I6AT0P1EEED2061PH080BTY:0P1>CTh2
04a<C080<c<c0P0k>c/00`0Y:BT0<c<c03<c<`0203Hf=P8092@T0P3=cLd208Z:RP80PX:20P2<S8`2
07]kN`80PH610P29RHT207moO`80Q8B40P25QHD207moO`80Q8B400<0QHF50861P@21PH400P21PH42
0820P080Ogmo0P1nOWh208>3P`80Q8B40P1jNWX207moO`80PH610P1mOGd207MgM`80Ogmo0P1fMWH2
08>3P`0307alO01iNGT0NGUi0080MgMg0P1`L70206a/K0@0KVi^0P2;Rh/208:2PP80GUiN0P1YJFT4
06i^KP80HF5Q0P1PH60205eMG@0304i>CP1XJ6P0J6QX0080AdM70P18B4P205UIF@80Fe]K0P1LG5`2
055AD@80KFe]0P1_Kfl206UYJ@80HF5Q0P1PH60205MGE`80SXj>0P1IFET00`1fMWH0HV9R069RHP02
08J6QP80HV9R0P1dM7@207]kN`H0PH610P26QXH208^;R`80Xj>S0P2HV9P209NGU`80YZJV0P2UYJD0
0`2EUID0XJ6Q0:6QX@040:6QX@80VIVI0P2SXj<20:6QX@80WIfM5@3oool001<0oooo0P2QXJ4209fM
W@80XJ6Q0P2MWId20:6QX@@0WIfM0`2QXJ4209VIV@80YJFU1P2QXJ4209RHV080WIfM0P2WYjL209^K
V`80VYZJ0P2KVi/209VIV@80ZJVY0P2HV9P20:6QX@<0WIfM0P2SXj<209bLW080UIFE0P2ATI4209RH
V080JFUY0P1cLg<204i>CP80EEEE0P1=CDd404a<C080<C4a0P0l?3`00`0i>CT0>SXj03Xj>P0202`/
;0805QHF0P3Xj>P207emO@@0QXJ60P23Ph<207moO`80Q8B40P1kNg/20861P@80QhN70P1kNg/20861
P@<0Ph>30P21PH4207moO`80PX:20P1oOgl207emO@@0PH610P1jNWX207emO@80NWYj0P1gMgL207mo
O`80NWYj0P1gMgL00`1iNGT0MgMg07MgM`0206e]K@80KVi^0P1QHF4206e]K@80P8200P22PX8206a/
K080HF5Q0P1WIfL206m_K`80JFUY0P1LG5`205ADE080@T9200<0De=C06=SH`1SHf<00P1:BTX204e=
C@80Cdm?0P1HF5P205IFEP80DU9B0P1/K6`206m_K`80JFUY0P1NGUh2061PH080GEeM0P1kNg/206=S
H`0307YjNP1TI6@0I6AT0080OGem0P1hN7P207AdM080PH610P2?Shl20820P080PH610P2DU9@4096A
T@80VIVI0P2KVi/20:FUY@80XJ6Q00<0UiNG0:FUY@2UYJD00P2QXJ4209fMW@80WYjN0P2QXJ420:NW
Y`80XJ6Q5@3oool001<0oooo0P2QXJ4209fMW@80XJ6Q0P2MWId20:6QX@@0WIfM0`2QXJ4209VIV@80
YJFU1P2QXJ4209RHV080WIfM0P2WYjL209^KV`80VYZJ0P2KVi/209VIV@80ZJVY0P2HV9P20:6QX@<0
WIfM0P2SXj<209bLW080UIFE0P2ATI4209RHV080JFUY0P1cLg<204i>CP80EEEE0P1=CDd404a<C080
<C4a0P0l?3`00`0i>CT0>SXj03Xj>P0202`/;0805QHF0P3Xj>P207emO@@0QXJ60P23Ph<207moO`80
Q8B40P1kNg/20861P@80QhN70P1kNg/20861P@<0Ph>30P21PH4207moO`80PX:20P1oOgl207emO@@0
PH610P1jNWX207emO@80NWYj0P1gMgL207moO`80NWYj0P1gMgL00`1iNGT0MgMg07MgM`0206e]K@80
KVi^0P1QHF4206e]K@80P8200P22PX8206a/K080HF5Q0P1WIfL206m_K`80JFUY0P1LG5`205ADE080
@T9200<0De=C06=SH`1SHf<00P1:BTX204e=C@80Cdm?0P1HF5P205IFEP80DU9B0P1/K6`206m_K`80
JFUY0P1NGUh2061PH080GEeM0P1kNg/206=SH`0307YjNP1TI6@0I6AT0080OGem0P1hN7P207AdM080
PH610P2?Shl20820P080PH610P2DU9@4096AT@80VIVI0P2KVi/20:FUY@80XJ6Q00<0UiNG0:FUY@2U
YJD00P2QXJ4209fMW@80WYjN0P2QXJ420:NWY`80XJ6Q5@3oool001<0oooo0P2QXJ4209^KV`80XJ6Q
0P2GUiL20:NWY`80XJ6Q0P2NWYh20:FUY@0309jNWP2QXJ40XJ6Q0080WYjN0P2UYJD40:6QX@80WIfM
0P2IVIT40::RXPH0WYjN0P2QXJ4209ZJVP80YJFU00<0UiNG0:6QX@2QXJ40102QXJ4209NGU`80TY:B
0P2>SXh2065QH@80KVi^0P1FEUH204m?C`80Bd];0P1:BTX203Lg=`80=3@d0P12@T800`13@d<0>CTi
03Ti>@0202TY:@808R8R0P3Ph>0207YjNP80Rh^;0P1lO7`207inOP80QhN70P21PH4207moO`80P820
0P1oOgl40820P00307emO@1jNWX0NWYj0080QHF50P1oOgl207]kN`80PH610P1oOgl207emO@80QXJ6
0P1fMWH20820P080MWIf0P1gMgL207YjNP80M7Ad0P1hN7P00`1gMgL0Lg=c07=cL`0206m_K`80HF5Q
0P1YJFT206QXJ080O7al0P1bLW8205eMG@80HF5Q0P1PH60206=SH`80FUYJ0P18B4P205ADE080ATI6
00<0DE5A06i^KP1^KVh00P1<C4`205=CD`80BTY:0P1?Cdl2069RHP80Cdm?0P1TI6@206UYJ@80JVYZ
0P1UIFD2075aL@80HV9R0P1_Kfl206=SH`0306m_K`1YJFT0JFUY0080JFUY0P1gMgL208J6QP80M7Ad
0P26QXH207alO080Shn?0P2CTi<20:BTY080Vi^K0P2DU9@20:2PX080Y:BT0P2QXJ400`2UYJD0XJ6Q
0:6QX@0209jNWP80WinO0P2MWId209^KV`@0XJ6Q5@3oool001<0oooo0P2QXJ4209^KV`80XJ6Q0P2G
UiL20:NWY`80XJ6Q0P2NWYh20:FUY@0309jNWP2QXJ40XJ6Q0080WYjN0P2UYJD40:6QX@80WIfM0P2I
VIT40::RXPH0WYjN0P2QXJ4209ZJVP80YJFU00<0UiNG0:6QX@2QXJ40102QXJ4209NGU`80TY:B0P2>
SXh2065QH@80KVi^0P1FEUH204m?C`80Bd];0P1:BTX203Lg=`80=3@d0P12@T800`13@d<0>CTi03Ti
>@0202TY:@808R8R0P3Ph>0207YjNP80Rh^;0P1lO7`207inOP80QhN70P21PH4207moO`80P8200P1o
Ogl40820P00307emO@1jNWX0NWYj0080QHF50P1oOgl207]kN`80PH610P1oOgl207emO@80QXJ60P1f
MWH20820P080MWIf0P1gMgL207YjNP80M7Ad0P1hN7P00`1gMgL0Lg=c07=cL`0206m_K`80HF5Q0P1Y
JFT206QXJ080O7al0P1bLW8205eMG@80HF5Q0P1PH60206=SH`80FUYJ0P18B4P205ADE080ATI600<0
DE5A06i^KP1^KVh00P1<C4`205=CD`80BTY:0P1?Cdl2069RHP80Cdm?0P1TI6@206UYJ@80JVYZ0P1U
IFD2075aL@80HV9R0P1_Kfl206=SH`0306m_K`1YJFT0JFUY0080JFUY0P1gMgL208J6QP80M7Ad0P26
QXH207alO080Shn?0P2CTi<20:BTY080Vi^K0P2DU9@20:2PX080Y:BT0P2QXJ400`2UYJD0XJ6Q0:6Q
X@0209jNWP80WinO0P2MWId209^KV`@0XJ6Q5@3oool001<0oooo0P2QXJ4209jNWP80YJFU0P2KVi/2
0:6QX@@0WYjN0P2UYJD00`2MWId0WYjN09jNWP080:6QX@80WYjN0P2QXJ4209ZJVP80WYjN0P2QXJ42
09fMW@80WYjN0P2UYJD209ZJVP80XZ:R00<0W9bL0::RXP2RXZ800P2RXZ820:6QX@80W9bL0P2BTY82
08>3P`80GemO0P1RHV8205YJFP80D51@0P1=CDd204m?C`@0>3Ph0P1?Cdl00`0i>CT0:2PX02PX:002
02XZ:P8092@T0P3Vi^H207YjNP80RXZ:0P1iNGT208J6QP80Q8B40P21PH4207QhN080Ph>30P25QHD2
07inOP80OGem00<0Ogmo07YjNP1jNWX00P1mOGd20861P@80NWYj0P1gMgL207YjNP80O7al0P1iNGT2
07emO@80M7Ad0P1hN7P207MgM`80NWYj0P1cLg<207AdM00306i^KP1_Kfl0Kfm_0080JFUY0P1NGUh2
065QH@80MWIf0P1SHf<205eMG@80EeMG0P1VIVH205QHF080HF5Q0P18B4P205EEE@80Bd];0P1=CDd0
0`1@D500Jf][06][J`0206EUI@80F5QH0P1:BTX205MGE`80GUiN0P1MGEd206IVIP80EEEE0P1aLG42
06YZJP80Q8B4101^KVh205aLG00306UYJ@1fMWH0MWIf0080GEeM0P1cLg<209BDU080PX:20P2<S8`2
08^;R`80V9RH0P2GUiL2096AT@80X:2P0P2CTi<20::RXP80WIfM0P2OWil30:6QX@80VYZJ0P2QXJ42
0:BTY080XJ6Q0P2TY:@20:FUYAD0oooo000C0?ooo`80XJ6Q0P2MWId20:6QX@80WYjN0P2UYJD209fM
W@80VYZJ0P2UYJD00`2QXJ40WIfM09fMW@0209jNWP80YJFU102QXJ4209fMW@80XJ6Q102MWId40:6Q
X@80VYZJ0P2UYJD209ZJVP80WYjN00<0XJ6Q09VIV@2IVIT00P2NWYh20::RXP80Vi^K0P2<S8`207Mg
M`80I6AT0P1YJFT205IFEP@0C4a<0P1?Cdl203@d=080Bd];0P13@d<00`0e=CD0820P020P800202l_
;`808B4Q0P3UiND207inOP80PH610P1hN7P20861P@80Ogmo0P28R8P207MgM`80Lg=c0P25QHD207Qh
N080MgMg00<0O7al07MgM`1gMgL00P1dM7@207emO@80MgMg0P1jNWX207AdM080NWYj0P1dM7@207em
O@80M7Ad101aLG42079bLP80NGUi0P1_Kfl306i^KP80I6AT0P1LG5`206UYJ@80JVYZ0P1HF5P2059B
DP80EEEE0P1DE5@205=CD`80B4Q80P1@D502059BDP80@D510P1BDU800`1FEUH0KFe]06e]K@0206EU
I@80HF5Q0P1KFe/2055AD@80FUYJ0P1EEED205iNGP80HV9R0P1YJFT2061PH080R8R80P1iNGT206m_
K`80HV9R00<0MgMg07QhN01hN7P00P1PH60207MgM`80RXZ:0P21PH4209JFUP80UIFE0P2KVi/209RH
V080WinO0P2PX:0209VIV@@0WIfM0P2UYJD00`2NWYh0YJFU0:FUY@0209fMW@80Vi^K0P2JVYX209bL
W080XJ6Q0P2NWYhE0?ooo`004`3oool20:6QX@80WIfM0P2QXJ4209jNWP80YJFU0P2MWId209ZJVP80
YJFU00<0XJ6Q09fMW@2MWId00P2NWYh20:FUY@@0XJ6Q0P2MWId20:6QX@@0WIfM102QXJ4209ZJVP80
YJFU0P2JVYX209jNWP030:6QX@2IVIT0VIVI0080WYjN0P2RXZ8209^KV`80S8b<0P1gMgL206ATI080
JFUY0P1FEUH404a<C080Cdm?0P0d=3@204];B`80@d=300<0=CDe020P800P82000P0_;bl2024Q8@80
iNGU0P1nOWh20861P@80N7Qh0P21PH4207moO`80R8R80P1gMgL207=cL`80QHF50P1hN7P207MgM`03
07alO01gMgL0MgMg0080M7Ad0P1mOGd207MgM`80NWYj0P1dM7@207YjNP80M7Ad0P1mOGd207AdM0@0
LG5a0P1bLW8207UiN@80Kfm_0`1^KVh206ATI080G5aL0P1YJFT206YZJP80F5QH0P1BDU8205EEE@80
E5AD0P1CDe<204Q8B080D51@0P1BDU820451@@80DU9B00<0EUIF06e]K@1]KFd00P1UIFD2065QH@80
Fe]K0P1ADE4205YJFP80EEEE0P1NGUh2069RHP80JFUY0P1PH60208R8R080NGUi0P1_Kfl2069RHP03
07MgM`1hN7P0N7Qh0080H61P0P1gMgL208Z:RP80PH610P2FUYH209FEU@80Vi^K0P2HV9P209nOW`80
X:2P0P2IVIT409fMW@80YJFU00<0WYjN0:FUY@2UYJD00P2MWId209^KV`80VYZJ0P2LW9`20:6QX@80
WYjN5@3oool001<0oooo1P2QXJ4209fMW@80WYjN0P2RXZ820:6QX@80WYjN00<0XJ6Q0:NWY`2WYjL0
0P2MWId40:6QX@80WYjN0P2UYJD80:6QX@80WYjN102QXJ4209ZJVP80Vi^K00<0YZJV09ZJVP2JVYX0
0P2SXj<209jNWP80XJ6Q0P2FUYH205]KF`80IfMW0P1TI6@205iNGP80@T920P1ADE4204A4A080>SXj
0P1?Cdl203Ti>@03030`<00W9bL09bLW0080=3@d0P0T92@20>3Ph080NGUi0P2:RXX207emO@80QHF5
0P1jNWX207moO`80R8R80P1cLg<207moO`80NWYj0P1eMGD307MgM`80M7Ad0P1bLW8207EeM@80Ng]k
0P1aLG4207AdM080N7Qh101gMgL206i^KP80LW9b0P1]KFd207=cL`<0Kfm_0P1UIFD206QXJ080G5aL
0P1aLG4205eMG@80D51@0P1>CTh2051@D080CTi>0P19BDT204a<C080Bd];0P13@d<20451@@80C4a<
00<0EUIF06YZJP1ZJVX00P1]KFd2061PH080K6a/0P1HF5P205iNGP80C4a<0P1EEED205YJFP80LG5a
0P1^KVh207=cL`80MGEe0P1gMgL206QXJ00307EeM@1[Jf/0Jf][0080Lg=c0P21PH4208^;R`80QXJ6
0P2NWYh209BDU080WinO0P2FUYH209FEU@80V9RH0P2WYjL20:6QX@80VYZJ0P2UYJD00`2MWId0XJ6Q
0:6QX@040:6QX@80VYZJ102QXJ4209ZJVQD0oooo000C0?ooo`H0XJ6Q0P2MWId209jNWP80XZ:R0P2Q
XJ4209jNWP030:6QX@2WYjL0YjNW0080WIfM102QXJ4209jNWP80YJFU202QXJ4209jNWP@0XJ6Q0P2J
VYX209^KV`030:JVYP2JVYX0VYZJ0080Xj>S0P2NWYh20:6QX@80UYJF0P1KFe/206MWI`80I6AT0P1N
GUh20492@P80DE5A0P14A4@203Xj>P80Cdm?0P0i>CT00`0`<3009bLW02LW9`0203@d=08092@T0P3P
h>0207UiN@80RXZ:0P1mOGd208F5Q@80NWYj0P1oOgl208R8R080Lg=c0P1oOgl207YjNP80MGEe0`1g
MgL207AdM080LW9b0P1eMGD207]kN`80LG5a0P1dM7@207QhN0@0MgMg0P1^KVh2079bLP80KFe]0P1c
Lg<306m_K`80IFEU0P1XJ6P205aLG080LG5a0P1MGEd2051@D080CTi>0P1@D50204i>CP80BDU90P1<
C4`204];B`80@d=30P11@D4204a<C00305IFEP1ZJVX0JVYZ0080KFe]0P1PH60206a/K080F5QH0P1N
GUh204a<C080EEEE0P1JFUX2075aL@80KVi^0P1cLg<207EeM@80MgMg0P1XJ6P00`1eMGD0Jf][06][
J`0207=cL`80PH610P2;Rh/208J6QP80WYjN0P2DU9@209nOW`80UYJF0P2EUID209RHV080YjNW0P2Q
XJ4209ZJVP80YJFU00<0WIfM0:6QX@2QXJ40102QXJ4209ZJVP@0XJ6Q0P2JVYXE0?ooo`004`3oool2
0:6QX@80WYjN0P2RXZ820:FUY@80VYZJ0P2NWYh20:FUY@80WIfM00<0Vi^K09jNWP2NWYh00P2QXJ42
0:NWY`80XJ6Q0P2JVYX20:FUY@80XJ6Q0P2NWYh20::RXP80XJ6Q0P2NWYh20:NWY`H0WYjN00<0WIfM
09NGU`2GUiL00P2UYJD209NGU`80WinO0P2>SXh205mOG`80IVIV0P1HF5P205UIF@80ADE50P1CDe<2
03Hf=P@0B4Q80P0m?Cd00`0R8R809RHV02HV9P0202l_;`80;Bd]0P3Lg=`2075aL@80QhN70P1hN7P2
08J6QP80OGem0P1fMWH20861P@80NWYj0P1dM7@207emO@80M7Ad00<0LG5a07QhN01hN7P00P1aLG44
071`L080K6a/101_Kfl207UiN@80Lg=c0P1eMGD206a/K080Kfm_0P1YJFT406e]K@0306YZJP1UIFD0
IFEU00@0HF5Q0P1JFUX205MGE`80DU9B0P19BDT204m?C`80D51@0P1:BTX204Q8B080Bd];0P15ADD2
04Q8B080Cdm?00<0DE5A069RHP1RHV800P1]KFd206m_K`80HF5Q0P1YJFT2059BDP80ADE50P1CDe<2
05IFEP80KFe]0P1XJ6P207alO0H0MWIf00<0J6QX06UYJ@1YJFT00P1]KFd2096AT@80QXJ60P27QhL2
0:6QX@80V9RH0P2CTi<20:RXZ080V9RH0P2QXJ4209ZJVP80YJFU0P2MWId30:6QX@80WYjN0P2UYJD2
0:6QX@@0WIfM0P2WYjL209ZJVQD0oooo000C0?ooo`80XJ6Q0P2NWYh20::RXP80YJFU0P2JVYX209jN
WP80YJFU0P2MWId00`2KVi/0WYjN09jNWP020:6QX@80YjNW0P2QXJ4209ZJVP80YJFU0P2QXJ4209jN
WP80XZ:R0P2QXJ4209jNWP80YjNW1P2NWYh00`2MWId0UiNG09NGU`020:FUY@80UiNG0P2OWil208j>
SP80GemO0P1VIVH205QHF080FEUI0P15ADD205=CD`80=SHf1018B4P203dm?@03028R8P0V9RH09RHV
0080;bl_0P0];Bd20=cLg080LG5a0P27QhL207QhN080QXJ60P1mOGd207IfMP80PH610P1jNWX207Ad
M080OGem0P1dM7@00`1aLG40N7Qh07QhN002075aL@@0L71`0P1/K6`406m_K`80NGUi0P1cLg<207Ee
M@80K6a/0P1_Kfl206UYJ@@0KFe]00<0JVYZ06EUI@1UIFD0101QHF4205YJFP80EeMG0P1BDU8204U9
B@80Cdm?0P1@D50204Y:BP80B4Q80P1;Bd/204E5A@80B4Q80P1?Cdl00`1ADE40HV9R069RHP0206e]
K@80Kfm_0P1QHF4206UYJ@80DU9B0P15ADD205=CD`80EUIF0P1]KFd206QXJ080O7al1P1fMWH00`1X
J6P0JFUY06UYJ@0206e]K@80TI6A0P26QXH208N7Q`80XJ6Q0P2HV9P209>CT`80Z:RX0P2HV9P20:6Q
X@80VYZJ0P2UYJD209fMW@<0XJ6Q0P2NWYh20:FUY@80XJ6Q102MWId20:NWY`80VYZJ5@3oool001<0
oooo0P2RXZ820:6QX@80WIfM102NWYh209fMW@80XZ:R0P2SXj<00`2TY:@0XJ6Q0:6QX@0209^KV`80
XJ6Q0P2MWId20:>SX`80WYjN0P2UYJD209ZJVP80XJ6Q0P2GUiL40:6QX@@0WIfM0P2QXJ400`2NWYh0
WIfM09fMW@020:BTY080VIVI0P2MWId2075aL@80Jf][0P1QHF4205aLG080Cdm?0P15ADD205EEE@80
>c/k0P1CDe<203Lg=`80>CTi00<07AdM028R8P0R8R800P0/;2`202XZ:P80gmoO0P1`L70208>3P`80
NGUi0P1mOGd407YjNP80M7Ad0P1iNGT207AdM080MgMg0P1dM7@00`1/K6`0LW9b079bLP0206m_K`80
LW9b0P1^KVh206UYJ@80I6AT0P1YJFT406e]K@80MGEe0P1^KVh606UYJ@80HF5Q0`1TI6@205YJFP80
IfMW0P1:BTX204Q8B080ATI60P1CDe<204M7A`80E5AD0P1@D502030`<080?3`l0P15ADD205MGE`80
GEeM00<0E5AD05]KF`1KFe/00P1XJ6P207UiN@80Lg=c101aLG420492@P80B4Q80P1PH60206=SH`80
JFUY0P1TI6@208b<S080MWIf0`1XJ6P206UYJ@80J6QX0P2JVYX208b<S080V9RH0P2;Rh/209nOW`80
TY:B0P2MWId209bLW080YjNW0P2GUiL20:BTY080YjNW0P2QXJ400`2NWYh0XJ6Q0:6QX@040:6QX@80
WYjN0P2OWil20:6QX@80WIfM5@3oool001<0oooo0P2RXZ820:6QX@80WIfM102NWYh209fMW@80XZ:R
0P2SXj<00`2TY:@0XJ6Q0:6QX@0209^KV`80XJ6Q0P2MWId20:>SX`80WYjN0P2UYJD209ZJVP80XJ6Q
0P2GUiL40:6QX@@0WIfM0P2QXJ400`2NWYh0WIfM09fMW@020:BTY080VIVI0P2MWId2075aL@80Jf][
0P1QHF4205aLG080Cdm?0P15ADD205EEE@80>c/k0P1CDe<203Lg=`80>CTi00<07AdM028R8P0R8R80
0P0/;2`202XZ:P80gmoO0P1`L70208>3P`80NGUi0P1mOGd407YjNP80M7Ad0P1iNGT207AdM080MgMg
0P1dM7@00`1/K6`0LW9b079bLP0206m_K`80LW9b0P1^KVh206UYJ@80I6AT0P1YJFT406e]K@80MGEe
0P1^KVh606UYJ@80HF5Q0`1TI6@205YJFP80IfMW0P1:BTX204Q8B080ATI60P1CDe<204M7A`80E5AD
0P1@D502030`<080?3`l0P15ADD205MGE`80GEeM00<0E5AD05]KF`1KFe/00P1XJ6P207UiN@80Lg=c
101aLG420492@P80B4Q80P1PH60206=SH`80JFUY0P1TI6@208b<S080MWIf0`1XJ6P206UYJ@80J6QX
0P2JVYX208b<S080V9RH0P2;Rh/209nOW`80TY:B0P2MWId209bLW080YjNW0P2GUiL20:BTY080YjNW
0P2QXJ400`2NWYh0XJ6Q0:6QX@040:6QX@80WYjN0P2OWil20:6QX@80WIfM5@3oool001<0oooo0P2M
WId40:6QX@80WIfM0P2JVYX20:2PX0@0Vi^K00<0WIfM0:6QX@2QXJ40102QXJ4209^KV`80WIfM0P2P
X:020:FUY@80VIVI0P2WYjL209VIV@80YJFU0P2NWYh20:FUY@80WYjN0P2QXJ400`2PX:00WinO09nO
W`0209NGU`80X:2P0P2ATI4206][J`80LG5a0P1FEUH205UIF@80CDe=0P18B4P404=3@`80D51@0P0d
=3@202d];@0302@T900Z:RX0:RXZ0080;2`/0P0^;Rh20<[:bP80NGUi0P1mOGd207inOP80Ogmo0P1h
N7P207IfMP80N7Qh0P1`L70207AdM080KVi^0P1dM7@00`1`L700J6QX06QXJ00206e]K@80Kfm_0P1U
IFD2071`L080J6QX0P1TI6@2071`L080JFUY0P1UIFD207AdM0@0JFUY0P1QHF42061PH003065QH@1O
Gel0GemO0080D51@0P1^KVh204=3@`80=cLg0P1BDU8204m?C`80ATI60P17AdL203/k>`80<c<c0P0T
92@205UIF@80G5aL0P1=CDd00`1UIFD0DE5A055AD@0206IVIP80Lg=c0P1iNGT206EUI@80Ogmo0P1@
D50205MGE`80IfMW0P1KFe/206m_K`80H61P0P25QHD406UYJ@0305mOG`1/K6`0K6a/0080Ng]k0P2@
T90208n?S`80WIfM0P2BTY8209RHV080Xj>S0P2IVIT209bLW080YjNW0P2GUiL209fMW@80YJFU0P2Q
XJ4309fMW@80YjNW0P2NWYh20:6QX@80WYjN0P2UYJD20:6QXAD0oooo000C0?ooo`80WIfM102QXJ42
09fMW@80VYZJ0P2PX:0409^KV`0309fMW@2QXJ40XJ6Q00@0XJ6Q0P2KVi/209fMW@80X:2P0P2UYJD2
09VIV@80YjNW0P2IVIT20:FUY@80WYjN0P2UYJD209jNWP80XJ6Q00<0X:2P09nOW`2OWil00P2GUiL2
0:2PX080TI6A0P1[Jf/2075aL@80EUIF0P1IFET204e=C@80B4Q81013@d<2051@D080=3@d0P0];Bd0
0`0T92@0:RXZ02XZ:P0202`/;080;Rh^0P3:b/X207UiN@80OGem0P1nOWh207moO`80N7Qh0P1fMWH2
07QhN080L71`0P1dM7@206i^KP80M7Ad00<0L71`06QXJ01XJ6P00P1]KFd206m_K`80IFEU0P1`L702
06QXJ080I6AT0P1`L70206UYJ@80IFEU0P1dM7@406UYJ@80HF5Q0P1PH6000`1QHF40GemO05mOG`02
051@D080KVi^0P13@d<203Lg=`80DU9B0P1?Cdl204I6AP80AdM70P0k>c/203<c<`8092@T0P1IFET2
05aLG080CDe=00<0IFEU055AD@1ADE400P1VIVH207=cL`80NGUi0P1UIFD207moO`80D51@0P1GEeL2
06MWI`80Fe]K0P1_Kfl2061PH080QHF5101YJFT00`1OGel0K6a/06a/K00207]kN`80T92@0P2?Shl2
09fMW@80TY:B0P2HV9P20:>SX`80VIVI0P2LW9`20:NWY`80UiNG0P2MWId20:FUY@80XJ6Q0`2MWId2
0:NWY`80WYjN0P2QXJ4209jNWP80YJFU0P2QXJ4E0?ooo`004`3oool40:6QX@80WYjN0P2UYJD209ZJ
VP80XZ:R0P2QXJ420:BTY0030::RXP2UYJD0YJFU0080WYjN0P2UYJD20:6QX@80W9bL0P2MWId20:6Q
X@80UiNG0P2SXj<20:2PX080XJ6Q0P2SXj<20:6QX@80VYZJ0P2PX:0509fMW@80Vi^K0P1lO7`406a/
K080DE5A0P1IFET204M7A`80C4a<0P13@d<20410@080ATI60P0Z:RX202h^;P0302PX:00^;Rh0;Rh^
0080;Bd]0P0^;Rh20<C4a080N7Qh0P1iNGT20861P@80LW9b0P1hN7P2075aL@80Ng]k0P1aLG4207Ad
M080Kfm_0P1/K6`00`1`L700I6AT06ATI002061PH080Hf=S0P1VIVH205aLG080IfMW0P1QHF4406MW
I`80IVIV0P1XJ6P206=SH`80IfMW0P1PH60205UIF@0305mOG`1GEeL0EeMG0080EeMG0P1/K6`203lo
?`80<C4a0P1EEED2059BDP@0=cLg0P0`<30203Ti>@80=CDe0P1?Cdl206UYJ@80D51@00<0EEEE05QH
F01HF5P00P1?Cdl207inOP80N7Qh0P1fMWH206YZJP80HF5Q0P1LG5`206][J`80HV9R0P1VIVH207]k
N`80MWIf0P1MGEd206m_K`0305aLG01bLW80LW9b0080MgMg0P2FUYH20:^[Z`80Q8B40P2FUYH209^K
V`80V9RH0P2WYjL209bLW080XJ6Q0P2MWId209ZJVP80YJFU0`2QXJ4209^KV`80XJ6Q0P2MWId20:6Q
X@80VYZJ0P2UYJD209jNWQD0oooo000C0?ooo`@0XJ6Q0P2NWYh20:FUY@80VYZJ0P2RXZ820:6QX@80
Y:BT00<0XZ:R0:FUY@2UYJD00P2NWYh20:FUY@80XJ6Q0P2LW9`209fMW@80XJ6Q0P2GUiL20:>SX`80
X:2P0P2QXJ420:>SX`80XJ6Q0P2JVYX20:2PX0D0WIfM0P2KVi/207alO0@0K6a/0P1ADE4205UIF@80
AdM70P1<C4`204=3@`80@4100P16ATH202XZ:P80;Rh^00<0:2PX02h^;P0^;Rh00P0];Bd202h^;P80
a<C40P1hN7P207UiN@80PH610P1bLW8207QhN080LG5a0P1kNg/2075aL@80M7Ad0P1_Kfl206a/K003
071`L01TI6@0I6AT0080H61P0P1SHf<206IVIP80G5aL0P1WIfL2065QH@@0IfMW0P1VIVH206QXJ080
Hf=S0P1WIfL2061PH080FEUI00<0GemO05MGE`1GEeL00P1GEeL206a/K080?clo0P0a<C4205EEE@80
DU9B100g=cL2030`<080>CTi0P0e=CD204m?C`80JFUY0P1@D5000`1EEED0F5QH05QHF00204m?C`80
OWin0P1hN7P207IfMP80JVYZ0P1QHF4205aLG080Jf][0P1RHV8206IVIP80Ng]k0P1fMWH205eMG@80
Kfm_00<0G5aL079bLP1bLW800P1gMgL209JFUP80Zj^[0P24Q8@209JFUP80Vi^K0P2HV9P20:NWY`80
W9bL0P2QXJ4209fMW@80VYZJ0P2UYJD30:6QX@80Vi^K0P2QXJ4209fMW@80XJ6Q0P2JVYX20:FUY@80
WYjN5@3oool001<0oooo0P2RXZ820:FUY@80WIfM0P2KVi/209nOW`80YJFU0P2HV9P20:6QX@0309fM
W@2NWYh0WYjN0080WYjN0P2UYJD20:6QX@80WIfM0P2WYjL209jNWP80WinO0P2GUiL20:2PX080Vi^K
0P2WYjL20:6QX@80VYZJ0P2RXZ800`2QXJ40WIfM09fMW@0209nOW`80UYJF0P1bLW8206QXJ080GemO
0P1?Cdl205EEE@80BTY:0P17AdL205EEE@80=CDe0P15ADD201PH6080>CTi00<0:BTY02d];@0];Bd0
0P0Y:BT203lo?`80];Bd0P25QHD207UiN@80PH610P1iNGT207QhN080MGEe0P1bLW8407MgM`80Lg=c
0`1dM7@206a/K080HV9R0P1LG5`205EEE@80G5aL0P1NGUh2061PH080GemO0P1LG5`4069RHP80IFEU
101LG5`205]KF`0305=CD`1>CTh0CTi>0080De=C0P1XJ6P2034a<@80>CTi0P1ADE4204I6AP80<S8b
0P0Y:BT202l_;`80DU9B0P0`<30205ADE080JFUY0P1JFUX00`1ADE40De=C05=CD`0205EEE@80MGEe
0P1gMgL207moO`80JVYZ0P1VIVH205ADE080I6AT0P1FEUH205MGE`80VYZJ0P1fMWH205aLG080Kfm_
00<0MGEe07IfMP1fMWH00P21PH420:2PX080VYZJ0P2=SHd2096AT@80X:2P0P2IVIT20:BTY080YJFU
0P2NWYh20:FUY@80WIfM102QXJ400`2NWYh0YJFU0:FUY@060:6QX@80WIfM0P2NWYh209fMWAD0oooo
000C0?ooo`80XZ:R0P2UYJD209fMW@80Vi^K0P2OWil20:FUY@80V9RH0P2QXJ400`2MWId0WYjN09jN
WP0209jNWP80YJFU0P2QXJ4209fMW@80YjNW0P2NWYh209nOW`80UiNG0P2PX:0209^KV`80YjNW0P2Q
XJ4209ZJVP80XZ:R00<0XJ6Q09fMW@2MWId00P2OWil209JFUP80LW9b0P1XJ6P205mOG`80Cdm?0P1E
EED204Y:BP80AdM70P1EEED203De=@80ADE50P0H61P203Ti>@0302TY:@0];Bd0;Bd]0080:BTY0P0o
?cl20;Bd]080QHF50P1iNGT20861P@80NGUi0P1hN7P207EeM@80LW9b101gMgL207=cL`<0M7Ad0P1/
K6`2069RHP80G5aL0P1EEED205aLG080GUiN0P1PH60205mOG`80G5aL101RHV8206EUI@@0G5aL0P1K
Fe/00`1CDe<0CTi>04i>CP0205=CD`80J6QX0P0a<C4203Ti>@80DE5A0P16ATH2038b<P80:BTY0P0_
;bl2059BDP80<30`0P1DE5@206UYJ@80FUYJ00<0DE5A05=CD`1CDe<00P1EEED207EeM@80MgMg0P1o
Ogl206YZJP80IVIV0P1DE5@206ATI080EUIF0P1GEeL209ZJVP80MWIf0P1LG5`206m_K`0307EeM@1f
MWH0MWIf0080PH610P2PX:0209ZJVP80SHf=0P2ATI420:2PX080VIVI0P2TY:@20:FUY@80WYjN0P2U
YJD209fMW@@0XJ6Q00<0WYjN0:FUY@2UYJD01P2QXJ4209fMW@80WYjN0P2MWIdE0?ooo`004`3oool2
09fMW@80WYjN0P2RXZ8209jNWP80VIVI0P2QXJ4209ZJVP80YJFU00<0XJ6Q09fMW@2MWId00P2MWId4
0:6QX@80V9RH0P2UYJD209fMW@80WYjN0P2PX:0209fMW@80UYJF0P2YZJT209jNWP80XJ6Q0P2IVIT0
0`2LW9`0WYjN09jNWP0209bLW080Ph>30P1fMWH206UYJ@80GUiN101ADE420451@@80C4a<0P1:BTX2
04I6AP80<c<c0P0M7Ad203Xj>P03030`<00[:b/0:b/[0080:2PX0P1/K6`20:JVYP80QXJ60P2@T902
07moO`80QhN70P24Q8@208N7Q`80PH610P1lO7`207moO`80LW9b0P1jNWX00`1iNGT0M7Ad07AdM002
079bLP80Jf][0P1JFUX205QHF080DE5A0P1FEUH205mOG`80Fe]K0P1JFUX205]KF`80EEEE0P1PH602
05]KF`80FEUI00<0DU9B04a<C01<C4`00P18B4P206=SH`80=3@d0P14A4@205EEE@80;Bd]0P0_;bl2
02LW9`80>3Ph0P1OGel202XZ:P80De=C0P1NGUh2069RHP0304a<C01>CTh0CTi>0080FEUI0P1/K6`2
075aL@80RXZ:0P1iNGT207AdM0@0HF5Q0P1;Bd/205mOG`80P8200P1eMGD206QXJ080JFUY00<0RHV9
06ATI01TI6@00P2EUID20;fm_@80SXj>0P2CTi<20:JVYP80Vi^K0P2WYjL209ZJVP80YJFU0P2IVIT2
0:BTY080XJ6Q0P2TY:@20::RXP<0XJ6Q0P2NWYh20:FUY@@0XJ6Q0P2MWId209^KVaD0oooo000C0?oo
o`80WIfM0P2NWYh20::RXP80WYjN0P2IVIT20:6QX@80VYZJ0P2UYJD00`2QXJ40WIfM09fMW@0209fM
W@@0XJ6Q0P2HV9P20:FUY@80WIfM0P2NWYh20:2PX080WIfM0P2FUYH20:VYZ@80WYjN0P2QXJ4209VI
V@0309bLW02NWYh0WYjN0080W9bL0P23Ph<207IfMP80JFUY0P1NGUh4055AD@80@D510P1<C4`204Y:
BP80ATI60P0c<c<201dM7@80>SXj00<0<30`02/[:`0[:b/00P0X:2P206a/K080YZJV0P26QXH2092@
T080Ogmo0P27QhL208B4Q080QhN70P21PH4207alO080Ogmo0P1bLW8207YjNP0307UiN@1dM7@0M7Ad
0080LW9b0P1[Jf/205YJFP80F5QH0P1ADE4205IFEP80GemO0P1KFe/205YJFP80Fe]K0P1EEED2061P
H080Fe]K0P1IFET00`1BDU80C4a<04a<C00204Q8B080Hf=S0P0d=3@204A4A080EEEE0P0];Bd202l_
;`809bLW0P0h>3P205mOG`80:RXZ0P1CDe<205iNGP80HV9R00<0C4a<04i>CP1>CTh00P1IFET206a/
K080LG5a0P2:RXX207UiN@80M7Ad101QHF4204];B`80GemO0P20P80207EeM@80J6QX0P1YJFT00`29
RHT0I6AT06ATI00209FEU@80_Kfm0P2>SXh209>CT`80YZJV0P2KVi/20:NWY`80VYZJ0P2UYJD209VI
V@80Y:BT0P2QXJ420:BTY080XZ:R0`2QXJ4209jNWP80YJFU102QXJ4209fMW@80Vi^K5@3oool001<0
oooo0P2RXZ820:6QX@80VIVI0P2WYjL209jNWP80XJ6Q0P2SXj<209fMW@030:NWY`2QXJ40XJ6Q00@0
XJ6Q0P2NWYh209fMW@80YjNW102NWYh20:FUY@80WYjN0P2KVi/20:FUY@80VYZJ0P2QXJ4309fMW@80
X:2P0P2NWYh207=cL`80IfMW0P1QHF4205mOG`80CTi>0P1@D50204M7A`80A4A40P10@40204a<C080
7QhN0P0];Bd203Xj>P0302/[:`0];Bd0;Bd]0080GUiN0P23Ph<208b<S080Rh^;102=SHd208:2PP80
SXj>0P1oOgl208f=S@80Q8B40P25QHD207inOP80Ogmo00<0MWIf07YjNP1jNWX00P1cLg<207AdM080
Jf][0P1YJFT205QHF080De=C0P1:BTX405UIF@80FUYJ0P1IFET205=CD`80GUiN0P1EEED00`1<C4`0
Cdm?04m?C`0203/k>`80@4100P1NGUh203`l?080KVi^0P0O7al202TY:@807QhN0P0[:b/206a/K080
@D510P0k>c/205eMG@80KFe]00<0@T92069RHP1RHV800P1<C4`206UYJ@80LW9b1021PH4207IfMP80
Hf=S0P17AdL206EUI@80HV9R0P1cLg<206QXJ080N7Qh0P1fMWH00`20P800K6a/06a/K0020:VYZ@80
UiNG0P2<S8`209ZJVP80WinO0P2HV9P20:FUY@@0WIfM0P2QXJ4209fMW@80Vi^K0P2MWId209ZJVP03
0::RXP2UYJD0YJFU0080WIfM102QXJ4209jNWP80YJFU0P2QXJ4E0?ooo`004`3oool20::RXP80XJ6Q
0P2IVIT20:NWY`80WYjN0P2QXJ420:>SX`80WIfM00<0YjNW0:6QX@2QXJ40102QXJ4209jNWP80WIfM
0P2WYjL409jNWP80YJFU0P2NWYh209^KV`80YJFU0P2JVYX20:6QX@<0WIfM0P2PX:0209jNWP80Lg=c
0P1WIfL2065QH@80GemO0P1>CTh2051@D080AdM70P14A4@20410@080C4a<0P0N7Qh202d];@80>SXj
00<0:b/[02d];@0];Bd00P1NGUh208>3P`80S8b<0P2;Rh/408f=S@80PX:20P2>SXh207moO`80SHf=
0P24Q8@208F5Q@80OWin0P1oOgl00`1fMWH0NWYj07YjNP0207=cL`80M7Ad0P1[Jf/206UYJ@80F5QH
0P1CDe<204Y:BP@0FEUI0P1JFUX205UIF@80De=C0P1NGUh205EEE@0304a<C01?Cdl0Cdm?0080>c/k
0P10@40205iNGP80?3`l0P1^KVh201lO7`80:BTY0P0N7Qh202/[:`80K6a/0P11@D4203/k>`80GEeM
0P1]KFd00`12@T80HV9R069RHP0204a<C080JFUY0P1bLW840861P@80MWIf0P1SHf<204M7A`80IFEU
0P1RHV8207=cL`80J6QX0P1hN7P207IfMP030820P01/K6`0K6a/0080ZJVY0P2GUiL208b<S080VYZJ
0P2OWil209RHV080YJFU102MWId20:6QX@80WIfM0P2KVi/209fMW@80VYZJ00<0XZ:R0:FUY@2UYJD0
0P2MWId40:6QX@80WYjN0P2UYJD20:6QXAD0oooo000C0?ooo`80WIfM0P2NWYh20:2PX080XJ6Q0P2M
WId209bLW080XJ6Q0P2GUiL00`2TY:@0XJ6Q0:6QX@020:NWY`80XJ6Q0P2MWId209NGU`80Y:BT0P2Q
XJ4209ZJVP80XZ:R102NWYh20:FUY@80WIfM102KVi/00`2GUiL0VYZJ09ZJVP0209FEU@80PX:20P1N
GUh206=SH`80EEEE0P19BDT204A4A080D51@0P18B4P20410@080?3`l0P0N7Qh203/k>`80=cLg00<0
:BTY08J6QP26QXH00P1RHV8208F5Q@80Shn?0P2EUID208b<S080Shn?0P29RHT208n?S`80Ph>30P2=
SHd408Z:RP80PH610P27QhL307moO`80M7Ad0P1aLG4207AdM080MGEe0P1YJFT206ATI080DU9B0P15
ADD2055AD@80De=C0P1MGEd2051@D080FEUI0P1ADE400`1;Bd/0BDU904U9B@02030`<080=3@d0P1j
NWX202PX:080RHV90P0X:2P2024Q8@80;bl_0P0I6AT204];B`80L71`0P0Z:RX206=SH`80JVYZ00<0
B4Q806i^KP1^KVh00P1GEeL2061PH080MGEe0P1lO7`209FEU@80PX:20P1[Jf/204E5A@80F5QH0P1Y
JFT206e]K@80I6AT0P1lO7`207MgM`0307EeM@1nOWh0OWin0080[jn_0P2@T90208n?S`80Xj>S0P2M
WId20:FUY@80WIfM0P2WYjL209VIV@80YJFU0P2QXJ4209jNWP80XZ:R0P2QXJ400`2JVYX0XZ:R0::R
XP020:FUY@@0XJ6Q0P2MWId40:6QXAD0oooo000C0?ooo`80WIfM0P2NWYh20:2PX080XJ6Q0P2MWId2
09bLW080XJ6Q0P2GUiL00`2TY:@0XJ6Q0:6QX@020:NWY`80XJ6Q0P2MWId209NGU`80Y:BT0P2QXJ42
09ZJVP80XZ:R102NWYh20:FUY@80WIfM102KVi/00`2GUiL0VYZJ09ZJVP0209FEU@80PX:20P1NGUh2
06=SH`80EEEE0P19BDT204A4A080D51@0P18B4P20410@080?3`l0P0N7Qh203/k>`80=cLg00<0:BTY
08J6QP26QXH00P1RHV8208F5Q@80Shn?0P2EUID208b<S080Shn?0P29RHT208n?S`80Ph>30P2=SHd4
08Z:RP80PH610P27QhL307moO`80M7Ad0P1aLG4207AdM080MGEe0P1YJFT206ATI080DU9B0P15ADD2
055AD@80De=C0P1MGEd2051@D080FEUI0P1ADE400`1;Bd/0BDU904U9B@02030`<080=3@d0P1jNWX2
02PX:080RHV90P0X:2P2024Q8@80;bl_0P0I6AT204];B`80L71`0P0Z:RX206=SH`80JVYZ00<0B4Q8
06i^KP1^KVh00P1GEeL2061PH080MGEe0P1lO7`209FEU@80PX:20P1[Jf/204E5A@80F5QH0P1YJFT2
06e]K@80I6AT0P1lO7`207MgM`0307EeM@1nOWh0OWin0080[jn_0P2@T90208n?S`80Xj>S0P2MWId2
0:FUY@80WIfM0P2WYjL209VIV@80YJFU0P2QXJ4209jNWP80XZ:R0P2QXJ400`2JVYX0XZ:R0::RXP02
0:FUY@@0XJ6Q0P2MWId40:6QXAD0oooo000C0?ooo`80XJ6Q0P2MWId40:6QX@80WIfM0P2WYjL20:6Q
X@80Vi^K00<0WIfM09bLW02LW9`0102QXJ4209fMW@80WinO0P2MWId20:NWY`80WIfM0P2JVYX20:6Q
X@80WIfM1P2QXJ4209jNWP0309VIV@2DU9@0U9BD00@0O7al0P1GEeL2069RHP80De=C0P17AdL20410
@080BDU91013@d<202TY:@809RHV0P0j>SX202h^;P0305]KF`2m_Kd0_Kfm0080SXj>0P25QHD209>C
T`80TI6A0P2EUID208n?S`80T92@0P2?Shl208N7Q`80RHV90P22PX8208f=S@80QHF50`27QhL20861
P@80OGem0P1kNg/207AdM080MWIf0P1cLg<206][J`80I6AT0P1:BTX205YJFP80?3`l101BDU8204m?
C`80CTi>00<0B4Q803lo?`0o?cl00P0e=CD2030`<080OGem0P0i>CT206IVIP80BDU90P0K6a/2024Q
8@80=3@d0P1:BTX206UYJ@80@d=30P1@D50205]KF`0305MGE`1@D500D51@0080LG5a0P1OGel206e]
K@80M7Ad0P28R8P208j>SP80MGEe0P1:BTX204m?C`80K6a/0P1OGel2079bLP80RXZ:0P1kNg/00`1_
Kfl0OGem07emO@020:BTY080XZ:R0P2FUYH209^KV`80W9bL0P2UYJD209VIV@80YJFU0P2JVYX20:FU
Y@@0WYjN102QXJ4309fMW@80WYjN0P2UYJD40:6QX@80WYjN0P2UYJDE0?ooo`004`3oool20:6QX@80
WIfM102QXJ4209fMW@80YjNW0P2QXJ4209^KV`0309fMW@2LW9`0W9bL00@0XJ6Q0P2MWId209nOW`80
WIfM0P2WYjL209fMW@80VYZJ0P2QXJ4209fMW@H0XJ6Q0P2NWYh00`2IVIT0U9BD09BDU00407alO080
EeMG0P1RHV8205=CD`80AdM70P10@40204U9B@@0@d=30P0Y:BT202HV9P80>SXj0P0^;Rh00`1KFe/0
_Kfm0;fm_@0208j>SP80QHF50P2CTi<2096AT@80UIFE0P2?Shl2092@T080Shn?0P27QhL208V9R@80
PX:20P2=SHd208F5Q@<0QhN70P21PH4207emO@80Ng]k0P1dM7@207IfMP80Lg=c0P1[Jf/206ATI080
BTY:0P1JFUX203`l?0@0DU9B0P1?Cdl204i>CP0304Q8B00o?cl0?clo0080=CDe0P0`<30207emO@80
>CTi0P1VIVH204U9B@806a/K0P0Q8B4203@d=080BTY:0P1YJFT204=3@`80D51@0P1KFe/00`1GEeL0
D51@051@D002075aL@80GemO0P1]KFd207AdM080R8R80P2>SXh207EeM@80BTY:0P1?Cdl206a/K080
GemO0P1bLW8208Z:RP80Ng]k00<0Kfm_07emO@1mOGd00P2TY:@20::RXP80UYJF0P2KVi/209bLW080
YJFU0P2IVIT20:FUY@80VYZJ0P2UYJD409jNWP@0XJ6Q0`2MWId209jNWP80YJFU102QXJ4209jNWP80
YJFU5@3oool001<0oooo0P2SXj<20:NWY`80WYjN0P2UYJD209^KV`80XJ6Q0P2MWId20:NWY`0309jN
WP2RXZ80XZ:R0080YJFU0P2NWYh209bLW080WYjN0P2KVi/20:NWY`@0WYjN0P2QXJ420:NWY`80XJ6Q
0P2KVi/20:VYZ@80VIVI00<0VYZJ08j>SP2>SXh00P1mOGd206a/K080FUYJ0P1NGUh204m?C`80BDU9
0P0k>c/204U9B@80>c/k0P17AdL201/K6`80<30`0P0e=CD203lo?`030::RXP2<S8`0S8b<0080TY:B
0P27QhL408f=S@80UIFE0P2:RXX209RHV080RXZ:0P2@T90209RHV080PX:20P2:RXX208F5Q@80QhN7
00<0R8R80861P@21PH400P1lO7`207QhN080OGem0P1iNGT407AdM080Jf][0P1MGEd206ATI080BTY:
0P0l?3`2055AD@80CDe=0P14A4@00`1;Bd/0=3@d03@d=00203Lg=`808b<S0P1`L70207EeM@80<30`
0P20P802028R8P80=3@d0P0P820205mOG`80@d=30P20P80204M7A`80IfMW00<0GemO05QHF01HF5P0
0P1OGel206][J`80FEUI0P2:RXX206QXJ080W9bL0P2:RXX20410@080C4a<0P1/K6`205iNGP80Kfm_
0P1lO7`208R8R00307YjNP21PH40PH610080V9RH102OWil20:>SX`80WIfM0P2VYZH20:6QX@80WYjN
102QXJ4209ZJVP80WYjN0P2UYJD209jNWP030::RXP2UYJD0YJFU0080VYZJ0P2RXZ820:FUY@80WYjN
102QXJ4E0?ooo`004`3oool20:>SX`80YjNW0P2NWYh20:FUY@80Vi^K0P2QXJ4209fMW@80YjNW00<0
WYjN0::RXP2RXZ800P2UYJD209jNWP80W9bL0P2NWYh209^KV`80YjNW102NWYh20:6QX@80YjNW0P2Q
XJ4209^KV`80ZJVY0P2IVIT00`2JVYX0SXj>08j>SP0207emO@80K6a/0P1JFUX205iNGP80Cdm?0P19
BDT203/k>`80BDU90P0k>c/204M7A`806a/K0P0`<30203De=@80?clo00<0XZ:R08b<S02<S8`00P2B
TY8208N7Q`@0SHf=0P2EUID208Z:RP80V9RH0P2:RXX2092@T080V9RH0P22PX8208Z:RP80QHF50P27
QhL00`28R8P0PH610861P@0207alO080N7Qh0P1mOGd207UiN@@0M7Ad0P1[Jf/205eMG@80I6AT0P1:
BTX203`l?080DE5A0P1=CDd204A4A00304];B`0d=3@0=3@d0080=cLg0P0S8b<2071`L080MGEe0P0`
<3020820P0808R8R0P0d=3@2020P8080GemO0P13@d<20820P080AdM70P1WIfL00`1OGel0F5QH05QH
F00205mOG`80Jf][0P1IFET208Z:RP80J6QX0P2LW9`208Z:RP80@4100P1<C4`206a/K080GUiN0P1_
Kfl207alO080R8R800<0NWYj0861P@21PH400P2HV9P409nOW`80Xj>S0P2MWId20:JVYP80XJ6Q0P2N
WYh40:6QX@80VYZJ0P2NWYh20:FUY@80WYjN00<0XZ:R0:FUY@2UYJD00P2JVYX20::RXP80YJFU0P2N
WYh40:6QXAD0oooo000C0?ooo`80W9bL0P2UYJD209ZJVP80YJFU102QXJ4209VIV@80XZ:R00<0XJ6Q
09fMW@2MWId00P2QXJ4209fMW@80VYZJ0P2NWYh20:2PX080WYjN0P2QXJ4209fMW@80W9bL102QXJ42
09VIV@80WYjN0P2FUYH00`2LW9`0Ph>308>3P`0208J6QP80Fe]K0P1OGel205=CD`80EEEE0P13@d<2
03dm?@80@d=30P0h>3P202l_;`809BDU0P0k>c/203dm?@80RXZ:00<0QhN708^;R`2;Rh/00P2?Shl4
08f=S@80RXZ:0P2BTY8208J6QP80TI6A102:RXX2096AT@80RHV90P22PX8208R8R080RHV900<0SHf=
08:2PP22PX800P29RHT207UiN@80OWin0P1gMgL207YjNP80MgMg0P1dM7@206][J`80I6AT0P1NGUh2
04Y:BP80>SXj0P10@40204a<C00303/k>`0i>CT0>CTi0080;2`/0P0Z:RX204e=C@80RXZ:0P0l?3`2
05MGE`80IfMW0P0Z:RX204m?C`80>c/k0P18B4P205mOG`80EeMG0P1?Cdl00`1UIFD0IfMW06MWI`02
04I6AP80Ng]k0P1KFe/20820P080JFUY0P29RHT208f=S@80JFUY0P0n?Sh2055AD@80LG5a0P1eMGD2
06UYJ@80Q8B400<0PH6108j>SP2>SXh00P2PX:0208j>SP80Xj>S0P2OWil209VIV@80YJFU102NWYh2
0:FUY@80WYjN0P2QXJ4209fMW@80WYjN0P2QXJ400`2JVYX0YJFU0:FUY@0409fMW@80WYjN1P2QXJ4E
0?ooo`004`3oool209bLW080YJFU0P2JVYX20:FUY@@0XJ6Q0P2IVIT20::RXP030:6QX@2MWId0WIfM
0080XJ6Q0P2MWId209ZJVP80WYjN0P2PX:0209jNWP80XJ6Q0P2MWId209bLW0@0XJ6Q0P2IVIT209jN
WP80UYJF00<0W9bL08>3P`23Ph<00P26QXH205]KF`80GemO0P1CDe<205EEE@80@d=30P0m?Cd204=3
@`80>3Ph0P0_;bl202DU9@80>c/k0P0m?Cd208Z:RP0308N7Q`2;Rh/0Rh^;0080Shn?102=SHd208Z:
RP80TY:B0P26QXH2096AT@@0RXZ:0P2ATI4208V9R@80PX:20P28R8P208V9R@0308f=S@22PX80PX:2
0080RHV90P1iNGT207inOP80MgMg0P1jNWX207MgM`80M7Ad0P1[Jf/206ATI080GUiN0P1:BTX203Xj
>P80@4100P1<C4`00`0k>c/0>CTi03Ti>@0202`/;080:RXZ0P1=CDd208Z:RP80?3`l0P1GEeL206MW
I`80:RXZ0P1?Cdl203/k>`80B4Q80P1OGel205MGE`80Cdm?00<0IFEU06MWI`1WIfL00P16ATH207]k
N`80Fe]K0P20P80206UYJ@80RHV90P2=SHd206UYJ@80?Shn0P1ADE42075aL@80MGEe0P1YJFT208B4
Q0030861P@2>SXh0SXj>0080X:2P0P2>SXh20:>SX`80WinO0P2IVIT20:FUY@@0WYjN0P2UYJD209jN
WP80XJ6Q0P2MWId209jNWP80XJ6Q00<0VYZJ0:FUY@2UYJD0102MWId209jNWPH0XJ6Q5@3oool001<0
oooo0P2MWId20:6QX@80VYZJ0P2UYJD40:6QX@80VYZJ0P2QXJ400`2NWYh0XZ:R0::RXP040::RXP80
XJ6Q0P2MWId209jNWP80XJ6Q0P2NWYh20:6QX@80XZ:R0P2TY:@20::RXP80YJFU0P2MWId208f=S@03
08j>SP25QHD0QHF50080N7Qh0P1KFe/205MGE`80D51@0P18B4P604=3@`8092@T0P0_;bl202PX:080
;bl_0P2SXj<208R8R00308b<S028R8P0R8R80080RXZ:0P2=SHd208n?S`80QhN70P26QXH208>3P`80
Q8B40P28R8P208F5Q@@0QhN70P1lO7`208>3P`80PX:200<0QhN70861P@21PH400P28R8P407inOP80
N7Qh0P1iNGT207=cL`80N7Qh0P1aLG4206YZJP80J6QX0P1UIFD204I6AP80>3Ph0P0m?Cd303Ti>@80
;Bd]0P0[:b/203hn?P80HF5Q0P1hN7P204];B`80GEeM0P1BDU8204];B`80AdM70P0`<302065QH@80
JVYZ0P1>CTh00`1LG5`0De=C05=CD`0205ADE080H61P0P1gMgL206MWI`80M7Ad0P1mOGd208B4Q080
QHF50P14A4@205UIF@80JVYZ0P1UIFD206ATI080QhN700<0SHf=0:j^[P2^[Zh00P2@T90209jNWP80
V9RH0P2OWil209VIV@80ZJVY0P2MWId209ZJVP80YJFU0P2IVIT20:BTY080YJFU0P2JVYX20::RXPL0
XJ6Q0P2MWId40:6QX@80WYjN5@3oool001<0oooo0P2MWId20:6QX@80VYZJ0P2UYJD40:6QX@80VYZJ
0P2QXJ400`2NWYh0XZ:R0::RXP040::RXP80XJ6Q0P2MWId209jNWP80XJ6Q0P2NWYh20:6QX@80XZ:R
0P2TY:@20::RXP80YJFU0P2MWId208f=S@0308j>SP25QHD0QHF50080N7Qh0P1KFe/205MGE`80D51@
0P18B4P604=3@`8092@T0P0_;bl202PX:080;bl_0P2SXj<208R8R00308b<S028R8P0R8R80080RXZ:
0P2=SHd208n?S`80QhN70P26QXH208>3P`80Q8B40P28R8P208F5Q@@0QhN70P1lO7`208>3P`80PX:2
00<0QhN70861P@21PH400P28R8P407inOP80N7Qh0P1iNGT207=cL`80N7Qh0P1aLG4206YZJP80J6QX
0P1UIFD204I6AP80>3Ph0P0m?Cd303Ti>@80;Bd]0P0[:b/203hn?P80HF5Q0P1hN7P204];B`80GEeM
0P1BDU8204];B`80AdM70P0`<302065QH@80JVYZ0P1>CTh00`1LG5`0De=C05=CD`0205ADE080H61P
0P1gMgL206MWI`80M7Ad0P1mOGd208B4Q080QHF50P14A4@205UIF@80JVYZ0P1UIFD206ATI080QhN7
00<0SHf=0:j^[P2^[Zh00P2@T90209jNWP80V9RH0P2OWil209VIV@80ZJVY0P2MWId209ZJVP80YJFU
0P2IVIT20:BTY080YJFU0P2JVYX20::RXPL0XJ6Q0P2MWId40:6QX@80WYjN5@3oool001<0oooo0P2Q
XJ4209jNWPH0XJ6Q0P2NWYh40:6QX@<0WIfM0P2JVYX60:6QX@80WIfM0P2QXJ4209ZJVP80WIfM0P2L
W9`20:6QX@80WIfM0P2NWYh20::RXP80TI6A00<0PX:208B4Q024Q8@00P1XJ6P205YJFP80Bd];0P1D
E5@204A4A080=SHf0P17AdL203dm?@808R8R0P0^;Rh203Lg=`80MGEe0P2=SHd208N7Q`0308j>SP28
R8P0R8R80080Q8B40P27QhL208V9R@80PX:20P1kNg/207emO@80MGEe0P1fMWH207=cL`@0MgMg0P1c
Lg<207MgM`80P82000<0M7Ad07alO01lO7`00P21PH4207YjNP80QhN7101nOWh207=cL`80MgMg0P1a
LG4206m_K`80Jf][0P1XJ6P206IVIP80Cdm?0P0b<S800`0c<c<0>CTi03Ti>@0202/[:`808B4Q0P0e
=CD205IFEP80QhN70P1?Cdl204A4A080W9bL0P19BDT206IVIP80<c<c0P12@T8205mOG`80KVi^00<0
E5AD04a<C01<C4`00P1UIFD205=CD`80PX:20P1QHF4207alO080KVi^0P29RHT209RHV080De=C0P1Q
HF4206e]K@80J6QX0P1VIVH207inOP0308f=S@2j^[X0^[Zj0080TI6A0P2UYJD209VIV@80X:2P102N
WYh20:FUY@@0WIfM0P2QXJ4209fMW@80XJ6Q0P2JVYX30:6QX@80WYjN0P2UYJD80:6QX@80WIfM5@3o
ool001<0oooo0P2QXJ4209jNWPH0XJ6Q0P2NWYh40:6QX@<0WIfM0P2JVYX60:6QX@80WIfM0P2QXJ42
09ZJVP80WIfM0P2LW9`20:6QX@80WIfM0P2NWYh20::RXP80TI6A00<0PX:208B4Q024Q8@00P1XJ6P2
05YJFP80Bd];0P1DE5@204A4A080=SHf0P17AdL203dm?@808R8R0P0^;Rh203Lg=`80MGEe0P2=SHd2
08N7Q`0308j>SP28R8P0R8R80080Q8B40P27QhL208V9R@80PX:20P1kNg/207emO@80MGEe0P1fMWH2
07=cL`@0MgMg0P1cLg<207MgM`80P82000<0M7Ad07alO01lO7`00P21PH4207YjNP80QhN7101nOWh2
07=cL`80MgMg0P1aLG4206m_K`80Jf][0P1XJ6P206IVIP80Cdm?0P0b<S800`0c<c<0>CTi03Ti>@02
02/[:`808B4Q0P0e=CD205IFEP80QhN70P1?Cdl204A4A080W9bL0P19BDT206IVIP80<c<c0P12@T82
05mOG`80KVi^00<0E5AD04a<C01<C4`00P1UIFD205=CD`80PX:20P1QHF4207alO080KVi^0P29RHT2
09RHV080De=C0P1QHF4206e]K@80J6QX0P1VIVH207inOP0308f=S@2j^[X0^[Zj0080TI6A0P2UYJD2
09VIV@80X:2P102NWYh20:FUY@@0WIfM0P2QXJ4209fMW@80XJ6Q0P2JVYX30:6QX@80WYjN0P2UYJD8
0:6QX@80WIfM5@3oool001<0oooo0P2QXJ4209ZJVP80YJFU0P2QXJ4209jNWPT0XJ6Q0P2JVYX20:FU
Y@P0XJ6Q0P2MWId209ZJVP80WIfM0P2RXZ820:NWY`80VYZJ0P2KVi/208^;R`0308V9R@27QhL0QhN7
0080G5aL0P1EEED2055AD@80BDU90P1?Cdl203@d=080?3`l0P0^;Rh202`/;080;bl_0P0l?3`20>7Q
h@@0Rh^;00<0SHf=08^;R`2;Rh/01027QhL20820P080H61P0P1/K6`207inOP80LG5a0P1bLW8806][
J`80G5aL0P1]KFd00`1ZJVX0KFe]06e]K@0208b<S080OWin0P1mOGd208>3P`80OWin0P1hN7P207=c
L`80M7Ad0P1_Kfl406UYJ@80I6AT0P1JFUX204Q8B00302@T900];Bd0;Bd]0080:BTY0P0L71`202h^
;P80C4a<0P1bLW8206m_K`80>c/k0P1bLW82071`L080GEeM0P1PH60204M7A`80BDU90P1KFe/00`1U
IFD0FEUI05UIF@0204m?C`80G5aL0P1fMWH207=cL`80J6QX0P24Q8@207EeM@80TI6A0P1fMWH205]K
F`80MWIf0P1OGel207AdM080RHV900<0RXZ:0:2PX02PX:000P2TY:@20:6QX@80V9RH0P2SXj<20:BT
Y080Xj>S0P2MWId20:BTY080WinO0P2NWYh20:FUY@80XJ6Q0P2MWId209jNWP030:FUY@2MWId0WIfM
0080WYjN0P2UYJD20:6QX@80WYjN0P2UYJD20:6QXAD0oooo000C0?ooo`80XJ6Q0P2JVYX20:FUY@80
WYjN0P2QXJ4209jNWP80YJFU1@2QXJ4209ZJVP80YJFU0P2QXJ4209jNWP80XJ6Q0P2WYjL20:6QX@80
VYZJ0P2PX:0209bLW080WIfM0P2SXj<2096AT@80QXJ600<0Q8B4079bLP1bLW800P1NGUh204a<C080
Bd];0P16ATH204E5A@80=CDe0P0n?Sh202`/;080:b/[0P0h>3P208b<S080Q8B41@27QhL208^;R`80
Q8B40P1[Jf/207MgM`80H61P0P1JFUX208>3P`80F5QH0P1EEED206MWI`80LW9b0P1^KVh2055AD@80
FUYJ0P1FEUH00`1IFET0E5AD05ADE00206IVIP80S8b<0P21PH4207inOP80PX:20P1nOWh207=cL`80
MgMg0P1dM7@206YZJP80Jf][0P1TI6@2061PH080Fe]K00<0>c/k028R8P0R8R800P0N7Qh2020P8080
7alO0P1=CDd202LW9`80_;bl0P1SHf<203/k>`80Xj>S0P1?Cdl208R8R080JVYZ0P1<C4`205IFEP03
06QXJ017AdL0AdM70080Hf=S0P1ADE4206UYJ@80LW9b0P1TI6@207alO080OWin0P2=SHd208J6QP80
D51@0P1YJFT2071`L080M7Ad0P27QhL00`2_[jl0S8b<08b<S00209bLW080Vi^K0P2DU9@20:JVYP80
W9bL0P2MWId409jNWP80YJFU0P2JVYX20:FUY@80WYjN0P2RXZ830:6QX@80WYjN102QXJ4409jNWP80
YJFU0P2NWYhE0?ooo`004`3oool20:6QX@80VYZJ0P2UYJD209jNWP80XJ6Q0P2NWYh20:FUY@D0XJ6Q
0P2JVYX20:FUY@80XJ6Q0P2NWYh20:6QX@80YjNW0P2QXJ4209ZJVP80X:2P0P2LW9`209fMW@80Xj>S
0P2ATI4208J6QP0308B4Q01bLW80LW9b0080GUiN0P1<C4`204];B`80ATI60P15ADD203De=@80?Shn
0P0/;2`202/[:`80>3Ph0P2<S8`208B4Q0D0QhN70P2;Rh/208B4Q080Jf][0P1gMgL2061PH080FUYJ
0P23Ph<205QHF080EEEE0P1WIfL2079bLP80KVi^0P1ADE4205YJFP80EUIF00<0FEUI05ADE01DE5@0
0P1VIVH208b<S080PH610P1nOWh208:2PP80OWin0P1cLg<207MgM`80M7Ad0P1ZJVX206][J`80I6AT
0P1PH60205]KF`0303/k>`0R8R808R8R00807QhN0P0P820201lO7`80CDe=0P0W9bL20;bl_080Hf=S
0P0k>c/20:>SX`80Cdm?0P28R8P206YZJP80C4a<0P1FEUH00`1XJ6P0AdM704M7A`0206=SH`80DE5A
0P1YJFT2079bLP80I6AT0P1lO7`207inOP80SHf=0P26QXH2051@D080JFUY0P1`L70207AdM080QhN7
00<0[jn_08b<S02<S8`00P2LW9`209^KV`80U9BD0P2VYZH209bLW080WIfM102NWYh20:FUY@80VYZJ
0P2UYJD209jNWP80XZ:R0`2QXJ4209jNWP@0XJ6Q102NWYh20:FUY@80WYjN5@3oool001<0oooo0P2R
XZ820:6QX@80WYjN0P2QXJ4209jNWP80XJ6Q0P2NWYh20:FUY@0309jNWP2RXZ80XZ:R0080XJ6Q0P2N
WYh20::RXP80WYjN0P2MWId40::RXP80WIfM0P2WYjL20:6QX@80UiNG0P2WYjL208B4Q080S8b<00<0
Ng]k06QXJ01XJ6P00P1MGEd2055AD@80>CTi0P19BDT203/k>`80@D510P0R8R82038b<P80;Bd]0P1R
HV820<?3``@0QhN70P23Ph<00`26QXH0Rh^;08^;R`0208N7Q`80C4a<0P1ZJVX206IVIP80HV9R0P1l
O7`207QhN080JFUY0P1aLG4206ATI080MGEe0P1HF5P2069RHP80GEeM00<0NGUi04m?C`1?Cdl00P1I
FET205]KF`80Vi^K0P20P8020861P@80OWin101hN7P207=cL`80KVi^0P1[Jf/206UYJ@@0HV9R00<0
De=C03Lg=`0g=cL00P0J6QX202TY:@804Q8B0P0g=cL203hn?P80PX:20P1nOWh20492@P80NWYj0P1]
KFd205iNGP80SHf=0P1bLW8203lo?`0305UIF@1HF5P0F5QH0080H61P0P1;Bd/206IVIP80MGEe0P1X
J6P207EeM@80MWIf0P2GUiL208N7Q`80E5AD0P1JFUX206a/K080J6QX0P24Q8@00`32`/80V9RH09RH
V0020:6QX@80UYJF0P2GUiL20:f][@80XJ6Q0P2KVi/409fMW@80XJ6Q0P2MWId209jNWP80XJ6Q0P2M
WId30:6QX@80WIfM102QXJ4409fMW@80XJ6Q0P2MWIdE0?ooo`004`3oool20::RXP80XJ6Q0P2NWYh2
0:6QX@80WYjN0P2QXJ4209jNWP80YJFU00<0WYjN0::RXP2RXZ800P2QXJ4209jNWP80XZ:R0P2NWYh2
09fMW@@0XZ:R0P2MWId20:NWY`80XJ6Q0P2GUiL20:NWY`80Q8B40P2<S8`00`1kNg/0J6QX06QXJ002
05eMG@80DE5A0P0i>CT204U9B@80>c/k0P11@D42028R8P80<S8b0P0];Bd2069RHP80`l?31027QhL2
08>3P`0308J6QP2;Rh/0Rh^;0080QhN70P1<C4`206YZJP80IVIV0P1RHV8207alO080N7Qh0P1YJFT2
075aL@80I6AT0P1eMGD205QHF080HV9R0P1MGEd00`1iNGT0Cdm?04m?C`0205UIF@80Fe]K0P2KVi/2
0820P080PH610P1nOWh407QhN080Lg=c0P1^KVh206][J`80JFUY101RHV800`1CDe<0=cLg03Lg=`02
01XJ6P80:BTY0P0B4Q8203Lg=`80?Shn0P22PX8207inOP80@T920P1jNWX206e]K@80GUiN0P2=SHd2
079bLP80?clo00<0FEUI05QHF01HF5P00P1PH60204];B`80IVIV0P1eMGD206QXJ080MGEe0P1fMWH2
09NGU`80QhN70P1DE5@205YJFP80K6a/0P1XJ6P208B4Q0030<;2`P2HV9P0V9RH0080XJ6Q0P2FUYH2
09NGU`80[Jf]0P2QXJ4209^KV`@0WIfM0P2QXJ4209fMW@80WYjN0P2QXJ4209fMW@<0XJ6Q0P2MWId4
0:6QX@@0WIfM0P2QXJ4209fMWAD0oooo000C0?ooo`80WIfM0P2QXJ4209fMW@80XJ6Q0P2JVYX20::R
XP80XJ6Q1@2NWYh20:FUY@80VYZJ102NWYh20:6QX@80WIfM0P2JVYX209fMW@80YJFU0P2NWYh209bL
W080XZ:R0P1mOGd207alO003069RHP1QHF40HF5Q0080CDe=0P19BDT203Hf=P80AdM70P0e=CD202d]
;@80<C4a0P0W9bL204E5A@80YjNW0P2;Rh/208Z:RP@0QhN700<0QXJ606a/K01/K6`00P1mOGd2055A
D@80B4Q80P1GEeL205eMG@80Hf=S0P1@D50205IFEP80HV9R0P1<C4`204M7A`80>SXj0P19BDT204i>
CP030451@@1EEED0EEEE0080BDU90P0o?cl206MWI`80U9BD0P2EUID407emO@@0N7Qh0P1cLg<206IV
IP80Kfm_0P1YJFT206YZJP0305EEE@1@D500D51@0080:RXZ0P0D51@201DE5@80=3@d0P10@40205IF
EP80PH610P1ZJVX203Ti>@80Xj>S0P1;Bd/208Z:RP80WinO0P1WIfL00`0j>SX0HF5Q065QH@0204];
B`80GemO0P1DE5@206i^KP80J6QX0P1QHF4208Z:RP80SHf=0P23Ph<206QXJ080F5QH0P1dM7@205mO
G`80QHF500<0];Bd0:>SX`2SXj<00P2JVYX209bLW080VYZJ0P2OWil20:VYZ@80XJ6Q0P2NWYh20:FU
Y@80WYjN0P2UYJD209fMW@/0XJ6Q0P2NWYh20:FUY@80WYjN0P2UYJD20:6QXAD0oooo000C0?ooo`80
WIfM0P2QXJ4209fMW@80XJ6Q0P2JVYX20::RXP80XJ6Q1@2NWYh20:FUY@80VYZJ102NWYh20:6QX@80
WIfM0P2JVYX209fMW@80YJFU0P2NWYh209bLW080XZ:R0P1mOGd207alO003069RHP1QHF40HF5Q0080
CDe=0P19BDT203Hf=P80AdM70P0e=CD202d];@80<C4a0P0W9bL204E5A@80YjNW0P2;Rh/208Z:RP@0
QhN700<0QXJ606a/K01/K6`00P1mOGd2055AD@80B4Q80P1GEeL205eMG@80Hf=S0P1@D50205IFEP80
HV9R0P1<C4`204M7A`80>SXj0P19BDT204i>CP030451@@1EEED0EEEE0080BDU90P0o?cl206MWI`80
U9BD0P2EUID407emO@@0N7Qh0P1cLg<206IVIP80Kfm_0P1YJFT206YZJP0305EEE@1@D500D51@0080
:RXZ0P0D51@201DE5@80=3@d0P10@40205IFEP80PH610P1ZJVX203Ti>@80Xj>S0P1;Bd/208Z:RP80
WinO0P1WIfL00`0j>SX0HF5Q065QH@0204];B`80GemO0P1DE5@206i^KP80J6QX0P1QHF4208Z:RP80
SHf=0P23Ph<206QXJ080F5QH0P1dM7@205mOG`80QHF500<0];Bd0:>SX`2SXj<00P2JVYX209bLW080
VYZJ0P2OWil20:VYZ@80XJ6Q0P2NWYh20:FUY@80WYjN0P2UYJD209fMW@/0XJ6Q0P2NWYh20:FUY@80
WYjN0P2UYJD20:6QXAD0oooo000C0?ooo`H0XZ:R0P2UYJD209fMW@80VYZJ0P2RXZ820:6QX@0309ZJ
VP2QXJ40XJ6Q0080WYjN0P2QXJ4209ZJVP80XJ6Q0P2NWYh20::RXP@0WYjN0P2RXZ8209fMW@80X:2P
0P2HV9P208>3P`80Lg=c00<0F5QH05UIF@1IFET00P14A4@203/k>`80@d=30P0k>c/203Hf=P80<C4a
0P0f=SH2030`<080Vi^K0P2<S8`208R8R080Shn?0P28R8P208:2PP0308J6QP1SHf<0Hf=S0080Jf][
0P0n?Sh203Ti>@80ADE50P18B4P205UIF@80B4Q80P1ADE4205]KF`80?clo0P15ADD203dm?@80@T92
0P17AdL00`0k>c/0G5aL05aLG0020492@P80>CTi0P19BDT206MWI`80Ph>30P1mOGd207YjNP80N7Qh
0P1fMWH207YjNP80JVYZ0P1YJFT406i^KP0305eMG@1DE5@0E5AD0080?3`l0P0F5QH2014A4@806ATI
0P0f=SH204e=C@80IVIV0P2>SXh20492@P80E5AD0P1iNGT205UIF@80[:b/0P2;Rh/00`1_Kfl0?3`l
03`l?00205eMG@80H61P0P1DE5@206UYJ@80Hf=S0P1CDe<209:BTP80P8200P2?Shl208>3P`80De=C
0P24Q8@206EUI@80WIfM00<0WYjN09bLW02LW9`00P2GUiL209bLW080YjNW0P2KVi/40::RXP@0XJ6Q
0P2MWId20:6QX@80WYjN0P2UYJD20:6QX@80WYjN00<0YJFU0:6QX@2QXJ400P2NWYh40:6QX@80VYZJ
0P2UYJD20:6QXAD0oooo000C0?ooo`H0XZ:R0P2UYJD209fMW@80VYZJ0P2RXZ820:6QX@0309ZJVP2Q
XJ40XJ6Q0080WYjN0P2QXJ4209ZJVP80XJ6Q0P2NWYh20::RXP@0WYjN0P2RXZ8209fMW@80X:2P0P2H
V9P208>3P`80Lg=c00<0F5QH05UIF@1IFET00P14A4@203/k>`80@d=30P0k>c/203Hf=P80<C4a0P0f
=SH2030`<080Vi^K0P2<S8`208R8R080Shn?0P28R8P208:2PP0308J6QP1SHf<0Hf=S0080Jf][0P0n
?Sh203Ti>@80ADE50P18B4P205UIF@80B4Q80P1ADE4205]KF`80?clo0P15ADD203dm?@80@T920P17
AdL00`0k>c/0G5aL05aLG0020492@P80>CTi0P19BDT206MWI`80Ph>30P1mOGd207YjNP80N7Qh0P1f
MWH207YjNP80JVYZ0P1YJFT406i^KP0305eMG@1DE5@0E5AD0080?3`l0P0F5QH2014A4@806ATI0P0f
=SH204e=C@80IVIV0P2>SXh20492@P80E5AD0P1iNGT205UIF@80[:b/0P2;Rh/00`1_Kfl0?3`l03`l
?00205eMG@80H61P0P1DE5@206UYJ@80Hf=S0P1CDe<209:BTP80P8200P2?Shl208>3P`80De=C0P24
Q8@206EUI@80WIfM00<0WYjN09bLW02LW9`00P2GUiL209bLW080YjNW0P2KVi/40::RXP@0XJ6Q0P2M
WId20:6QX@80WYjN0P2UYJD20:6QX@80WYjN00<0YJFU0:6QX@2QXJ400P2NWYh40:6QX@80VYZJ0P2U
YJD20:6QXAD0oooo000C0?ooo`80WIfM0P2JVYX209jNWP80YJFU0P2NWYh20:6QX@80WIfM0P2QXJ40
0`2JVYX0YJFU0:FUY@0209ZJVP80YJFU0P2MWId20:6QX@@0WIfM0P2IVIT20:>SX`@0VYZJ0P2PX:02
09:BTP80OWin0P1]KFd00`1ADE40BTY:04Y:BP0204U9B@80>CTi0P0k>c/203Ti>@80<S8b0P0i>CT2
03De=@80?Cdm0P3Vi^H208R8R080S8b<1P2:RXX00`23Ph<0PX:208:2PP0208R8R080IfMW0P1FEUH2
04a<C080@d=30P1BDU82055AD@80B4Q80P1NGUh204m?C`80BTY:0P12@T8204];B`80B4Q800<0C4a<
075aL@1aLG400P1^KVh2079bLP@0N7Qh0P1mOGd207inOP80NGUi0P1gMgL207IfMP80NWYj0P1aLG42
06m_K`80JFUY0P1^KVh00`1TI6@0HV9R069RHP0204M7A`809BDU0P0G5aL200d=3@80D51@0P0f=SH2
04m?C`80Kfm_0P1dM7@203`l?080OWin0P1;Bd/208N7Q`80YJFU00<0S8b<04E5A@15ADD00P1MGEd2
05]KF`80Cdm?0P1NGUh206a/K080HF5Q0P1jNWX2071`L080W9bL0P2:RXX2055AD@80MGEe0P1UIFD2
0<G5a@030:2PX02HV9P0V9RH0080V9RH0P2GUiL20:ZZZP@0WIfM0P2JVYX20:FUY@H0XJ6Q0P2MWId2
0:6QX@80WYjN0P2QXJ400`2NWYh0YJFU0:FUY@0209fMW@80XJ6Q0P2NWYh60:6QXAD0oooo000C0?oo
o`80WIfM0P2JVYX209jNWP80YJFU0P2NWYh20:6QX@80WIfM0P2QXJ400`2JVYX0YJFU0:FUY@0209ZJ
VP80YJFU0P2MWId20:6QX@@0WIfM0P2IVIT20:>SX`@0VYZJ0P2PX:0209:BTP80OWin0P1]KFd00`1A
DE40BTY:04Y:BP0204U9B@80>CTi0P0k>c/203Ti>@80<S8b0P0i>CT203De=@80?Cdm0P3Vi^H208R8
R080S8b<1P2:RXX00`23Ph<0PX:208:2PP0208R8R080IfMW0P1FEUH204a<C080@d=30P1BDU82055A
D@80B4Q80P1NGUh204m?C`80BTY:0P12@T8204];B`80B4Q800<0C4a<075aL@1aLG400P1^KVh2079b
LP@0N7Qh0P1mOGd207inOP80NGUi0P1gMgL207IfMP80NWYj0P1aLG4206m_K`80JFUY0P1^KVh00`1T
I6@0HV9R069RHP0204M7A`809BDU0P0G5aL200d=3@80D51@0P0f=SH204m?C`80Kfm_0P1dM7@203`l
?080OWin0P1;Bd/208N7Q`80YJFU00<0S8b<04E5A@15ADD00P1MGEd205]KF`80Cdm?0P1NGUh206a/
K080HF5Q0P1jNWX2071`L080W9bL0P2:RXX2055AD@80MGEe0P1UIFD20<G5a@030:2PX02HV9P0V9RH
0080V9RH0P2GUiL20:ZZZP@0WIfM0P2JVYX20:FUY@H0XJ6Q0P2MWId20:6QX@80WYjN0P2QXJ400`2N
WYh0YJFU0:FUY@0209fMW@80XJ6Q0P2NWYh60:6QXAD0oooo000C0?ooo`80XZ:R0P2QXJ4209fMW@80
XJ6Q0P2MWId20:6QX@80WYjN0P2UYJD00`2MWId0XJ6Q0:6QX@0209ZJVP80YJFU0P2NWYh20::RXP80
YJFU0P2QXJ4209VIV@80XJ6Q0P2PX:0209^KV`80UiNG0P24Q8@208J6QP80Hf=S00<0BDU904=3@`13
@d<00P0o?cl20410@080>CTi0P0Y:BT203/k>`80=cLg0P0c<c<208F5Q@80WIfM0P27QhL208^;R`80
RHV90P2:RXX208F5Q@0308b<S025QHD0QHF50080Ti>C0P2=SHd209FEU@80S8b<0P2;Rh/208:2PP80
UIFE0P1mOGd208N7Q`80SHf=0P2ATI4207moO`80R8R80P22PX800`1nOWh0QHF508F5Q@0207]kN`80
P8200P23Ph<207EeM@80OGem0P22PX8207YjNP80MgMg0P1hN7P207IfMP80LG5a0P1dM7@206UYJ@80
IVIV00<0Jf][06UYJ@1YJFT00P1=CDd203@d=0805ADE0P0H61P204M7A`80?Cdm0P1NGUh204Y:BP80
O7al0P0c<c<2051@D080KVi^0P1OGel209RHV00308Z:RP1bLW80LW9b0080FEUI0P1@D50205MGE`80
FUYJ0P1DE5@206QXJ080JFUY0P1gMgL209bLW080RXZ:0P1GEeL207EeM@80EeMG0P3=cLd00`2HV9P0
TI6A096AT@020:2PX080WIfM0P2WYjL40:6QX@80VYZJ0P2UYJD20:6QX@80WYjN102RXZ820:FUY@80
WIfM0P2QXJ400`2MWId0XJ6Q0:6QX@040:6QX@80WIfM102QXJ4209jNWQD0oooo000C0?ooo`80XZ:R
0P2QXJ4209fMW@80XJ6Q0P2MWId20:6QX@80WYjN0P2UYJD00`2MWId0XJ6Q0:6QX@0209ZJVP80YJFU
0P2NWYh20::RXP80YJFU0P2QXJ4209VIV@80XJ6Q0P2PX:0209^KV`80UiNG0P24Q8@208J6QP80Hf=S
00<0BDU904=3@`13@d<00P0o?cl20410@080>CTi0P0Y:BT203/k>`80=cLg0P0c<c<208F5Q@80WIfM
0P27QhL208^;R`80RHV90P2:RXX208F5Q@0308b<S025QHD0QHF50080Ti>C0P2=SHd209FEU@80S8b<
0P2;Rh/208:2PP80UIFE0P1mOGd208N7Q`80SHf=0P2ATI4207moO`80R8R80P22PX800`1nOWh0QHF5
08F5Q@0207]kN`80P8200P23Ph<207EeM@80OGem0P22PX8207YjNP80MgMg0P1hN7P207IfMP80LG5a
0P1dM7@206UYJ@80IVIV00<0Jf][06UYJ@1YJFT00P1=CDd203@d=0805ADE0P0H61P204M7A`80?Cdm
0P1NGUh204Y:BP80O7al0P0c<c<2051@D080KVi^0P1OGel209RHV00308Z:RP1bLW80LW9b0080FEUI
0P1@D50205MGE`80FUYJ0P1DE5@206QXJ080JFUY0P1gMgL209bLW080RXZ:0P1GEeL207EeM@80EeMG
0P3=cLd00`2HV9P0TI6A096AT@020:2PX080WIfM0P2WYjL40:6QX@80VYZJ0P2UYJD20:6QX@80WYjN
102RXZ820:FUY@80WIfM0P2QXJ400`2MWId0XJ6Q0:6QX@040:6QX@80WIfM102QXJ4209jNWQD0oooo
000C0?ooo`80WYjN0P2UYJD209jNWPH0XZ:R0P2QXJ4209fMW@030:NWY`2QXJ40XJ6Q0080WIfM0P2Q
XJ4209ZJVP80XJ6Q0P2NWYh20:FUY@80VYZJ102MWId20:2PX080UiNG0P1/K6`206EUI@80FEUI00<0
ADE504a<C01<C4`00P0a<C4203/k>`80;Bd]0P0e=CD403Lg=`80=SHf0P3IfMT208^;R`80R8R80P2?
Shl208^;R`80RXZ:0P27QhL00`2@T900QHF508F5Q@0208j>SP80SHf=0P2ATI4208f=S@80TI6A0P2=
SHd208n?S`80Ph>31P27QhL207EeM@80PH610P1oOgl00`1iNGT0QHF508F5Q@0207YjNP80RXZ:0P1n
OWh208N7Q`80M7Ad0P21PH4407YjNP80OGem0P1cLg<2075aL@80L71`0P1cLg<2065QH@0306ATI01Y
JFT0JFUY0080E5AD0P0k>c/201lO7`808R8R0P0G5aL204i>CP80CDe=0P1CDe<205iNGP80E5AD0P0n
?Sh206e]K@80G5aL0P27QhL00`2JVYX0QhN708N7Q`02061PH080IVIV0P1EEED206EUI@80C4a<0P1U
IFD204m?C`80P8200P29RHT209>CT`80HV9R0P1XJ6P206m_K`80_kno00<0Y:BT096AT@2ATI400P2>
SXh20;Fe]@80WYjN0P2UYJD20:6QX@80VYZJ0P2UYJD209jNWP80XJ6Q102MWId20:6QX@80WYjN0P2U
YJD30:6QX@80WYjN0P2RXZ820:FUY@@0XJ6Q0P2MWIdE0?ooo`004`3oool209jNWP80YJFU0P2NWYh6
0::RXP80XJ6Q0P2MWId00`2WYjL0XJ6Q0:6QX@0209fMW@80XJ6Q0P2JVYX20:6QX@80WYjN0P2UYJD2
09ZJVP@0WIfM0P2PX:0209NGU`80K6a/0P1UIFD205UIF@0304E5A@1<C4`0C4a<0080<C4a0P0k>c/2
02d];@80=CDe100g=cL203Hf=P80fMWI0P2;Rh/208R8R080Shn?0P2;Rh/208Z:RP80QhN700<0T92@
08F5Q@25QHD00P2>SXh208f=S@80TI6A0P2=SHd2096AT@80SHf=0P2?Shl208>3P`H0QhN70P1eMGD2
0861P@80Ogmo00<0NGUi08F5Q@25QHD00P1jNWX208Z:RP80OWin0P27QhL207AdM080PH61101jNWX2
07emO@80Lg=c0P1aLG42071`L080Lg=c0P1QHF400`1TI6@0JFUY06UYJ@0205ADE080>c/k0P0O7al2
028R8P805aLG0P1>CTh204e=C@80De=C0P1NGUh205ADE080?Shn0P1]KFd205aLG080QhN700<0VYZJ
08N7Q`27QhL00P1PH60206IVIP80EEEE0P1UIFD204a<C080IFEU0P1?Cdl20820P080RHV90P2CTi<2
069RHP80J6QX0P1_Kfl20;no_`030:BTY02ATI40TI6A0080SXj>0P2e]KD209jNWP80YJFU0P2QXJ42
09ZJVP80YJFU0P2NWYh20:6QX@@0WIfM0P2QXJ4209jNWP80YJFU0`2QXJ4209jNWP80XZ:R0P2UYJD4
0:6QX@80WIfM5@3oool001<0oooo0P2MWId209jNWP80XJ6Q0P2JVYX209jNWP@0XJ6Q0P2LW9`00`2N
WYh0YJFU0:FUY@040:6QX@80WIfM0P2QXJ4209fMW@80XJ6Q0P2MWId209ZJVP@0WIfM0P2:RXX208>3
P`80De=C0P1;Bd/00`15ADD0>CTi03Ti>@0204=3@`80:RXZ0P0g=cL202TY:@80?Shn0P0i>CT202`/
;080moOg1028R8P208n?S`80SXj>1029RHT00`2:RXX0SXj>08j>SP0608f=S@80Rh^;0P2>SXh208f=
S@80QHF50P27QhL207inOP80TI6A0P1nOWh207YjNP80QHF50P27QhL00`1kNg/0Q8B408B4Q0020861
P@80Rh^;0P1fMWH208N7Q`80QXJ60P1lO7`2075aL@@0NWYj0P1gMgL206m_K`80L71`0P1_Kfl206i^
KP03069RHP1SHf<0Hf=S0080H61P0P17AdL202LW9`806a/K0P0O7al20492@P80Bd];0P1<C4`204i>
CP80H61P0P10@40204U9B@80De=C0P23Ph<00`1iNGT0Shn?08n?S`0207]kN`80GUiN0P1;Bd/206UY
J@80@d=30P1iNGT205=CD`80NWYj0P1eMGD209NGU`80JFUY0P1FEUH209FEU@80UiNG00<0YJFU09NG
U`2GUiL00P2;Rh/20:ZZZPH0XJ6Q0P2MWId20:6QX@80WIfM0P2NWYh20:FUY@@0XJ6Q0P2JVYX20:FU
Y@0309jNWP2UYJD0YJFU00@0WIfM202QXJ4E0?ooo`004`3oool209fMW@80WYjN0P2QXJ4209ZJVP80
WYjN102QXJ4209bLW00309jNWP2UYJD0YJFU00@0XJ6Q0P2MWId20:6QX@80WIfM0P2QXJ4209fMW@80
VYZJ102MWId208Z:RP80Ph>30P1CDe<204];B`0304E5A@0i>CT0>CTi0080@d=30P0Z:RX203Lg=`80
:BTY0P0n?Sh203Ti>@80;2`/0P3gmoL408R8R080Shn?0P2>SXh408V9R@0308Z:RP2>SXh0SXj>00H0
SHf=0P2;Rh/208j>SP80SHf=0P25QHD208N7Q`80OWin0P2ATI4207inOP80NWYj0P25QHD208N7Q`03
07]kN`24Q8@0Q8B40080PH610P2;Rh/207IfMP80QhN70P26QXH207alO080LG5a101jNWX207MgM`80
Kfm_0P1`L70206m_K`80KVi^00<0HV9R06=SH`1SHf<00P1PH60204M7A`809bLW0P0K6a/201lO7`80
@T920P1;Bd/204a<C080CTi>0P1PH6020410@080BDU90P1CDe<208>3P`0307UiN@2?Shl0Shn?0080
Ng]k0P1NGUh204];B`80JFUY0P13@d<207UiN@80De=C0P1jNWX207EeM@80UiNG0P1YJFT205IFEP80
UIFE0P2GUiL00`2UYJD0UiNG09NGU`0208^;R`80ZZZZ1P2QXJ4209fMW@80XJ6Q0P2MWId209jNWP80
YJFU102QXJ4209ZJVP80YJFU00<0WYjN0:FUY@2UYJD0102MWId80:6QXAD0oooo000C0?ooo`80XJ6Q
0P2MWId20:6QX@@0WIfM1P2QXJ400`2MWId0WYjN09jNWP020:FUY@H0XJ6Q0P2NWYh40::RXP80XJ6Q
0P2MWId209>CT`80M7Ad0P1_Kfl205iNGP80@D5100<0B4Q803hn?P0n?Sh00P0d=3@203<c<`80=cLg
0P0`<30203Ph>080;Rh^0P1MGEd20;Vi^@80RXZ:0P28R8P2092@T0L0SHf=0P28R8P208^;R`80SXj>
0P2=SHd208^;R`80QhN70P2=SHd207emO@80PH610P1jNWX208f=S@80O7al0P1eMGD20861P@80Q8B4
00<0PH610820P020P8000P28R8P208J6QP80Q8B40P1oOgl208N7Q`80Ogmo0P1nOWh207alO0@0MgMg
0P1aLG4207AdM080JFUY0P1^KVh00`1WIfL0GUiN05iNGP0205IFEP80CDe=0P0c<c<201dM7@80:RXZ
0P0b<S8204i>CP80@d=30P1MGEd204m?C`80F5QH0P0c<c<204m?C`80CDe=00<0W9bL07emO@1mOGd0
0P1dM7@207]kN`80Cdm?0P1WIfL204=3@`80IVIV0P1YJFT207QhN080L71`0P2FUYH206m_K`80DE5A
0P2h^;P207emO@030;bl_02ATI40TI6A0080XJ6Q0P2MWId80:6QX@80WYjN0P2UYJD209fMW@H0XJ6Q
0P2MWId309jNWP80YJFU0P2QXJ4209jNWP80YJFU1P2QXJ4E0?ooo`004`3oool20:6QX@80WIfM0P2Q
XJ4409fMW@H0XJ6Q00<0WIfM09jNWP2NWYh00P2UYJD60:6QX@80WYjN102RXZ820:6QX@80WIfM0P2C
Ti<207AdM080Kfm_0P1NGUh20451@@0304Q8B00n?Sh0?Shn0080=3@d0P0c<c<203Lg=`80<30`0P0h
>3P202h^;P80GEeM0P2i^KT208Z:RP80R8R80P2@T90708f=S@80R8R80P2;Rh/208j>SP80SHf=0P2;
Rh/208N7Q`80SHf=0P1mOGd20861P@80NWYj0P2=SHd207alO080MGEe0P21PH4208B4Q0030861P@20
P800P8200080R8R80P26QXH208B4Q080Ogmo0P27QhL207moO`80OWin0P1lO7`407MgM`80LG5a0P1d
M7@206UYJ@80KVi^00<0IfMW05iNGP1NGUh00P1FEUH204e=C@80<c<c0P0M7Ad202XZ:P80<S8b0P1>
CTh204=3@`80GEeM0P1?Cdl205QHF080<c<c0P1?Cdl204e=C@0309bLW01mOGd0OGem0080M7Ad0P1k
Ng/204m?C`80IfMW0P13@d<206IVIP80JFUY0P1hN7P2071`L080UYJF0P1_Kfl2055AD@80^;Rh0P1m
OGd00`2l_;`0TI6A096AT@020:6QX@80WIfM202QXJ4209jNWP80YJFU0P2MWId60:6QX@80WIfM0`2N
WYh20:FUY@80XJ6Q0P2NWYh20:FUY@H0XJ6Q5@3oool001<0oooo0P2RXZ820:FUY@P0XJ6Q0P2NWYh2
0:FUY@<0WYjN0P2UYJD20:6QX@80WYjN0P2UYJD409fMW@80VIVI0P2WYjL209jNWP80UiNG0P1VIVH2
05UIF@80E5AD0P13@d<00`0l?3`0@D510451@@0203De=@80;Bd]0P0a<C4203/k>`80=cLg0P0V9RH2
0<30`0@0R8R80P2:RXX2092@T0H0SHf=00<0TI6A08f=S@2=SHd00P29RHT208n?S`@0SHf=0P22PX82
0820P080NGUi0P1jNWX206QXJ080OWin0P1hN7P206m_K`80O7al0P20P8000`1mOGd0Q8B408B4Q002
08>3P`80QhN70P24Q8@208n?S`80QhN70P1oOgl207QhN080QHF50P1bLW8207=cL`80LW9b0P1aLG42
06UYJ@80Kfm_00<0KVi^05eMG@1MGEd00P1MGEd204m?C`80=cLg0P0Q8B4200l?3`809bLW0P16ATH2
0410@080FEUI0P0k>c/206EUI@80>SXj0P18B4P2038b<P030:n_[`1[Jf/0Jf][0080Ng]k0P2ATI42
04I6AP80I6AT0P1HF5P2055AD@@0J6QX0P1cLg<209fMW@80NGUi0P1VIVH209jNWP80QhN700<0XJ6Q
09JFUP2FUYH00P2o_kl:0:6QX@80VYZJ0P2UYJD:0:6QX@<0WIfM102QXJ4209ZJVP80YJFU1P2QXJ4E
0?ooo`004`3oool20::RXP80YJFU202QXJ4209jNWP80YJFU0`2NWYh20:FUY@80XJ6Q0P2NWYh20:FU
Y@@0WIfM0P2IVIT20:NWY`80WYjN0P2GUiL206IVIP80FEUI0P1DE5@204=3@`0303`l?011@D40@D51
0080=CDe0P0];Bd2034a<@80>c/k0P0g=cL202HV9P80`<301028R8P208Z:RP80T92@1P2=SHd00`2A
TI40SHf=08f=S@0208V9R@80Shn?102=SHd208:2PP80P8200P1iNGT207YjNP80J6QX0P1nOWh207Qh
N080Kfm_0P1lO7`20820P00307emO@24Q8@0Q8B40080Ph>30P27QhL208B4Q080Shn?0P27QhL207mo
O`80N7Qh0P25QHD2079bLP80Lg=c0P1bLW82075aL@80JFUY0P1_Kfl00`1^KVh0GEeM05eMG@0205eM
G@80Cdm?0P0g=cL2024Q8@803`l?0P0W9bL204I6AP80@4100P1IFET203/k>`80IFEU0P0j>SX204Q8
B080<S8b00<0[jn_06][J`1[Jf/00P1kNg/2096AT@80ATI60P1TI6@205QHF080DE5A101XJ6P207=c
L`80WIfM0P1iNGT206IVIP80WYjN0P27QhL00`2QXJ40UYJF09JFUP020;no_`X0XJ6Q0P2JVYX20:FU
Y@X0XJ6Q0`2MWId40:6QX@80VYZJ0P2UYJD60:6QXAD0oooo000C0?ooo`80WIfM2P2QXJ4209fMW@80
WYjN00<0XJ6Q09fMW@2MWId00P2QXJ4209jNWPP0XJ6Q0P2LW9`20:6QX@80WIfM0P2DU9@2061PH080
DE5A0P12@T8203dm?@0303Xj>P0];Bd0;Bd]0080?3`l0P0^;Rh203De=@80=SHf0P0Z:RX202HV9P80
m?Cd0P26QXH408Z:RP80Ti>C0P2:RXX209BDU080S8b<00<0R8R808f=S@2=SHd0102:RXX209>CT`80
KVi^0P1eMGD20:RXZ080NGUi0P1eMGD206QXJ080C4a<0P1WIfL207]kN`80PH610P1OGel00`2:RXX0
QhN708N7Q`0208B4Q080S8b<0P1oOgl608N7Q`80OWin0P20P80207emO@@0MgMg101_Kfl206UYJ@03
06i^KP1NGUh0GUiN0080FUYJ0P1=CDd204=3@`8092@T0P0?3`l2024Q8@80;Rh^0P10@40204U9B@80
@D510P1IFET204Y:BP80>SXj0P19BDT00`1GEeL0NWYj07YjNP0208B4Q080Ogmo0P1aLG42051@D080
IFEU0P13@d<206][J`80GUiN0P1kNg/209FEU@80OGem0P2HV9P206IVIP80^;Rh00<0LG5a0;Jf]P2f
][H0302QXJ4209fMWA<0XJ6Q0P2MWId40:6QX@80WYjN0P2UYJDE0?ooo`004`3oool209fMW@X0XJ6Q
0P2MWId209jNWP030:6QX@2MWId0WIfM0080XJ6Q0P2NWYh80:6QX@80W9bL0P2QXJ4209fMW@80U9BD
0P1PH602055AD@80@T920P0m?Cd00`0j>SX0;Bd]02d];@0203`l?080;Rh^0P0e=CD203Hf=P80:RXZ
0P0V9RH20?Cdm080QXJ6102:RXX209>CT`80RXZ:0P2DU9@208b<S00308R8R02=SHd0SHf=00@0RXZ:
0P2CTi<206i^KP80MGEe0P2XZ:P207UiN@80MGEe0P1XJ6P204a<C080IfMW0P1kNg/20861P@80GemO
00<0RXZ:08N7Q`27QhL00P24Q8@208b<S080Ogmo1P27QhL207inOP80P8200P1mOGd407MgM`@0Kfm_
0P1YJFT00`1^KVh0GUiN05iNGP0205YJFP80CDe=0P13@d<202@T90803`l?0P0Q8B4202h^;P80@410
0P19BDT20451@@80FEUI0P1:BTX203Xj>P80BDU900<0EeMG07YjNP1jNWX00P24Q8@207moO`80LG5a
0P1@D50206EUI@80@d=30P1[Jf/205iNGP80Ng]k0P2EUID207emO@80V9RH0P1VIVH20;Rh^003075a
L@2f][H0][Jf00`0XJ6Q0P2MWIdC0:6QX@80WIfM102QXJ4209jNWP80YJFU5@3oool001<0oooo102R
XZ820:FUY@80WYjN0P2RXZ820:FUY@80XJ6Q0P2MWId00`2QXJ40WYjN09jNWP020::RXP80XJ6Q0P2N
WYh20:FUY@P0XJ6Q0P2NWYh208b<S080Cdm?0P1=CDd20410@080@T9200<0<C4a038b<P0b<S800P0]
;Bd203Hf=P80>CTi0P0/;2`202DU9@80?Cdm0P3Lg=`208F5Q@80Rh^;0P28R8P2092@T080QHF50P2>
SXh209RHV00308F5Q@2@T900T92@0080RXZ:0P2<S8`209BDU080IVIV0P1JFUX208V9R@80QhN70P1l
O7`206e]K@80BDU90P1?Cdl2069RHP80M7Ad0P1ADE400`1PH600P8200820P00208j>SP80TI6A2027
QhL207moO`80QhN70P1mOGd2079bLP80MGEe0P1cLg<2075aL@80JFUY00<0J6QX06UYJ@1YJFT00P1J
FUX2059BDP80ATI60P0b<S8200T92@8061PH0P0S8b<203Ph>080@T920P16ATH20492@P80Fe]K0P0c
<c<204a<C003024Q8@2e]KD0]KFe0080IVIV0P1`L702096AT@80@D510P1YJFT203dm?@80G5aL0P1V
IVH2079bLP80SXj>0P2?Shl209ZJVP80IVIV0P2PX:030:6QX@80WYjN0P2UYJD80:6QX@80WYjN0P2U
YJD60:6QX@80WYjN0P2UYJD70:6QX@80WYjN0P2RXZ820:FUY@80WIfM0P2QXJ4E0?ooo`004`3oool4
0::RXP80YJFU0P2NWYh20::RXP80YJFU0P2QXJ4209fMW@030:6QX@2NWYh0WYjN0080XZ:R0P2QXJ42
09jNWP80YJFU202QXJ4209jNWP80S8b<0P1?Cdl204e=C@80@4100P12@T800`0a<C40<S8b038b<P02
02d];@80=SHf0P0i>CT202`/;0809BDU0P0m?Cd20=cLg080QHF50P2;Rh/208R8R080T92@0P25QHD2
08j>SP80V9RH00<0QHF5092@T02@T9000P2:RXX208b<S080U9BD0P1VIVH205YJFP80RHV90P27QhL2
07alO080KFe]0P19BDT204m?C`80HV9R0P1dM7@2055AD@03061PH020P800P8200080SXj>0P2ATI48
08N7Q`80Ogmo0P27QhL207emO@80LW9b0P1eMGD207=cL`80LG5a0P1YJFT00`1XJ6P0JFUY06UYJ@02
05YJFP80DU9B0P16ATH2038b<P802@T90P0H61P202<S8`80>3Ph0P12@T8204I6AP80@T920P1KFe/2
03<c<`80C4a<00<08B4Q0;Fe]@2e]KD00P1VIVH2071`L080TI6A0P11@D4206UYJ@80?Cdm0P1LG5`2
06IVIP80LW9b0P2>SXh208n?S`80VYZJ0P1VIVH20:2PX0<0XJ6Q0P2NWYh20:FUY@P0XJ6Q0P2NWYh2
0:FUY@H0XJ6Q0P2NWYh20:FUY@L0XJ6Q0P2NWYh20::RXP80YJFU0P2MWId20:6QXAD0oooo000C0?oo
o`@0WIfM0P2QXJ4409fMW@80XJ6Q0P2NWYh20:FUY@030:6QX@2JVYX0VYZJ0080WYjN0P2UYJD209fM
W@@0XJ6Q0P2MWId20:NWY`80XJ6Q0P2MWId207emO@80@T920P0o?cl204A4A080;bl_00<0>c/k03Xj
>P0j>SX00P0];Bd203Ph>080>SXj0P0P820202DU9@80JFUY0P2l_;`408^;R`80SHf=0P2GUiL208f=
S@80R8R80P2@T9000`27QhL0RHV908V9R@0408Z:RP80V9RH0P22PX8208n?S`@0R8R80P20P80207Ui
N@80KVi^0P1fMWH207YjNP80Ng]k0P1dM7@00`1RHV80Kfm_06m_K`0208Z:RP80T92@0P27QhL208Z:
RP80QHF50P27QhL407moO`80QhN70P1oOgl207MgM`80M7Ad0P1cLg<206QXJ003061PH01XJ6P0J6QX
0080G5aL0P1FEUH204Y:BP80@4100P071`L201`L70805QHF0P12@T8203lo?`80Bd];0P0^;Rh2061P
H080=3@d0P16ATH00`0L71`0Zj^[0:^[Z`02061PH080O7al0P2=SHd203`l?080JFUY0P15ADD205UI
F@80I6AT0P1_Kfl208F5Q@80U9BD0P25QHD206i^KP80Q8B400<0`/;20:6QX@2QXJ400P2JVYX20:FU
Y@P0XJ6Q0P2MWId20:6QX@80WYjN0P2UYJD20:6QX@80WIfM2@2QXJ4209fMW@80VYZJ0P2UYJD40:6Q
XAD0oooo000C0?ooo`@0WIfM0P2QXJ4409fMW@80XJ6Q0P2NWYh20:FUY@030:6QX@2JVYX0VYZJ0080
WYjN0P2UYJD209fMW@@0XJ6Q0P2MWId20:NWY`80XJ6Q0P2MWId207emO@80@T920P0o?cl204A4A080
;bl_00<0>c/k03Xj>P0j>SX00P0];Bd203Ph>080>SXj0P0P820202DU9@80JFUY0P2l_;`408^;R`80
SHf=0P2GUiL208f=S@80R8R80P2@T9000`27QhL0RHV908V9R@0408Z:RP80V9RH0P22PX8208n?S`@0
R8R80P20P80207UiN@80KVi^0P1fMWH207YjNP80Ng]k0P1dM7@00`1RHV80Kfm_06m_K`0208Z:RP80
T92@0P27QhL208Z:RP80QHF50P27QhL407moO`80QhN70P1oOgl207MgM`80M7Ad0P1cLg<206QXJ003
061PH01XJ6P0J6QX0080G5aL0P1FEUH204Y:BP80@4100P071`L201`L70805QHF0P12@T8203lo?`80
Bd];0P0^;Rh2061PH080=3@d0P16ATH00`0L71`0Zj^[0:^[Z`02061PH080O7al0P2=SHd203`l?080
JFUY0P15ADD205UIF@80I6AT0P1_Kfl208F5Q@80U9BD0P25QHD206i^KP80Q8B400<0`/;20:6QX@2Q
XJ400P2JVYX20:FUY@P0XJ6Q0P2MWId20:6QX@80WYjN0P2UYJD20:6QX@80WIfM2@2QXJ4209fMW@80
VYZJ0P2UYJD40:6QXAD0oooo000C0?ooo`H0XJ6Q0P2NWYh20:FUY@80WYjN102QXJ400`2NWYh0XJ6Q
0:6QX@0209ZJVP80YJFU0P2QXJ4209fMW@80YjNW0P2IVIT20::RXP80YJFU0P2NWYh207UiN@80=cLg
0P0l?3`204A4A080<S8b00<0=3@d03Ph>00h>3P00P0g=cL203Xj>P80<c<c0P0M7Ad202/[:`80^;Rh
0P27QhL208j>SP80RHV90P2=SHd208n?S`80T92@0P2?Shl2096AT@0308j>SP2=SHd0SHf=0080QHF5
0P27QhL209^KV`80QXJ60P2>SXh209FEU@80R8R80P23Ph<208B4Q080MgMg0P1cLg<207QhN080NWYj
0P1gMgL00`1aLG40NWYj07YjNP0208F5Q@80T92@0P27QhL208f=S@80Q8B40P2:RXX208F5Q@80OWin
0P1oOgl207QhN080OGem0P1dM7@207MgM`80Jf][00<0Hf=S061PH01PH6000P1JFUX205=CD`80BDU9
0P0n?Sh201<C4`801`L70P0N7Qh203hn?P8092@T0P1PH602038b<P80EeMG0P0];Bd204A4A00303Hf
=P1]KFd0KFe]0080Kfm_0P25QHD20861P@80EUIF0P1@D50205iNGP80CTi>0P1PH60206=SH`80TY:B
0P2GUiL207YjNP80Shn?0P2KVi/00`2UYJD0XJ6Q0:6QX@0209fMW@P0XJ6Q0P2NWYh20::RXP80YJFU
0P2MWIdA0:6QX@80WIfM1P2QXJ4E0?ooo`004`3oool60:6QX@80WYjN0P2UYJD209jNWP@0XJ6Q00<0
WYjN0:6QX@2QXJ400P2JVYX20:FUY@80XJ6Q0P2MWId20:NWY`80VIVI0P2RXZ820:FUY@80WYjN0P1i
NGT203Lg=`80?3`l0P14A4@2038b<P0303@d=00h>3P0>3Ph0080=cLg0P0j>SX203<c<`807AdM0P0[
:b/20;Rh^080QhN70P2>SXh208V9R@80SHf=0P2?Shl2092@T080Shn?0P2ATI400`2>SXh0SHf=08f=
S@0208F5Q@80QhN70P2KVi/208J6QP80SXj>0P2EUID208R8R080Ph>30P24Q8@207MgM`80Lg=c0P1h
N7P207YjNP80MgMg00<0LG5a07YjNP1jNWX00P25QHD2092@T080QhN70P2=SHd208B4Q080RXZ:0P25
QHD207inOP80Ogmo0P1hN7P207emO@80M7Ad0P1gMgL206][J`0306=SH`1PH600H61P0080FUYJ0P1C
De<204U9B@80?Shn0P0C4a<200L71`807QhN0P0n?Sh202@T9080H61P0P0b<S8205MGE`80;Bd]0P14
A4@00`0f=SH0KFe]06e]K@0206m_K`80QHF50P21PH4205IFEP80D51@0P1NGUh204i>CP80H61P0P1S
Hf<209:BTP80UiNG0P1jNWX208n?S`80Vi^K00<0YJFU0:6QX@2QXJ400P2MWId80:6QX@80WYjN0P2R
XZ820:FUY@80WIfM4@2QXJ4209fMW@H0XJ6Q5@3oool001<0oooo1P2QXJ4209fMW@80XJ6Q0P2MWId2
0:6QX@<0WYjN0P2UYJD209ZJVP80XZ:R0P2UYJD209bLW080WYjN0P2QXJ4209fMW@80XJ6Q0P2IVIT2
05QHF080?3`l0P15ADD202/[:`80>CTi00<0=3@d03Ti>@0i>CT00P0j>SX203Ph>0806QXJ0P0V9RH2
01`L7080oooo0P2:RXX208n?S`80Rh^;0P2HV9P2092@T080Shn?102@T9000`2?Shl0T92@092@T002
08R8R080PX:20P2ATI4208j>SP@0UYJF0P2?Shl208J6QP80PX:20P1eMGD207=cL`80N7Qh0P1lO7`2
07=cL`0307YjNP20P800P8200080RHV90P28R8P208N7Q`80SXj>0P28R8P208B4Q080QhN70P26QXH2
08N7Q`80OWin0P1hN7P207EeM@80NGUi0P1cLg<00`1]KFd0I6AT06ATI00205MGE`80De=C0P1=CDd2
0492@P808b<S0P0820P201PH6080=3@d0P0j>SX40492@P80CTi>0P0^;Rh203lo?`0303Ti>@1TI6@0
I6AT0080Kfm_0P1jNWX208>3P`80MgMg0P0h>3P206=SH`80CDe=0P1OGel206MWI`80T92@0P2;Rh/2
06=SH`80Zj^[0P2n_[h00`2NWYh0YJFU0:FUY@0209jNWP@0XZ:R0P2UYJD20:6QX@80WIfM0P2JVYX2
0:FUY@l0XJ6Q0P2NWYh20:FUY@P0XJ6Q5@3oool001<0oooo1P2QXJ4209fMW@80XJ6Q0P2MWId20:6Q
X@<0WYjN0P2UYJD209ZJVP80XZ:R0P2UYJD209bLW080WYjN0P2QXJ4209fMW@80XJ6Q0P2IVIT205QH
F080?3`l0P15ADD202/[:`80>CTi00<0=3@d03Ti>@0i>CT00P0j>SX203Ph>0806QXJ0P0V9RH201`L
7080oooo0P2:RXX208n?S`80Rh^;0P2HV9P2092@T080Shn?102@T9000`2?Shl0T92@092@T00208R8
R080PX:20P2ATI4208j>SP@0UYJF0P2?Shl208J6QP80PX:20P1eMGD207=cL`80N7Qh0P1lO7`207=c
L`0307YjNP20P800P8200080RHV90P28R8P208N7Q`80SXj>0P28R8P208B4Q080QhN70P26QXH208N7
Q`80OWin0P1hN7P207EeM@80NGUi0P1cLg<00`1]KFd0I6AT06ATI00205MGE`80De=C0P1=CDd20492
@P808b<S0P0820P201PH6080=3@d0P0j>SX40492@P80CTi>0P0^;Rh203lo?`0303Ti>@1TI6@0I6AT
0080Kfm_0P1jNWX208>3P`80MgMg0P0h>3P206=SH`80CDe=0P1OGel206MWI`80T92@0P2;Rh/206=S
H`80Zj^[0P2n_[h00`2NWYh0YJFU0:FUY@0209jNWP@0XZ:R0P2UYJD20:6QX@80WIfM0P2JVYX20:FU
Y@l0XJ6Q0P2NWYh20:FUY@P0XJ6Q5@3oool001<0oooo102RXZ820:FUY@@0XJ6Q0P2NWYh20:FUY@<0
WIfM0P2QXJ4409fMW@80WYjN0P2UYJD209ZJVP80YJFU102QXJ4209NGU`80=3@d0P0j>SX203Ti>@80
:2PX0P10@4000`0d=3@0>3Ph03Ph>00203Lg=`805ADE0P0S8b<201hN7P80:BTY0P3`l?0408n?S`80
QhN7102@T90208n?S`L0T92@0P2ATI4208b<S080QHF50P2<S8`208j>SP80UiNG0P28R8P208^;R`80
Ogmo0P1iNGT206UYJ@@0NGUi0P1cLg<00`1nOWh0QhN708N7Q`0208N7Q`80R8R80P29RHT208f=S@80
T92@0P22PX8208V9R@80Q8B41027QhL207MgM`80NWYj0P1dM7@207MgM`0306i^KP1`L700L71`0080
F5QH0P1DE5@204];B`80B4Q80P0`<30200T92@8092@T0P0S8b<203lo?`80>c/k0P13@d<20492@P80
ADE50P0g=cL00`0i>CT0I6AT06ATI00206YZJP80KVi^0P28R8P209JFUP80<C4a0P1EEED204Y:BP80
GemO0P1[Jf/209RHV080UiNG0P1]KFd209jNWP80YJFU00<0WIfM0:6QX@2QXJ401P2MWId60:6QX@80
WIfM202QXJ4209jNWP80YJFU1@2QXJ4209ZJVP80XZ:R0P2UYJD60:6QXAD0oooo000C0?ooo`@0WIfM
102QXJ4209jNWP/0XJ6Q0P2NWYh20:6QX@80WYjN0P2QXJ4209jNWP@0XZ:R0P2LW9`202`/;080=cLg
0P0c<c<2038b<P80@41000<0=CDe03Ti>@0i>CT00P0j>SX201LG5`806a/K0P0R8R8207inOP80X:2P
0P2=SHd209NGU`80SXj>1P2?Shl209FEU@<0SXj>0P29RHT2096AT@80T92@0P28R8P208N7Q`80Q8B4
0P2JVYX208R8R080OWin101gMgL207=cL`80MgMg0P1nOWh207UiN@0308:2PP2>SXh0SXj>0080Rh^;
0P24Q8@408Z:RP80U9BD0P22PX8208N7Q`@0QXJ60P27QhL207MgM`80OWin0P1jNWX207AdM0<0Kfm_
0P1YJFT205IFEP80BTY:0P19BDT203dm?@@03Ph>0P0];Bd202DU9@80B4Q80P12@T8203@d=080C4a<
0P15ADD00`0g=cL0HF5Q065QH@0207alO080Jf][0P21PH420:2PX080<S8b0P1TI6@203Hf=P80K6a/
0P1DE5@20:BTY080Shn?0P26QXH20;jn_Q/0XJ6Q0P2MWId70:6QX@@0WIfM102QXJ4209jNWP80YJFU
5@3oool001<0oooo102MWId40:6QX@80WYjN2`2QXJ4209jNWP80XJ6Q0P2NWYh20:6QX@80WYjN102R
XZ8209bLW080;2`/0P0g=cL203<c<`80<S8b0P10@4000`0e=CD0>CTi03Ti>@0203Xj>P805aLG0P0K
6a/2028R8P80OWin0P2PX:0208f=S@80UiNG0P2>SXh608n?S`80UIFE0`2>SXh208V9R@80TI6A0P2@
T90208R8R080QhN70P24Q8@209ZJVP80R8R80P1nOWh407MgM`80Lg=c0P1gMgL207inOP80NGUi00<0
PX:208j>SP2>SXh00P2;Rh/208B4Q0@0RXZ:0P2DU9@208:2PP80QhN71026QXH208N7Q`80MgMg0P1n
OWh207YjNP80M7Ad0`1_Kfl206UYJ@80EUIF0P1:BTX204U9B@80?Cdm100>3Ph202d];@809BDU0P18
B4P20492@P80=3@d0P1<C4`204E5A@0303Lg=`1QHF40HF5Q0080O7al0P1[Jf/20861P@80X:2P0P0b
<S8206ATI080=SHf0P1/K6`205ADE080Y:BT0P2?Shl208J6QP80_[jn6`2QXJ4209fMW@L0XJ6Q102M
WId40:6QX@80WYjN0P2UYJDE0?ooo`004`3oool60::RXP80YJFU0P2MWId90:6QX@@0WYjN0P2RXZ84
0:6QX@80VYZJ0P2NWYh20:6QX@80PX:20P0f=SH203/k>`80;Rh^0P0o?cl203dm?@<0=SHf0P0R8R82
01/K6`805ADE0P2<S8`20820P080RHV90P2BTY8209FEU@80RHV90P2?Shl209FEU@80RHV91@2FUYH2
08n?S`H0T92@0P2=SHd208>3P`80UIFE0P2@T90207moO`80O7al0P1_Kfl207=cL`@0OGem0P1oOgl0
0`26QXH0SXj>08j>SP0208^;R`80Shn?0P29RHT208:2PP80UiNG0P25QHD2092@T080PX:20P27QhL2
08>3P`80OWin0P1kNg/207MgM`80MWIf00<0Kfm_06YZJP1ZJVX00P1ZJVX2065QH@H0ADE50P0O7al2
01TI6@80;Rh^0P0a<C4203Ti>@80Cdm?0P0d=3@204a<C080@d=300<0>3Ph05mOG`1OGel00P2=SHd2
06YZJP80Ogmo0P2HV9P203dm?@80EUIF0P0c<c<206e]K@80EeMG0P2OWil20:>SX`80U9BD0P2YZJT?
0:6QX@80WYjN0P2UYJD20:6QX@80WYjN0P2RXZ820:FUY@80XJ6Q0P2NWYh20:FUY@0309jNWP2UYJD0
YJFU00P0XJ6Q0P2MWId20:6QXAD0oooo000C0?ooo`H0XZ:R0P2UYJD209fMW@T0XJ6Q102NWYh20::R
XP@0XJ6Q0P2JVYX209jNWP80XJ6Q0P22PX8203Hf=P80>c/k0P0^;Rh203lo?`80?Cdm0`0f=SH2028R
8P806a/K0P0E5AD208b<S080P8200P29RHT209:BTP80UIFE0P29RHT208n?S`80UIFE0P29RHT509JF
UP80Shn?1P2@T90208f=S@80Ph>30P2EUID2092@T080Ogmo0P1lO7`206m_K`80Lg=c101mOGd207mo
O`0308J6QP2>SXh0SXj>0080Rh^;0P2?Shl208V9R@80PX:20P2GUiL208F5Q@80T92@0P22PX8208N7
Q`80Ph>30P1nOWh207]kN`80MgMg0P1fMWH00`1_Kfl0JVYZ06YZJP0206YZJP80HF5Q1P15ADD201lO
7`806ATI0P0^;Rh2034a<@80>CTi0P1?Cdl203@d=080C4a<0P13@d<00`0h>3P0GemO05mOG`0208f=
S@80JVYZ0P1oOgl209RHV080?Cdm0P1FEUH203<c<`80KFe]0P1GEeL209nOW`80Xj>S0P2DU9@20:VY
Z@l0XJ6Q0P2NWYh20:FUY@80XJ6Q0P2NWYh20::RXP80YJFU0P2QXJ4209jNWP80YJFU00<0WYjN0:FU
Y@2UYJD0202QXJ4209fMW@80XJ6Q5@3oool001<0oooo0P2NWYh20:6QX@80VYZJ0P2UYJD90:6QX@80
WYjN0P2QXJ4209fMW@80VYZJ0P2UYJD20:6QX@@0WIfM0P2QXJ4203hn?P80@d=30P0l?3`202<S8`80
Bd];0P0e=CD00`0h>3P0>SXj03Xj>P0201XJ6P80:b/[0P0R8R820>OWi`80SHf=102ATI4209BDU080
Shn?102EUID208V9R@80Shn?0P2@T9000`2CTi<0RHV908V9R@0608n?S`80TI6A0P27QhL209JFUP80
T92@0P28R8P207moO`80LW9b0P1cLg<208>3P`80P8200P1nOWh00`22PX80SHf=08f=S@0208j>SP80
UIFE0P2<S8`408j>SP80RHV90P2:RXX208j>SP80S8b<0P27QhL208>3P`80QHF50P1iNGT207YjNP03
07=cL`1bLW80LW9b0080IVIV0P1^KVh204a<C080B4Q80P0o?cl202h^;P809RHV0P0];Bd2030`<0@0
@T921018B4P20410@00304];B`1OGel0GemO0080PX:20P1^KVh207EeM@80RHV90P1CDe<204E5A@80
<30`0P1ZJVX206UYJ@80QhN7102^[ZhA0:6QX@80WIfM102QXJ4409fMW@@0XJ6Q0P2MWId209jNWPD0
XJ6Q0P2NWYh20:FUY@H0XJ6Q5@3oool001<0oooo0P2NWYh20:6QX@80VYZJ0P2UYJD90:6QX@80WYjN
0P2QXJ4209fMW@80VYZJ0P2UYJD20:6QX@@0WIfM0P2QXJ4203hn?P80@d=30P0l?3`202<S8`80Bd];
0P0e=CD00`0h>3P0>SXj03Xj>P0201XJ6P80:b/[0P0R8R820>OWi`80SHf=102ATI4209BDU080Shn?
102EUID208V9R@80Shn?0P2@T9000`2CTi<0RHV908V9R@0608n?S`80TI6A0P27QhL209JFUP80T92@
0P28R8P207moO`80LW9b0P1cLg<208>3P`80P8200P1nOWh00`22PX80SHf=08f=S@0208j>SP80UIFE
0P2<S8`408j>SP80RHV90P2:RXX208j>SP80S8b<0P27QhL208>3P`80QHF50P1iNGT207YjNP0307=c
L`1bLW80LW9b0080IVIV0P1^KVh204a<C080B4Q80P0o?cl202h^;P809RHV0P0];Bd2030`<0@0@T92
1018B4P20410@00304];B`1OGel0GemO0080PX:20P1^KVh207EeM@80RHV90P1CDe<204E5A@80<30`
0P1ZJVX206UYJ@80QhN7102^[ZhA0:6QX@80WIfM102QXJ4409fMW@@0XJ6Q0P2MWId209jNWPD0XJ6Q
0P2NWYh20:FUY@H0XJ6Q5@3oool001<0oooo0P2NWYh20:FUY@80WIfM2`2QXJ4209fMW@@0XJ6Q0P2J
VYX20:FUY@@0XJ6Q0P2NWYh20:FUY@8071`L0P0n?Sh2034a<@809bLW0P1=CDd203Lg=`<0=3@d0P0V
9RH2024Q8@80HV9R0P2l_;`208Z:RP80U9BD0P2@T90208n?S`@0UIFE0P2?Shl2092@T080SXj>0P2A
TI400`2EUID0SXj>08j>SP0209FEU@80SXj>0P29RHT2092@T080S8b<0P2@T90208n?S`80Rh^;0P2:
RXX2079bLP80Lg=c0P1nOWh208Z:RP80PX:200<0QhN708J6QP26QXH00P2@T902096AT@80S8b<0P2E
UID208n?S`80Rh^;0P2:RXX209>CT`80QhN70P2:RXX208B4Q080QhN70P21PH4207QhN00306m_K`1g
MgL0MgMg00@0JVYZ0P1BDU8204U9B@80?3`l0P0d=3@2028R8P80:BTY0P0_;bl203hn?P80?Cdm0P1@
D50204Q8B080A4A400<0AdM708N7Q`27QhL00P1_Kfl406i^KP80NWYj0P1WIfL203Hf=P80@D510P1H
F5P206a/K080T92@0P2n_[h20:VYZAL0XJ6Q0P2NWYh20:FUY@80WYjN0P2UYJD20:6QX@80WIfM1@2Q
XJ4209fMW@P0XJ6Q5@3oool001<0oooo0P2NWYh20:FUY@80WIfM2`2QXJ4209fMW@@0XJ6Q0P2JVYX2
0:FUY@@0XJ6Q0P2NWYh20:FUY@8071`L0P0n?Sh2034a<@809bLW0P1=CDd203Lg=`<0=3@d0P0V9RH2
024Q8@80HV9R0P2l_;`208Z:RP80U9BD0P2@T90208n?S`@0UIFE0P2?Shl2092@T080SXj>0P2ATI40
0`2EUID0SXj>08j>SP0209FEU@80SXj>0P29RHT2092@T080S8b<0P2@T90208n?S`80Rh^;0P2:RXX2
079bLP80Lg=c0P1nOWh208Z:RP80PX:200<0QhN708J6QP26QXH00P2@T902096AT@80S8b<0P2EUID2
08n?S`80Rh^;0P2:RXX209>CT`80QhN70P2:RXX208B4Q080QhN70P21PH4207QhN00306m_K`1gMgL0
MgMg00@0JVYZ0P1BDU8204U9B@80?3`l0P0d=3@2028R8P80:BTY0P0_;bl203hn?P80?Cdm0P1@D502
04Q8B080A4A400<0AdM708N7Q`27QhL00P1_Kfl406i^KP80NWYj0P1WIfL203Hf=P80@D510P1HF5P2
06a/K080T92@0P2n_[h20:VYZAL0XJ6Q0P2NWYh20:FUY@80WYjN0P2UYJD20:6QX@80WIfM1@2QXJ42
09fMW@P0XJ6Q5@3oool001<0oooo0P2MWId20:6QX@80WYjN0P2UYJD209jNWP80YJFU102QXJ400`2N
WYh0YJFU0:FUY@040:6QX@80WIfM1P2QXJ4209fMW@80WYjN0P0O7al204];B`80<30`0P0_;bl203Ph
>080@d=300<0=cLg02@T900T92@00P0e=CD203@d=080ZZZZ0P2>SXh208Z:RP80U9BD102?Shl409JF
UP80Shn?102@T90208n?S`0308f=S@2DU9@0U9BD00@0UYJF0P2?Shl4092@T080R8R80P2HV9P208R8
R080RHV90P1^KVh2075aL@80MgMg0P27QhL208J6QP0308R8R02<S8`0S8b<0080SXj>0P2@T90208b<
S080T92@0P2DU9@208F5Q@80SXj>0P2<S8`208V9R@80Rh^;0P27QhL208R8R080QHF50P1mOGd00`1h
N7P0Kfm_06m_K`0206e]K@80JVYZ0P1MGEd204Q8B080?clo0P0d=3@202TY:@809BDU0P0^;Rh2030`
<080A4A40P19BDT204Y:BP80?Shn00<0?3`l0:ZZZP2ZZZX00P1VIVH206MWI`80MGEe0P1`L70208:2
PP80;2`/0P1MGEd205ADE080HV9R0P2BTY820<k>cP80YjNW5`2QXJ4209fMW@80XJ6Q0P2MWId20:6Q
X@80WYjN0P2UYJD?0:6QXAD0oooo000C0?ooo`80WIfM0P2QXJ4209jNWP80YJFU0P2NWYh20:FUY@@0
XJ6Q00<0WYjN0:FUY@2UYJD0102QXJ4209fMW@H0XJ6Q0P2MWId209jNWP807alO0P1;Bd/2030`<080
;bl_0P0h>3P204=3@`0303Lg=`0T92@092@T0080=CDe0P0d=3@20:ZZZP80SXj>0P2:RXX209BDU0@0
Shn?102FUYH208n?S`@0T92@0P2?Shl00`2=SHd0U9BD09BDU00409JFUP80Shn?102@T90208R8R080
V9RH0P28R8P208V9R@80KVi^0P1aLG4207MgM`80QhN70P26QXH00`28R8P0S8b<08b<S00208j>SP80
T92@0P2<S8`2092@T080U9BD0P25QHD208j>SP80S8b<0P29RHT208^;R`80QhN70P28R8P208F5Q@80
OGem00<0N7Qh06m_K`1_Kfl00P1]KFd206YZJP80GEeM0P18B4P203lo?`80=3@d0P0Y:BT202DU9@80
;Rh^0P0`<30204A4A080BDU90P1:BTX203hn?P0303`l?02ZZZX0ZZZZ0080IVIV0P1WIfL207EeM@80
L71`0P22PX8202`/;080GEeM0P1DE5@2069RHP80TY:B0P3>c/h20:NWYaL0XJ6Q0P2MWId20:6QX@80
WIfM0P2QXJ4209jNWP80YJFU3`2QXJ4E0?ooo`004`3oool20::RXP80YJFU0P2MWId20:6QX@80VYZJ
0P2UYJD209jNWP80YJFU00<0VYZJ0:FUY@2UYJD02P2QXJ4209jNWP80YJFU0P1aLG4202l_;`80Cdm?
0P0h>3P203lo?`80=CDe0P0k>c/00`0/;2`0:2PX02PX:00203Hf=P80TY:B0P2CTi<208B4Q080UIFE
0P2>SXh608n?S`80UIFE0P29RHT208n?S`80TI6A0P2;Rh/00`28R8P0T92@092@T00209BDU080T92@
0P2EUID2092@T080RXZ:0P2;Rh/209>CT`80Shn?0P2ATI4207MgM`80KFe]0P1fMWH207moO`80PX:2
00<0RXZ:07inOP1nOWh00P2GUiL2092@T080RXZ:0P2DU9@408b<S080TI6A0P28R8P208J6QP80RXZ:
0P27QhL208R8R080QXJ60P1lO7`00`22PX80L71`071`L002079bLP80JVYZ0P1NGUh205IFEP80@410
0P0j>SX202l_;`807QhN0P0a<C4202d];@80?Shn0P1EEED203lo?`80@41000<0?Cdm09^KV`2KVi/0
0P1YJFT206i^KP80Kfm_0P1<C4`20:j^[P806QXJ0P1PH60206MWI`80HF5Q0P24Q8@20=KFeQd0XJ6Q
0P2NWYh20:FUY@80WIfM4@2QXJ4E0?ooo`004`3oool20::RXP80YJFU0P2MWId20:6QX@80VYZJ0P2U
YJD209jNWP80YJFU00<0VYZJ0:FUY@2UYJD02P2QXJ4209jNWP80YJFU0P1aLG4202l_;`80Cdm?0P0h
>3P203lo?`80=CDe0P0k>c/00`0/;2`0:2PX02PX:00203Hf=P80TY:B0P2CTi<208B4Q080UIFE0P2>
SXh608n?S`80UIFE0P29RHT208n?S`80TI6A0P2;Rh/00`28R8P0T92@092@T00209BDU080T92@0P2E
UID2092@T080RXZ:0P2;Rh/209>CT`80Shn?0P2ATI4207MgM`80KFe]0P1fMWH207moO`80PX:200<0
RXZ:07inOP1nOWh00P2GUiL2092@T080RXZ:0P2DU9@408b<S080TI6A0P28R8P208J6QP80RXZ:0P27
QhL208R8R080QXJ60P1lO7`00`22PX80L71`071`L002079bLP80JVYZ0P1NGUh205IFEP80@4100P0j
>SX202l_;`807QhN0P0a<C4202d];@80?Shn0P1EEED203lo?`80@41000<0?Cdm09^KV`2KVi/00P1Y
JFT206i^KP80Kfm_0P1<C4`20:j^[P806QXJ0P1PH60206MWI`80HF5Q0P24Q8@20=KFeQd0XJ6Q0P2N
WYh20:FUY@80WIfM4@2QXJ4E0?ooo`004`3oool209fMW@@0XJ6Q0P2NWYh40:6QX@80VYZJ0P2UYJD0
0`2MWId0XJ6Q0:6QX@0:0:6QX@80VYZJ0P2UYJD203Hf=P80DE5A0P0l?3`202l_;`80EEEE0P0_;bl2
03hn?P03028R8P0h>3P0>3Ph0080=SHf0P3MgMd209FEU@80Q8B40P2LW9`208n?S`80UIFE0P29RHT2
08n?S`80UiNG0P2>SXh208b<S080TI6A0P20P8000`2?Shl0RXZ:08Z:RP0208b<S080SHf=0P2EUID2
09JFUP80Ph>30P2>SXh209BDU080SXj>0P2ATI4207emO@80JVYZ0P1iNGT207AdM080OWin00<0PH61
08:2PP22PX801P2<S8`208Z:RP80S8b<0P28R8P2096AT@80R8R80P26QXH208R8R080RHV90P28R8P2
08F5Q@80PH6100<0MgMg07moO`1oOgl00P1_Kfl206i^KP80Hf=S0P1FEUH204I6AP80>CTi0P0c<c<2
01XJ6P80820P0P0c<c<203Xj>P80Cdm?0P18B4P203lo?`0304=3@`2ATI40TI6A0080IFEU0P1]KFd2
07=cL`80:RXZ0P2m_Kd201lO7`80AdM70P1fMWH207alO080RHV90P36a/H40:6QX@80WYjN00<0YJFU
0:6QX@2QXJ40502QXJ4209ZJVP80YJFU4`2QXJ4E0?ooo`004`3oool209fMW@@0XJ6Q0P2NWYh40:6Q
X@80VYZJ0P2UYJD00`2MWId0XJ6Q0:6QX@0:0:6QX@80VYZJ0P2UYJD203Hf=P80DE5A0P0l?3`202l_
;`80EEEE0P0_;bl203hn?P03028R8P0h>3P0>3Ph0080=SHf0P3MgMd209FEU@80Q8B40P2LW9`208n?
S`80UIFE0P29RHT208n?S`80UiNG0P2>SXh208b<S080TI6A0P20P8000`2?Shl0RXZ:08Z:RP0208b<
S080SHf=0P2EUID209JFUP80Ph>30P2>SXh209BDU080SXj>0P2ATI4207emO@80JVYZ0P1iNGT207Ad
M080OWin00<0PH6108:2PP22PX801P2<S8`208Z:RP80S8b<0P28R8P2096AT@80R8R80P26QXH208R8
R080RHV90P28R8P208F5Q@80PH6100<0MgMg07moO`1oOgl00P1_Kfl206i^KP80Hf=S0P1FEUH204I6
AP80>CTi0P0c<c<201XJ6P80820P0P0c<c<203Xj>P80Cdm?0P18B4P203lo?`0304=3@`2ATI40TI6A
0080IFEU0P1]KFd207=cL`80:RXZ0P2m_Kd201lO7`80AdM70P1fMWH207alO080RHV90P36a/H40:6Q
X@80WYjN00<0YJFU0:6QX@2QXJ40502QXJ4209ZJVP80YJFU4`2QXJ4E0?ooo`004`3oool60:6QX@80
VYZJ0P2UYJD20:6QX@80WIfM0P2NWYh00`2UYJD0XJ6Q0:6QX@020:6QX@80WYjN1P2RXZ840:6QX@80
5aLG0P26QXH203De=@80A4A40P11@D4203dm?@80<c<c00<07AdM05EEE@1EEED00P1XJ6P209FEU@80
OGem0P2EUID209VIV@80SXj>0P2FUYH408n?S`80SHf=0P2>SXh208Z:RP80S8b<0P1nOWh00`1hN7P0
QhN708N7Q`0209:BTP80SHf=0P2>SXh209FEU@80QHF50P2@T90209VIV@80Shn?0P2ATI4207IfMP@0
L71`0P1iNGT207EeM@0307]kN`28R8P0R8R80080TY:B0P29RHT208N7Q`80QXJ60P1oOgl20861P@80
Ph>30P26QXH20820P080S8b<0P27QhL209:BTP@0QXJ600<0NWYj0861P@21PH400P1`L70206e]K@80
IFEU0P1JFUX204U9B@80@d=30P0c<c<202LW9`804A4A0P0[:b/203@d=080CTi>0P16ATH204e=C@03
03Ph>02>SXh0SXj>0080LG5a0P1EEED207=cL`809RHV0P33`l<202HV9P80=SHf0P25QHD20861P@80
X:2P0P2k^k/40:6QX@80WIfM1`2QXJ4209jNWP80YJFU302QXJ4209fMW@H0XJ6Q00<0WYjN0:FUY@2U
YJD0302QXJ4E0?ooo`004`3oool60:6QX@80VYZJ0P2UYJD20:6QX@80WIfM0P2NWYh00`2UYJD0XJ6Q
0:6QX@020:6QX@80WYjN1P2RXZ840:6QX@805aLG0P26QXH203De=@80A4A40P11@D4203dm?@80<c<c
00<07AdM05EEE@1EEED00P1XJ6P209FEU@80OGem0P2EUID209VIV@80SXj>0P2FUYH408n?S`80SHf=
0P2>SXh208Z:RP80S8b<0P1nOWh00`1hN7P0QhN708N7Q`0209:BTP80SHf=0P2>SXh209FEU@80QHF5
0P2@T90209VIV@80Shn?0P2ATI4207IfMP@0L71`0P1iNGT207EeM@0307]kN`28R8P0R8R80080TY:B
0P29RHT208N7Q`80QXJ60P1oOgl20861P@80Ph>30P26QXH20820P080S8b<0P27QhL209:BTP@0QXJ6
00<0NWYj0861P@21PH400P1`L70206e]K@80IFEU0P1JFUX204U9B@80@d=30P0c<c<202LW9`804A4A
0P0[:b/203@d=080CTi>0P16ATH204e=C@0303Ph>02>SXh0SXj>0080LG5a0P1EEED207=cL`809RHV
0P33`l<202HV9P80=SHf0P25QHD20861P@80X:2P0P2k^k/40:6QX@80WIfM1`2QXJ4209jNWP80YJFU
302QXJ4209fMW@H0XJ6Q00<0WYjN0:FUY@2UYJD0302QXJ4E0?ooo`004`3oool60:6QX@80WIfM1P2Q
XJ4209fMW@030:6QX@2NWYh0WYjN0080YJFU0P2JVYX20:6QX@@0WIfM0P2QXJ420:JVYP8020P80P1X
J6P203<c<`80Bd];0P0l?3`204M7A`806QXJ00<0?Shn03lo?`0o?cl00P3Bd]8206MWI`80QHF50P2R
XZ8209NGU`80SXj>102?Shl208b<S080QXJ60P1mOGd207=cL`80O7al0P2HV9P00`1hN7P0K6a/06a/
K00209BDU080QXJ60P2MWId208b<S080PH610P28R8P209VIV@80Shn?0P2@T90207EeM@80JVYZ0P1W
IfL207=cL`80MGEe00<0R8R807=cL`1cLg<00P2DU9@207]kN`80P8200P1iNGT207AdM080JVYZ0P1g
MgL20820P080Lg=c0P1hN7P207moO`80TY:B0P22PX8207UiN@<0PH610P1gMgL206i^KP80Hf=S0P1H
F5P204i>CP80?Cdm0P0j>SX2034a<@808B4Q0P0T92@202TY:@80Bd];0P0o?cl2051@D00303dm?@1j
NWX0NWYj0080Kfm_0P1CDe<2061PH080<C4a0P32`/8202HV9P80=cLg0P2DU9@207MgM`80];Bd0P30
`<0209ZJVP/0XJ6Q0P2MWIdF0:6QX@0309fMW@2QXJ40XJ6Q00`0XJ6Q5@3oool001<0oooo1P2QXJ42
09fMW@H0XJ6Q0P2MWId00`2QXJ40WYjN09jNWP020:FUY@80VYZJ0P2QXJ4409fMW@80XJ6Q0P2VYZH2
00P82080J6QX0P0c<c<204];B`80?3`l0P17AdL201XJ6P0303hn?P0o?cl0?clo0080d];B0P1WIfL2
08F5Q@80XZ:R0P2GUiL208j>SP@0Shn?0P2<S8`208J6QP80OGem0P1cLg<207alO080V9RH00<0N7Qh
06a/K01/K6`00P2DU9@208J6QP80WIfM0P2<S8`20861P@80R8R80P2IVIT208n?S`80T92@0P1eMGD2
06YZJP80IfMW0P1cLg<207EeM@0308R8R01cLg<0Lg=c0080U9BD0P1kNg/20820P080NGUi0P1dM7@2
06YZJP80MgMg0P20P80207=cL`80N7Qh0P1oOgl209:BTP80PX:20P1iNGT30861P@80MgMg0P1^KVh2
06=SH`80F5QH0P1>CTh203dm?@80>SXj0P0a<C42024Q8@8092@T0P0Y:BT204];B`80?clo0P1@D500
0`0m?Cd0NWYj07YjNP0206m_K`80De=C0P1PH602034a<@80`/;20P0V9RH203Lg=`80U9BD0P1gMgL2
0;Bd]080`<300P2JVYX;0:6QX@80WIfM5P2QXJ400`2MWId0XJ6Q0:6QX@0<0:6QXAD0oooo000C0?oo
o`80XZ:R0P2UYJD60:6QX@80WYjN0P2UYJD209jNWP030:FUY@2MWId0WIfM0080XJ6Q0P2MWId80:6Q
X@80L71`0P10@402055AD@80;Rh^0P13@d<203Hf=P80C4a<0P0J6QX00`1?Cdl0MGEe07EeM@0208^;
R`80F5QH0P1kNg/20:JVYP80TY:B0P2DU9@208n?S`80R8R80P1oOgl206IVIP80N7Qh0P1nOWh205eM
G@80ATI600<0IFEU075aL@1aLG400P27QhL2075aL@80QXJ60P2b/[8208R8R080QXJ60P2MWId4092@
T080OGem0P1_Kfl2065QH@80L71`0P1SHf<00`2<S8`0@T920492@P0207emO@80QHF50P2:RXX208B4
Q080@T920P13@d<2075aL@80IVIV0P1UIFD206IVIP80Lg=c0P2EUID208N7Q`80NGUi00<0NWYj07Ui
N@1iNGT00P1bLW8207=cL`80Hf=S0P1KFe/204e=C@80A4A40P0j>SX2034a<@80>3Ph0P0K6a/202<S
8`80Bd];0P0m?Cd204Q8B00304e=C@1ZJVX0JVYZ0080Jf][0P1;Bd/205aLG080=3@d0P37alL202<S
8`80B4Q80P2ATI4206i^KP80]kNg0P2d];@K0:6QX@80WYjN0P2UYJDE0:6QXAD0oooo000C0?ooo`80
XZ:R0P2UYJD60:6QX@80WYjN0P2UYJD209jNWP030:FUY@2MWId0WIfM0080XJ6Q0P2MWId80:6QX@80
L71`0P10@402055AD@80;Rh^0P13@d<203Hf=P80C4a<0P0J6QX00`1?Cdl0MGEe07EeM@0208^;R`80
F5QH0P1kNg/20:JVYP80TY:B0P2DU9@208n?S`80R8R80P1oOgl206IVIP80N7Qh0P1nOWh205eMG@80
ATI600<0IFEU075aL@1aLG400P27QhL2075aL@80QXJ60P2b/[8208R8R080QXJ60P2MWId4092@T080
OGem0P1_Kfl2065QH@80L71`0P1SHf<00`2<S8`0@T920492@P0207emO@80QHF50P2:RXX208B4Q080
@T920P13@d<2075aL@80IVIV0P1UIFD206IVIP80Lg=c0P2EUID208N7Q`80NGUi00<0NWYj07UiN@1i
NGT00P1bLW8207=cL`80Hf=S0P1KFe/204e=C@80A4A40P0j>SX2034a<@80>3Ph0P0K6a/202<S8`80
Bd];0P0m?Cd204Q8B00304e=C@1ZJVX0JVYZ0080Jf][0P1;Bd/205aLG080=3@d0P37alL202<S8`80
B4Q80P2ATI4206i^KP80]kNg0P2d];@K0:6QX@80WYjN0P2UYJDE0:6QXAD0oooo000C0?ooo`80WIfM
202QXJ4209fMW@80XJ6Q0P2MWId50:6QX@80WYjN0P2UYJD60:6QX@80=3@d0P1TI6@203lo?`80=cLg
0P0S8b<204E5A@80B4Q80P0O7al00`0X:2P0m?Cd0?Cdm002071`L080JFUY0P1eMGD20:6QX@80T92@
0P2;Rh/208Z:RP80OGem0P1NGUh2065QH@80P8200P27QhL203`l?080@d=300<0?Cdm06IVIP1VIVH0
0P1[Jf/207YjNP80HV9R0P2MWId208J6QP80UYJF0P2LW9`2092@T080Rh^;0P23Ph<207AdM080IVIV
0P1UIFD205iNGP03079bLP1=CDd0CDe=0080;bl_0P2/[:`20861P@80@d=30P1CDe<203dm?@80J6QX
0P0n?Sh207inOP80@T920P1BDU8207inOP80S8b<0P1hN7P00`1oOgl0NGUi07UiN@0406m_K`80JFUY
0P1DE5@204a<C080B4Q80P0g=cL203<c<`80:BTY0P0>3Ph201lO7`80Cdm?0P13@d<203<c<`0305iN
GP1ZJVX0JVYZ0080I6AT0P17AdL205mOG`80?Shn0P2/[:`2028R8P80Ng]k0P25QHD207IfMP80c/k>
5`2QXJ4209jNWP80YJFU0P2QXJ4209fMW@80WYjN0P2UYJDC0:6QXAD0oooo000C0?ooo`80WIfM202Q
XJ4209fMW@80XJ6Q0P2MWId50:6QX@80WYjN0P2UYJD60:6QX@80=3@d0P1TI6@203lo?`80=cLg0P0S
8b<204E5A@80B4Q80P0O7al00`0X:2P0m?Cd0?Cdm002071`L080JFUY0P1eMGD20:6QX@80T92@0P2;
Rh/208Z:RP80OGem0P1NGUh2065QH@80P8200P27QhL203`l?080@d=300<0?Cdm06IVIP1VIVH00P1[
Jf/207YjNP80HV9R0P2MWId208J6QP80UYJF0P2LW9`2092@T080Rh^;0P23Ph<207AdM080IVIV0P1U
IFD205iNGP03079bLP1=CDd0CDe=0080;bl_0P2/[:`20861P@80@d=30P1CDe<203dm?@80J6QX0P0n
?Sh207inOP80@T920P1BDU8207inOP80S8b<0P1hN7P00`1oOgl0NGUi07UiN@0406m_K`80JFUY0P1D
E5@204a<C080B4Q80P0g=cL203<c<`80:BTY0P0>3Ph201lO7`80Cdm?0P13@d<203<c<`0305iNGP1Z
JVX0JVYZ0080I6AT0P17AdL205mOG`80?Shn0P2/[:`2028R8P80Ng]k0P25QHD207IfMP80c/k>5`2Q
XJ4209jNWP80YJFU0P2QXJ4209fMW@80WYjN0P2UYJDC0:6QXAD0oooo000C0?oooa00XJ6Q00<0WYjN
0:FUY@2UYJD00P2QXJ4209fMW@H0XJ6Q0P2VYZH203lo?`80=3@d0P0h>3P203`l?0808B4Q0P19BDT2
0451@@80<c<c00<0=3@d0=SHf03Hf=P00P1UIFD206i^KP80QHF50P2LW9`209JFUP80R8R80P1hN7P2
06QXJ080BTY:0P0`<3020:n_[`80XJ6Q0P0e=CD206YZJP0300P8201gMgL0MgMg0080=cLg0P1eMGD2
071`L080Ogmo0P2ATI4209FEU@80UiNG0P2@T90208N7Q`80PX:20P1gMgL2071`L080De=C0P1JFUX0
0`1@D500N7Qh07QhN00204U9B@80HF5Q0P3Cdm<2028R8P80Shn?0P0:2PX207QhN080=cLg0P2FUYH2
01/K6`80CTi>0P1`L70207QhN080MGEe00<0Q8B407QhN01hN7P00P1cLg<206=SH`80KVi^0P1IFET2
04];B`80@4100P0i>CT203Hf=P805aLG0P0C4a<201`L7080:b/[0P1>CTh2034a<@0306=SH`1GEeL0
EeMG0080GemO0P1?Cdl205UIF@80ADE50P2PX:0201`L7080QhN70P21PH4208f=S@80alO75`2QXJ42
09fMW@H0XJ6Q0P2MWIdE0:6QXAD0oooo000C0?oooa00XJ6Q00<0WYjN0:FUY@2UYJD00P2QXJ4209fM
W@H0XJ6Q0P2VYZH203lo?`80=3@d0P0h>3P203`l?0808B4Q0P19BDT20451@@80<c<c00<0=3@d0=SH
f03Hf=P00P1UIFD206i^KP80QHF50P2LW9`209JFUP80R8R80P1hN7P206QXJ080BTY:0P0`<3020:n_
[`80XJ6Q0P0e=CD206YZJP0300P8201gMgL0MgMg0080=cLg0P1eMGD2071`L080Ogmo0P2ATI4209FE
U@80UiNG0P2@T90208N7Q`80PX:20P1gMgL2071`L080De=C0P1JFUX00`1@D500N7Qh07QhN00204U9
B@80HF5Q0P3Cdm<2028R8P80Shn?0P0:2PX207QhN080=cLg0P2FUYH201/K6`80CTi>0P1`L70207Qh
N080MGEe00<0Q8B407QhN01hN7P00P1cLg<206=SH`80KVi^0P1IFET204];B`80@4100P0i>CT203Hf
=P805aLG0P0C4a<201`L7080:b/[0P1>CTh2034a<@0306=SH`1GEeL0EeMG0080GemO0P1?Cdl205UI
F@80ADE50P2PX:0201`L7080QhN70P21PH4208f=S@80alO75`2QXJ4209fMW@H0XJ6Q0P2MWIdE0:6Q
XAD0oooo000C0?oooa00XJ6Q00<0WIfM0:6QX@2QXJ402P2QXJ4206UYJ@80`l?30P0n?Sh203Ti>@80
<30`0P0/;2`20451@@80?Cdm0P14A4@00`1LG5`0/;2`0;2`/002069RHP80Kfm_0P22PX8209RHV080
Shn?0P1jNWX206i^KP80F5QH0P0^;Rh203lo?`80F5QH0P13@d<202PX:080BDU900<0<30`05ADE01D
E5@00P0h>3P205iNGP80KFe]0P1jNWX208N7Q`80UYJF0P2ATI4209FEU@80R8R80P22PX8207alO080
NGUi0P1NGUh205MGE`0304m?C`1DE5@0E5AD0080G5aL0P1MGEd207]kN`807QhN0P0h>3P202@T9080
=CDe0P0n?Sh204A4A080>3Ph0P0j>SX206UYJ@80IVIV0P1UIFD00`1kNg/0N7Qh07QhN002079bLP80
H61P0P1NGUh205]KF`80@D510P13@d<20410@080<S8b0P0S8b<201HF5P@0:RXZ0P0c<c<203Xj>P03
061PH01FEUH0EUIF00@0CTi>0P1UIFD204];B`80UiNG0P0S8b<207MgM`80NWYj0P2d];@20:j^[RL0
XJ6Q00<0WYjN0:FUY@2UYJD0302QXJ4E0?ooo`004`3oool@0:6QX@0309fMW@2QXJ40XJ6Q00X0XJ6Q
0P1YJFT20<?3``80?Shn0P0i>CT2030`<080;2`/0P11@D4203dm?@80A4A400<0G5aL0;2`/02`/;00
0P1RHV8206m_K`80PX:20P2HV9P208n?S`80NWYj0P1^KVh205QHF080;Rh^0P0o?cl205QHF080@d=3
0P0X:2P204U9B@03030`<01DE5@0E5AD0080>3Ph0P1NGUh206e]K@80NWYj0P27QhL209JFUP80TI6A
0P2EUID208R8R080PX:20P1lO7`207UiN@80GUiN0P1GEeL00`1?Cdl0E5AD05ADE00205aLG080GEeM
0P1kNg/201hN7P80>3Ph0P0T92@203De=@80?Shn0P14A4@203Ph>080>SXj0P1YJFT206IVIP80IFEU
00<0Ng]k07QhN01hN7P00P1bLW82061PH080GUiN0P1KFe/20451@@80@d=30P10@402038b<P808b<S
0P0F5QH402XZ:P80<c<c0P0j>SX00`1PH600EUIF05IFEP0404i>CP80IFEU0P1;Bd/209NGU`808b<S
0P1gMgL207YjNP80];Bd0P2^[ZhW0:6QX@0309jNWP2UYJD0YJFU00`0XJ6Q5@3oool001<0oooo202Q
XJ4209jNWP80YJFU102QXJ400`2NWYh0YJFU0:FUY@0:0:6QX@80:RXZ0P2GUiL205iNGP80=3@d0P0c
<c<204M7A`80>3Ph0P0f=SH20492@P0307YjNP2FUYH0UYJF0080I6AT0P1_Kfl20861P@80VYZJ0P2:
RXX207emO@80KFe]0P1HF5P202h^;P80?3`l0P0o?cl2030`<080;Bd]0P0c<c<00`0n?Sh0F5QH05QH
F00205UIF@80JFUY0P1aLG4208>3P`80PX:20P2CTi<4092@T080R8R81022PX8207alO080JVYZ0P1N
GUh00`1MGEd0D51@051@D00204a<C080ATI60P1ZJVX203Xj>P80;2`/0P0];Bd202PX:080<30`0P0f
=SH205IFEP80DE5A0P1HF5P205iNGP80IVIV0`1_Kfl206MWI`80JFUY0P1IFET204a<C080?3`l0P12
@T8203dm?@80>SXj0P0/;2`201/K6`80;Bd]0P0W9bL202TY:@80>CTi00<0HV9R05]KF`1KFe/00P18
B4P204A4A080IFEU0P1NGUh208V9R@80;bl_0P1cLg<207inOP80bl_;0P2YZJTW0:6QX@0309fMW@2Q
XJ40XJ6Q00`0XJ6Q5@3oool001<0oooo202QXJ4209jNWP80YJFU102QXJ400`2NWYh0YJFU0:FUY@0:
0:6QX@80:RXZ0P2GUiL205iNGP80=3@d0P0c<c<204M7A`80>3Ph0P0f=SH20492@P0307YjNP2FUYH0
UYJF0080I6AT0P1_Kfl20861P@80VYZJ0P2:RXX207emO@80KFe]0P1HF5P202h^;P80?3`l0P0o?cl2
030`<080;Bd]0P0c<c<00`0n?Sh0F5QH05QHF00205UIF@80JFUY0P1aLG4208>3P`80PX:20P2CTi<4
092@T080R8R81022PX8207alO080JVYZ0P1NGUh00`1MGEd0D51@051@D00204a<C080ATI60P1ZJVX2
03Xj>P80;2`/0P0];Bd202PX:080<30`0P0f=SH205IFEP80DE5A0P1HF5P205iNGP80IVIV0`1_Kfl2
06MWI`80JFUY0P1IFET204a<C080?3`l0P12@T8203dm?@80>SXj0P0/;2`201/K6`80;Bd]0P0W9bL2
02TY:@80>CTi00<0HV9R05]KF`1KFe/00P18B4P204A4A080IFEU0P1NGUh208V9R@80;bl_0P1cLg<2
07inOP80bl_;0P2YZJTW0:6QX@0309fMW@2QXJ40XJ6Q00`0XJ6Q5@3oool001<0oooo202QXJ4209fM
W@H0XJ6Q00<0WIfM0:6QX@2QXJ40102QXJ4209jNWP80YJFU0P2QXJ4203Lg=`80?3`l0P1BDU82038b
<P80<c<c0P0o?cl203Ti>@80;Bd]0P1FEUH00`1`L700OGem07emO@02075aL@80JFUY0P24Q8@209fM
W@80Rh^;1025QHD2071`L080GUiN0P1<C4`203`l?080=CDe0P0h>3P203dm?@0303`l?01:BTX0BTY:
0080E5AD0P1hN7P208B4Q080UIFE0P2ATI4208R8R080U9BD0P2@T90208f=S@80PX:20P24Q8@208>3
P`80Lg=c0P1VIVH00`1aLG40GemO05mOG`0206YZJP80B4Q80P1GEeL205=CD`80F5QH0P1;Bd/203dm
?@80>SXj0P0m?Cd2059BDP80IfMW0P1SHf<2061PH080I6AT00<0KVi^06][J`1[Jf/00P1RHV82065Q
H@80HV9R0P1>CTh203Ph>080ATI60P0h>3P202d];@80;bl_0P0N7Qh202d];@80=CDe0P0/;2`202d]
;@0306=SH`1/K6`0K6a/0080@T920P16ATH206e]K@80J6QX0P28R8P203<c<`80MGEe0P2RXZ820;:b
/P80VYZJ<P2QXJ4209jNWP80YJFU5@3oool001<0oooo202QXJ4209fMW@H0XJ6Q00<0WIfM0:6QX@2Q
XJ40102QXJ4209jNWP80YJFU0P2QXJ4203Lg=`80?3`l0P1BDU82038b<P80<c<c0P0o?cl203Ti>@80
;Bd]0P1FEUH00`1`L700OGem07emO@02075aL@80JFUY0P24Q8@209fMW@80Rh^;1025QHD2071`L080
GUiN0P1<C4`203`l?080=CDe0P0h>3P203dm?@0303`l?01:BTX0BTY:0080E5AD0P1hN7P208B4Q080
UIFE0P2ATI4208R8R080U9BD0P2@T90208f=S@80PX:20P24Q8@208>3P`80Lg=c0P1VIVH00`1aLG40
GemO05mOG`0206YZJP80B4Q80P1GEeL205=CD`80F5QH0P1;Bd/203dm?@80>SXj0P0m?Cd2059BDP80
IfMW0P1SHf<2061PH080I6AT00<0KVi^06][J`1[Jf/00P1RHV82065QH@80HV9R0P1>CTh203Ph>080
ATI60P0h>3P202d];@80;bl_0P0N7Qh202d];@80=CDe0P0/;2`202d];@0306=SH`1/K6`0K6a/0080
@T920P16ATH206e]K@80J6QX0P28R8P203<c<`80MGEe0P2RXZ820;:b/P80VYZJ<P2QXJ4209jNWP80
YJFU5@3oool001<0oooo102QXJ4209jNWP80YJFU0P2QXJ4209jNWP80YJFU1`2QXJ4209jNWP@0XJ6Q
0P2VYZH209:BTP8051@D0P1@D50202<S8`80<C4a0P0`<30204e=C@807QhN0P1BDU800`1ZJVX0NGUi
07UiN@0206i^KP80H61P0P24Q8@20::RXP80PX:20P2GUiL209FEU@80Rh^;0P25QHD208N7Q`80Ogmo
0P1jNWX206=SH`80IfMW00<0KVi^06][J`1[Jf/00P1WIfL20:6QX@80Ph>3102@T90208b<S080Ti>C
0P29RHT2096AT@80Rh^;0P27QhL208Z:RP80KVi^0P1VIVH00`1IFET0D51@051@D00406YZJP80O7al
0P27QhL206QXJ080IFEU0P1TI6@206UYJ@80LW9b0P1^KVh207QhN080NWYj0P1cLg<206i^KP0306MW
I`1SHf<0Hf=S0080Lg=c0P1LG5`205UIF@80E5AD0P13@d<203lo?`80>SXj0P0e=CD201lO7`80820P
0P0T92@2038b<P80820P0P0m?Cd00`1?Cdl0JVYZ06YZJP0204Q8B080ADE50P1hN7P206YZJP80U9BD
0P0c<c<207]kN`80bLW90P2d];@d0:6QX@80WIfM0P2QXJ4E0?ooo`004`3oool40:6QX@80WIfM102Q
XJ4209fMW@T0XJ6Q0P2MWId40:6QX@80WinO0P2j^[X200820P80@D510P0Q8B4202l_;`80=SHf0P16
ATH202`/;080CDe=00<0E5AD06][J`1[Jf/00P1_Kfl2065QH@80O7al0P2ZZZX207inOP80RXZ:0P2I
VIT209ZJVP80SXj>0P2@T90208^;R`80HV9R0P1YJFT205IFEP0305MGE`1aLG40LG5a0080Hf=S0P22
PX8208J6QP@0UIFE0P2;Rh/209ZJVP80RHV90P2ATI4208n?S`80S8b<0P2=SHd20861P@80LW9b00<0
E5AD03dm?@0m?Cd00P0j>SX204A4A080FEUI0P1lO7`20:JVYP80SXj>0P2BTY8208>3P`80PH610P1f
MWH20820P080MGEe0P1dM7@206EUI@0305IFEP1_Kfl0Kfm_0080HF5Q0P1NGUh2055AD@@0CDe=0P0m
?Cd202/[:`80<c<c0P0O7al202HV9P@0820P0P0k>c/203lo?`0304e=C@1LG5`0G5aL0080BTY:0P0n
?Sh207alO080IVIV0P2EUID204];B`80LG5a0P3Lg=`j0:6QXAD0oooo000C0?ooo`@0XJ6Q0P2MWId4
0:6QX@80WIfM2@2QXJ4209fMW@@0XJ6Q0P2OWil20;Zj^P800P820P11@D42024Q8@80;bl_0P0f=SH2
04I6AP80;2`/0P1=CDd00`1DE5@0Jf][06][J`0206m_K`80HF5Q0P1lO7`20:ZZZP80OWin0P2:RXX2
09VIV@80VYZJ0P2>SXh2092@T080Rh^;0P1RHV8206UYJ@80EUIF00<0EeMG075aL@1aLG400P1SHf<2
08:2PP80QXJ6102EUID208^;R`80VYZJ0P29RHT2096AT@80Shn?0P2<S8`208f=S@80PH610P1bLW80
0`1DE5@0?Cdm03dm?@0203Xj>P80A4A40P1IFET207alO080YZJV0P2>SXh209:BTP80Ph>30P21PH42
07IfMP80P8200P1eMGD207AdM080IFEU00<0EUIF06m_K`1_Kfl00P1QHF4205iNGP80DE5A101=CDd2
03dm?@80:b/[0P0c<c<201lO7`809RHV100P820203/k>`80?clo00<0CDe=05aLG01LG5`00P1:BTX2
03hn?P80O7al0P1VIVH209FEU@80Bd];0P1aLG420=cLg3X0XJ6Q5@3oool001<0oooo5@2QXJ4209jN
WP80YJFU0P2VYZH206IVIP80k>c/0P000002030`<080<C4a0P0b<S8202HV9P80BDU90P0d=3@204a<
C00304Y:BP1@D500D51@0080K6a/0P1VIVH207UiN@80YJFU0P2:RXX205iNGP80RXZ:0P2EUID208V9
R@80PX:20P1ZJVX205aLG080LG5a0P1XJ6P00`1;Bd/0KFe]06e]K@0208V9R@@0Rh^;0P2?Shl209FE
U@H0Shn?102@T902096AT@80Rh^;0P29RHT208J6QP0307MgM`1JFUX0FUYJ00@0=CDe0P0l?3`204I6
AP80EeMG0P1fMWH206i^KP80Ph>30P28R8P207UiN@80MWIf0P1ZJVX406][J`03061PH01XJ6P0J6QX
0080HV9R0P1KFe/204Y:BP80B4Q80P1=CDd203Ph>080@T920P0D51@203De=@80;Bd]0P0V9RH201dM
7@809BDU0P1IFET00`1ADE40FUYJ05YJFP0204];B`80@T920P1gMgL206i^KP80I6AT0P1EEED20:RX
Z080`/;27`2QXJ4209jNWP80YJFU5`2QXJ4E0?ooo`004`3ooolE0:6QX@80WYjN0P2UYJD20:JVYP80
IVIV0P3/k>`200000080<30`0P0a<C42038b<P809RHV0P19BDT203@d=080C4a<00<0BTY:051@D01@
D5000P1/K6`206IVIP80NGUi0P2UYJD208Z:RP80GUiN0P2:RXX209FEU@80RHV90P22PX8206YZJP80
G5aL0P1aLG4206QXJ00304];B`1]KFd0KFe]0080RHV9102;Rh/208n?S`80UIFE1P2?Shl4092@T080
TI6A0P2;Rh/208V9R@80QXJ600<0MgMg05YJFP1JFUX0100e=CD203`l?080ATI60P1GEeL207IfMP80
KVi^0P23Ph<208R8R080NGUi0P1fMWH206YZJP@0Jf][00<0H61P06QXJ01XJ6P00P1RHV8205]KF`80
BTY:0P18B4P204e=C@80>3Ph0P12@T8201@D5080=CDe0P0];Bd202HV9P807AdM0P0U9BD205UIF@03
055AD@1JFUX0FUYJ0080Bd];0P12@T8207MgM`80KVi^0P1TI6@205EEE@80Z:RX0P32`/8O0:6QX@80
WYjN0P2UYJDG0:6QXAD0oooo000C0?oooaD0XJ6Q0P2JVYX20:FUY@80Z:RX0P17AdL207AdM080;Bd]
0P0e=CD204E5A@80=SHf0P0/;2`203Ti>@80=cLg0P14A4@304M7A`80Fe]K0P1OGel208R8R080W9bL
0P2ATI42065QH@80IFEU0P1OGel206MWI`80HV9R0P1UIFD206=SH`80K6a/0P2;Rh/308n?S``0UIFE
0P28R8P208n?S`80UIFE0P2>SXh208n?S`80RXZ:0P2<S8`208^;R`0308f=S@26QXH0QXJ60080NGUi
0P1^KVh205eMG@80BDU90P0j>SX204];B`80>CTi0P18B4P205]KF`80H61P0P1KFe/206MWI`80GEeM
0P1JFUX00`1YJFT0K6a/06a/K002069RHP80G5aL0P1:BTX204a<C080DE5A0P0b<S8203<c<`80;Rh^
0P0/;2`202PX:0805QHF0P0G5aL201dM7@80GemO00<0E5AD04E5A@15ADD00P1MGEd204=3@`80NGUi
0P1bLW8204A4A080I6AT0P39bLT20:f][Al0XJ6Q0P2MWId20:6QX@80WYjN0P2UYJDC0:6QXAD0oooo
000C0?oooaD0XJ6Q0P2JVYX20:FUY@80Z:RX0P17AdL207AdM080;Bd]0P0e=CD204E5A@80=SHf0P0/
;2`203Ti>@80=cLg0P14A4@304M7A`80Fe]K0P1OGel208R8R080W9bL0P2ATI42065QH@80IFEU0P1O
Gel206MWI`80HV9R0P1UIFD206=SH`80K6a/0P2;Rh/308n?S``0UIFE0P28R8P208n?S`80UIFE0P2>
SXh208n?S`80RXZ:0P2<S8`208^;R`0308f=S@26QXH0QXJ60080NGUi0P1^KVh205eMG@80BDU90P0j
>SX204];B`80>CTi0P18B4P205]KF`80H61P0P1KFe/206MWI`80GEeM0P1JFUX00`1YJFT0K6a/06a/
K002069RHP80G5aL0P1:BTX204a<C080DE5A0P0b<S8203<c<`80;Rh^0P0/;2`202PX:0805QHF0P0G
5aL201dM7@80GemO00<0E5AD04E5A@15ADD00P1MGEd204=3@`80NGUi0P1bLW8204A4A080I6AT0P39
bLT20:f][Al0XJ6Q0P2MWId20:6QX@80WYjN0P2UYJDC0:6QXAD0oooo000C0?ooo`P0XJ6Q0P2NWYh2
0:FUY@@0XJ6Q00<0WYjN0:FUY@2UYJD00P2QXJ4209fMW@@0XJ6Q0P1?Cdl202`/;080<c<c0P0b<S82
061PH080>c/k0P0e=CD203Ti>@80<c<c0P16ATH00`13@d<0BDU904U9B@0205]KF`80EEEE0P2;Rh/2
0::RXP80S8b<0P2?Shl208N7Q`80Lg=c0P1TI6@205iNGP80MGEe0P2?Shl209^KV`d0UIFE0P2DU9@2
09FEU@80RHV91P2EUID208n?S`@0T92@0P2?Shl00`2@T900SHf=08f=S@0208>3P`80QhN70P28R8P2
08:2PP@0QXJ60P1UIFD205IFEP80Cdm?0P1=CDd2055AD@80IVIV0P1XJ6P206=SH`0306e]K@1SHf<0
Hf=S0080Hf=S0P1IFET2051@D080E5AD0P1BDU8203hn?P80:2PX0P0];Bd201hN7P805aLG100E5AD2
01`L7080QHF500<0?3`l0410@010@4000P20P80203Lg=`80KFe]0P28R8P203<c<`80Ogmo0P3Lg=`U
0:6QX@80WIfM5@2QXJ4E0?ooo`004`3oool80:6QX@80WYjN0P2UYJD40:6QX@0309jNWP2UYJD0YJFU
0080XJ6Q0P2MWId40:6QX@80Cdm?0P0/;2`203<c<`80<S8b0P1PH60203/k>`80=CDe0P0i>CT203<c
<`80ATI600<0@d=304U9B@19BDT00P1KFe/205EEE@80Rh^;0P2RXZ8208b<S080Shn?0P27QhL207=c
L`80I6AT0P1NGUh207EeM@80Shn?0P2KVi/=09FEU@80U9BD0P2EUID208V9R@H0UIFE0P2?Shl4092@
T080Shn?00<0T92@08f=S@2=SHd00P23Ph<208N7Q`80R8R80P22PX8408J6QP80IFEU0P1FEUH204m?
C`80CDe=0P1ADE4206IVIP80J6QX0P1SHf<00`1]KFd0Hf=S06=SH`0206=SH`80FEUI0P1@D50205AD
E080DU9B0P0n?Sh202PX:080;Bd]0P0N7Qh201LG5`@05ADE0P0L71`208F5Q@0303`l?010@400@410
0080P8200P0g=cL206e]K@80R8R80P0c<c<207moO`80g=cL9@2QXJ4209fMWAD0XJ6Q5@3oool001<0
oooo102QXJ4209jNWP80YJFU0P2MWId40:6QX@80WYjN2`2QXJ4205eMG@8092@T0P0n?Sh203lo?`80
KVi^0P0o?cl203Lg=`80@D510P0j>SX204=3@`030492@P16ATH0ATI60080HV9R0P1?Cdl208Z:RP80
XJ6Q0P2>SXh208^;R`80S8b<0P2FUYH2092@T080SXj>0P2EUID208j>SP80Shn?0P2GUiL00`2JVYX0
UIFE09FEU@0209FEU@80T92@0P2JVYX609FEU@80RXZ:0P2DU9@209^KV`@0Shn?0P2EUID208V9R@80
T92@00<0Shn?092@T02@T9000P2:RXX208B4Q080T92@0P22PX8208N7Q`80QXJ60P1mOGd208b<S080
O7al0P1nOWh207=cL`80LW9b0P1cLg<206][J`03079bLP1PH600H61P0080Hf=S0P1FEUH204U9B@80
EUIF0P1DE5@203lo?`80ADE50P0U9BD201/K6`807QhN0P0H61P202DU9@806a/K0P2PX:000`0o?cl0
>3Ph03Ph>00208b<S080@T920P1@D50209nOW`80<S8b0P2PX:020=GEe@80VYZJ>P2QXJ4E0?ooo`00
4`3oool40:6QX@80WYjN0P2UYJD209fMW@@0XJ6Q0P2NWYh;0:6QX@80GEeM0P0T92@203hn?P80?clo
0P1^KVh203lo?`80=cLg0P11@D4203Xj>P80@d=300<0@T9204I6AP16ATH00P1RHV8204m?C`80RXZ:
0P2QXJ4208j>SP80Rh^;0P2<S8`209JFUP80T92@0P2>SXh209FEU@80SXj>0P2?Shl209NGU`0309ZJ
VP2EUID0UIFE0080UIFE0P2@T90209ZJVPH0UIFE0P2:RXX209BDU080Vi^K102?Shl209FEU@80RHV9
0P2@T9000`2?Shl0T92@092@T00208Z:RP80Q8B40P2@T90208:2PP80QhN70P26QXH207emO@80S8b<
0P1lO7`207inOP80Lg=c0P1bLW8207=cL`80Jf][00<0LW9b061PH01PH6000P1SHf<205IFEP80BDU9
0P1FEUH205ADE080?clo0P15ADD202DU9@806a/K0P0N7Qh201PH60809BDU0P0K6a/20:2PX00303lo
?`0h>3P0>3Ph0080S8b<0P12@T82051@D080WinO0P0b<S820:2PX080eMGE0P2JVYXj0:6QXAD0oooo
000C0?ooo`@0XJ6Q0P2MWId80:6QX@80WIfM2`2QXJ4205aLG0805ADE0P19BDT20451@@80H61P1014
A4@20451@@@0?Cdm00<0?clo0410@010@4000P1MGEd205=CD`80NGUi0P2XZ:P209>CT`80Shn?0P2<
S8`209:BTP80UYJF0P2?Shl209BDU080Vi^K0P2>SXh208^;R`0309ZJVP2EUID0UIFE0080UIFE0P2?
Shl809FEU@80Shn?0P2>SXh209FEU@@0SXj>102?Shl2092@T00308j>SP2ATI40TI6A0080TI6A0P29
RHT208f=S@80PX:20P27QhL208F5Q@80Ph>30P22PX8207emO@80NWYj0P1dM7@2079bLP@0KVi^00<0
Jf][06MWI`1WIfL00P1SHf<205ADE080Cdm?0P1IFET204e=C@80A4A40P0f=SH202DU9@80:b/[0P0S
8b<201<C4`8061PH0P0M7Ad20:RXZ00304Y:BP10@400@4100080QXJ61012@T8208n?S`80?3`l0P3P
h>020:b/[3`0XJ6Q5@3oool001<0oooo102QXJ4209fMW@P0XJ6Q0P2MWId;0:6QX@80G5aL0P0E5AD2
04U9B@80@D510P1PH60404A4A080@D51100m?Cd00`0o?cl0@4100410@00205eMG@80De=C0P1iNGT2
0:RXZ080Ti>C0P2?Shl208b<S080TY:B0P2FUYH208n?S`80U9BD0P2KVi/208j>SP80Rh^;00<0VYZJ
09FEU@2EUID00P2EUID208n?S`P0UIFE0P2?Shl208j>SP80UIFE102>SXh408n?S`80T92@00<0SXj>
096AT@2ATI400P2ATI4208V9R@80SHf=0P22PX8208N7Q`80QHF50P23Ph<208:2PP80OGem0P1jNWX2
07AdM080LW9b101^KVh00`1[Jf/0IfMW06MWI`0206=SH`80E5AD0P1?Cdl205UIF@80CDe=0P14A4@2
03Hf=P809BDU0P0[:b/202<S8`804a<C0P0H61P201dM7@80Z:RX00<0BTY:0410@010@4000P26QXH4
0492@P80Shn?0P0l?3`20>3Ph080[:b/?02QXJ4E0?ooo`004`3oool:0:6QX@80WYjN0P2UYJD=0:6Q
X@80OWin0P0>3Ph203lo?`80@T920P17AdL404Y:BP80?Cdm0P13@d<203/k>`030451@@0k>c/0>c/k
0080HF5Q0P1EEED206i^KP80VIVI0P2<S8`209FEU@80S8b<0P2=SHd209FEU@80T92@0P2>SXh209JF
UP80Vi^K0P2?Shl509FEU@80T92@0P2EUID209ZJVPP0UIFE0P2?Shl409JFUP@0Shn?0P2:RXX00`2@
T900SHf=08f=S@0208f=S@@0RXZ:1027QhL207inOP80RXZ:0P21PH4208:2PP80NWYj0P1cLg<207Ui
N@80Kfm_0P1aLG400`1SHf<0Kfm_06m_K`02065QH@80Fe]K0P1?Cdl205ADE080Bd];0P0m?Cd203<c
<`809BDU0P0d=3@201PH608051@D0P0E5AD202PX:080O7al00<0M7Ad04A4A014A4@00P1nOWh204I6
AP80A4A40P1EEED207]kN`80emOG9@2QXJ4209jNWP80YJFU5@2QXJ4E0?ooo`004`3oool:0:6QX@80
WYjN0P2UYJD=0:6QX@80OWin0P0>3Ph203lo?`80@T920P17AdL404Y:BP80?Cdm0P13@d<203/k>`03
0451@@0k>c/0>c/k0080HF5Q0P1EEED206i^KP80VIVI0P2<S8`209FEU@80S8b<0P2=SHd209FEU@80
T92@0P2>SXh209JFUP80Vi^K0P2?Shl509FEU@80T92@0P2EUID209ZJVPP0UIFE0P2?Shl409JFUP@0
Shn?0P2:RXX00`2@T900SHf=08f=S@0208f=S@@0RXZ:1027QhL207inOP80RXZ:0P21PH4208:2PP80
NWYj0P1cLg<207UiN@80Kfm_0P1aLG400`1SHf<0Kfm_06m_K`02065QH@80Fe]K0P1?Cdl205ADE080
Bd];0P0m?Cd203<c<`809BDU0P0d=3@201PH608051@D0P0E5AD202PX:080O7al00<0M7Ad04A4A014
A4@00P1nOWh204I6AP80A4A40P1EEED207]kN`80emOG9@2QXJ4209jNWP80YJFU5@2QXJ4E0?ooo`00
4`3oool:0:6QX@80WIfM3`2QXJ420::RXP8030`<0P1;Bd/203Lg=`80AdM71019BDT403hn?P80?clo
00<0?Cdm04M7A`17AdL00P1KFe/206UYJ@80Jf][0P2?Shl208b<S080UIFE0P2<S8`2096AT@@0T92@
0P2?Shl209>CT`80UIFE0P2@T9000`2EUID0VYZJ09ZJVP0209FEU@80Rh^;102EUID208n?S`80Vi^K
102EUID208V9R@@0Shn?0P2@T90208n?S`80R8R800<0S8b<08R8R028R8P00P2=SHd208R8R080Q8B4
1027QhL207MgM`80P8200P21PH4208:2PP80OWin0P1dM7@207IfMP80L71`0P1bLW8306ATI080Fe]K
0P1MGEd205YJFP80D51@0P17AdL203Xj>P80:2PX0P0e=CD201dM7@@06QXJ0P0D51@202<S8`80L71`
00<0PH6104Y:BP1:BTX00P21PH4205IFEP80CTi>0P0l?3`40;no_bD0XJ6Q0P2MWIdG0:6QXAD0oooo
000C0?ooo`X0XJ6Q0P2MWId?0:6QX@80XZ:R0P0<30`204];B`80=cLg0P17AdL404U9B@@0?Shn0P0o
?cl00`0m?Cd0AdM704M7A`0205]KF`80JFUY0P1[Jf/208n?S`80S8b<0P2EUID208b<S080TI6A102@
T90208n?S`80Ti>C0P2EUID2092@T00309FEU@2JVYX0VYZJ0080UIFE0P2;Rh/409FEU@80Shn?0P2K
Vi/409FEU@80RHV9102?Shl2092@T080Shn?0P28R8P00`2<S8`0R8R808R8R00208f=S@80R8R80P24
Q8@408N7Q`80MgMg0P20P8020861P@80PX:20P1nOWh207AdM080MWIf0P1`L702079bLP<0I6AT0P1K
Fe/205eMG@80FUYJ0P1@D50204M7A`80>SXj0P0X:2P203De=@807AdM100J6QX201@D50808b<S0P1`
L7000`21PH40BTY:04Y:BP020861P@80EUIF0P1>CTh203`l?0@0_kno9@2QXJ4209fMWAL0XJ6Q5@3o
ool001<0oooo6`2QXJ420:j^[P802PX:0P0e=CD204A4A080CTi>0P1;Bd/20451@@80BTY:0P0j>SX2
0451@@0304];B`14A4@0A4A40080EeMG0P1[Jf/206m_K`80Ph>30P2ATI4409:BTP@0TI6A0P2EUID2
092@T080UIFE0P2JVYX208n?S`0308Z:RP2GUiL0UiNG0080VYZJ102?Shl209NGU`80Ti>C0P2@T902
09BDU080UYJF0P2@T90208j>SPH0T92@0P2=SHd00`2EUID0R8R808R8R00208f=S@80QHF50P2=SHd2
08:2PP80QhN70P1oOgl207QhN080OGem0P1nOWh207YjNP80MWIf0P1gMgL206m_K`80LW9b00<0Hf=S
06][J`1[Jf/00P1KFe/205YJFP80GEeM0P19BDT204e=C@80?Cdm0P0/;2`202d];@806QXJ0P0E5AD4
00l?3`80A4A40P1BDU800`1]KFd0D51@051@D00207inOP80GUiN0P1ZJVX203lo?`80d=3@@02QXJ4E
0?ooo`004`3ooolK0:6QX@80[Zj^0P0:2PX203De=@80A4A40P1>CTh204];B`80@D510P1:BTX203Xj
>P80@D5100<0Bd];04A4A014A4@00P1GEeL206][J`80Kfm_0P23Ph<2096AT@@0TY:B102ATI4209FE
U@80T92@0P2EUID209ZJVP80Shn?00<0RXZ:09NGU`2GUiL00P2JVYX408n?S`80UiNG0P2CTi<2092@
T080U9BD0P2FUYH2092@T080SXj>1P2@T90208f=S@0309FEU@28R8P0R8R80080SHf=0P25QHD208f=
S@80PX:20P27QhL207moO`80N7Qh0P1mOGd207inOP80NWYj0P1fMWH207MgM`80Kfm_0P1bLW800`1S
Hf<0Jf][06][J`0205]KF`80FUYJ0P1MGEd204U9B@80CDe=0P0m?Cd202`/;080;Bd]0P0J6QX201DE
5@@03`l?0P14A4@2059BDP0306e]K@1@D500D51@0080OWin0P1NGUh206YZJP80?clo0P3@d=100:6Q
XAD0oooo000C0?oooa/0XJ6Q0P2^[Zh201@D5080EEEE0P18B4P203dm?@80C4a<0P12@T8204=3@`80
?Shn0P17AdL00`0d=3@0DU9B059BDP0205iNGP80J6QX0P1VIVH208B4Q080TI6A0P2>SXh2096AT@80
SXj>1P2@T90409FEU@80Shn?00<0UIFE08n?S`2?Shl00P2EUID2092@T080Ti>C0P2;Rh/209BDU080
UYJF0P2:RXX208j>SP@0T92@0P2?Shl2092@T080TI6A0P2<S8`00`2@T900S8b<08b<S00208>3P`80
RXZ:0P2>SXh208B4Q080QhN70P1oOgl208V9R@80N7Qh0P22PX8207QhN080NGUi0P1gMgL206m_K`80
LW9b00<0G5aL071`L01`L7000P1GEeL205YJFP80D51@0P19BDT20451@@80=cLg0P0m?Cd2024Q8@80
51@D0P0>3Ph201lO7`8030`<0P1OGel204e=C@0305=CD`1<C4`0C4a<0080QXJ60P1WIfL207YjNP80
S8b<0P2e]KE00:6QXAD0oooo000C0?oooa/0XJ6Q0P2^[Zh201@D5080EEEE0P18B4P203dm?@80C4a<
0P12@T8204=3@`80?Shn0P17AdL00`0d=3@0DU9B059BDP0205iNGP80J6QX0P1VIVH208B4Q080TI6A
0P2>SXh2096AT@80SXj>1P2@T90409FEU@80Shn?00<0UIFE08n?S`2?Shl00P2EUID2092@T080Ti>C
0P2;Rh/209BDU080UYJF0P2:RXX208j>SP@0T92@0P2?Shl2092@T080TI6A0P2<S8`00`2@T900S8b<
08b<S00208>3P`80RXZ:0P2>SXh208B4Q080QhN70P1oOgl208V9R@80N7Qh0P22PX8207QhN080NGUi
0P1gMgL206m_K`80LW9b00<0G5aL071`L01`L7000P1GEeL205YJFP80D51@0P19BDT20451@@80=cLg
0P0m?Cd2024Q8@8051@D0P0>3Ph201lO7`8030`<0P1OGel204e=C@0305=CD`1<C4`0C4a<0080QXJ6
0P1WIfL207YjNP80S8b<0P2e]KE00:6QXAD0oooo000C0?ooo`@0XJ6Q0P2NWYh20:FUY@80WYjN0P2U
YJD?0:6QX@80Z:RX0P0J6QX202`/;080?clo1P11@D4203lo?`80@d=30P11@D400`10@400AdM704M7
A`02065QH@80Jf][0P1/K6`207YjNP80T92@0P2>SXh208n?S`80TY:B0P2@T90208n?S`80TI6A0P2J
VYX209FEU@80RXZ:00<0VYZJ092@T02@T9000P2JVYX208^;R`80U9BD0P2ATI4209>CT`80T92@102?
Shl4092@T0H0Shn?0P2ATI400`2@T900RXZ:08Z:RP0208Z:RP80RHV90P25QHD408N7Q`80MgMg0P2?
Shl207EeM@80OWin0P1cLg<407QhN080Lg=c0P1^KVh00`1QHF40L71`071`L00205=CD`80EeMG0P1<
C4`204e=C@80@d=30P0c<c<202`/;08092@T0P0B4Q8201@D50808B4Q0P0B4Q8206YZJP80C4a<00<0
DE5A04=3@`13@d<00P22PX8206a/K080Lg=c0P3:b/Y20:6QXAD0oooo000C0?ooo`@0XJ6Q0P2NWYh2
0:FUY@80WYjN0P2UYJD?0:6QX@80Z:RX0P0J6QX202`/;080?clo1P11@D4203lo?`80@d=30P11@D40
0`10@400AdM704M7A`02065QH@80Jf][0P1/K6`207YjNP80T92@0P2>SXh208n?S`80TY:B0P2@T902
08n?S`80TI6A0P2JVYX209FEU@80RXZ:00<0VYZJ092@T02@T9000P2JVYX208^;R`80U9BD0P2ATI42
09>CT`80T92@102?Shl4092@T0H0Shn?0P2ATI400`2@T900RXZ:08Z:RP0208Z:RP80RHV90P25QHD4
08N7Q`80MgMg0P2?Shl207EeM@80OWin0P1cLg<407QhN080Lg=c0P1^KVh00`1QHF40L71`071`L002
05=CD`80EeMG0P1<C4`204e=C@80@d=30P0c<c<202`/;08092@T0P0B4Q8201@D50808B4Q0P0B4Q82
06YZJP80C4a<00<0DE5A04=3@`13@d<00P22PX8206a/K080Lg=c0P3:b/Y20:6QXAD0oooo000C0?oo
o`@0XJ6Q0P2MWId20:6QX@80WIfM4`2QXJ4209:BTP8061PH0P0k>c/203dm?@80=SHf0P10@40203/k
>`80>CTi0P13@d<00`1;Bd/0CDe=04e=C@0206ATI080IFEU0P1hN7P207]kN`80S8b<0P2>SXh2096A
T@80SXj>0P2HV9P208j>SP80TI6A102EUID2092@T00309BDU02FUYH0UYJF0080UIFE0P2?Shl208j>
SP80RXZ:102FUYH208Z:RP80Shn?202@T90208n?S`80T92@00<0RXZ:08f=S@2=SHd0102=SHd208:2
PP80SHf=0P22PX8207inOP80QhN7101iNGT207=cL`80MgMg0P1cLg<207emO@80KVi^00<0K6a/06=S
H`1SHf<00P1GEeL205QHF080CDe=0P13@d<204I6AP80;2`/0P0V9RH201/K6`806QXJ0P0>3Ph201dM
7@8051@D0P1kNg/204I6AP0304];B`18B4P0B4Q80080R8R80P1jNWX208:2PP80`/;2@P2QXJ4E0?oo
o`004`3oool40:6QX@80WIfM0P2QXJ4209fMWA<0XJ6Q0P2BTY8201PH6080>c/k0P0m?Cd203Hf=P80
@4100P0k>c/203Ti>@80@d=300<0Bd];04e=C@1=CDd00P1TI6@206EUI@80N7Qh0P1kNg/208b<S080
SXj>0P2ATI4208j>SP80V9RH0P2>SXh2096AT@@0UIFE0P2@T9000`2DU9@0UYJF09JFUP0209FEU@80
Shn?0P2>SXh208Z:RP@0UYJF0P2:RXX208n?S`P0T92@0P2?Shl2092@T00308Z:RP2=SHd0SHf=00@0
SHf=0P22PX8208f=S@80PX:20P1nOWh208N7Q`@0NGUi0P1cLg<207MgM`80Lg=c0P1mOGd206i^KP03
06a/K01SHf<0Hf=S0080EeMG0P1HF5P204e=C@80@d=30P16ATH202`/;0809RHV0P0K6a/201XJ6P80
3Ph>0P0M7Ad201@D5080Ng]k0P16ATH00`1;Bd/0B4Q804Q8B00208R8R080NWYj0P22PX820<;2`T80
XJ6Q5@3oool001<0oooo7@2QXJ420:RXZ0807alO0P0S8b<203Ti>@80>SXj100l?3`203Xj>P80>c/k
00<0@d=305MGE`1GEeL00P1RHV8206YZJP80N7Qh0P23Ph<208Z:RP80SXj>0P2CTi<208V9R@80UIFE
0P2>SXh2092@T080UYJF0P2:RXX209JFUP0308j>SP2EUID0UIFE00@0UIFE0P2?Shl209FEU@80RXZ:
0P2DU9@209JFUP80RXZ:0P2ATI4208n?S`80TI6A1P2@T9000`25QHD0T92@092@T00208R8R080RXZ:
0P28R8P208Z:RP80QhN70P26QXH208N7Q`80NWYj0P1nOWh207AdM080MgMg1P1cLg<00`1XJ6P0IfMW
06MWI`0205UIF@80E5AD0P1FEUH204I6AP80>c/k0P0S8b<202DU9@8061PH0P0O7al2014A4@8071`L
0P0J6QX20820P080EEEE00<0=cLg05MGE`1GEeL00P1lO7`209FEU@80[:b/0P2QXJ4209jNWP80YJFU
?P2QXJ4E0?ooo`004`3ooolM0:6QX@80Z:RX0P0O7al202<S8`80>CTi0P0j>SX403`l?080>SXj0P0k
>c/00`13@d<0EeMG05MGE`02069RHP80JVYZ0P1hN7P208>3P`80RXZ:0P2>SXh209>CT`80RHV90P2E
UID208j>SP80T92@0P2FUYH208Z:RP80UYJF00<0SXj>09FEU@2EUID0102EUID208n?S`80UIFE0P2:
RXX209BDU080UYJF0P2:RXX2096AT@80Shn?0P2ATI46092@T00308F5Q@2@T900T92@0080R8R80P2:
RXX208R8R080RXZ:0P27QhL208J6QP80QhN70P1jNWX207inOP80M7Ad0P1gMgL607=cL`0306QXJ01W
IfL0IfMW0080FEUI0P1DE5@205IFEP80ATI60P0k>c/202<S8`809BDU0P0H61P201lO7`804A4A0P0L
71`201XJ6P80P8200P1EEED00`0g=cL0EeMG05MGE`0207alO080UIFE0P2/[:`20:6QX@80WYjN0P2U
YJDn0:6QXAD0oooo000C0?ooo`80XJ6Q0P2NWYh20:FUYAT0XJ6Q0P1/K6`201<C4`80<30`0P0i>CT2
03hn?P80?3`l0P0o?cl203hn?P0303Xj>P1GEeL0EeMG0080IFEU0P1ZJVX207QhN080Ogmo0P2ATI42
08R8R080SXj>0P2@T90209>CT`80U9BD0P2?Shl209FEU@80Shn?0P2EUID00`2JVYX0T92@092@T002
09ZJVP80Shn?0P2@T90209FEU@80Shn?0P2@T90209BDU080Shn?0P2ATI4208n?S`80T92@0P2?Shl2
096AT@80T92@00<0R8R8096AT@2ATI400P2:RXX208b<S080QhN70P25QHD408N7Q`80PH610P1nOWh2
07emO@80MGEe0P1cLg<207QhN080KVi^0P1_Kfl00`1YJFT0GEeM05eMG@02069RHP80CTi>0P1@D502
04M7A`80>c/k0P0S8b<202DU9@8071`L0P0K6a/401lO7`8051@D0P1fMWH206YZJP0303`l?01UIFD0
IFEU0080NWYj0P2JVYX20<71`@80XJ6Q0P2MWIe00:6QXAD0oooo000C0?ooo`80XJ6Q0P2NWYh20:FU
YAT0XJ6Q0P1/K6`201<C4`80<30`0P0i>CT203hn?P80?3`l0P0o?cl203hn?P0303Xj>P1GEeL0EeMG
0080IFEU0P1ZJVX207QhN080Ogmo0P2ATI4208R8R080SXj>0P2@T90209>CT`80U9BD0P2?Shl209FE
U@80Shn?0P2EUID00`2JVYX0T92@092@T00209ZJVP80Shn?0P2@T90209FEU@80Shn?0P2@T90209BD
U080Shn?0P2ATI4208n?S`80T92@0P2?Shl2096AT@80T92@00<0R8R8096AT@2ATI400P2:RXX208b<
S080QhN70P25QHD408N7Q`80PH610P1nOWh207emO@80MGEe0P1cLg<207QhN080KVi^0P1_Kfl00`1Y
JFT0GEeM05eMG@02069RHP80CTi>0P1@D50204M7A`80>c/k0P0S8b<202DU9@8071`L0P0K6a/401lO
7`8051@D0P1fMWH206YZJP0303`l?01UIFD0IFEU0080NWYj0P2JVYX20<71`@80XJ6Q0P2MWIe00:6Q
XAD0oooo000C0?ooo`80XJ6Q0P2MWIdK0:6QX@80WIfM0P0H61P203Hf=P80<C4a0P11@D4203`l?080
>SXj0P12@T800`0n?Sh0De=C05=CD`0205aLG080NWYj0P22PX8208B4Q080QhN70P2>SXh208f=S@80
Rh^;1P2@T90208n?S`80T92@0P2FUYH00`2EUID0RXZ:08Z:RP0209NGU`@0Shn?0P2@T90208n?S`@0
T92@102?Shl2096AT@80T92@0P2?Shl2092@T0D0SHf=0P28R8P208f=S@80QXJ61027QhL208R8R080
O7al0P21PH4207emO@80NWYj0P1fMWH207QhN080L71`0P1_Kfl00`1TI6@0Fe]K05]KF`0205iNGP80
Cdm?0P1;Bd/203lo?`80=3@d0P0V9RH202TY:@807QhN0P0J6QX202<S8`805ADE0P0>3Ph207=cL`80
G5aL00<0BTY:075aL@1aLG400P29RHT20;:b/P80ZJVYA02QXJ4E0?ooo`004`3oool20:6QX@80WIfM
6`2QXJ4209fMW@8061PH0P0f=SH2034a<@80@D510P0l?3`203Xj>P80@T9200<0?Shn05=CD`1CDe<0
0P1LG5`207YjNP80PX:20P24Q8@208N7Q`80SXj>0P2=SHd208^;R`H0T92@0P2?Shl2092@T080UYJF
00<0UIFE08Z:RP2:RXX00P2GUiL408n?S`80T92@0P2?Shl4092@T0@0Shn?0P2ATI42092@T080Shn?
0P2@T90508f=S@80R8R80P2=SHd208J6QP@0QhN70P28R8P207alO080PH610P1mOGd207YjNP80MWIf
0P1hN7P2071`L080Kfm_00<0I6AT05]KF`1KFe/00P1NGUh204m?C`80Bd];0P0o?cl203@d=0809RHV
0P0Y:BT201hN7P806QXJ0P0S8b<201DE5@803Ph>0P1cLg<205aLG00304Y:BP1aLG40LG5a0080RHV9
0P2b/[820:VYZD@0XJ6Q5@3oool001<0oooo8@2QXJ420410@0807AdM0P0X:2P203hn?P80A4A40P11
@D4203Ti>@030410@01DE5@0E5AD0080GUiN0P1/K6`208:2PP80TY:B0P2;Rh/208R8R080SHf=0P2C
Ti<208n?S`80Ti>C0P2DU9@408n?S`80UYJF00<0UiNG08n?S`2?Shl00P2?Shl209JFUP80RXZ:0P2>
SXh2092@T080Shn?102@T90208b<S080UIFE0P2=SHd4096AT@80SHf=00<0T92@08F5Q@25QHD00P2>
SXh208B4Q0H0QhN70P20P80208B4Q080P8200P1jNWX207IfMP80OGem0P1^KVh407AdM00305UIF@1Q
HF40HF5Q00@0E5AD0P11@D4203/k>`80<30`0P0b<S8202<S8`809BDU0P0H61P201HF5P803@d=0P0[
:b/207QhN080B4Q800<0DU9B07AdM01dM7@00P24Q8@20=CDe080WYjN0P2UYJE20:6QXAD0oooo000C
0?ooo`80XJ6Q0P2NWYh20:FUY@l0XJ6Q0P2NWYh20:FUY@P0XJ6Q0P2^[Zh206][J`80=3@d0P0M7Ad2
04U9B@80@D510P16ATH00`11@D40Bd];04];B`02069RHP80LW9b0P1cLg<208Z:RP80UiNG0P28R8P2
08N7Q`80Ti>C0P2;Rh/2092@T080Shn?0P2<S8`209>CT`80Shn?00<0TI6A092@T02@T9000P2?Shl2
09FEU@80T92@102?Shl2096AT@@0T92@0P2<S8`2092@T080R8R8102=SHd2092@T00308f=S@24Q8@0
Q8B40080SHf=1027QhL208J6QP80QhN70P1jNWX207emO@80PH610P1mOGd407QhN080JVYZ0P1gMgL2
06IVIP03069RHP1NGUh0GUiN0080C4a<0P15ADD203hn?P80@D510P0/;2`202/[:`80:BTY0P0N7Qh2
020P80803`l?0P0<30`206][J`80G5aL0P14A4@00`1SHf<0LG5a075aL@0209jNWP80`<300P2MWIe4
0:6QXAD0oooo000C0?ooo`80XJ6Q0P2NWYh20:FUY@l0XJ6Q0P2NWYh20:FUY@P0XJ6Q0P2^[Zh206][
J`80=3@d0P0M7Ad204U9B@80@D510P16ATH00`11@D40Bd];04];B`02069RHP80LW9b0P1cLg<208Z:
RP80UiNG0P28R8P208N7Q`80Ti>C0P2;Rh/2092@T080Shn?0P2<S8`209>CT`80Shn?00<0TI6A092@
T02@T9000P2?Shl209FEU@80T92@102?Shl2096AT@@0T92@0P2<S8`2092@T080R8R8102=SHd2092@
T00308f=S@24Q8@0Q8B40080SHf=1027QhL208J6QP80QhN70P1jNWX207emO@80PH610P1mOGd407Qh
N080JVYZ0P1gMgL206IVIP03069RHP1NGUh0GUiN0080C4a<0P15ADD203hn?P80@D510P0/;2`202/[
:`80:BTY0P0N7Qh2020P80803`l?0P0<30`206][J`80G5aL0P14A4@00`1SHf<0LG5a075aL@0209jN
WP80`<300P2MWIe40:6QXAD0oooo000C0?ooo`80XJ6Q0P2MWIdA0:6QX@80WIfM2P2QXJ440:RXZ080
VYZJ0P0N7Qh202d];@80AdM70P0k>c/00`1=CDd0AdM704M7A`0205mOG`80Kfm_0P1hN7P208>3P`80
T92@0P26QXH2092@T080SHf=0P2CTi<208n?S`80TI6A0P2?Shl2092@T080U9BD0`2@T90208f=S@80
UIFE102@T90208b<S080UIFE0P2;Rh/209>CT`80T92@0P2BTY8408f=S@80RXZ:0P2>SXh00`2=SHd0
QhN708N7Q`0408N7Q`80R8R80P26QXH208N7Q`80Ng]k0P1lO7`407inOP@0N7Qh0P1ZJVX206m_K`80
Jf][00<0F5QH05MGE`1GEeL00P1;Bd/20492@P80?Cdm0P10@40203Ti>@807alO0P0X:2P201lO7`80
5ADE0P0>3Ph205eMG@80Cdm?0P1>CTh204A4A003071`L01mOGd0OGem0080Zj^[0P2][Jd209jNWP80
XZ:R0P2UYJE00:6QXAD0oooo000C0?ooo`80XJ6Q0P2MWIdA0:6QX@80WIfM2P2QXJ440:RXZ080VYZJ
0P0N7Qh202d];@80AdM70P0k>c/00`1=CDd0AdM704M7A`0205mOG`80Kfm_0P1hN7P208>3P`80T92@
0P26QXH2092@T080SHf=0P2CTi<208n?S`80TI6A0P2?Shl2092@T080U9BD0`2@T90208f=S@80UIFE
102@T90208b<S080UIFE0P2;Rh/209>CT`80T92@0P2BTY8408f=S@80RXZ:0P2>SXh00`2=SHd0QhN7
08N7Q`0408N7Q`80R8R80P26QXH208N7Q`80Ng]k0P1lO7`407inOP@0N7Qh0P1ZJVX206m_K`80Jf][
00<0F5QH05MGE`1GEeL00P1;Bd/20492@P80?Cdm0P10@40203Ti>@807alO0P0X:2P201lO7`805ADE
0P0>3Ph205eMG@80Cdm?0P1>CTh204A4A003071`L01mOGd0OGem0080Zj^[0P2][Jd209jNWP80XZ:R
0P2UYJE00:6QXAD0oooo000C0?ooobD0XJ6Q0P2^[Zh204I6AP804A4A0P1>CTh2055AD@0303Lg=`1K
Fe/0Fe]K0080EUIF0P1[Jf/207QhN080QXJ60P2;Rh/208B4Q080RHV90P27QhL208j>SP80T92@0P2:
RXX2092@T080R8R80P2@T9000`2FUYH0SHf=08f=S@08092@T080S8b<0P2=SHd208^;R`80T92@1027
QhL209>CT`80QhN70P2@T90208:2PP<0QhN70P28R8P608N7Q`@0PH610P1iNGT207inOP80NWYj0P1g
MgL207IfMP80IFEU0P1fMWH206a/K00305QHF01ADE40DE5A0080BTY:0P17AdL203/k>`80=SHf0P10
@40203lo?`804a<C0P0F5QH201TI6@80>CTi0P1=CDd206MWI`80AdM70P1@D5000`1cLg<0UiNG09NG
U`020;bl_080YJFU0P2JVYX20:JVYP80VYZJ@02QXJ4E0?ooo`004`3ooolU0:6QX@80[Zj^0P16ATH2
014A4@80CTi>0P1ADE400`0g=cL0Fe]K05]KF`0205IFEP80Jf][0P1hN7P208J6QP80Rh^;0P24Q8@2
08V9R@80QhN70P2>SXh2092@T080RXZ:0P2@T90208R8R080T92@00<0UYJF08f=S@2=SHd0202@T902
08b<S080SHf=0P2;Rh/2092@T0@0QhN70P2CTi<208N7Q`80T92@0P22PX8308N7Q`80R8R81P27QhL4
0861P@80NGUi0P1nOWh207YjNP80MgMg0P1fMWH206EUI@80MWIf0P1/K6`00`1HF5P0DE5A055AD@02
04Y:BP80AdM70P0k>c/203Hf=P80@4100P0o?cl201<C4`805QHF0P0I6AT203Ti>@80CDe=0P1WIfL2
04M7A`80D51@00<0Lg=c09NGU`2GUiL00P2l_;`20:FUY@80VYZJ0P2VYZH209ZJVT00XJ6Q5@3oool0
01<0oooo9@2QXJ420:j^[P80Fe]K0P0M7Ad203De=@80BTY:00<0ATI606=SH`1SHf<00P1EEED206][
J`80N7Qh1022PX8208n?S`80SXj>0P26QXH208R8R080Shn?0P2;Rh/209^KV`80QXJ60P2>SXh00`2A
TI40SHf=08f=S@08096AT@80UIFE0P25QHD208f=S@80Shn?0P2=SHd208N7Q`80QHF50P2@T90208f=
S@L0QhN70P28R8P208J6QP80QhN70P1hN7P208>3P`80OWin0P1hN7P207UiN@80MgMg0P1`L70205aL
G080KFe]0P1OGel00`1DE5@0DU9B059BDP0204Q8B080A4A40P11@D4203Ph>080?3`l100_;bl201lO
7`80;bl_0P0f=SH205iNGP80D51@101JFUX00`1lO7`0Rh^;08^;R`020<_;b`80YZJV0P2FUYH20:RX
Z480XJ6Q5@3oool001<0oooo9@2QXJ420:j^[P80Fe]K0P0M7Ad203De=@80BTY:00<0ATI606=SH`1S
Hf<00P1EEED206][J`80N7Qh1022PX8208n?S`80SXj>0P26QXH208R8R080Shn?0P2;Rh/209^KV`80
QXJ60P2>SXh00`2ATI40SHf=08f=S@08096AT@80UIFE0P25QHD208f=S@80Shn?0P2=SHd208N7Q`80
QHF50P2@T90208f=S@L0QhN70P28R8P208J6QP80QhN70P1hN7P208>3P`80OWin0P1hN7P207UiN@80
MgMg0P1`L70205aLG080KFe]0P1OGel00`1DE5@0DU9B059BDP0204Q8B080A4A40P11@D4203Ph>080
?3`l100_;bl201lO7`80;bl_0P0f=SH205iNGP80D51@101JFUX00`1lO7`0Rh^;08^;R`020<_;b`80
YZJV0P2FUYH20:RXZ480XJ6Q5@3oool001<0oooo9@2QXJ420:j^[P80AdM70P1?Cdl201lO7`80@T92
00<0A4A404m?C`1?Cdl00P1MGEd206][J`80MGEe0P1lO7`208V9R@80QHF5102<S8`20820P080UIFE
0P27QhL209>CT`@0RXZ:00<0SHf=08n?S`2?Shl00P2@T90208f=S@80T92@0P24Q8@209FEU@80QXJ6
0P2:RXX208N7Q`80P8200P26QXH20820P080RHV90P2?Shl208N7Q`0308>3P`24Q8@0Q8B40080RXZ:
0P24Q8@208J6QP80QhN70P1gMgL20820P080O7al0P1cLg<207QhN080Lg=c0P1ZJVX206MWI`80HF5Q
0P1KFe/00`1=CDd0E5AD05ADE00204A4A080=CDe0P0n?Sh203Lg=`80>CTi0P0Z:RX203Hf=P8092@T
0P1VIVH203<c<`80F5QH0P1=CDd207inOP80G5aL00<0TI6A09jNWP2NWYh00P2QXJ420:RXZ080WYjN
0P2UYJD20:6QX@80YZJV0P2JVYXO0:6QX@80YZJV0P2JVYXI0:6QXAD0oooo000C0?ooobD0XJ6Q0P2^
[Zh204M7A`80Cdm?0P0O7al20492@P0304A4A01?Cdl0Cdm?0080GEeM0P1[Jf/207EeM@80O7al0P29
RHT208F5Q@@0S8b<0P20P80209FEU@80QhN70P2CTi<408Z:RP0308f=S@2?Shl0Shn?0080T92@0P2=
SHd2092@T080Q8B40P2EUID208J6QP80RXZ:0P27QhL20820P080QXJ60P20P80208V9R@80Shn?0P27
QhL00`23Ph<0Q8B408B4Q00208Z:RP80Q8B40P26QXH208N7Q`80MgMg0P20P80207alO080Lg=c0P1h
N7P207=cL`80JVYZ0P1WIfL2065QH@80Fe]K00<0CDe=05ADE01DE5@00P14A4@203De=@80?Shn0P0g
=cL203Ti>@80:RXZ0P0f=SH202@T9080IVIV0P0c<c<205QHF080CDe=0P1nOWh205aLG003096AT@2N
WYh0WYjN0080XJ6Q0P2XZ:P209jNWP80YJFU0P2QXJ420:JVYP80VYZJ7`2QXJ420:JVYP80VYZJ6@2Q
XJ4E0?ooo`004`3ooolU0:6QX@80Z:RX0P1HF5P205]KF`8030`<0P0l?3`00`1EEED0>3Ph03Ph>002
05eMG@80I6AT0P1[Jf/207inOP80PH610P1oOgl208N7Q`80RHV90P20P80209:BTP@0RXZ:0P2=SHd2
08b<S00308>3P`2:RXX0RXZ:0080SHf=0P2>SXh2096AT@80QhN70P2<S8`208N7Q`80Ph>30P22PX82
07]kN`80Ogmo0P1nOWh208:2PP80RHV90P22PX800`23Ph<0P8200820P00208>3P`80NGUi0P22PX82
0820P080LG5a0P20P80407=cL`80KFe]0P1`L702061PH080GUiN0P1PH60205iNGP0304m?C`1@D500
D51@0080@4100P0m?Cd203`l?080=SHf0P18B4P4034a<@80@D510P1ZJVX204A4A080EeMG0P1JFUX2
07moO`80MGEe00<0Ogmo0<_;b`3;bl/00P2UYJD20:6QX@80WIfM0P2VYZH209ZJVP80Z:RX5@2QXJ42
09jNWP80YJFU202QXJ420:RXZ1/0XJ6Q5@3oool001<0oooo9@2QXJ420:RXZ080F5QH0P1KFe/200`<
3080?3`l00<0EEEE03Ph>00h>3P00P1MGEd206ATI080Jf][0P1nOWh20861P@80Ogmo0P27QhL208V9
R@80P8200P2BTY8408Z:RP80SHf=0P2<S8`00`23Ph<0RXZ:08Z:RP0208f=S@80SXj>0P2ATI4208N7
Q`80S8b<0P27QhL208>3P`80PX:20P1kNg/207moO`80OWin0P22PX8208V9R@80PX:200<0Ph>30820
P020P8000P23Ph<207UiN@80PX:20P20P802075aL@80P820101cLg<206e]K@80L71`0P1PH60205iN
GP80H61P0P1NGUh00`1?Cdl0D51@051@D0020410@080?Cdm0P0l?3`203Hf=P80B4Q8100a<C420451
@@80JVYZ0P14A4@205MGE`80FUYJ0P1oOgl207EeM@0307moO`3;bl/0bl_;0080YJFU0P2QXJ4209fM
W@80YZJV0P2JVYX20:RXZ1D0XJ6Q0P2NWYh20:FUY@P0XJ6Q0P2XZ:PK0:6QXAD0oooo000C0?ooobL0
XJ6Q0P2>SXh205MGE`808B4Q0P0];Bd00`18B4P0BDU904U9B@0204U9B@80GUiN0P1SHf<207moO`80
Q8B40P27QhL207IfMP@0PX:20P27QhL209:BTP80QXJ60P27QhL208^;R`0308J6QP23Ph<0Ph>300H0
R8R81023Ph<208J6QP80Ph>30P1nOWh207AdM080NWYj0P1fMWH207alO080OWin0P1hN7P00`1kNg/0
MgMg07MgM`0207QhN080M7Ad0P1_Kfl207YjNP80LG5a0P1fMWH2075aL@80JFUY0P1ZJVX2075aL@80
HF5Q0P1KFe/205UIF@80Cdm?00<0C4a<05IFEP1FEUH00P14A4@203Ti>@80C4a<0P11@D4203De=@80
C4a<0P12@T8204];B`80G5aL0P1<C4`206YZJP80GEeM0P2>SXh208Z:RP0309ZJVP2SXj<0Xj>S00H0
XJ6Q0P2XZ:PI0:6QX@80WIfM9`2QXJ4E0?ooo`004`3ooolW0:6QX@80SXj>0P1GEeL2024Q8@80;Bd]
00<0B4Q804U9B@19BDT00P19BDT205iNGP80Hf=S0P1oOgl208B4Q080QhN70P1fMWH408:2PP80QhN7
0P2BTY8208J6QP80QhN70P2;Rh/00`26QXH0Ph>308>3P`0608R8R0@0Ph>30P26QXH208>3P`80OWin
0P1dM7@207YjNP80MWIf0P1lO7`207inOP80N7Qh00<0Ng]k07MgM`1gMgL00P1hN7P207AdM080Kfm_
0P1jNWX2075aL@80MWIf0P1aLG4206UYJ@80JVYZ0P1aLG42065QH@80Fe]K0P1IFET204m?C`0304a<
C01FEUH0EUIF0080A4A40P0i>CT204a<C080@D510P0e=CD204a<C080@T920P1;Bd/205aLG080C4a<
0P1ZJVX205eMG@80SXj>0P2:RXX00`2JVYX0Xj>S0:>SX`060:6QX@80Z:RX6@2QXJ4209fMWBL0XJ6Q
5@3oool001<0oooo:@2QXJ42065QH@80:b/[0P0];Bd00`0i>CT0CDe=04e=C@0204a<C080FEUI101N
GUh207QhN080PX:20P2;Rh/207inOP80QHF50P23Ph<208J6QP80Ph>31028R8P00`25QHD0NGUi07Ui
N@0208:2PP80Ng]k0P28R8P208N7Q`80K6a/0P1iNGT207MgM`80NGUi0P1VIVH207MgM`80Hf=S0P1e
MGD206MWI`80NWYj00<0GEeM07UiN@1iNGT00P1MGEd2079bLP80GEeM0P1UIFD206m_K`80Hf=S0P1V
IVH4065QH@80GEeM0P1ZJVX206ATI080D51@0P1DE5@00`15ADD0DU9B059BDP020410@080@T920P1C
De<205ADE080<30`0P0_;bl204e=C@80IFEU0P1GEeL204e=C@80JFUY0P1aLG4207moO`80QHF500<0
bLW90:6QX@2QXJ402P2QXJ4209jNWP80YJFU7`2QXJ420:JVYP80VYZJ6@2QXJ4E0?ooo`004`3ooolY
0:6QX@80HF5Q0P0[:b/202d];@0303Ti>@1=CDd0CDe=0080C4a<0P1IFET405iNGP80N7Qh0P22PX82
08^;R`80OWin0P25QHD208>3P`80QXJ60P23Ph<408R8R00308F5Q@1iNGT0NGUi0080PX:20P1kNg/2
08R8R080QhN70P1/K6`207UiN@80MgMg0P1iNGT206IVIP80MgMg0P1SHf<207EeM@80IfMW0P1jNWX0
0`1MGEd0NGUi07UiN@0205eMG@80LW9b0P1MGEd206EUI@80Kfm_0P1SHf<206IVIP@0HF5Q0P1MGEd2
06YZJP80I6AT0P1@D50205ADE00304E5A@1BDU80DU9B0080@4100P12@T8205=CD`80E5AD0P0`<302
02l_;`80CDe=0P1UIFD205MGE`80CDe=0P1YJFT2075aL@80Ogmo0P25QHD00`39bLT0XJ6Q0:6QX@0:
0:6QX@80WYjN0P2UYJDO0:6QX@80YZJV0P2JVYXI0:6QXAD0oooo000C0?ooob/0XJ6Q0P1UIFD2038b
<P0301XJ6P0o?cl0?clo0080?Cdm0P1PH60205mOG`80AdM70P1gMgL2075aL@80S8b<0P22PX820861
P@80QhN70P21PH4208:2PP80Ng]k0P20P8000`1jNWX0Ng]k07]kN`0207IfMP80Lg=c0P1hN7P20861
P@80Lg=c0P1dM7@206MWI`80LW9b0P1QHF4206YZJP80GEeM0P1ZJVX205iNGP80H61P00<0I6AT06IV
IP1VIVH00P1>CTh205QHF080IfMW0P1=CDd206][J`80D51@0P1MGEd205iNGP80Fe]K0P1GEeL204e=
C@80H61P0P1IFET205iNGP03055AD@1EEED0EEEE0080BDU90P1;Bd/203dm?@80Cdm?0P1:BTX203Xj
>P80ATI60P1LG5`205]KF`80JVYZ0P1fMWH207EeM@80K6a/0P2j^[X50:6QX@80WYjN0P2UYJD40:6Q
X@80WIfM6@2QXJ4209jNWP80YJFU102QXJ420:RXZ1/0XJ6Q5@3oool001<0oooo:`2QXJ4206EUI@80
<S8b00<06QXJ03lo?`0o?cl00P0m?Cd2061PH080GemO0P17AdL207MgM`80LG5a0P2<S8`208:2PP80
PH610P27QhL20861P@80PX:20P1kNg/20820P00307YjNP1kNg/0Ng]k0080MWIf0P1cLg<207QhN080
PH610P1cLg<207AdM080IfMW0P1bLW82065QH@80JVYZ0P1MGEd206YZJP80GUiN0P1PH6000`1TI6@0
IVIV06IVIP0204i>CP80F5QH0P1WIfL204e=C@80Jf][0P1@D50205eMG@80GUiN0P1KFe/205MGE`80
CDe=0P1PH60205UIF@80GUiN00<0DE5A05EEE@1EEED00P19BDT204];B`80?Cdm0P1?Cdl204Y:BP80
>SXj0P16ATH205aLG080Fe]K0P1ZJVX207IfMP80MGEe0P1/K6`20;Zj^PD0XJ6Q0P2NWYh20:FUY@@0
XJ6Q0P2MWIdI0:6QX@80WYjN0P2UYJD40:6QX@80Z:RX6`2QXJ4E0?ooo`004`3oool>0:6QX@80WYjN
00<0YJFU09jNWP2NWYh00P2UYJDH0:6QX@80UIFE00<0:b/[04a<C01<C4`00P15ADD204i>CP80HV9R
0P1KFe/206ATI080IFEU0P2=SHd207moO`@0SHf=0P22PX8207alO080Ng]k0P1dM7@00`1bLW80MWIf
07IfMP0206MWI`80N7Qh0P1iNGT406e]K@80MWIf101RHV8205eMG@80HF5Q0P1@D50207EeM@80D51@
0P1TI6@00`1FEUH0EeMG05MGE`0205eMG@80AdM70P1BDU8206YZJP80Cdm?0P1JFUX204m?C`80EUIF
101KFe/203Lg=`80D51@0P1IFET205=CD`0304M7A`1DE5@0E5AD0080EeMG0P14A4@204I6AP80@D51
0P1>CTh204Q8B080EUIF0P1QHF4206m_K`80Jf][0P1gMgL207alO080Ogmo0P2o_kl50:6QX@80XZ:R
0P2JVYXO0:6QX@80WIfM8`2QXJ4E0?ooo`004`3oool>0:6QX@80WYjN00<0YJFU09jNWP2NWYh00P2U
YJDH0:6QX@80UIFE00<0:b/[04a<C01<C4`00P15ADD204i>CP80HV9R0P1KFe/206ATI080IFEU0P2=
SHd207moO`@0SHf=0P22PX8207alO080Ng]k0P1dM7@00`1bLW80MWIf07IfMP0206MWI`80N7Qh0P1i
NGT406e]K@80MWIf101RHV8205eMG@80HF5Q0P1@D50207EeM@80D51@0P1TI6@00`1FEUH0EeMG05MG
E`0205eMG@80AdM70P1BDU8206YZJP80Cdm?0P1JFUX204m?C`80EUIF101KFe/203Lg=`80D51@0P1I
FET205=CD`0304M7A`1DE5@0E5AD0080EeMG0P14A4@204I6AP80@D510P1>CTh204Q8B080EUIF0P1Q
HF4206m_K`80Jf][0P1gMgL207alO080Ogmo0P2o_kl50:6QX@80XZ:R0P2JVYXO0:6QX@80WIfM8`2Q
XJ4E0?ooo`004`3oool40:6QX@80WYjN0P2UYJD60:6QX@80WIfM00<0XJ6Q09fMW@2MWId0702QXJ40
0`1;Bd/06a/K01/K6`02065QH@80Bd];0P1DE5@207IfMP80MGEe0P1YJFT20820P080PH610P1kNg/4
07alO080MgMg0P1lO7`206UYJ@03079bLP1cLg<0Lg=c0080GEeM0P1`L70206][J`80L71`0P1RHV82
071`L080GUiN0P1YJFT204m?C`80EUIF0P1GEeL2055AD@80IVIV0P1NGUh00`1WIfL0BDU904U9B@02
06=SH`80EEEE0P1@D50207EeM@80?3`l0P1PH60205EEE@80HV9R0P1DE5@2055AD@80B4Q80P11@D42
04Y:BP80@41000<0A4A405=CD`1CDe<00P15ADD20492@P80AdM70P14A4@2051@D080EEEE0P1TI6@2
06a/K080QXJ60P1PH6020861P@80GEeM0P3Ng]h70:6QX@80Z:RXAP2QXJ4E0?ooo`004`3oool40:6Q
X@80WYjN0P2UYJD60:6QX@80WIfM00<0XJ6Q09fMW@2MWId0702QXJ400`1;Bd/06a/K01/K6`02065Q
H@80Bd];0P1DE5@207IfMP80MGEe0P1YJFT20820P080PH610P1kNg/407alO080MgMg0P1lO7`206UY
J@03079bLP1cLg<0Lg=c0080GEeM0P1`L70206][J`80L71`0P1RHV82071`L080GUiN0P1YJFT204m?
C`80EUIF0P1GEeL2055AD@80IVIV0P1NGUh00`1WIfL0BDU904U9B@0206=SH`80EEEE0P1@D50207Ee
M@80?3`l0P1PH60205EEE@80HV9R0P1DE5@2055AD@80B4Q80P11@D4204Y:BP80@41000<0A4A405=C
D`1CDe<00P15ADD20492@P80AdM70P14A4@2051@D080EEEE0P1TI6@206a/K080QXJ60P1PH6020861
P@80GEeM0P3Ng]h70:6QX@80Z:RXAP2QXJ4E0?ooo`004`3oool40:6QX@80WIfM:@2QXJ400`2XZ:P0
=SHf03Hf=P0202HV9P80BDU90P1>CTh206m_K`80Hf=S0P1WIfL207EeM@80NGUi0P1kNg/207UiN@80
IfMW0P1cLg<207EeM@80K6a/00<0IfMW075aL@1aLG400P1NGUh206MWI`80FUYJ0P1UIFD206YZJP80
GEeM0P1FEUH206=SH`80AdM70P1QHF4205QHF080>c/k0P0o?cl206e]K@0304M7A`1YJFT0JFUY0080
DE5A101GEeL204a<C080Cdm?0P1IFET2030`<080BTY:0P1LG5`204A4A080ATI60P13@d<204I6AP80
?Cdm0`14A4@20451@@80>3Ph0P1:BTX204M7A`80L71`0P1;Bd/207MgM`80OWin0P1;Bd/208^;R`80
Hf=S0P2<S8`20<O7a`80VYZJ2`2QXJ4209jNWP80YJFU?P2QXJ4E0?ooo`004`3oool40:6QX@80WIfM
:@2QXJ400`2XZ:P0=SHf03Hf=P0202HV9P80BDU90P1>CTh206m_K`80Hf=S0P1WIfL207EeM@80NGUi
0P1kNg/207UiN@80IfMW0P1cLg<207EeM@80K6a/00<0IfMW075aL@1aLG400P1NGUh206MWI`80FUYJ
0P1UIFD206YZJP80GEeM0P1FEUH206=SH`80AdM70P1QHF4205QHF080>c/k0P0o?cl206e]K@0304M7
A`1YJFT0JFUY0080DE5A101GEeL204a<C080Cdm?0P1IFET2030`<080BTY:0P1LG5`204A4A080ATI6
0P13@d<204I6AP80?Cdm0`14A4@20451@@80>3Ph0P1:BTX204M7A`80L71`0P1;Bd/207MgM`80OWin
0P1;Bd/208^;R`80Hf=S0P2<S8`20<O7a`80VYZJ2`2QXJ4209jNWP80YJFU?P2QXJ4E0?ooo`004`3o
ool`0:6QX@80Z:RX0P0i>CT204M7A`80@T920P1/K6`205iNGP80MWIf0P2@T90208B4Q080Ng]k0P1n
OWh406=SH`80Jf][0P1VIVH306][J`80HF5Q0P1OGel4065QH@80FUYJ0P1RHV8205QHF080@d=30P1X
J6P204e=C@80BDU90P1WIfL202XZ:P80BTY:00<0EeMG04Y:BP1:BTX00P1@D50205IFEP80AdM70P13
@d<20492@P@0?Cdm0P0j>SX204m?C`80>SXj0P11@D4204Y:BP80@d=30P10@4000`11@D40BTY:04Y:
BP0205ADE080CTi>0P1=CDd205iNGP80Kfm_0P21PH42071`L080GEeM0P18B4P207inOP80CTi>0P3P
h>020:RXZ0D0XJ6Q0P2NWYh20:FUY@80XJ6Q0P2NWYhK0:6QX@80WYjN0P2UYJD20:6QX@80YZJV0P2J
VYXM0:6QXAD0oooo000C0?oooc00XJ6Q0P2XZ:P203Ti>@80AdM70P12@T8206a/K080GUiN0P1fMWH2
092@T080Q8B40P1kNg/207inOP@0Hf=S0P1[Jf/206IVIP<0Jf][0P1QHF4205mOG`@0HF5Q0P1JFUX2
069RHP80F5QH0P13@d<206QXJ080CDe=0P19BDT206MWI`80:RXZ0P1:BTX00`1GEeL0BTY:04Y:BP02
051@D080EUIF0P17AdL204=3@`80@T92100m?Cd203Xj>P80Cdm?0P0j>SX20451@@80BTY:0P13@d<2
0410@0030451@@1:BTX0BTY:0080E5AD0P1>CTh204e=C@80GUiN0P1_Kfl20861P@80L71`0P1MGEd2
04Q8B080OWin0P1>CTh20>3Ph080Z:RX1@2QXJ4209jNWP80YJFU0P2QXJ4209jNWQ/0XJ6Q0P2NWYh2
0:FUY@80XJ6Q0P2VYZH209ZJVQd0XJ6Q5@3oool001<0oooo<P2QXJ4206EUI@805aLG0P1JFUX206QX
J080@D510P1MGEd207QhN080R8R80P1nOWh207EeM@80KVi^0P1?Cdl206YZJP80GEeM00<0LG5a06MW
I`1WIfL00P1JFUX2051@D080IfMW0P1PH602059BDP80IfMW0P1DE5@2055AD@80ATI60P1NGUh204U9
B@80E5AD0P1FEUH203Hf=P0305=CD`18B4P0B4Q80080@4100P1;Bd/203lo?`80>c/k0P0n?Sh203Ph
>080?Cdm0P0f=SH203Xj>P80@d=30P10@4020451@@80?clo0P0m?Cd00`15ADD0De=C05=CD`02059B
DP@0Fe]K0P20P80207AdM080FUYJ0P1`L70205mOG`80K6a/0P1RHV8208V9R@80ZZZZ0P2RXZ820:FU
Y@030:6QX@2NWYh0WYjN00@0XJ6Q0P2NWYh40:6QX@80YZJV0P2JVYX60:6QX@80YZJV0P2JVYX;0:6Q
X@80WIfM102QXJ420:RXZ1l0XJ6Q5@3oool001<0oooo<P2QXJ4206EUI@805aLG0P1JFUX206QXJ080
@D510P1MGEd207QhN080R8R80P1nOWh207EeM@80KVi^0P1?Cdl206YZJP80GEeM00<0LG5a06MWI`1W
IfL00P1JFUX2051@D080IfMW0P1PH602059BDP80IfMW0P1DE5@2055AD@80ATI60P1NGUh204U9B@80
E5AD0P1FEUH203Hf=P0305=CD`18B4P0B4Q80080@4100P1;Bd/203lo?`80>c/k0P0n?Sh203Ph>080
?Cdm0P0f=SH203Xj>P80@d=30P10@4020451@@80?clo0P0m?Cd00`15ADD0De=C05=CD`02059BDP@0
Fe]K0P20P80207AdM080FUYJ0P1`L70205mOG`80K6a/0P1RHV8208V9R@80ZZZZ0P2RXZ820:FUY@03
0:6QX@2NWYh0WYjN00@0XJ6Q0P2NWYh40:6QX@80YZJV0P2JVYX60:6QX@80YZJV0P2JVYX;0:6QX@80
WIfM102QXJ420:RXZ1l0XJ6Q5@3oool001<0oooo<P2QXJ420:RXZ0807AdM0P0P82020410@080PH61
0P1PH60206MWI`80KFe]0P2@T90207=cL`80JVYZ0P11@D4206QXJ080DU9B00<0HV9R06YZJP1ZJVX0
0P1FEUH204e=C@80IFEU0P1MGEd204e=C@80Hf=S0P1?Cdl2061PH080=CDe0P1QHF4204U9B@80B4Q8
0P0o?cl203Ti>@03069RHP0d=3@0=3@d0080@d=30P14A4@203lo?`80>SXj0P0f=SH203Ti>@80<30`
0P0];Bd203Hf=P80=cLg0P0h>3P20492@P80CDe=0P0h>3P00`1:BTX0IVIV06IVIP0206QXJ080E5AD
0P1`L70206ATI080Jf][0P1=CDd204I6AP80NGUi0P1?Cdl20;Zj^P80YZJV0P2KVi/209>CT`80YJFU
00<0XJ6Q09fMW@2MWId0102QXJ4209fMW@@0XJ6Q0P2XZ:P80:6QX@80Z:RX=02QXJ4E0?ooo`004`3o
oolb0:6QX@80Z:RX0P0M7Ad2020P8080@4100P21PH42061PH080IfMW0P1]KFd2092@T080Lg=c0P1Z
JVX20451@@80J6QX0P1BDU800`1RHV80JVYZ06YZJP0205IFEP80CDe=0P1UIFD205eMG@80CDe=0P1S
Hf<204m?C`80H61P0P0e=CD2065QH@80BDU90P18B4P203lo?`80>CTi00<0HV9R03@d=00d=3@00P13
@d<204A4A080?clo0P0j>SX203Hf=P80>CTi0P0`<30202d];@80=SHf0P0g=cL203Ph>080@T920P1=
CDd203Ph>00304Y:BP1VIVH0IVIV0080J6QX0P1DE5@2071`L080I6AT0P1[Jf/204e=C@80ATI60P1i
NGT204m?C`80^[Zj0P2VYZH209^KV`80Ti>C0P2UYJD00`2QXJ40WIfM09fMW@040:6QX@80WIfM102Q
XJ420:RXZ0P0XJ6Q0P2XZ:Pd0:6QXAD0oooo000C0?oooc80XJ6Q0P2NWYh20:FUY@80?Shn0P061PH2
03Ph>080MGEe0P1_Kfl206e]K@80T92@0P21PH4206YZJP80@4100P1CDe<206i^KP0304a<C01WIfL0
IfMW0080Fe]K0P1=CDd204Y:BP80IVIV0P1>CTh204M7A`80GEeM0P1GEeL203Xj>P80Fe]K0P1CDe<2
04U9B@80?Cdm0P0P82000`1<C4`0@D510451@@0205IFEP80<c<c0P0n?Sh202d];@80@T920P0`<302
02/[:`809RHV0P0^;Rh202TY:@80:RXZ0P10@40204m?C`80FEUI00<0EUIF05ADE01DE5@00P1cLg<2
07YjNP80K6a/0P1ADE4206i^KP80IFEU0P1>CTh205QHF080L71`0P3EeMD40:RXZ080WIfM0`2QXJ42
09jNWP80YJFU0P2VYZH209ZJVQ@0XJ6Q0P2NWYh00`2UYJD0XJ6Q0:6QX@0>0:6QX@80YZJV0P2JVYXI
0:6QXAD0oooo000C0?ooo`X0XJ6Q0P2NWYh20:FUYB@0XJ6Q0P2MWId20:6QX@80Z:RX0P0e=CD201@D
5080A4A40P1EEED207MgM`80Ph>30P28R8P207]kN`80?clo0P13@d<206QXJ003069RHP1?Cdl0Cdm?
0080GUiN0P1PH60204A4A080D51@0P1LG5`204Q8B080Cdm?0P1DE5@205=CD`80Bd];0P1:BTX205aL
G080BDU90P0`<3000`0k>c/0<c<c03<c<`0204A4A080BDU90P0i>CT203De=@80@d=30P0e=CD204=3
@`80:BTY0P0c<c<203Lg=`80>c/k0P14A4@204Y:BP80IFEU00<0L71`07EeM@1eMGD00P1<C4`207em
O@80DE5A0P0_;bl206=SH`@0IFEU0P1ADE420;:b/PX0XJ6Q00<0YZJV09JFUP2FUYH00P2NWYh20:b/
[0P0XJ6Q0P2VYZH209ZJVPX0XJ6Q0P2MWId00`2QXJ40YZJV0:JVYP0209ZJVP`0XJ6Q0P2XZ:PK0:6Q
XAD0oooo000C0?ooo`X0XJ6Q0P2NWYh20:FUYB@0XJ6Q0P2MWId20:6QX@80Z:RX0P0e=CD201@D5080
A4A40P1EEED207MgM`80Ph>30P28R8P207]kN`80?clo0P13@d<206QXJ003069RHP1?Cdl0Cdm?0080
GUiN0P1PH60204A4A080D51@0P1LG5`204Q8B080Cdm?0P1DE5@205=CD`80Bd];0P1:BTX205aLG080
BDU90P0`<3000`0k>c/0<c<c03<c<`0204A4A080BDU90P0i>CT203De=@80@d=30P0e=CD204=3@`80
:BTY0P0c<c<203Lg=`80>c/k0P14A4@204Y:BP80IFEU00<0L71`07EeM@1eMGD00P1<C4`207emO@80
DE5A0P0_;bl206=SH`@0IFEU0P1ADE420;:b/PX0XJ6Q00<0YZJV09JFUP2FUYH00P2NWYh20:b/[0P0
XJ6Q0P2VYZH209ZJVPX0XJ6Q0P2MWId00`2QXJ40YZJV0:JVYP0209ZJVP`0XJ6Q0P2XZ:PK0:6QXAD0
oooo000C0?ooo`X0XJ6Q0P2MWId/0:6QX@80PX:20P0Q8B4202LW9`80A4A40P1?Cdl205YJFP80Ogmo
0P1iNGT207IfMP80:b/[0P1DE5@00`1UIFD0FEUI05UIF@0204I6AP80D51@0P10@4020492@P80BDU9
0P1@D50204U9B@80Cdm?0P1GEeL404M7A`80HF5Q0P1GEeL204I6AP0304U9B@0b<S80<S8b0080D51@
0P0e=CD203dm?@80D51@0P14A4@203hn?P80Bd];0P16ATH204Y:BP80CTi>0P1NGUh204i>CP80GEeM
0P1fMWH00`1NGUh0P8200820P00205]KF`80J6QX0P0k>c/204a<C080GEeM0P1HF5P205mOG`80^[Zj
0P2JVYX20:JVYP80WinO0P2JVYX209jNWP80Zj^[00<0WYjN0:^[Z`2[Zj/00P2FUYH209jNWP80YJFU
0P2VYZH209ZJVP80XJ6Q0P2XZ:P?0:6QX@80Z:RX202QXJ420:JVYP80VYZJ7`2QXJ4E0?ooo`004`3o
ool:0:6QX@80WIfM;02QXJ4208:2PP808B4Q0P0W9bL204A4A080Cdm?0P1JFUX207moO`80NGUi0P1f
MWH202/[:`80E5AD00<0IFEU05UIF@1IFET00P16ATH2051@D080@4100P12@T8204U9B@80D51@0P19
BDT204m?C`80EeMG1017AdL2065QH@80EeMG0P16ATH00`19BDT0<S8b038b<P02051@D080=CDe0P0m
?Cd2051@D080A4A40P0n?Sh204];B`80ATI60P1:BTX204i>CP80GUiN0P1>CTh205eMG@80MWIf00<0
GUiN0820P020P8000P1KFe/206QXJ080>c/k0P1<C4`205eMG@80F5QH0P1OGel20;Zj^P80VYZJ0P2V
YZH209nOW`80VYZJ0P2NWYh20:^[Z`0309jNWP2[Zj/0Zj^[0080UYJF0P2NWYh20:FUY@80YZJV0P2J
VYX20:6QX@80Z:RX3`2QXJ420:RXZ0P0XJ6Q0P2VYZH209ZJVQl0XJ6Q5@3oool001<0oooo<P2QXJ42
0:JVYP80VYZJ102QXJ4207AdM080:RXZ0P0f=SH404Y:BP80HV9R0P1SHf<208J6QP80CTi>0P0c<c<0
0`1ADE40JFUY06UYJ@02059BDP80@d=30P1BDU8202l_;`80@T920P14A4@2051@D080Bd];0P1CDe<2
03Ph>080GUiN0P1@D50206YZJP80BTY:00<0F5QH04a<C01<C4`00P12@T8203Xj>P80?clo0P1IFET2
04e=C@80EUIF0P1=CDd205EEE@80F5QH0P1^KVh206a/K080HF5Q0P1?Cdl206m_K`0306EUI@1>CTh0
CTi>0080?Shn0P1CDe<205QHF0@0EeMG0P1/K6`2096AT@@0XJ6Q0P2XZ:P20:j^[P80WinO0P2FUYH2
0:RXZ0030::RXP2QXJ40XJ6Q0080XJ6Q0P2MWId20:6QX@80Z:RX7`2QXJ420:RXZ240XJ6Q5@3oool0
01<0oooo<P2QXJ420:JVYP80VYZJ102QXJ4207AdM080:RXZ0P0f=SH404Y:BP80HV9R0P1SHf<208J6
QP80CTi>0P0c<c<00`1ADE40JFUY06UYJ@02059BDP80@d=30P1BDU8202l_;`80@T920P14A4@2051@
D080Bd];0P1CDe<203Ph>080GUiN0P1@D50206YZJP80BTY:00<0F5QH04a<C01<C4`00P12@T8203Xj
>P80?clo0P1IFET204e=C@80EUIF0P1=CDd205EEE@80F5QH0P1^KVh206a/K080HF5Q0P1?Cdl206m_
K`0306EUI@1>CTh0CTi>0080?Shn0P1CDe<205QHF0@0EeMG0P1/K6`2096AT@@0XJ6Q0P2XZ:P20:j^
[P80WinO0P2FUYH20:RXZ0030::RXP2QXJ40XJ6Q0080XJ6Q0P2MWId20:6QX@80Z:RX7`2QXJ420:RX
Z240XJ6Q5@3oool001<0oooo<P2QXJ440:FUY@80XJ6Q0P2NWYh20:FUY@80IFEU0P0X:2P202d];@80
F5QH101VIVH2075aL@80MWIf0P1?Cdl00`0d=3@0Hf=S06=SH`0204M7A`80GemO0P1?Cdl204U9B@80
?Shn0P0h>3P204A4A080?Cdm0P1FEUH203Xj>P80HV9R0P1@D50207EeM@80E5AD00<0PH6106=SH`1S
Hf<00P10@40203Ti>@80Cdm?0P1=CDd2059BDP80GUiN0P1]KFd205iNGP80EEEE0P1dM7@205UIF@80
EUIF0P1MGEd204a<C00304I6AP10@400@4100080?clo0P1FEUH2061PH080Cdm?0P1FEUH20;bl_0@0
XJ6Q0P2VYZH209ZJVP@0Z:RX102QXJ400`2XZ:P0XJ6Q0:6QX@0209jNWP80YJFU0P2QXJ420:JVYP80
WinO0P2JVYXn0:6QXAD0oooo000C0?oooc80XJ6Q102UYJD20:6QX@80WYjN0P2UYJD206EUI@80:2PX
0P0];Bd205QHF0@0IVIV0P1aLG4207IfMP80Cdm?00<0=3@d06=SH`1SHf<00P17AdL205mOG`80Cdm?
0P19BDT203hn?P80>3Ph0P14A4@203dm?@80EUIF0P0j>SX2069RHP80D51@0P1eMGD205ADE0030861
P@1SHf<0Hf=S0080@4100P0i>CT204m?C`80CDe=0P1BDU8205iNGP80KFe]0P1NGUh205EEE@80M7Ad
0P1IFET205IFEP80GEeM0P1<C4`00`16ATH0@4100410@00203lo?`80EUIF0P1PH60204m?C`80EUIF
0P2l_;`40:6QX@80YZJV0P2JVYX40:RXZ0@0XJ6Q00<0Z:RX0:6QX@2QXJ400P2NWYh20:FUY@80XJ6Q
0P2VYZH209nOW`80VYZJ?P2QXJ4E0?ooo`004`3ooolb0:6QX@80WIfM102QXJ4209fMW@80YZJV0P2J
VYX206i^KP809RHV0P0Q8B4205=CD`80CTi>0P1nOWh208b<S080M7Ad00<0C4a<04M7A`17AdL00P1A
DE4405IFEP80DE5A0P1MGEd204Y:BP80<30`0P0];Bd2055AD@80=cLg0P1NGUh206IVIP80LW9b0P1M
GEd00`1cLg<0Z:RX0:RXZ00207alO080Jf][0P1nOWh207YjNP80K6a/0P1VIVH2079bLP80Ng]k0P1e
MGD206][J`80DU9B0P1<C4`204m?C`80>c/k00<0@410055AD@1ADE400P1?Cdl206i^KP80EEEE0P1U
IFD208n?S`80Z:RX0P2QXJ4209jNWP80[:b/0P2QXJ4209jNWP80XZ:R0P2UYJD30:6QX@80WYjN1P2Q
XJ440:RXZ080XJ6Q0P2NWYh20:FUYCX0XJ6Q5@3oool001<0oooo<P2QXJ4209fMW@@0XJ6Q0P2MWId2
0:JVYP80VYZJ0P1^KVh202HV9P808B4Q0P1CDe<204i>CP80OWin0P2<S8`207AdM00304a<C017AdL0
AdM70080DE5A101FEUH2055AD@80GEeM0P1:BTX2030`<080;Bd]0P1ADE4203Lg=`80GUiN0P1VIVH2
079bLP80GEeM00<0Lg=c0:RXZ02XZ:P00P1lO7`206][J`80OWin0P1jNWX206a/K080IVIV0P1bLW82
07]kN`80MGEe0P1[Jf/2059BDP80C4a<0P1?Cdl203/k>`030410@01ADE40DE5A0080Cdm?0P1^KVh2
05EEE@80IFEU0P2?Shl20:RXZ080XJ6Q0P2NWYh20:b/[080XJ6Q0P2NWYh20::RXP80YJFU0`2QXJ42
09jNWPH0XJ6Q102XZ:P20:6QX@80WYjN0P2UYJDj0:6QXAD0oooo000C0?ooocX0XJ6Q0P2^[Zh209ZJ
VP80XJ6Q0P2KVi/204E5A@8061PH0P0k>c/206a/K080N7Qh0P2>SXh00`27QhL0Bd];04];B`02069R
HP80IFEU0P1EEED206QXJ080G5aL0P1SHf<206][J`80<S8b0P13@d<201hN7P80>SXj0P1JFUX206a/
K080GUiN00<0I6AT07YjNP1jNWX00P1oOgl207inOP80RXZ:0P1nOWh206][J`80Shn?0P1KFe/205YJ
FP80HF5Q0P1IFET204A4A080D51@0P0o?cl205ADE00304];B`1@D500D51@0080EUIF0P1OGel20:JV
YP80BTY:0P2QXJ420:JVYP80UiNG1P2QXJ4209fMW@80VYZJ0P2UYJD30:6QX@80WIfM0P2NWYh20:FU
Y@80XJ6Q0P2VYZH209ZJVP80XJ6Q0P2JVYX20:FUY@80XJ6Q0P2NWYh20:FUY@80YZJV0P2JVYX`0:6Q
XAD0oooo000C0?ooocX0XJ6Q0P2^[Zh209ZJVP80XJ6Q0P2KVi/204E5A@8061PH0P0k>c/206a/K080
N7Qh0P2>SXh00`27QhL0Bd];04];B`02069RHP80IFEU0P1EEED206QXJ080G5aL0P1SHf<206][J`80
<S8b0P13@d<201hN7P80>SXj0P1JFUX206a/K080GUiN00<0I6AT07YjNP1jNWX00P1oOgl207inOP80
RXZ:0P1nOWh206][J`80Shn?0P1KFe/205YJFP80HF5Q0P1IFET204A4A080D51@0P0o?cl205ADE003
04];B`1@D500D51@0080EUIF0P1OGel20:JVYP80BTY:0P2QXJ420:JVYP80UiNG1P2QXJ4209fMW@80
VYZJ0P2UYJD30:6QX@80WIfM0P2NWYh20:FUY@80XJ6Q0P2VYZH209ZJVP80XJ6Q0P2JVYX20:FUY@80
XJ6Q0P2NWYh20:FUY@80YZJV0P2JVYX`0:6QXAD0oooo000C0?ooobL0XJ6Q0P2VYZH209ZJVPl0XJ6Q
0P2^[Zh209ZJVP@0XJ6Q0P2XZ:P203`l?08092@T0P0U9BD205mOG`80QHF500<0SXj>08F5Q@25QHD0
0P1lO7`208B4Q080Jf][0P28R8P207inOP80KVi^0P2ATI4208J6QP80XJ6Q0P2NWYh208b<S080U9BD
0P2=SHd207MgM`030861P@26QXH0QXJ60080M7Ad0P1eMGD209nOW`80IVIV0P1NGUh2079bLP80ADE5
0P1KFe/204I6APH0De=C0P1ADE4205YJFP0305IFEP1EEED0EEEE0080LG5a0P1nOWh20:RXZ080WYjN
102UYJD:0:6QX@80WIfM0P2QXJ4209jNWP030:FUY@2QXJ40XJ6Q0080WIfM102QXJ420:RXZ0@0XJ6Q
0P2MWId40:6QX@80WIfM0P2QXJ420:RXZ0l0XJ6Q0P2VYZH209ZJVP80XJ6Q0P2VYZH209ZJVP80WYjN
0P2UYJDE0:6QXAD0oooo000C0?ooobL0XJ6Q0P2VYZH209ZJVPl0XJ6Q0P2^[Zh209ZJVP@0XJ6Q0P2X
Z:P203`l?08092@T0P0U9BD205mOG`80QHF500<0SXj>08F5Q@25QHD00P1lO7`208B4Q080Jf][0P28
R8P207inOP80KVi^0P2ATI4208J6QP80XJ6Q0P2NWYh208b<S080U9BD0P2=SHd207MgM`030861P@26
QXH0QXJ60080M7Ad0P1eMGD209nOW`80IVIV0P1NGUh2079bLP80ADE50P1KFe/204I6APH0De=C0P1A
DE4205YJFP0305IFEP1EEED0EEEE0080LG5a0P1nOWh20:RXZ080WYjN102UYJD:0:6QX@80WIfM0P2Q
XJ4209jNWP030:FUY@2QXJ40XJ6Q0080WIfM102QXJ420:RXZ0@0XJ6Q0P2MWId40:6QX@80WIfM0P2Q
XJ420:RXZ0l0XJ6Q0P2VYZH209ZJVP80XJ6Q0P2VYZH209ZJVP80WYjN0P2UYJDE0:6QXAD0oooo000C
0?ooobL0XJ6Q0P2XZ:P=0:6QX@80YZJV0P2JVYX20:j^[P80WinO0P2JVYX20:JVYP80VYZJ0P2QXJ42
09:BTP807alO0P0T92@2065QH@03075aL@2JVYX0VYZJ0080R8R80P2EUID208f=S@@0SXj>0P27QhL2
08j>SP80Ph>30P2>SXh208:2PP80PH610P2?Shl209VIV@80QHF500<0QXJ608:2PP22PX800P1lO7`2
05IFEP80LG5a0P1fMWH205=CD`80IFEU0P1;Bd/206=SH`80>3Ph0P1RHV8206=SH`80GUiN0P1XJ6P2
065QH@0306i^KP1mOGd0OGem0080MGEe102QXJ4209ZJVP80YJFU0P2MWId20:6QX@80YZJV0P2JVYX2
0:JVYP80VYZJ0P2QXJ4209jNWQ40XJ6Q0P2VYZH209ZJVP`0XJ6Q00<0YZJV09ZJVP2JVYX01P2QXJ42
0:JVYPH0XJ6Q0P2XZ:P20:JVYP80UYJF5`2QXJ4E0?ooo`004`3ooolW0:6QX@80Z:RX3@2QXJ420:JV
YP80VYZJ0P2^[Zh209nOW`80VYZJ0P2VYZH209ZJVP80XJ6Q0P2BTY8201lO7`8092@T0P1QHF400`1a
LG40VYZJ09ZJVP0208R8R080UIFE0P2=SHd408j>SP80QhN70P2>SXh208>3P`80SXj>0P22PX820861
P@80Shn?0P2IVIT208F5Q@0308J6QP22PX80PX:20080O7al0P1FEUH2075aL@80MWIf0P1CDe<206EU
I@80Bd];0P1SHf<203Ph>080HV9R0P1SHf<205iNGP80J6QX0P1QHF400`1^KVh0OGem07emO@0207Ee
M@@0XJ6Q0P2JVYX20:FUY@80WIfM0P2QXJ420:JVYP80VYZJ0P2VYZH209ZJVP80XJ6Q0P2NWYhA0:6Q
X@80YZJV0P2JVYX<0:6QX@030:JVYP2JVYX0VYZJ00H0XJ6Q0P2VYZH60:6QX@80Z:RX0P2VYZH209JF
UQL0XJ6Q5@3oool001<0oooo=P2QXJ420:RXZ080XJ6Q102XZ:P20:6QX@80Z:RX0P2QXJ4209jNWP80
[:b/0P2JVYX203dm?@80@T9200<0;bl_06=SH`1SHf<00P1gMgL20:2PX080Shn?0P2ATI4408j>SP80
Rh^;0P2:RXX20:BTY0@0S8b<0P29RHT208N7Q`80Ogmo00<0OWin08V9R@29RHT00P25QHD2061PH080
EeMG0P1@D502061PH080J6QX0P1;Bd/207AdM080AdM70P1TI6@206IVIP80FEUI0P1nOWh208:2PP03
05mOG`2>SXh0SXj>00H0XJ6Q0P2MWId20:JVYP80VYZJ0P2QXJ420:RXZ080XJ6Q102UYJD20:6QX@80
XZ:R0P2JVYX00`2VYZH0VYZJ09ZJVP040:6QX@80WYjN0P2UYJD20:JVYP80VYZJ0P2XZ:P60:6QX@80
YZJV0P2JVYX40:6QX@030:RXZ02QXJ40XJ6Q00H0XJ6Q0P2XZ:P40:6QX@80YZJV0P2OWil20:JVYP80
UiNG0P2UYJD90:6QX@80YZJV0P2JVYX80:6QXAD0oooo000C0?ooocH0XJ6Q0P2XZ:P20:6QX@@0Z:RX
0P2QXJ420:RXZ080XJ6Q0P2NWYh20:b/[080VYZJ0P0m?Cd20492@P0302l_;`1SHf<0Hf=S0080MgMg
0P2PX:0208n?S`80TI6A102>SXh208^;R`80RXZ:0P2TY:@408b<S080RHV90P27QhL207moO`0307in
OP29RHT0RHV90080QHF50P1PH60205MGE`80D51@0P1PH60206QXJ080Bd];0P1dM7@204M7A`80I6AT
0P1VIVH205UIF@80OWin0P22PX800`1OGel0SXj>08j>SP060:6QX@80WIfM0P2VYZH209ZJVP80XJ6Q
0P2XZ:P20:6QX@@0YJFU0P2QXJ420::RXP80VYZJ00<0YZJV09ZJVP2JVYX0102QXJ4209jNWP80YJFU
0P2VYZH209ZJVP80Z:RX1P2QXJ420:JVYP80VYZJ102QXJ400`2XZ:P0XJ6Q0:6QX@060:6QX@80Z:RX
102QXJ420:JVYP80WinO0P2VYZH209NGU`80YJFU2@2QXJ420:JVYP80VYZJ202QXJ4E0?ooo`004`3o
oolU0:6QX@80YZJV0P2JVYXG0:6QX@80WYjN0P2[Zj/209JFUP80XJ6Q0P2^[Zh209ZJVP80XJ6Q00<0
De=C03`l?00l?3`00P14A4@204U9B@80OGem0P2QXJ42092@T080Ti>C0P2LW9`208B4Q080SXj>0P29
RHT208B4Q080O7al0P1TI6@206YZJP0305UIF@1_Kfl0Kfm_0080JVYZ0P1mOGd206YZJP80<c<c0P1Z
JVX206e]K@80EUIF0P1RHV8206e]K@80UIFE0P2;Rh/205QHF080HV9R0P2KVi/00`2JVYX0XJ6Q0:6Q
X@020:6QX@80YZJV0P2JVYX20:6QX@80Z:RX102QXJ420:JVYP80VYZJ0P2MWId40:6QX@80Z:RX0P2Q
XJ430:FUY@@0XJ6Q0P2MWId20:6QX@80Z:RX0P2QXJ420:JVYP80VYZJ0P2VYZH209nOW`80YZJV102O
Wil209ZJVPL0XJ6Q0P2VYZH209ZJVP@0XJ6Q0P2^[Zh20:JVYP80XJ6Q0P2RXZ8209ZJVPT0XJ6Q0P2X
Z:P:0:6QXAD0oooo000C0?ooobD0XJ6Q0P2VYZH209ZJVQL0XJ6Q0P2NWYh20:^[Z`80UYJF0P2QXJ42
0:j^[P80VYZJ0P2QXJ400`1CDe<0?3`l03`l?00204A4A080BDU90P1mOGd20:6QX@80T92@0P2CTi<2
09bLW080Q8B40P2>SXh208V9R@80Q8B40P1lO7`206ATI080JVYZ00<0FEUI06m_K`1_Kfl00P1ZJVX2
07emO@80JVYZ0P0c<c<206YZJP80KFe]0P1FEUH2069RHP80KFe]0P2EUID208^;R`80F5QH0P1RHV82
09^KV`0309ZJVP2QXJ40XJ6Q0080XJ6Q0P2VYZH209ZJVP80XJ6Q0P2XZ:P40:6QX@80YZJV0P2JVYX2
09fMW@@0XJ6Q0P2XZ:P20:6QX@<0YJFU102QXJ4209fMW@80XJ6Q0P2XZ:P20:6QX@80YZJV0P2JVYX2
0:JVYP80WinO0P2VYZH409nOW`80VYZJ1`2QXJ420:JVYP80VYZJ102QXJ420:j^[P80YZJV0P2QXJ42
0::RXP80VYZJ2@2QXJ420:RXZ0X0XJ6Q5@3oool001<0oooo8`2QXJ4209jNWP80[:b/6@2QXJ4209fM
W@80Z:RX102QXJ420:RXZ0@0XJ6Q00<0YZJV09ZJVP2JVYX00P2VYZH405=CD`80CTi>0P1fMWH2092@
T080P8200P2NWYh209ZJVP80T92@0P2IVIT208^;R`80Q8B40P1nOWh00`1QHF40GemO05mOG`0205]K
F`80OGem0P22PX8206MWI`80JFUY0P1mOGd208j>SP80N7Qh0P1/K6`20820P080UIFE0P2^[Zh20:JV
YP80WYjN00<0YJFU0:6QX@2QXJ400P2QXJ420:RXZ0H0XJ6Q0P2NWYh20:FUY@80Z:RX0P2NWYh20:FU
Y@@0XJ6Q0P2NWYh20:FUY@0309fMW@2QXJ40XJ6Q00P0XJ6Q0P2NWYh20:FUY@80Z:RX0P2QXJ480:RX
Z0@0YJFU00<0YZJV09NGU`2GUiL00P2UYJD20:6QX@80Z:RX102QXJ4209jNWP80[:b/0P2XZ:P20:6Q
X@80Z:RX0P2NWYh20:FUYA<0XJ6Q5@3oool001<0oooo8`2QXJ4209jNWP80[:b/6@2QXJ4209fMW@80
Z:RX102QXJ420:RXZ0@0XJ6Q00<0YZJV09ZJVP2JVYX00P2VYZH405=CD`80CTi>0P1fMWH2092@T080
P8200P2NWYh209ZJVP80T92@0P2IVIT208^;R`80Q8B40P1nOWh00`1QHF40GemO05mOG`0205]KF`80
OGem0P22PX8206MWI`80JFUY0P1mOGd208j>SP80N7Qh0P1/K6`20820P080UIFE0P2^[Zh20:JVYP80
WYjN00<0YJFU0:6QX@2QXJ400P2QXJ420:RXZ0H0XJ6Q0P2NWYh20:FUY@80Z:RX0P2NWYh20:FUY@@0
XJ6Q0P2NWYh20:FUY@0309fMW@2QXJ40XJ6Q00P0XJ6Q0P2NWYh20:FUY@80Z:RX0P2QXJ480:RXZ0@0
YJFU00<0YZJV09NGU`2GUiL00P2UYJD20:6QX@80Z:RX102QXJ4209jNWP80[:b/0P2XZ:P20:6QX@80
Z:RX0P2NWYh20:FUYA<0XJ6Q5@3oool001<0oooo8`2QXJ4209fMW@80YZJV0P2JVYXO0:6QX@80WYjN
0P2UYJD20:6QX@030:j^[P2GUiL0UiNG0080ZJVY0P2UYJD20:6QX@80IFEU0P1MGEd207IfMP80I6AT
0P1aLG4208F5Q@80P8200P2LW9`208J6QP80R8R80P2EUID309VIV@80RHV90P2<S8`208V9R@80S8b<
0P1jNWX206=SH`80LG5a0P20P80209FEU@@0XJ6Q0P2^[Zh20:JVYP80UYJF00<0YZJV09nOW`2OWil0
0P2OWil209ZJVPH0XJ6Q0P2MWId209jNWP80XZ:R202QXJ4209fMW@80XJ6Q00<0WYjN0:FUY@2UYJD0
0P2VYZH209NGU`80YJFU0P2QXJ4209fMW@80YZJV0P2JVYX:0:6QX@80WIfM0P2QXJ400`2XZ:P0XZ:R
0::RXP0209ZJVP80YZJV0P2JVYX40:6QX@80WIfM202QXJ420::RXP80VYZJ2`2QXJ420:JVYP80VYZJ
102QXJ4E0?ooo`004`3ooolS0:6QX@80WIfM0P2VYZH209ZJVQl0XJ6Q0P2NWYh20:FUY@80XJ6Q00<0
[Zj^09NGU`2GUiL00P2YZJT20:FUY@80XJ6Q0P1UIFD205eMG@80MWIf0P1TI6@2075aL@80QHF50P20
P80209bLW080QXJ60P28R8P209FEU@<0VIVI0P29RHT208b<S080RHV90P2<S8`207YjNP80Hf=S0P1a
LG420820P080UIFE102QXJ420:j^[P80YZJV0P2FUYH00`2VYZH0WinO09nOW`0209nOW`80VYZJ1P2Q
XJ4209fMW@80WYjN0P2RXZ880:6QX@80WIfM0P2QXJ400`2NWYh0YJFU0:FUY@020:JVYP80UiNG0P2U
YJD20:6QX@80WIfM0P2VYZH209ZJVPX0XJ6Q0P2MWId20:6QX@030:RXZ02RXZ80XZ:R0080VYZJ0P2V
YZH209ZJVP@0XJ6Q0P2MWId80:6QX@80XZ:R0P2JVYX;0:6QX@80YZJV0P2JVYX40:6QXAD0oooo000C
0?ooobD0XJ6Q0P2XZ:P209jNWP80YJFU4`2QXJ420:JVYP80UiNG0P2UYJD40:6QX@80WIfM0P2NWYh2
0:FUY@030:RXZ02MWId0WIfM0080WIfM1P2QXJ4409fMW@80XZ:R0P2>SXh209FEU@80SXj>0P2LW9`2
09BDU080OWin0`1fMWH208:2PP80RHV90P1fMWH207emO@80PX:20P2EUID209fMW@80XJ6Q0P2VYZH2
09nOW`80VYZJ0P2QXJ420:RXZ080[Zj^0P2JVYX50:RXZ080WYjN0P2UYJD20:JVYP80VYZJ0P2QXJ42
0::RXP80UYJF102QXJ420:JVYP80VYZJ0P2VYZH209ZJVP030::RXP2JVYX0VYZJ0080YJFU102QXJ42
09jNWP80YJFU0P2XZ:PA0:6QX@@0YJFU0P2XZ:P20:JVYP80VYZJ1P2QXJ420:JVYP80VYZJ0P2QXJ42
0:RXZ0d0XJ6Q0P2XZ:P60:6QXAD0oooo000C0?ooobD0XJ6Q0P2XZ:P209jNWP80YJFU4`2QXJ420:JV
YP80UiNG0P2UYJD40:6QX@80WIfM0P2NWYh20:FUY@030:RXZ02MWId0WIfM0080WIfM1P2QXJ4409fM
W@80XZ:R0P2>SXh209FEU@80SXj>0P2LW9`209BDU080OWin0`1fMWH208:2PP80RHV90P1fMWH207em
O@80PX:20P2EUID209fMW@80XJ6Q0P2VYZH209nOW`80VYZJ0P2QXJ420:RXZ080[Zj^0P2JVYX50:RX
Z080WYjN0P2UYJD20:JVYP80VYZJ0P2QXJ420::RXP80UYJF102QXJ420:JVYP80VYZJ0P2VYZH209ZJ
VP030::RXP2JVYX0VYZJ0080YJFU102QXJ4209jNWP80YJFU0P2XZ:PA0:6QX@@0YJFU0P2XZ:P20:JV
YP80VYZJ1P2QXJ420:JVYP80VYZJ0P2QXJ420:RXZ0d0XJ6Q0P2XZ:P60:6QXAD0oooo000C0?ooobL0
XJ6Q0P2MWIdE0:6QX@80Z:RX0P2MWId60:6QX@80WYjN102QXJ400`2NWYh0Zj^[0:^[Z`0209ZJVP@0
XJ6Q0P2NWYh20:FUY@80WYjN0P2/[:`20:6QX@80YZJV0P2GUiL20:FUY@80XJ6Q1`2MWId20:j^[P80
VYZJ0P2QXJ4209jNWP80YJFU102QXJ440:RXZ080XJ6Q0P2VYZH209ZJVP80[Zj^0P2JVYX30:6QX@80
WYjN0P2VYZH209ZJVP80[Zj^0P2OWil209ZJVP80Z:RX1P2QXJ420:RXZ080XJ6Q0P2XZ:P20:6QX@03
0:j^[P2GUiL0UiNG0080WYjN0P2UYJD209jNWQ00XJ6Q0P2VYZH209ZJVP<0XJ6Q0P2MWId40:6QX@80
[Zj^0P2JVYX40:6QX@80WYjN0P2/[:`20:JVYP80WinO0P2JVYX=0:6QX@80YZJV0P2JVYX209jNWP80
YJFU5@3oool001<0oooo9`2QXJ4209fMWAD0XJ6Q0P2XZ:P209fMW@H0XJ6Q0P2NWYh40:6QX@0309jN
WP2[Zj/0Zj^[0080VYZJ102QXJ4209jNWP80YJFU0P2NWYh20:b/[080XJ6Q0P2VYZH209NGU`80YJFU
0P2QXJ4709fMW@80[Zj^0P2JVYX20:6QX@80WYjN0P2UYJD40:6QX@@0Z:RX0P2QXJ420:JVYP80VYZJ
0P2^[Zh209ZJVP<0XJ6Q0P2NWYh20:JVYP80VYZJ0P2^[Zh209nOW`80VYZJ0P2XZ:P60:6QX@80Z:RX
0P2QXJ420:RXZ080XJ6Q00<0[Zj^09NGU`2GUiL00P2NWYh20:FUY@80WYjN402QXJ420:JVYP80VYZJ
0`2QXJ4209fMW@@0XJ6Q0P2^[Zh209ZJVP@0XJ6Q0P2NWYh20:b/[080YZJV0P2OWil209ZJVPd0XJ6Q
0P2VYZH209ZJVP80WYjN0P2UYJDE0?ooo`004`3ooolY0:6QX@80YZJV0P2JVYXK0:6QX@80WIfM0P2Q
XJ420:JVYP0309^KV`2QXJ40XJ6Q00@0XJ6Q0P2NWYh40:6QX@80XZ:R0P2JVYX20:6QX@80Z:RX0P2R
XZ8209ZJVP80XJ6Q0P2VYZH209ZJVP<0XJ6Q102UYJD20:6QX@80WIfM1P2QXJ4209jNWP80YJFU0P2V
YZH40:6QX@80[Zj^0P2OWil00`2JVYX0XJ6Q0:6QX@0209fMW@@0YJFU0P2XZ:P40:FUY@80YZJV0P2J
VYX60:6QX@80YZJV0P2JVYX20:6QX@030:RXZ02MWId0WIfM0080WIfM0P2QXJ4209fMW@@0XJ6Q0P2V
YZH209NGU`80YJFU1P2QXJ420:j^[P80VYZJ0P2QXJ400`2VYZH0VYZJ09ZJVP020:6QX@80WYjN0P2/
[:`60:6QX@80WIfM0P2QXJ420:FUY@80/[:b0P2JVYX=0:6QX@80Z:RX0P2QXJ420::RXP80VYZJ5@3o
ool001<0oooo:@2QXJ420:JVYP80VYZJ6`2QXJ4209fMW@80XJ6Q0P2VYZH00`2KVi/0XJ6Q0:6QX@04
0:6QX@80WYjN102QXJ420::RXP80VYZJ0P2QXJ420:RXZ080XZ:R0P2JVYX20:6QX@80YZJV0P2JVYX3
0:6QX@@0YJFU0P2QXJ4209fMW@H0XJ6Q0P2NWYh20:FUY@80YZJV102QXJ420:j^[P80WinO00<0VYZJ
0:6QX@2QXJ400P2MWId40:FUY@80Z:RX102UYJD20:JVYP80VYZJ1P2QXJ420:JVYP80VYZJ0P2QXJ40
0`2XZ:P0WIfM09fMW@0209fMW@80XJ6Q0P2MWId40:6QX@80YZJV0P2GUiL20:FUY@H0XJ6Q0P2^[Zh2
09ZJVP80XJ6Q00<0YZJV09ZJVP2JVYX00P2QXJ4209jNWP80[:b/1P2QXJ4209fMW@80XJ6Q0P2UYJD2
0;:b/P80VYZJ3@2QXJ420:RXZ080XJ6Q0P2RXZ8209ZJVQD0oooo000C0?ooob40XJ6Q0P2VYZH209ZJ
VP80XJ6Q0P2NWYh20:b/[080XJ6Q0P2NWYh00`2UYJD0XJ6Q0:6QX@0B0:6QX@80WYjN0P2[Zj/209ZJ
VP80XJ6Q0P2XZ:P30:FUY@@0XJ6Q0P2MWId209jNWP80Zj^[0P2NWYh20:FUY@@0XJ6Q0P2^[Zh209ZJ
VP80XJ6Q0P2XZ:P20:JVYP0309ZJVP2NWYh0WYjN00@0XJ6Q0P2NWYh20:FUY@H0XJ6Q0P2MWId20:6Q
X@80Z:RX102QXJ420:RXZ080[Zj^00<0VYZJ0:6QX@2QXJ400P2NWYh20:6QX@80YZJV0P2JVYX209fM
W@80XJ6Q0P2UYJD20:^[Z`80WinO0P2JVYX20:6QX@80YJFU0P2[Zj/209ZJVPD0XJ6Q0P2VYZH209ZJ
VP@0XJ6Q0P2^[Zh209JFUP@0XJ6Q0P2VYZH209ZJVP80Z:RX0P2VYZH209ZJVP030:RXZ02VYZH0YZJV
0080WinO0P2FUYH20:6QX@80YZJV0P2JVYX40:6QX@80WYjN0P2QXJ420:RXZ0/0XJ6Q0P2VYZH209ZJ
VP@0XJ6Q0P2XZ:P20:6QXAD0oooo000C0?ooob40XJ6Q0P2XZ:P40:6QX@80WIfM0P2QXJ420:JVYP80
UYJF5@2QXJ4209fMW@80Z:RX1P2QXJ400`2MWId0XJ6Q0:6QX@060:6QX@80VYZJ0P2/[:`209fMW@80
XJ6Q0P2VYZH209NGU`80[:b/0P2VYZH209ZJVP80XJ6Q0P2XZ:P00`2QXJ40XZ:R0::RXP0209ZJVP80
YZJV0P2FUYH:0:6QX@80WYjN0P2UYJD20:JVYP80VYZJ0P2QXJ420:RXZ0<0XJ6Q0P2MWId20:6QX@80
Z:RX1P2QXJ4209fMW@80Z:RX102UYJD20:6QX@80WIfM0P2XZ:P30:6QX@80WYjN0P2[Zj/209jNWP80
Zj^[0P2JVYX20:6QX@80[Zj^0P2JVYX20:6QX@80WYjN0P2/[:`40:6QX@80Z:RX0`2QXJ440:RXZ0@0
XJ6Q0P2XZ:P20:6QX@80WYjN0P2UYJD209fMW@d0XJ6Q0P2NWYh20;:b/P80VYZJ202QXJ4E0?ooo`00
4`3ooolQ0:6QX@80Z:RX102QXJ4209fMW@80XJ6Q0P2VYZH209JFUQD0XJ6Q0P2MWId20:RXZ0H0XJ6Q
00<0WIfM0:6QX@2QXJ401P2QXJ4209ZJVP80[:b/0P2MWId20:6QX@80YZJV0P2GUiL20:b/[080YZJV
0P2JVYX20:6QX@80Z:RX00<0XJ6Q0::RXP2RXZ800P2JVYX20:JVYP80UYJF2P2QXJ4209jNWP80YJFU
0P2VYZH209ZJVP80XJ6Q0P2XZ:P30:6QX@80WIfM0P2QXJ420:RXZ0H0XJ6Q0P2MWId20:RXZ0@0YJFU
0P2QXJ4209fMW@80Z:RX0`2QXJ4209jNWP80Zj^[0P2NWYh20:^[Z`80VYZJ0P2QXJ420:j^[P80VYZJ
0P2QXJ4209jNWP80[:b/102QXJ420:RXZ0<0XJ6Q102XZ:P40:6QX@80Z:RX0P2QXJ4209jNWP80YJFU
0P2MWId=0:6QX@80WYjN0P2b/[8209ZJVPP0XJ6Q5@3oool001<0oooo9`2QXJ420:JVYP80VYZJ0P2X
Z:PE0:6QX@80WYjN0P2UYJDA0:6QX@80VYZJ0P2RXZ820:FUY@80XJ6Q0P2XZ:P209fMW@80WYjN0P2b
/[8209nOW`80VYZJ0P2QXJ400`2VYZH0WYjN09jNWP020:FUY@80Z:RX1P2QXJ420:JVYP80VYZJ102N
WYh20:FUY@80Z:RX0P2VYZH209NGU`80YJFU00<0YZJV09ZJVP2JVYX00P2VYZH209ZJVP80XJ6Q0P2V
YZH209ZJVP80YZJV0P2JVYX20:6QX@80WIfM102QXJ420:JVYP80VYZJ0`2QXJ4209fMW@80Z:RX0P2J
VYX20:b/[080YZJV0P2JVYX20:RXZ080XJ6Q0P2VYZH209JFUP@0XJ6Q0P2VYZH209ZJVP80YZJV00<0
VYZJ0:6QX@2QXJ400P2VYZH209NGU`80YJFU102QXJ4209fMW@80XJ6Q0P2VYZH209ZJVP80XJ6Q0P2V
YZH209ZJVPD0XJ6Q0P2MWId20:RXZ0H0XJ6Q0P2NWYh20::RXQD0oooo000C0?ooobL0XJ6Q0P2VYZH2
09ZJVP80Z:RX5@2QXJ4209jNWP80YJFU4@2QXJ4209ZJVP80XZ:R0P2UYJD20:6QX@80Z:RX0P2MWId2
09jNWP80/[:b0P2OWil209ZJVP80XJ6Q00<0YZJV09jNWP2NWYh00P2UYJD20:RXZ0H0XJ6Q0P2VYZH2
09ZJVP@0WYjN0P2UYJD20:RXZ080YZJV0P2GUiL20:FUY@030:JVYP2JVYX0VYZJ0080YZJV0P2JVYX2
0:6QX@80YZJV0P2JVYX20:JVYP80VYZJ0P2QXJ4209fMW@@0XJ6Q0P2VYZH209ZJVP<0XJ6Q0P2MWId2
0:RXZ080VYZJ0P2/[:`20:JVYP80VYZJ0P2XZ:P20:6QX@80YZJV0P2FUYH40:6QX@80YZJV0P2JVYX2
0:JVYP0309ZJVP2QXJ40XJ6Q0080YZJV0P2GUiL20:FUY@@0XJ6Q0P2MWId20:6QX@80YZJV0P2JVYX2
0:6QX@80YZJV0P2JVYX50:6QX@80WIfM0P2XZ:P60:6QX@80WYjN0P2RXZ8E0?ooo`004`3ooolW0:6Q
X@80Z:RX0P2QXJ420:JVYP80VYZJ4`2QXJ4209fMW@80YZJV0P2JVYX20:6QX@80WYjN0P2UYJD00`2N
WYh0YJFU0:FUY@060:6QX@@0WIfM0P2VYZH209ZJVP@0XJ6Q0P2MWId40:RXZ080XJ6Q0P2NWYh00`2b
/[80UYJF09JFUP0:0:6QX@80Z:RX0P2QXJ4409fMW@80XJ6Q0P2NWYh20:b/[080XZ:R0P2JVYX00`2^
[Zh0VYZJ09ZJVP020:RXZ080XJ6Q0P2NWYh20;:b/P80UiNG0P2b/[8209ZJVP@0XJ6Q0P2NWYh20:FU
Y@80Z:RX2@2QXJ4209fMW@80YZJV0P2NWYh20::RXP80YJFU0P2QXJ420:RXZ080WYjN0P2UYJD20:6Q
X@80Z:RX0P2QXJ420:j^[P0309ZJVP2QXJ40XJ6Q0080Z:RX0P2MWId60:6QX@80YZJV0P2JVYX20:RX
Z0@0XJ6Q0P2XZ:P=0:6QX@80WYjN0P2UYJD20::RXP80UYJF5@3oool001<0oooo9`2QXJ420:RXZ080
XJ6Q0P2VYZH209ZJVQ<0XJ6Q0P2MWId20:JVYP80VYZJ0P2QXJ4209jNWP80YJFU00<0WYjN0:FUY@2U
YJD01P2QXJ4409fMW@80YZJV0P2JVYX40:6QX@80WIfM102XZ:P20:6QX@80WYjN00<0/[:b09JFUP2F
UYH02P2QXJ420:RXZ080XJ6Q102MWId20:6QX@80WYjN0P2/[:`20::RXP80VYZJ00<0[Zj^09ZJVP2J
VYX00P2XZ:P20:6QX@80WYjN0P2b/[8209NGU`80/[:b0P2JVYX40:6QX@80WYjN0P2UYJD20:RXZ0T0
XJ6Q0P2MWId20:JVYP80WYjN0P2RXZ820:FUY@80XJ6Q0P2XZ:P209jNWP80YJFU0P2QXJ420:RXZ080
XJ6Q0P2^[Zh00`2JVYX0XJ6Q0:6QX@020:RXZ080WIfM1P2QXJ420:JVYP80VYZJ0P2XZ:P40:6QX@80
Z:RX3@2QXJ4209jNWP80YJFU0P2RXZ8209JFUQD0oooo000C0?ooob/0XJ6Q0P2XZ:P209jNWP030:FU
Y@2QXJ40XJ6Q00`0XJ6Q0P2NWYh20:^[Z`80VYZJ0P2XZ:P209jNWP80YJFU0P2MWId309jNWP80YJFU
102QXJ420:JVYP80WinO0P2JVYX20:RXZ080XJ6Q0P2NWYh20:FUY@H0XJ6Q0P2NWYh20:6QX@030:RX
Z02VYZH0YZJV0080VYZJ0P2NWYh20:^[Z`80VYZJ202QXJ420:JVYP80VYZJ0P2RXZ8209ZJVP80YJFU
0P2[Zj/00`2QXJ40WYjN09jNWP020:FUY@80WYjN0P2QXJ420:RXZ080XZ:R102QXJ4209jNWP80YJFU
0P2MWId20:JVYP80UiNG0P2[Zj/209ZJVP0309jNWP2UYJD0YJFU0080WYjN0P2[Zj/20:6QX@80XZ:R
0P2FUYH40:6QX@80WYjN2P2QXJ420:RXZ0d0XJ6Q0P2XZ:P20:6QX@80WYjN0P2UYJDA0:6QX@80WIfM
0P2QXJ420:RXZ080XJ6Q5@3oool001<0oooo:`2QXJ420:RXZ080WYjN00<0YJFU0:6QX@2QXJ40302Q
XJ4209jNWP80Zj^[0P2JVYX20:RXZ080WYjN0P2UYJD209fMW@<0WYjN0P2UYJD40:6QX@80YZJV0P2O
Wil209ZJVP80Z:RX0P2QXJ4209jNWP80YJFU1P2QXJ4209jNWP80XJ6Q00<0Z:RX0:JVYP2VYZH00P2J
VYX209jNWP80Zj^[0P2JVYX80:6QX@80YZJV0P2JVYX20::RXP80VYZJ0P2UYJD20:^[Z`030:6QX@2N
WYh0WYjN0080YJFU0P2NWYh20:6QX@80Z:RX0P2RXZ840:6QX@80WYjN0P2UYJD209fMW@80YZJV0P2G
UiL20:^[Z`80VYZJ00<0WYjN0:FUY@2UYJD00P2NWYh20:^[Z`80XJ6Q0P2RXZ8209JFUP@0XJ6Q0P2N
WYh:0:6QX@80Z:RX3@2QXJ420:RXZ080XJ6Q0P2NWYh20:FUYA40XJ6Q0P2MWId20:6QX@80Z:RX0P2Q
XJ4E0?ooo`004`3oool]0:6QX@80WIfM3`2QXJ4209fMW@80Z:RX102QXJ420::RXP80VYZJ0P2VYZH2
09JFUP0309ZJVP2[Zj/0Zj^[0080WinO0P2JVYX20:FUY@80/[:b0P2JVYX40:6QX@80WIfM202QXJ42
0::RXP80WinO00<0VYZJ0:RXZ02XZ:P00P2QXJ4209fMW@80[Zj^0P2JVYX80:6QX@80Z:RX0P2VYZH4
0:6QX@80WIfM0P2XZ:P00`2QXJ40XZ:R0::RXP0209nOW`80Vi^K0P2OWil209ZJVP80Z:RX102QXJ42
09ZJVP80YJFU0P2VYZH20:6QX@80WIfM0P2XZ:P20:JVYP0309^KV`2OWil0WinO0080Vi^K102QXJ42
0:RXZ0H0XJ6Q0P2RXZ8209nOW`80VYZJ1P2QXJ4209jNWP030:FUY@2QXJ40XJ6Q00P0XJ6Q0P2VYZH2
09ZJVP80XJ6Q0P2MWId20:6QX@80YZJV0P2JVYX60:6QX@030:JVYP2JVYX0VYZJ0080YZJV0P2JVYX2
0:6QX@80YZJV0P2JVYX20:6QXAD0oooo000C0?ooobd0XJ6Q0P2MWId?0:6QX@80WIfM0P2XZ:P40:6Q
X@80XZ:R0P2JVYX20:JVYP80UYJF00<0VYZJ0:^[Z`2[Zj/00P2OWil209ZJVP80YJFU0P2b/[8209ZJ
VP@0XJ6Q0P2MWId80:6QX@80XZ:R0P2OWil00`2JVYX0Z:RX0:RXZ0020:6QX@80WIfM0P2^[Zh209ZJ
VPP0XJ6Q0P2XZ:P20:JVYP@0XJ6Q0P2MWId20:RXZ0030:6QX@2RXZ80XZ:R0080WinO0P2KVi/209nO
W`80VYZJ0P2XZ:P40:6QX@80VYZJ0P2UYJD20:JVYP80XJ6Q0P2MWId20:RXZ080YZJV00<0Vi^K09nO
W`2OWil00P2KVi/40:6QX@80Z:RX1P2QXJ420::RXP80WinO0P2JVYX60:6QX@80WYjN00<0YJFU0:6Q
X@2QXJ40202QXJ420:JVYP80VYZJ0P2QXJ4209fMW@80XJ6Q0P2VYZH209ZJVPH0XJ6Q00<0YZJV09ZJ
VP2JVYX00P2VYZH209ZJVP80XJ6Q0P2VYZH209ZJVP80XJ6Q5@3oool001<0oooo8`2QXJ420:JVYP80
VYZJ0P2VYZH209ZJVP80XJ6Q0P2NWYh00`2UYJD0WYjN09jNWP020:FUY@P0XJ6Q0P2VYZH209ZJVPH0
XJ6Q0P2XZ:P20:6QX@@0YJFU00<0VYZJ0:b/[02/[:`0102UYJD209fMW@80Z:RX202QXJ4209jNWP80
YJFU102QXJ440:RXZ0030:6QX@2VYZH0YZJV0080VYZJ0P2QXJ420:RXZ080XJ6Q0P2VYZH209NGU`80
YJFU0P2VYZH209nOW`/0XJ6Q202XZ:P20:6QX@80YZJV0P2JVYX20:6QX@80WIfM0P2QXJ420:RXZ080
WYjN0P2UYJD20:6QX@L0Z:RX0P2VYZH209ZJVP80YZJV0P2JVYX20:6QX@80WYjN0P2/[:`20:j^[P80
VYZJ102QXJ420:JVYP80UYJF2`2QXJ420:RXZ080WYjN0P2UYJD209jNWP80YJFU0P2XZ:P80:6QX@03
0:RXZ02QXJ40XJ6Q0080Z:RX102QXJ420:RXZ0@0XJ6Q5@3oool001<0oooo8`2QXJ420:JVYP80VYZJ
0P2VYZH209ZJVP80XJ6Q0P2NWYh00`2UYJD0WYjN09jNWP020:FUY@P0XJ6Q0P2VYZH209ZJVPH0XJ6Q
0P2XZ:P20:6QX@@0YJFU00<0VYZJ0:b/[02/[:`0102UYJD209fMW@80Z:RX202QXJ4209jNWP80YJFU
102QXJ440:RXZ0030:6QX@2VYZH0YZJV0080VYZJ0P2QXJ420:RXZ080XJ6Q0P2VYZH209NGU`80YJFU
0P2VYZH209nOW`/0XJ6Q202XZ:P20:6QX@80YZJV0P2JVYX20:6QX@80WIfM0P2QXJ420:RXZ080WYjN
0P2UYJD20:6QX@L0Z:RX0P2VYZH209ZJVP80YZJV0P2JVYX20:6QX@80WYjN0P2/[:`20:j^[P80VYZJ
102QXJ420:JVYP80UYJF2`2QXJ420:RXZ080WYjN0P2UYJD209jNWP80YJFU0P2XZ:P80:6QX@030:RX
Z02QXJ40XJ6Q0080Z:RX102QXJ420:RXZ0@0XJ6Q5@3oool001<0oooo8`2QXJ420:j^[P80VYZJ0P2X
Z:P20:JVYP80VYZJ0P2MWId00`2QXJ40WIfM09fMW@0:0:6QX@80Z:RX202QXJ4209jNWP80YJFU0P2M
WId20:6QX@0309fMW@2QXJ40XJ6Q0080WIfM0P2VYZH209ZJVP80YZJV0P2JVYX60:6QX@80WIfM2P2Q
XJ430:JVYP80VYZJ102QXJ4209jNWP80[:b/0P2MWId40:JVYQD0XJ6Q102VYZH209nOW`80VYZJ1P2Q
XJ4209fMW@/0XJ6Q0P2^[Zh209nOW`80YZJV0P2JVYX20:6QX@80WIfM0P2QXJ420:RXZ0H0XJ6Q0P2X
Z:P;0:6QX@80YZJV102JVYX20:FUY@80VYZJ0P2UYJD20:6QX@80YZJV0P2JVYX20:6QX@80YZJV00<0
UiNG0:FUY@2UYJD0302QXJ4E0?ooo`004`3ooolS0:6QX@80[Zj^0P2JVYX20:RXZ080YZJV0P2JVYX2
09fMW@030:6QX@2MWId0WIfM00X0XJ6Q0P2XZ:P80:6QX@80WYjN0P2UYJD209fMW@80XJ6Q00<0WIfM
0:6QX@2QXJ400P2MWId20:JVYP80VYZJ0P2VYZH209ZJVPH0XJ6Q0P2MWId:0:6QX@<0YZJV0P2JVYX4
0:6QX@80WYjN0P2/[:`209fMW@@0YZJV5@2QXJ440:JVYP80WinO0P2JVYX60:6QX@80WIfM2`2QXJ42
0:j^[P80WinO0P2VYZH209ZJVP80XJ6Q0P2MWId20:6QX@80Z:RX1P2QXJ420:RXZ0/0XJ6Q0P2VYZH4
09ZJVP80YJFU0P2JVYX20:FUY@80XJ6Q0P2VYZH209ZJVP80XJ6Q0P2VYZH00`2GUiL0YJFU0:FUY@0<
0:6QXAD0oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o
0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o
0?ooob40oooo002B0?ooo`900000S03oool009@0oooo00=000000?ooo`3oool0R@3oool00880oooo
00=000000?ooo`3oool00`3oool3@0000080oooo0T0000030?ooo`=000001@3oool00d000000oooo
0?ooo`230?ooo`00P@3oool00d000000oooo@00000030?ooo`06@000003oool0oooo@000003ooom0
0000103oool014000000oooo0?oood00002;0?ooo`00P@3oool00d000000oooo@00000030?ooo`05
@000003oool0oooo@000003oool00d0000020?ooo`04@000003oool0oooo@00008/0oooo00210?oo
o`03@000003ooom0000000@0oooo0d000000103ooom00000@000040000030?ooo`=00000R`3oool0
0840oooo00=000000?oood0000001P3oool00d000000oooo0?ooo`2C0?ooo`00PP3oool00d000000
oooo0?ooo`040?ooo`900000U@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool0
0?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool0
0?l0oooo8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.0250052, -0.0250052, 
  0.00365857, 0.00365857}, {{6.8125, 280.125}, {280.125, 
  6.8125}} -> {-10.161, -6.11446, 0.516914, 0.516914}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0238095 0.952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0238095 0.97619 0.97619 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00751202 0.0192308 0.00751202 [
[.5 1.0125 -20 0 ]
[.5 1.0125 20 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(60) show
75.000000 12.812500 moveto
(deg) show
93.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(.) show
99.000000 12.812500 moveto
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
128 string
128 128 8 [128 0 0 128 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
9C9DA7A1969D999BA9949F768B8B8C94878C8C8C8CB49433
AF927F867D8C877B8D8886887C828C878F8A848786878788
77908787938D8D8D8D8D8D888F81878C9081878787878687
8787888784898786888786A6A88A429D828C877C82828A86
86868686918A858D97889590908696858185787F8582807D
AC925D9FAAA6A596
9CA0A0989AA5A29BA0A19C91858C8C8D898C8C8B8B929D48
AB9180858482807E86898787858883898F858586867B8389
8383898888868B8885868F83878D85888884878B86878687
8887888787867E898886878C9F9D5069968A877C82828380
898888888F858C878F888D8A8A908C8880868388828288A7
AB72708CAEA69D99
9B9C9A9C9D9E9B999C9FA1A296848B8B8B888B8B868CA489
4A9886857F79838A898A888688867D8092898686807E8282
7A797F838888898B84878984868A848E8F8E8A8B8E858787
888787878786868B878788878C8E9294598D807E8A878082
8C7E808A8F898E888E8B8C929292868983858885848E9698
9C7C7C83A9A4A49B
9D9DA0A69AA5A398A5A39D9B9A91A18D838C868685888AA5
6C898C85847E84848080898788867C818F8785877E8A7E7C
81827D7F858987898586888686878D978C8D8C938D8A8A8F
8E8587888888878888878787878995A1796497898B87868E
8A858A8B8E858D858D8C949290888F8386848F83A78F919F
7893797FB29F9A9C
9C9F9CA0A09F9D97A8A19FA29BA49B98878B8C858D8690AE
945F97898C7B82828A808489878784888B8780817F8B8487
8B88807C8584897B7D7D8A87878789898C8486978F838E89
8E85868E8C87888E8C8C868E86878995A1528E8C8D8B8B87
85878D8C8C8A90898D8E958E8F8E8C878D8398A5A5929AA7
75A96F7EB6A99C9E
9CA098A19D9A9FA39A9E9D98A2A599A5978C888B8D8A8E91
A0878B8E8D8087808487878C877E80897E7A8283808C8787
888686877E7D7F807C8D8389888787878987909282888E89
8D8C8A908A8B8C888C86858A848D868995937B7D8E8D8B89
878C8D8E8D8D8E898E8C8D908F8F8783827A9BA49E768F7E
82A86B98BBA49B99
9CA6A1A597A699A19AA698A4A699A2A4A09D9A8B8F929093
98A47F878D8A8A83878280807F7E7A767B7B7F827A8F888D
8C8B8C8F81887B887E887884817C8A8788888D8484898686
8787858D8A8686868885878787868687869C969488898686
848E898F8D8A8D89958992928F80816D6F84B194A46D9087
8D8F6DB1AE9CA498
9C9F9D9D9AA899A69A9D96A09BA19FA3A1A1999594969697
939A9B86539B85857E7F82818173747D817D7D7F7B888989
8C8A8A8F8187777F7B7D7B857C7B807C828081867E808280
897E89867D8587867E808080807F81897D849A9974868788
8789868E8D898C9394868D8A807862707396A07A6F768A7C
958279B5A698A098
9CA59BA5A2A4979E9B9FA49E9C9DA29EA3A197A497A7A0A1
A6A6A5988D898588828082827B7F7A8882858B8A827D8789
8E8A8A8B8B8A827B858B7E878182837C7F7376776C787575
776C797474787575737676847C828183787C8873868C6B5A
7B84808B87858D8E8A8F8A8354697280787F907F7986839A
8F7695AEA49D9B9B
A39FA09DA3A19F9D9F999F999B9DA8979BA496A799A79A9B
A69B9B9CA48C79639D7A74858083757D757F84828078868C
8890898E8A84857C85847E8C81898886828984858281847E
807E877E8087838684848D8F788E88887F8B827E8D89828A
8D309477838787856B514E5056868D8673868A808D8571A6
8868AB96A6A0A29B
999AA697A1989B9C9EA299A0A4A39F9B9EA899A79AA5979E
A199A599A19B635D8B69758A81817F84788185848378848D
8889858D89898B8381838A8A858A878785837B8B87878B7F
8285858989848284818A8A87838D80887E8C858988818A86
876FC46A606272554C5C56627B778E746EB678818A6692AA
759191A89E9D9CA2
A39B9FA19BA3A4999D9EA09FA599A29A9FA0A19BA2A49FA4
9A9B9D97A1996A7F617977638B827C827186847C857D838E
878688898C848C8385818488878787878785877F83818885
887F83837D818A887B8D87878780808B7D8C7D8986858B7E
817F917F8A813D45625C5D6F6F686D747DB550788F639E95
6FB992AE9AA09DA8
9BA1A39C99A799A0A4A39CA2A4999FA1A4A2A497A1A3A19B
989C9F9C9E9B758462687B4A4D87827E7A877C81817A838E
878787878E8388848785888A878788868787877D85838B80
81867F7E8385847F7E8E888687798B8A7E857F8D877E807E
817370674C41485F5F597167696980807B98587F8C69A885
85B29BA393A8A39F
A39F9A9B9CA797A796A496A799A299A7A1A1999CA5A499A2
9A9A9EA49B9C839C854F6E4A49429B74857576818180848D
8787878789848787878780818181897F8887877E83838480
80827D838583837F8485897D827E8E877E80838481778273
75646049465B6F666A605D6B6A7A8377887A5F7D7B899380
96B49D9F99A59D96
9B9CA39E98A89FA597A8999EA19CA1A5999B9B9CA696A29F
99A49EA1969D7FAA73445854453735897C738780847B8285
898787878088878787878588818A838084888785887B7E84
8283837E84807D80827E8D7D8B818289858084807A7A7671
68685043666D5B67755E5D6C7B687D697B6C848983AB6A8C
B1A89E979E9BA59B
9D9D9D9A9AA8969C96A8A0A19DA19D9BA19AA69C9EA19D9A
A49DA29D9B9B85A46F6D4C624737293996798473877F7D8D
8A8787878583818887808181807E7F838A8A8780817E8180
807B8581857C8176847F8780848082857E6E746E666A686B
543D3360826A43706E79747A645E6E6B81718E80AA8079A1
AC96999CA09CA89A
9BA59D9CA59C98A0A3A09DA399A699A4A599A79A9B9FA19D
9E97A2999E999A8F8865485B4037322E3195846E8A7B8089
8880818181878184887E838A81817E8185817F87817C7B7E
7D7B7F7C81797E747C778184748670837A73707169665A4D
31414A7574655980727C696D70606B7D79778D838A7997A7
A08D9CA59E9BA7A0
9D9DA2A1A594A6A4A4989CA698A096A19A99A6A0A29DA0A1
999C9F9E9D93977A974353573D393E34261C94777D7D7F85
82808383838B7E8A838083847D83817E7F807D87807E807F
7C8077757B7F77778278877D73797A7974746F6C5D4A4744
41566E7967626876655C5A6A6373797B738B898388AAA197
9BA0A3A9A2A1A5A1
9BA5A0A3A19E9E9DA39F9D9E97A0A2A5A1A39F9A9E9B9EA5
999F9F9C9C9D95809A425B57403A3F331F221EA078897D85
818483838384878A7E8383838284837E81857C847D7E7B7C
7C7E75797B7C73717A7778846B7879746975684F3B492C55
576378666169647D6A6D727D757D7A76888B8382959C9398
A3A2A49FA39B9AA3
A3A695A79BA39FA39E9D969FA49C9B9E9DA3A09AA0A49A9D
9CA49D9A9D9B91898846594A43453D2A1F1C2AD478848183
82818A818A81848180837C84837F837C827F7A7E767F7C7D
7D777776727271717B89726D656F6E6E5B6551522D4C425B
47646D5B5F667276777B6B788A737A86888381939A92AAA3
A9A49F9BA597A4A5
A19B98A09C9DA399A29A9AA7A499A49DA49E9D9BA59B99A5
A49EA19A9F9996836351594C4253393625293A479288848B
7F818D7E84808383838082827A7F857E7F7E817683758083
7C767A7072626E7D8A7856646F6670655058434857536361
66786F606665785F6B6F68796F668B878082909BA19AADA4
9C99A2A29E9BA79B
A1A099A59B9EA1A1A597A5A5A1A09B9CA6979F999EA19AA2
A398A0999B92967760515B48525131392A383B21C28A838D
7B81867A80837C808382807D7F8080837A7D7D7F767E777B
7474726A646A719187536073715F544A3E5F4949545A614D
676E68615E4F8A5F81668F6A748B8D80808A8CA79F98A6A5
94A5A6A197A5A4A0
A199A19DA1A4A2A4A199A6A1A1A1999DA69F9E9D9BA899A5
9B99A6A29A92985E694E504846452D3B3F432D13E7818483
8080847B80867B807F7E7D7E82807E7E7F7C7D75727A7677
77786B6A5E668183595061655D504C3A50664A4F52554D4D
6C70695D6069825F7660706D76788781829CACA3999EAAA4
99A8A1999B9EA3A1
A19FA597A7A19BA39BA19EA3A1A1A09CA09D9B9EA2A69AA5
96A5A5A1979187596853524D4D352F4346382725EE7A8F7F
7B84817F847F7D817E76817F7778777883717A74777B7172
736B6959626A7864525E5F61543F4A475573565D4E4E6B5C
69656565807172616B6669758C8794809AA0A39A96A0A199
A2A49BA0A4A1A5A1
A19BA39FA59B9BA5A09EA1A4A1A19BA19D9EA4A29EA39AA0
9BA19D9B9891825F5F564D4B4E3A3E5A3D232622E47A8770
82878274787E7D77777678797676777B7377727273747074
6A6B665D607761504A5D51593E53524F5167645F4E5F6059
6750696A847378606A7E647394828B94A9A699A093A39EA4
A6A19A9D9E9A9EA3
A1A0A49BA3A09DA5A1A09EA3A1A1A0A4A0A2A4A19AA59A9E
A49A9CA4A28F6F58675A4C4C4F324C402E1D2F22E67F837E
877C857B778576747B76717972777274717C75726E6D756C
6B6E645A6B694E4B53504C3E4951394954736963695A5B53
5562725E81776A5D7F82648191819CA0A09096A09EA39EA6
9BA3A0A19E9DA59E
A1A1A1A09E9DA19E9AA3A0A4A19BA3A1A1A1A19BA1A49A99
A196A59F9B9756605E583C4B3F3750392F293826E674847B
82797982737C76757372726E6D766C6F767572696E6C706B
6E60615A715A4C4B4B4A454E503F3F4D5665675D6758644E
55536572796E77767F626A818B8AA5959D9FA098A3A49DA5
A0A4A1A19AA4A49A
A19B9DA39A9EA5A0A19F9AA3A19AA5A19B9D9B99A69B9BA2
A59BA8959D8255675554455A374A4C3F20222A2BDF708473
817B767C757178706C756E6D70666567716C706A6F656868
62605E60524749444C514F4947464D5655626D7A717E5F43
4E557163737A7B7660616A93908AA19B94A393A6A2A5A0A4
A19BA3A1A09BA39A
9DA1A29E9B9C9D9B9EA1A1A599A29EA39AA49AA5A5A0A2A4
9B99A0989E69635C594D414F3A5735311A202B2ADE70837C
80777771727075716C6F6B706D6B67696A68706D6666695C
5E5E5362474340514853502B313A52635D5F65706D697355
5268676C618477616069689B8CA6989F959E9DAC959FA3A1
9BA1A4A19BA0A5A0
A2A4A1A09DA3A2A3A4A4A1A19F9D9CA598A699A69BA39B9B
9CA3999F895F6C53524748413F4D322C252F2F30CA737977
7974727773746B6F6D6567685B64615E6B695F6A66695C5B
615F4E6E443250514542302B215A6B4D5E4D60717C6B8351
5E726070638961615B65829E9BA18F94A1A0A1A799A0A6A1
A09BA39BA19EA3A1
A1A19BA39AA09A9E9DA39BA3A19FA3A4979F9C9DA2A49AA3
A39B9B9B7161634855454B454244252A272E2D2DC4787888
797A747E74787775756A615C635A605D625E63685C5E5B55
584E506A3A2E5352332F2B383F586757585A4E787578665C
5D676163807F5C7163828194B58B93A29DA8A3A5A09DA5A1
A19FA5A0A49AA59B
9DA3A09998A59CA5A29E9BA5A199A39BA09BA09BA7A19AA0
9A999D926D665C4C534A4659374416362C2E2842BF8F8D90
868A898080827A797C76716D58585C5C5C5759575F5B5759
524B50632B3652422C252C5933506A5A514E527676807478
606A534B90765B6B7A7E89BCA88F9CA59DA5A39BA3A0A4A1
9BA3A1A1A1A09E99
A29E9DA0A3A69AA5A1A0A2A4A199A7A09EA1A397A89BA19A
9B9F9F7A675F584F503C474343321B3C312C287DC9929887
8A868788898A7B817E78767169695752595B5C5D50595B59
514C445C354C602D2B263B652C545A5E4A4C596A69847974
64654965866C6770946690BE8B889F9AA89DA597A09A9E9D
A1A49BA3A1A1A0A1
9DA19AA69B9BA29BA3A1A1A19B99A69B9BA59B9AA89A9D99
9DA09E73635A5A4A4B4B49404C1B2B3E2B2C7BCBB095908F
879487908786838A7C7F777971726968515454545A555B52
474A363458407120261B26644B405972456B546978878784
704160697160727C7E69C1A2809CAAA0AAA09CA1A4A1A49D
A0A3A0A4A19BA3A1
A29EA1A5A0A2A596A29BA3A1A09AA1A19DA09B9EA5A0A1A3
9A958473555E51433D494640371B3E3A29C6C4A791958F91
8E94828B878E858783897D75757C706B604C4E4F584B544C
48472D317F27853328371C42692A5F66456E5C6571738F83
6A4E5C646C65847C7587B48790AB9FA69CA399A6A19B9DA1
9DA0A3A1A1A0A4A1
A1A0A4A199A3A19FA4A2A5A1999C9DA6A09DA4A2A4A1A19B
96937874505D5048434B414126253A2B6CE39283908E9290
91908C93878B8387877E787F7D7976716B5570454D4E4C4B
443A33317B456F491D1C3359735769605F4F6A626D748286
7B4F4C6A596B8E86787995A0A6A5A0A899A69AA59B9BA4A4
A0A29EA3A1A19BA3
9BA39BA39FA599A39B9DA39B9B9F9BA79B9B9DA3A196A497
98897866555E4D4636433645192E3647D2AA908A908D9584
93848794828985868885867C7C7C767671686B55424E4B41
4833351F657C2F7A3455285C3A70415F5D5F646B55876594
92454B6C627777797185AAA99B9F9BA1A19EA1A49A9EA59B
9DA39AA0A39BA1A4
9FA79AA5A1A199A0A1A2A4A09D9EA39FA1A2A2A5A19EA090
967B8056584B4F413D45392A224147C6B98D918D8D878C80
89828789817A7C81897D82767E74787876716A655D433A48
38362A294B7C44586C2D5A494B6056505F673E6D5C816785
7A70554F6774658088A0B390A1A299A79E9BA59BA1A29EA1
9DA5A0A29EA1A4A1
A2A49AA5A1A19AA49E9D9D9DA1A29EA19E9B9B9E9DA3A08F
877E6E504F4B433C4143202A282BCBBB908C868689847F77
75777374746C777777727F7A7D7C7F7578716C6C6E594D42
37392E2C3C55725E5D6567522F576B56614B5363796A707D
8B9047657E695F858DBB94A0A29F99A9A09DA597A0A39AA0
A1A4A1A1A0A4A19B
A19BA1A4A19BA1A4A0A29DA4A4A1A0A49A9D9EA5A29E9D8E
8182655849534635443B212F3CC2D48C91888487877D7275
6E6C666969686B766D757B71817E7E737871706C65655737
3136291E3052864938944B6F4B4E566A594F6D578261816E
7D8F5E706F696F858EB691A998A1A3A0A3A09BA1A4A49AA4
A49BA3A1A1A1A1A0
A19AA5A19BA1A4A1A1A19AA5A1A1A1A1A09D9C9EA39A9981
7F85564A4A444A35392829313CE28A86878585867A4B4C60
5B636365656550565154767A7C7F7E7B7676726A6D675B56
2D2B261A2D4865725577766B6C635E5A5F624C516E70617D
7B8E7B607B617190969F9DA1949E9FA29B9EA09FA3A1A09E
A3A09EA3A19BA3A1
A19AA59BA19EA3A1A1A19AA5A19B9BA3A19AA3A39DA29186
8A685148474342303D2E2C3BD0C18787868D865C5B5666A9
85696D808A5E6263635B5D7A7B7B7F7E7377776E6D64635E
4A2E1E1F1E4A1EA1763B94478276575E7341605B6B6E647B
798E8A4F5A627481B3A0A69E93ABA49C9B9FA59AA59B9DA1
A49BA1A49B9BA59B
9DA19EA19EA19EA39B9DA19E9D9B9DA09D99A6A197A77D7E
6552514C33423742202B2C73DE898C868688844765666066
53526753543D4F4D76545A4F857E827E7B7E766E6B6D6667
5B47242E13314389694278726382905551596A475E706774
709184546375677FC399A39595AEA19FA4A2A4A09EA1A2A4
A1A0A4A1A0A2A4A0
A2A4A0A49AA0A19E9B9EA59A9E9EA4A29D9DA69B9BA17978
5A5D4840314635262E294BDCB08B8585865C5D3C363D4553
43454F3D392C3A412E38352E4D70887D7D747476696F6C70
5852331412353E487077378F4682937D5B7148605C6B6355
82928275677E678CB5A1989AA19FA4A19BA39BA3A0A4A1A1
A1A1A19BA39BA3A1
9D9D9DA3A09DA0A19DA49EA19DA49E9D9B9EA0999F937E70
524F3A33413A33343B34DAC2858C8C858670905E525D555F
4D5C6D4C52535958518C808191938F7D7777777B6E6D6E6E
615C451D13172E495F8253546F599E8581425A6854696252
927A8787538066ADB29F9499A39DA29DA1A4A0A49BA3A19B
A3A19BA1A49AA5A1
A29D9EA59BA1A2A49AA59AA5A0A4A0A29AA49D989E907A64
4841463D3A363038353EEC848B8C8689858A9583969E919A
A4969995A695978D899C83808280817E7C79767970726D6D
64664F2D1D0D563A465C62387541728E854E70604D56666A
7F64948A53725AC1A2979897ACA2A29DA5A1A1A1A0A49BA1
9EA3A0A49BA1A4A1
9DA1A2A4A0A49BA3A0A49AA59B9DA3A1999E9C9D95737358
403E38383625383932ADCC898E888D868E87908D95898F8C
997C878A87727B797B857A838C7B7D847D77797771746962
67694D361519483B6D55823746696A94848370555C68545A
576B9D8A577C5FD59D8D9AA1ABA1A19AA5A19B9D9DA3A0A4
A0A4A1A1A0A4A19B
9EA59B9D9D9DA19CA3A1A0A49AA49EA39A9D9D9F9B735B46
394A323929363B3737E997868C8D89869288918D8E8A8E8A
8B7F8787877483857C857A8E7C877A8076787F74716E7469
68695741262A154343444E49456B52788F8355665C644B6A
5181858864646ABE9C948AB19FA3A19AA59BA1A2A2A49BA3
A1A19B9DA3A1A1A0
A29EA19D9EA4A49F9FA3A1A1A0A4A0A4A09D9D9D7A704D47
45343F2936283A392AF186868F8E8B8D898D8E8D8D8A8D8D
8284788A787180837A82838F77838789797F7A7670736E6A
605E5C4A2A191F444D5253684543457A697587754C684178
5C8270926953A2A9A59894B0A1A4A1A0A4A09EA3A1A19AA5
9BA3A0A2A4A1A1A1
A1A0A4A0A2A4A1A1A09EA3A1A1A19B9D9DA1A2916D62543E
444234323A343B2B6FD98688918E8D8D928D8A8D8D8C8586
74726B7F716F7A7C7C7F8783868A8D7A7A7D76767074696E
6B66584A36232F33493C574752344D3F8E936D6B526E4964
62766E967357C57DB795A9A7A4A1A1A19BA3A0A4A1A1A09E
9BA5A19BA3A1A1A1
9DA3A1A1A1A19BA39B9BA5A19BA3A0A29AA69B996751473A
3639312B2C393725DCA7898B918D8D8D8E8A888F8D8D817A
727C68787269757B78808084808A87837D8B7B787673696F
6D595B533A210C1F3E3C5836613E4D30AA5868A254645D58
686269987B78A8899F81B4A1A1A1A1A19AA5A1A1A1A1A1A0
A2A4A19AA5A1A1A1
A2A4A1A1A1A1A09EA1A2A49BA1A4A1A19FA5A09255473A35
3729383039382623F5858888918794918B8D8C89935E5393
887F6E3F4761774F737E818F878D8787837F78767870726D
6D625E4A442810222B3A423D5848384D4E628B746956623C
60577B997DAD6AB16BB9B4A1A1A1A1A1A0A4A1A1A1A1A1A1
A1A1A1A0A4A19BA3
9D9DA39B9DA3A1A0A49B9DA19EA3A1A1A1A19B8443423D46
33342D33392A2344EE868F8F978A8B93838E898C977A88A6
8A837667848D8D6A6A758892878887877A87887B77757369
65665A564C39091620343E463E56344819AD67639441653E
5C6873838B91598DA9C29BA3A1A1A1A19BA3A1A1A19BA3A1
A1A1A19B9DA3A0A4
A2A2A4A0A2A49BA3A19A9EA5A0A4A199A3A1A07C3D383E27
333A2F3A3B1F2273CE8B8C8A948F90958C8E8C8996809392
918681787B7C79736E7C8F91878B8687847F7D7A7A78766A
5F665A544841081D1541434E2D5A33461DA75783973B6948
5F646C8595857595CEA19AA5A1A1A1A1A0A49BA3A1A0A4A1
A1A1A1A09DA5A1A1
A1A1A19BA39BA1A49BA19DA5A199A399A0A39B732F354136
3938383D321B2CDFAB928D9495918F918E908684998C949A
8D83857A76757777717E8990878E848B8683897D7F76796F
6B675C53493D15071C3F1E55355B2A3F3E716685775A5660
515C5B89977591B7B8A1A0A4A1A1A19B9DA3A0A4A1A1A1A1
A1A1A1A1A0A4A1A1
A1A1A1A0A4A0A49B9BA59AA0A39F9FA1A2A498432A422731
30383B3716221BF78C908896908F909190918D8B92869192
8B8884706A727A707985918E888F8D86868688837D757975
716959534F472B0918314248404E2D41355E6C727F873F5D
485E6FA2935A9EBF9EA39B9D9DA3A1A09DA5A1A1A1A1A1A1
A1A19BA3A1A1A1A1
9D9DA3A1A19BA3A0A2A4A0A29EA39AA5A1A1972F37342544
3A3B37111E1E2BFC91958F948F8F908F8F8F918F868B8B93
858476766B7B7B7785928E88888C8F828B868787787D7879
6E73605B4E483109272439353F3D483C3B6A6E6F879C3755
475C648B8E80C8B8A0A4A0A2A2A4A1A1A0A4A1A1A19BA3A1
A1A19AA0A3A1A1A1
A2A2A4A19BA1A4A1A1A1A19BA19EA19E9D9D9B2C35313544
343739191C21B0DA8E958E8F8F8F9996968D91908D8D8499
8D827773737B818088908E878B8B97878A868788777D7B76
6F6C6858494942110D2A2245473549473A5F7F7485A02F69
376B53A69B8AC1A4A1A1A1A1A1A1A1A1A1A1A1A1A1A0A4A1
A1A1A0A2A4A19BA3
9D9D9DA3A0A4A1A1A1A19B9BA0A1A49A9EA47325362C3F3E
37371D1614C9D698959C8C8F998D928E8E8B908F8F8F8998
908183777680817F868F8A9394879783948A8C8784867E7A
746E6D694E4846262135393D4E385142365E916E7E913F56
2D67569EA0A7B9A1A1A1A1A1A1A1A19BA3A19B9DA3A19BA3
9BA3A1A1A1A1A0A4
9EA49DA5A1A1A1A1A19BA1A29DA5A1A0A2A4272B361F4834
353A1B2F2AFD909396908B9999898F91988D8F8F8F918695
908D867373838383848B8E98898F938E89898C8A86867C7B
7376696D4E4B3F2E292F2E4141494C3F536F886B717D4D43
2D69718FB1B6A6A1A1A1A1A1A1A1A1A0A4A1A0A2A4A1A09E
A1A4A19BA3A1A1A1
9EA5A0A4A1A1A1A1A1A0A4A19AA5A1A19BA31C423127503A
3632272174E28E97908F99998B8D8F91928B99968D908F94
8F858472737B87828B8B918E88948F8684968B8A8487857E
72776C6C544A3C3622262E3C3A4F48464589786E6E78703D
4A61668BC7B1A1A1A1A1A1A1A1A1A1A1A1A19BA39BA3A1A0
A4A1A1A0A4A1A1A1
A2A49BA39BA3A1A19BA3A1A1A0A4A1A1A09E1B4D3533363D
3722343FDFB28D948F8F928E8B90908F8890928E8B919182
928D93757478858484878B8D8C8D9186948D82868588847C
7E756D6B614F46382D282F2E4248473A35AA6B63716C7F28
59566090CEA8A1A1A1A1A1A1A1A1A1A1A1A1A0A4A0A49BA3
A1A1A1A1A1A1A1A1
9DA3A0A49AA59BA39AA5A1A1A1A1A19BA3571B4634433C3E
292637C5D18695928F8F8F998D8F918883888C8A93918489
968F917B71767B7984758D8E86948C898E8283898788867D
8270756F5F58433C311D2F2D3C564140429B5F6E723E9F18
586B708BDAA5A1A1A1A1A1A1A1A1A1A1A1A1A1A19BA3A0A4
A1A1A1A1A1A1A1A1
A2A4A19BA1A49AA5A0A4A1A1A1A1A19AA528524A2F56303B
20393AE1917E9A8F998D8F938B898B74858889878F928490
948F917D6877717B7B82928B8D86817D8682848688888483
7580746E6759493C341B1E2F3A4B47414292656B7023AD20
496F809DD4A1A19BA3A1A1A1A1A1A1A1A1A1A1A19AA5A1A1
A1A1A1A1A1A1A1A1
A1A1A19AA5A1A09EA3A1A19B9D9D9DA1A40D793348453D35
1B5A9FC6748C9C8F928B8F8987838781747584878A8F7E88
958F91716C6C767475828D877F7C767676746D7876847F80
7B85706D62584946382C12282F4B444F398971506422CA2D
368689A9C2A1A1A0A4A1A1A19BA3A1A1A1A1A1A1A0A4A1A1
9BA3A1A1A1A1A1A1
A1A1A1A0A4A1A1A0A49BA39AA4A2A2A4AB116A2C45384616
3F43D45F6FA0998E8F8F89806F585774685E8478968E8389
9A90917A6F666C6C8D799374736A61535C6D686C738D8274
7677726D655A513C3732272928483C4C3D78644C5B31CA22
349775AFC69EA1A1A1A1A1A1A0A4A1A1A1A1A1A1A1A1A1A1
A0A4A1A1A1A1A1A1
9DA3A1A1A19BA39BA3A0A4A0A4A1A1A14E29522A3F33491C
55A8B3537DA68E908F836F49577B743C4458796068958584
9B90907C726374627F294E5B778E40315D5751525E807873
79796F7061594A443F323E1D214A3D464F6F6D4B5A32C625
53A579C6B89DA1A1A1A1A1A1A1A1A1A1A1A1A19BA3A1A1A1
A1A1A1A1A1A1A1A1
A2A4A1A1A1A0A4A0A4A1A19BA3A1A1A12C68483D22404B1F
23E5736D7FA5948B806E495397AD3434395C5C716595738B
9C90877F74696253645D39BBBC3B3A3F6F387E49486A7C71
7B776E6C69544B493532240A1C4D4430576B60405A42B01B
7E9477D7A9A1A1A1A1A1A1A1A1A1A1A19BA3A1A09EA3A1A1
A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A19BA3A1A0A4A1A1AB784B2C311E493E37
48F361657E988F816D563B2184842E8C09642C5A5D70879B
9A9088827978585C4B6A595A9E159F085C3094123B666C65
79726F5E65574C3D373715121D264331685456505F46A01B
857A92D4A1A1A1A1A1A1A1A1A1A1A1A1A0A4A1A1A0A4A1A1
A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1A0A4A1A1A1A1A1468332423732463D47
6ABA576B839990746451253F5728132C26653D6A768D989B
909288817D7A66615A554C5B731225163433332D446A635F
71706D5D5953393C413326192F3032365D554C455F4E9C28
7F7AC3BEA1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1
9BA3A1A1A1A1A1A1
A1A1A1A19BA3A1A19BA3A1A1A1A1A1227F56332E4A3E343D
79946170819A867F7C70555644353B42445A6A8B949D8F96
939388818586766C6D615C41594D5A4A333036616E71656E
797262665C4B39423B3A2F1D2F26263662604C4565659231
7681D2ACA1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1
A0A4A1A1A1A1A1A1
A1A1A1A1A0A4A1A1A0A4A1A19BA3A16C5741262E3A332959
7A7568637C998D8C9489838A88888B92989677828392978F
938F8F898A8673626E5F7770856867666C7D888C8B817E79
776D635E5E513A473A292A1D2D39332E606E4444716F8D35
7ABFD8A3A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1
A1A1A1A1A1A19BA3
A1A19BA3A19BA3A1A1A1A19BA1A4ABA30C3E1D2C2D50204B
5D716B5B80A57E92968E8E9490926B564D45479592A1978F
9A8D918D8A927870573F504D628E91928F8A89808380766D
6154695C554D4441383A201F222D1A3A4F5F4245796C9A39
82D3B49DA1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A0A4
A1A1A0A4A1A0A4A1A1A1A1A0A4A193AE003C1F2F39462D57
5763645D78A37E848B948E90854643414E83A0B49599988E
9A8991908F8D85826C543D3A465B7E7B8987897A84746E5C
496C64584C484A3D272B1B27211E404C55614D3D79628B4E
7BE4A9A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1A1A1A19BA3AB53CD043334392544344B
45455D5F77A48E536B72645A403F79A8A8B3AB9C97999893
8F8B908F918D8B8A898476786651444F46525C56554A4E57
6470635F4C484D364D1635352C202150535A48427A755E41
ADDBA1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A19BA3A1A1A1A1
A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1A1A1A19AA5A4414E12344C3D323C3442
44485A5987A1917B926F65607EADB9AF9996989494949496
898F9996978E8F90928A8385868B90A069565555536C736B
6F72675D4A4D56342B2D312512131B5F55405A497F743C65
E5BBA1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A0A49BA3A1A1
A1A1A1A1A1A1A1A1
A1A1A1A19BA3A1A19BA3A1A0A4A15C32353567473C3E3548
44495C5688A08B8C898C9699A5A09B949494949494969495
899999948B8C8F8F908F878B8F858788748693888087776C
78645B524C5655452F2D1A1313151C93433D8E4166863685
EDA9A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A0A4A1A1
A1A1A1A1A1A1A1A1
A1A19BA3A0A4A19BA1A4A1A1A1A1551A3641784337423E45
4144614E89A08F8D8C96908E99968F8F9694948D96959494
8B91978B8B998D9190918E868F8287857C8D7879736F706A
705D665E4C55533B4A2D1D211B291EA5483D88414E9832AD
EB9EA1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1
A1A1A0A4A1A1A1A0A4A1A1A1A1A1671A50495D3D47483F3D
3C3C574F739C8E8C8B8E92909197928F9A94949398949494
93969992968F8B908A8B8B888F82868487827B7C73757271
6D6B68504C5C4E47331E2B2613161AA84A449046408436FB
C39DA1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1
A1A1A1A1A19BA3A1A1A1A1A1A1A190183E3B3E434839403B
423D665D769B86908C8E95908E9297939894948D8F969494
94948B8E8E8B8F858C8D8D898484877A827D827A72787072
5F685A5C555447372E25361713152B77745788484A4D81FE
A4A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A19BA3A1A1A1
A1A1A1A1A1A1A1A1
A1A1A1A1A1A0A4A1A1A1A1A1A1A1A90B4C3B4A4F4E434140
3D495C6B708B88968D9493909098998D8F96948B98988B97
9494898F8F91908E948B8D88848787777E7D7D7B76776F72
68685B5B5A53483C27361B171A15226D7C4176575640D0D2
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A0A4A1A1A1
A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1AE143840534E3E46393F
504957696D818E8F908F8B92909296938D9396938F8F9491
8D8E8D8F9191908A92888D838E8586838082837C74766F72
5F665B5A5D44493D2F2D18140E0E4C5A614A82647F5FFFB4
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1AE0B565D404741433E4C
3049606D6580908E908D93939098988B9497988D948F9095
8E8F90908F8F918F938F82878E82877A88797D7275776F72
5C735A5B4B443D303B21120D200E635252447E6474A5DAA1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1
A1A19BA39BA3A1A1A1A1A1A1A1A1A4565237383D3C3B413D
434E616B7281908E8F95938F919A948B9B8D968B908D9791
8B8F919190908F919084898F858587778F757E7378787670
64745251494F493A2A2112152213704F5345826F7BDEAEA1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1
A1A1A0A4A0A4A1A1A1A1A1A1A1A1A1A318363D343E3A3540
4C4F6B697A7F8F8E928A938E91928F8D90959893968D9195
8E90919090909091848A8F8D819085838C7C7C7377707A6E
7062535C53413F252118190D1B14804A48448B869BD4A1A1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A43C383B3C3F3D3D3C
3F535F6777848D8E938B978E90988D98969994948B948F91
958D918F9190909087958B878888848687767B7477767270
63635C52524A3E2225181F121D1B845F3B5A8097C7B69BA3
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1
A19BA3A1A1A1A1A1A1A1A1A1A1A1A1A1892330353B3A3E3F
3A5668717F83948C8A8C8F9190938C93968D968B8D938B90
918B9190918F9190888E868C898487877E7D827A75786F6C
6A5C5E4E4E413622251C1B21231471653F7188A9C8A1A0A4
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1
A1A0A4A1A1A1A1A1A1A1A1A1A1A1A1A1A01E4338453F3A41
41555774858D8A8A918F9493908F8F989889938C8F8F8F90
90908F919090918A8A8D888B838587887C817A7674787073
64585C4C483C31242A1F1A23140D705645728EC5B8A1A1A1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A185704B4E4D4D3E
3F53636E7A8A8C8C898F8B8C908F8F928F8C8F988E8F9190
919089938A8B8B8A93868D838486877B7F8079747F6E7072
555D505240372D35242519150B2F8F4F567D87D7A0A3A1A1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1
A19BA3A1A1A1A1A1A1A1A19BA3A1A1A1A1AE908B3A4B3D44
464B5C717586938887938C94938A908F919090938D908F91
90908F93888D8D938D8088838786887D7D7D7C7B78647560
5E604B3E363F2D29271D200F0C7F6D3E6170AAD2A0A4A1A1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1
A1A0A4A1A1A1A1A1A1A1A1A0A4A1A1A1A1A49FA235314339
4947606E77858D7D8B898F8A898B8E9291908A9290908993
878C8A8C8A8D898683848786888687797A7E7E75756D6F70
5B4F434140423E21261F140D847349417592CAB99B9DA3A1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1AE5A13475C
3E5F5D6C76848A888E868A8E8D958B8C928A909390908F8D
89948B848F848E838786888787867D7F7A7D7674745C6F67
51504B4B3D333A4B1614184B525847567DA0C6AA9AAEA1A1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1AE51254041
3F66566C7A847D878B86888D8597858D8F8A8E8B8B8B9283
888683847C878883878687888687757D7B7576776F5B6956
4A4B423D3D3A3F282D293D3B6459606A8E93CBAE9DA69DA1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1AE4159233E
414653666F71828485887B8F8991878785898E8D93838D80
87857A7B78828A87807C837B7B7B6E7A776D726A5E605F58
4D5648343A3335293622764B604986699DC5BEA497A3A1AB
9EA1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1AB9EA1A1A1A1A1
A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A46D850E36
563B5B63677F837A81817B908785878B8588888787808985
7F797278797F83747576796D777A6B7B6E6F686C6059595B
504F3B3B3F39513D36507E465C688E898FC7A3A1A0AE9EA4
9DA1A1A1A1A1A1A1A1A1A19BA3A1A1A1A1A49DA1A1A1A1A1
A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A19A532C41
494A4B5559737A89787C7F808C878889827E8080807A7473
73746C716A6D6B686E6B6B6962676268635B5C685B585747
404F473B504D35474E5557466E608F8EB3BFA4A1A1A49DA1
A1A1A1A1A1A1A1A1A1A1A1A0A4A1A1A1A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1895B40
3F4B4C5E645A676A7A7E878B8B7E80807E70766D78836A73
71725D6C596A5D73536B5061505763595B595D546268555D
545C4143585A372B406363596F809085CBA5A1A1A1A1A19B
A3A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1AB9EA1A1A1A1A1
A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A18B8F
4D503C58593E6F74948F8C8A7E7F77766C70717075756A73
60655862566558525761454C5F4C644953565453434B4955
4A504A523A41454B5C63566E908A67CBBEA1A19BA3A1A1A0
A4A1A1A1A1A1A1A1A1A1A1A1A19BA3A1A1A49DA1A1A1A1A1
A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A19BA39BA3A1A1A1A1A1A1A1A1A1A1A1A19D
2E4F53586679886E896F787F7B75736F6F755E6C7568636C
5E5E585D49714F6B5F5362534F6D565C57575C61394F5B57
45515943494952465465878B7F7592DAA1A1A1A9A1A1A1A1
A1A1A1A1A1A1A1A1A1A1A1A1A1A0A4A1A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1
A1A19BA3A1A1A1A0A4A0A4A1A1A1A1A1A1A1A1A1A1A1A1A1
89355F4D4C63605B737C8179726D77646A6B566A5F635C6A
56684E4D5448595961485B50547B37544C635548433F3F31
364A3A373F3C4B58778AA3617851DCB4A1A1A1A49DA1A1A1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1
A1A1A0A4A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1
A47D5950567F73768A857D7A63696B66646E6069585E685B
4E583B5F5E3C345D3C5F5756573F435E2A36473C3F3F4B47
534B463B4D50956D8C8F36685698F39EA1A1A1A1A1A19BA3
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1
A1A43C4F3D59465C7D7C787C6562655D65685C565B63555A
5B3F7159406D3C48564A414B3C3C3D2F353F52383F4B433A
38425562677B7889854E3E874EF5B89DA1A19BA3A19BA1A4
A1A1A1A1A1A1A1A1A1A1A1A19BA3A1AB9EA1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1
A1A1931F547F5162727E7B7069485E566D67584A635E5069
5259414C4A4C4E3B4D423F473C393C3B4134323B403E3A3B
49625D5A547C804F4B4C7C6EB7DB9DA3A19BA1A49BA1A4AB
9EA1A1A1AB9EA1A1A1A1A1A1A0A4A1A49DA1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1
A1A1A46C4C316C707368887971426951595D4E48635A495B
485A33644A49392E64343E423D3A35352A273334323E533F
4B68776999896A4A467E47C5DFAF9AA5A1A0A4A1A0A4A1A4
9DA1A1A1A49DA1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1
A1A19BA3843A34555C658F826C404A6A5369665B4A5F5143
595A3C5B554E45203E3862393C283F302A252C25253B4961
7566728267334D59545174FEAB9F9BA4A19BA3AB9EA1A1A1
A1A1A1A1A1A1A19BA3A1A1A1A1A1A1A1A1AB9EA1A1A1A1A1
A1A1A1A1A1A1A1A1
A1A1A1A1A19BA3A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1
A1A1A0A4A4552E454769777879444461604C4D534048524A
4D4A555244584E414E3539403C3A4A39543B404756626173
7894607443265B626963F0CAA1A1A1A1AB9D9EA59DA1A1A1
AB9EA1A1A1A1A1A0A4AB9EA1A1A1A1A1A1A49DA1A1A1A1A1
A1A1A1A1A1A1A1A1
A1A1A1A1A1A0A4A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1
A1A1A1A1A1955649504944615E79354D5A594C4C393C4046
444E544043615B4C4F38623C3A574F454D4A5D687E656D92
6B704A5E2F4E725F58E7D2ABA89E9BAD9BA89D9EA3AB9EA1
A49DA1A1A1A1A1A1A1A49DA1A1A1AB9EA1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1
A1A1AB9EA1A19051444F5468627D5D434D6356475F374243
514E533561546A5062674D39435C5063626B69837E6D4F57
4A38283B5366576DE2E19DA4A9A49DA6A5A49DA0A4A49DA1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A49DA1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1
A1A19E9EA19BA38B613953686B74756947663F5D51504D3A
3D324A37614D785DA496746C8D837C819A947A87523E4B48
3C384570785455F7D39DAB9EA49F9DA1A49D9BA3A1ABA89E
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1
A1A1A0A4A1A0AE9E8E8C4F513D678A7D67595F635D586C79
523655375C708568658B797A9396917E6A5B59533F484E32
3A565C7B5365DAE39D9BA59D9B9DA3A1A19BA1A4A1A49F9D
9BA3A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1
A1A1A1A1A1A1AE9AA19F8B3C3D6B697B8F647D8A779A8E73
9299CCA9AFA49A7C909B868692744B6C4C4C52503E4A395A
69655E5BDFC1D5AB99A1A4A1A09DA5A1A1A09EA3A1AB9EA1
9AA5A19BA3AB9EA1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1AB9EA1A1
A1A1A1A1A1A1AE9AA1A1A47799395074787D929E85978585
A5818A837C9197898C8B706187575C763C54414954627480
63577FD0E497A39E9DA4A1A1A1A0A49BA3A1A0A4A1A49DA1
A0A4A1A0A4A49DA1A1A1A1A1A1A1AB9EA1AB9E9BA3A1A1A1
A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A49DA1A1
A1A1A1A1AB9EAEA49EAB9EA1A36F5161638C7B827F8A9390
938AA3958D949882837B7A5960644A5242683A6C7A747159
6DB1CDCAA19AA5A0A4AB9EAB9EA19BA1A4A1A1A1A1A1A1A1
AB9EA1A1A1A1A1A1AB9EA1A1A1ABA19DA1A4A69DA4A1A1A1
A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1
A1A1A1A1A49DA49F9DA49D9BA5A283BA595656898E98938D
8881977F80786B5B5A6C7458574351745C8B71937C577DC0
C1C7AEA1A1A0AE9EA1A49D9E9EA1A9A1AB9EA1A19BA3AB9E
A49DA1A1AB9EA1A1A49DA1A1A1A49DA1ABA8AB94A3A1A1A1
A1A1AB9EA1A1A1A1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1AB9EA1A1A1
A1A1A1A1A1A1A1A1A19BAD9DA4AE9AA184AEBF686380767D
958E958C8F8E757F6C76627E935E9D9E7F6F5F8EACB6CCCE
A1A1A1AB9EA1A49DA1AB9EA0A4A1A49D9E9EA1A1A0A4A49D
AB9EABA8ABA4A89EA1A1A1A1AB9EA1A1AEA69DA5A1A1A1A1
A1A1A49DA1A1A1A1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A19BA59DA1A1A1
A1A1A1A1A1A1A1A1A1A0A69DA1A49DA1AB9EAB84B26E6C89
6E808B87978D98AA979389A6917C72667A89ACC8BAB6A697
9EA1A1A49DA1A19BA3A497A3A1A19BA3A0A4A1A1A1A19BA3
A49DA49F9F9F9A9EAB99A3A1A49DA19BA59F9DA497A3A1A1
A1A1A1A1A1A1A1A1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A0AE9EA1A1A1
A1A1A1A1A1A1A1A1A1A1A1A1A19BA3A1AE949F9EA18BA9B6
A2A9A693AD96837775838586818B9AAEBEB7B2A9A1AEA698
AEA8A89EA1A1A1A09E9DA1A4A1A1A0A49BA3AB99A3A1A0AE
9EA1A1A1A1A1A0A4A4A5A1AB9EA1A1A0A4A1A1A1A9A1A1A1
A1A1A1A1AB9EA1A1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A497A3A1A1
A1A1A1A1A1A1A1A1AB99A3A1A1A09EA3A49BA2A4A1A1A0A2
AC9DA4A1ACA097A2A9ADB6A6ABADB1A7A4ABA89EA1A4A99A
A49F9F97A3AB9EA1A9A0A4A1AB9EAB9EA9A19E9DA49BA3A4
9DA1A1A1A1A1A1A1A19E9EA4A69EA1A1A1AB9EA1A49DA1A1
A1A1A1A1A49DA1A1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A0A4A1A1
A1A1A1A1A1A1A1A1A49BA4A1A19BA1A49BAD9EA1A19BA39B
A59DAB99A3A1A0A2A2A2B09AA19BA3A1A1A49F9DAB9EAE9A
A1A19BABA1AEA49EA49DA1A1A49DA49DAE949BA59BA1A4A1
A1A1A1A1A1AB9EA1A1A0A4A1AE9AA1A19BA5A6A89EA1A1A1
A1A1A1A1AB9E9BA3
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1AB9EA1
A1A1A1A1A1A1A1A1A1A1A1A1A1A0A4ABA7A49DA19BA1A4A9
A1A1A4A5A1A1AB9EA1A19E9EA1A0A4A1A19BA3ABA19DAEA4
9EA1A0A19EA49A9EAB9EA1A1A1AB9EA1A49BA2A4A0A4A1AB
99A3A1A1A1AE9AA1AB9EA19BA59DA1A1A0A49EAB9AA1A1A1
A1A1A1A1A49DA9A1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1AB9EA19BA59D9B
A3A1A1A1A1A1A1A1A1A1A19BAD9EA1A49A9EA1A1A09EAD9B
9EA1A1AE9AA1A4A69E9BA1A49BA3A1A1A1A0A4A49DA1A4A9
9AA19BA1AE9EA0A49EA8A89EA19EA89EA1A1A1AB9EA1A1AE
98A4A1AB9EA4A69EA4A6A89DA4AB9EA1A19BA1A69DA1A1A1
A1A1AB9EA1A1A49D
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A49DA1A0A4AB9D
A4A1A1A1A1A1A1A1A1A1A1A0A69DA1A1A0A4A1A1A19AA89B
A4AB99A5A69EA1A49DA9A1AB9DA4A1A1A1A19BA3AB9EA1A4
9DA1A0A4A49DA1A1A0A69A9EA1A0A69DA19BAD9BA89EA1AE
9AA19BA59DA1A49DA1A49F9DA1A49D9BA3A0A4A1A1A1A1A1
A19BAF9AA1A1A1A1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1AB9EA49D
A1A1A1A1A1A1A1A1A1A19BA3A1A1A1A1A1A1A1A1A19AA0A3
A1A49B9EAFA49EA1AB9B9EA49DA1A1AB9E9B9BA5A4A699A3
AB9EAB9EA1AB9EAB9EA1A0A4A1AB9EA1A1A0A695A8A69EA4
9DAB9DA4A1AB9EAB9EA1AB99A3A1A1A0A4AB9EA1AB9EA1A1
A1A0A69DA1A19B9D
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A49DAB9E
A1A1A1A1A1A1A1A1A1A1A0AE9EA19BA39BA3A1A1A1A0A2AE
9EA1A1A0A69F9D9BAF98A4A1A1A1A1A49DA0A2A49BA5A5A1
AE9AA49D9BAF94AF9AA1A19BA3A49DA1A1A1A1A0AE9B98A3
A1A497A3A1A49DAE9AA1A49BA4A1A1AB9EA49DA1A49DA1A1
A1A1A1A19BA3A9A0
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A497
A3A1A1A1A1A1A1A19BAD9EA497A3A09E9BA5A1A1ABA89EA4
9D9BA3A1A1A19BA1A6A69E9BAD9EA1A1A1A1AB9EA9A19EA8
A197A39BA1A6A5A49D9BA3A0AE99AD9E9BA39BADA1A5A0A4
A19BA1A4A1A1A1A49DA1A1A1A1A1A1A49D9BA3A1A1A1A1A1
A1A1A1A1A0A4A49D
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A0
A4A1A1A1A1A1A1A1A0A69DA1A9A1AB9D9DAFA89E9EAB9AA1
A1A0A4A1A1A1A9AB9EA49DA0B09AA1A1A1A1A4A6A19DA0A6
9DA9ABA7AB9EA49DA19AA5ABA19BA6A6A7ABA7A49DA49DA1
A1A9AB9EA1A1A19BA3A1A1A1A1A1AB9EA1A0A4AB9EA1A1A1
AB9EAB9EA1AB9EA1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1AB9EAB9EA19B
A39BA3A1A1A1A1AB9EA1A1A1A49D9E9E9AA89A9EA0A69DA1
A1A19BA3A1A1A49F9DAB9EA1A49DAB99A3ABA8A19DA1A1A1
A1A49F9F9F9DAB9EA1A0A4A497A3A1A49F9F9FA69EAB9EA1
9BA5A99AA1A1AB9DA4A1A1A1A1A1A497A39BA3A49DA1A1A1
A49DA49DA1A49DA1
A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1AE9AA4A69EA0
A4A0A4A1A1A1A1A49DA1A1A19BA3A0A4A0A4A0AE9EAB9EA1
A1A1A0A4A1A1A1A1ABAB9AA1A19BA59BAEAB9D9DA1A1A1A1
A1A1A1A1A1ABABA49EA1A1A1A0A4A1A1A1A1A1AEA4AB9AA1
A0A4A49DA1A1A49DA1A1A1A1A1AB9E9AA59AA5A1AB9EA1AB
99A3A1A1A1A1A1A1
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[40]:=",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`004`3oool209bLW080WIfM0P2WYjL20:6QX@80UYJF
0P2MWId209VIV@80Vi^K00<0ZJVY09BDU02DU9@00P2OWil207IfMP@0Rh^;0P2<S8`209BDU080QhN7
202<S8`20;Bd]080U9BD0P0c<c<00`2_[jl0TY:B09:BTP0207moO`80QXJ60P1mOGd208b<S080QhN7
0P1kNg/208f=S@80R8R80P26QXH208R8R080O7al0P22PX8208b<S080QhN700<0Shn?08Z:RP2:RXX0
0P24Q8@208N7Q`80QXJ61027QhL208R8R080MgMg0P2@T90408N7Q`80Ti>C2`2=SHd208R8R080Shn?
0P21PH4208N7Q`80S8b<0P2@T9020861P@P0QhN70P26QXH508N7Q`80R8R80P27QhL208B4Q080RHV9
0P27QhL208J6QP80R8R80P27QhL208J6QP80YZJV0P2XZ:P208Z:RP80@T920P2MWId00`22PX80S8b<
08b<S00208N7Q`80O7al1022PX8208Z:RPX0QXJ60P2ATI4208Z:RP80QHF50P2=SHd00`2GUiL0R8R8
08R8R00209FEU@@0T92@0P26QXH209JFUP80QHF50P21PH4208F5Q@80N7Qh0P1oOgl208F5Q@80PX:2
0P20P80207emO@030:b/[02BTY80TY:B0080GEeM0P2OWil20:ZZZP80YZJV0P2UYJD209JFUQD0oooo
000C0?ooo`80W9bL0P2MWId20:NWY`80XJ6Q0P2FUYH209fMW@80VIVI0P2KVi/00`2YZJT0U9BD09BD
U00209nOW`80MWIf102;Rh/208b<S080U9BD0P27QhL808b<S080];Bd0P2DU9@203<c<`030:n_[`2B
TY80TY:B0080Ogmo0P26QXH207emO@80S8b<0P27QhL207]kN`80SHf=0P28R8P208J6QP80R8R80P1l
O7`208:2PP80S8b<0P27QhL00`2?Shl0RXZ:08Z:RP0208B4Q080QhN70P26QXH408N7Q`80R8R80P1g
MgL2092@T0@0QhN70P2CTi<;08f=S@80R8R80P2?Shl20861P@80QhN70P2<S8`2092@T080PH612027
QhL208J6QPD0QhN70P28R8P208N7Q`80Q8B40P29RHT208N7Q`80QXJ60P28R8P208N7Q`80QXJ60P2V
YZH20:RXZ080RXZ:0P12@T8209fMW@0308:2PP2<S8`0S8b<0080QhN70P1lO7`408:2PP80RXZ:2P26
QXH2096AT@80RXZ:0P25QHD208f=S@0309NGU`28R8P0R8R80080UIFE102@T90208J6QP80UYJF0P25
QHD20861P@80QHF50P1hN7P207moO`80QHF50P22PX820820P080OGem00<0[:b/09:BTP2BTY800P1M
GEd209nOW`80ZZZZ0P2VYZH20:FUY@80UYJF5@3oool001<0oooo0P2LW9`40:2PX080V9RH0P2JVYX2
0:FUY@80XZ:R0P2KVi/00`2PX:00XJ6Q0:6QX@0209bLW080TI6A0P25QHD408b<S080SHf=0P29RHT4
08b<S0@0Rh^;0P2BTY8209fMW@80B4Q800<0Zj^[096AT@2ATI400P20P80208F5Q@80Q8B40P22PX82
0820P080OWin0P26QXH208V9R@@0QhN70P25QHD208R8R080Ph>30P29RHT00`2?Shl0QHF508F5Q@02
08F5Q@@0QXJ60P1kNg/208>3P`80RHV91023Ph<208V9R@@0R8R80P26QXH208^;R`80R8R800<0QHF5
08J6QP26QXH00P2?Shl208>3P`80QhN70P2=SHd208F5Q@@0R8R80P24Q8@208N7Q`80Rh^;0P26QXH2
08N7Q`80QXJ60P27QhL00`28R8P0QhN708N7Q`0208R8R0@0QhN70P26QXH207inOP80RHV90P28R8P2
08J6QP80QhN70P2<S8`209nOW`80WIfM0P1@D50206UYJ@0309JFUP2:RXX0RXZ:0080QhN70P1lO7`4
08:2PP80Ph>30P20P80208V9R@H0R8R80P2?Shl208F5Q@80S8b<0P27QhL00`2?Shl0R8R808R8R002
08f=S@@0RXZ:0P2@T90208b<S080R8R80P20P80208J6QP80Ph>30P28R8P408:2PP80R8R80P2WYjL0
0`2[Zj/0LW9b079bLP02071`L080S8b<0P2^[Zh20:JVYP80WIfM0P2IVITE0?ooo`004`3oool209bL
W0@0X:2P0P2HV9P209ZJVP80YJFU0P2RXZ8209^KV`030:2PX02QXJ40XJ6Q0080W9bL0P2ATI4208F5
Q@@0S8b<0P2=SHd208V9R@@0S8b<102;Rh/209:BTP80WIfM0P18B4P00`2[Zj/0TI6A096AT@020820
P080QHF50P24Q8@208:2PP80P8200P1nOWh208J6QP80RHV91027QhL208F5Q@80R8R80P23Ph<208V9
R@0308n?S`25QHD0QHF50080QHF51026QXH207]kN`80Ph>30P29RHT408>3P`80RHV91028R8P208J6
QP80Rh^;0P28R8P00`25QHD0QXJ608J6QP0208n?S`80Ph>30P27QhL208f=S@80QHF51028R8P208B4
Q080QhN70P2;Rh/208J6QP80QhN70P26QXH208N7Q`0308R8R027QhL0QhN70080R8R81027QhL208J6
QP80OWin0P29RHT208R8R080QXJ60P27QhL208b<S080WinO0P2MWId2051@D080JFUY00<0UYJF08Z:
RP2:RXX00P27QhL207alO0@0PX:20P23Ph<20820P080RHV91P28R8P208n?S`80QHF50P2<S8`208N7
Q`0308n?S`28R8P0R8R80080SHf=102:RXX2092@T080S8b<0P28R8P20820P080QXJ60P23Ph<208R8
R0@0PX:20P28R8P20:NWY`030:^[Z`1bLW80LW9b0080L71`0P2<S8`20:j^[P80YZJV0P2MWId209VI
VAD0oooo000C0?ooo`80Vi^K0P2LW9`209ZJVP80W9bL0P2MWId209jNWP80Vi^K0P2IVIT00`2LW9`0
WinO09nOW`020:6QX@80XZ:R0P2FUYH208B4Q0H0Rh^;0P28R8P408^;R`80QXJ60P2<S8`20:BTY080
RHV900<0BTY:09RHV02HV9P00P26QXH208F5Q@80Ogmo0P1iNGT208>3P`80RXZ:0P29RHT208Z:RP80
R8R80P26QXH208R8R080QXJ60P1mOGd20820P00309:BTP29RHT0RHV900@0QXJ60P20P80207inOP@0
PX:20P1jNWX207UiN@80Ogmo0P23Ph<408R8R080RHV90P2;Rh/00`24Q8@0QhN708N7Q`0208V9R@80
Q8B40P26QXH208Z:RP80Q8B40P2>SXh208n?S`80SXj>0P2:RXX208^;R`80SXj>0P25QHD408N7Q`03
08R8R027QhL0QhN700H0QhN71026QXH208^;R`@0QhN70P28R8P208N7Q`80S8b<0P2>SXh209:BTP80
U9BD00<0FEUI08f=S@2=SHd00P20P80207inOP80RXZ:0P27QhL20820P080PX:20P2<S8`207inOP80
P8200P2:RXX208n?S`80RHV90P2>SXh208R8R00308j>SP2;Rh/0Rh^;0080S8b<1P2BTY8208J6QP80
RHV90P23Ph<208F5Q@80R8R80P25QHD208B4Q080SXj>0P2FUYH209RHV00309bLW01lO7`0O7al0080
O7al0P23Ph<20:VYZ@@0Y:BT0P2KVi/E0?ooo`004`3oool209^KV`80W9bL0P2JVYX209bLW080WIfM
0P2NWYh209^KV`80VIVI00<0W9bL09nOW`2OWil00P2QXJ420::RXP80UYJF0P24Q8@608^;R`80R8R8
102;Rh/208J6QP80S8b<0P2TY:@208V9R@0304Y:BP2HV9P0V9RH0080QXJ60P25QHD207moO`80NGUi
0P23Ph<208Z:RP80RHV90P2:RXX208R8R080QXJ60P28R8P208J6QP80OGem0P20P8000`2BTY80RHV9
08V9R@0408J6QP80P8200P1nOWh408:2PP80NWYj0P1iNGT207moO`80Ph>31028R8P208V9R@80Rh^;
00<0Q8B408N7Q`27QhL00P29RHT208B4Q080QXJ60P2:RXX208B4Q080SXj>0P2?Shl208j>SP80RXZ:
0P2;Rh/208j>SP80QHF51027QhL00`28R8P0QhN708N7Q`0608N7Q`@0QXJ60P2;Rh/408N7Q`80R8R8
0P27QhL208b<S080SXj>0P2BTY8209BDU00305UIF@2=SHd0SHf=0080P8200P1nOWh208Z:RP80QhN7
0P20P80208:2PP80S8b<0P1nOWh20820P080RXZ:0P2?Shl208V9R@80SXj>0P28R8P00`2>SXh0Rh^;
08^;R`0208b<S0H0TY:B0P26QXH208V9R@80Ph>30P25QHD208R8R080QHF50P24Q8@208j>SP80UYJF
0P2HV9P00`2LW9`0O7al07alO00207alO080Ph>30P2YZJT40:BTY080Vi^K5@3oool001<0oooo102M
WId20:2PX080YZJV0P2JVYX20:FUY@80Xj>S0P2HV9P00`2UYJD0Xj>S0:>SX`0209fMW@80Vi^K0P2J
VYX2096AT@80XJ6Q0P2=SHd208>3P`80S8b<1026QXH208F5Q@80R8R80P2:RXX20:FUY@0306a/K029
RHT0RHV90080S8b<0P25QHD208B4Q080OWin1024Q8@40820P080RHV90P27QhL208R8R080QXJ60P1l
O7`20861P@0308n?S`27QhL0QhN70080QHF50P27QhL207inOP80RXZ:0P1nOWh207alO080PH610P22
PX8207emO@80Ogmo0P25QHD208V9R@80QhN70P29RHT00`25QHD0QXJ608J6QP0208R8R0@0QXJ60P27
QhL208f=S@80UiNG0P2<S8`208f=S@80S8b<0P2CTi<208f=S@@0RXZ:0P2?Shl00`2>SXh0QHF508F5
Q@0208N7Q`H0R8R80P27QhL408R8R0P0QhN70P29RHT209FEU@80XJ6Q00<0NGUi06ATI01TI6@00P2G
UiL208V9R@80Rh^;0P27QhL208J6QP80SXj>0P2:RXX208F5Q@80RXZ:0P2;Rh/208j>SP80QHF50P2=
SHd208F5Q@0308f=S@2<S8`0S8b<0080U9BD0P2BTY82092@T080R8R80P2?Shl208>3P`80QXJ60P24
Q8@208n?S`80Ph>30P2WYjL208n?S`80TI6A0P2OWil00`1hN7P0Ti>C09>CT`0207UiN@80Ogmo0P2b
/[8209nOW`80VYZJ0P2LW9`E0?ooo`004`3oool409fMW@80X:2P0P2VYZH209ZJVP80YJFU0P2SXj<2
09RHV0030:FUY@2SXj<0Xj>S0080WIfM0P2KVi/209ZJVP80TI6A0P2QXJ4208f=S@80Ph>30P2<S8`4
08J6QP80QHF50P28R8P208Z:RP80YJFU00<0K6a/08V9R@29RHT00P2<S8`208F5Q@80Q8B40P1nOWh4
08B4Q0@0P8200P29RHT208N7Q`80R8R80P26QXH207alO080PH6100<0Shn?08N7Q`27QhL00P25QHD2
08N7Q`80OWin0P2:RXX207inOP80O7al0P21PH4208:2PP80OGem0P1oOgl208F5Q@80RHV90P27QhL2
08V9R@0308F5Q@26QXH0QXJ60080R8R81026QXH208N7Q`80SHf=0P2GUiL208b<S080SHf=0P2<S8`2
09>CT`80SHf=102:RXX208n?S`0308j>SP25QHD0QHF50080QhN71P28R8P208N7Q`@0R8R82027QhL2
08V9R@80UIFE0P2QXJ400`1iNGT0I6AT06ATI00209NGU`80RHV90P2;Rh/208N7Q`80QXJ60P2>SXh2
08Z:RP80QHF50P2:RXX208^;R`80SXj>0P25QHD208f=S@80QHF500<0SHf=08b<S02<S8`00P2DU9@2
09:BTP80T92@0P28R8P208n?S`80Ph>30P26QXH208B4Q080Shn?0P23Ph<20:NWY`80Shn?0P2ATI42
09nOW`0307QhN02CTi<0Ti>C0080NGUi0P1oOgl20;:b/P80WinO0P2JVYX209bLW1D0oooo000C0?oo
o`80W9bL0P2OWil209bLW0@0X:2P0P2OWil209fMW@80UiNG00<0Z:RX0:6QX@2QXJ400P2OWil20::R
XP80Vi^K0P2TY:@209^KV`80V9RH0P27QhL208^;R`80S8b<0P25QHD208f=S@80QXJ60P2@T9020:j^
[P0309BDU01OGel0GemO0080UiNG0P29RHT208b<S080Ng]k1022PX8208Z:RP80P8200P24Q8@208V9
R@@0QhN70P24Q8@208R8R00308^;R`27QhL0QhN70080P8200P21PH4207moO`80Rh^;0P24Q8@208N7
Q`80Rh^;0P28R8P20820P080O7al0P25QHD208B4Q080RHV90P1kNg/307emO@80RXZ:1P27QhL408V9
R@80S8b<0P24Q8@208J6QP80UiNG0P2?Shl208>3P`80SXj>0P29RHT00`2>SXh0QHF508F5Q@0208J6
QP80SXj>0P2<S8`208N7Q`80R8R80P2>SXh408b<S080QXJ60P2>SXh208J6QP80QhN70P29RHT209FE
U@030:6QX@1BDU80DU9B0080SXj>0P2<S8`208f=S@@0Rh^;0P27QhL208F5Q@80QhN70P2=SHd408b<
S080RXZ:0P2@T90208V9R@0308f=S@2>SXh0SXj>0080UIFE0P2>SXh208n?S`80SXj>0P2<S8`208N7
Q`80SHf=0P23Ph<209RHV0@0YJFU0P2BTY8209ZJVP80YjNW00<0MGEe0:VYZ@2YZJT00P1_Kfl207in
OP80][Jf0P2YZJT209bLW080WYjN5@3oool001<0oooo0P2LW9`209nOW`80W9bL102PX:0209nOW`80
WIfM0P2GUiL00`2XZ:P0XJ6Q0:6QX@0209nOW`80XZ:R0P2KVi/20:BTY080Vi^K0P2HV9P208N7Q`80
Rh^;0P2<S8`208F5Q@80SHf=0P26QXH2092@T080[Zj^00<0U9BD05mOG`1OGel00P2GUiL208V9R@80
S8b<0P1kNg/408:2PP80RXZ:0P20P80208B4Q080RHV91027QhL208B4Q080R8R800<0Rh^;08N7Q`27
QhL00P20P8020861P@80Ogmo0P2;Rh/208B4Q080QhN70P2;Rh/208R8R080P8200P1lO7`208F5Q@80
Q8B40P29RHT207]kN`<0OGem0P2:RXX608N7Q`@0RHV90P2<S8`208B4Q080QXJ60P2GUiL208n?S`80
Ph>30P2>SXh208V9R@0308j>SP25QHD0QHF50080QXJ60P2>SXh208b<S080QhN70P28R8P208j>SP@0
S8b<0P26QXH208j>SP80QXJ60P27QhL208V9R@80UIFE00<0XJ6Q059BDP1BDU800P2>SXh208b<S080
SHf=102;Rh/208N7Q`80QHF50P27QhL208f=S@@0S8b<0P2:RXX2092@T080RHV900<0SHf=08j>SP2>
SXh00P2EUID208j>SP80Shn?0P2>SXh208b<S080QhN70P2=SHd208>3P`80V9RH102UYJD209:BTP80
VYZJ0P2WYjL00`1eMGD0ZJVY0:VYZ@0206m_K`80OWin0P2f][H20:VYZ@80W9bL0P2NWYhE0?ooo`00
4`3oool209bLW080X:2P0P2HV9P20:6QX@80WIfM0P2JVYX209nOW`80Xj>S00<0VYZJ09jNWP2NWYh0
0P2MWId209RHV080XZ:R0P2UYJD209VIV@80YJFU0P2GUiL208b<S080R8R80P2;Rh/208f=S@80RXZ:
0P2>SXh2096AT@030:2PX027QhL0QhN70080Rh^;0P2>SXh208f=S@80P8200P27QhL20820P080Q8B4
1027QhL208b<S080QhN70P1nOWh20820P080RHV900<0OWin07YjNP1jNWX00P22PX8208>3P`80P820
0P2<S8`408N7Q`80R8R81026QXH208N7Q`80OWin0P1mOGd207moO`80P82000<0O7al08f=S@2=SHd0
0P23Ph<208V9R@80R8R81P27QhL208V9R@80QhN70P2@T90209:BTP80PX:20P28R8P208j>SP80RHV9
00<0SHf=08b<S02<S8`00P2:RXX2092@T080RXZ:0P2;Rh/208b<S080R8R80P2<S8`208J6QP80QHF5
0P2:RXX208B4Q080SHf=0P26QXH208V9R@0309FEU@2CTi<0Ti>C0080Ng]k0P1mOGd208j>SP80SHf=
0P2;Rh/208V9R@80QhN70P2<S8`208f=S@80SXj>102=SHd208j>SP80RHV900<0SXj>08b<S02<S8`0
0P2=SHd2092@T0@0Shn?0P27QhL208>3P`80PX:20P1jNWX209^KV`80Y:BT0P2NWYh207IfMP80Shn?
0P1nOWh00`22PX80Z:RX0:RXZ00206][J`80V9RH0P2k^k/20:BTY080Vi^K0P2IVITE0?ooo`004`3o
ool209bLW080X:2P0P2HV9P20:6QX@80WIfM0P2JVYX209nOW`80Xj>S00<0VYZJ09jNWP2NWYh00P2M
WId209RHV080XZ:R0P2UYJD209VIV@80YJFU0P2GUiL208b<S080R8R80P2;Rh/208f=S@80RXZ:0P2>
SXh2096AT@030:2PX027QhL0QhN70080Rh^;0P2>SXh208f=S@80P8200P27QhL20820P080Q8B41027
QhL208b<S080QhN70P1nOWh20820P080RHV900<0OWin07YjNP1jNWX00P22PX8208>3P`80P8200P2<
S8`408N7Q`80R8R81026QXH208N7Q`80OWin0P1mOGd207moO`80P82000<0O7al08f=S@2=SHd00P23
Ph<208V9R@80R8R81P27QhL208V9R@80QhN70P2@T90209:BTP80PX:20P28R8P208j>SP80RHV900<0
SHf=08b<S02<S8`00P2:RXX2092@T080RXZ:0P2;Rh/208b<S080R8R80P2<S8`208J6QP80QHF50P2:
RXX208B4Q080SHf=0P26QXH208V9R@0309FEU@2CTi<0Ti>C0080Ng]k0P1mOGd208j>SP80SHf=0P2;
Rh/208V9R@80QhN70P2<S8`208f=S@80SXj>102=SHd208j>SP80RHV900<0SXj>08b<S02<S8`00P2=
SHd2092@T0@0Shn?0P27QhL208>3P`80PX:20P1jNWX209^KV`80Y:BT0P2NWYh207IfMP80Shn?0P1n
OWh00`22PX80Z:RX0:RXZ00206][J`80V9RH0P2k^k/20:BTY080Vi^K0P2IVITE0?ooo`004`3oool2
09bLW080YZJV0P2QXJ420:FUY@80UiNG0P2VYZH209VIV@80XJ6Q00<0VYZJ0:JVYP2VYZH00P2HV9P2
0:BTY080YZJV0P2IVIT20::RXP80Y:BT0P2PX:0209fMW@80VYZJ0P2;Rh/208n?S`80TY:B0P2@T902
09>CT`0309RHV02TY:@0Y:BT0080Ogmo0P27QhL208f=S@@0RXZ:0P23Ph<208N7Q`80PX:21020P802
07moO`80OWin0P1jNWX207IfMP<0Ng]k0P1oOgl208:2PP80NWYj0P2?Shl208R8R080SHf=0P2<S8`2
08^;R`80S8b<0P2?Shl20861P@80R8R80P1kNg/208R8R00307inOP28R8P0R8R80080N7Qh0P24Q8@2
0861P@80O7al0P2:RXX208N7Q`@0R8R80P2=SHd408B4Q080RHV91026QXH308N7Q`80QHF50P2=SHd2
08Z:RPH0QXJ60P28R8P208F5Q@H0QhN71026QXH208N7Q`0308J6QP2LW9`0W9bL0080UYJF0P2DU9@2
08R8R080RHV91026QXH208B4Q080SXj>0P29RHT208n?S`80SHf=0P2:RXX208f=S@80RHV900<0UIFE
08V9R@29RHT0102BTY8208n?S`80P8200P21PH4206e]K@80Kfm_0P24Q8@20;6a/@80U9BD0P2TY:@2
06e]K@80T92@0P27QhL00`2=SHd0Shn?08n?S`0206e]K@80/K6a0P2^[Zh209bLW080Y:BT0P2HV9PE
0?ooo`004`3oool209bLW080YZJV0P2QXJ420:FUY@80UiNG0P2VYZH209VIV@80XJ6Q00<0VYZJ0:JV
YP2VYZH00P2HV9P20:BTY080YZJV0P2IVIT20::RXP80Y:BT0P2PX:0209fMW@80VYZJ0P2;Rh/208n?
S`80TY:B0P2@T90209>CT`0309RHV02TY:@0Y:BT0080Ogmo0P27QhL208f=S@@0RXZ:0P23Ph<208N7
Q`80PX:21020P80207moO`80OWin0P1jNWX207IfMP<0Ng]k0P1oOgl208:2PP80NWYj0P2?Shl208R8
R080SHf=0P2<S8`208^;R`80S8b<0P2?Shl20861P@80R8R80P1kNg/208R8R00307inOP28R8P0R8R8
0080N7Qh0P24Q8@20861P@80O7al0P2:RXX208N7Q`@0R8R80P2=SHd408B4Q080RHV91026QXH308N7
Q`80QHF50P2=SHd208Z:RPH0QXJ60P28R8P208F5Q@H0QhN71026QXH208N7Q`0308J6QP2LW9`0W9bL
0080UYJF0P2DU9@208R8R080RHV91026QXH208B4Q080SXj>0P29RHT208n?S`80SHf=0P2:RXX208f=
S@80RHV900<0UIFE08V9R@29RHT0102BTY8208n?S`80P8200P21PH4206e]K@80Kfm_0P24Q8@20;6a
/@80U9BD0P2TY:@206e]K@80T92@0P27QhL00`2=SHd0Shn?08n?S`0206e]K@80/K6a0P2^[Zh209bL
W080Y:BT0P2HV9PE0?ooo`004`3oool209bLW080WinO102MWId209ZJVP80Z:RX0P2IVIT20:JVYP03
09ZJVP2MWId0WIfM0080UYJF0P2PX:0209^KV`80XJ6Q0P2OWil20:>SX`@0XJ6Q0P2IVIT209FEU@80
U9BD102FUYH209NGU`0309>CT`2JVYX0VYZJ0080Vi^K0P26QXH205=CD`80Vi^K1025QHD207inOP80
Ogmo0P22PX840861P@80Lg=c0P1dM7@207emO@030861P@1mOGd0OGem0080OGem0P1oOgl207]kN`80
R8R81029RHT208b<S0@0RXZ:0P2?Shl20861P@80QhN70P1gMgL207moO`0307]kN`1mOGd0OGem0080
Ng]k0P25QHD207alO080Ng]k0P20P80207alO080PX:20P20P8020861P@80QXJ60P1nOWh20820P080
PX:20P20P8000`29RHT0OWin07inOP0208V9R@80QXJ60P1mOGd208F5Q@80QhN70P26QXH207inOPP0
P8200P1oOgl20861P@80RHV900<0OGem08B4Q024Q8@00P2JVYX209VIV@80M7Ad0P26QXH208N7Q`80
R8R80P27QhL208V9R@80QXJ60P2>SXh208f=S@80RHV90P2<S8`209>CT`0309BDU026QXH0QXJ60080
SHf=0P2:RXX20820P080N7Qh0P1RHV82071`L080Lg=c0P2FUYH20:2PX080NWYj0P1_Kfl207IfMP80
RXZ:0P1lO7`00`2EUID0PX:208:2PP0207UiN@80]KFe0P2VYZH209RHV080X:2P0P2HV9PE0?ooo`00
4`3oool209bLW080WinO102MWId209ZJVP80Z:RX0P2IVIT20:JVYP0309ZJVP2MWId0WIfM0080UYJF
0P2PX:0209^KV`80XJ6Q0P2OWil20:>SX`@0XJ6Q0P2IVIT209FEU@80U9BD102FUYH209NGU`0309>C
T`2JVYX0VYZJ0080Vi^K0P26QXH205=CD`80Vi^K1025QHD207inOP80Ogmo0P22PX840861P@80Lg=c
0P1dM7@207emO@030861P@1mOGd0OGem0080OGem0P1oOgl207]kN`80R8R81029RHT208b<S0@0RXZ:
0P2?Shl20861P@80QhN70P1gMgL207moO`0307]kN`1mOGd0OGem0080Ng]k0P25QHD207alO080Ng]k
0P20P80207alO080PX:20P20P8020861P@80QXJ60P1nOWh20820P080PX:20P20P8000`29RHT0OWin
07inOP0208V9R@80QXJ60P1mOGd208F5Q@80QhN70P26QXH207inOPP0P8200P1oOgl20861P@80RHV9
00<0OGem08B4Q024Q8@00P2JVYX209VIV@80M7Ad0P26QXH208N7Q`80R8R80P27QhL208V9R@80QXJ6
0P2>SXh208f=S@80RHV90P2<S8`209>CT`0309BDU026QXH0QXJ60080SHf=0P2:RXX20820P080N7Qh
0P1RHV82071`L080Lg=c0P2FUYH20:2PX080NWYj0P1_Kfl207IfMP80RXZ:0P1lO7`00`2EUID0PX:2
08:2PP0207UiN@80]KFe0P2VYZH209RHV080X:2P0P2HV9PE0?ooo`004`3oool209bLW080YJFU0P2K
Vi/20:FUY@80XZ:R0P2TY:@209NGU`80WYjN00<0Vi^K09nOW`2OWil00P2TY:@209jNWP80W9bL0P2M
WId20::RXP80WYjN0P2SXj<20:6QX@80UiNG0P2TY:@209NGU`80YjNW0P2PX:020:6QX@<0YZJV0P2U
YJD209RHV080SHf=0P29RHT208F5Q@80R8R80P22PX820820P0@0PX:20P1kNg/207moO`80NWYj0P28
R8P00`22PX80QHF508F5Q@0208^;R`80RXZ:0P22PX8207emO@80QhN70P29RHT208j>SP@0RXZ:102;
Rh/208Z:RP80PX:20P1kNg/00`25QHD0Rh^;08^;R`0207inOP80QhN70P21PH4208:2PP80Ph>30P1l
O7`207moO`80Lg=c0P1fMWH207MgM`80K6a/0P1hN7P407EeM@0307MgM`1/K6`0K6a/0080NGUi101d
M7@207QhN0@0MGEe0P1cLg<407IfMP80Q8B40P1lO7`208:2PP80PH610P23Ph<00`1hN7P0O7al07al
O00208R8R080Lg=c0P26QXH208b<S080Jf][0P1JFUX207]kN`80Q8B40P20P80208^;R`80QhN70P25
QHD208f=S@80SXj>00<0RXZ:08n?S`2?Shl00P2:RXX208>3P`80E5AD0P1YJFT2079bLP80P8200P1h
N7P207moO`80T92@0P1oOgl207UiN@80QXJ60P23Ph<209ZJVP0308n?S`1fMWH0MWIf0080UIFE0P2^
[Zh20:BTY080WIfM102KVi/E0?ooo`004`3oool20:>SX`80WinO0P2PX:0209fMW@80Xj>S0P2QXJ42
09nOW`80WIfM00<0WinO09VIV@2IVIT00P2OWil209VIV@80Vi^K0P2MWId20:RXZ080UiNG0P2KVi/2
0:BTY080UYJF0P2WYjL209VIV@80YjNW0P2JVYX209^KV`030:JVYP2KVi/0Vi^K0080Vi^K0P2LW9`2
0:BTY080S8b<0P1iNGT206=SH`80WIfM0P1jNWX207AdM080QHF50P20P80208>3P`80MGEe0P1mOGd0
0`1eMGD0Ogmo07moO`0208B4Q080PX:20P20P80207QhN080QXJ60P2<S8`208R8R080T92@0P29RHT2
08j>SP80RXZ:0P24Q8@208F5Q@80O7al00<0QHF508B4Q024Q8@00P1nOWh208b<S080PH610P29RHT2
08R8R080QXJ60P22PX8208V9R@80Q8B40P25QHD208:2PP80PH610P24Q8@207inOP030820P01nOWh0
OWin0080QhN70P1nOWh20820P080QhN70P23Ph<208J6QP@0Q8B40P2=SHd208n?S`80N7Qh0P2>SXh4
08R8R00307moO`2;Rh/0Rh^;0080PX:20P1nOWh208f=S@80RHV90P22PX8208Z:RP80SHf=0P0`<302
09BDU080MgMg0P23Ph<408N7Q`80QHF500<0Jf][055AD@1ADE400P1>CTh2051@D080EUIF0P26QXH2
08f=S@80QXJ60P1cLg<208J6QP80RXZ:0P20P80208f=S@80QHF50P1aLG420:JVYP0308R8R01XJ6P0
J6QX0080Zj^[0P2FUYH20:JVYP80X:2P0P2RXZ8209^KVaD0oooo000C0?ooo`80Xj>S0P2OWil20:2P
X080WIfM0P2SXj<20:6QX@80WinO0P2MWId00`2OWil0VIVI09VIV@0209nOW`80VIVI0P2KVi/209fM
W@80Z:RX0P2GUiL209^KV`80Y:BT0P2FUYH20:NWY`80VIVI0P2WYjL209ZJVP80Vi^K00<0YZJV09^K
V`2KVi/00P2KVi/209bLW080Y:BT0P2<S8`207UiN@80Hf=S0P2MWId207YjNP80M7Ad0P25QHD20820
P080Ph>30P1eMGD207emO@0307EeM@1oOgl0Ogmo0080Q8B40P22PX820820P080N7Qh0P26QXH208b<
S080R8R80P2@T90208V9R@80SXj>0P2:RXX208B4Q080QHF50P1lO7`00`25QHD0Q8B408B4Q00207in
OP80S8b<0P21PH4208V9R@80R8R80P26QXH208:2PP80RHV90P24Q8@208F5Q@80PX:20P21PH4208B4
Q080OWin00<0P82007inOP1nOWh00P27QhL207inOP80P8200P27QhL208>3P`80QXJ61024Q8@208f=
S@80Shn?0P1hN7P208j>SP@0R8R800<0Ogmo08^;R`2;Rh/00P22PX8207inOP80SHf=0P29RHT208:2
PP80RXZ:0P2=SHd2030`<080U9BD0P1gMgL208>3P`@0QhN70P25QHD00`1[Jf/0DE5A055AD@0204i>
CP80D51@0P1FEUH208J6QP80SHf=0P26QXH207=cL`80QXJ60P2:RXX20820P080SHf=0P25QHD2075a
L@80YZJV00<0R8R806QXJ01XJ6P00P2[Zj/209JFUP80YZJV0P2PX:020::RXP80Vi^K5@3oool001<0
oooo0P2IVIT209ZJVP80YZJV0P2GUiL20:6QX@80V9RH0P2KVi/209bLW00309jNWP2RXZ80XZ:R0080
VIVI0P2PX:020:BTY080Xj>S0P2OWil209^KV`80WYjN0P2XZ:P209VIV@80YjNW0P2JVYX20:FUY@80
UiNG0P2NWYh00`2QXJ40VIVI09VIV@020:FUY@80VIVI0P2QXJ4209^KV`80Hf=S0P1MGEd208^;R`80
JFUY0P1eMGD208Z:RP@0PH610P1oOgl208B4Q00307QhN021PH40PH610080QHF50P24Q8@208>3P`80
N7Qh0P24Q8@208f=S@80R8R80P29RHT208F5Q@80SHf=1029RHT208^;R`80Ph>300<0PH6108>3P`23
Ph<0102:RXX208F5Q@80RXZ:1027QhL208F5Q@80Ph>30P1kNg/208^;R`@0QhN70P2;Rh/207moO`03
08:2PP25QHD0QHF50080QHF51029RHT208B4Q080PX:20P24Q8@20861P@@0RXZ:0P27QhL208>3P`80
SHf=0P20P80208R8R00307inOP2<S8`0S8b<0080QHF50P29RHT208R8R080PH610P2:RXX208J6QP80
QhN70P1_Kfl20<C4a080JVYZ0P1PH602069RHP80LW9b0P1EEED00`1<C4`0G5aL05aLG00205IFEP80
HV9R0P1kNg/207MgM`80SXj>0P1dM7@206i^KP80][Jf0P1hN7P20861P@80RXZ:0P1VIVH209:BTP80
ZZZZ00<0MGEe096AT@2ATI400P2ATI420:RXZ080WYjN0P2MWId209bLW080XZ:R5@3oool001<0oooo
0P2IVIT209ZJVP80YZJV0P2GUiL20:6QX@80V9RH0P2KVi/209bLW00309jNWP2RXZ80XZ:R0080VIVI
0P2PX:020:BTY080Xj>S0P2OWil209^KV`80WYjN0P2XZ:P209VIV@80YjNW0P2JVYX20:FUY@80UiNG
0P2NWYh00`2QXJ40VIVI09VIV@020:FUY@80VIVI0P2QXJ4209^KV`80Hf=S0P1MGEd208^;R`80JFUY
0P1eMGD208Z:RP@0PH610P1oOgl208B4Q00307QhN021PH40PH610080QHF50P24Q8@208>3P`80N7Qh
0P24Q8@208f=S@80R8R80P29RHT208F5Q@80SHf=1029RHT208^;R`80Ph>300<0PH6108>3P`23Ph<0
102:RXX208F5Q@80RXZ:1027QhL208F5Q@80Ph>30P1kNg/208^;R`@0QhN70P2;Rh/207moO`0308:2
PP25QHD0QHF50080QHF51029RHT208B4Q080PX:20P24Q8@20861P@@0RXZ:0P27QhL208>3P`80SHf=
0P20P80208R8R00307inOP2<S8`0S8b<0080QHF50P29RHT208R8R080PH610P2:RXX208J6QP80QhN7
0P1_Kfl20<C4a080JVYZ0P1PH602069RHP80LW9b0P1EEED00`1<C4`0G5aL05aLG00205IFEP80HV9R
0P1kNg/207MgM`80SXj>0P1dM7@206i^KP80][Jf0P1hN7P20861P@80RXZ:0P1VIVH209:BTP80ZZZZ
00<0MGEe096AT@2ATI400P2ATI420:RXZ080WYjN0P2MWId209bLW080XZ:R5@3oool001<0oooo0P2S
Xj<209^KV`80WinO0P2QXJ4209^KV`80Xj>S0P2TY:@209VIV@0309fMW@2NWYh0WYjN0080X:2P0P2O
Wil20:FUY@80VIVI0P2RXZ8209ZJVP80WinO0P2PX:020:6QX@80Vi^K0P2RXZ820:BTY080WinO0P2T
Y:@00`2JVYX0Vi^K09^KV`0209fMW@80UiNG0P2QXJ4209VIV@80JVYZ0P1oOgl2065QH@80NGUi0P1g
MgL206=SH`80Rh^;0P22PX8207alO080PX:200<0LG5a08J6QP26QXH00P24Q8@207alO080QHF50P1m
OGd208>3P`80SXj>0P27QhL208J6QP80R8R80P29RHT208b<S080Q8B40P2<S8`208>3P`0308F5Q@21
PH40PH610080Q8B40P28R8P:08N7Q`80QHF50P27QhL207moO`80Ph>30P21PH4208R8R080QHF500<0
R8R807moO`1oOgl01023Ph<207emO@80PH610P2:RXX208R8R080Ng]k0P2=SHd608N7Q`@0P8200P2;
Rh/00`1mOGd0S8b<08b<S00207emO@80RHV90P26QXH208F5Q@80Rh^;0P1nOWh20861P@80Ogmo0P2A
TI4207moO`80RXZ:0P21PH4203dm?@80ADE500<0HV9R05aLG01LG5`00P1MGEd406m_K`80J6QX0P1]
KFd207AdM080OGem0P2e]KD2051@D080N7Qh0P2?Shl206=SH`80WYjN0P2EUID00`1_Kfl0^KVi0;Vi
^@0209:BTP80[Zj^0P2JVYX20:2PX080WIfM0P2XZ:PE0?ooo`004`3oool20:>SX`80Vi^K0P2OWil2
0:6QX@80Vi^K0P2SXj<20:BTY080VIVI00<0WIfM09jNWP2NWYh00P2PX:0209nOW`80YJFU0P2IVIT2
0::RXP80VYZJ0P2OWil20:2PX080XJ6Q0P2KVi/20::RXP80Y:BT0P2OWil20:BTY00309ZJVP2KVi/0
Vi^K0080WIfM0P2GUiL20:6QX@80VIVI0P1ZJVX207moO`80HF5Q0P1iNGT207MgM`80Hf=S0P2;Rh/2
08:2PP80O7al0P22PX800`1aLG40QXJ608J6QP0208B4Q080O7al0P25QHD207emO@80Ph>30P2>SXh2
08N7Q`80QXJ60P28R8P208V9R@80S8b<0P24Q8@208b<S080Ph>300<0QHF50861P@21PH400P24Q8@2
08R8R0X0QhN70P25QHD208N7Q`80Ogmo0P23Ph<20861P@80R8R80P25QHD00`28R8P0Ogmo07moO`04
08>3P`80OGem0P21PH4208Z:RP80R8R80P1kNg/208f=S@H0QhN71020P80208^;R`0307emO@2<S8`0
S8b<0080OGem0P29RHT208J6QP80QHF50P2;Rh/207inOP80PH610P1oOgl2096AT@80Ogmo0P2:RXX2
0861P@80?Cdm0P15ADD00`1RHV80G5aL05aLG00205eMG@@0Kfm_0P1XJ6P206e]K@80M7Ad0P1mOGd2
0;Fe]@80D51@0P1hN7P208n?S`80Hf=S0P2NWYh209FEU@0306m_K`2i^KT0^KVi0080TY:B0P2^[Zh2
09ZJVP80X:2P0P2MWId20:RXZ1D0oooo000C0?ooo`80Vi^K0P2QXJ420:>SX`80W9bL0P2IVIT20:NW
Y`80VIVI0P2PX:000`2TY:@0Xj>S0:>SX`0209bLW080XZ:R0P2TY:@209VIV@80WinO0P2QXJ420:BT
Y080XZ:R0P2TY:@209NGU`80XJ6Q0P2SXj<20:6QX@80Vi^K00<0V9RH09bLW02LW9`00P2OWil209bL
W080WYjN0P2KVi/207EeM@80Q8B40P1RHV8206QXJ080Ng]k0P1:BTX204e=C@80QhN70P22PX8207in
OP0307YjNP27QhL0QhN70080O7al1021PH4207YjNP80Ph>30P2>SXh808N7Q`80SXj>0P23Ph<208R8
R080Q8B400<0QhN708F5Q@25QHD00P28R8P208Z:RP@0QhN70P28R8P208J6QPH0QhN70P1mOGd208F5
Q@80Ph>30P2;Rh/20820P0030861P@26QXH0QXJ60080Ogmo0P1nOWh208>3P`80QHF50P24Q8@207mo
O`80OWin0P2>SXh208R8R080QXJ60P27QhL207UiN@80Rh^;0P2:RXX00`1nOWh0QHF508F5Q@0207mo
O`80SHf=0P27QhL207inOP80P8200P1nOWh20861P@80Lg=c0P1`L70206MWI`80C4a<0P11@D4204Q8
B0<0GemO0P1IFET2075aL@80IfMW101YJFT40820P080Ng]k0P2HV9P205QHF080Ogmo0P2<S8`206UY
J@80Z:RX0`25QHD20;:b/P80Vi^K0P2SXj<209>CT`80Z:RX0P2SXj<209nOWaD0oooo000C0?ooo`80
Vi^K0P2QXJ420:>SX`80W9bL0P2IVIT20:NWY`80VIVI0P2PX:000`2TY:@0Xj>S0:>SX`0209bLW080
XZ:R0P2TY:@209VIV@80WinO0P2QXJ420:BTY080XZ:R0P2TY:@209NGU`80XJ6Q0P2SXj<20:6QX@80
Vi^K00<0V9RH09bLW02LW9`00P2OWil209bLW080WYjN0P2KVi/207EeM@80Q8B40P1RHV8206QXJ080
Ng]k0P1:BTX204e=C@80QhN70P22PX8207inOP0307YjNP27QhL0QhN70080O7al1021PH4207YjNP80
Ph>30P2>SXh808N7Q`80SXj>0P23Ph<208R8R080Q8B400<0QhN708F5Q@25QHD00P28R8P208Z:RP@0
QhN70P28R8P208J6QPH0QhN70P1mOGd208F5Q@80Ph>30P2;Rh/20820P0030861P@26QXH0QXJ60080
Ogmo0P1nOWh208>3P`80QHF50P24Q8@207moO`80OWin0P2>SXh208R8R080QXJ60P27QhL207UiN@80
Rh^;0P2:RXX00`1nOWh0QHF508F5Q@0207moO`80SHf=0P27QhL207inOP80P8200P1nOWh20861P@80
Lg=c0P1`L70206MWI`80C4a<0P11@D4204Q8B0<0GemO0P1IFET2075aL@80IfMW101YJFT40820P080
Ng]k0P2HV9P205QHF080Ogmo0P2<S8`206UYJ@80Z:RX0`25QHD20;:b/P80Vi^K0P2SXj<209>CT`80
Z:RX0P2SXj<209nOWaD0oooo000C0?ooo`80Xj>S0P2OWil209ZJVP80Vi^K0P2LW9`20:NWY`80UiNG
0P2WYjL00`2FUYH0Y:BT0:BTY00209JFUP80YjNW0P2IVIT20::RXP80VIVI0P2WYjL40:6QX@80VIVI
0P2LW9`20:FUY@80Y:BT0P2IVIT20::RXP<0VYZJ0P2NWYh20:BTY080Vi^K0P2LW9`208>3P`80W9bL
0P25QHD204m?C`80KVi^0P1:BTX204U9B@80@T920P2KVi/207AdM00308F5Q@1eMGD0MGEe0080MWIf
1021PH420820P080Q8B40P2=SHd808N7Q`80RHV90P24Q8@708N7Q`80P8201P21PH4208V9R@80Ogmo
0P28R8P408N7Q`80OWin1023Ph<208B4Q0<0P8200P22PX8207emO@80Ph>30P25QHD408>3P`80Ogmo
0P24Q8@208F5Q@80RHV90P1mOGd208:2PP80OWin0P2>SXh208N7Q`0307inOP20P800P8200080Ph>3
0P24Q8@20861P@80MgMg0P22PX8207=cL`80MGEe0P1TI6@2061PH080BDU90P16ATH205]KF`80Kfm_
0P1VIVH00`1ZJVX0H61P061PH00205eMG@80Jf][0P1ZJVX207YjNP80Ph>30P1gMgL208R8R080NWYj
0P1OGel207emO@80Ng]k0P29RHT209>CT`80P82000<0UYJF0;Bd]02d];@00P2MWId209nOW`80VIVI
0P2UYJD209fMW@80UYJF5@3oool001<0oooo0P2SXj<209nOW`80VYZJ0P2KVi/209bLW080YjNW0P2G
UiL20:NWY`0309JFUP2TY:@0Y:BT0080UYJF0P2WYjL209VIV@80XZ:R0P2IVIT20:NWY`@0XJ6Q0P2I
VIT209bLW080YJFU0P2TY:@209VIV@80XZ:R0`2JVYX209jNWP80Y:BT0P2KVi/209bLW080Ph>30P2L
W9`208F5Q@80Cdm?0P1^KVh204Y:BP80BDU90P12@T8209^KV`80M7Ad00<0QHF507EeM@1eMGD00P1f
MWH40861P@80P8200P24Q8@208f=S@P0QhN70P29RHT208B4Q0L0QhN70P20P8060861P@80RHV90P1o
Ogl208R8R0@0QhN70P1nOWh408>3P`80Q8B40`20P80208:2PP80OGem0P23Ph<208F5Q@@0Ph>30P1o
Ogl208B4Q080QHF50P29RHT207emO@80PX:20P1nOWh208j>SP80QhN700<0OWin0820P020P8000P23
Ph<208B4Q080PH610P1gMgL208:2PP80Lg=c0P1eMGD206ATI080H61P0P19BDT204I6AP80Fe]K0P1_
Kfl206IVIP0306YZJP1PH600H61P0080GEeM0P1[Jf/206YZJP80NWYj0P23Ph<207MgM`80R8R80P1j
NWX205mOG`80OGem0P1kNg/208V9R@80Ti>C0P20P8000`2FUYH0];Bd0;Bd]00209fMW@80WinO0P2I
VIT20:FUY@80WIfM0P2FUYHE0?ooo`004`3oool209^KV`80W9bL0P2SXj<209jNWP80V9RH0P2XZ:P2
09nOW`80YJFU00<0UiNG0:RXZ02XZ:P00P2IVIT209jNWP80XJ6Q0P2LW9`20:6QX@80YJFU0P2IVIT4
09^KV`80W9bL0P2VYZH209JFUP80XZ:R0P2OWil00`2IVIT0Y:BT0:BTY00209jNWP80XJ6Q0P2FUYH2
09fMW@80Ogmo0P2ZZZX207=cL`80A4A40P1HF5P205ADE080ADE50P0g=cL203De=@80RHV900<0O7al
07=cL`1cLg<00P27QhL20820P080Q8B40P1kNg/208:2PP80QHF50P29RHT608N7Q`80P8200P28R8P7
08N7Q`80QHF50P28R8P20861P@80RXZ:0P23Ph<20820P080Q8B40P28R8P208N7Q`80QHF50P28R8P2
07]kN`80OWin0P24Q8@00`22PX80Ph>308>3P`0208>3P`80OWin0P24Q8@20820P080OGem0P20P802
08:2PP80OWin0P2=SHd207emO@80Rh^;0P21PH4208:2PP80RHV900<0QHF50820P020P8000P24Q8@2
0820P0@0NWYj0P1fMWH2075aL@@0J6QX0P1@D50204=3@`80IVIV0P1]KFd205]KF`80IfMW00<0MGEe
05iNGP1NGUh00P1MGEd206a/K080Ng]k0P1XJ6P207emO@80JFUY0P1kNg/206a/K080Q8B40P29RHT2
08>3P`80Zj^[0P1ZJVX208b<S0030;6a/@2XZ:P0Z:RX0080WYjN0P2GUiL209jNWP80Vi^K0P2UYJD2
09^KVaD0oooo000C0?ooo`80Vi^K0P2LW9`20:>SX`80WYjN0P2HV9P20:RXZ080WinO0P2UYJD00`2G
UiL0Z:RX0:RXZ00209VIV@80WYjN0P2QXJ4209bLW080XJ6Q0P2UYJD209VIV@@0Vi^K0P2LW9`20:JV
YP80UYJF0P2RXZ8209nOW`0309VIV@2TY:@0Y:BT0080WYjN0P2QXJ4209JFUP80WIfM0P1oOgl20:ZZ
ZP80Lg=c0P14A4@205QHF080E5AD0P15ADD203Lg=`80=CDe0P29RHT00`1lO7`0Lg=c07=cL`0208N7
Q`80P8200P24Q8@207]kN`80PX:20P25QHD208V9R@H0QhN70P20P80208R8R0L0QhN70P25QHD208R8
R080PH610P2:RXX208>3P`80P8200P24Q8@208R8R080QhN70P25QHD208R8R080Ng]k0P1nOWh208B4
Q00308:2PP23Ph<0Ph>30080Ph>30P1nOWh208B4Q080P8200P1mOGd20820P080PX:20P1nOWh208f=
S@80OGem0P2;Rh/20861P@80PX:20P29RHT00`25QHD0P8200820P00208B4Q080P820101jNWX207If
MP80LG5a101XJ6P2051@D080@d=30P1VIVH206e]K@80Fe]K0P1WIfL00`1eMGD0GUiN05iNGP0205eM
G@80K6a/0P1kNg/206QXJ080OGem0P1YJFT207]kN`80K6a/0P24Q8@208V9R@80Ph>30P2[Zj/206YZ
JP80S8b<00<0/K6a0:RXZ02XZ:P00P2NWYh209NGU`80WYjN0P2KVi/20:FUY@80Vi^K5@3oool001<0
oooo1P2MWId409ZJVP80Z:RX0P2FUYH209bLW00309JFUP2XZ:P0Z:RX0080X:2P0P2QXJ4209fMW@80
XJ6Q0P2MWId209^KV`80XJ6Q0P2JVYX20:JVYP80W9bL0P2NWYh20:6QX@80WIfM0P2JVYX00`2TY:@0
WIfM09fMW@020::RXP80WIfM102KVi/208F5Q@80Y:BT0P1_Kfl206e]K@80C4a<0P1RHV8204M7A`80
=cLg0P0Y:BT203Ti>@0309JFUP1iNGT0NGUi0080Q8B40P1cLg<208N7Q`80Ogmo0P1mOGd208f=S@80
RXZ:1P27QhL208F5Q@80Ph>30P21PH4208R8R00308N7Q`20P800P82000@0PH610P20P80207inOP80
Ogmo0P23Ph<408Z:RP80QhN70P20P8020861P@80OWin0P21PH430820P080Ng]k0P25QHD20861P@80
QHF50P1lO7`20861P@80MWIf0P24Q8@207moO`80QhN70P20P80208B4Q080P8200P22PX8208F5Q@03
07inOP1^KVh0KVi^0080M7Ad0P1^KVh206IVIP80JVYZ0P1XJ6P206][J`80E5AD0P0m?Cd203<c<`80
H61P0P22PX8206YZJP80@d=30P1`L7000`1^KVh0NGUi07UiN@0207AdM080NWYj0P1TI6@205iNGP80
KVi^0P1[Jf/20861P@80LG5a0P2>SXh20820P080ZZZZ0P20P80207UiN@80XJ6Q00<0[:b/09JFUP2F
UYH00P2IVIT209bLW080X:2P0P2LW9`20:RXZ080VYZJ5@3oool001<0oooo1P2MWId409ZJVP80Z:RX
0P2FUYH209bLW00309JFUP2XZ:P0Z:RX0080X:2P0P2QXJ4209fMW@80XJ6Q0P2MWId209^KV`80XJ6Q
0P2JVYX20:JVYP80W9bL0P2NWYh20:6QX@80WIfM0P2JVYX00`2TY:@0WIfM09fMW@020::RXP80WIfM
102KVi/208F5Q@80Y:BT0P1_Kfl206e]K@80C4a<0P1RHV8204M7A`80=cLg0P0Y:BT203Ti>@0309JF
UP1iNGT0NGUi0080Q8B40P1cLg<208N7Q`80Ogmo0P1mOGd208f=S@80RXZ:1P27QhL208F5Q@80Ph>3
0P21PH4208R8R00308N7Q`20P800P82000@0PH610P20P80207inOP80Ogmo0P23Ph<408Z:RP80QhN7
0P20P8020861P@80OWin0P21PH430820P080Ng]k0P25QHD20861P@80QHF50P1lO7`20861P@80MWIf
0P24Q8@207moO`80QhN70P20P80208B4Q080P8200P22PX8208F5Q@0307inOP1^KVh0KVi^0080M7Ad
0P1^KVh206IVIP80JVYZ0P1XJ6P206][J`80E5AD0P0m?Cd203<c<`80H61P0P22PX8206YZJP80@d=3
0P1`L7000`1^KVh0NGUi07UiN@0207AdM080NWYj0P1TI6@205iNGP80KVi^0P1[Jf/20861P@80LG5a
0P2>SXh20820P080ZZZZ0P20P80207UiN@80XJ6Q00<0[:b/09JFUP2FUYH00P2IVIT209bLW080X:2P
0P2LW9`20:RXZ080VYZJ5@3oool001<0oooo0P2KVi/20:FUY@80WIfM0P2LW9`20:FUY@80W9bL0P2H
V9P20:2PX0030:>SX`2PX:00X:2P0080WIfM0P2SXj<209VIV@80YZJV0P2IVIT20:BTY080YJFU0P2I
VIT20:NWY`80VYZJ0P2KVi/209nOW`80XJ6Q0P2MWId00`2NWYh0UiNG09NGU`020::RXP80VIVI0P2N
WYh209VIV@80VYZJ0P2?Shl208R8R080IFEU0P18B4P205]KF`80@4100P0g=cL2038b<P80;Rh^00<0
<C4a09FEU@2EUID00P24Q8@206i^KP80RXZ:0P1kNg/20820P080RHV90P28R8P20820P0H0PH610P27
QhL20861P@80Q8B400<0R8R807inOP1nOWh00P23Ph<208Z:RP@0PH610P1nOWh20861P@80QHF50P21
PH4207moO`80QhN70P21PH4207alO080Ng]k0P1nOWh00`1mOGd0Ng]k07]kN`0207moO`80O7al0P21
PH4207UiN@80OWin0P1dM7@207alO080MgMg0P21PH4208B4Q080M7Ad0P26QXH2071`L080Ph>300<0
NWYj07=cL`1cLg<00P1`L702075aL@80JFUY0P1VIVH205YJFP80CDe=0P0a<C420451@@80BTY:0P1e
MGD207AdM080IFEU0P1IFET20820P003079bLP1lO7`0O7al0080JFUY0P1]KFd2071`L080H61P0P1[
Jf/207emO@80NGUi0P1gMgL208f=S@80Ph>30P2:RXX207UiN@80UiNG0P2WYjL00`2PX:00SHf=08f=
S@0209bLW080YJFU0P2NWYh209^KV`80YjNW0P2PX:0E0?ooo`004`3oool209^KV`80YJFU0P2MWId2
09bLW080YJFU0P2LW9`209RHV080X:2P00<0Xj>S0:2PX02PX:000P2MWId20:>SX`80VIVI0P2VYZH2
09VIV@80Y:BT0P2UYJD209VIV@80YjNW0P2JVYX209^KV`80WinO0P2QXJ4209fMW@0309jNWP2GUiL0
UiNG0080XZ:R0P2IVIT209jNWP80VIVI0P2JVYX208n?S`80R8R80P1UIFD204Q8B080Fe]K0P10@402
03Lg=`80<S8b0P0^;Rh00`0a<C40UIFE09FEU@0208B4Q080KVi^0P2:RXX207]kN`80P8200P29RHT2
08R8R080P8201P21PH4208N7Q`80PH610P24Q8@00`28R8P0OWin07inOP0208>3P`80RXZ:1021PH42
07inOP80PH610P25QHD20861P@80Ogmo0P27QhL20861P@80O7al0P1kNg/207inOP0307emO@1kNg/0
Ng]k0080Ogmo0P1lO7`20861P@80NGUi0P1nOWh207AdM080O7al0P1gMgL20861P@80Q8B40P1dM7@2
08J6QP80L71`0P23Ph<00`1jNWX0Lg=c07=cL`02071`L080LG5a0P1YJFT206IVIP80FUYJ0P1=CDd2
034a<@80@D510P1:BTX207EeM@80M7Ad0P1UIFD205UIF@80P82000<0LW9b07alO01lO7`00P1YJFT2
06e]K@80L71`0P1PH60206][J`80OGem0P1iNGT207MgM`80SHf=0P23Ph<208Z:RP80NGUi0P2GUiL2
0:NWY`030:2PX02=SHd0SHf=0080W9bL0P2UYJD209jNWP80Vi^K0P2WYjL20:2PX1D0oooo000C0?oo
o`@0WIfM0P2RXZ820:6QX@80YJFU0P2DU9@20:JVYP<0Y:BT0P2HV9P209bLW080YZJV0P2HV9P20:2P
X080UYJF0P2QXJ4209ZJVP80VIVI0P2VYZH20:2PX080XZ:R0P2MWId20:2PX080XJ6Q00<0VIVI09bL
W02LW9`00P2OWil209jNWP80WIfM0P2CTi<209NGU`80NWYj0P2GUiL204=3@`80De=C0P1GEeL203dm
?@80>CTi0P0n?Sh203@d=00302HV9P0L71`071`L0080U9BD0P1gMgL407emO@80Ogmo0P25QHD208:2
PP80P8201P23Ph<208^;R`80OWin0P2:RXX00`23Ph<0P8200820P00208>3P`80Q8B40P1mOGd208>3
P`80PH610P1nOWh207moO`80P8200P1mOGd208N7Q`80P8200P1nOWh20820P080Ogmo00<0O7al0820
P020P8000P1gMgL207EeM@80Ng]k0P1oOgl407MgM`80PX:20P1hN7P208N7Q`80OGem0P1cLg<207Ui
N@80NWYj0P1iNGT307AdM080Kfm_0P1/K6`205eMG@80BTY:0P17AdL204A4A080@D510P1FEUH206i^
KP80NGUi0P1WIfL2069RHP80J6QX0P1fMWH00`1UIFD0G5aL05aLG00205YJFP80JVYZ0P1SHf<207=c
L`80NGUi0P1kNg/207=cL`80Rh^;0P29RHT208>3P`80R8R80P2ZZZX20:6QX@80UiNG00<0Vi^K0:2P
X02PX:000P2SXj<20:VYZ@80XZ:R0P2QXJ420:FUY@80XJ6Q5@3oool001<0oooo102MWId20::RXP80
XJ6Q0P2UYJD209BDU080YZJV0`2TY:@209RHV080W9bL0P2VYZH209RHV080X:2P0P2FUYH20:6QX@80
VYZJ0P2IVIT20:JVYP80X:2P0P2RXZ8209fMW@80X:2P0P2QXJ400`2IVIT0W9bL09bLW00209nOW`80
WYjN0P2MWId209>CT`80UiNG0P1jNWX209NGU`80@d=30P1CDe<205MGE`80?Cdm0P0i>CT203hn?P80
=3@d00<09RHV01`L700L71`00P2DU9@207MgM`@0OGem0P1oOgl208F5Q@80PX:20P20P80608>3P`80
Rh^;0P1nOWh208Z:RP0308>3P`20P800P8200080Ph>30P24Q8@207emO@80Ph>30P21PH4207inOP80
Ogmo0P20P80207emO@80QhN70P20P80207inOP80P8200P1oOgl00`1lO7`0P8200820P00207MgM`80
MGEe0P1kNg/207moO`@0MgMg0P22PX8207QhN080QhN70P1mOGd207=cL`80NGUi0P1jNWX207UiN@<0
M7Ad0P1_Kfl206a/K080GEeM0P1:BTX204M7A`80A4A40P11@D4205IFEP80KVi^0P1iNGT206MWI`80
HV9R0P1XJ6P207IfMP0306EUI@1LG5`0G5aL0080FUYJ0P1ZJVX206=SH`80Lg=c0P1iNGT207]kN`80
Lg=c0P2;Rh/208V9R@80Ph>30P28R8P20:ZZZP80XJ6Q0P2GUiL00`2KVi/0X:2P0:2PX0020:>SX`80
ZJVY0P2RXZ820:6QX@80YJFU0P2QXJ4E0?ooo`004`3oool209^KV`80YJFU0P2PX:020:>SX`80XJ6Q
102NWYh209fMW@030:>SX`2OWil0WinO0080WIfM0P2NWYh209NGU`80X:2P0P2RXZ820:FUY@80XJ6Q
0P2SXj<209nOW`80VYZJ0P2NWYh209^KV`80WYjN0P2UYJD00`2IVIT0WinO09nOW`0209nOW`@0W9bL
0P2MWId209FEU@80P8200P2JVYX20492@P80Fe]K0P1GEeL20410@080>SXj0P0o?cl203<c<`0301lO
7`0R8R808R8R00807QhN0P2PX:0207QhN080RHV90P1mOGd208F5Q@80PH610P24Q8@608>3P`80Q8B4
0P27QhL208Z:RP0307inOP23Ph<0Ph>300@0Ph>30P22PX8208B4Q080Ph>30P1nOWh20861P@80QHF5
0P1lO7`208B4Q080OGem0P1nOWh207]kN`<0O7al0P1nOWh207EeM@80NGUi0P1kNg/207alO080Lg=c
0P1aLG4207YjNP80MgMg0P1hN7P208B4Q080Jf][0P1hN7P207UiN@80M7Ad00<0JFUY07EeM@1eMGD0
0P1XJ6P204m?C`80>c/k0P19BDT202`/;080EEEE0P1GEeL206=SH`80N7Qh0P1VIVH2065QH@80JFUY
0P1TI6@207emO@0306YZJP1]KFd0KFe]0080LW9b0P1mOGd207EeM@80OGem0P1jNWX207IfMP80R8R8
0P2;Rh/208>3P`80PX:20P2EUID209bLW080Ti>C0P2HV9P00`2SXj<0XZ:R0::RXP020:BTY080WinO
0P2SXj<209^KV`80VYZJ0P2SXj<E0?ooo`004`3oool209^KV`80YJFU0P2PX:020:>SX`80XJ6Q102N
WYh209fMW@030:>SX`2OWil0WinO0080WIfM0P2NWYh209NGU`80X:2P0P2RXZ820:FUY@80XJ6Q0P2S
Xj<209nOW`80VYZJ0P2NWYh209^KV`80WYjN0P2UYJD00`2IVIT0WinO09nOW`0209nOW`@0W9bL0P2M
WId209FEU@80P8200P2JVYX20492@P80Fe]K0P1GEeL20410@080>SXj0P0o?cl203<c<`0301lO7`0R
8R808R8R00807QhN0P2PX:0207QhN080RHV90P1mOGd208F5Q@80PH610P24Q8@608>3P`80Q8B40P27
QhL208Z:RP0307inOP23Ph<0Ph>300@0Ph>30P22PX8208B4Q080Ph>30P1nOWh20861P@80QHF50P1l
O7`208B4Q080OGem0P1nOWh207]kN`<0O7al0P1nOWh207EeM@80NGUi0P1kNg/207alO080Lg=c0P1a
LG4207YjNP80MgMg0P1hN7P208B4Q080Jf][0P1hN7P207UiN@80M7Ad00<0JFUY07EeM@1eMGD00P1X
J6P204m?C`80>c/k0P19BDT202`/;080EEEE0P1GEeL206=SH`80N7Qh0P1VIVH2065QH@80JFUY0P1T
I6@207emO@0306YZJP1]KFd0KFe]0080LW9b0P1mOGd207EeM@80OGem0P1jNWX207IfMP80R8R80P2;
Rh/208>3P`80PX:20P2EUID209bLW080Ti>C0P2HV9P00`2SXj<0XZ:R0::RXP020:BTY080WinO0P2S
Xj<209^KV`80VYZJ0P2SXj<E0?ooo`004`3oool20:>SX`80YZJV0P2EUID20:NWY`80Vi^K0P2SXj<2
09nOW`80Xj>S00<0WYjN09fMW@2MWId00P2FUYH209nOW`80Y:BT0P2LW9`209^KV`80WYjN0P2MWId2
0:>SX`80X:2P0P2JVYX20:2PX080Y:BT0P2JVYX209fMW@0309bLW02TY:@0Y:BT0080WIfM0P2JVYX2
09fMW@80Vi^K0P2ATI4208V9R@80R8R80P16ATH205UIF@80BTY:0P13@d<204E5A@80?Cdm0P0Z:RX0
0`0O7al071`L01`L700202XZ:P80e=CD0P1hN7P208B4Q080PH610P23Ph<208:2PP80PH610P2:RXX2
0861P@80RXZ:0P21PH4208B4Q080PH6100<0P82008>3P`23Ph<00P1lO7`208B4Q080Ph>30P1oOgl2
08>3P`80O7al0P22PX8207moO`80NWYj0P1nOWh207IfMP80Ogmo0P1lO7`307emO@@0MgMg0P1fMWH4
079bLP@0LG5a0P1kNg/208V9R@80LW9b0P1]KFd206EUI@80Kfm_101^KVh00`1KFe/0IFEU06EUI@02
055AD@80DU9B0P0];Bd204a<C080@T920P1KFe/204M7A`80I6AT0P1]KFd205]KF`80GemO0P1VIVH2
079bLP80MWIf00<0MgMg07]kN`1kNg/00P1[Jf/207QhN080RXZ:0P1cLg<207YjNP80QXJ60P28R8P2
08>3P`80PH610P2CTi<209ZJVP80TY:B0P2ZZZX20:>SX`030:VYZ@2TY:@0Y:BT0080WinO0P2KVi/2
0:FUY@80UiNG0P2TY:@20:FUYAD0oooo000C0?ooo`80Xj>S0P2VYZH209FEU@80YjNW0P2KVi/20:>S
X`80WinO0P2SXj<00`2NWYh0WIfM09fMW@0209JFUP80WinO0P2TY:@209bLW080Vi^K0P2NWYh209fM
W@80Xj>S0P2PX:0209ZJVP80X:2P0P2TY:@209ZJVP80WIfM00<0W9bL0:BTY02TY:@00P2MWId209ZJ
VP80WIfM0P2KVi/2096AT@80RHV90P28R8P204I6AP80FEUI0P1:BTX204=3@`80ADE50P0m?Cd202XZ
:P0301lO7`0L71`071`L0080:RXZ0P3De=@207QhN080Q8B40P21PH4208>3P`80PX:20P21PH4208Z:
RP80PH610P2:RXX20861P@80Q8B40P21PH400`20P800Ph>308>3P`0207alO080Q8B40P23Ph<207mo
O`80Ph>30P1lO7`208:2PP80Ogmo0P1jNWX207inOP80MWIf0P1oOgl207alO0<0OGem101gMgL207If
MP@0LW9b101aLG4207]kN`80RHV90P1bLW8206e]K@80IFEU0P1_Kfl406i^KP0305]KF`1UIFD0IFEU
0080DE5A0P1BDU8202d];@80C4a<0P12@T8205]KF`80AdM70P1TI6@206e]K@80Fe]K0P1OGel206IV
IP80LW9b0P1fMWH00`1gMgL0Ng]k07]kN`0206][J`80N7Qh0P2:RXX207=cL`80NWYj0P26QXH208R8
R080Ph>30P21PH4209>CT`80VYZJ0P2BTY820:ZZZP80Xj>S00<0ZJVY0:BTY02TY:@00P2OWil209^K
V`80YJFU0P2GUiL20:BTY080YJFU5@3oool001<0oooo0P2QXJ4209^KV`80V9RH0P2PX:0209bLW080
WIfM0P2SXj<209VIV@030::RXP2JVYX0VYZJ0080VYZJ0P2WYjL20:BTY080VIVI0P2TY:@209fMW@80
Y:BT0P2NWYh209fMW@80Vi^K0P2UYJD209^KV`80VIVI0P2UYJD00`2TY:@0WYjN09jNWP020:6QX@80
VYZJ0P2OWil209VIV@80UYJF0P23Ph<206=SH`80DE5A0P1IFET204a<C080@T920P1CDe<203Ti>@80
=SHf00<09BDU02TY:@0Y:BT00P0j>SX204M7A`80TY:B0P28R8P208B4Q080Rh^;0P1oOgl20861P@80
SHf=0P1nOWh208B4Q080P8201@23Ph<20820P0@0PX:20P1jNWX207moO`80QHF50P1nOWh207moO`80
OWin0P21PH4207IfMP80Ph>30P1eMGD20820P080Ph>300<0O7al07IfMP1fMWH00P1jNWX2071`L080
LW9b0P1RHV8206i^KP80OGem0P2:RXX207QhN080EUIF0P1TI6@206m_K`80IVIV0P1`L70206EUI@03
051@D01HF5P0F5QH0080@d=30P18B4P205MGE`80De=C0P1SHf<2065QH@80IVIV0P1hN7P206m_K`80
H61P0P1VIVH206EUI@80N7Qh0P1OGel00`1[Jf/0Kfm_06m_K`0206QXJ080NGUi0P1_Kfl206IVIP80
Rh^;0P27QhL20820P080PX:20P2@T90209^KV`80XJ6Q0P2JVYX20:f][@80Y:BT00<0W9bL09VIV@2I
VIT0102RXZ8209jNWP80Vi^K0P2WYjL209^KVaD0oooo000C0?ooo`80XJ6Q0P2KVi/209RHV080X:2P
0P2LW9`209fMW@80Xj>S0P2IVIT00`2RXZ80VYZJ09ZJVP0209ZJVP80YjNW0P2TY:@209VIV@80Y:BT
0P2MWId20:BTY080WYjN0P2MWId209^KV`80YJFU0P2KVi/209VIV@80YJFU00<0Y:BT09jNWP2NWYh0
0P2QXJ4209ZJVP80WinO0P2IVIT209JFUP80Ph>30P1SHf<2055AD@80FEUI0P1<C4`20492@P80De=C
0P0i>CT203Hf=P0302DU9@0Y:BT0:BTY0080>SXj0P17AdL209:BTP80R8R80P24Q8@208^;R`80Ogmo
0P21PH4208f=S@80OWin0P24Q8@20820P0D0Ph>30P20P80408:2PP80NWYj0P1oOgl208F5Q@80OWin
0P1oOgl207inOP80PH610P1fMWH208>3P`80MGEe0P20P80208>3P`0307alO01fMWH0MWIf0080NWYj
0P1`L702079bLP80HV9R0P1^KVh207emO@80RXZ:0P1hN7P205IFEP80I6AT0P1_Kfl206IVIP80L71`
0P1UIFD00`1@D500F5QH05QHF00204=3@`80B4Q80P1GEeL205=CD`80Hf=S0P1QHF4206IVIP80N7Qh
0P1_Kfl2061PH080IVIV0P1UIFD207QhN080GemO00<0Jf][06m_K`1_Kfl00P1XJ6P207UiN@80Kfm_
0P1VIVH208^;R`80QhN70P20P80208:2PP80T92@0P2KVi/20:6QX@80VYZJ0P2][Jd20:BTY00309bL
W02IVIT0VIVI00@0XZ:R0P2NWYh209^KV`80YjNW0P2KVi/E0?ooo`004`3oool20:6QX@80X:2P0P2I
VIT20:FUY@80Vi^K0P2NWYh40:6QX@030:FUY@2GUiL0UiNG00@0YJFU0P2QXJ420:2PX080Vi^K0P2L
W9`20:JVYP80UiNG0P2OWil209VIV@80WYjN0P2QXJ4209ZJVP80XZ:R00<0Xj>S09RHV02HV9P00P2P
X:0209VIV@80Vi^K0P2BTY8209JFUP80MgMg0P1PH602055AD@80Fe]K0P18B4P2059BDP80DE5A0P0a
<C4203Ti>@0302XZ:P0h>3P0>3Ph0080>c/k0P0Q8B420<;2`P80RXZ:0P23Ph<208f=S@80Ng]k0P21
PH4208J6QP80NWYj0P20P80208>3P`80O7al0P20P8000`23Ph<0PX:208:2PP020820P080OGem0P1o
Ogl40820P080Ph>30P1jNWX407emO@80Ogmo0P1fMWH207inOP80MgMg0P1kNg/307AdM080LW9b0P1Z
JVX206ATI080JVYZ0P1aLG42096AT@80QhN70P1CDe<2061PH080Lg=c0P1aLG4205mOG`80E5AD0P1:
BTX00`0n?Sh0GemO05mOG`0404U9B@80E5AD0P1JFUX2065QH@80CDe=0P1WIfL206i^KP80J6QX0P1Q
HF4205iNGP80Cdm?0P2:RXX205mOG`030861P@1VIVH0IVIV0080Shn?0P1ZJVX207AdM080Rh^;0P2=
SHd40820P080RXZ:0P2<S8`20:NWY`80WinO0P2HV9P20:JVYP80YJFU00<0U9BD0:FUY@2UYJD00P2V
YZH20:6QX@80UiNG0P2UYJD20:BTY080X:2P5@3oool001<0oooo0P2QXJ420:2PX080VIVI0P2UYJD2
09^KV`80WYjN102QXJ400`2UYJD0UiNG09NGU`040:FUY@80XJ6Q0P2PX:0209^KV`80W9bL0P2VYZH2
09NGU`80WinO0P2IVIT209jNWP80XJ6Q0P2JVYX20::RXP030:>SX`2HV9P0V9RH0080X:2P0P2IVIT2
09^KV`80TY:B0P2FUYH207MgM`80H61P0P1ADE4205]KF`80B4Q80P1BDU82055AD@80<C4a0P0i>CT0
0`0Z:RX0>3Ph03Ph>00203/k>`808B4Q0P32`/8208Z:RP80Ph>30P2=SHd207]kN`80PH610P26QXH2
07YjNP80P8200P23Ph<207alO080P82000<0Ph>308:2PP22PX800P20P80207emO@80Ogmo1020P802
08>3P`80NWYj101mOGd207moO`80MWIf0P1nOWh207MgM`80Ng]k0`1dM7@2079bLP80JVYZ0P1TI6@2
06YZJP80LG5a0P2ATI4208N7Q`80De=C0P1PH60207=cL`80LG5a0P1OGel205ADE080BTY:00<0?Shn
05mOG`1OGel01019BDT205ADE080FUYJ0P1QHF4204e=C@80IfMW0P1^KVh206QXJ080HF5Q0P1NGUh2
04m?C`80RXZ:0P1OGel00`21PH40IVIV06IVIP0208n?S`80JVYZ0P1dM7@208^;R`80SHf=1020P802
08Z:RP80S8b<0P2WYjL209nOW`80V9RH0P2VYZH20:FUY@0309BDU02UYJD0YJFU0080YZJV0P2QXJ42
09NGU`80YJFU0P2TY:@20:2PX1D0oooo000C0?ooo`80XJ6Q0P2IVIT20:6QX@80WIfM0P2QXJ420:BT
Y080XZ:R0P2TY:@00`2QXJ40VIVI09VIV@020:JVYPH0XJ6Q0P2IVIT209fMW@80YZJV0P2OWil209jN
WP80WIfM0P2KVi/20:RXZ080VIVI0P2UYJD00`2KVi/0VIVI09VIV@020:JVYP80XZ:R0P2JVYX209:B
TP80V9RH0P1NGUh206UYJ@80CTi>0P1@D50204Q8B080ATI60P15ADD202d];@80>c/k00<0?clo04=3
@`13@d<00P0];Bd201<C4`80inOW0P21PH4208B4Q080Ph>31020P80208B4Q080Ng]k0P20P80208J6
QP80Ng]k0P20P8000`1oOgl0OWin07inOP0207emO@80OWin0P22PX820820P0@0OWin0P1oOgl207al
O080OGem0P1eMGD2079bLP80NWYj0P1fMWH307MgM`80N7Qh0P1[Jf/206YZJP80GUiN0P1VIVH20861
P@80Ph>30P1IFET2051@D080HF5Q0P1UIFD205eMG@80D51@0P1<C4`203Xj>P03051@D01VIVH0IVIV
0080BTY:0P1?Cdl2059BDP80EEEE101=CDd206a/K080L71`0P1YJFT205eMG@80H61P0P1YJFT208:2
PP80GemO00<0MWIf061PH01PH6000P1`L70206e]K@80MWIf0P1hN7P208N7Q`80PH610P22PX8209bL
W080[:b/0P2SXj<209VIV@80WYjN0P2ZZZX20:BTY00309VIV@2XZ:P0Z:RX0080XJ6Q0P2IVIT209^K
V`80WYjN0P2SXj<20:6QXAD0oooo000C0?ooo`80XJ6Q0P2IVIT20:6QX@80WIfM0P2QXJ420:BTY080
XZ:R0P2TY:@00`2QXJ40VIVI09VIV@020:JVYPH0XJ6Q0P2IVIT209fMW@80YZJV0P2OWil209jNWP80
WIfM0P2KVi/20:RXZ080VIVI0P2UYJD00`2KVi/0VIVI09VIV@020:JVYP80XZ:R0P2JVYX209:BTP80
V9RH0P1NGUh206UYJ@80CTi>0P1@D50204Q8B080ATI60P15ADD202d];@80>c/k00<0?clo04=3@`13
@d<00P0];Bd201<C4`80inOW0P21PH4208B4Q080Ph>31020P80208B4Q080Ng]k0P20P80208J6QP80
Ng]k0P20P8000`1oOgl0OWin07inOP0207emO@80OWin0P22PX820820P0@0OWin0P1oOgl207alO080
OGem0P1eMGD2079bLP80NWYj0P1fMWH307MgM`80N7Qh0P1[Jf/206YZJP80GUiN0P1VIVH20861P@80
Ph>30P1IFET2051@D080HF5Q0P1UIFD205eMG@80D51@0P1<C4`203Xj>P03051@D01VIVH0IVIV0080
BTY:0P1?Cdl2059BDP80EEEE101=CDd206a/K080L71`0P1YJFT205eMG@80H61P0P1YJFT208:2PP80
GemO00<0MWIf061PH01PH6000P1`L70206e]K@80MWIf0P1hN7P208N7Q`80PH610P22PX8209bLW080
[:b/0P2SXj<209VIV@80WYjN0P2ZZZX20:BTY00309VIV@2XZ:P0Z:RX0080XJ6Q0P2IVIT209^KV`80
WYjN0P2SXj<20:6QXAD0oooo000C0?ooo`80XJ6Q0P2OWil20:FUY@80UiNG0P2WYjL20:6QX@80Vi^K
0P2SXj<00`2KVi/0XJ6Q0:6QX@0209jNWP80Xj>S102QXJ420:2PX080W9bL0P2PX:0209fMW@80Vi^K
0P2NWYh20::RXP80YZJV0P2JVYX20:FUY@0309JFUP2UYJD0YJFU0080YJFU0P2QXJ4209NGU`80TI6A
0P27QhL205UIF@80J6QX0P1CDe<2059BDP@0CDe=0P0e=CD202l_;`80@d=300<0ATI603Ph>00h>3P0
0P0W9bL202DU9@80k^k^0P1jNWX208n?S`80Ogmo0P1kNg/208B4Q080PH610P1oOgl208B4Q080Ogmo
0P1mOGd20861P@0307inOP1fMWH0MWIf0080PH610P1oOgl207MgM`80N7Qh0P1gMgL207QhN080Ph>3
0P1aLG4207YjNP80M7Ad0P1gMgL207]kN`80LG5a0P1bLW800`1cLg<0Jf][06][J`0206UYJ@80FEUI
0P1RHV8206YZJP80N7Qh0P1TI6@2059BDP80GUiN0P1OGel2065QH@80E5AD0P0o?cl204Y:BP80AdM7
00<0EEEE07=cL`1cLg<00P1FEUH205eMG@@0CTi>0P1[Jf/205aLG080JFUY1P1UIFD20820P080LG5a
0P1bLW82065QH@0306][J`1VIVH0IVIV0080JFUY0P1eMGD208b<S080QhN70P2DU9@20820P080VYZJ
0P2PX:020:>SX`80VYZJ0P2FUYH20:2PX080XJ6Q0P2IVIT00`2RXZ80Y:BT0:BTY00209^KV`80X:2P
0P2TY:@20:6QX@80YJFU0P2QXJ4E0?ooo`004`3oool20:6QX@80WinO0P2UYJD209NGU`80YjNW0P2Q
XJ4209^KV`80Xj>S00<0Vi^K0:6QX@2QXJ400P2NWYh20:>SX`@0XJ6Q0P2PX:0209bLW080X:2P0P2M
WId209^KV`80WYjN0P2RXZ820:JVYP80VYZJ0P2UYJD00`2FUYH0YJFU0:FUY@020:FUY@80XJ6Q0P2G
UiL2096AT@80QhN70P1IFET206QXJ080De=C0P1BDU8404e=C@80=CDe0P0_;bl204=3@`0304I6AP0h
>3P0>3Ph00809bLW0P0U9BD20>k^kP80NWYj0P2?Shl207moO`80Ng]k0P24Q8@20861P@80Ogmo0P24
Q8@207moO`80OGem0P21PH400`1nOWh0MWIf07IfMP020861P@80Ogmo0P1gMgL207QhN080MgMg0P1h
N7P208>3P`80LG5a0P1jNWX207AdM080MgMg0P1kNg/2075aL@80LW9b00<0Lg=c06][J`1[Jf/00P1Y
JFT205UIF@80HV9R0P1ZJVX207QhN080I6AT0P1BDU8205iNGP80GemO0P1QHF4205ADE080?clo0P1:
BTX204M7A`0305EEE@1cLg<0Lg=c0080EUIF0P1MGEd404i>CP80Jf][0P1LG5`206UYJ@H0IFEU0P20
P802075aL@80LW9b0P1QHF400`1[Jf/0IVIV06IVIP0206UYJ@80MGEe0P2<S8`208N7Q`80U9BD0P20
P80209ZJVP80X:2P0P2SXj<209ZJVP80UYJF0P2PX:020:6QX@80VIVI00<0XZ:R0:BTY02TY:@00P2K
Vi/20:2PX080Y:BT0P2QXJ420:FUY@80XJ6Q5@3oool001<0oooo0P2QXJ4209^KV`80Xj>S0P2OWil2
0:FUY@@0Vi^K0P2UYJD00`2PX:00WYjN09jNWP020:6QX@80Y:BT102QXJ4209^KV`80XJ6Q0P2MWId2
09jNWP80Y:BT0P2RXZ8209jNWP80Xj>S0P2JVYX20:2PX00309^KV`2QXJ40XJ6Q0080WIfM0P2KVi/2
09RHV080TI6A0P22PX8405mOG`80EUIF0P1=CDd204];B`80CTi>0P0j>SX203hn?P80FUYJ00<0?Cdm
02<S8`0S8b<00P0V9RH2028R8P80i>CT0P1jNWX208N7Q`80L71`0P22PX8208N7Q`80PX:20P1dM7@2
07QhN080OWin0P1mOGd307MgM`80MWIf0P1hN7P207UiN@@0MWIf0P1gMgL207]kN`80Lg=c0P1gMgL4
079bLP80Lg=c0P1dM7@2071`L080M7Ad00<0JVYZ06][J`1[Jf/00P1VIVH205eMG@80H61P0P1gMgL2
065QH@80D51@0P1:BTX205eMG@80DE5A0P1IFET203hn?P80De=C0P1BDU8204m?C`03055AD@1WIfL0
IfMW0080I6AT0P1OGel204i>CP80GemO0P1PH60205UIF@80IfMW0P1@D50206UYJ@80JVYZ0P24Q8@2
07=cL`80N7Qh0P1PH6000`1ZJVX0OWin07inOP0206ATI080Lg=c0P2DU9@208:2PP80Rh^;0P2DU9@2
0:VYZ@80YZJV0P2IVIT20:2PX080Ti>C0P2SXj<209jNWP80Y:BT00<0YZJV0:6QX@2QXJ400P2JVYX2
09fMW@80WYjN0P2JVYX209jNWP80Xj>S5@3oool001<0oooo0P2QXJ420:2PX080Y:BT0P2KVi/20:>S
X`80X:2P0P2MWId20:FUY@030:6QX@2PX:00X:2P0080WYjN0P2SXj<40:6QX@80X:2P0P2TY:@20:2P
X080XZ:R0P2TY:@20:6QX@80VYZJ0P2UYJD209ZJVP80WYjN00<0Y:BT09ZJVP2JVYX00P2LW9`20:BT
Y080XZ:R0P2?Shl206m_K`80F5QH0P1WIfL205YJFP@0C4a<0P1?Cdl2038b<P80C4a<0P10@4000`0^
;Rh07AdM01dM7@0202l_;`808R8R0P3Vi^H207moO`80Ph>30P1nOWh208N7Q`80O7al0P25QHD207]k
N`80MgMg0P25QHD207IfMP80M7Ad00<0Ng]k07IfMP1fMWH00P1aLG4207UiN@80LW9b0P1gMgL2079b
LP80M7Ad0P1aLG4207alO080MGEe0P1bLW8206i^KP80KFe]0P1eMGD206a/K00306][J`1^KVh0KVi^
0080I6AT0P1JFUX206][J`80JFUY0P1>CTh204];B`80De=C0P1@D50204a<C080?Shn0P19BDT2055A
D@80>CTi0P19BDT00`1DE5@0Lg=c07=cL`0206UYJ@80Hf=S0P1YJFT205YJFP80Fe]K0P1CDe<205EE
E@80HV9R0P1bLW8205iNGP80PH610P1gMgL206YZJP80GEeM00<0Ogmo08:2PP22PX800P1TI6@20861
P@80TI6A0P21PH4209bLW0@0X:2P0P2@T90209JFUP80X:2P0P2NWYh20:>SX`80WYjN0P2VYZH00`2K
Vi/0Xj>S0:>SX`020:2PX080XJ6Q0P2NWYh209fMW@80YJFU0P2NWYhE0?ooo`004`3oool20:6QX@80
X:2P0P2TY:@209^KV`80Xj>S0P2PX:0209fMW@80YJFU00<0XJ6Q0:2PX02PX:000P2NWYh20:>SX`@0
XJ6Q0P2PX:020:BTY080X:2P0P2RXZ820:BTY080XJ6Q0P2JVYX20:FUY@80VYZJ0P2NWYh00`2TY:@0
VYZJ09ZJVP0209bLW080Y:BT0P2RXZ8208n?S`80Kfm_0P1HF5P206MWI`80FUYJ101<C4`204m?C`80
<S8b0P1<C4`20410@00302h^;P0M7Ad07AdM0080;bl_0P0R8R820>KViP80Ogmo0P23Ph<207inOP80
QhN70P1lO7`208F5Q@80Ng]k0P1gMgL208F5Q@80MWIf0P1dM7@00`1kNg/0MWIf07IfMP02075aL@80
NGUi0P1bLW8207MgM`80LW9b0P1dM7@2075aL@80O7al0P1eMGD2079bLP80KVi^0P1]KFd207EeM@80
K6a/00<0Jf][06i^KP1^KVh00P1TI6@205YJFP80Jf][0P1YJFT204i>CP80Bd];0P1CDe<2051@D080
C4a<0P0n?Sh204U9B@80DE5A0P0i>CT204U9B@0305ADE01cLg<0Lg=c0080JFUY0P1SHf<206UYJ@80
FUYJ0P1KFe/205=CD`80EEEE0P1RHV82079bLP80GUiN0P21PH4207MgM`80JVYZ0P1MGEd00`1oOgl0
PX:208:2PP0206ATI080PH610P2ATI420861P@80W9bL102PX:02092@T080UYJF0P2PX:0209jNWP80
Xj>S0P2NWYh20:JVYP0309^KV`2SXj<0Xj>S0080X:2P0P2QXJ4209jNWP80WIfM0P2UYJD209jNWQD0
oooo000C0?ooo`H0XJ6Q0P2PX:0209jNWP80WIfM0P2QXJ4209jNWP0309ZJVP2SXj<0Xj>S0080X:2P
0P2TY:@20:6QX@80Vi^K0P2SXj<80:6QX@80Vi^K0P2QXJ420:BTY080VYZJ0P2IVIT00`2QXJ40UYJF
09JFUP020:FUY@80WinO0P2KVi/209NGU`80EUIF0P1PH60205iNGP80F5QH0P0l?3`204];B`80?clo
0P0g=cL2051@D080>CTi00<0;bl_02TY:@0Y:BT00P0h>3P202HV9P80i^KV0P1dM7@208B4Q080Ng]k
0P22PX8407UiN@80PX:20P1cLg<207alO080MWIf0P1eMGD00`1cLg<0LW9b079bLP02079bLP80KVi^
0P1]KFd207IfMP80K6a/0P1_Kfl207IfMP80MGEe0P1bLW8206UYJ@80KVi^0P1/K6`2071`L080Jf][
00<0KVi^061PH01PH6000P1QHF4205YJFP80LG5a0P1JFUX204a<C0@0Bd];0P1:BTX204E5A@80CTi>
0P1@D50403lo?`80CDe=00<0EUIF06EUI@1UIFD00P1WIfL205eMG@80IfMW0P1HF5P206ATI080CTi>
0P1EEED205=CD`80IFEU0P1bLW8207UiN@80KVi^0P1gMgL207IfMP0307moO`1RHV80HV9R0080JVYZ
0P21PH4208^;R`80RXZ:0P2UYJD209FEU@80WIfM0P2OWil20:2PX080V9RH0P2SXj<20:BTY080WIfM
0P2UYJD00`2PX:00Y:BT0:BTY0040:6QX@80VYZJ102TY:@209ZJVQD0oooo000C0?ooo`H0XJ6Q0P2P
X:0209jNWP80WIfM0P2QXJ4209jNWP0309ZJVP2SXj<0Xj>S0080X:2P0P2TY:@20:6QX@80Vi^K0P2S
Xj<80:6QX@80Vi^K0P2QXJ420:BTY080VYZJ0P2IVIT00`2QXJ40UYJF09JFUP020:FUY@80WinO0P2K
Vi/209NGU`80EUIF0P1PH60205iNGP80F5QH0P0l?3`204];B`80?clo0P0g=cL2051@D080>CTi00<0
;bl_02TY:@0Y:BT00P0h>3P202HV9P80i^KV0P1dM7@208B4Q080Ng]k0P22PX8407UiN@80PX:20P1c
Lg<207alO080MWIf0P1eMGD00`1cLg<0LW9b079bLP02079bLP80KVi^0P1]KFd207IfMP80K6a/0P1_
Kfl207IfMP80MGEe0P1bLW8206UYJ@80KVi^0P1/K6`2071`L080Jf][00<0KVi^061PH01PH6000P1Q
HF4205YJFP80LG5a0P1JFUX204a<C0@0Bd];0P1:BTX204E5A@80CTi>0P1@D50403lo?`80CDe=00<0
EUIF06EUI@1UIFD00P1WIfL205eMG@80IfMW0P1HF5P206ATI080CTi>0P1EEED205=CD`80IFEU0P1b
LW8207UiN@80KVi^0P1gMgL207IfMP0307moO`1RHV80HV9R0080JVYZ0P21PH4208^;R`80RXZ:0P2U
YJD209FEU@80WIfM0P2OWil20:2PX080V9RH0P2SXj<20:BTY080WIfM0P2UYJD00`2PX:00Y:BT0:BT
Y0040:6QX@80VYZJ102TY:@209ZJVQD0oooo000C0?ooo`80XJ6Q0P2KVi/209fMW@80Xj>S0P2JVYX2
09jNWP80YJFU0P2PX:000`2QXJ40WinO09nOW`0209ZJVP80Xj>S0P2QXJ4209ZJVP80YJFU0P2QXJ42
09^KV`80WIfM0P2KVi/209VIV@80YZJV102KVi/20::RXP030:FUY@2KVi/0Vi^K0080Z:RX0P2EUID2
09fMW@80PX:20P1EEED206MWI`80EEEE0P1DE5@204E5A@80FUYJ0P0g=cL204Y:BP80C4a<0P0o?cl0
0`0P82008R8R028R8P0202XZ:P80:b/[0P3Ogml2071`L080Q8B40P1cLg<20861P@80Ng]k0P1fMWH2
07alO080MGEe0P1aLG4207QhN080L71`00<0K6a/07EeM@1eMGD00P1^KVh206e]K@80L71`0P1VIVH2
06EUI@80IfMW0P1aLG4206a/K080L71`0P1ZJVX206m_K`80IFEU101XJ6P00`1RHV80H61P061PH002
05iNGP80H61P0P1BDU8204M7A`80BDU90P14A4@204a<C080DE5A0P1?Cdl204U9B@80AdM70P16ATH2
04e=C@80EUIF00<0EEEE069RHP1RHV800P1]KFd207YjNP80LG5a0P1nOWh205mOG`80@d=30P1>CTh2
05EEE@80LG5a0P1SHf<207=cL`80NWYj0P1kNg/207IfMP03061PH01QHF40HF5Q0080JVYZ0P2CTi<2
092@T080RXZ:0P2QXJ4209^KV`80U9BD0P2SXj<209>CT`80YZJV0P2RXZ820:FUY@80X:2P0P2TY:@0
0`2QXJ40Vi^K09^KV`020:>SX`80XJ6Q0P2PX:0209^KV`80Xj>S0P2JVYXE0?ooo`004`3oool20:6Q
X@80Vi^K0P2MWId20:>SX`80VYZJ0P2NWYh20:FUY@80X:2P00<0XJ6Q09nOW`2OWil00P2JVYX20:>S
X`80XJ6Q0P2JVYX20:FUY@80XJ6Q0P2KVi/209fMW@80Vi^K0P2IVIT20:JVYP@0Vi^K0P2RXZ800`2U
YJD0Vi^K09^KV`020:RXZ080UIFE0P2MWId208:2PP80EEEE0P1WIfL205EEE@80E5AD0P15ADD205YJ
FP80=cLg0P1:BTX204a<C080?clo00<0820P028R8P0R8R800P0Z:RX202/[:`80gmoO0P1`L70208B4
Q080Lg=c0P21PH4207]kN`80MWIf0P1lO7`207EeM@80LG5a0P1hN7P2071`L00306a/K01eMGD0MGEe
0080KVi^0P1]KFd2071`L080IVIV0P1UIFD206MWI`80LG5a0P1/K6`2071`L080JVYZ0P1_Kfl206EU
I@@0J6QX00<0HV9R061PH01PH6000P1NGUh2061PH080DU9B0P17AdL204U9B@80A4A40P1<C4`2055A
D@80Cdm?0P19BDT204M7A`80ATI60P1=CDd205IFEP0305EEE@1RHV80HV9R0080KFe]0P1jNWX2075a
L@80OWin0P1OGel204=3@`80CTi>0P1EEED2075aL@80Hf=S0P1cLg<207YjNP80Ng]k0P1fMWH00`1P
H600HF5Q065QH@0206YZJP80Ti>C0P2@T90208Z:RP80XJ6Q0P2KVi/209BDU080Xj>S0P2CTi<20:JV
YP80XZ:R0P2UYJD20:2PX080Y:BT00<0XJ6Q09^KV`2KVi/00P2SXj<20:6QX@80X:2P0P2KVi/20:>S
X`80VYZJ5@3oool001<0oooo0P2MWId20:6QX@80XZ:R0P2NWYh209^KV`80W9bL0P2MWId209^KV`03
09jNWP2QXJ40XJ6Q0080XJ6Q0P2UYJD209VIV@80XZ:R0P2NWYh20:>SX`80VYZJ0P2TY:@209ZJVP@0
YJFU0P2PX:020::RXP80Y:BT00<0Vi^K09VIV@2IVIT00P2PX:0209RHV080WYjN0P1YJFT206=SH`80
G5aL0P1IFET204e=C@80@D510P1?Cdl203Xj>P80EeMG0P0e=CD2034a<@0301XJ6P0P8200820P0080
:b/[0P0Z:RX20=kNgP80L71`0P23Ph<207alO080P820101gMgL2075aL@80LW9b0P1`L70207EeM@80
LG5a00<0K6a/06m_K`1_Kfl00P1[Jf/2071`L080KFe]0P1[Jf/206MWI`80JFUY0P1ZJVX206QXJ080
L71`0P1]KFd406IVIP80JFUY0P1LG5`305iNGP80De=C0P1RHV8204M7A`80@d=30P10@402055AD@80
B4Q80P1CDe<2051@D080:b/[0P0a<C4203Xj>P80DU9B0P1SHf<00`1MGEd0GemO05mOG`0206EUI@80
L71`0P1]KFd206UYJ@80Lg=c0P1EEED2059BDP80J6QX0P1WIfL206a/K080HF5Q0P24Q8@207MgM`80
HF5Q00<0H61P06UYJ@1YJFT00P1XJ6P209^KV`80S8b<0P2VYZH209RHV080WinO0P2EUID209jNWP80
WIfM0P2/[:`209FEU@80WinO0P2SXj<20:6QX@0309^KV`2QXJ40XJ6Q0080Y:BT0P2QXJ4209^KV`80
X:2P0P2UYJD20:2PX1D0oooo000C0?ooo`80WIfM0P2QXJ420::RXP80WYjN0P2KVi/209bLW080WIfM
0P2KVi/00`2NWYh0XJ6Q0:6QX@020:6QX@80YJFU0P2IVIT20::RXP80WYjN0P2SXj<209ZJVP80Y:BT
0P2JVYX40:FUY@80X:2P0P2RXZ820:BTY00309^KV`2IVIT0VIVI0080X:2P0P2HV9P209jNWP80JFUY
0P1SHf<205aLG080FEUI0P1=CDd20451@@80Cdm?0P0j>SX205MGE`80=CDe0P0a<C400`0J6QX0820P
020P800202/[:`80:RXZ0P3Ng]h2071`L080Ph>30P1lO7`20820P0@0MgMg0P1aLG42079bLP80L71`
0P1eMGD2075aL@0306a/K01_Kfl0Kfm_0080Jf][0P1`L70206e]K@80Jf][0P1WIfL206UYJ@80JVYZ
0P1XJ6P2071`L080KFe]101VIVH206UYJ@80G5aL0`1NGUh205=CD`80HV9R0P17AdL204=3@`80@410
0P1ADE4204Q8B080De=C0P1@D50202/[:`80<C4a0P0j>SX2059BDP80Hf=S00<0GEeM05mOG`1OGel0
0P1UIFD2071`L080KFe]0P1YJFT207=cL`80EEEE0P1BDU8206QXJ080IfMW0P1/K6`2065QH@80Q8B4
0P1gMgL2065QH@03061PH01YJFT0JFUY0080J6QX0P2KVi/208b<S080YZJV0P2HV9P209nOW`80UIFE
0P2NWYh209fMW@80[:b/0P2EUID209nOW`80Xj>S0P2QXJ400`2KVi/0XJ6Q0:6QX@020:BTY080XJ6Q
0P2KVi/20:2PX080YJFU0P2PX:0E0?ooo`004`3oool20::RXP80Y:BT0P2QXJ420:2PX080WIfM0P2S
Xj<20::RXP80Xj>S0`2TY:@40:6QX@80WinO0P2MWId209bLW080YJFU0P2HV9P20:JVYP80VIVI0P2V
YZH209^KV`80Xj>S102KVi/00`2LW9`0Xj>S0:>SX`0209VIV@80WinO0P29RHT205mOG`80K6a/0P1C
De<2059BDP80AdM70P18B4P20451@@80?clo0P1=CDd2038b<P80;2`/00<09BDU02l_;`0_;bl00P0_
;bl2030`<080b/[:0P1cLg<207UiN@80MgMg0P1iNGT207AdM080LW9b0P1gMgL207=cL`80M7Ad0P1[
Jf/206m_K`0306e]K@1UIFD0IFEU0080IfMW0P1XJ6P205]KF`80I6AT0P1QHF4205iNGP80Jf][0P1Y
JFT205mOG`80JVYZ0P1VIVH206UYJ@80G5aL0P1KFe/00`1QHF40GemO05mOG`0204i>CP80KVi^0P14
A4@2038b<P80D51@0P1ADE4204E5A@80@T920P0`<30202/[:`808B4Q0P1JFUX206][J`80CDe=00<0
GUiN04e=C@1=CDd00P1PH602075aL@80O7al0P1[Jf/208>3P`80DE5A0P1NGUh2079bLP80H61P0P1`
L70206=SH`80RHV9101QHF400`1KFe/0IFEU06EUI@0208:2PP80WYjN0P2KVi/20:6QX@80Shn?0P2D
U9@20:6QX@80X:2P0P2QXJ420:NWY`80VIVI0P2PX:020:JVYP80XJ6Q00<0X:2P09^KV`2KVi/00P2S
Xj<209^KV`80XJ6Q0P2NWYh20:>SX`80XJ6Q5@3oool001<0oooo0P2RXZ820:BTY080XJ6Q0P2PX:02
09fMW@80Xj>S0P2RXZ820:>SX`<0Y:BT102QXJ4209nOW`80WIfM0P2LW9`20:FUY@80V9RH0P2VYZH2
09VIV@80YZJV0P2KVi/20:>SX`@0Vi^K00<0W9bL0:>SX`2SXj<00P2IVIT209nOW`80RHV90P1OGel2
06a/K080De=C0P1BDU8204M7A`80B4Q80P11@D4203lo?`80CDe=0P0b<S8202`/;00302DU9@0_;bl0
;bl_0080;bl_0P0`<3020<[:bP80Lg=c0P1iNGT207MgM`80NGUi0P1dM7@2079bLP80MgMg0P1cLg<2
07AdM080Jf][0P1_Kfl00`1]KFd0IFEU06EUI@0206MWI`80J6QX0P1KFe/206ATI080HF5Q0P1NGUh2
06][J`80JFUY0P1OGel206YZJP80IVIV0P1YJFT205aLG080Fe]K00<0HF5Q05mOG`1OGel00P1>CTh2
06i^KP80A4A40P0b<S82051@D080DE5A0P15ADD20492@P80<30`0P0[:b/2024Q8@80FUYJ0P1[Jf/2
04e=C@0305iNGP1=CDd0CDe=0080H61P0P1aLG4207alO080Jf][0P23Ph<2055AD@80GUiN0P1bLW82
061PH080L71`0P1SHf<208V9R@@0HF5Q00<0Fe]K06EUI@1UIFD00P22PX8209jNWP80Vi^K0P2QXJ42
08n?S`80U9BD0P2QXJ420:2PX080XJ6Q0P2WYjL209VIV@80X:2P0P2VYZH20:6QX@030:2PX02KVi/0
Vi^K0080Xj>S0P2KVi/20:6QX@80WYjN0P2SXj<20:6QXAD0oooo000C0?ooo`@0XJ6Q0P2KVi/20:>S
X`80VYZJ0P2PX:0209ZJVP80WYjN00<0WIfM0:>SX`2SXj<00P2KVi/20:>SX`80XJ6Q0P2OWil20:>S
X`80Y:BT0P2GUiL209nOW`80W9bL0P2MWId20::RXP80Y:BT0P2JVYX30:>SX`H0Vi^K0P1aLG42065Q
H@80Hf=S0P18B4P205EEE@80ADE50P1;Bd/204E5A@80@T920P14A4@202DU9@80:RXZ00<09bLW02h^
;P0^;Rh0100];Bd20<C4a0@0N7Qh0P28R8P207UiN@80NWYj0P1dM7@207inOP80M7Ad0P1hN7P207Mg
M`<0MGEe0P1ZJVX2065QH@80G5aL0P1SHf<205YJFP80H61P0P1MGEd2069RHP80GUiN0P1SHf<206QX
J080G5aL0P1NGUh205]KF`80EEEE00<0F5QH04i>CP1>CTh00P1@D50206YZJP80>SXj0P0^;Rh205=C
D`80DU9B0P0c<c<202l_;`80:b/[0P0h>3P203lo?`80F5QH0P1WIfL205MGE`0305QHF01JFUX0FUYJ
0080CTi>0P1hN7P207EeM@80N7Qh0P1VIVH205aLG080GEeM0P1WIfL2065QH@80Hf=S0P20P80207mo
O`80G5aL0P1aLG400`1SHf<0PX:208:2PP020861P@80U9BD0P2e]KD208^;R`80Ti>C0P2RXZ8209fM
W@80Z:RX0P2SXj<20:FUY@80X:2P0P2MWId20:FUY@<0XJ6Q0P2OWil20:FUY@80X:2P0P2TY:@209ZJ
VP80YJFU0P2KVi/E0?ooo`004`3oool40:6QX@80Vi^K0P2SXj<209ZJVP80X:2P0P2JVYX209jNWP03
09fMW@2SXj<0Xj>S0080Vi^K0P2SXj<20:6QX@80WinO0P2SXj<20:BTY080UiNG0P2OWil209bLW080
WIfM0P2RXZ820:BTY080VYZJ0`2SXj<609^KV`80LG5a0P1QHF4206=SH`80B4Q80P1EEED204E5A@80
Bd];0P15ADD20492@P80A4A40P0U9BD202XZ:P0302LW9`0^;Rh0;Rh^00@0;Bd]0P34a<@407QhN080
R8R80P1iNGT207YjNP80M7Ad0P1nOWh207AdM080N7Qh0P1gMgL307EeM@80JVYZ0P1QHF4205aLG080
Hf=S0P1JFUX2061PH080GEeM0P1RHV8205iNGP80Hf=S0P1XJ6P205aLG080GUiN0P1KFe/205EEE@03
05QHF01>CTh0CTi>0080D51@0P1ZJVX203Xj>P80;Rh^0P1CDe<2059BDP80<c<c0P0_;bl202/[:`80
>3Ph0P0o?cl205QHF080IfMW0P1GEeL00`1HF5P0FUYJ05YJFP0204i>CP80N7Qh0P1eMGD207QhN080
IVIV0P1LG5`205eMG@80IfMW0P1QHF4206=SH`80P8200P1oOgl205aLG080LG5a00<0Hf=S08:2PP22
PX800P21PH4209BDU080]KFe0P2;Rh/209>CT`80XZ:R0P2MWId20:RXZ080Xj>S0P2UYJD20:2PX080
WIfM0P2UYJD30:6QX@80WinO0P2UYJD20:2PX080Y:BT0P2JVYX20:FUY@80Vi^K5@3oool001<0oooo
0P2MWId20:>SX`80X:2P0P2IVIT209RHV080YJFU0P2LW9`20:FUY@030::RXP2NWYh0WYjN0080Vi^K
0P2UYJD20:6QX@80VIVI0P2SXj<209^KV`80X:2P0P2KVi/20:2PX080Vi^K0P2WYjL20:6QX@80VYZJ
0P2PX:000`2JVYX0VIVI09VIV@0209fMW@80TY:B0P1]KFd206IVIP80G5aL0P1<C4`205=CD`80BTY:
0P16ATH205UIF@80=cLg0P14A4@201HF5P80=SHf00<0;2`/02h^;P0^;Rh00P0X:2P20492@P80_kno
0P2?Shl208f=S@80T92@0P26QXH208Z:RP80RHV91020P80208:2PP80NWYj0P1iNGT00`1lO7`0MWIf
07IfMP02075aL@80KFe]101HF5P605aLG080EeMG0P1IFET205MGE`80GemO0P1KFe/205MGE`80FEUI
00<0DU9B04];B`1;Bd/00P1@D50206=SH`80:b/[0P0f=SH2059BDP80@T920P0/;2`202DU9@80;2`/
0P1IFET203<c<`80D51@0P1ZJVX205YJFP03055AD@1>CTh0CTi>0080DU9B101fMWH20820P080M7Ad
0P1hN7P2061PH080JVYZ0P1CDe<204];B`80T92@0P1fMWH205]KF`80Jf][00<0NWYj07inOP1nOWh0
0P29RHT20;bl_080Z:RX0P2?Shl209bLW080YJFU0P2MWId20:FUY@80Xj>S0P2KVi/20:>SX`80X:2P
0P2TY:@20:6QX@0309^KV`2SXj<0Xj>S00H0XJ6Q0P2PX:0209jNWP80VIVI5@3oool001<0oooo0P2M
WId20:>SX`80X:2P0P2IVIT209RHV080YJFU0P2LW9`20:FUY@030::RXP2NWYh0WYjN0080Vi^K0P2U
YJD20:6QX@80VIVI0P2SXj<209^KV`80X:2P0P2KVi/20:2PX080Vi^K0P2WYjL20:6QX@80VYZJ0P2P
X:000`2JVYX0VIVI09VIV@0209fMW@80TY:B0P1]KFd206IVIP80G5aL0P1<C4`205=CD`80BTY:0P16
ATH205UIF@80=cLg0P14A4@201HF5P80=SHf00<0;2`/02h^;P0^;Rh00P0X:2P20492@P80_kno0P2?
Shl208f=S@80T92@0P26QXH208Z:RP80RHV91020P80208:2PP80NWYj0P1iNGT00`1lO7`0MWIf07If
MP02075aL@80KFe]101HF5P605aLG080EeMG0P1IFET205MGE`80GemO0P1KFe/205MGE`80FEUI00<0
DU9B04];B`1;Bd/00P1@D50206=SH`80:b/[0P0f=SH2059BDP80@T920P0/;2`202DU9@80;2`/0P1I
FET203<c<`80D51@0P1ZJVX205YJFP03055AD@1>CTh0CTi>0080DU9B101fMWH20820P080M7Ad0P1h
N7P2061PH080JVYZ0P1CDe<204];B`80T92@0P1fMWH205]KF`80Jf][00<0NWYj07inOP1nOWh00P29
RHT20;bl_080Z:RX0P2?Shl209bLW080YJFU0P2MWId20:FUY@80Xj>S0P2KVi/20:>SX`80X:2P0P2T
Y:@20:6QX@0309^KV`2SXj<0Xj>S00H0XJ6Q0P2PX:0209jNWP80VIVI5@3oool001<0oooo0P2RXZ82
09jNWP80WIfM0P2PX:020:>SX`80YZJV0P2JVYX20:FUY@030:6QX@2PX:00X:2P0080XZ:R0P2TY:@2
0:6QX@80VIVI0P2WYjL20:2PX080WYjN0P2QXJ420:>SX`80UiNG0P2XZ:P209^KV`80XJ6Q0P2JVYX0
0`2KVi/0WinO09nOW`0209nOW`80NWYj0P1WIfL205mOG`80F5QH0P1?Cdl2051@D080?3`l0P17AdL4
04=3@`80<S8b0P0K6a/203`l?003034a<@0/;2`0;2`/0080:2PX0P1mOGd20<W9b@80TY:B0P2HV9P2
08N7Q`80RXZ:0P26QXH208N7Q`80R8R80P29RHT208Z:RP80Ng]k0P21PH400`1nOWh0N7Qh07QhN002
07IfMP80LG5a101YJFT205MGE`80DU9B0P1IFET205]KF`80G5aL0P1MGEd2051@D080FEUI0P1KFe/2
05UIF@03055AD@1<C4`0C4a<0080A4A40P1LG5`203De=@80C4a<0P1PH60202d];@80:b/[0P0V9RH2
03/k>`80IFEU0P0/;2`205ADE080FUYJ0P1NGUh00`1:BTX0C4a<04a<C00205UIF@80JVYZ0P1YJFT2
08B4Q080NGUi0P1dM7@206ATI080IFEU0P19BDT206EUI@80QXJ60P1/K6`206MWI`80L71`00<0U9BD
06IVIP1VIVH00P2@T9020;jn_P80Rh^;0P28R8P209nOW`80VYZJ0P2XZ:P209fMW@80YJFU0P2GUiL2
0:2PX080VYZJ0P2NWYh209fMW@030:6QX@2TY:@0Y:BT0080Vi^K0P2SXj<40:6QX@80X:2P0P2QXJ4E
0?ooo`004`3oool20::RXP80WYjN0P2MWId20:2PX080Xj>S0P2VYZH209ZJVP80YJFU00<0XJ6Q0:2P
X02PX:000P2RXZ820:BTY080XJ6Q0P2IVIT20:NWY`80X:2P0P2NWYh20:6QX@80Xj>S0P2GUiL20:RX
Z080Vi^K0P2QXJ4209ZJVP0309^KV`2OWil0WinO0080WinO0P1jNWX206MWI`80GemO0P1HF5P204m?
C`80D51@0P0l?3`204M7A`@0@d=30P0b<S8201/K6`80?3`l00<0<C4a02`/;00/;2`00P0X:2P207em
O@80bLW90P2BTY8209RHV080QhN70P2:RXX208J6QP80QhN70P28R8P208V9R@80RXZ:0P1kNg/20861
P@0307inOP1hN7P0N7Qh0080MWIf0P1aLG4406UYJ@80EeMG0P1BDU8205UIF@80Fe]K0P1LG5`205eM
G@80D51@0P1IFET205]KF`80FEUI00<0DE5A04a<C01<C4`00P14A4@205aLG080=CDe0P1<C4`2061P
H080;Bd]0P0[:b/202HV9P80>c/k0P1UIFD202`/;080E5AD0P1JFUX205iNGP0304Y:BP1<C4`0C4a<
0080FEUI0P1ZJVX206UYJ@80Q8B40P1iNGT207AdM080I6AT0P1UIFD204U9B@80IFEU0P26QXH206a/
K080IfMW0P1`L7000`2DU9@0IVIV06IVIP02092@T080_[jn0P2;Rh/208R8R080WinO0P2JVYX20:RX
Z080WIfM0P2UYJD209NGU`80X:2P0P2JVYX209jNWP80WIfM00<0XJ6Q0:BTY02TY:@00P2KVi/20:>S
X`@0XJ6Q0P2PX:020:6QXAD0oooo000C0?ooo`80WIfM0P2QXJ4209ZJVP80YZJV102KVi/20::RXP80
Vi^K00<0Xj>S0:6QX@2QXJ40102QXJ4209^KV`80VIVI0P2VYZH409^KV`80YJFU0P2KVi/209ZJVP80
Z:RX0P2JVYX209fMW@80VIVI00<0WIfM0:2PX02PX:000P2NWYh207=cL`80Hf=S101JFUX204Y:BP@0
Bd];0P19BDT20410@080C4a<0P0K6a/202/[:`80?Shn00<0:b/[02`/;00/;2`00P1kNg/20<_;b`80
/;2`0P2EUID2092@T080Shn?0P27QhL209BDU080QhN70P2@T90208N7Q`80QXJ60P23Ph<208Z:RP03
07alO01oOgl0Ogmo0080MgMg0P1iNGT2075aL@80LW9b0P1YJFT206QXJ080DE5A1P1DE5@205YJFP80
EEEE0P1KFe/2059BDP0304M7A`1:BTX0BTY:0080=SHf0P0d=3@205QHF080@4100P1aLG42020P8080
9RHV0P0K6a/202HV9P80I6AT0P1;Bd/20410@080FEUI0P1bLW800`15ADD0Jf][06][J`0205ADE080
JFUY0P1hN7P408N7Q`80Q8B40P1`L7020451@@80H61P0P1YJFT2075aL@80H61P0P1bLW8207alO003
07inOP1YJFT0JFUY0080`L710P2RXZ820820P080W9bL0P2ZZZX20:2PX080ZZZZ0P2PX:0209bLW080
XJ6Q0P2TY:@20:6QX@80Y:BT0P2MWId00`2PX:00Xj>S0:>SX`020:2PX080Y:BT0P2QXJ4209^KV`80
Xj>S0P2QXJ4E0?ooo`004`3oool209fMW@80XJ6Q0P2JVYX20:JVYP@0Vi^K0P2RXZ8209^KV`030:>S
X`2QXJ40XJ6Q00@0XJ6Q0P2KVi/209VIV@80YZJV102KVi/20:FUY@80Vi^K0P2JVYX20:RXZ080VYZJ
0P2MWId209VIV@0309fMW@2PX:00X:2P0080WYjN0P1cLg<206=SH`@0FUYJ0P1:BTX404];B`80BDU9
0P10@40204a<C0806a/K0P0[:b/203hn?P0302/[:`0/;2`0;2`/0080Ng]k0P3;bl/20;2`/080UIFE
0P2@T90208n?S`80QhN70P2DU9@208N7Q`80T92@0P27QhL208J6QP80Ph>30P2:RXX00`1lO7`0Ogmo
07moO`0207MgM`80NGUi0P1aLG42079bLP80JFUY0P1XJ6P2055AD@H0E5AD0P1JFUX205EEE@80Fe]K
0P1BDU800`17AdL0BTY:04Y:BP0203Hf=P80=3@d0P1HF5P20410@080LG5a0P0P820202HV9P806a/K
0P0V9RH206ATI080Bd];0P10@40205UIF@80LW9b00<0ADE506][J`1[Jf/00P1DE5@206UYJ@80N7Qh
1027QhL208B4Q080L71`0P11@D42061PH080JFUY0P1aLG42061PH080LW9b0P1lO7`00`1nOWh0JFUY
06UYJ@020<71`@80XZ:R0P20P80209bLW080ZZZZ0P2PX:020:ZZZP80X:2P0P2LW9`20:6QX@80Y:BT
0P2QXJ420:BTY080WIfM00<0X:2P0:>SX`2SXj<00P2PX:020:BTY080XJ6Q0P2KVi/20:>SX`80XJ6Q
5@3oool001<0oooo0P2RXZ8209jNWP80XJ6Q0P2UYJD20:2PX080XZ:R0P2UYJD209JFUP030::RXP2K
Vi/0Vi^K0080Xj>S0P2QXJ420:2PX080VYZJ102QXJ4209fMW@80X:2P0P2KVi/209jNWP80YJFU0P2P
X:020:6QX@80Xj>S00<0VYZJ09FEU@2EUID00P24Q8@207=cL`80EEEE0P1NGUh2055AD@80@d=30P0m
?Cd204U9B@80ATI60P10@40203Lg=`806a/K0P0n?Sh203Xj>P0302TY:@36a/H0a/K60080a<C40P2W
YjL2096AT@80UIFE0P2?Shl2096AT@80SXj>0P2DU9@208:2PP80Rh^;0P27QhL208j>SP80QHF50P27
QhL00`23Ph<0RHV908V9R@0207emO@@0MGEe0P1lO7`2071`L080Jf][0P1PH60204a<C080CTi>0P1?
Cdl205QHF080Bd];0P1DE5@204a<C00304Q8B017AdL0AdM70080;Bd]0P0a<C4207moO`809bLW0P25
QHD203<c<`80:2PX0P0g=cL201`L7080@T920P1YJFT202XZ:P80GemO0P1VIVH00`15ADD0KVi^06i^
KP0205aLG080IFEU0P1aLG4207=cL`80Shn?0P23Ph<206YZJP80CTi>0P1LG5`206ATI080K6a/0P1U
IFD208B4Q080O7al00<0MGEe08N7Q`27QhL00P2d];@208N7Q`80T92@0P2[Zj/209nOW`80YZJV0P2L
W9`20:>SX`80VIVI0P2VYZH20:6QX@80Vi^K0P2MWId20:6QX@0309fMW@2PX:00X:2P0080Xj>S102Q
XJ420:2PX080Y:BT0P2QXJ4E0?ooo`004`3oool20::RXP80WYjN0P2QXJ420:FUY@80X:2P0P2RXZ82
0:FUY@80UYJF00<0XZ:R09^KV`2KVi/00P2SXj<20:6QX@80X:2P0P2JVYX40:6QX@80WIfM0P2PX:02
09^KV`80WYjN0P2UYJD20:2PX080XJ6Q0P2SXj<00`2JVYX0UIFE09FEU@0208B4Q080Lg=c0P1EEED2
05iNGP80DE5A0P13@d<203dm?@80BDU90P16ATH20410@080=cLg0P0K6a/203hn?P80>SXj00<0:BTY
0<K6aP36a/H00P34a<@20:NWY`80TI6A0P2EUID208n?S`80TI6A0P2>SXh209BDU080PX:20P2;Rh/2
08N7Q`80SXj>0P25QHD208N7Q`0308>3P`29RHT0RHV90080OGem101eMGD207alO080L71`0P1[Jf/2
061PH080C4a<0P1>CTh204m?C`80F5QH0P1;Bd/205ADE080C4a<00<0B4Q804M7A`17AdL00P0];Bd2
034a<@80Ogmo0P0W9bL208F5Q@80<c<c0P0X:2P203Lg=`8071`L0P12@T8206UYJ@80:RXZ0P1OGel2
06IVIP0304E5A@1^KVh0KVi^0080G5aL0P1UIFD2075aL@80Lg=c0P2?Shl208>3P`80JVYZ0P1>CTh2
05aLG080I6AT0P1/K6`206EUI@80Q8B40P1lO7`00`1eMGD0QhN708N7Q`020;Bd]080QhN70P2@T902
0:^[Z`80WinO0P2VYZH209bLW080Xj>S0P2IVIT20:JVYP80XJ6Q0P2KVi/209fMW@80XJ6Q00<0WIfM
0:2PX02PX:000P2SXj<40:6QX@80X:2P0P2TY:@20:6QXAD0oooo000C0?ooo`80XJ6Q0P2PX:020:BT
Y080XJ6Q0P2IVIT20:>SX`80XJ6Q0P2OWil00`2TY:@0XZ:R0::RXP020:FUY@80XJ6Q0P2IVIT209bL
W080WIfM0P2VYZH20:2PX080WIfM0P2TY:@20::RXP80Y:BT102QXJ4209^KV`0309JFUP2CTi<0Ti>C
0080N7Qh0P1dM7@2051@D080GEeM0P1@D50204Q8B080@d=30P1;Bd/40451@@809RHV0P0U9BD203Xj
>P80:b/[00<0K6a/0>?Sh`3Shn<00P2BTY8208>3P`80T92@0P2>SXh209:BTP80T92@0P2ATI42092@
T080S8b<0P2CTi<208N7Q`80Rh^;0P23Ph<308N7Q`80OWin0P1hN7P207moO`80OGem0P1iNGT207If
MP80LG5a0P1[Jf/205EEE@80L71`0P15ADD204e=C@80CTi>0P1<C4`204];B`0304A4A00j>SX0>SXj
0080<c<c0P0a<C4207]kN`80ADE50P1_Kfl204U9B@807AdM0P0L71`203<c<`80FEUI0P1cLg<205MG
E`80JFUY0P1PH6000`1OGel0Cdm?04m?C`0206YZJP80HV9R0P1]KFd207AdM080PX:20P26QXH207]k
N`80Cdm?0P1<C4`206YZJP80FEUI0P1[Jf/208j>SP80QXJ600<0N7Qh07UiN@1iNGT00P2EUID20:2P
X080YZJV0P2UYJD20:2PX080Z:RX0P2IVIT20:JVYP80VYZJ0P2UYJD409^KV`@0Y:BT00<0X:2P0::R
XP2RXZ800P2NWYh20:>SX`@0XJ6Q0P2KVi/20:>SXaD0oooo000C0?ooo`80XJ6Q0P2PX:020:BTY080
XJ6Q0P2IVIT20:>SX`80XJ6Q0P2OWil00`2TY:@0XZ:R0::RXP020:FUY@80XJ6Q0P2IVIT209bLW080
WIfM0P2VYZH20:2PX080WIfM0P2TY:@20::RXP80Y:BT102QXJ4209^KV`0309JFUP2CTi<0Ti>C0080
N7Qh0P1dM7@2051@D080GEeM0P1@D50204Q8B080@d=30P1;Bd/40451@@809RHV0P0U9BD203Xj>P80
:b/[00<0K6a/0>?Sh`3Shn<00P2BTY8208>3P`80T92@0P2>SXh209:BTP80T92@0P2ATI42092@T080
S8b<0P2CTi<208N7Q`80Rh^;0P23Ph<308N7Q`80OWin0P1hN7P207moO`80OGem0P1iNGT207IfMP80
LG5a0P1[Jf/205EEE@80L71`0P15ADD204e=C@80CTi>0P1<C4`204];B`0304A4A00j>SX0>SXj0080
<c<c0P0a<C4207]kN`80ADE50P1_Kfl204U9B@807AdM0P0L71`203<c<`80FEUI0P1cLg<205MGE`80
JFUY0P1PH6000`1OGel0Cdm?04m?C`0206YZJP80HV9R0P1]KFd207AdM080PX:20P26QXH207]kN`80
Cdm?0P1<C4`206YZJP80FEUI0P1[Jf/208j>SP80QXJ600<0N7Qh07UiN@1iNGT00P2EUID20:2PX080
YZJV0P2UYJD20:2PX080Z:RX0P2IVIT20:JVYP80VYZJ0P2UYJD409^KV`@0Y:BT00<0X:2P0::RXP2R
XZ800P2NWYh20:>SX`@0XJ6Q0P2KVi/20:>SXaD0oooo000C0?ooo`80Vi^K0P2SXj<209^KV`80Xj>S
0P2OWil20:FUY@80VIVI0P2SXj<00`2KVi/0WIfM09fMW@020:>SX`@0Vi^K0P2OWil209^KV`80YjNW
102KVi/209fMW@80Xj>S0P2QXJ4209JFUP80Y:BT0P2GUiL00`2HV9P0RHV908V9R@0207QhN080IVIV
0P1EEED205iNGP80CDe=0P16ATH203Hf=P80@d=30P0f=SH204E5A@806ATI0P0^;Rh203Hf=P80AdM7
00<0d];B0:ZZZP2ZZZX00P2@T90208Z:RP80T92@0P2=SHd209FEU@80Q8B40P2CTi<208B4Q080QhN7
0P2DU9@208:2PP80RHV90P25QHD208J6QP0308R8R025QHD0QHF50080QXJ61P1lO7`407IfMP80LG5a
0P1XJ6P206][J`80EEEE0P12@T8204i>CP80Bd];0P11@D400`18B4P0<c<c03<c<`0203De=@807alO
0P1UIFD207alO080;bl_0P1jNWX203@d=080EEEE0P0X:2P205aLG080>SXj0P1`L7020451@@80GemO
00<0GEeM05mOG`1OGel00P1TI6@206][J`80EEEE0P27QhL206EUI@80U9BD0P2BTY8204E5A@80Bd];
0P1/K6`2069RHP@0MgMg0P1iNGT00`1aLG40QHF508F5Q@020:ZZZP80ZJVY0P2KVi/209nOW`80Vi^K
102QXJ4209jNWP80XJ6Q0P2TY:@209ZJVP80WYjN0P2UYJD209^KV`0309fMW@2SXj<0Xj>S0080VYZJ
0P2PX:020:>SX`80Vi^K0P2QXJ420:BTY1D0oooo000C0?ooo`80Vi^K0P2SXj<209^KV`80Xj>S0P2O
Wil20:FUY@80VIVI0P2SXj<00`2KVi/0WIfM09fMW@020:>SX`@0Vi^K0P2OWil209^KV`80YjNW102K
Vi/209fMW@80Xj>S0P2QXJ4209JFUP80Y:BT0P2GUiL00`2HV9P0RHV908V9R@0207QhN080IVIV0P1E
EED205iNGP80CDe=0P16ATH203Hf=P80@d=30P0f=SH204E5A@806ATI0P0^;Rh203Hf=P80AdM700<0
d];B0:ZZZP2ZZZX00P2@T90208Z:RP80T92@0P2=SHd209FEU@80Q8B40P2CTi<208B4Q080QhN70P2D
U9@208:2PP80RHV90P25QHD208J6QP0308R8R025QHD0QHF50080QXJ61P1lO7`407IfMP80LG5a0P1X
J6P206][J`80EEEE0P12@T8204i>CP80Bd];0P11@D400`18B4P0<c<c03<c<`0203De=@807alO0P1U
IFD207alO080;bl_0P1jNWX203@d=080EEEE0P0X:2P205aLG080>SXj0P1`L7020451@@80GemO00<0
GEeM05mOG`1OGel00P1TI6@206][J`80EEEE0P27QhL206EUI@80U9BD0P2BTY8204E5A@80Bd];0P1/
K6`2069RHP@0MgMg0P1iNGT00`1aLG40QHF508F5Q@020:ZZZP80ZJVY0P2KVi/209nOW`80Vi^K102Q
XJ4209jNWP80XJ6Q0P2TY:@209ZJVP80WYjN0P2UYJD209^KV`0309fMW@2SXj<0Xj>S0080VYZJ0P2P
X:020:>SX`80Vi^K0P2QXJ420:BTY1D0oooo000C0?ooo`80WinO0P2WYjL209ZJVP80YJFU102QXJ42
09VIV@80X:2P00<0XJ6Q0::RXP2RXZ800P2TY:@20:2PX080WIfM0P2NWYh20:>SX`80WinO0P2QXJ44
0::RXP80YJFU0P2QXJ4209jNWP80X:2P0P2@T9000`2FUYH0Ng]k07]kN`020820P080EUIF0P1HF5P2
04];B`80Cdm?0P11@D4203dm?@80ADE50P0i>CT202XZ:P808R8R0P11@D4204M7A`80a/K600<0^KVi
08f=S@2=SHd00P2ATI4408f=S@80QhN70P2<S8`20820P080RHV90P22PX8208N7Q`80RHV90P21PH42
07YjNP80O7al0P21PH400`29RHT0OGem07emO@0208:2PP80MWIf0P1nOWh207AdM0@0N7Qh0P1fMWH2
075aL@80JVYZ0P1UIFD205eMG@80@d=30P0j>SX204Q8B00303Ph>00f=SH0=SHf0080:RXZ0P0Y:BT2
04];B`80O7al0P14A4@205QHF080K6a/0P0];Bd205YJFP80BDU90P1;Bd/2061PH080EUIF0P1@D500
0`1OGel0IfMW06MWI`0203hn?P80KFe]0P1LG5`20861P@80IfMW0P25QHD207YjNP80L71`0P1EEED2
04m?C`80IfMW0P1dM7@206EUI@80P82000<0R8R80:2PX02PX:000P2c/k<2092@T080XJ6Q0P2RXZ82
09VIV@80YjNW0P2NWYh209^KV`80YJFU0P2KVi/20:6QX@80XZ:R0P2NWYh20:6QX@0309fMW@2UYJD0
YJFU0080X:2P0P2RXZ8209jNWP80XJ6Q0P2TY:@20:6QXAD0oooo000C0?ooo`80WinO0P2WYjL209ZJ
VP80YJFU102QXJ4209VIV@80X:2P00<0XJ6Q0::RXP2RXZ800P2TY:@20:2PX080WIfM0P2NWYh20:>S
X`80WinO0P2QXJ440::RXP80YJFU0P2QXJ4209jNWP80X:2P0P2@T9000`2FUYH0Ng]k07]kN`020820
P080EUIF0P1HF5P204];B`80Cdm?0P11@D4203dm?@80ADE50P0i>CT202XZ:P808R8R0P11@D4204M7
A`80a/K600<0^KVi08f=S@2=SHd00P2ATI4408f=S@80QhN70P2<S8`20820P080RHV90P22PX8208N7
Q`80RHV90P21PH4207YjNP80O7al0P21PH400`29RHT0OGem07emO@0208:2PP80MWIf0P1nOWh207Ad
M0@0N7Qh0P1fMWH2075aL@80JVYZ0P1UIFD205eMG@80@d=30P0j>SX204Q8B00303Ph>00f=SH0=SHf
0080:RXZ0P0Y:BT204];B`80O7al0P14A4@205QHF080K6a/0P0];Bd205YJFP80BDU90P1;Bd/2061P
H080EUIF0P1@D5000`1OGel0IfMW06MWI`0203hn?P80KFe]0P1LG5`20861P@80IfMW0P25QHD207Yj
NP80L71`0P1EEED204m?C`80IfMW0P1dM7@206EUI@80P82000<0R8R80:2PX02PX:000P2c/k<2092@
T080XJ6Q0P2RXZ8209VIV@80YjNW0P2NWYh209^KV`80YJFU0P2KVi/20:6QX@80XZ:R0P2NWYh20:6Q
X@0309fMW@2UYJD0YJFU0080X:2P0P2RXZ8209jNWP80XJ6Q0P2TY:@20:6QXAD0oooo000C0?ooo`80
XZ:R0P2TY:@209ZJVP80YJFU102QXJ4209ZJVP80Y:BT00<0WYjN09fMW@2MWId0102MWId20:6QX@80
XZ:R0P2NWYh20:6QX@80WYjN102KVi/209jNWP80WIfM0P2SXj<20:2PX080Shn?00<0QhN707inOP1n
OWh00P1^KVh2051@D080Cdm?0P1;Bd/204=3@`80?3`l0P11@D4204=3@`80820P0P0Z:RX202PX:080
:b/[0P3;bl/20;^k^`03092@T02<S8`0S8b<00@0QXJ60P29RHT208B4Q080Ogmo0P1gMgL207EeM@80
MgMg0P1cLg<407AdM080K6a/1@1gMgL2079bLP80Ogmo0P1jNWX207emO@80O7al0P1oOgl207EeM@80
N7Qh0P1aLG4406a/K080KVi^0P1IFET204e=C@80@T9200<0=cLg03Ti>@0i>CT00P0^;Rh202`/;080
?3`l0P1EEED2079bLP80GUiN0P1MGEd206EUI@80IfMW0P1BDU8202l_;`80EeMG0P1[Jf/205IFEP03
065QH@1;Bd/0Bd];0080De=C0P1SHf<207UiN@80JVYZ0P1`L70207emO@80Rh^;0P2@T90204M7A`80
IFEU0P1nOWh206UYJ@80GemO0P25QHD00`2=SHd0^k^k0;^k^`0209BDU080X:2P0P2RXZ8209nOW`80
VIVI0P2YZJT20:2PX080WIfM0P2UYJD209NGU`80X:2P0P2SXj<209ZJVP80X:2P00<0XJ6Q0:BTY02T
Y:@0102QXJ420:2PX080Y:BT0P2QXJ4209^KVaD0oooo000C0?ooo`80XZ:R0P2TY:@209ZJVP80YJFU
102QXJ4209ZJVP80Y:BT00<0WYjN09fMW@2MWId0102MWId20:6QX@80XZ:R0P2NWYh20:6QX@80WYjN
102KVi/209jNWP80WIfM0P2SXj<20:2PX080Shn?00<0QhN707inOP1nOWh00P1^KVh2051@D080Cdm?
0P1;Bd/204=3@`80?3`l0P11@D4204=3@`80820P0P0Z:RX202PX:080:b/[0P3;bl/20;^k^`03092@
T02<S8`0S8b<00@0QXJ60P29RHT208B4Q080Ogmo0P1gMgL207EeM@80MgMg0P1cLg<407AdM080K6a/
1@1gMgL2079bLP80Ogmo0P1jNWX207emO@80O7al0P1oOgl207EeM@80N7Qh0P1aLG4406a/K080KVi^
0P1IFET204e=C@80@T9200<0=cLg03Ti>@0i>CT00P0^;Rh202`/;080?3`l0P1EEED2079bLP80GUiN
0P1MGEd206EUI@80IfMW0P1BDU8202l_;`80EeMG0P1[Jf/205IFEP03065QH@1;Bd/0Bd];0080De=C
0P1SHf<207UiN@80JVYZ0P1`L70207emO@80Rh^;0P2@T90204M7A`80IFEU0P1nOWh206UYJ@80GemO
0P25QHD00`2=SHd0^k^k0;^k^`0209BDU080X:2P0P2RXZ8209nOW`80VIVI0P2YZJT20:2PX080WIfM
0P2UYJD209NGU`80X:2P0P2SXj<209ZJVP80X:2P00<0XJ6Q0:BTY02TY:@0102QXJ420:2PX080Y:BT
0P2QXJ4209^KVaD0oooo000C0?ooo`80XJ6Q0P2KVi/20:6QX@80Y:BT0P2QXJ4209^KV`80XJ6Q0P2T
Y:@00`2PX:00XZ:R0::RXP0209fMW@@0Y:BT0P2QXJ420:2PX080Y:BT0P2JVYX209fMW@80WYjN0P2U
YJD20::RXP80WYjN0P2MWId208j>SP030861P@22PX80PX:20080IFEU0P1HF5P204U9B@80De=C0P16
ATH203De=@80A4A40P0k>c/2024Q8@80;bl_0P0l?3`20<;2`P80e=CD0P2<S8`00`2ATI40R8R808R8
R00208B4Q0@0QhN70P1mOGd2079bLP80MGEe0P1^KVh206a/K080IVIV101YJFT206QXJ080Jf][0P1f
MWH00`1]KFd0MGEe07EeM@0207]kN`80LG5a0P21PH4407inOP80Lg=c0P1hN7P2075aL@80L71`0P1/
K6`406EUI@80EeMG0P0g=cL00`0a<C40=SHf03Hf=P0202TY:@807QhN0P0`<302059BDP80QXJ60P19
BDT203Ph>080U9BD0P1;Bd/206m_K`80Bd];0P1>CTh205IFEP80JVYZ00<0FEUI04m?C`1?Cdl00P1]
KFd205MGE`80PX:20P1QHF420861P@80KVi^0P1mOGd208n?S`80GUiN0P1`L70206m_K`80JFUY0P1_
Kfl208F5Q@0308j>SP2f][H0][Jf0080TI6A0P2YZJT209RHV080XJ6Q0P2SXj<20:2PX080Xj>S0P2P
X:0209^KV`80XJ6Q102TY:@209ZJVP<0Y:BT0P2KVi/20:>SX`P0XJ6Q0P2PX:0E0?ooo`004`3oool2
0:6QX@80Vi^K0P2QXJ420:BTY080XJ6Q0P2KVi/20:6QX@80Y:BT00<0X:2P0::RXP2RXZ800P2MWId4
0:BTY080XJ6Q0P2PX:020:BTY080VYZJ0P2MWId209jNWP80YJFU0P2RXZ8209jNWP80WIfM0P2>SXh0
0`21PH40PX:208:2PP0206EUI@80F5QH0P19BDT205=CD`80ATI60P0e=CD204A4A080>c/k0P0Q8B42
02l_;`80?3`l0P32`/820=CDe080S8b<00<0TI6A08R8R028R8P00P24Q8@408N7Q`80OGem0P1bLW82
07EeM@80KVi^0P1/K6`206IVIP@0JFUY0P1XJ6P206][J`80MWIf00<0KFe]07EeM@1eMGD00P1kNg/2
075aL@80PH61101nOWh207=cL`80N7Qh0P1aLG42071`L080K6a/101UIFD205MGE`80=cLg00<0<C4a
03Hf=P0f=SH00P0Y:BT201hN7P80<30`0P1BDU8208J6QP80BDU90P0h>3P209BDU080Bd];0P1_Kfl2
04];B`80CTi>0P1FEUH206YZJP0305UIF@1?Cdl0Cdm?0080KFe]0P1GEeL208:2PP80HF5Q0P21PH42
06i^KP80OGem0P2?Shl205iNGP80L71`0P1_Kfl206UYJ@80Kfm_0P25QHD00`2>SXh0][Jf0;Jf]P02
096AT@80ZJVY0P2HV9P20:6QX@80Xj>S0P2PX:020:>SX`80X:2P0P2KVi/20:6QX@@0Y:BT0P2JVYX3
0:BTY080Vi^K0P2SXj<80:6QX@80X:2P5@3oool001<0oooo0P2QXJ4209ZJVP80YJFU0P2QXJ4209^K
V`80XJ6Q0P2TY:@50:6QX@80VYZJ0P2UYJD80:6QX@80X:2P0P2MWId209bLW080WYjN0P2SXj<209ZJ
VP80VIVI0P21PH400`1oOgl0QHF508F5Q@0205IFEP@0BTY:0P14A4@204Y:BP80=CDe0P0i>CT202PX
:080:BTY0P0a<C4203`l?080h^;R0P2:RXX208J6QP0308N7Q`25QHD0QHF50080QHF50P26QXH207Yj
NP80Bd];0P1<C4`2061PH080Fe]K101SHf<606EUI@80D51@0P1FEUH00`1ADE40E5AD05ADE00207If
MP80NWYj0P1lO7`207moO`80OWin0P1kNg/407IfMP80LW9b0P1ZJVX206e]K@80IfMW0P1KFe/205IF
EP0302d];@0[:b/0:b/[00809RHV0P0J6QX202d];@80B4Q80P1UIFD2079bLP80EEEE0P1gMgL207If
MP80Jf][0P1/K6`206=SH`80GUiN0P1JFUX00`1OGel0HV9R069RHP0204a<C080DE5A0P1^KVh2071`
L080HF5Q0P1mOGd207]kN`80SXj>0P1kNg/2061PH080Ng]k0P1QHF42075aL@80T92@00<0UYJF09nO
W`2OWil00P2MWId20:6QX@80U9BD0P2NWYh209nOW`80XZ:R0P2KVi/209jNWP80X:2P0P2OWil20:>S
X`80XJ6Q0P2PX:0209jNWP030:>SX`2PX:00X:2P0080WYjN0P2SXj<20:6QX@80Vi^K0P2SXj<20:6Q
XAD0oooo000C0?ooo`80XJ6Q0P2JVYX20:FUY@80Vi^K0P2QXJ4209jNWP80Xj>S1@2QXJ4209ZJVP80
YJFU0P2QXJ4409^KV`80Xj>S0P2QXJ4209ZJVP@0Xj>S0P2MWId20::RXP80TI6A0P26QXH00`2:RXX0
J6QX06QXJ002055AD@80B4Q80P17AdL204=3@`80@T920P0`<30203dm?@80;Rh^0P0/;2`203/k>`80
d=3@0P31`L4408N7Q`0308J6QP2=SHd0SHf=0080QXJ60P1LG5`205]KF`80EUIF0P1VIVH20:VYZ@80
QHF50P1YJFT206e]K@80P8200P2:RXX205iNGP80HV9R0`1SHf<205]KF`80GEeM0P1jNWX407]kN`80
Ogmo0P1nOWh207=cL`@0MgMg0P1^KVh206e]K@80I6AT0P1SHf<205iNGP0304Y:BP0^;Rh0;Rh^0080
7QhN0P0O7al201hN7P80BTY:0P0N7Qh20:6QX@80MWIf0P0k>c/209BDU080AdM70P22PX8207IfMP80
EeMG0P1NGUh00`1cLg<0@D510451@@02061PH080Fe]K0P1[Jf/206i^KP80I6AT0P1kNg/207UiN@80
SXj>0P2:RXX204m?C`80FUYJ0P1RHV8207AdM080PH6100<0/k>c0:2PX02PX:000P2VYZH209jNWP80
Ti>C0P2[Zj/20:BTY080W9bL0P2KVi/209nOW`80YJFU0P2JVYX20:FUY@80Vi^K0P2MWId20:6QX@03
0:BTY02KVi/0Vi^K0080XJ6Q0P2TY:@409^KV`80YJFU0P2KVi/E0?ooo`004`3oool20:6QX@80VYZJ
0P2UYJD209^KV`80XJ6Q0P2NWYh20:>SX`D0XJ6Q0P2JVYX20:FUY@80XJ6Q102KVi/20:>SX`80XJ6Q
0P2JVYX40:>SX`80WIfM0P2RXZ82096AT@80QXJ600<0RXZ:06QXJ01XJ6P00P1ADE4204Q8B080AdM7
0P13@d<20492@P80<30`0P0m?Cd202h^;P80;2`/0P0k>c/20=3@d080`L711027QhL00`26QXH0SHf=
08f=S@0208J6QP80G5aL0P1KFe/205IFEP80IVIV0P2YZJT208F5Q@80JFUY0P1]KFd20820P080RXZ:
0P1NGUh2069RHP<0Hf=S0P1KFe/205eMG@80NWYj101kNg/207moO`80OWin0P1cLg<407MgM`80KVi^
0P1]KFd206ATI080Hf=S0P1NGUh00`1:BTX0;Rh^02h^;P0201hN7P807alO0P0N7Qh204Y:BP807QhN
0P2QXJ4207IfMP80>c/k0P2DU9@204M7A`80PX:20P1fMWH205MGE`80GUiN00<0Lg=c0451@@11@D40
0P1PH60205]KF`80Jf][0P1^KVh206ATI080Ng]k0P1iNGT208j>SP80RXZ:0P1?Cdl205YJFP80HV9R
0P1dM7@20861P@030;>c/`2PX:00X:2P0080YZJV0P2NWYh209>CT`80Zj^[0P2TY:@209bLW080Vi^K
0P2OWil20:FUY@80VYZJ0P2UYJD209^KV`80WIfM0P2QXJ400`2TY:@0Vi^K09^KV`020:6QX@80Y:BT
102KVi/20:FUY@80Vi^K5@3oool001<0oooo0P2MWId20:6QX@80WYjN0P2QXJ4209jNWP80XJ6Q0P2N
WYh20:>SX`0309^KV`2MWId0WIfM0080XJ6Q0P2NWYh209fMW@80Vi^K0P2MWId20:2PX080WIfM0P2I
VIT20:JVYP80XJ6Q0P2GUiL20:NWY`80OGem0P1nOWh00`1UIFD0DU9B059BDP02055AD@80C4a<0P0c
<c<20492@P80=cLg0P12@T82020P8080:b/[0P0/;2`207=cL`80g]kN0P29RHT208b<S0<0QXJ60P28
R8P208B4Q080AdM70P1UIFD206IVIP80H61P0P1VIVH205=CD`80DU9B0P1WIfL205=CD`80E5AD0P0m
?Cd204m?C`80CDe=00<0MWIf05ADE01DE5@00P1JFUX204m?C`80QHF50P1nOWh208:2PP80OWin0P1k
Ng/207inOP80MWIf0P1^KVh206][J`80KFe]0P1VIVH206MWI`0305]KF`17AdL0AdM7008092@T0P0^
;Rh201<C4`80<C4a0P13@d<208V9R@80JFUY0P12@T8207QhN080LW9b0P1SHf<208:2PP80T92@0P1E
EED00`1ADE40FEUI05UIF@0206YZJP80AdM70P1NGUh2071`L080IfMW0P1dM7@2071`L080TI6A0P24
Q8@205ADE080Hf=S0P1eMGD206MWI`80Ogmo00<0`l?309VIV@2IVIT00P2SXj<409FEU@80[Zj^0P2Q
XJ4209nOW`80Y:BT0P2RXZ820:BTY080X:2P0P2NWYh20:6QX@80XZ:R0P2TY:@00`2QXJ40X:2P0:2P
X0020:BTY080XJ6Q0P2PX:020::RXP80Y:BT0P2PX:0E0?ooo`004`3oool209fMW@80XJ6Q0P2NWYh2
0:6QX@80WYjN0P2QXJ4209jNWP80Xj>S00<0Vi^K09fMW@2MWId00P2QXJ4209jNWP80WIfM0P2KVi/2
09fMW@80X:2P0P2MWId209VIV@80YZJV0P2QXJ4209NGU`80YjNW0P1mOGd207inOP0306EUI@1BDU80
DU9B0080DE5A0P1<C4`203<c<`80@T920P0g=cL20492@P80820P0P0[:b/202`/;080Lg=c0P3Ng]h2
08V9R@80S8b<0`26QXH208R8R080Q8B40P17AdL206EUI@80IVIV0P1PH60206IVIP80De=C0P1BDU82
06MWI`80De=C0P1DE5@203dm?@80Cdm?0P1=CDd00`1fMWH0E5AD05ADE00205YJFP80Cdm?0P25QHD2
07inOP80PX:20P1nOWh207]kN`80OWin0P1fMWH206i^KP80Jf][0P1]KFd206IVIP80IfMW00<0Fe]K
04M7A`17AdL00P0T92@202h^;P804a<C0P0a<C4204=3@`80RHV90P1YJFT20492@P80N7Qh0P1bLW82
06=SH`80PX:20P2@T90205EEE@03055AD@1IFET0FEUI0080JVYZ0P17AdL205iNGP80L71`0P1WIfL2
07AdM080L71`0P2ATI4208B4Q080E5AD0P1SHf<207EeM@80IfMW0P1oOgl00`33`l<0VIVI09VIV@02
0:>SX`@0UIFE0P2^[Zh20:6QX@80WinO0P2TY:@20::RXP80Y:BT0P2PX:0209jNWP80XJ6Q0P2RXZ82
0:BTY0030:6QX@2PX:00X:2P0080Y:BT0P2QXJ420:2PX080XZ:R0P2TY:@20:2PX1D0oooo000C0?oo
o`80XZ:R0P2TY:@20:2PX080Y:BT0P2JVYX20:2PX080XJ6Q0P2NWYh00`2KVi/0WYjN09jNWP020:FU
Y@80VYZJ102NWYh20:BTY080XZ:R102MWId20:JVYP@0Vi^K0P2QXJ4207UiN@80N7Qh00<0FUYJ05eM
G@1MGEd00P18B4P20410@080<C4a0P16ATH203De=@809RHV0P0^;Rh202TY:@80Bd];0P3Lg=`20;2`
/080Rh^;1025QHD00`26QXH0G5aL05aLG00205eMG@80?3`l0P0f=SH203dm?@80ADE50P1CDe<204=3
@`80ADE50P1?Cdl203dm?@80>CTi0P0/;2`203Xj>P80@D5100<0;Rh^03Ph>00h>3P00P0e=CD202h^
;P80CDe=0P1`L70208R8R0@0OGem101dM7@207IfMP80JFUY0P1_Kfl206a/K080L71`00<0F5QH059B
DP1BDU800P0c<c<201@D50804Q8B0P0e=CD203hn?P80B4Q80P1`L70207MgM`80=cLg0P2?Shl204I6
AP80PX:20P2CTi<207emO@0305]KF`1aLG40LG5a0080B4Q80P1PH60205aLG080Jf][0P1SHf<205EE
E@80PX:20P2BTY8208:2PP80MGEe0P1WIfL207inOP80IfMW0P2<S8`00`2e]KD0XJ6Q0:6QX@0209RH
V080VYZJ0P2QXJ4209nOW`80Y:BT0P2QXJ4209^KV`80Xj>S0P2KVi/20:>SX`80X:2P0P2TY:@90:6Q
X@80Vi^K0P2SXj<209^KV`80Xj>S0P2QXJ4E0?ooo`004`3oool20::RXP80Y:BT0P2PX:020:BTY080
VYZJ0P2PX:020:6QX@80WYjN00<0Vi^K09jNWP2NWYh00P2UYJD209ZJVP@0WYjN0P2TY:@20::RXP@0
WIfM0P2VYZH409^KV`80XJ6Q0P1iNGT207QhN00305YJFP1MGEd0GEeM0080B4Q80P10@402034a<@80
ATI60P0e=CD202HV9P80;Rh^0P0Y:BT204];B`80g=cL0P2`/;0208^;R`@0QHF500<0QXJ605aLG01L
G5`00P1MGEd203`l?080=SHf0P0m?Cd204E5A@80De=C0P13@d<204E5A@80Cdm?0P0m?Cd203Ti>@80
;2`/0P0j>SX20451@@0302h^;P0h>3P0>3Ph0080=CDe0P0^;Rh204e=C@80L71`0P28R8P407emO@@0
M7Ad0P1fMWH206UYJ@80Kfm_0P1/K6`2071`L00305QHF01BDU80DU9B0080<c<c0P0D51@2018B4P80
=CDe0P0n?Sh204Q8B080L71`0P1gMgL203Lg=`80Shn?0P16ATH208:2PP80Ti>C0P1mOGd00`1KFe/0
LG5a075aL@0204Q8B080H61P0P1LG5`206][J`80Hf=S0P1EEED208:2PP80TY:B0P22PX8207EeM@80
IfMW0P1nOWh206MWI`80S8b<00<0]KFe0:6QX@2QXJ400P2HV9P209ZJVP80XJ6Q0P2OWil20:BTY080
XJ6Q0P2KVi/20:>SX`80Vi^K0P2SXj<20:2PX080Y:BT2@2QXJ4209^KV`80Xj>S0P2KVi/20:>SX`80
XJ6Q5@3oool001<0oooo1P2MWId20:>SX`80X:2P0P2MWId20:2PX080XJ6Q00<0WIfM0:BTY02TY:@0
0P2NWYh20:6QX@80WIfM0P2TY:@209jNWP80WIfM0P2KVi/209jNWP80X:2P0P2IVIT209nOW`80Ti>C
0P1nOWh2071`L003059BDP1?Cdl0Cdm?0080>SXj0P0c<c<20451@@80>SXj0P0c<c<203@d=080>c/k
0P0d=3@20=[JfP80`/;20P25QHD408b<S080QHF500<0QXJ6071`L01`L7000P2@T90205iNGP80DU9B
0P1MGEd205EEE@80GemO0P1=CDd205aLG080KFe]0P1<C4`2059BDP80De=C0P1IFET205QHF003055A
D@2<S8`0S8b<0080P8200P21PH42096AT@80Ti>C0P2?Shl207emO@H0MgMg0P1kNg/206i^KP80KFe]
101^KVh00`1QHF40G5aL05aLG00204E5A@807AdM0P0C4a<201LG5`80;Rh^0P19BDT205mOG`80PX:2
0P1CDe<205ADE080Kfm_0P1IFET209jNWP80QHF500<0PH610492@P12@T800P1JFUX206QXJ080E5AD
0P1YJFT2069RHP80DU9B0P2BTY8207YjNP@0QhN70P1CDe<20820P080IVIV0P2][Jd00`2b/[80WinO
09nOW`0209BDU080VIVI0P2SXj<209fMW@80XZ:R0P2MWId20:6QX@80Y:BT0P2PX:020:BTY080Vi^K
0P2SXj<20:6QX@80Vi^K00<0Xj>S0:6QX@2QXJ400P2KVi/20:6QX@80Y:BT0P2JVYX20:FUY@80XJ6Q
5@3oool001<0oooo1P2MWId20:>SX`80X:2P0P2MWId20:2PX080XJ6Q00<0WIfM0:BTY02TY:@00P2N
WYh20:6QX@80WIfM0P2TY:@209jNWP80WIfM0P2KVi/209jNWP80X:2P0P2IVIT209nOW`80Ti>C0P1n
OWh2071`L003059BDP1?Cdl0Cdm?0080>SXj0P0c<c<20451@@80>SXj0P0c<c<203@d=080>c/k0P0d
=3@20=[JfP80`/;20P25QHD408b<S080QHF500<0QXJ6071`L01`L7000P2@T90205iNGP80DU9B0P1M
GEd205EEE@80GemO0P1=CDd205aLG080KFe]0P1<C4`2059BDP80De=C0P1IFET205QHF003055AD@2<
S8`0S8b<0080P8200P21PH42096AT@80Ti>C0P2?Shl207emO@H0MgMg0P1kNg/206i^KP80KFe]101^
KVh00`1QHF40G5aL05aLG00204E5A@807AdM0P0C4a<201LG5`80;Rh^0P19BDT205mOG`80PX:20P1C
De<205ADE080Kfm_0P1IFET209jNWP80QHF500<0PH610492@P12@T800P1JFUX206QXJ080E5AD0P1Y
JFT2069RHP80DU9B0P2BTY8207YjNP@0QhN70P1CDe<20820P080IVIV0P2][Jd00`2b/[80WinO09nO
W`0209BDU080VIVI0P2SXj<209fMW@80XZ:R0P2MWId20:6QX@80Y:BT0P2PX:020:BTY080Vi^K0P2S
Xj<20:6QX@80Vi^K00<0Xj>S0:6QX@2QXJ400P2KVi/20:6QX@80Y:BT0P2JVYX20:FUY@80XJ6Q5@3o
ool001<0oooo0P2RXZ8209fMW@80WYjN0P2UYJD209^KV`80XJ6Q0P2RXZ820:BTY00309ZJVP2UYJD0
YJFU0080VYZJ0P2UYJD20:2PX080Y:BT0P2PX:020::RXP80VYZJ0P2TY:@209fMW@80V9RH0P2NWYh2
092@T080NWYj0P1TI6@00`18B4P0@D510451@@0204I6AP80?Cdm0P0j>SX203Hf=P80<30`0P0h>3P2
03De=@80?Shn0P3/k>`208B4Q080Rh^;0P2<S8`208J6QP80RHV900<0QHF508Z:RP2:RXX00P2EUID2
08>3P`80UYJF0P2NWYh2096AT@80VYZJ0P2TY:@209JFUP80VIVI0P2EUID20:JVYP80UIFE0P2GUiL2
08f=S@0308V9R@2LW9`0W9bL0080Ph>30P20P80208:2PP80P8200P21PH4207inOP80O7al0P1iNGT2
07IfMP80NGUi0P1`L702079bLP@0KFe]00<0I6AT06IVIP1VIVH00P1?Cdl202d];@807AdM0P0=3@d2
05IFEP80>SXj0P16ATH205aLG080HV9R0P0h>3P207EeM@80@D510P1bLW8208j>SP0308F5Q@1>CTh0
CTi>0080L71`0P1PH60204e=C@80EUIF0P1VIVH206YZJP80Ogmo0P1TI6@209BDU080RXZ:0P1CDe<2
079bLP80FUYJ0P31`L400`2RXZ80UiNG09NGU`0209RHV080UiNG0P2/[:`40::RXP80WIfM0P2UYJD6
0:6QX@80X:2P0P2TY:@209^KV`80XJ6Q00<0WYjN0:>SX`2SXj<00P2PX:020:BTY080Vi^K0P2QXJ42
0:BTY080XJ6Q5@3oool001<0oooo0P2RXZ8209fMW@80WYjN0P2UYJD209^KV`80XJ6Q0P2RXZ820:BT
Y00309ZJVP2UYJD0YJFU0080VYZJ0P2UYJD20:2PX080Y:BT0P2PX:020::RXP80VYZJ0P2TY:@209fM
W@80V9RH0P2NWYh2092@T080NWYj0P1TI6@00`18B4P0@D510451@@0204I6AP80?Cdm0P0j>SX203Hf
=P80<30`0P0h>3P203De=@80?Shn0P3/k>`208B4Q080Rh^;0P2<S8`208J6QP80RHV900<0QHF508Z:
RP2:RXX00P2EUID208>3P`80UYJF0P2NWYh2096AT@80VYZJ0P2TY:@209JFUP80VIVI0P2EUID20:JV
YP80UIFE0P2GUiL208f=S@0308V9R@2LW9`0W9bL0080Ph>30P20P80208:2PP80P8200P21PH4207in
OP80O7al0P1iNGT207IfMP80NGUi0P1`L702079bLP@0KFe]00<0I6AT06IVIP1VIVH00P1?Cdl202d]
;@807AdM0P0=3@d205IFEP80>SXj0P16ATH205aLG080HV9R0P0h>3P207EeM@80@D510P1bLW8208j>
SP0308F5Q@1>CTh0CTi>0080L71`0P1PH60204e=C@80EUIF0P1VIVH206YZJP80Ogmo0P1TI6@209BD
U080RXZ:0P1CDe<2079bLP80FUYJ0P31`L400`2RXZ80UiNG09NGU`0209RHV080UiNG0P2/[:`40::R
XP80WIfM0P2UYJD60:6QX@80X:2P0P2TY:@209^KV`80XJ6Q00<0WYjN0:>SX`2SXj<00P2PX:020:BT
Y080Vi^K0P2QXJ420:BTY080XJ6Q5@3oool001<0oooo0P2MWId20:6QX@80XZ:R0P2TY:@20:2PX080
Y:BT0P2KVi/20:>SX`030:2PX02TY:@0Y:BT0080VYZJ0P2UYJD209^KV`80WIfM0P2SXj<20:6QX@80
VIVI0P2NWYh209bLW080WIfM0P2EUID407=cL`80F5QH00<0@41003hn?P0n?Sh0100h>3P203Hf=P80
9BDU0P0h>3P203Ti>@80<S8b0P2][Jd20<c<c080RHV90P2>SXh208R8R080SHf=0P26QXH00`2>SXh0
QhN708N7Q`02092@T080SHf=0P2EUID208V9R@80Shn?0P2<S8`209VIV@80O7al0P27QhL208Z:RP80
QhN70P1bLW8207]kN`80NGUi00<0Ng]k08F5Q@25QHD00P1jNWX208>3P`80S8b<0P1kNg/207emO@80
Q8B40P1mOGd207MgM`80NGUi0P1gMgL2075aL@80M7Ad0P1YJFT2069RHP0306MWI`1YJFT0JFUY0080
CDe=0P0f=SH201DE5@806ATI0P18B4P203/k>`80KFe]0P1EEED208:2PP80=cLg0P16ATH206UYJ@80
JVYZ0P2DU9@00`24Q8@0Ph>308>3P`02071`L080EEEE0P1LG5`206QXJ080E5AD0P1JFUX205MGE`80
Jf][0P2MWId208Z:RP80EeMG0P1lO7`205mOG`80eMGE00<0WIfM08f=S@2=SHd00P2JVYX20:6QX@80
Zj^[102QXJ4209ZJVP80YJFU0P2QXJ4209^KV`@0WIfM0P2SXj<20:2PX080Y:BT00<0X:2P0:BTY02T
Y:@0102QXJ420:2PX080Y:BT0P2QXJ4209^KVaD0oooo000C0?ooo`80WIfM0P2QXJ420::RXP80Y:BT
0P2PX:020:BTY080Vi^K0P2SXj<00`2PX:00Y:BT0:BTY00209ZJVP80YJFU0P2KVi/209fMW@80Xj>S
0P2QXJ4209VIV@80WYjN0P2LW9`209fMW@80UIFE101cLg<205QHF0030410@00n?Sh0?Shn00@0>3Ph
0P0f=SH202DU9@80>3Ph0P0i>CT2038b<P80[Jf]0P3<c<`208V9R@80SXj>0P28R8P208f=S@80QXJ6
00<0SXj>08N7Q`27QhL00P2@T90208f=S@80UIFE0P29RHT208n?S`80S8b<0P2IVIT207alO080QhN7
0P2:RXX208N7Q`80LW9b0P1kNg/207UiN@0307]kN`25QHD0QHF50080NWYj0P23Ph<208b<S080Ng]k
0P1mOGd208B4Q080OGem0P1gMgL207UiN@80MgMg0P1aLG4207AdM080JFUY0P1RHV800`1WIfL0JFUY
06UYJ@0204e=C@80=SHf0P0E5AD201TI6@80B4Q80P0k>c/206e]K@80EEEE0P22PX8203Lg=`80ATI6
0P1YJFT206YZJP80U9BD00<0Q8B408>3P`23Ph<00P1`L70205EEE@80G5aL0P1XJ6P205ADE080FUYJ
0P1GEeL206][J`80WIfM0P2:RXX205MGE`80O7al0P1OGel20=GEe@0309fMW@2=SHd0SHf=0080VYZJ
0P2QXJ420:^[Z`@0XJ6Q0P2JVYX20:FUY@80XJ6Q0P2KVi/409fMW@80Xj>S0P2PX:020:BTY0030:2P
X02TY:@0Y:BT00@0XJ6Q0P2PX:020:BTY080XJ6Q0P2KVi/E0?ooo`004`3oool209jNWP80YJFU0P2K
Vi/609fMW@80XJ6Q0P2LW9`00`2SXj<0XJ6Q0:6QX@020:2PX080Y:BT0P2JVYX20:BTY080WYjN0P2S
Xj<209ZJVP@0WIfM0P2OWil209^KV`80Lg=c0P1KFe/204I6AP0303Ti>@1:BTX0BTY:0080<S8b0P0i
>CT202TY:@80=SHf0P0k>c/403Lg=`80jNWY0P2GUiL208J6QP80S8b<0P2=SHd208V9R@80QXJ600<0
TY:B08R8R028R8P00P2ATI4208f=S@80SXj>0P2:RXX208j>SP80RXZ:0P2;Rh/207moO`H0QhN70P1d
M7@208>3P`80QHF500<0O7al08F5Q@25QHD00P1jNWX208j>SP80O7al0P27QhL207YjNP80P8200P1f
MWH207QhN080Ogmo0P1dM7@2075aL@80KVi^0P1dM7@206UYJ@0306QXJ01YJFT0JFUY0080EeMG0P11
@D4202HV9P80:RXZ0P0E5AD404=3@`80A4A40P1>CTh204U9B@80ADE50P1[Jf/2059BDP80N7Qh00<0
Shn?08>3P`23Ph<00P1EEED206IVIP80G5aL0P1TI6@204];B`80JVYZ0P1ADE420861P@80QHF50P28
R8P406ATI080JVYZ0P2n_[h00`2LW9`0U9BD09BDU00208Z:RP80/K6a0P2OWil20:>SX`80XJ6Q0P2J
VYX20:FUY@80Vi^K0P2QXJ440::RXP80Y:BT0P2KVi/20:>SX`<0XJ6Q0P2KVi/209fMW@80Xj>S102Q
XJ420:2PX1D0oooo000C0?ooo`80WYjN0P2UYJD209^KV`H0WIfM0P2QXJ4209bLW0030:>SX`2QXJ40
XJ6Q0080X:2P0P2TY:@209ZJVP80Y:BT0P2NWYh20:>SX`80VYZJ102MWId209nOW`80Vi^K0P1cLg<2
05]KF`80ATI600<0>CTi04Y:BP1:BTX00P0b<S8203Ti>@80:BTY0P0f=SH203/k>`@0=cLg0P3YjNT2
09NGU`80QXJ60P2<S8`208f=S@80RHV90P26QXH00`2BTY80R8R808R8R002096AT@80SHf=0P2>SXh2
08Z:RP80SXj>0P2:RXX208^;R`80Ogmo1P27QhL207AdM080Ph>30P25QHD00`1lO7`0QHF508F5Q@02
07YjNP80SXj>0P1lO7`208N7Q`80NWYj0P20P80207IfMP80N7Qh0P1oOgl207AdM080LG5a0P1^KVh2
07AdM080JFUY00<0J6QX06UYJ@1YJFT00P1GEeL20451@@809RHV0P0Z:RX201DE5@@0@d=30P14A4@2
04i>CP80BDU90P15ADD206][J`80DU9B0P1hN7P00`2?Shl0Ph>308>3P`0205EEE@80IVIV0P1LG5`2
06ATI080Bd];0P1ZJVX2055AD@80PH610P25QHD208R8R0@0I6AT0P1ZJVX20;jn_P0309bLW02DU9@0
U9BD0080RXZ:0P2a/K4209nOW`80Xj>S0P2QXJ4209ZJVP80YJFU0P2KVi/20:6QX@@0XZ:R0P2TY:@2
09^KV`80Xj>S0`2QXJ4209^KV`80WIfM0P2SXj<40:6QX@80X:2P5@3oool001<0oooo0P2RXZ8209jN
WP80XJ6Q0P2MWId209jNWP@0Y:BT0`2OWil20:>SX`@0XJ6Q0P2PX:020:BTY080X:2P0P2TY:@20:2P
X0H0WIfM0P1jNWX2071`L080CDe=0P17AdL00`15ADD0=3@d03@d=00203lo?`80:BTY0P0f=SH202PX
:080>SXj0P0i>CT202XZ:P80lO7a1026QXH208n?S`80SXj>0P2;Rh/208f=S@0308V9R@2=SHd0SHf=
0080SXj>102=SHd208Z:RP@0SHf=0P22PX8208B4Q080N7Qh0P2:RXX207QhN080LG5a0P20P80208>3
P`0307YjNP22PX80PX:20080Ph>30P2?Shl207MgM`80Ph>30P27QhL208V9R@80NGUi0P1oOgl207Yj
NP80MWIf0P1`L70207=cL`80KVi^0P1ZJVX00`1PH600GUiN05iNGP0205aLG080BTY:0P0Z:RX201TI
6@807alO0P14A4@204e=C@80DU9B0P1CDe<206QXJ080ADE50P13@d<204E5A@80NWYj00<0JFUY07Ee
M@1eMGD00P27QhL207EeM@80C4a<0P1XJ6P20451@@80N7Qh0P1LG5`208:2PP80L71`0P2BTY8206UY
J@80De=C0P2RXZ820:VYZ@030:FUY@2HV9P0V9RH0080U9BD0P2`/;020:6QX@80Y:BT0P2QXJ420:2P
X080Y:BT0P2PX:0209jNWP80Xj>S102QXJ4209ZJVP80YJFU00<0Vi^K0:>SX`2SXj<00P2PX:020::R
XP80Y:BT1P2QXJ4E0?ooo`004`3oool20::RXP80WYjN0P2QXJ4209fMW@80WYjN102TY:@309nOW`80
Xj>S102QXJ420:2PX080Y:BT0P2PX:020:BTY080X:2P1P2MWId207YjNP80L71`0P1=CDd204M7A`03
04E5A@0d=3@0=3@d0080?clo0P0Y:BT203Hf=P80:2PX0P0j>SX203Ti>@80:RXZ0P3alO4408J6QP80
Shn?0P2>SXh208^;R`80SHf=00<0RHV908f=S@2=SHd00P2>SXh408f=S@80RXZ:102=SHd208:2PP80
Q8B40P1hN7P208Z:RP80N7Qh0P1aLG420820P080Ph>300<0NWYj08:2PP22PX800P23Ph<208n?S`80
MgMg0P23Ph<208N7Q`80RHV90P1iNGT207moO`80NWYj0P1fMWH2071`L080Lg=c0P1^KVh206YZJP03
061PH01NGUh0GUiN0080G5aL0P1:BTX202XZ:P806ATI0P0O7al204A4A080CDe=0P1BDU8205=CD`80
J6QX0P15ADD204=3@`80ADE50P1jNWX00`1YJFT0MGEe07EeM@0208N7Q`80MGEe0P1<C4`206QXJ080
@D510P1hN7P205aLG080PX:20P1`L70209:BTP80JFUY0P1CDe<20::RXP80ZJVY00<0YJFU09RHV02H
V9P00P2DU9@20;2`/080XJ6Q0P2TY:@20:6QX@80X:2P0P2TY:@20:2PX080WYjN0P2SXj<40:6QX@80
VYZJ0P2UYJD00`2KVi/0Xj>S0:>SX`020:2PX080XZ:R0P2TY:@60:6QXAD0oooo000C0?ooo`80XJ6Q
0P2PX:020:BTY080X:2P0P2RXZ820:BTY0@0XJ6Q00<0X:2P09jNWP2NWYh00P2SXj<60:6QX@80Vi^K
102MWId20:6QX@80XZ:R0P2ATI4206e]K@80HV9R0P1DE5@203hn?P0304A4A012@T80@T920080=3@d
0P0b<S8203Xj>P80=3@d0P0k>c/202/[:`80Kfm_0P3IfMT208J6QP80R8R80P2ATI4208j>SP@0SHf=
00<0TY:B08f=S@2=SHd00P2:RXX408f=S@80S8b<0P25QHD208J6QP80M7Ad0P1bLW8206][J`80Ogmo
0P1aLG4206m_K`80NWYj0`1lO7`207moO`80QhN70P23Ph<208J6QP80RXZ:0P2=SHd407YjNP80OGem
101fMWH2071`L080M7Ad0P1YJFT206i^KP0306][J`1VIVH0IVIV0080F5QH0P1:BTX203Hf=P808b<S
0P0_;bl203<c<`80BDU90P0l?3`205MGE`80AdM70P1BDU8203@d=080CDe=0P0o?cl00`2>SXh0Ti>C
09>CT`0206e]K@80Jf][0P1BDU8206i^KP80BDU90P1TI6@2069RHP80MWIf0P1^KVh209JFUP80Lg=c
0P1GEeL20<G5a@80OGem00<0]kNg09FEU@2EUID00P2YZJT20:NWY`80Y:BT1P2QXJ4209^KV`80Xj>S
0P2PX:020:BTY0@0XJ6Q0P2PX:0209jNWP0309^KV`2UYJD0YJFU0080XJ6Q0P2KVi/20:>SX`H0XJ6Q
5@3oool001<0oooo0P2QXJ420:2PX080Y:BT0P2PX:020::RXP80Y:BT102QXJ400`2PX:00WYjN09jN
WP020:>SX`H0XJ6Q0P2KVi/409fMW@80XJ6Q0P2RXZ82096AT@80KFe]0P1RHV8205ADE080?Shn00<0
A4A40492@P12@T800P0d=3@2038b<P80>SXj0P0d=3@203/k>`80:b/[0P1_Kfl20=WIf@80QXJ60P28
R8P2096AT@80SXj>102=SHd00`2BTY80SHf=08f=S@0208Z:RP@0SHf=0P2<S8`208F5Q@80QXJ60P1d
M7@2079bLP80Jf][0P1oOgl2075aL@80Kfm_0P1jNWX307alO080Ogmo0P27QhL208>3P`80QXJ60P2:
RXX208f=S@@0NWYj0P1mOGd407IfMP80L71`0P1dM7@206UYJ@80KVi^00<0Jf][06IVIP1VIVH00P1H
F5P204Y:BP80=SHf0P0S8b<202l_;`80<c<c0P19BDT203`l?080EeMG0P17AdL2059BDP80=3@d0P1=
CDd203lo?`0308j>SP2CTi<0Ti>C0080KFe]0P1[Jf/2059BDP80KVi^0P19BDT206ATI080HV9R0P1f
MWH206i^KP80UYJF0P1cLg<205MGE`80aLG50P1mOGd00`2g]kL0UIFE09FEU@020:VYZ@80YjNW0P2T
Y:@60:6QX@80Vi^K0P2SXj<20:2PX080Y:BT102QXJ420:2PX080WYjN00<0Vi^K0:FUY@2UYJD00P2Q
XJ4209^KV`80Xj>S1P2QXJ4E0?ooo`004`3oool209fMW@80Xj>S202QXJ4209^KV`80Xj>S0`2KVi/2
0:FUY@80XJ6Q0P2KVi/20:>SX`80X:2P0P2RXZ8209ZJVP80YZJV0P2KVi/209VIV@80IfMW0P1ADE42
04M7A`80>SXj00<0=SHf03Ti>@0i>CT00P0a<C4202/[:`80;2`/0P0i>CT203Lg=`809BDU0P3Lg=`2
0:NWY`80RHV90P2;Rh/2096AT@H0SHf=00<0SXj>08Z:RP2:RXX00P28R8P208n?S`@0SHf=0P21PH42
07YjNP80LW9b0P1lO7`206QXJ080N7Qh0P1bLW8206UYJ@80MGEe0P1kNg/00`1hN7P0P8200820P002
0820P080Q8B40P20P80208Z:RP80QhN70P23Ph<207emO@80Rh^;0P1kNg/207QhN080MWIf0P1cLg<2
06UYJ@80Kfm_00<0KFe]05UIF@1IFET00P1KFe/205=CD`80>SXj0P0Q8B4200`<30807alO0P0n?Sh2
03`l?080F5QH0P0f=SH2065QH@80?Shn0P1=CDd2030`<0030:ZZZP1HF5P0F5QH0080J6QX0P2RXZ82
05ADE080I6AT0P1MGEd205QHF080J6QX0P1RHV8206UYJ@80V9RH0P1kNg/207QhN080Z:RX0P29RHT0
0`2OWil0PH610861P@020;Bd]0X0XJ6Q0P2JVYX20:FUY@X0XJ6Q0P2PX:000`2RXZ80Y:BT0:BTY002
0:6QX@80VYZJ0P2UYJD60:6QXAD0oooo000C0?ooo`80WIfM0P2SXj<80:6QX@80Vi^K0P2SXj<309^K
V`80YJFU0P2QXJ4209^KV`80Xj>S0P2PX:020::RXP80VYZJ0P2VYZH209^KV`80VIVI0P1WIfL2055A
D@80AdM70P0j>SX00`0f=SH0>CTi03Ti>@02034a<@80:b/[0P0/;2`203Ti>@80=cLg0P0U9BD20=cL
g080YjNW0P29RHT208^;R`80TI6A1P2=SHd00`2>SXh0RXZ:08Z:RP0208R8R080Shn?102=SHd20861
P@80NWYj0P1bLW8207alO080J6QX0P1hN7P2079bLP80JFUY0P1eMGD207]kN`0307QhN020P800P820
0080P8200P24Q8@20820P080RXZ:0P27QhL208>3P`80OGem0P2;Rh/207]kN`80N7Qh0P1fMWH207=c
L`80JFUY0P1_Kfl00`1]KFd0FEUI05UIF@0205]KF`80De=C0P0j>SX2024Q8@8030`<0P0O7al203hn
?P80?3`l0P1HF5P203Hf=P80HF5Q0P0n?Sh204e=C@80<30`00<0ZZZZ05QHF01HF5P00P1XJ6P20::R
XP80E5AD0P1TI6@205eMG@80F5QH0P1XJ6P2069RHP80JFUY0P2HV9P207]kN`80N7Qh0P2XZ:P208V9
R@0309nOW`21PH40PH610080];Bd2P2QXJ4209ZJVP80YJFU2P2QXJ420:2PX0030::RXP2TY:@0Y:BT
0080XJ6Q0P2JVYX20:FUY@H0XJ6Q5@3oool001<0oooo0P2RXZ820:BTY0P0XJ6Q0P2PX:0209jNWP03
0:6QX@2RXZ80XZ:R0080Y:BT0P2KVi/20:6QX@80Y:BT102QXJ4209nOW`80YJFU0P2PX:0209:BTP80
EEEE0P17AdL203Xj>P80=CDe00<0=cLg02TY:@0Y:BT00P0h>3P2030`<080>CTi0P0h>3P202HV9P80
8b<S0P3emOD208F5Q@@0R8R80P2ATI4208N7Q`80U9BD0P2ATI400`2;Rh/0SHf=08f=S@0208b<S080
RHV90P2CTi<205iNGP80De=C0P2CTi<208R8R080Ogmo0P1^KVh203lo?`80AdM70P1QHF4207MgM`80
Cdm?00<0Lg=c07inOP1nOWh00P21PH4208n?S`80QhN70P2=SHd408N7Q`80Ph>30P1oOgl207QhN080
MWIf0P1hN7P2071`L080LW9b0`1]KFd2069RHP80GUiN0P1:BTX204A4A080:2PX0P0@4102028R8P80
:b/[0P0j>SX20492@P80?Cdm0P1HF5P204Q8B080>3Ph0P1=CDd00`1>CTh0HV9R069RHP0208^;R`80
M7Ad0P1YJFT205IFEP80HV9R0P0l?3`2061PH080EeMG0P1kNg/209VIV@80OGem0P2][Jd206YZJP80
/K6a00<0Jf][0;Vi^@2i^KT00P2d];@:0:6QX@80X:2P0P2TY:@A0:6QX@80X:2P0P2TY:@20:6QX@80
Vi^K0P2SXj<E0?ooo`004`3oool20::RXP80Y:BT202QXJ420:2PX080WYjN00<0XJ6Q0::RXP2RXZ80
0P2TY:@209^KV`80XJ6Q0P2TY:@40:6QX@80WinO0P2UYJD20:2PX080TY:B0P1EEED204M7A`80>SXj
0P0e=CD00`0g=cL0:BTY02TY:@0203Ph>080<30`0P0i>CT203Ph>0809RHV0P0S8b<20?Gem@80QHF5
1028R8P2096AT@80QhN70P2DU9@2096AT@0308^;R`2=SHd0SHf=0080S8b<0P29RHT209>CT`80GUiN
0P1CDe<209>CT`80R8R80P1oOgl206i^KP80?clo0P17AdL2065QH@80MgMg0P1?Cdl00`1cLg<0OWin
07inOP020861P@80Shn?0P27QhL208f=S@@0QhN70P23Ph<207moO`80N7Qh0P1fMWH207QhN080L71`
0P1bLW8306e]K@80HV9R0P1NGUh204Y:BP80A4A40P0X:2P2010@40808R8R0P0[:b/203Xj>P80@T92
0P0m?Cd205QHF080B4Q80P0h>3P204e=C@0304i>CP1RHV80HV9R0080Rh^;0P1dM7@206UYJ@80EUIF
0P1RHV8203`l?080H61P0P1GEeL207]kN`80VIVI0P1mOGd20:f][@80JVYZ0P2a/K400`1[Jf/0^KVi
0;Vi^@020;Bd]0X0XJ6Q0P2PX:020:BTY140XJ6Q0P2PX:020:BTY080XJ6Q0P2KVi/20:>SXaD0oooo
000C0?ooo`@0WIfM0P2SXj<209^KV`80WIfM0P2SXj<20:6QX@80X:2P00<0Y:BT09^KV`2KVi/00P2M
WId20:6QX@80WYjN0P2SXj<80:6QX@80Vi^K0P24Q8@204=3@`80@T920P0m?Cd204I6AP0303<c<`0d
=3@0=3@d0080;Bd]0P0c<c<203Ti>@80:RXZ0P0S8b<204A4A080k^k^0P26QXH408n?S`80UiNG0P2:
RXX208^;R`80Ti>C00<0Ph>308j>SP2>SXh00P29RHT208b<S080UiNG0P1jNWX208R8R080YZJV0P2:
RXX208>3P`80MWIf0P1WIfL208B4Q0@0SHf=0`1ZJVX207EeM@80R8R80P2BTY8208N7Q`80R8R81027
QhL207YjNP80QhN70P28R8P207]kN`80MgMg0P1eMGD207=cL`80JFUY00<0IFEU06IVIP1VIVH00P1J
FUX205IFEP80C4a<0P0i>CT200T92@805QHF0P0P820203@d=080?Shn0P16ATH203hn?P80EUIF0P0d
=3@204Q8B00301TI6@2][Jd0[Jf]0080IfMW0P1SHf<209BDU080@D510P1UIFD203hn?P80G5aL0P1X
J6P207=cL`80Ph>30P2;Rh/2096AT@80FEUI0P2=SHd00`2YZJT0`/;20<;2`P0209^KV`80Xj>S202Q
XJ4209^KV`80Xj>S1P2QXJ4209^KV`80Xj>S1`2QXJ4209^KV`80WIfM0P2SXj<20:2PX080Y:BT5@3o
ool001<0oooo102MWId20:>SX`80Vi^K0P2MWId20:>SX`80XJ6Q0P2PX:000`2TY:@0Vi^K09^KV`02
09fMW@80XJ6Q0P2NWYh20:>SX`P0XJ6Q0P2KVi/208B4Q080@d=30P12@T8203dm?@80ATI600<0<c<c
03@d=00d=3@00P0];Bd203<c<`80>CTi0P0Z:RX202<S8`80A4A40P3^k^h208J6QP@0Shn?0P2GUiL2
08Z:RP80Rh^;0P2CTi<00`23Ph<0SXj>08j>SP0208V9R@80S8b<0P2GUiL207YjNP80R8R80P2VYZH2
08Z:RP80Ph>30P1fMWH206MWI`80Q8B4102=SHd306YZJP80MGEe0P28R8P209:BTP80QhN70P28R8P4
08N7Q`80NWYj0P27QhL208R8R080Ng]k0P1gMgL207EeM@80Lg=c0P1YJFT00`1UIFD0IVIV06IVIP02
05YJFP80EUIF0P1<C4`203Ti>@802@T90P0F5QH2020P8080=3@d0P0n?Sh204I6AP80?Shn0P1FEUH2
03@d=080B4Q800<06ATI0:f][@2][Jd00P1WIfL206=SH`80U9BD0P11@D4206EUI@80?Shn0P1LG5`2
06QXJ080Lg=c0P23Ph<208^;R`80TI6A0P1IFET208f=S@030:VYZ@32`/80`/;20080Vi^K0P2SXj<8
0:6QX@80Vi^K0P2SXj<60:6QX@80Vi^K0P2SXj<70:6QX@80Vi^K0P2MWId20:>SX`80X:2P0P2TY:@E
0?ooo`004`3oool40::RXP80Y:BT0P2PX:020::RXP80Y:BT0P2KVi/20:>SX`030:6QX@2JVYX0VYZJ
0080WYjN0P2UYJD20:2PX080Y:BT0P2QXJ4209VIV@80Xj>S0P2QXJ420:2PX080O7al0P0m?Cd203Ph
>080?Shn0P0W9bL00`0c<c<0>SXj03Xj>P0202l_;`80>SXj0P0k>c/201lO7`808R8R0P1cLg<20<k>
cP80Rh^;0P2<S8`208Z:RP80U9BD0P2?Shl2092@T080UIFE00<0S8b<08j>SP2>SXh00P2<S8`208V9
R@80UYJF0P20P80209>CT`80TY:B0P2ATI4208J6QP80PH610P1hN7P207]kN`80O7al0P1iNGT207=c
L`0306i^KP1lO7`0O7al0080Shn?0P2ATI4208N7Q`80Rh^;0P26QXH208N7Q`80Q8B40P1oOgl207em
O@@0NWYj0P1hN7P207IfMP80JVYZ00<0GemO06IVIP1VIVH00P1JFUX205ADE080B4Q80P11@D4200P8
20807AdM0P0E5AD20451@@80@d=30P1>CTh202d];@80FUYJ0P0c<c<204I6AP0301dM7@2WYjL0YjNW
0080EeMG0P23Ph<209NGU`80>c/k0P1YJFT204Q8B080GemO0P1TI6@206a/K080QHF50P2EUID208F5
Q@80MGEe0P2EUID00`3>c/h0XJ6Q0:6QX@0209ZJVP80YJFU202QXJ420:2PX080Y:BT0P2KVi/20:>S
X`80XJ6Q0P2PX:020:BTY0L0XJ6Q0P2PX:0209fMW@80YJFU102QXJ4E0?ooo`004`3oool40::RXP80
Y:BT0P2PX:020::RXP80Y:BT0P2KVi/20:>SX`030:6QX@2JVYX0VYZJ0080WYjN0P2UYJD20:2PX080
Y:BT0P2QXJ4209VIV@80Xj>S0P2QXJ420:2PX080O7al0P0m?Cd203Ph>080?Shn0P0W9bL00`0c<c<0
>SXj03Xj>P0202l_;`80>SXj0P0k>c/201lO7`808R8R0P1cLg<20<k>cP80Rh^;0P2<S8`208Z:RP80
U9BD0P2?Shl2092@T080UIFE00<0S8b<08j>SP2>SXh00P2<S8`208V9R@80UYJF0P20P80209>CT`80
TY:B0P2ATI4208J6QP80PH610P1hN7P207]kN`80O7al0P1iNGT207=cL`0306i^KP1lO7`0O7al0080
Shn?0P2ATI4208N7Q`80Rh^;0P26QXH208N7Q`80Q8B40P1oOgl207emO@@0NWYj0P1hN7P207IfMP80
JVYZ00<0GemO06IVIP1VIVH00P1JFUX205ADE080B4Q80P11@D4200P820807AdM0P0E5AD20451@@80
@d=30P1>CTh202d];@80FUYJ0P0c<c<204I6AP0301dM7@2WYjL0YjNW0080EeMG0P23Ph<209NGU`80
>c/k0P1YJFT204Q8B080GemO0P1TI6@206a/K080QHF50P2EUID208F5Q@80MGEe0P2EUID00`3>c/h0
XJ6Q0:6QX@0209ZJVP80YJFU202QXJ420:2PX080Y:BT0P2KVi/20:>SX`80XJ6Q0P2PX:020:BTY0L0
XJ6Q0P2PX:0209fMW@80YJFU102QXJ4E0?ooo`004`3oool60:6QX@80Vi^K0P2SXj<209^KV`80XJ6Q
0P2TY:@00`2KVi/0XJ6Q0:6QX@0209fMW@80YJFU0P2QXJ4209VIV@80Xj>S0P2IVIT20:2PX080Xj>S
0P2KVi/207=cL`80;bl_0P0e=CD20451@@80=SHf00<0>CTi03Ph>00h>3P00P0h>3P203dm?@80<S8b
0P0K6a/202`/;080gmoO0P2[Zj/209:BTP80SHf=0P2DU9@209FEU@80TI6A0P2?Shl2096AT@0308j>
SP2@T900T92@0080QXJ60P24Q8@209VIV@80S8b<0P2DU9@209ZJVP80SHf=0P23Ph<208F5Q@80NWYj
0P1fMWH207EeM@@0MgMg00<0LG5a07inOP1nOWh00P29RHT2092@T080QhN70P2>SXh208B4Q080Rh^;
0P26QXH208>3P`80RHV90P1mOGd207moO`80MWIf0P1iNGT206m_K`0306][J`1WIfL0IfMW0080G5aL
0P1CDe<204U9B@80?Cdm0P0E5AD200L71`8071`L0P0o?cl201hN7P80EEEE0P0e=CD205]KF`80:RXZ
0P0o?cl00`0n?Sh0LG5a075aL@0206IVIP80QHF50P1gMgL205YJFP80EUIF0P1PH602055AD@80G5aL
0P1KFe/208V9R@80UiNG0P1eMGD2096AT@80]kNg00<0^;Rh0:6QX@2QXJ400P2PX:020:BTY0H0XJ6Q
0P2KVi/209fMW@80Xj>S0P2PX:020:BTY0l0XJ6Q0P2PX:020:BTY0@0XJ6Q5@3oool001<0oooo1P2Q
XJ4209^KV`80Xj>S0P2KVi/20:6QX@80Y:BT00<0Vi^K0:6QX@2QXJ400P2MWId20:FUY@80XJ6Q0P2I
VIT20:>SX`80VIVI0P2PX:020:>SX`80Vi^K0P1cLg<202l_;`80=CDe0P11@D4203Hf=P0303Ti>@0h
>3P0>3Ph0080>3Ph0P0m?Cd2038b<P806a/K0P0/;2`20=oOg`80Zj^[0P2BTY8208f=S@80U9BD0P2E
UID2096AT@80Shn?0P2ATI400`2>SXh0T92@092@T00208J6QP80Q8B40P2IVIT208b<S080U9BD0P2J
VYX208f=S@80Ph>30P25QHD207YjNP80MWIf0P1eMGD407MgM`03075aL@1nOWh0OWin0080RHV90P2@
T90208N7Q`80SXj>0P24Q8@208^;R`80QXJ60P23Ph<208V9R@80OGem0P1oOgl207IfMP80NGUi0P1_
Kfl00`1[Jf/0IfMW06MWI`0205aLG080De=C0P19BDT203dm?@805ADE0P071`L201`L7080?clo0P0N
7Qh205EEE@80=CDe0P1KFe/202XZ:P80?clo00<0?Shn075aL@1aLG400P1VIVH208F5Q@80MgMg0P1J
FUX205IFEP80H61P0P1ADE4205aLG080Fe]K0P29RHT209NGU`80MGEe0P2ATI420;Ng]`030;Rh^02Q
XJ40XJ6Q0080X:2P0P2TY:@60:6QX@80Vi^K0P2MWId20:>SX`80X:2P0P2TY:@?0:6QX@80X:2P0P2T
Y:@40:6QXAD0oooo000C0?ooo`H0XJ6Q0P2PX:020:BTY080X:2P0P2TY:@309^KV`80YJFU0P2JVYX2
0:2PX080Xj>S102OWil20:6QX@80XZ:R0P2TY:@209RHV080@d=30P0Z:RX20492@P809bLW0P0a<C40
0`0`<300>3Ph03Ph>00203/k>`80=cLg0P0F5QH2028R8P806a/K0P3gmoL208b<S080T92@0P28R8P2
09JFUP80T92@0P2?Shl2092@T080TI6A00<0T92@096AT@2ATI400P2=SHd208^;R`80TY:B0P26QXH2
096AT@80TY:B0P2;Rh/208R8R080Q8B40P1`L70206YZJP80LW9b0P1jNWX2071`L00307UiN@25QHD0
QHF50080TI6A0P2>SXh208R8R080Shn?0P2=SHd608J6QP80R8R80P23Ph<207emO@80MGEe0P1iNGT2
07EeM@03075aL@1YJFT0JFUY0080FEUI0P1CDe<204m?C`80AdM70P0[:b/200T92@8061PH0P0a<C42
0492@P80B4Q80P10@40204i>CP80;Bd]0P11@D400`0e=CD0GUiN05iNGP0206a/K080LW9b0P1oOgl2
08N7Q`80?clo0P1MGEd204Q8B080GUiN0P1_Kfl20::RXP80Ti>C0P1JFUX209jNWP80_kno00<0WYjN
0:>SX`2SXj<00P2KVi/409fMW@80Xj>S0P2QXJ420:2PX080WIfM0P2UYJD?0:6QX@80Vi^K0P2SXj<8
0:6QXAD0oooo000C0?ooo`H0XJ6Q0P2PX:020:BTY080X:2P0P2TY:@309^KV`80YJFU0P2JVYX20:2P
X080Xj>S102OWil20:6QX@80XZ:R0P2TY:@209RHV080@d=30P0Z:RX20492@P809bLW0P0a<C400`0`
<300>3Ph03Ph>00203/k>`80=cLg0P0F5QH2028R8P806a/K0P3gmoL208b<S080T92@0P28R8P209JF
UP80T92@0P2?Shl2092@T080TI6A00<0T92@096AT@2ATI400P2=SHd208^;R`80TY:B0P26QXH2096A
T@80TY:B0P2;Rh/208R8R080Q8B40P1`L70206YZJP80LW9b0P1jNWX2071`L00307UiN@25QHD0QHF5
0080TI6A0P2>SXh208R8R080Shn?0P2=SHd608J6QP80R8R80P23Ph<207emO@80MGEe0P1iNGT207Ee
M@03075aL@1YJFT0JFUY0080FEUI0P1CDe<204m?C`80AdM70P0[:b/200T92@8061PH0P0a<C420492
@P80B4Q80P10@40204i>CP80;Bd]0P11@D400`0e=CD0GUiN05iNGP0206a/K080LW9b0P1oOgl208N7
Q`80?clo0P1MGEd204Q8B080GUiN0P1_Kfl20::RXP80Ti>C0P1JFUX209jNWP80_kno00<0WYjN0:>S
X`2SXj<00P2KVi/409fMW@80Xj>S0P2QXJ420:2PX080WIfM0P2UYJD?0:6QX@80Vi^K0P2SXj<80:6Q
XAD0oooo000C0?ooo`@0WIfM0P2SXj<40:6QX@80Vi^K0P2SXj<20:2PX0030::RXP2TY:@0Y:BT0080
X:2P0P2RXZ8209jNWP80Xj>S0P2JVYX20:FUY@@0XJ6Q0P2GUiL202l_;`80=cLg0P0d=3@202DU9@80
A4A400<0>SXj03/k>`0k>c/00P0g=cL2014A4@@07QhN0P0[:b/20?clo080TI6A0P2EUID208n?S`80
U9BD102?Shl2092@T0D0Shn?0P2ATI4208n?S`80QXJ6102;Rh/209>CT`80QHF50P24Q8@407IfMP80
Jf][101kNg/207MgM`0308F5Q@2BTY80TY:B0080SXj>1028R8P208b<S080Shn?0P22PX8208^;R`80
QXJ61027QhL207QhN080OGem0P1hN7P207UiN@0306i^KP1cLg<0Lg=c0080H61P0P1KFe/204i>CP80
B4Q80P0a<C4200T92@809bLW0P0T92@203Ti>@80=CDe0P0o?cl203dm?@80B4Q80P0l?3`00`0k>c/0
JVYZ06YZJP0206i^KP80Kfm_0P27QhL209bLW080=cLg0P1EEED204M7A`80G5aL0P1TI6@208^;R`80
SXj>0P20P8020<S8b080^;Rh00<0X:2P0:BTY02TY:@00P2PX:040::RXP80Y:BT102QXJ420:2PX080
Y:BT1P2QXJ4209^KV`80Xj>S1@2QXJ4209ZJVP80X:2P0P2SXj<60:6QXAD0oooo000C0?ooo`@0XZ:R
0P2TY:@20:6QX@80Vi^K0P2QXJ420:BTY0L0XJ6Q0P2KVi/20:6QX@80WYjN0P2QXJ4209jNWP@0WIfM
0P2KVi/202`/;080=CDe0P0a<C4203De=@80A4A400<0=3@d03Lg=`0g=cL00P0i>CT201TI6@8071`L
0P0Q8B420;2`/080f][J0P2>SXh209FEU@80SXj>1P2?Shl209VIV@<0UYJF0P2=SHd2096AT@80T92@
102=SHd208B4Q080VIVI0P2=SHd208:2PP80MgMg101cLg<207]kN`80PH610P20P8000`28R8P0T92@
092@T00208j>SP80QhN7102;Rh/209NGU`80QhN70P2:RXX208J6QP80QhN70P28R8P207MgM`80OGem
0P1kNg/207IfMP0306m_K`1/K6`0K6a/0080J6QX0P1HF5P404U9B@80@T920P0A4A4200d=3@80:RXZ
0P0R8R8204E5A@80AdM70P0e=CD204U9B@80AdM700<0>SXj05mOG`1OGel00P1oOgl207AdM080QHF5
0P2PX:0202l_;`80JFUY0P0g=cL206][J`80De=C0P2VYZH209^KV`80RXZ:0P31`L420:BTY1T0XJ6Q
0P2PX:020:BTY0D0XJ6Q0P2PX:020::RXP80Y:BT0P2QXJ4209^KV`80Xj>S5@3oool001<0oooo102R
XZ820:BTY080XJ6Q0P2KVi/20:6QX@80Y:BT1`2QXJ4209^KV`80XJ6Q0P2NWYh20:6QX@80WYjN102M
WId209^KV`80;2`/0P0e=CD2034a<@80=CDe0P14A4@00`0d=3@0=cLg03Lg=`0203Ti>@806ATI0P0L
71`2024Q8@80/;2`0P3Jf]X208j>SP80UIFE0P2>SXh608n?S`80VIVI0`2FUYH208f=S@80TI6A0P2@
T90408f=S@80Q8B40P2IVIT208f=S@80PX:20P1gMgL407=cL`80Ng]k0P21PH420820P00308R8R02@
T900T92@0080SXj>0P27QhL408^;R`80UiNG0P27QhL208Z:RP80QXJ60P27QhL208R8R080MgMg0P1m
OGd207]kN`80MWIf00<0Kfm_06a/K01/K6`00P1XJ6P205QHF0@0BDU90P12@T82014A4@803@d=0P0Z
:RX2028R8P80ADE50P17AdL203De=@80BDU90P17AdL00`0j>SX0GemO05mOG`0207moO`80M7Ad0P25
QHD20:2PX080;bl_0P1YJFT203Lg=`80Jf][0P1CDe<20:JVYP80Vi^K0P2:RXX20<71`@80Y:BT6@2Q
XJ420:2PX080Y:BT1@2QXJ420:2PX080XZ:R0P2TY:@20:6QX@80Vi^K0P2SXj<E0?ooo`004`3oool6
09fMW@80Xj>S0P2PX:020:BTY0L0XJ6Q102KVi/20:2PX080XJ6Q0P2TY:@209ZJVP80WYjN0P2TY:@2
07=cL`809BDU0P0f=SH202`/;080?clo0P0n?Sh303Lg=`807AdM0P0F5QH201@D5080bLW90P3Fe]H2
09RHV080UIFE0P2LW9`208b<S080Shn?0P2IVIT208f=S@80TY:B0`2>SXh208^;R`80T92@1P2?Shl2
08V9R@80V9RH0P2@T9020861P@80Ph>30P1gMgL207IfMP80P8200P21PH4207moO`0308J6QP2?Shl0
Shn?0080RXZ:0P2CTi<209BDU080QhN70P2GUiL208>3P`80U9BD0P2:RXX208b<S080QhN70P24Q8@2
08J6QP80OWin0P1jNWX00`1dM7@0KVi^06i^KP0206e]K@80JFUY0P1>CTh204Q8B080ATI60P0V9RH2
024Q8@80=CDe0P0i>CT203dm?@80CTi>0P0h>3P2055AD@80@T9200<0=SHf05iNGP1NGUh00P2ATI42
06i^KP80OWin0P2ATI4203lo?`80EUIF0P0];Bd206MWI`80EUIF0P2NWYh20:2PX080YjNW0P2i^KT?
0:6QX@80Vi^K0P2SXj<20:6QX@80Vi^K0P2MWId20:>SX`80XJ6Q0P2KVi/20:>SX`0309^KV`2SXj<0
Xj>S00P0XJ6Q0P2PX:020:BTY1D0oooo000C0?ooo`H0WIfM0P2SXj<20:2PX080Y:BT1`2QXJ4409^K
V`80X:2P0P2QXJ420:BTY080VYZJ0P2NWYh20:BTY080Lg=c0P0U9BD203Hf=P80;2`/0P0o?cl203hn
?P<0=cLg0P0M7Ad201HF5P8051@D0P39bLT20=KFeP80V9RH0P2EUID209bLW080S8b<0P2?Shl209VI
V@80SHf=0P2BTY8308j>SP80Rh^;0P2@T90608n?S`80RHV90P2HV9P2092@T080PH610P23Ph<207Mg
M`80MWIf0P20P8020861P@80Ogmo00<0QXJ608n?S`2?Shl00P2:RXX209>CT`80U9BD0P27QhL209NG
U`80Ph>30P2DU9@208Z:RP80S8b<0P27QhL208B4Q080QXJ60P1nOWh207YjNP0307AdM01^KVh0KVi^
0080KFe]0P1YJFT204i>CP80B4Q80P16ATH202HV9P808B4Q0P0e=CD203Ti>@80?Cdm0P1>CTh203Ph
>080DE5A0P12@T800`0f=SH0GUiN05iNGP02096AT@80KVi^0P1nOWh2096AT@80?clo0P1FEUH202d]
;@80IfMW0P1FEUH209jNWP80X:2P0P2WYjL20;Vi^@l0XJ6Q0P2KVi/20:>SX`80XJ6Q0P2KVi/209fM
W@80Xj>S0P2QXJ4209^KV`80Xj>S00<0Vi^K0:>SX`2SXj<0202QXJ420:2PX080Y:BT5@3oool001<0
oooo0P2NWYh20:BTY080WIfM0P2UYJD90:6QX@80Vi^K0P2QXJ420::RXP80WIfM0P2UYJD20:6QX@80
X:2P0P2RXZ820:BTY0809bLW0P0[:b/203Hf=P807alO0P18B4P203@d=00303De=@0j>SX0>SXj0080
6a/K0P0_;bl202XZ:P80oOgm0P2@T90209>CT`80UYJF0P2@T90208^;R`@0VIVI0P29RHT208n?S`80
TI6A00<0V9RH08f=S@2=SHd01P2?Shl2096AT@80QXJ60P2EUID2092@T080SHf=0P26QXH407=cL`H0
Ph>300<0Q8B408^;R`2;Rh/00P2>SXh209RHV080RHV90P2?Shl209>CT`80SXj>1029RHT208b<S080
RXZ:1026QXH207alO080Ng]k00<0Lg=c07IfMP1fMWH00P1YJFT206e]K@80CTi>0P1;Bd/203lo?`80
;Rh^0P0Y:BT202l_;`80;Rh^1011@D4204U9B@80C4a<0P0o?cl00`1CDe<0Kfm_06m_K`0208R8R080
Jf][0P1aLG4207emO@80CDe=0P13@d<202d];@80JFUY0P1aLG4208n?S`80/K6a0P2f][H20:JVYPl0
XJ6Q0P2PX:020:BTY080XJ6Q0P2PX:020::RXP80Y:BT0P2QXJ420:2PX080WYjN00<0XJ6Q0:BTY02T
Y:@00P2QXJ4209^KV`80Xj>S1P2QXJ4E0?ooo`004`3oool209jNWP80Y:BT0P2MWId20:FUY@T0XJ6Q
0P2KVi/20:6QX@80XZ:R0P2MWId20:FUY@80XJ6Q0P2PX:020::RXP80Y:BT0P0W9bL202/[:`80=SHf
0P0O7al204Q8B080=3@d00<0=CDe03Xj>P0j>SX00P0K6a/202l_;`80:RXZ0P3moOd2092@T080Ti>C
0P2FUYH2092@T080Rh^;102IVIT208V9R@80Shn?0P2ATI400`2HV9P0SHf=08f=S@0608n?S`80TI6A
0P26QXH209FEU@80T92@0P2=SHd208J6QP@0Lg=c1P23Ph<00`24Q8@0Rh^;08^;R`0208j>SP80V9RH
0P29RHT208n?S`80Ti>C0P2>SXh408V9R@80S8b<0P2:RXX408J6QP80O7al0P1kNg/00`1cLg<0MWIf
07IfMP0206UYJ@80KFe]0P1>CTh204];B`80?clo0P0^;Rh202TY:@80;bl_0P0^;Rh40451@@80BDU9
0P1<C4`203lo?`0305=CD`1_Kfl0Kfm_0080R8R80P1[Jf/2075aL@80OGem0P1=CDd204=3@`80;Bd]
0P1YJFT2075aL@80Shn?0P2a/K420;Jf]P80YZJV3`2QXJ420:2PX080Y:BT0P2QXJ420:2PX080XZ:R
0P2TY:@20:6QX@80X:2P0P2NWYh00`2QXJ40Y:BT0:BTY0020:6QX@80Vi^K0P2SXj<60:6QXAD0oooo
000C0?ooo`80WYjN0P2UYJD20:2PX080Y:BT2@2QXJ420:2PX080Y:BT0P2QXJ4209ZJVP80YJFU102Q
XJ4209^KV`80Xj>S0P0L71`20492@P80<C4a0P0W9bL2051@D080>SXj00<0=SHf038b<P0b<S800P0W
9bL2024Q8@80M7Ad0P3Rh^8208j>SP80UiNG0P2@T90208n?S`@0VIVI0P2;Rh/208f=S@80Shn?0P2A
TI400`2BTY80Rh^;08^;R`0209VIV@80UYJF0P2=SHd2092@T080Shn?0P2DU9@208n?S`80QHF50P24
Q8@2079bLP80Lg=c0P1kNg/208N7Q`80PX:20`2;Rh/2096AT@80SXj>0P28R8P209BDU080Shn?0P26
QXH208B4Q080UYJF0P2;Rh/208Z:RP80Q8B40P27QhL208F5Q@80OWin00<0LW9b07MgM`1gMgL0101/
K6`205ADE080BTY:0P0l?3`203Hf=P808R8R0P0V9RH202h^;P80?3`l0P0j>SX204m?C`80B4Q80P16
ATH00`15ADD0RHV908V9R@0207QhN0@0KVi^0P1hN7P2071`L080?Cdm0P1:BTX2065QH@80IVIV0P2;
Rh/20<O7a`80/K6a5`2QXJ4209^KV`80Xj>S0P2KVi/20:>SX`80XJ6Q0P2PX:000`2TY:@0XJ6Q0:6Q
X@020:6QX@80X:2P0P2TY:@60:6QXAD0oooo000C0?ooo`80WYjN0P2UYJD20:2PX080Y:BT2@2QXJ42
0:2PX080Y:BT0P2QXJ4209ZJVP80YJFU102QXJ4209^KV`80Xj>S0P0L71`20492@P80<C4a0P0W9bL2
051@D080>SXj00<0=SHf038b<P0b<S800P0W9bL2024Q8@80M7Ad0P3Rh^8208j>SP80UiNG0P2@T902
08n?S`@0VIVI0P2;Rh/208f=S@80Shn?0P2ATI400`2BTY80Rh^;08^;R`0209VIV@80UYJF0P2=SHd2
092@T080Shn?0P2DU9@208n?S`80QHF50P24Q8@2079bLP80Lg=c0P1kNg/208N7Q`80PX:20`2;Rh/2
096AT@80SXj>0P28R8P209BDU080Shn?0P26QXH208B4Q080UYJF0P2;Rh/208Z:RP80Q8B40P27QhL2
08F5Q@80OWin00<0LW9b07MgM`1gMgL0101/K6`205ADE080BTY:0P0l?3`203Hf=P808R8R0P0V9RH2
02h^;P80?3`l0P0j>SX204m?C`80B4Q80P16ATH00`15ADD0RHV908V9R@0207QhN0@0KVi^0P1hN7P2
071`L080?Cdm0P1:BTX2065QH@80IVIV0P2;Rh/20<O7a`80/K6a5`2QXJ4209^KV`80Xj>S0P2KVi/2
0:>SX`80XJ6Q0P2PX:000`2TY:@0XJ6Q0:6QX@020:6QX@80X:2P0P2TY:@60:6QXAD0oooo000C0?oo
o`80XZ:R0P2TY:@209^KV`80Xj>S0P2KVi/20:>SX`@0XJ6Q00<0Vi^K0:>SX`2SXj<0102QXJ420:2P
X080Y:BT102QXJ420:2PX080WYjN0P0K6a/204e=C@80=CDe0P0c<c<203Hf=P80?Cdm00<0=cLg028R
8P0R8R800P0d=3@203lo?`80gmoO0P2b/[8208f=S@80U9BD102?Shl209:BTP80SXj>0P2;Rh/4092@
T080Shn?00<0R8R8092@T02@T9000P2BTY8208j>SP80Rh^;102ATI4208:2PP80TY:B0P2=SHd209>C
T`80MGEe0P1dM7@207QhN080QHF50`24Q8@208N7Q`80Rh^;0P2=SHd208b<S080SHf=0P2ATI4208J6
QP80U9BD0P2=SHd208:2PP80QXJ60P25QHD208R8R080Q8B40P1lO7`00`1nOWh0MGEe07EeM@0206e]
K@80Jf][0P1QHF4204m?C`80ATI60P0h>3P202d];@80:2PX0P0_;bl202h^;P80@T920P18B4P204M7
A`80>SXj00<0=CDe0:ZZZP2ZZZX00P1[Jf/206=SH`80LG5a0P1/K6`207moO`80:2PX0P1IFET205IF
EP80H61P0P2@T9020<k>cP80Z:RX5`2QXJ420:2PX080Y:BT0P2PX:020:BTY080Vi^K0P2SXj<?0:6Q
XAD0oooo000C0?ooo`80XZ:R0P2TY:@209^KV`80Xj>S0P2KVi/20:>SX`@0XJ6Q00<0Vi^K0:>SX`2S
Xj<0102QXJ420:2PX080Y:BT102QXJ420:2PX080WYjN0P0K6a/204e=C@80=CDe0P0c<c<203Hf=P80
?Cdm00<0=cLg028R8P0R8R800P0d=3@203lo?`80gmoO0P2b/[8208f=S@80U9BD102?Shl209:BTP80
SXj>0P2;Rh/4092@T080Shn?00<0R8R8092@T02@T9000P2BTY8208j>SP80Rh^;102ATI4208:2PP80
TY:B0P2=SHd209>CT`80MGEe0P1dM7@207QhN080QHF50`24Q8@208N7Q`80Rh^;0P2=SHd208b<S080
SHf=0P2ATI4208J6QP80U9BD0P2=SHd208:2PP80QXJ60P25QHD208R8R080Q8B40P1lO7`00`1nOWh0
MGEe07EeM@0206e]K@80Jf][0P1QHF4204m?C`80ATI60P0h>3P202d];@80:2PX0P0_;bl202h^;P80
@T920P18B4P204M7A`80>SXj00<0=CDe0:ZZZP2ZZZX00P1[Jf/206=SH`80LG5a0P1/K6`207moO`80
:2PX0P1IFET205IFEP80H61P0P2@T9020<k>cP80Z:RX5`2QXJ420:2PX080Y:BT0P2PX:020:BTY080
Vi^K0P2SXj<?0:6QXAD0oooo000C0?ooo`80WIfM0P2SXj<20:2PX080Y:BT0P2JVYX20:FUY@80Vi^K
0P2SXj<00`2JVYX0YJFU0:FUY@0:0:6QX@80Vi^K0P2SXj<205MGE`806a/K0P16ATH203@d=080@d=3
0P0l?3`203hn?P0302TY:@0V9RH09RHV0080=cLg0P35aLD20=7Ad@80QXJ60P2EUID209:BTPH0Shn?
0P2IVIT208f=S@80Shn?0P2ATI4208R8R00308>3P`28R8P0R8R80080S8b<0P2:RXX209>CT`80TI6A
0P24Q8@208V9R@80UYJF0P2?Shl2096AT@80Ng]k0P1aLG4207IfMP80Ng]k0P1iNGT00`24Q8@0MGEe
07EeM@0208f=S@80SXj>0P26QXH209BDU080S8b<0P29RHT208j>SP80PX:20P23Ph<208V9R@80QhN7
0P28R8P208J6QP80OGem00<0PX:2071`L01`L7000P1eMGD206m_K`80GemO0P1HF5P204=3@`80?3`l
0P0a<C4201dM7@80;bl_0P0];Bd203`l?080EUIF0P11@D420410@0030492@P2KVi/0Vi^K0080GemO
0P1^KVh2079bLP80?Shn0P2OWil201PH6080F5QH0P1[Jf/2071`L080Rh^;0P3Jf]X20:FUYA/0XJ6Q
0P2KVi/20:>SX`80X:2P0P2TY:@?0:6QXAD0oooo000C0?ooo`80WIfM0P2SXj<20:2PX080Y:BT0P2J
VYX20:FUY@80Vi^K0P2SXj<00`2JVYX0YJFU0:FUY@0:0:6QX@80Vi^K0P2SXj<205MGE`806a/K0P16
ATH203@d=080@d=30P0l?3`203hn?P0302TY:@0V9RH09RHV0080=cLg0P35aLD20=7Ad@80QXJ60P2E
UID209:BTPH0Shn?0P2IVIT208f=S@80Shn?0P2ATI4208R8R00308>3P`28R8P0R8R80080S8b<0P2:
RXX209>CT`80TI6A0P24Q8@208V9R@80UYJF0P2?Shl2096AT@80Ng]k0P1aLG4207IfMP80Ng]k0P1i
NGT00`24Q8@0MGEe07EeM@0208f=S@80SXj>0P26QXH209BDU080S8b<0P29RHT208j>SP80PX:20P23
Ph<208V9R@80QhN70P28R8P208J6QP80OGem00<0PX:2071`L01`L7000P1eMGD206m_K`80GemO0P1H
F5P204=3@`80?3`l0P0a<C4201dM7@80;bl_0P0];Bd203`l?080EUIF0P11@D420410@0030492@P2K
Vi/0Vi^K0080GemO0P1^KVh2079bLP80?Shn0P2OWil201PH6080F5QH0P1[Jf/2071`L080Rh^;0P3J
f]X20:FUYA/0XJ6Q0P2KVi/20:>SX`80X:2P0P2TY:@?0:6QXAD0oooo000C0?ooo`80XZ:R0P2TY:@2
0:6QX@80Vi^K0P2QXJ420:BTY080VYZJ0P2UYJD00`2PX:00Y:BT0:BTY00:0:6QX@80VYZJ0P2UYJD2
02PX:080DU9B0P1:BTX202l_;`80EUIF0P0`<30203/k>`03020P800i>CT0>CTi0080>SXj0P3QhN42
096AT@80OWin0P2JVYX208n?S`80VIVI0P2=SHd208n?S`80Ti>C0P2;Rh/208V9R@80Rh^;0P1dM7@0
0`25QHD0R8R808R8R00208V9R@80QhN70P2?Shl209:BTP80Q8B40P2@T90209BDU080Shn?0P2ATI42
07emO@80J6QX0P1gMgL2075aL@<0Ng]k0P22PX8209:BTP80Rh^;0P2=SHd208J6QP80PH610P1mOGd2
08J6QP80PX:20P24Q8@208J6QP@0R8R80P24Q8@208>3P`0307EeM@20P800P8200080M7Ad0P1^KVh2
06MWI`80FEUI0P19BDT203`l?080=3@d0P0K6a/201hN7P80;bl_0P0j>SX204];B`80AdM70P11@D40
0`12@T80TY:B09:BTP0206EUI@80Jf][0P1`L70202<S8`80[Jf]0P0P820204U9B@80Kfm_0P20P802
09fMW@80e=CD102QXJ4209^KV`030:>SX`2QXJ40XJ6Q01@0XJ6Q0P2JVYX20:FUYA<0XJ6Q5@3oool0
01<0oooo0P2RXZ820:BTY080XJ6Q0P2KVi/20:6QX@80Y:BT0P2JVYX20:FUY@030:2PX02TY:@0Y:BT
00X0XJ6Q0P2JVYX20:FUY@80:2PX0P1BDU8204Y:BP80;bl_0P1FEUH2030`<080>c/k00<0820P03Ti
>@0i>CT00P0j>SX20>7Qh@80TI6A0P1nOWh209ZJVP80Shn?0P2IVIT208f=S@80Shn?0P2CTi<208^;
R`80RHV90P2;Rh/207AdM00308F5Q@28R8P0R8R80080RHV90P27QhL208n?S`80TY:B0P24Q8@2092@
T080U9BD0P2?Shl2096AT@80OGem0P1XJ6P207MgM`80LG5a0`1kNg/208:2PP80TY:B0P2;Rh/208f=
S@80QXJ60P21PH4207emO@80QXJ60P22PX8208B4Q080QXJ61028R8P208B4Q080Ph>300<0MGEe0820
P020P8000P1dM7@206i^KP80IfMW0P1IFET204U9B@80?3`l0P0d=3@201/K6`807QhN0P0_;bl203Xj
>P80Bd];0P17AdL20451@@030492@P2BTY80TY:B0080IFEU0P1[Jf/2071`L0808b<S0P2][Jd2020P
8080BDU90P1_Kfl20820P080WIfM0P3De=@40:6QX@80Vi^K00<0Xj>S0:6QX@2QXJ40502QXJ4209ZJ
VP80YJFU4`2QXJ4E0?ooo`004`3oool60:6QX@80VYZJ0P2UYJD20:6QX@80X:2P0P2NWYh00`2SXj<0
XJ6Q0:6QX@020:6QX@80Vi^K1P2MWId20:6QX@80Y:BT0P0=3@d207UiN@80<c<c0P18B4P204E5A@80
?Cdm0P0e=CD00`0K6a/0FUYJ05YJFP0209nOW`80a/K60P1dM7@208b<S080W9bL0P2?Shl209:BTP80
Rh^;0P2?Shl208V9R@80QhN70P23Ph<208N7Q`80PH6100<0M7Ad07EeM@1eMGD00P24Q8@208N7Q`80
RXZ:0P2?Shl207inOP80R8R80P2EUID208n?S`80TI6A0P1aLG4406a/K080MWIf0P1dM7@00`1eMGD0
PX:208:2PP0208f=S@80QhN70P1oOgl207alO0H0MWIf0P1dM7@206e]K@80N7Qh0P1fMWH208B4Q080
Ogmo0P20P8000`1kNg/0QHF508F5Q@02071`L080KFe]0P1RHV8205QHF080BDU90P16ATH203Ph>080
;2`/0P0B4Q8202PX:080;bl_0P1;Bd/204A4A080Cdm?00<0>CTi08V9R@29RHT00P1aLG42051@D080
I6AT0P0R8R820<[:bP80;Bd]0P0f=SH208J6QP80RHV90P2YZJT20<;2`P@0XJ6Q0P2PX:000`2TY:@0
XJ6Q0:6QX@040:6QX@80Vi^K0P2SXj<<0:6QX@80X:2P0P2TY:@40:6QX@0309^KV`2SXj<0Xj>S00`0
XJ6Q5@3oool001<0oooo1P2QXJ4209ZJVP80YJFU0P2QXJ420:2PX080WYjN00<0Xj>S0:6QX@2QXJ40
0P2QXJ4209^KV`H0WIfM0P2QXJ420:BTY0803@d=0P1iNGT203<c<`80B4Q80P15ADD203dm?@80=CDe
00<06a/K05YJFP1JFUX00P2OWil20<K6aP80M7Ad0P2<S8`209bLW080Shn?0P2BTY8208^;R`80Shn?
0P29RHT208N7Q`80Ph>30P27QhL20861P@0307AdM01eMGD0MGEe0080Q8B40P27QhL208Z:RP80Shn?
0P1nOWh208R8R080UIFE0P2?Shl2096AT@80LG5a101/K6`207IfMP80M7Ad00<0MGEe08:2PP22PX80
0P2=SHd208N7Q`80Ogmo0P1lO7`607IfMP80M7Ad0P1]KFd207QhN080MWIf0P24Q8@207moO`80P820
00<0Ng]k08F5Q@25QHD00P1`L70206e]K@80HV9R0P1HF5P204U9B@80ATI60P0h>3P202`/;0804Q8B
0P0X:2P202l_;`80Bd];0P14A4@204m?C`0303Ti>@29RHT0RHV90080LG5a0P1@D50206ATI0808R8R
0P3:b/X202d];@80=SHf0P26QXH208V9R@80ZJVY0P32`/840:6QX@80X:2P00<0Y:BT0:6QX@2QXJ40
102QXJ4209^KV`80Xj>S302QXJ420:2PX080Y:BT102QXJ400`2KVi/0Xj>S0:>SX`0<0:6QXAD0oooo
000C0?ooo`H0XJ6Q0P2PX:020:BTY0@0XJ6Q0P2PX:000`2TY:@0Vi^K09^KV`020:>SX`80VYZJ0P2T
Y:@40::RXP80Y:BT0P2[Zj/2014A4@80JVYZ0P0/;2`204E5A@80>3Ph0P16ATH201HF5P0303lo?`13
@d<0@d=30080e=CD0P1OGel206m_K`80X:2P0P2IVIT208j>SP@0Shn?0P29RHT20820P080Kfm_0P1H
F5P205MGE`80M7Ad00<0J6QX05iNGP1NGUh00P24Q8@207QhN080UYJF0P2>SXh208>3P`80RHV90P2J
VYX2092@T080TI6A0P1jNWX206m_K`80IVIV101/K6`00`2=SHd0NGUi07UiN@0209>CT`80M7Ad0P1c
Lg<206YZJP80HF5Q0P1CDe<205aLG080KFe]0P1XJ6P206a/K080Lg=c0P2=SHd208:2PP80M7Ad00<0
MWIf07MgM`1gMgL00P1bLW8206e]K@80IFEU0P1JFUX2055AD@80?3`l0P0g=cL2038b<P809bLW0P0Y
:BT202PX:080B4Q80P0l?3`204a<C00303dm?@1hN7P0N7Qh0080I6AT0P1<C4`205]KF`80<C4a0P3:
b/X2028R8P80=3@d0P2GUiL207EeM@80[jn_0P36a/H209jNWP/0XJ6Q0P2PX:020:BTY1@0XJ6Q00<0
X:2P0:BTY02TY:@0302QXJ4E0?ooo`004`3oool60:6QX@80X:2P0P2TY:@40:6QX@80X:2P00<0Y:BT
09^KV`2KVi/00P2SXj<209ZJVP80Y:BT102RXZ820:BTY080Zj^[0P0A4A4206YZJP80;2`/0P15ADD2
03Ph>080ATI60P0F5QH00`0o?cl0@d=304=3@`020=CDe080GemO0P1_Kfl20:2PX080VIVI0P2>SXh4
08n?S`80RHV90P20P80206m_K`80F5QH0P1GEeL207AdM00306QXJ01NGUh0GUiN0080Q8B40P1hN7P2
09JFUP80SXj>0P23Ph<208V9R@80VYZJ0P2@T902096AT@80NWYj0P1_Kfl206IVIP@0K6a/00<0SHf=
07UiN@1iNGT00P2CTi<207AdM080Lg=c0P1ZJVX2065QH@80De=C0P1LG5`206e]K@80J6QX0P1/K6`2
07=cL`80SHf=0P22PX8207AdM00307IfMP1gMgL0MgMg0080LW9b0P1]KFd206EUI@80FUYJ0P1ADE42
03`l?080=cLg0P0b<S8202LW9`80:BTY0P0X:2P204Q8B080?3`l0P1<C4`00`0m?Cd0N7Qh07QhN002
06ATI080C4a<0P1KFe/2034a<@80b/[:0P0R8R8203@d=080UiNG0P1eMGD20:n_[`80a/K60P2NWYh;
0:6QX@80X:2P0P2TY:@D0:6QX@030:2PX02TY:@0Y:BT00`0XJ6Q5@3oool001<0oooo0P2MWId20:>S
X`H0XJ6Q0P2KVi/20:>SX`80Vi^K00<0Xj>S0:2PX02PX:000P2TY:@20:2PX080Y:BT1P2QXJ4204i>
CP80:BTY0P1BDU8202XZ:P80?clo0P0c<c<204U9B@8071`L00<0EEEE0:RXZ02XZ:P00P2c/k<205=C
D`80OGem0P2VYZH208j>SP80T92@0P2?Shl208>3P`80Kfm_0P19BDT205MGE`80Ng]k0P1dM7@203`l
?00304A4A01HF5P0F5QH0080NGUi0P1PH60206QXJ080UIFE0P25QHD208B4Q080Vi^K102@T90207al
O080LW9b0P1SHf<207AdM080HV9R00<0Ogmo02TY:@0Y:BT00P1>CTh205]KF`80MgMg0P2>SXh20410
@080<C4a0P1MGEd205MGE`80DE5A0P1BDU8205iNGP80P8200P1hN7P207=cL`<0NGUi0P1_Kfl2071`
L080HF5Q0P1IFET204Y:BP80A4A40P0o?cl2038b<P80?Shn0P0M7Ad2024Q8@80BTY:0P0m?Cd204I6
AP0304m?C`1_Kfl0Kfm_0080KFe]0P1;Bd/205YJFP80<S8b0P36a/H202DU9@80De=C0P2UYJD207Ui
N@80a/K60P2h^;P209fMWAT0XJ6Q0P2KVi/20:>SXaD0XJ6Q5@3oool001<0oooo0P2MWId20:>SX`H0
XJ6Q0P2KVi/20:>SX`80Vi^K00<0Xj>S0:2PX02PX:000P2TY:@20:2PX080Y:BT1P2QXJ4204i>CP80
:BTY0P1BDU8202XZ:P80?clo0P0c<c<204U9B@8071`L00<0EEEE0:RXZ02XZ:P00P2c/k<205=CD`80
OGem0P2VYZH208j>SP80T92@0P2?Shl208>3P`80Kfm_0P19BDT205MGE`80Ng]k0P1dM7@203`l?003
04A4A01HF5P0F5QH0080NGUi0P1PH60206QXJ080UIFE0P25QHD208B4Q080Vi^K102@T90207alO080
LW9b0P1SHf<207AdM080HV9R00<0Ogmo02TY:@0Y:BT00P1>CTh205]KF`80MgMg0P2>SXh20410@080
<C4a0P1MGEd205MGE`80DE5A0P1BDU8205iNGP80P8200P1hN7P207=cL`<0NGUi0P1_Kfl2071`L080
HF5Q0P1IFET204Y:BP80A4A40P0o?cl2038b<P80?Shn0P0M7Ad2024Q8@80BTY:0P0m?Cd204I6AP03
04m?C`1_Kfl0Kfm_0080KFe]0P1;Bd/205YJFP80<S8b0P36a/H202DU9@80De=C0P2UYJD207UiN@80
a/K60P2h^;P209fMWAT0XJ6Q0P2KVi/20:>SXaD0XJ6Q5@3oool001<0oooo0P2RXZ820:BTY0H0XJ6Q
0P2PX:020:BTY080X:2P00<0Y:BT0:6QX@2QXJ400P2QXJ4209^KV`80Xj>S1P2QXJ4202`/;080J6QX
0P18B4P203dm?@808R8R0P10@40204];B`807alO00<08b<S0>GUi@3UiND00P1cLg<206e]K@80Ogmo
0P2UYJD209BDU080Rh^;0P20P80206i^KP80BDU90P1CDe<209NGU`80[Jf]100d=3@00`0i>CT0G5aL
05aLG00205aLG080LG5a0P1UIFD209FEU@80Lg=c0P2;Rh/209bLW080T92@0P27QhL207moO`80M7Ad
0P1YJFT2069RHP80De=C00<0I6AT05eMG@1MGEd00P0i>CT20;^k^`80_;bl0P0k>c/203Xj>P80?clo
0P1_Kfl203Ph>080OWin0P19BDT204Q8B080JVYZ0P1lO7`2075aL@0307]kN`1gMgL0MgMg0080KVi^
0P1/K6`206UYJ@80E5AD0P1;Bd/204U9B@80=CDe0P0b<S8202@T90802PX:0P0L71`204e=C@80A4A4
0P0`<3000`1GEeL0Jf][06][J`02061PH080@4100P1JFUX20492@P80/;2`0P0K6a/207inOP80U9BD
0P1gMgL20=OGe`80ZJVY5@2QXJ4209^KV`80Xj>S0P2QXJ420:2PX080WYjN0P2SXj<C0:6QXAD0oooo
000C0?ooo`80XZ:R0P2TY:@60:6QX@80X:2P0P2TY:@20:2PX0030:BTY02QXJ40XJ6Q0080XJ6Q0P2K
Vi/20:>SX`H0XJ6Q0P0/;2`206QXJ080B4Q80P0m?Cd2028R8P80@4100P1;Bd/201lO7`0302<S8`3U
iND0iNGU0080Lg=c0P1]KFd207moO`80YJFU0P2DU9@208^;R`80P8200P1^KVh204U9B@80De=C0P2G
UiL20:f][@@0=3@d00<0>CTi05aLG01LG5`00P1LG5`2075aL@80IFEU0P2EUID207=cL`80Rh^;0P2L
W9`2092@T080QhN70P1oOgl207AdM080JFUY0P1RHV8205=CD`0306ATI01MGEd0GEeM0080>CTi0P2k
^k/20;bl_080>c/k0P0j>SX203lo?`80Kfm_0P0h>3P207inOP80BDU90P18B4P206YZJP80O7al0P1a
LG400`1kNg/0MgMg07MgM`0206i^KP80K6a/0P1YJFT205ADE080Bd];0P19BDT203De=@80<S8b0P0T
92@200X:2P8071`L0P1=CDd204A4A080<30`00<0EeMG06][J`1[Jf/00P1PH6020410@080FUYJ0P12
@T820;2`/0806a/K0P1nOWh209BDU080MgMg0P3GemL20:VYZAD0XJ6Q0P2KVi/20:>SX`80XJ6Q0P2P
X:0209jNWP80Xj>S4`2QXJ4E0?ooo`004`3oool@0:6QX@0309^KV`2SXj<0Xj>S0080XJ6Q0P2PX:02
0:BTY0@0XJ6Q0P2[Zj/207QhN080Bd];0P0/;2`2034a<@807QhN0P19BDT203hn?P80=cLg00<0B4Q8
0??cl`3clo<00P1QHF4206EUI@80OWin0P2HV9P208n?S`80PH610P1]KFd205IFEP80>c/k0P0Q8B44
08B4Q080;Rh^0P2<S8`00`092@T0I6AT06ATI00202`/;080FUYJ0P1MGEd2071`L080QhN70P2KVi/2
09ZJVP80T92@0P28R8P208:2PP80NGUi0P1hN7P205QHF080G5aL00<0Bd];06YZJP1ZJVX00P1IFET2
05YJFP80WYjN0P0E5AD209nOW`8020P80P1LG5`2030`<080U9BD0P0B4Q8203/k>`80IVIV0P1/K6`2
06EUI@0307UiN@1bLW80LW9b0080Kfm_0P1NGUh206EUI@80EeMG0P1<C4`203dm?@@0=cLg0P0E5AD2
018B4P807AdM0P0V9RH204=3@`80<C4a00<0J6QX05ADE01DE5@00P1FEUH2051@D080GemO0P16ATH2
0:2PX0806a/K0P25QHD207YjNP80TY:B0P3De=@G0:6QX@80X:2P0P2TY:@40:6QX@80X:2P0P2TY:@C
0:6QXAD0oooo000C0?oooa00XJ6Q00<0Vi^K0:>SX`2SXj<00P2QXJ420:2PX080Y:BT102QXJ420:^[
Z`80N7Qh0P1;Bd/202`/;080<C4a0P0N7Qh204U9B@80?Shn0P0g=cL00`18B4P0lo?c0??cl`02065Q
H@80IFEU0P1nOWh209RHV080Shn?0P21PH4206e]K@80EUIF0P0k>c/2024Q8@@0Q8B40P0^;Rh208b<
S00300T92@1TI6@0I6AT0080;2`/0P1JFUX205eMG@80L71`0P27QhL209^KV`80VYZJ0P2@T90208R8
R080PX:20P1iNGT207QhN080F5QH0P1LG5`00`1;Bd/0JVYZ06YZJP0205UIF@80FUYJ0P2NWYh201DE
5@80WinO0P0820P205aLG080<30`0P2DU9@2018B4P80>c/k0P1VIVH206a/K080IFEU00<0NGUi079b
LP1bLW800P1_Kfl205iNGP80IFEU0P1GEeL204a<C080?Cdm100g=cL201DE5@804Q8B0P0M7Ad202HV
9P80@d=30P0a<C400`1XJ6P0E5AD05ADE00205IFEP80D51@0P1OGel204I6AP80X:2P0P0K6a/208F5
Q@80NWYj0P2BTY820=CDe1L0XJ6Q0P2PX:020:BTY0@0XJ6Q0P2PX:020:BTY1<0XJ6Q5@3oool001<0
oooo402QXJ400`2PX:00Y:BT0:BTY00:0:6QX@80ATI60P23Ph<2038b<P80@T920P0g=cL2038b<P80
ATI60P0m?Cd204M7A`0306YZJP2j^[X0^[Zj0080EeMG0P1[Jf/208>3P`80VIVI0P2@T90207AdM080
I6AT0P1ADE4202DU9@80?clo0P1GEeL202PX:0804a<C0P0/;2`00`0V9RH0IFEU06EUI@0203dm?@80
JVYZ0P1fMWH208f=S@80V9RH0P2KVi/2092@T080TY:B0P28R8P20861P@80OGem0P1jNWX206IVIP80
HF5Q00<0FUYJ05EEE@1EEED00P1<C4`205]KF`80Lg=c0P0B4Q8202DU9@805QHF0P0d=3@403<c<`80
;Bd]0P14A4@206YZJP80Hf=S0P1OGel00`1aLG40L71`071`L00206e]K@80GEeM0P1IFET205=CD`80
>CTi0P0l?3`20451@@80<c<c0P0V9RH201TI6@80;bl_0P0`<302038b<P80=SHf00<0GEeM05EEE@1E
EED00P1<C4`204E5A@80GemO0P1>CTh209bLW080:2PX0P1oOgl207YjNP80`l?30P2n_[hW0:6QX@03
09^KV`2SXj<0Xj>S00`0XJ6Q5@3oool001<0oooo402QXJ400`2PX:00Y:BT0:BTY00:0:6QX@80ATI6
0P23Ph<2038b<P80@T920P0g=cL2038b<P80ATI60P0m?Cd204M7A`0306YZJP2j^[X0^[Zj0080EeMG
0P1[Jf/208>3P`80VIVI0P2@T90207AdM080I6AT0P1ADE4202DU9@80?clo0P1GEeL202PX:0804a<C
0P0/;2`00`0V9RH0IFEU06EUI@0203dm?@80JVYZ0P1fMWH208f=S@80V9RH0P2KVi/2092@T080TY:B
0P28R8P20861P@80OGem0P1jNWX206IVIP80HF5Q00<0FUYJ05EEE@1EEED00P1<C4`205]KF`80Lg=c
0P0B4Q8202DU9@805QHF0P0d=3@403<c<`80;Bd]0P14A4@206YZJP80Hf=S0P1OGel00`1aLG40L71`
071`L00206e]K@80GEeM0P1IFET205=CD`80>CTi0P0l?3`20451@@80<c<c0P0V9RH201TI6@80;bl_
0P0`<302038b<P80=SHf00<0GEeM05EEE@1EEED00P1<C4`204E5A@80GemO0P1>CTh209bLW080:2PX
0P1oOgl207YjNP80`l?30P2n_[hW0:6QX@0309^KV`2SXj<0Xj>S00`0XJ6Q5@3oool001<0oooo202Q
XJ4209^KV`80Xj>S102QXJ400`2KVi/0Xj>S0:>SX`0:0:6QX@808R8R0P1oOgl205IFEP80<c<c0P0^
;Rh204Y:BP80?Shn0P0d=3@203dm?@0307UiN@2DU9@0U9BD0080HF5Q0P1`L7020861P@80VYZJ0P26
QXH207moO`80O7al0P1`L70205EEE@80EUIF0P14A4@203De=@80>c/k0P12@T800`14A4@0FUYJ05YJ
FP0206YZJP80Rh^;0P2DU9@209fMW@80Shn?0P2FUYH409>CT`80R8R80P21PH4208F5Q@80QXJ60P1f
MWH206a/K00306e]K@1QHF40HF5Q0080G5aL0P11@D4205UIF@80CDe=0P1JFUX204Y:BP80<c<c0P0`
<30203Hf=P80HF5Q0P1^KVh2075aL@80IFEU0P1^KVh00`1iNGT0LW9b079bLP02069RHP80IVIV0P1L
G5`204];B`80>CTi0P12@T8203/k>`80>SXj0P0_;bl201dM7@80;bl_100V9RH203Hf=P03069RHP1P
H600H61P0080C4a<0P15ADD406EUI@80TY:B0P0a<C4207IfMP80PH610P3Bd]820:b/[2L0XJ6Q00<0
X:2P0:BTY02TY:@0302QXJ4E0?ooo`004`3oool80:6QX@80Vi^K0P2SXj<40:6QX@0309^KV`2SXj<0
Xj>S00X0XJ6Q0P0R8R8207moO`80EUIF0P0c<c<202h^;P80BTY:0P0n?Sh203@d=080?Cdm00<0NGUi
09BDU02DU9@00P1QHF42071`L080PH610P2JVYX208J6QP80Ogmo0P1lO7`2071`L080EEEE0P1FEUH2
04A4A080=CDe0P0k>c/20492@P0304A4A01JFUX0FUYJ0080JVYZ0P2;Rh/209BDU080WIfM0P2?Shl2
09JFUP@0Ti>C0P28R8P20861P@80QHF50P26QXH207IfMP80K6a/00<0KFe]065QH@1QHF400P1LG5`2
0451@@80FEUI0P1=CDd205YJFP80BTY:0P0c<c<2030`<080=SHf0P1QHF4206i^KP80LG5a0P1UIFD2
06i^KP0307UiN@1bLW80LW9b0080HV9R0P1VIVH205aLG080Bd];0P0i>CT20492@P80>c/k0P0j>SX2
02l_;`807AdM0P0_;bl402HV9P80=SHf00<0HV9R061PH01PH6000P1<C4`204E5A@@0IFEU0P2BTY82
034a<@80MWIf0P21PH420=;BdP80[:b/9`2QXJ400`2PX:00Y:BT0:BTY00<0:6QXAD0oooo000C0?oo
o`P0XJ6Q0P2PX:020:BTY0@0XJ6Q00<0X:2P0:BTY02TY:@0102QXJ4209^KV`80Xj>S0P2QXJ4206a/
K080EeMG0P11@D4202HV9P80;Rh^0P0j>SX203<c<`80:BTY0P1IFET00`1jNWX0MGEe07EeM@0206QX
J080Hf=S0P1lO7`209VIV@80SHf=0P2<S8`209BDU080RHV90P23Ph<208Z:RP@0R8R80P2;Rh/209:B
TP0309RHV02FUYH0UYJF0080MgMg0P22PX8208>3P`80TY:B0P2GUiL208n?S`80Ti>C102?Shl208V9
R@80RXZ:0P26QXH207=cL`80HV9R00<0KVi^05mOG`1OGel00P1gMgL2071`L080QHF50P1XJ6P206MW
I`80IVIV0P1/K6`207emO@80R8R80P2<S8`208^;R`80PH610P1nOWh207UiN@0307MgM`1]KFd0KFe]
0080Hf=S101NGUh2055AD@80>SXj0P17AdL203Xj>P80:BTY0P0Z:RX201dM7@80;Bd]0P0i>CT203<c
<`80;Rh^00<0H61P06i^KP1^KVh01014A4@2075aL@80Kfm_0P2=SHd203De=@80NWYj0P2o_kl20=SH
f080Xj>S<P2QXJ4209^KV`80Xj>S5@3oool001<0oooo202QXJ420:2PX080Y:BT102QXJ400`2PX:00
Y:BT0:BTY0040:6QX@80Vi^K0P2SXj<20:6QX@80K6a/0P1GEeL20451@@809RHV0P0^;Rh203Xj>P80
<c<c0P0Y:BT205UIF@0307YjNP1eMGD0MGEe0080J6QX0P1SHf<207alO080VIVI0P2=SHd208b<S080
U9BD0P29RHT208>3P`80RXZ:1028R8P208^;R`80TY:B00<0V9RH09JFUP2FUYH00P1gMgL208:2PP80
Ph>30P2BTY8209NGU`80Shn?0P2CTi<408n?S`80RHV90P2:RXX208J6QP80Lg=c0P1RHV800`1^KVh0
GemO05mOG`0207MgM`80L71`0P25QHD206QXJ080IfMW0P1VIVH206a/K080OGem0P28R8P208b<S080
Rh^;0P21PH4207inOP80NGUi00<0MgMg06e]K@1]KFd00P1SHf<405iNGP80DE5A0P0j>SX204M7A`80
>SXj0P0Y:BT202XZ:P807AdM0P0];Bd203Ti>@80<c<c0P0^;Rh00`1PH600KVi^06i^KP0404A4A080
LG5a0P1_Kfl208f=S@80=CDe0P1jNWX20;no_`80f=SH0P2SXj<b0:6QX@80Vi^K0P2SXj<E0?ooo`00
4`3oool40:6QX@80Vi^K0P2SXj<20:6QX@80Vi^K0P2SXj<70:6QX@80Vi^K0P2QXJ420:BTY080Zj^[
0P2SXj<200`<3080?Shn0P0M7Ad202`/;080;Bd]0P1@D502020P8080Bd];00<0GEeM075aL@1aLG40
0P1[Jf/205]KF`80P8200P2UYJD207inOP80TY:B0P2FUYH408j>SP80U9BD0P2@T90209:BTP80Jf][
0P1FEUH00`1=CDd0ADE504E5A@0204M7A`80UIFE0P2BTY820:6QX@80UiNG0P2?Shl209ZJVP80SHf=
0P2ATI4208f=S@80RXZ:0P2BTY8207QhN080L71`00<0EeMG03lo?`0o?cl00P1@D50204e=C@80HV9R
0P2>SXh2096AT@80TY:B0P2?Shl208Z:RP80RHV90P20P80208>3P`80P8200P1fMWH206e]K@03065Q
H@1DE5@0E5AD0080JFUY0P1LG5`205EEE@80CDe=0P14A4@20451@@80>3Ph0P0j>SX2020P80807alO
0P0R8R8202d];@806QXJ0P0j>SX00`1?Cdl0GemO05mOG`020492@P80ADE50P1iNGT206a/K080VYZJ
0P0i>CT208:2PP80dm?C0P2d];@209fMWC80XJ6Q0P2PX:020:BTY1D0oooo000C0?ooo`@0XJ6Q0P2P
X:020:BTY080XJ6Q0P2PX:020:BTY0L0XJ6Q0P2PX:020:BTY080XJ6Q0P2CTi<20:j^[P8000000P0l
?3`201lO7`80;bl_0P0i>CT204I6AP80;Bd]0`1GEeL206=SH`80I6AT0P1MGEd207QhN080Xj>S0P1n
OWh208B4Q080Rh^;0P2DU9@208j>SP80T92@0P25QHD204I6AP80@d=30P11@D400`1>CTh0Ph>308>3
P`020:2PX080];Bd0P2EUID209VIV@80V9RH0P2>SXh209ZJVP80RHV90P2ATI42092@T080Shn?0P2=
SHd208F5Q@80PX:200<0K6a/05ADE01DE5@00P0m?Cd203Xj>P80ATI60P1KFe/207inOP80Ng]k0P29
RHT208N7Q`80RHV90P1jNWX208B4Q080M7Ad0P1^KVh205aLG00304U9B@1/K6`0K6a/0080I6AT0P1H
F5P204a<C080B4Q80P1:BTX203dm?@809bLW0P0[:b/201/K6`809bLW0P0Q8B4201hN7P80@4100P1<
C4`00`1EEED0HF5Q065QH@0204e=C@80?Cdm0P1iNGT2069RHP80Rh^;0P1>CTh207]kN`80i>CT0P2Y
ZJTh0:6QXAD0oooo000C0?ooo`@0XJ6Q0P2PX:020:BTY080XJ6Q0P2PX:020:BTY0L0XJ6Q0P2PX:02
0:BTY080XJ6Q0P2CTi<20:j^[P8000000P0l?3`201lO7`80;bl_0P0i>CT204I6AP80;Bd]0`1GEeL2
06=SH`80I6AT0P1MGEd207QhN080Xj>S0P1nOWh208B4Q080Rh^;0P2DU9@208j>SP80T92@0P25QHD2
04I6AP80@d=30P11@D400`1>CTh0Ph>308>3P`020:2PX080];Bd0P2EUID209VIV@80V9RH0P2>SXh2
09ZJVP80RHV90P2ATI42092@T080Shn?0P2=SHd208F5Q@80PX:200<0K6a/05ADE01DE5@00P0m?Cd2
03Xj>P80ATI60P1KFe/207inOP80Ng]k0P29RHT208N7Q`80RHV90P1jNWX208B4Q080M7Ad0P1^KVh2
05aLG00304U9B@1/K6`0K6a/0080I6AT0P1HF5P204a<C080B4Q80P1:BTX203dm?@809bLW0P0[:b/2
01/K6`809bLW0P0Q8B4201hN7P80@4100P1<C4`00`1EEED0HF5Q065QH@0204e=C@80?Cdm0P1iNGT2
069RHP80Rh^;0P1>CTh207]kN`80i>CT0P2YZJTh0:6QXAD0oooo000C0?oooaD0XJ6Q0P2KVi/20:>S
X`80Zj^[0P1CDe<20<g=c@8010@40P0c<c<203@d=080>CTi0P0U9BD204A4A080=3@d0P1;Bd/304E5
A@80GEeM0P1OGel207MgM`80Y:BT0P2>SXh205=CD`80Jf][0P1bLW8206ATI080FUYJ0P10@40203lo
?`80NGUi0`2XZ:P20;>c/`80Zj^[0P2LW9`209NGU`80VIVI0P2HV9P209>CT`80Shn?0P2;Rh/2092@
T080Shn?0P2ATI4208f=S@80Rh^;0P2:RXX00`29RHT0Q8B408B4Q00207IfMP80N7Qh0P1VIVH2055A
D@80A4A40P1?Cdl204I6AP80DU9B0P1LG5`205IFEP80EEEE0P1:BTX204i>CP80EeMG00<0I6AT071`
L01`L7000P1SHf<205mOG`80C4a<0P18B4P204e=C@80=SHf0P1=CDd201HF5P@0=CDe0P0/;2`2020P
80808B4Q0P1@D5000`1CDe<0FUYJ05YJFP0204Q8B080@T920P1jNWX207EeM@80GUiN0P11@D420:f]
[@80fm_K7`2QXJ4209^KV`80Xj>S5`2QXJ4E0?ooo`004`3ooolE0:6QX@80Vi^K0P2SXj<20:^[Z`80
De=C0P3=cLd200@41080<c<c0P0d=3@203Ti>@809BDU0P14A4@203@d=080Bd];0`15ADD205eMG@80
GemO0P1gMgL20:BTY080SXj>0P1CDe<206][J`80LW9b0P1TI6@205YJFP80@4100P0o?cl207UiN@<0
Z:RX0P2c/k<20:^[Z`80W9bL0P2GUiL209VIV@80V9RH0P2CTi<208n?S`80Rh^;0P2@T90208n?S`80
TI6A0P2=SHd208^;R`80RXZ:00<0RHV908B4Q024Q8@00P1fMWH207QhN080IVIV0P1ADE4204A4A080
Cdm?0P16ATH2059BDP80G5aL0P1FEUH205EEE@80BTY:0P1>CTh205MGE`0306ATI01`L700L71`0080
Hf=S0P1OGel204a<C080B4Q80P1=CDd203Hf=P80CDe=0P0F5QH403De=@80;2`/0P0P8202024Q8@80
D51@00<0De=C05YJFP1JFUX00P18B4P20492@P80NWYj0P1eMGD205iNGP80@D510P2][Jd20=_Kfal0
XJ6Q0P2KVi/20:>SXaL0XJ6Q5@3oool001<0oooo5@2QXJ4209ZJVP80YJFU0P2TY:@20451@@80CTi>
0P0B4Q8203@d=080C4a<0P0m?Cd2038b<P80?3`l0P0d=3@20492@P0304A4A018B4P0B4Q80080FUYJ
0P1IFET208N7Q`80XJ6Q0P2ATI4207]kN`80TY:B0P1_Kfl206EUI@80H61P0P1nOWh20:f][@80^KVi
0P2_[jl00`2IVIT0UYJF09JFUP0209RHV0P0U9BD0P2FUYH208V9R@80Shn?0P2IVIT209JFUP80UiNG
0P2>SXh208n?S`80T92@00<0TY:B08Z:RP2:RXX00P23Ph<208F5Q@80QXJ60P2;Rh/2092@T080X:2P
0P1YJFT205IFEP@0EEEE0P1CDe<206a/K080Lg=c0P1[Jf/00`1_Kfl0LW9b079bLP0206MWI`80GEeM
0P1:BTX204e=C@80EUIF0P0d=3@202/[:`80;Bd]0P0a<C4202DU9@804Q8B0P0C4a<201/K6`80GemO
00<0EEEE0410@010@4000P1JFUX204U9B@80Ogmo0P1dM7@203`l?080IFEU0P3UiND20;^k^al0XJ6Q
0P2PX:020:BTY080Vi^K0P2SXj<C0:6QXAD0oooo000C0?oooaD0XJ6Q0P2JVYX20:FUY@80Y:BT0P11
@D4204i>CP804Q8B0P0d=3@204a<C080?Cdm0P0b<S8203`l?080=3@d0P12@T800`14A4@0B4Q804Q8
B00205YJFP80FEUI0P27QhL20:6QX@80TI6A0P1kNg/209:BTP80Kfm_0P1UIFD2061PH080OWin0P2]
[Jd20;Vi^@80[jn_00<0VIVI09JFUP2FUYH00P2HV9P809BDU080UYJF0P29RHT208n?S`80VIVI0P2F
UYH209NGU`80SXj>0P2?Shl2092@T00309:BTP2:RXX0RXZ:0080Ph>30P25QHD208J6QP80Rh^;0P2@
T9020:2PX080JFUY0P1FEUH405EEE@80De=C0P1/K6`207=cL`80Jf][00<0Kfm_079bLP1bLW800P1W
IfL205eMG@80BTY:0P1=CDd205IFEP80=3@d0P0[:b/202d];@80<C4a0P0U9BD2018B4P804a<C0P0K
6a/205mOG`0305EEE@10@400@4100080FUYJ0P19BDT207moO`80M7Ad0P0l?3`206EUI@80iNGU0P2k
^k/O0:6QX@80X:2P0P2TY:@209^KV`80Xj>S4`2QXJ4E0?ooo`004`3oool80:6QX@80Vi^K0P2SXj<4
0:6QX@0309^KV`2SXj<0Xj>S0080XJ6Q0P2PX:020:BTY080XJ6Q0P1LG5`2038b<P@0=CDe0P1WIfL2
04M7A`80?3`l0P0n?Sh203De=@80B4Q800<0A4A404U9B@19BDT00P1LG5`205IFEP80R8R80P2PX:02
08^;R`80S8b<0P29RHT208b<S080UYJF0P2IVIT20:FUY@80X:2P0P2KVi/;09BDU080UYJF0P2DU9@2
09FEU@80RHV9102IVIT209BDU080Rh^;0P2<S8`408n?S`03092@T02?Shl0Shn?0080QhN70P2;Rh/2
08n?S`80QHF50P27QhL208R8R080M7Ad0P26QXH209>CT`80R8R80P20P80208N7Q`80MgMg0P1/K6`0
0`1hN7P0I6AT06ATI00205]KF`80DU9B0P1<C4`205IFEP80EEEE0P15ADD202l_;`80;Bd]0P0J6QX4
01<C4`805ADE0P0L71`209>CT`0304=3@`0m?Cd0?Cdm0080SXj>0P11@D4206IVIP80QXJ60P0f=SH2
08F5Q@80kNg]0P2YZJTS0:6QX@80X:2P0P2TY:@C0:6QXAD0oooo000C0?ooo`P0XJ6Q0P2KVi/20:>S
X`@0XJ6Q00<0Vi^K0:>SX`2SXj<00P2QXJ420:2PX080Y:BT0P2QXJ4205aLG080<S8b100e=CD206MW
I`80AdM70P0l?3`203hn?P80=CDe0P18B4P00`14A4@0BDU904U9B@0205aLG080EUIF0P28R8P20:2P
X080Rh^;0P2<S8`208V9R@80S8b<0P2FUYH209VIV@80YJFU0P2PX:0209^KV`/0U9BD0P2FUYH209BD
U080UIFE0P29RHT409VIV@80U9BD0P2;Rh/208b<S0@0Shn?00<0T92@08n?S`2?Shl00P27QhL208^;
R`80Shn?0P25QHD208N7Q`80R8R80P1dM7@208J6QP80Ti>C0P28R8P20820P080QhN70P1gMgL206a/
K00307QhN01TI6@0I6AT0080Fe]K0P1BDU8204a<C080EUIF0P1EEED204E5A@80;bl_0P0];Bd201XJ
6P@04a<C0P0E5AD201`L7080Ti>C00<0@d=303dm?@0m?Cd00P2>SXh20451@@80IVIV0P26QXH203Hf
=P80QHF50P3]kNd20:VYZB<0XJ6Q0P2PX:020:BTY1<0XJ6Q5@3oool001<0oooo102QXJ4209^KV`80
Xj>S0P2PX:020:BTY080XJ6Q0P2KVi/00`2QXJ40Y:BT0:BTY0080:6QX@80EEEE0P0J6QX203Hf=P80
@D510P1hN7P204=3@`80=cLg0P12@T8203hn?P80ADE500<0@D5104A4A014A4@00P1QHF4204i>CP80
RHV90P2PX:0208n?S`80SHf=0P2<S8`209JFUP80T92@0P2>SXh209VIV@80UYJF102?Shl00`2FUYH0
U9BD09BDU00209BDU080SHf=0P2FUYH209FEU@@0U9BD0P2;Rh/2096AT@80UiNG102;Rh/209VIV@80
SHf=0P2ATI400`2@T900TI6A096AT@0208j>SP80QXJ60P2?Shl208:2PP80QhN70P25QHD207alO080
SHf=0P1hN7P207UiN@80Lg=c0P1_Kfl2071`L080JVYZ00<0L71`05eMG@1MGEd00P1VIVH205iNGP80
C4a<0P1EEED205=CD`80>c/k0P1:BTX202d];@807AdM0P0Q8B4201/K6`80:BTY0P0N7Qh20:FUY@03
04Q8B00m?Cd0?Cdm0080R8R80P11@D4204i>CP80V9RH0P0b<S820:f][@80jn_[0P2NWYhj0:6QXAD0
oooo000C0?ooo`@0XJ6Q0P2KVi/20:>SX`80X:2P0P2TY:@20:6QX@80Vi^K00<0XJ6Q0:BTY02TY:@0
202QXJ4205EEE@806QXJ0P0f=SH20451@@80N7Qh0P13@d<203Lg=`80@T920P0n?Sh204E5A@030451
@@14A4@0A4A40080HF5Q0P1>CTh208V9R@80X:2P0P2?Shl208f=S@80S8b<0P2FUYH2092@T080SXj>
0P2IVIT209JFUP@0Shn?00<0UYJF09BDU02DU9@00P2DU9@208f=S@80UYJF0P2EUID409BDU080Rh^;
0P2ATI4209NGU`@0Rh^;0P2IVIT208f=S@80TI6A00<0T92@096AT@2ATI400P2>SXh208J6QP80Shn?
0P22PX8208N7Q`80QHF50P1lO7`208f=S@80N7Qh0P1iNGT207=cL`80Kfm_0P1`L70206YZJP03071`
L01MGEd0GEeM0080IVIV0P1NGUh204a<C080EEEE0P1CDe<203/k>`80BTY:0P0];Bd201dM7@808B4Q
0P0K6a/202TY:@807QhN0P2UYJD00`18B4P0?Cdm03dm?@0208R8R080@D510P1>CTh209RHV080<S8b
0P2][Jd20>_[j`80WYjN>P2QXJ4E0?ooo`004`3oool40:6QX@80X:2P0P2TY:@60:6QX@80X:2P00<0
Y:BT0:6QX@2QXJ40202QXJ4206MWI`806QXJ0P1@D50204U9B@80GEeM0P0m?Cd204M7A`80B4Q80P0o
?cl203dm?@<0?3`l0P1GEeL204m?C`80Lg=c0P2LW9`208j>SP80S8b<0P2;Rh/208j>SP80TY:B0P2@
T902096AT@80UiNG0P2BTY8208n?S`0309ZJVP2DU9@0U9BD0080U9BD0P2CTi<209RHV0H0U9BD0P2C
Ti<209JFUP80VIVI0P2BTY8209JFUP80Shn?0P2;Rh/2092@T00308Z:RP2;Rh/0Rh^;0080Rh^;0P28
R8P208n?S`80PX:20P26QXH208B4Q080QhN70P22PX8207]kN`80O7al0P1cLg<207EeM@80LW9b0P1a
LG400`1]KFd0Jf][06][J`0206QXJ080D51@0P1<C4`205aLG080CTi>0P17AdL203<c<`807QhN0P0[
:b/202HV9P804a<C0P0F5QH201XJ6P80Z:RX00<0BTY:04A4A014A4@00P2@T90204I6AP80@4100P24
Q8@203Hf=P80no_k0P33`l<209fMWCX0XJ6Q5@3oool001<0oooo102QXJ420:2PX080Y:BT1P2QXJ42
0:2PX0030:BTY02QXJ40XJ6Q00P0XJ6Q0P1WIfL201XJ6P80D51@0P19BDT205eMG@80?Cdm0P17AdL2
04Q8B080?clo0P0m?Cd303`l?080EeMG0P1?Cdl207=cL`80W9bL0P2>SXh208b<S080Rh^;0P2>SXh2
09:BTP80T92@0P2ATI4209NGU`80TY:B0P2?Shl00`2JVYX0U9BD09BDU00209BDU080Ti>C0P2HV9P6
09BDU080Ti>C0P2FUYH209VIV@80TY:B0P2FUYH208n?S`80Rh^;0P2@T9000`2:RXX0Rh^;08^;R`02
08^;R`80R8R80P2?Shl208:2PP80QXJ60P24Q8@208N7Q`80PX:20P1kNg/207alO080Lg=c0P1eMGD2
079bLP80LG5a00<0KFe]06][J`1[Jf/00P1XJ6P2051@D080C4a<0P1LG5`204i>CP80AdM70P0c<c<2
01hN7P80:b/[0P0V9RH201<C4`805QHF0P0J6QX20:RXZ00304Y:BP14A4@0A4A40080T92@0P16ATH2
0410@080Q8B40P0f=SH20?_kn`80`l?30P2MWIdj0:6QXAD0oooo000C0?ooo`X0XJ6Q0P2KVi/20:>S
X`d0XJ6Q0P2@T90201PH6080?Shn0P0k>c/203hn?P80@d=30P18B4P203Ti>@80@4100P0k>c/00`12
@T80?Cdm03dm?@0206IVIP80GEeM0P1fMWH209^KV`80QXJ60P2@T90208b<S080SXj>0P2EUID2092@
T080SXj>0P2BTY8209NGU`80Ti>C00<0V9RH09BDU02DU9@00P2DU9@208f=S@80Shn?0P2FUYH809BD
U080Rh^;102>SXh208^;R`80Shn?0P25QHD00`2<S8`0SHf=08f=S@0208f=S@80RHV91024Q8@208N7
Q`80NWYj0P22PX8207emO@80PX:20P1jNWX2079bLP80N7Qh0P1`L702079bLP0305mOG`1XJ6P0J6QX
0080FUYJ0P1LG5`205EEE@80E5AD0P17AdL203Lg=`80;Rh^0P0U9BD203Hf=P805aLG0P0C4a<201DE
5@80:b/[0P1gMgL00`1dM7@0EeMG05MGE`0208R8R080B4Q80P1:BTX204e=C@80PH610P3no_h20:BT
Y2<0XJ6Q0P2KVi/20:>SXaD0XJ6Q5@3oool001<0oooo2P2QXJ4209^KV`80Xj>S3@2QXJ42092@T080
61PH0P0n?Sh203/k>`80?Shn0P13@d<204Q8B080>CTi0P10@40203/k>`030492@P0m?Cd0?Cdm0080
IVIV0P1MGEd207IfMP80Vi^K0P26QXH2092@T080S8b<0P2>SXh209FEU@80T92@0P2>SXh209:BTP80
UiNG0P2CTi<00`2HV9P0U9BD09BDU00209BDU080SHf=0P2?Shl209JFUPP0U9BD0P2;Rh/408j>SP80
Rh^;0P2?Shl208F5Q@0308b<S02=SHd0SHf=0080SHf=0P29RHT408B4Q080QhN70P1jNWX208:2PP80
OGem0P22PX8207YjNP80LW9b0P1hN7P2071`L080LW9b00<0GemO06QXJ01XJ6P00P1JFUX205aLG080
EEEE0P1DE5@204M7A`80=cLg0P0^;Rh202DU9@80=SHf0P0G5aL201<C4`805ADE0P0[:b/207MgM`03
07AdM01GEeL0EeMG0080R8R80P18B4P204Y:BP80CDe=0P21PH420?knoP80Y:BT8`2QXJ4209^KV`80
Xj>S5@2QXJ4E0?ooo`004`3oool:0:6QX@80X:2P0P2TY:@=0:6QX@80ZJVY0P0;2`/204a<C080>c/k
0P1:BTX204m?C`80CTi>0P13@d<20451@@80@41000<0?Cdm04U9B@19BDT00P1LG5`206][J`80L71`
0P2;Rh/208R8R080UYJF0P2=SHd209BDU080Ti>C102@T90209RHV080VIVI0P2=SHd00`2?Shl0UYJF
09JFUP0209BDU080Rh^;102HV9P208^;R`80UiNG102DU9@208V9R@@0Shn?0P2ATI42092@T080SXj>
00<0U9BD08^;R`2;Rh/00P2=SHd208R8R080Q8B41027QhL207MgM`80OWin101mOGd207]kN`80MWIf
0P1gMgL206m_K`80LW9b0`1XJ6P405]KF`80FUYJ0P1CDe<204Q8B080?3`l0P0W9bL203Hf=P806a/K
0P0G5aL201XJ6P805ADE0P0R8R8206e]K@0307alO011@D40@D510080MWIf0P1GEeL205IFEP80@410
0P3@d=020=;BdRD0XJ6Q0P2PX:020:BTY1D0XJ6Q5@3oool001<0oooo2P2QXJ420:2PX080Y:BT3@2Q
XJ420:VYZ@802`/;0P1<C4`203/k>`80BTY:0P1?Cdl204i>CP80@d=30P11@D420410@00303dm?@19
BDT0BDU90080G5aL0P1[Jf/2071`L080Rh^;0P28R8P209JFUP80SHf=0P2DU9@209>CT`@0T92@0P2H
V9P209VIV@80SHf=00<0Shn?09JFUP2FUYH00P2DU9@208^;R`@0V9RH0P2;Rh/209NGU`@0U9BD0P29
RHT408n?S`80TI6A0P2@T90208j>SP0309BDU02;Rh/0Rh^;0080SHf=0P28R8P208B4Q0@0QhN70P1g
MgL207inOP@0OGem0P1kNg/207IfMP80MgMg0P1_Kfl2079bLP<0J6QX101KFe/205YJFP80De=C0P18
B4P203`l?0809bLW0P0f=SH201/K6`805aLG0P0J6QX201DE5@808R8R0P1]KFd00`1lO7`0@D510451
@@0207IfMP80EeMG0P1FEUH20410@080d=3@0P3Bd]8U0:6QX@80X:2P0P2TY:@E0:6QXAD0oooo000C
0?oooa/0XJ6Q0P2^[Zh201@D5080>3Ph0P10@40205=CD`80CTi>0P0n?Sh204I6AP80>CTi0P0o?cl0
0`1@D500BDU904U9B@0205MGE`80JFUY0P1]KFd20861P@80SXj>0P2?Shl2092@T080Shn?0P2;Rh/2
09:BTP80T92@0P2BTY8209JFUP80Ti>C00<0SHf=09>CT`2CTi<00P2FUYH209>CT`@0Shn?0P2DU9@2
096AT@80SHf=0P2>SXh208f=S@80Shn?102ATI42092@T080RXZ:00<0TY:B08R8R028R8P00P2=SHd2
08>3P`80SXj>0P25QHD208J6QP80Ph>30P20P80208:2PP80Ph>30P1lO7`207AdM080MWIf0P1_Kfl2
079bLP0305mOG`1VIVH0IVIV0080Fe]K0P1JFUX205eMG@80A4A40P19BDT203dm?@80;bl_0P0];Bd2
01PH608051@D100>3Ph204a<C080FUYJ00<0HF5Q04Y:BP1:BTX00P22PX8206ATI080Ogmo0P1OGel2
0?ooo`80];Bd?P2QXJ4E0?ooo`004`3ooolK0:6QX@80[Zj^0P0D51@203Ph>080@4100P1CDe<204i>
CP80?Shn0P16ATH203Ti>@80?clo00<0D51@04U9B@19BDT00P1GEeL206UYJ@80KFe]0P21PH4208j>
SP80Shn?0P2@T90208n?S`80Rh^;0P2BTY82092@T080TY:B0P2FUYH209>CT`0308f=S@2CTi<0Ti>C
0080UYJF0P2CTi<408n?S`80U9BD0P2ATI4208f=S@80SXj>0P2=SHd208n?S`@0TI6A0P2@T90208Z:
RP0309:BTP28R8P0R8R80080SHf=0P23Ph<208j>SP80QHF50P26QXH208>3P`80P8200P22PX8208>3
P`80O7al0P1dM7@207IfMP80Kfm_0P1bLW800`1OGel0IVIV06IVIP0205]KF`80FUYJ0P1MGEd204A4
A080BDU90P0m?Cd202l_;`80;Bd]0P0H61P201@D50@03Ph>0P1<C4`205YJFP03065QH@1:BTX0BTY:
0080PX:20P1TI6@207moO`80GemO0P3oool20;Bd]3h0XJ6Q5@3oool001<0oooo6`2QXJ420:j^[P80
2`/;0P1FEUH205eMG@80@4100P17AdL20451@@80@d=30P0n?Sh204a<C003030`<019BDT0BDU90080
H61P0P1]KFd206EUI@80P8200P2@T90208j>SP80T92@0P2=SHd409>CT`80T92@102HV9P208^;R`03
09BDU02GUiL0UiNG0080V9RH0P2=SHd209BDU080Shn?0P2@T90209FEU@80SXj>0P2?Shl4092@T0@0
Shn?0P2ATI4208n?S`0309>CT`2?Shl0Shn?0080PX:20P27QhL208j>SP80PX:20P27QhL207YjNP80
R8R80P1iNGT207emO@80LW9b0P1eMGD207MgM`80Kfm_0P1bLW800`1LG5`0Lg=c07=cL`0205YJFP80
Fe]K0P1;Bd/204A4A080?Cdm0P0`<30203/k>`808B4Q0P0B4Q8200d=3@80820P0P0>3Ph206=SH`<0
DU9B0P14A4@207inOP80I6AT0P1dM7@20:FUY@80f][J@02QXJ4E0?ooo`004`3ooolK0:6QX@80[Zj^
0P0;2`/205IFEP80GEeM0P10@40204M7A`80@D510P13@d<203hn?P80C4a<00<0<30`04U9B@19BDT0
0P1PH60206e]K@80IFEU0P20P802092@T080SXj>0P2@T90208f=S@@0Ti>C0P2@T90409RHV080Rh^;
00<0U9BD09NGU`2GUiL00P2HV9P208f=S@80U9BD0P2?Shl2092@T080UIFE0P2>SXh208n?S`@0T92@
102?Shl2096AT@80Shn?00<0Ti>C08n?S`2?Shl00P22PX8208N7Q`80SXj>0P22PX8208N7Q`80NWYj
0P28R8P207UiN@80OGem0P1bLW8207EeM@80MgMg0P1_Kfl2079bLP0305aLG01cLg<0Lg=c0080FUYJ
0P1KFe/204];B`80A4A40P0m?Cd2030`<080>c/k0P0Q8B42018B4P803@d=0P0P820200h>3P80Hf=S
0`1BDU8204A4A080OWin0P1TI6@207AdM080YJFU0P3Jf]Y00:6QXAD0oooo000C0?ooo`@0XJ6Q0P2K
Vi/20:>SX`80Vi^K0P2SXj<?0:6QX@80Y:BT0P1FEUH2059BDP80=cLg0P0h>3P203dm?@80?3`l0P0k
>c/20451@@80?Cdm00<0@d=304i>CP1>CTh00P1QHF4206][J`80LW9b0P21PH42092@T080SXj>0P2?
Shl209FEU@80Ti>C0P2?Shl2096AT@80VYZJ0P2DU9@208^;R`0309^KV`2=SHd0SHf=0080UYJF0P2;
Rh/2092@T080SHf=0P2GUiL2096AT@80Rh^;0P2?Shl4096AT@@0T92@0P2?Shl2096AT@03092@T024
Q8@0Q8B40080RHV90P2?Shl408F5Q@80QhN70P1gMgL208n?S`80MGEe0P1nOWh207=cL`@0N7Qh0P1f
MWH2071`L00306ATI01dM7@0M7Ad0080DU9B0P1ADE4204U9B@80Cdm?0P19BDT203Xj>P80:RXZ0P0Q
8B42018B4P805ADE0P0R8R8201<C4`80L71`0P1?Cdl00`1CDe<0ADE504E5A@0208:2PP80Kfm_0P1k
Ng/20=kNgP80[Zj^@02QXJ4E0?ooo`004`3oool40:6QX@80Vi^K0P2SXj<209^KV`80Xj>S3`2QXJ42
0:BTY080EUIF0P1BDU8203Lg=`80>3Ph0P0m?Cd203`l?080>c/k0P11@D4203dm?@0304=3@`1>CTh0
CTi>0080HF5Q0P1[Jf/2079bLP80PH610P2@T90208j>SP80Shn?0P2EUID209>CT`80Shn?0P2ATI42
09ZJVP80U9BD0P2;Rh/00`2KVi/0SHf=08f=S@0209JFUP80Rh^;0P2@T90208f=S@80UiNG0P2ATI42
08^;R`80Shn?102ATI44092@T080Shn?0P2ATI400`2@T900Q8B408B4Q00208V9R@80Shn?1025QHD2
08N7Q`80MgMg0P2?Shl207EeM@80OWin0P1cLg<407QhN080MWIf0P1`L7000`1TI6@0M7Ad07AdM002
059BDP80DE5A0P19BDT204m?C`80BDU90P0j>SX202XZ:P808B4Q0P0B4Q8201DE5@808R8R0P0C4a<2
071`L080Cdm?00<0De=C04E5A@15ADD00P22PX8206m_K`80Ng]k0P3Ng]h20:j^[T00XJ6Q5@3oool0
01<0oooo102QXJ420:2PX080Y:BT0P2PX:020:BTY140XJ6Q0P2SXj<201PH6080=SHf0P0m?Cd203@d
=080?Shn0P0j>SX203De=@80@41000<0C4a<04m?C`1?Cdl00P1[Jf/206UYJ@80NWYj0P1oOgl208n?
S`80SXj>0P2BTY8208Z:RP80Ti>C0P2>SXh2096AT@80TY:B0P2?Shl208f=S@03092@T02EUID0UIFE
0080V9RH0P2CTi<209JFUP80SHf=0P2ATI4209FEU@80SXj>0P2@T902096AT@P0T92@0P2ATI400`24
Q8@0RXZ:08Z:RP0208n?S`80SHf=0P21PH42092@T080QHF50P23Ph<208b<S0@0O7al0P1cLg<207Mg
M`80L71`0P1jNWX206i^KP03071`L01RHV80HV9R0080De=C0P1LG5`205=CD`80@D510P0o?cl202DU
9@808B4Q0P0H61P201TI6@803@d=0P0K6a/201@D5080P8200P1:BTX00`18B4P0A4A404A4A00208^;
R`80QXJ60P2KVi/20=CDe480XJ6Q5@3oool001<0oooo102QXJ420:2PX080Y:BT0P2PX:020:BTY140
XJ6Q0P2SXj<201PH6080=SHf0P0m?Cd203@d=080?Shn0P0j>SX203De=@80@41000<0C4a<04m?C`1?
Cdl00P1[Jf/206UYJ@80NWYj0P1oOgl208n?S`80SXj>0P2BTY8208Z:RP80Ti>C0P2>SXh2096AT@80
TY:B0P2?Shl208f=S@03092@T02EUID0UIFE0080V9RH0P2CTi<209JFUP80SHf=0P2ATI4209FEU@80
SXj>0P2@T902096AT@P0T92@0P2ATI400`24Q8@0RXZ:08Z:RP0208n?S`80SHf=0P21PH42092@T080
QHF50P23Ph<208b<S0@0O7al0P1cLg<207MgM`80L71`0P1jNWX206i^KP03071`L01RHV80HV9R0080
De=C0P1LG5`205=CD`80@D510P0o?cl202DU9@808B4Q0P0H61P201TI6@803@d=0P0K6a/201@D5080
P8200P1:BTX00`18B4P0A4A404A4A00208^;R`80QXJ60P2KVi/20=CDe480XJ6Q5@3oool001<0oooo
7@2QXJ420:BTY080?3`l0P0h>3P203/k>`80?3`l0P0o?cl403dm?@80?3`l00<0?clo05=CD`1CDe<0
0P1OGel206MWI`80MgMg0P24Q8@208f=S@80SXj>0P2CTi<208^;R`80UiNG0P2>SXh2092@T080V9RH
0P2=SHd209RHV00309JFUP2IVIT0VIVI00@0U9BD0P2;Rh/209BDU080Shn?0P2ATI4209FEU@80SHf=
0P2ATI4208n?S`80TI6A1P2@T9000`27QhL0UIFE09FEU@0208^;R`80QhN71028R8P208B4Q080QXJ6
0P27QhL207IfMP80Ng]k0P1dM7@207MgM`80MWIf0P1bLW82071`L0<0Hf=S0P1LG5`4059BDP80BTY:
0P0n?Sh2028R8P809BDU0P0H61P201lO7`804Q8B0P0M7Ad201/K6`80Q8B40P1OGel00`0k>c/0FUYJ
05YJFP020820P080UiNG0P37alL20;Jf]P80Vi^K0P2SXj<n0:6QXAD0oooo000C0?oooad0XJ6Q0P2T
Y:@203`l?080>3Ph0P0k>c/203`l?080?clo100m?Cd203`l?00303lo?`1CDe<0De=C0080GemO0P1W
IfL207MgM`80Q8B40P2=SHd208j>SP80Ti>C0P2;Rh/209NGU`80SXj>0P2@T90209RHV080SHf=0P2H
V9P00`2FUYH0VIVI09VIV@0409BDU080Rh^;0P2DU9@208n?S`80TI6A0P2EUID208f=S@80TI6A0P2?
Shl2096AT@H0T92@00<0QhN709FEU@2EUID00P2;Rh/208N7Q`@0R8R80P24Q8@208J6QP80QhN70P1f
MWH207]kN`80M7Ad0P1gMgL207IfMP80LW9b0P1`L70306=SH`80G5aL101BDU8204Y:BP80?Shn0P0R
8R8202DU9@8061PH0P0O7al2018B4P807AdM0P0K6a/208B4Q080GemO00<0>c/k05YJFP1JFUX00P20
P80209NGU`80alO70P2f][H209^KV`80Xj>S?P2QXJ4E0?ooo`004`3oool20:6QX@80Vi^K0P2SXj<I
0:6QX@80RHV90P0S8b<2030`<080=CDe0P0k>c/203Xj>P80?Shn0P0o?cl00`0j>SX0EUIF05IFEP02
06QXJ080LG5a0P1oOgl208>3P`80U9BD0P2<S8`208Z:RP80S8b<0P2?Shl2096AT@80T92@0P2CTi<2
08b<S080Ti>C00<0UYJF08f=S@2=SHd00P2FUYH208^;R`80SHf=0P2CTi<208^;R`80T92@0P2ATI42
08^;R`80TI6A0P2@T902096AT@80Shn?0P2ATI42092@T00308R8R02>SXh0SXj>0080QXJ60P2<S8`2
08V9R@80Q8B41027QhL207inOP80OGem0P22PX8207YjNP80MGEe0P1hN7P206m_K`80K6a/00<0JVYZ
05aLG01LG5`00P1NGUh404i>CP80@D510P0f=SH2028R8P809BDU0P0L71`201/K6`808B4Q0P0S8b<2
01@D5080LG5a0P1UIFD00`0o?cl0LG5a075aL@0208R8R080ZJVY0P38b<P20:6QX@80X:2P0P2TY:@n
0:6QXAD0oooo000C0?ooo`80XJ6Q0P2KVi/20:>SXaT0XJ6Q0P29RHT202<S8`80<30`0P0e=CD203/k
>`80>SXj0P0n?Sh203lo?`0303Xj>P1FEUH0EUIF0080J6QX0P1aLG4207moO`80Ph>30P2DU9@208b<
S080RXZ:0P2<S8`208n?S`80TI6A0P2@T90209>CT`80S8b<0P2CTi<00`2FUYH0SHf=08f=S@0209JF
UP80Rh^;0P2=SHd209>CT`80Rh^;0P2@T902096AT@80Rh^;0P2ATI42092@T080TI6A0P2?Shl2096A
T@80T92@00<0R8R808j>SP2>SXh00P26QXH208b<S080RHV90P24Q8@408N7Q`80OWin0P1mOGd208:2
PP80NWYj0P1eMGD207QhN080Kfm_0P1/K6`00`1ZJVX0G5aL05aLG00205iNGP@0CTi>0P11@D4203Hf
=P808R8R0P0U9BD201`L70806a/K0P0Q8B4202<S8`8051@D0P1aLG4206EUI@0303lo?`1aLG40LG5a
0080R8R80P2YZJT20<S8b080XJ6Q0P2PX:020:BTY3h0XJ6Q5@3oool001<0oooo0P2QXJ420:2PX080
Y:BT6@2QXJ420:2PX0807QhN0P13@d<203Ph>080ADE50P0o?cl203Xj>P<0@D510P1EEED205MGE`80
M7Ad0P25QHD208f=S@@0RXZ:0P2ATI4208n?S`80U9BD0P2CTi<2092@T0@0Shn?0`2HV9P208V9R@80
Ti>C0P2<S8`608n?S`H0T92@0P2?Shl2096AT@@0T92@0P2ATI4308Z:RP80SHf=0P28R8P208^;R`80
Ph>30P25QHD208N7Q`80R8R80P1lO7`20861P@80NWYj0P1fMWH207AdM080N7Qh0P1`L70207=cL`03
06ATI01HF5P0F5QH0080G5aL0P1<C4`204Q8B080?3`l0P0a<C4202@T9080:RXZ0P0O7al201XJ6P80
8b<S0P0D51@200d=3@80L71`0P1FEUH00`15ADD0LW9b079bLP0208j>SP80aLG50P2h^;Q40:6QXAD0
oooo000C0?ooo`80XJ6Q0P2PX:020:BTY1T0XJ6Q0P2PX:0201hN7P80@d=30P0h>3P204E5A@80?clo
0P0j>SX30451@@80EEEE0P1GEeL207AdM080QHF50P2=SHd408Z:RP80TI6A0P2?Shl209BDU080Ti>C
0P2@T90408n?S`<0V9RH0P29RHT209>CT`80S8b<1P2?Shl6092@T080Shn?0P2ATI44092@T080TI6A
0`2:RXX208f=S@80R8R80P2;Rh/208>3P`80QHF50P27QhL208R8R080O7al0P21PH4207YjNP80MWIf
0P1dM7@207QhN080L71`0P1cLg<00`1TI6@0F5QH05QHF00205aLG080C4a<0P18B4P203`l?080<C4a
0P0T92@202XZ:P807alO0P0J6QX202<S8`8051@D0P0=3@d2071`L080EUIF00<0ADE5079bLP1bLW80
0P2>SXh20<G5a@80^;RhA02QXJ4E0?ooo`004`3ooolQ0:6QX@80QHF50P1`L70204];B`80CTi>101=
CDd203hn?P0303lo?`1CDe<0De=C0080Hf=S0P1^KVh207YjNP80RXZ:102<S8`208V9R@80Shn?0P2;
Rh/208b<S080T92@102?Shl209:BTP0308n?S`2<S8`0S8b<0080Shn?0P2HV9P208j>SP80Shn?0P2A
TI42092@T080TI6A0P2@T90208V9R@80Ti>C0P2:RXX408^;R`80RXZ:00<0Ti>C08J6QP26QXH00P2=
SHd208>3P`80Q8B40P26QXH208N7Q`80Ng]k0P1oOgl20820P080NGUi0P1dM7@207moO`80KVi^0P1`
L702079bLP0305EEE@1MGEd0GEeM0080D51@0P1BDU820410@080=cLg0P0];Bd203De=@8092@T0P0U
9BD201TI6@805ADE0P0;2`/202l_;`80Shn?0P1?Cdl00`1FEUH0OGem07emO@0208N7Q`80emOG0P2P
X:020:>SXd80XJ6Q5@3oool001<0oooo0P2QXJ4209^KV`80Xj>S3`2QXJ4209^KV`80Xj>S202QXJ42
0:j^[P80T92@0P2;Rh/203Xj>P80Bd];0P0m?Cd204A4A00304I6AP1;Bd/0Bd];0080G5aL0P1aLG42
07EeM@80QXJ60P2CTi<208R8R080QhN70P2CTi<208b<S080U9BD0P2CTi<208Z:RP80T92@0P2?Shl0
0`2ATI40T92@092@T002092@T080Ti>C0P2=SHd2092@T080Shn?0P2ATI44092@T080Shn?0P2CTi<2
08R8R0@0SHf=0P2CTi<00`2=SHd0P8200820P00208R8R080Ph>30P27QhL208J6QP80R8R81P1mOGd2
07alO080Ng]k0P1hN7P206ATI080MGEe0P1PH6000`1NGUh0H61P061PH00204];B`80?Shn0P0f=SH2
03lo?`80;Bd]0P0Y:BT202LW9`807AdM0P0P820200l?3`8030`<0P1oOgl206e]K@80?Shn00<0HF5Q
071`L01`L7000P2ZZZX20=;BdP80X:2P0P2TY:A20:6QXAD0oooo000C0?ooo`80XJ6Q0P2KVi/20:>S
X`l0XJ6Q0P2KVi/20:>SX`P0XJ6Q0P2^[Zh2092@T080Rh^;0P0j>SX204];B`80?Cdm0P14A4@00`16
ATH0Bd];04];B`0205aLG080LG5a0P1eMGD208J6QP80Ti>C0P28R8P208N7Q`80Ti>C0P2<S8`209BD
U080Ti>C0P2:RXX2092@T080Shn?00<0TI6A092@T02@T9000P2@T90209>CT`80SHf=0P2@T90208n?
S`80TI6A102@T90208n?S`80Ti>C0P28R8P408f=S@80Ti>C00<0SHf=0820P020P8000P28R8P208>3
P`80QhN70P26QXH208R8R0H0OGem0P1lO7`207]kN`80N7Qh0P1TI6@207EeM@80H61P00<0GUiN061P
H01PH6000P1;Bd/203hn?P80=SHf0P0o?cl202d];@80:BTY0P0W9bL201dM7@80820P0P0?3`l200`<
3080Ogmo0P1]KFd203hn?P03065QH@1`L700L71`0080ZZZZ0P3Bd]820:2PX080Y:BT@P2QXJ4E0?oo
o`004`3oool20:6QX@80X:2P0P2TY:@?0:6QX@80X:2P0P2TY:@80:6QX@80Y:BT0P2OWil20::RXP80
=CDe0P0a<C4204=3@`80>CTi00<0BDU904M7A`17AdL00P1PH60206i^KP80MgMg0P25QHD208f=S@80
OGem0P2;Rh/208V9R@80Shn?0P2:RXX208V9R@80Rh^;0P2>SXh209:BTP03096AT@2@T900T92@0080
RXZ:0P2BTY84092@T080RHV90P2CTi<208N7Q`80S8b<0P2:RXX208b<S080RXZ:0P2=SHd208V9R@80
QXJ600<0Ph>308B4Q024Q8@00P27QhL208J6QP80R8R80P26QXH208N7Q`80NGUi0P1jNWX407inOP@0
MGEe0P1]KFd206m_K`80L71`00<0Fe]K04m?C`1?Cdl00P13@d<20451@@80@4100P12@T8203hn?P80
8B4Q0P0V9RH201lO7`8051@D0P0=3@d208B4Q080Lg=c0P19BDT20451@@0307EeM@2BTY80TY:B0080
b/[:0P2i^KT209^KV`80WIfM0P2SXj=00:6QXAD0oooo000C0?ooo`80XJ6Q0P2PX:020:BTY0l0XJ6Q
0P2PX:020:BTY0P0XJ6Q0P2TY:@209nOW`80XZ:R0P0e=CD2034a<@80@d=30P0i>CT00`19BDT0AdM7
04M7A`02061PH080KVi^0P1gMgL208F5Q@80SHf=0P1mOGd208^;R`80RHV90P2?Shl208Z:RP80RHV9
0P2;Rh/208j>SP80TY:B00<0TI6A092@T02@T9000P2:RXX209:BTP@0T92@0P29RHT209>CT`80QhN7
0P2<S8`208Z:RP80S8b<0P2:RXX208f=S@80RHV90P26QXH00`23Ph<0Q8B408B4Q00208N7Q`80QXJ6
0P28R8P208J6QP80QhN70P1iNGT207YjNP@0OWin101eMGD206e]K@80Kfm_0P1`L7000`1KFe/0Cdm?
04m?C`0204=3@`80@D510P10@4020492@P80?Shn0P0Q8B4202HV9P807alO0P0D51@200d=3@80Q8B4
0P1cLg<204U9B@80@D5100<0MGEe09:BTP2BTY800P3:b/X20;Vi^@80Vi^K0P2MWId20:>SXd00XJ6Q
5@3oool001<0oooo9@2QXJ420:j^[P80FUYJ0P0C4a<204M7A`80G5aL00<0?Shn05mOG`1OGel00P1M
GEd206a/K080MWIf0P24Q8@208Z:RP80R8R80P2>SXh208J6QP80RXZ:0P2>SXh208f=S@80UIFE0P2;
Rh/208b<S00309:BTP2:RXX0RXZ:0080T92@0P2CTi<4092@T080Shn?0P2=SHd208V9R@80U9BD0P2;
Rh/208B4Q080Shn?0P24Q8@208j>SP80Ph>300<0QhN708J6QP26QXH00P28R8P408N7Q`80QXJ60P1m
OGd207moO`80NWYj0P1mOGd207IfMP@0M7Ad0P1LG5`206m_K`80IfMW00<0DE5A051@D01@D500101;
Bd/203dm?@80<c<c0P0j>SX204];B`805QHF0P0D51@201PH6080Bd];0P1BDU8205QHF080AdM70P1F
EUH00`1mOGd0X:2P0:2PX0020<K6aP80ZZZZ0P2JVYX20:j^[T80XJ6Q5@3oool001<0oooo9@2QXJ42
0:j^[P80FUYJ0P0C4a<204M7A`80G5aL00<0?Shn05mOG`1OGel00P1MGEd206a/K080MWIf0P24Q8@2
08Z:RP80R8R80P2>SXh208J6QP80RXZ:0P2>SXh208f=S@80UIFE0P2;Rh/208b<S00309:BTP2:RXX0
RXZ:0080T92@0P2CTi<4092@T080Shn?0P2=SHd208V9R@80U9BD0P2;Rh/208B4Q080Shn?0P24Q8@2
08j>SP80Ph>300<0QhN708J6QP26QXH00P28R8P408N7Q`80QXJ60P1mOGd207moO`80NWYj0P1mOGd2
07IfMP@0M7Ad0P1LG5`206m_K`80IfMW00<0DE5A051@D01@D500101;Bd/203dm?@80<c<c0P0j>SX2
04];B`805QHF0P0D51@201PH6080Bd];0P1BDU8205QHF080AdM70P1FEUH00`1mOGd0X:2P0:2PX002
0<K6aP80ZZZZ0P2JVYX20:j^[T80XJ6Q5@3oool001<0oooo9@2QXJ420:j^[P80DE5A0P0U9BD20410
@080@D5100<0?clo06IVIP1VIVH00P1FEUH206a/K080NWYj0P24Q8@207emO@80QhN70P2;Rh/208J6
QP80R8R80P2=SHd208F5Q@80UiNG0P25QHD208f=S@0308n?S`2:RXX0RXZ:0080SXj>1P2;Rh/209:B
TP80Ph>30P28R8P208J6QP80Ph>30P24Q8@207alO080QhN70P28R8P208>3P`0308N7Q`26QXH0QXJ6
0080QhN70P28R8P208J6QP80QhN70P1eMGD207emO@80Ng]k0P1eMGD207IfMP80MgMg0P1_Kfl205]K
F`80JFUY0P1FEUH00`1:BTX0Bd];04];B`020492@P@0?Cdm0P0j>SX203lo?`80:2PX0P0];Bd202TY
:@80?Cdm0P0k>c/206ATI080FEUI0P1PH60206YZJP0308j>SP2CTi<0Ti>C0080bl_;0P2^[Zh209fM
W@80YZJV0P2MWIe00:6QXAD0oooo000C0?ooobD0XJ6Q0P2^[Zh2055AD@809BDU0P10@4020451@@03
03lo?`1VIVH0IVIV0080EUIF0P1/K6`207YjNP80Q8B40P1mOGd208N7Q`80Rh^;0P26QXH208R8R080
SHf=0P25QHD209NGU`80QHF50P2=SHd00`2?Shl0RXZ:08Z:RP0208j>SPH0Rh^;0P2BTY8208>3P`80
R8R80P26QXH208>3P`80Q8B40P1lO7`208N7Q`80R8R80P23Ph<00`27QhL0QXJ608J6QP0208N7Q`80
R8R80P26QXH208N7Q`80MGEe0P1mOGd207]kN`80MGEe0P1fMWH207MgM`80Kfm_0P1KFe/206UYJ@80
EUIF00<0BTY:04];B`1;Bd/00P12@T8403dm?@80>SXj0P0o?cl202PX:080;Bd]0P0Y:BT203dm?@80
>c/k0P1TI6@205UIF@80H61P0P1ZJVX00`2>SXh0Ti>C09>CT`020<_;b`80[Zj^0P2MWId20:JVYP80
WIfM@02QXJ4E0?ooo`004`3ooolU0:6QX@80[Zj^0P11@D4205UIF@808b<S0P0n?Sh00`11@D40ATI6
04I6AP0205=CD`80IVIV0P1_Kfl2075aL@80PX:20P24Q8@208F5Q@80R8R80P1kNg/208n?S`80RHV9
0P2ATI4408N7Q`0308F5Q@29RHT0RHV90080SXj>0P2=SHd209>CT`80Ph>30P2=SHd20820P080QhN7
0P25QHD207YjNP80Ng]k0P1hN7P208:2PP80RXZ:0P27QhL00`20P800O7al07alO00208>3P`H0Ng]k
0P1^KVh207YjNP80MgMg0P1]KFd2079bLP80JVYZ0P1NGUh2061PH080GemO0P1HF5P00`1=CDd0EUIF
05IFEP0204Q8B080=3@d0P0j>SX203<c<`80=CDe0P0Y:BT203Hf=P808R8R0P1fMWH204];B`80H61P
0P19BDT208J6QP80JFUY00<0WIfM0<G5a@35aLD00P2n_[h20:BTY080UiNG0P2SXj<20:6QX@80Zj^[
0P2NWYhO0:6QX@80Zj^[0P2NWYhI0:6QXAD0oooo000C0?ooobD0XJ6Q0P2^[Zh20451@@80FEUI0P0S
8b<203hn?P030451@@16ATH0ATI60080De=C0P1VIVH206m_K`80LG5a0P22PX8208B4Q080QHF50P28
R8P207]kN`80Shn?0P29RHT2096AT@@0QhN700<0QHF508V9R@29RHT00P2>SXh208f=S@80Ti>C0P23
Ph<208f=S@80P8200P27QhL208F5Q@80NWYj0P1kNg/207QhN080PX:20P2:RXX208N7Q`030820P01l
O7`0O7al0080Ph>31P1kNg/206i^KP80NWYj0P1gMgL206e]K@80LW9b0P1ZJVX205iNGP80H61P0P1O
Gel205QHF00304e=C@1FEUH0EUIF0080B4Q80P0d=3@203Xj>P80<c<c0P0e=CD202TY:@80=SHf0P0R
8R8207IfMP80Bd];0P1PH60204U9B@80QXJ60P1YJFT00`2MWId0aLG50<G5a@020;jn_P80Y:BT0P2G
UiL20:>SX`80XJ6Q0P2[Zj/209jNWQl0XJ6Q0P2[Zj/209jNWQT0XJ6Q5@3oool001<0oooo9@2QXJ42
0:BTY080KFe]0P25QHD200h>3P80=SHf00<0EUIF03/k>`0k>c/00P1KFe/206=SH`80IfMW0P1oOgl2
08>3P`80NWYj1021PH4207]kN`80T92@0P27QhL208F5Q@80QhN70P2;Rh/00`25QHD0R8R808R8R002
08R8R0@0QhN70P20P80208V9R@80QHF50P1oOgl207UiN@80LW9b0P1hN7P207UiN@80Ogmo0P23Ph<2
07AdM00307EeM@1fMWH0MWIf0080NGUi0P1]KFd207MgM`80NWYj0P1[Jf/207]kN`80KVi^0P1_Kfl2
06QXJ080K6a/0P1PH60405UIF@80Fe]K00<0D51@04m?C`1?Cdl0100k>c/203lo?`80>CTi0P1ADE42
03dm?@80=SHf0P1@D50207inOP80ATI60P1LG5`206QXJ080SXj>0P29RHT00`2?Shl0alO70<O7a`02
0:>SX`80XJ6Q0P2PX:020:j^[P80WYjN0P2TY:@209fMWA<0XJ6Q0P2KVi/20:>SX`P0XJ6Q0P2TY:@2
09fMWAT0XJ6Q5@3oool001<0oooo9@2QXJ420:BTY080KFe]0P25QHD200h>3P80=SHf00<0EUIF03/k
>`0k>c/00P1KFe/206=SH`80IfMW0P1oOgl208>3P`80NWYj1021PH4207]kN`80T92@0P27QhL208F5
Q@80QhN70P2;Rh/00`25QHD0R8R808R8R00208R8R0@0QhN70P20P80208V9R@80QHF50P1oOgl207Ui
N@80LW9b0P1hN7P207UiN@80Ogmo0P23Ph<207AdM00307EeM@1fMWH0MWIf0080NGUi0P1]KFd207Mg
M`80NWYj0P1[Jf/207]kN`80KVi^0P1_Kfl206QXJ080K6a/0P1PH60405UIF@80Fe]K00<0D51@04m?
C`1?Cdl0100k>c/203lo?`80>CTi0P1ADE4203dm?@80=SHf0P1@D50207inOP80ATI60P1LG5`206QX
J080SXj>0P29RHT00`2?Shl0alO70<O7a`020:>SX`80XJ6Q0P2PX:020:j^[P80WYjN0P2TY:@209fM
WA<0XJ6Q0P2KVi/20:>SX`P0XJ6Q0P2TY:@209fMWAT0XJ6Q5@3oool001<0oooo9`2QXJ4209ZJVP80
De=C0P0/;2`20451@@0304U9B@1:BTX0BTY:0080Bd];0P1EEED205UIF@80Lg=c0P1jNWX208V9R@80
N7Qh0P1lO7`207moO`80P8200P2<S8`208N7Q`80R8R80P29RHT00`22PX80OWin07inOP060820P080
NWYj0P1dM7@407=cL`80M7Ad0P1/K6`2075aL@80JVYZ0P1]KFd206][J`80J6QX00<0KVi^06][J`1[
Jf/00P1[Jf/206UYJ@80HV9R0P1WIfL2069RHP80J6QX0P1SHf<205]KF`80G5aL0P1XJ6P205]KF`80
F5QH0P1GEeL204M7A`030410@01?Cdl0Cdm?0080AdM70P0k>c/2051@D080CDe=0P0e=CD204M7A`80
CTi>0P1EEED205MGE`80ATI60P1^KVh2061PH080Shn?0P2>SXh00`2c/k<0_kno0;no_`020:BTY0@0
XJ6Q0P2TY:@209fMWAL0XJ6Q0P2PX:020:BTY2D0XJ6Q5@3oool001<0oooo9`2QXJ4209ZJVP80De=C
0P0/;2`20451@@0304U9B@1:BTX0BTY:0080Bd];0P1EEED205UIF@80Lg=c0P1jNWX208V9R@80N7Qh
0P1lO7`207moO`80P8200P2<S8`208N7Q`80R8R80P29RHT00`22PX80OWin07inOP060820P080NWYj
0P1dM7@407=cL`80M7Ad0P1/K6`2075aL@80JVYZ0P1]KFd206][J`80J6QX00<0KVi^06][J`1[Jf/0
0P1[Jf/206UYJ@80HV9R0P1WIfL2069RHP80J6QX0P1SHf<205]KF`80G5aL0P1XJ6P205]KF`80F5QH
0P1GEeL204M7A`030410@01?Cdl0Cdm?0080AdM70P0k>c/2051@D080CDe=0P0e=CD204M7A`80CTi>
0P1EEED205MGE`80ATI60P1^KVh2061PH080Shn?0P2>SXh00`2c/k<0_kno0;no_`020:BTY0@0XJ6Q
0P2TY:@209fMWAL0XJ6Q0P2PX:020:BTY2D0XJ6Q5@3oool001<0oooo:@2QXJ4208V9R@80Fe]K0P10
@4000`0o?cl0Bd];04];B`0204a<C080GUiN0P1TI6@205YJFP80IfMW0P1ZJVX207YjNP80OWin0P27
QhL408^;R`80OWin1020P8000`1nOWh0L71`071`L00207IfMP80KFe]0P1hN7P208>3P`80JVYZ0P1c
Lg<2075aL@80LW9b0P1MGEd206a/K080FEUI0P1ZJVX205eMG@80Lg=c00<0De=C06][J`1[Jf/00P1@
D502065QH@80D51@0P1GEeL206=SH`80FEUI0P1KFe/205UIF@80GEeM0P1DE5@2069RHP80J6QX0P1E
EED205eMG@0305ADE01LG5`0G5aL0080@D510P13@d<205QHF080FUYJ0P0g=cL202/[:`80@410101S
Hf<205UIF@80Kfm_0P20P802092@T080QHF500<0bl_;0:FUY@2UYJD02P2QXJ4209^KV`80Xj>S7`2Q
XJ420:^[Z`80WYjN6@2QXJ4E0?ooo`004`3ooolY0:6QX@80RHV90P1KFe/20410@00303lo?`1;Bd/0
Bd];0080C4a<0P1NGUh206ATI080FUYJ0P1WIfL206YZJP80NWYj0P1nOWh208N7Q`@0Rh^;0P1nOWh4
0820P00307inOP1`L700L71`0080MWIf0P1]KFd207QhN080Ph>30P1ZJVX207=cL`80LG5a0P1bLW82
05eMG@80K6a/0P1IFET206YZJP80GEeM0P1cLg<00`1CDe<0Jf][06][J`02051@D080HF5Q0P1@D502
05MGE`80Hf=S0P1IFET205]KF`80FEUI0P1MGEd205ADE080HV9R0P1XJ6P205EEE@80GEeM00<0E5AD
05aLG01LG5`00P11@D4204=3@`80F5QH0P1JFUX203Lg=`80:b/[0P10@40406=SH`80FEUI0P1_Kfl2
0820P080T92@0P25QHD00`3;bl/0YJFU0:FUY@0:0:6QX@80Vi^K0P2SXj<O0:6QX@80Zj^[0P2NWYhI
0:6QXAD0oooo000C0?ooob/0XJ6Q0P2;Rh/208n?S`0304e=C@1@D500D51@0080?3`l0P1HF5P205UI
F@80?Shn0P1_Kfl207AdM080U9BD0P2?Shl208b<S080RXZ:0P1nOWh207moO`80MgMg0P1fMWH00`1/
K6`0L71`071`L002075aL@80L71`101eMGD206YZJP80Lg=c0P1PH60206EUI@80F5QH0P1RHV8205IF
EP80IFEU0P1HF5P2059BDP0305MGE`1QHF40HF5Q0080ADE50P1<C4`205mOG`80C4a<0P1TI6@204U9
B@80De=C0P1FEUH205ADE080De=C0P13@d<204];B`80BDU90P1EEED00`1:BTX0D51@051@D00204Y:
BP80DU9B0P0j>SX20451@@80ADE50P1;Bd/205aLG080Hf=S0P1FEUH206i^KP80T92@0P2:RXX206MW
I`80bl_;00<0_[jn0:6QX@2QXJ400P2QXJ4209^KV`80Xj>S102QXJ420:2PX080Y:BT5`2QXJ4209^K
V`80Xj>S102QXJ420:BTY080WIfM6@2QXJ4E0?ooo`004`3oool[0:6QX@80Rh^;0P2?Shl00`1=CDd0
D51@051@D00203`l?080F5QH0P1IFET203hn?P80Kfm_0P1dM7@209BDU080Shn?0P2<S8`208Z:RP80
OWin0P1oOgl207MgM`80MWIf00<0K6a/071`L01`L7000P1aLG42071`L0@0MGEe0P1ZJVX207=cL`80
H61P0P1UIFD205QHF080HV9R0P1FEUH206EUI@80F5QH0P1BDU800`1GEeL0HF5Q065QH@0204E5A@80
C4a<0P1OGel204a<C080I6AT0P19BDT205=CD`80EUIF0P1DE5@205=CD`80@d=30P1;Bd/204U9B@80
EEEE00<0BTY:051@D01@D5000P1:BTX2059BDP80>SXj0P11@D4204E5A@80Bd];0P1LG5`206=SH`80
EUIF0P1^KVh2092@T080RXZ:0P1WIfL20<_;b`030;jn_P2QXJ40XJ6Q0080XJ6Q0P2KVi/20:>SX`@0
XJ6Q0P2PX:020:BTY1L0XJ6Q0P2KVi/20:>SX`@0XJ6Q0P2TY:@209fMWAT0XJ6Q5@3oool001<0oooo
3P2QXJ4209^KV`030:>SX`2KVi/0Vi^K0080Xj>S602QXJ4209fMW@0302h^;P1?Cdl0Cdm?0080De=C
0P1HF5P206IVIP80NGUi0P28R8P206i^KP80RHV90P1_Kfl207QhN080Ogmo0P1kNg/207EeM@80Lg=c
0`1_Kfl207EeM@80GUiN0P1/K6`207EeM@80J6QX0P1SHf<206a/K0@0GUiN0P1HF5P205eMG@80BDU9
0P1aLG4204m?C`80Jf][00<0GemO05=CD`1CDe<00P1RHV8205=CD`80Cdm?0P1]KFd205IFEP80G5aL
101GEeL205aLG080HF5Q0P0i>CT204m?C`80Fe]K0P1GEeL00`15ADD0DE5A055AD@0205UIF@80@d=3
1019BDT2059BDP80ATI60P1DE5@206EUI@80QhN70P2;Rh/207moO`80MGEe0P2BTY820=[JfPD0XJ6Q
0P2YZJTQ0:6QX@80X:2P0P2TY:@Q0:6QXAD0oooo000C0?ooo`h0XJ6Q0P2KVi/00`2SXj<0Vi^K09^K
V`020:>SXaP0XJ6Q0P2MWId00`0^;Rh0Cdm?04m?C`0205=CD`80F5QH0P1VIVH207UiN@80R8R80P1^
KVh208V9R@80Kfm_0P1hN7P207moO`80Ng]k0P1eMGD207=cL`<0Kfm_0P1eMGD205iNGP80K6a/0P1e
MGD206QXJ080Hf=S0P1/K6`405iNGP80F5QH0P1MGEd204U9B@80LG5a0P1?Cdl206][J`0305mOG`1C
De<0De=C0080HV9R0P1CDe<204m?C`80KFe]0P1FEUH205aLG0@0EeMG0P1LG5`2065QH@80>CTi0P1?
Cdl205]KF`80EeMG00<0ADE5055AD@1ADE400P1IFET204=3@`@0BDU90P1BDU8204I6AP80E5AD0P1U
IFD208N7Q`80Rh^;0P1oOgl207EeM@80TY:B0P3Jf]X50:6QX@80ZJVY8@2QXJ420:2PX080Y:BT8@2Q
XJ4E0?ooo`004`3oool40:6QX@80Vi^K0P2SXj<60:6QX@80X:2P00<0Y:BT0:2PX02PX:000P2TY:@J
0:6QX@0308V9R@0e=CD0=CDe0080GemO0P1=CDd204a<C080Hf=S0P1PH60205]KF`80Lg=c0P1lO7`2
0861P@80NGUi0P1bLW8206e]K@80MgMg0P1TI6@00`1ZJVX0Jf][06][J`0205IFEP80JVYZ0P1OGel2
06=SH`80G5aL0P1ZJVX205IFEP80J6QX0P1>CTh204e=C@80E5AD0P18B4P405UIF@03065QH@18B4P0
B4Q80080Fe]K0P1@D50205ADE080Ng]k0P0g=cL205ADE080C4a<0P1SHf<205EEE@80B4Q80P13@d<4
03lo?`80<C4a00<0=SHf04Y:BP1:BTX00P0j>SX203Lg=`80?clo0P0l?3`204];B`80F5QH0P1gMgL2
08Z:RP80Xj>S0P1QHF4207QhN080DE5A0P3Lg=`20;Bd]0D0XJ6Q0P2TY:@209fMWD@0XJ6Q5@3oool0
01<0oooo102QXJ4209^KV`80Xj>S1P2QXJ420:2PX0030:BTY02PX:00X:2P0080Y:BT6P2QXJ400`29
RHT0=CDe03De=@0205mOG`80CDe=0P1<C4`206=SH`80H61P0P1KFe/207=cL`80O7al0P21PH4207Ui
N@80LW9b0P1]KFd207MgM`80I6AT00<0JVYZ06][J`1[Jf/00P1FEUH206YZJP80GemO0P1SHf<205aL
G080JVYZ0P1FEUH206QXJ080CTi>0P1=CDd205ADE080B4Q8101IFET00`1QHF40B4Q804Q8B00205]K
F`80D51@0P1DE5@207]kN`80=cLg0P1DE5@204a<C080Hf=S0P1EEED204Q8B080@d=3100o?cl2034a
<@0303Hf=P1:BTX0BTY:0080>SXj0P0g=cL203lo?`80?3`l0P1;Bd/205QHF080MgMg0P2:RXX20:>S
X`80HF5Q0P1hN7P2055AD@80g=cL0P2d];@50:6QX@80Y:BT0P2MWIe40:6QXAD0oooo000C0?ooo`@0
XJ6Q0P2PX:020:BTY2L0XJ6Q00<0Y:BT07emO@1mOGd00P1IFET2051@D080EUIF0P1oOgl207=cL`80
MWIf0P2:RXX208F5Q@80OGem0P1jNWX206=SH`80JFUY0P1[Jf/206IVIP0306ATI01^KVh0KVi^0080
H61P0P1YJFT205QHF080GUiN0P1XJ6P205]KF`80CTi>0P1HF5P203/k>`80GemO0P1NGUh203`l?080
=3@d0P1MGEd00`0l?3`0GemO05mOG`0205MGE`80EUIF0P1GEeL203lo?`80@d=30P1NGUh202XZ:P80
=SHf0P17AdL203`l?0@0?clo0P1;Bd/204M7A`0305=CD`1;Bd/0Bd];0080ATI60P0k>c/204e=C@80
D51@0P2EUID206e]K@80S8b<0P2?Shl203Hf=P80J6QX0P1FEUH209RHV080lo?c0P2NWYh;0:6QX@80
Vi^K0P2SXj<n0:6QXAD0oooo000C0?ooo`@0XJ6Q0P2PX:020:BTY2L0XJ6Q00<0Y:BT07emO@1mOGd0
0P1IFET2051@D080EUIF0P1oOgl207=cL`80MWIf0P2:RXX208F5Q@80OGem0P1jNWX206=SH`80JFUY
0P1[Jf/206IVIP0306ATI01^KVh0KVi^0080H61P0P1YJFT205QHF080GUiN0P1XJ6P205]KF`80CTi>
0P1HF5P203/k>`80GemO0P1NGUh203`l?080=3@d0P1MGEd00`0l?3`0GemO05mOG`0205MGE`80EUIF
0P1GEeL203lo?`80@d=30P1NGUh202XZ:P80=SHf0P17AdL203`l?0@0?clo0P1;Bd/204M7A`0305=C
D`1;Bd/0Bd];0080ATI60P0k>c/204e=C@80D51@0P2EUID206e]K@80S8b<0P2?Shl203Hf=P80J6QX
0P1FEUH209RHV080lo?c0P2NWYh;0:6QX@80Vi^K0P2SXj<n0:6QXAD0oooo000C0?oooc00XJ6Q0P2T
Y:@203`l?080Cdm?0P0m?Cd205UIF@80ATI60P1LG5`207emO@80O7al0P1hN7P207alO080IFEU0P1R
HV8206EUI@80GEeM00<0IFEU06QXJ01XJ6P00P1LG5`205IFEP80Fe]K0P1SHf<205EEE@80FUYJ0P1K
Fe/203lo?`80LG5a0P1IFET20410@080KFe]0P0l?3`204Q8B00305IFEP1:BTX0BTY:0080@D510P1;
Bd/403`l?080?Cdm0P0_;bl203De=@80?clo0P1BDU8203Ph>080?clo0P1;Bd/204=3@`80>SXj00<0
>3Ph0492@P12@T800P1EEED2069RHP80IfMW0P1kNg/207QhN080RHV90P25QHD204i>CP80?Shn0P27
QhL204i>CP80mOGe0P2h^;P209fMW@<0XJ6Q0P2KVi/20:>SX`80XJ6Q0P2KVi/20:6QX@80Y:BT5`2Q
XJ4209^KV`80Xj>S0P2QXJ420:^[Z`80WYjN7@2QXJ4E0?ooo`004`3oool`0:6QX@80Y:BT0P0l?3`2
04m?C`80?Cdm0P1IFET204I6AP80G5aL0P1mOGd207alO080N7Qh0P1lO7`206EUI@80HV9R0P1UIFD2
05eMG@0306EUI@1XJ6P0J6QX0080G5aL0P1FEUH205]KF`80Hf=S0P1EEED205YJFP80Fe]K0P0o?cl2
075aL@80FEUI0P10@40206e]K@80?3`l0P18B4P00`1FEUH0BTY:04Y:BP020451@@80Bd];100l?3`2
03dm?@80;bl_0P0e=CD203lo?`80DU9B0P0h>3P203lo?`80Bd];0P13@d<203Xj>P0303Ph>012@T80
@T920080EEEE0P1RHV8206MWI`80Ng]k0P1hN7P208V9R@80QHF50P1>CTh203hn?P80QhN70P1>CTh2
0?Gem@80^;Rh0P2MWId30:6QX@80Vi^K0P2SXj<20:6QX@80Vi^K0P2QXJ420:BTY1L0XJ6Q0P2KVi/2
0:>SX`80XJ6Q0P2[Zj/209jNWQd0XJ6Q5@3oool001<0oooo<P2QXJ4209>CT`807alO0P1DE5@207mo
O`80DE5A0P1RHV82079bLP80OWin0P1kNg/2071`L080JFUY0P18B4P205iNGP80EUIF00<0KFe]06MW
I`1WIfL00P1HF5P204Y:BP80Hf=S0P1NGUh2051@D080JFUY0P1BDU8205UIF@80@D510P1<C4`204Y:
BP80C4a<0P1>CTh203/k>`0304e=C@12@T80@T920080?clo0P17AdL203`l?080>CTi0P0l?3`203/k
>`80@D510P0d=3@2038b<P80>c/k0P10@40203hn?P80>SXj0P0k>c/00`19BDT0HV9R069RHP0205eM
G@80FUYJ0P1DE5@207alO080P8200P1?Cdl204];B`80C4a<0P1lO7`206i^KP80]kNg0P3Kfm/209fM
W@80Xj>S00<0XJ6Q09^KV`2KVi/00P2QXJ420:BTY080Vi^K0P2QXJ420:BTY080Zj^[0P2NWYh60:6Q
X@80Zj^[0P2NWYh;0:6QX@80X:2P0P2TY:@20:6QX@80Y:BT0P2MWIdM0:6QXAD0oooo000C0?oooc80
XJ6Q0P2CTi<201lO7`80E5AD0P1oOgl2055AD@80HV9R0P1bLW8207inOP80Ng]k0P1`L70206UYJ@80
B4Q80P1NGUh205IFEP0306e]K@1WIfL0IfMW0080F5QH0P1:BTX206=SH`80GUiN0P1@D50206UYJ@80
DU9B0P1IFET20451@@80C4a<0P1:BTX204a<C080CTi>0P0k>c/00`1=CDd0@T920492@P0203lo?`80
AdM70P0l?3`203Ti>@80?3`l0P0k>c/20451@@80=3@d0P0b<S8203/k>`80@4100P0n?Sh203Xj>P80
>c/k00<0BDU9069RHP1RHV800P1MGEd205YJFP80E5AD0P1lO7`20820P080Cdm?0P1;Bd/204a<C080
O7al0P1^KVh20;Ng]`80fm_K0P2MWId20:>SX`030:6QX@2KVi/0Vi^K0080XJ6Q0P2TY:@209^KV`80
XJ6Q0P2TY:@20:^[Z`80WYjN1P2QXJ420:^[Z`80WYjN2`2QXJ420:2PX080Y:BT0P2QXJ420:BTY080
WIfM7@2QXJ4E0?ooo`004`3ooolb0:6QX@80Y:BT0P1/K6`204a<C080<C4a0P1/K6`2071`L080Lg=c
0P1XJ6P208R8R080NGUi0P1aLG420492@P80JFUY0P1ADE400`1IFET0GEeM05eMG@0204i>CP80B4Q8
0P1SHf<205YJFP80BDU90P1KFe/204Q8B080FUYJ0P0c<c<206ATI080BTY:0P19BDT203Ti>@80;Rh^
00<0I6AT03@d=00d=3@00P0n?Sh20492@P80?Cdm0P0j>SX403De=@80:RXZ0P0W9bL203<c<`80=3@d
0P0b<S8203hn?P80De=C0P0o?cl00`1;Bd/0J6QX06QXJ00207MgM`80JFUY0P2IVIT208V9R@80JVYZ
0P1:BTX204I6AP80OWin0P17AdL20<G5a@80gmoO0P2_[jl209ZJVP80YJFU00<0XJ6Q0:2PX02PX:00
0P2TY:@20:6QX@80X:2P0P2TY:@20:6QX@80Y:BT0P2MWId60:6QX@80Y:BT0P2MWIdb0:6QXAD0oooo
000C0?oooc80XJ6Q0P2TY:@206a/K080C4a<0P0a<C4206a/K080L71`0P1cLg<206QXJ080R8R80P1i
NGT2075aL@80@T920P1YJFT2055AD@0305UIF@1MGEd0GEeM0080CTi>0P18B4P206=SH`80FUYJ0P19
BDT205]KF`80B4Q80P1JFUX203<c<`80I6AT0P1:BTX204U9B@80>CTi0P0^;Rh00`1TI6@0=3@d03@d
=00203hn?P80@T920P0m?Cd203Xj>P@0=CDe0P0Z:RX202LW9`80<c<c0P0d=3@2038b<P80?Shn0P1C
De<203lo?`0304];B`1XJ6P0J6QX0080MgMg0P1YJFT209VIV@80RHV90P1ZJVX204Y:BP80ATI60P1n
OWh204M7A`80aLG50P3Ogml20:n_[`80VYZJ0P2UYJD00`2QXJ40X:2P0:2PX0020:BTY080XJ6Q0P2P
X:020:BTY080XJ6Q0P2TY:@209fMW@H0XJ6Q0P2TY:@209fMWC80XJ6Q5@3oool001<0oooo<P2QXJ42
09^KV`80Xj>S0P24Q8@203Xj>P80=3@d0P1EEED205aLG080IFEU0P2?Shl208:2PP80K6a/0P10@402
04Y:BP80JVYZ00<0De=C06UYJ@1YJFT00P1VIVH205]KF`80BTY:0P1OGel2055AD@80@d=30P1IFET2
05YJFP80?3`l0P1KFe/205EEE@80CTi>0P15ADD2020P800303hn?P0h>3P0>3Ph0080HV9R0P0i>CT2
03`l?080:2PX0P0o?cl2030`<080:RXZ0P0U9BD202`/;0@09BDU0P0k>c/204U9B@80HF5Q00<0MGEe
06IVIP1VIVH00P1bLW8208:2PP80IfMW0P0c<c<204e=C@80FEUI0P1DE5@2055AD@80M7Ad0P3no_h2
0:^[Z`80WinO0P2KVi/20:BTY0030:6QX@2KVi/0Vi^K0080Xj>S0P2[Zj/209jNWQ@0XJ6Q0P2KVi/0
0`2SXj<0XJ6Q0:6QX@0>0:6QX@80Zj^[0P2NWYhI0:6QXAD0oooo000C0?ooo`X0XJ6Q0P2KVi/20:>S
Xb@0XJ6Q0P2PX:040:BTY080EEEE0P0^;Rh204E5A@80AdM70P1YJFT207MgM`80N7Qh0P1iNGT404A4
A080HF5Q00<0H61P04a<C01<C4`00P1=CDd205=CD`80@4100P18B4P2059BDP80BTY:0P1=CDd204Y:
BP80EEEE0P1BDU8204A4A080F5QH0P1>CTh20451@@0304i>CP0e=CD0=CDe0080>CTi0P10@40203`l
?080>SXj0P1:BTX203Ti>@80E5AD0P0k>c/20410@080AdM70P1FEUH2069RHP80HF5Q0P1cLg<00`1h
N7P0U9BD09BDU002061PH080M7Ad0P13@d<202HV9P80Fe]K0P1RHV8206UYJ@80Hf=S0P3`l?020<[:
bPP0XJ6Q00<0Zj^[09fMW@2MWId00P2NWYh20:FUY@80WIfM1P2QXJ420:^[Z`80WYjN2P2QXJ420:2P
X0030:BTY02[Zj/0Zj^[0080WYjN302QXJ420:BTY080WIfM6@2QXJ4E0?ooo`004`3oool:0:6QX@80
Vi^K0P2SXj<T0:6QX@80X:2P102TY:@205EEE@80;Rh^0P15ADD204M7A`80JFUY0P1gMgL207QhN080
NGUi1014A4@2065QH@03061PH01<C4`0C4a<0080CDe=0P1CDe<20410@080B4Q80P1BDU8204Y:BP80
CDe=0P1:BTX205EEE@80DU9B0P14A4@205QHF080CTi>0P11@D400`1>CTh0=CDe03De=@0203Ti>@80
@4100P0l?3`203Xj>P80BTY:0P0i>CT205ADE080>c/k0P10@40204M7A`80EUIF0P1RHV82065QH@80
Lg=c00<0N7Qh09BDU02DU9@00P1PH60207AdM080@d=30P0V9RH205]KF`80HV9R0P1YJFT206=SH`80
l?3`0P3:b/X80:6QX@030:^[Z`2MWId0WIfM0080WYjN0P2UYJD209fMW@H0XJ6Q0P2[Zj/209jNWPX0
XJ6Q0P2PX:000`2TY:@0Zj^[0:^[Z`0209jNWP`0XJ6Q0P2TY:@209fMWAT0XJ6Q5@3oool001<0oooo
2P2QXJ420:2PX080Y:BT:P2QXJ4209FEU@80EUIF0P19BDT2051@D080BDU90P14A4@2065QH@80GUiN
0P1iNGT203De=@80CDe=00<0FUYJ05UIF@1IFET0101<C4`203Ti>@80?3`l0P10@40204I6AP80A4A4
0P1>CTh205ADE080@4100P13@d<2065QH@80Fe]K0P1<C4`00`1?Cdl0>3Ph03Ph>002069RHP80?3`l
0P0j>SX205MGE`80Cdm?0P15ADD204e=C@80BTY:0P1MGEd206QXJ080OWin0P1UIFD206e]K@80TY:B
00<0Jf][071`L01`L7000P1:BTX205iNGP80;bl_0P1>CTh2079bLP80GemO0P1HF5P20>OWi`80d];B
0P2[Zj/20:RXZ080WYjN0P2KVi/20:f][@0309^KV`2XZ:P0Z:RX0080WIfM0P2NWYh20:>SX`80Zj^[
0P2NWYh20:6QX@80Y:BT0P2MWId=0:6QX@80Y:BT0P2MWId60:6QX@80Zj^[0P2NWYhO0:6QXAD0oooo
000C0?ooo`X0XJ6Q0P2PX:020:BTY2X0XJ6Q0P2EUID205IFEP80BDU90P1@D50204U9B@80A4A40P1Q
HF4205iNGP80NGUi0P0e=CD204e=C@0305YJFP1IFET0FEUI00@0C4a<0P0i>CT203`l?080@4100P16
ATH204A4A080CTi>0P1DE5@20410@080@d=30P1QHF4205]KF`80C4a<00<0Cdm?03Ph>00h>3P00P1R
HV8203`l?080>SXj0P1GEeL204m?C`80ADE50P1=CDd204Y:BP80GEeM0P1XJ6P207inOP80IFEU0P1]
KFd209:BTP0306][J`1`L700L71`0080BTY:0P1NGUh202l_;`80CTi>0P1bLW8205mOG`80F5QH0P3W
inL20=;BdP80Zj^[0P2XZ:P209jNWP80Vi^K0P2][Jd00`2KVi/0Z:RX0:RXZ00209fMW@80WYjN0P2S
Xj<20:^[Z`80WYjN0P2QXJ420:BTY080WIfM3@2QXJ420:BTY080WIfM1P2QXJ420:^[Z`80WYjN7`2Q
XJ4E0?ooo`004`3ooolb0:6QX@80Zj^[0P2NWYh40:6QX@80T92@0P1ADE4204A4A080Cdm?0P1DE5@2
06QXJ080HV9R0P1mOGd205eMG@80@d=300<0CDe=06=SH`1SHf<00P1FEUH204M7A`80GemO0P0g=cL2
0492@P80@d=30P1ADE4204i>CP80De=C0P0e=CD2065QH@80E5AD0P1ZJVX2051@D003069RHP1WIfL0
IfMW0080CDe=0P0i>CT204=3@`80G5aL0P1@D50206=SH`80HV9R0P1[Jf/206UYJ@80Ph>30P1nOWh2
06e]K@80Cdm?0P1GEeL00`1:BTX0>3Ph03Ph>00202PX:080>c/k0P1CDe<206IVIP80EeMG0P1]KFd2
0>;RhP80hN7Q0P2MWId20:BTY080ZJVY0P2TY:@209fMW@80YZJV00<0YJFU0:BTY02TY:@00P2MWId2
0:2PX0@0Y:BT0P2MWIdM0:6QX@80Y:BT0P2MWIdO0:6QXAD0oooo000C0?oooc80XJ6Q0P2[Zj/209jN
WP@0XJ6Q0P2@T902055AD@80A4A40P1?Cdl205ADE080J6QX0P1RHV8207emO@80GEeM0P13@d<00`1=
CDd0Hf=S06=SH`0205IFEP80AdM70P1OGel203Lg=`80@T920P13@d<2055AD@80CTi>0P1CDe<203De
=@80HF5Q0P1DE5@206YZJP80D51@00<0HV9R06MWI`1WIfL00P1=CDd203Ti>@80@d=30P1LG5`2051@
D080Hf=S0P1RHV8206][J`80JFUY0P23Ph<207inOP80KFe]0P1?Cdl205MGE`0304Y:BP0h>3P0>3Ph
0080:2PX0P0k>c/205=CD`80IVIV0P1GEeL206e]K@80h^;R0P3QhN4209fMW@80Y:BT0P2YZJT20:BT
Y080WIfM0P2VYZH00`2UYJD0Y:BT0:BTY00209fMW@80X:2P102TY:@209fMWAd0XJ6Q0P2TY:@209fM
WAl0XJ6Q5@3oool001<0oooo<P2QXJ4409jNWP80XJ6Q0P2KVi/20:>SX`80Rh^;0P1QHF4203Ti>@80
De=C0P1XJ6P206][J`80M7Ad0P1eMGD206UYJ@0304M7A`1VIVH0IVIV0080?clo0P1MGEd2055AD@80
D51@0P1=CDd203Xj>P80?Cdm0P0b<S8204Y:BP80=cLg0P1QHF4204e=C@80N7Qh0P1MGEd00`2TY:@0
UYJF09JFUP0207AdM080K6a/0P2=SHd208>3P`80O7al0P21PH4209ZJVP80U9BD0P1jNWX208N7Q`80
DU9B0P0n?Sh204];B`80B4Q800<0?3`l03Ph>00h>3P00P15ADD2071`L080N7Qh0P1DE5@205EEE@80
moOg0P3Cdm<209fMW@80Zj^[0P2NWYh20:BTY080WinO0P2MWId20:6QX@030:BTY02MWId0WIfM0080
Vi^K0P2SXj<20:6QX@80Zj^[0P2XZ:P209jNWSh0XJ6Q5@3oool001<0oooo<P2QXJ4409jNWP80XJ6Q
0P2KVi/20:>SX`80Rh^;0P1QHF4203Ti>@80De=C0P1XJ6P206][J`80M7Ad0P1eMGD206UYJ@0304M7
A`1VIVH0IVIV0080?clo0P1MGEd2055AD@80D51@0P1=CDd203Xj>P80?Cdm0P0b<S8204Y:BP80=cLg
0P1QHF4204e=C@80N7Qh0P1MGEd00`2TY:@0UYJF09JFUP0207AdM080K6a/0P2=SHd208>3P`80O7al
0P21PH4209ZJVP80U9BD0P1jNWX208N7Q`80DU9B0P0n?Sh204];B`80B4Q800<0?3`l03Ph>00h>3P0
0P15ADD2071`L080N7Qh0P1DE5@205EEE@80moOg0P3Cdm<209fMW@80Zj^[0P2NWYh20:BTY080WinO
0P2MWId20:6QX@030:BTY02MWId0WIfM0080Vi^K0P2SXj<20:6QX@80Zj^[0P2XZ:P209jNWSh0XJ6Q
5@3oool001<0oooo<P2QXJ420:2PX080Y:BT0P2QXJ420:2PX080[Zj^0P2NWYh208j>SP80S8b<0P1?
Cdl2055AD@80?Cdm0P1WIfL208Z:RP80OGem00<0IfMW05UIF@1IFET00P1OGel206=SH`80GEeM0P1H
F5P206a/K080NGUi0P1BDU8203Hf=P80EEEE0P0g=cL205aLG080L71`0P25QHD206QXJ00306EUI@2;
Rh/0Rh^;0080NGUi0P1jNWX209>CT`80UYJF0P2ATI4207inOP80JVYZ0P1KFe/205UIF@80De=C0P0o
?cl204Q8B080CTi>0P0b<S800`0j>SX0EUIF05IFEP0205aLG080Ng]k0P1CDe<206EUI@80f][J0P3S
hn<209fMW@80Vi^K0P2UYJD209fMW@80Vi^K0P2MWId20:>SX`<0XJ6Q0P2KVi/20:6QX@80Y:BT0P2Q
XJ420:BTY080WinO0P2MWId209^KV`80Xj>S>P2QXJ4E0?ooo`004`3ooolb0:6QX@80X:2P0P2TY:@2
0:6QX@80X:2P0P2^[Zh209jNWP80SXj>0P2<S8`204m?C`80DE5A0P0m?Cd206MWI`80RXZ:0P1mOGd0
0`1WIfL0FEUI05UIF@0205mOG`80Hf=S0P1MGEd205QHF080K6a/0P1iNGT2059BDP80=SHf0P1EEED2
03Lg=`80G5aL0P1`L70208F5Q@80J6QX00<0IFEU08^;R`2;Rh/00P1iNGT207YjNP80Ti>C0P2FUYH2
096AT@80OWin0P1ZJVX205]KF`80FEUI0P1CDe<203lo?`80B4Q80P1>CTh2038b<P0303Xj>P1FEUH0
EUIF0080G5aL0P1kNg/205=CD`80IFEU0P3Jf]X20>?Sh`80WIfM0P2KVi/20:FUY@80WIfM0P2KVi/2
09fMW@80Xj>S0`2QXJ4209^KV`80XJ6Q0P2TY:@20:6QX@80Y:BT0P2OWil209fMW@80Vi^K0P2SXj<j
0:6QXAD0oooo000C0?ooocX0XJ6Q0P2^[Zh209ZJVP80XJ6Q0P2OWil208^;R`80?3`l0P0m?Cd206][
J`80JFUY0P1kNg/00`2?Shl0I6AT06ATI00207emO@80RXZ:0P1gMgL209ZJVP80SXj>0P1cLg<209:B
TP80VIVI0P3<c<`20:VYZ@80[jn_0P2TY:@209ZJVP80O7al00<0T92@09^KV`2KVi/01026QXH209:B
TP80M7Ad0P1;Bd/206a/K0@0C4a<0P1BDU82051@D080?Shn0P1:BTX203Ti>@80FUYJ00<0JFUY06EU
I@1UIFD00P1NGUh205]KF`80gmoO0P31`L420=GEe@80Zj^[0P2IVIT20:6QX@80Y:BT0P2QXJ420:2P
X080WIfM0P2UYJD30:6QX@80X:2P0P2NWYh20:>SX`80XJ6Q0P2[Zj/209jNWP80XJ6Q0P2JVYX20:FU
Y@80XJ6Q0P2KVi/20:>SX`80Zj^[0P2NWYh`0:6QXAD0oooo000C0?ooocX0XJ6Q0P2^[Zh209ZJVP80
XJ6Q0P2OWil208^;R`80?3`l0P0m?Cd206][J`80JFUY0P1kNg/00`2?Shl0I6AT06ATI00207emO@80
RXZ:0P1gMgL209ZJVP80SXj>0P1cLg<209:BTP80VIVI0P3<c<`20:VYZ@80[jn_0P2TY:@209ZJVP80
O7al00<0T92@09^KV`2KVi/01026QXH209:BTP80M7Ad0P1;Bd/206a/K0@0C4a<0P1BDU82051@D080
?Shn0P1:BTX203Ti>@80FUYJ00<0JFUY06EUI@1UIFD00P1NGUh205]KF`80gmoO0P31`L420=GEe@80
Zj^[0P2IVIT20:6QX@80Y:BT0P2QXJ420:2PX080WIfM0P2UYJD30:6QX@80X:2P0P2NWYh20:>SX`80
XJ6Q0P2[Zj/209jNWP80XJ6Q0P2JVYX20:FUY@80XJ6Q0P2KVi/20:>SX`80Zj^[0P2NWYh`0:6QXAD0
oooo000C0?ooobL0XJ6Q0P2[Zj/209jNWPl0XJ6Q0P2^[Zh209ZJVP@0XJ6Q0P2TY:@207MgM`80VIVI
0P0i>CT2051@D080M7Ad00<0N7Qh07emO@1mOGd00P2BTY8209jNWP80QHF50P2GUiL408F5Q@80YJFU
0P21PH4208Z:RP80Ph>30P1lO7`2096AT@80UiNG0P29RHT00`2<S8`0Rh^;08^;R`02071`L080HF5Q
0P27QhL205MGE`80G5aL0P1fMWH203`l?080E5AD0P11@D4204U9B@80E5AD0P1RHV8207AdM080P820
00<0Hf=S05MGE`1GEeL00P1oOgl20=3@d080i>CT0P2GUiL20:>SX`80WYjN0P2MWId20:BTY0H0XJ6Q
0P2PX:020:BTY080Vi^K00<0Xj>S0:6QX@2QXJ400P2PX:020:BTY080XJ6Q0P2TY:@209fMW@80XJ6Q
0P2PX:020:BTY080XJ6Q0P2PX:040:BTY080WIfM3@2QXJ420:^[Z`80WYjN0P2QXJ420:^[Z`80WYjN
0P2KVi/20:>SXaD0XJ6Q5@3oool001<0oooo9`2QXJ420:^[Z`80WYjN3`2QXJ420:j^[P80VYZJ102Q
XJ420:BTY080MgMg0P2IVIT203Ti>@80D51@0P1dM7@00`1hN7P0OGem07emO@0209:BTP80WYjN0P25
QHD209NGU`@0QHF50P2UYJD20861P@80RXZ:0P23Ph<207alO080TI6A0P2GUiL208V9R@0308b<S02;
Rh/0Rh^;0080L71`0P1QHF4208N7Q`80EeMG0P1LG5`207IfMP80?3`l0P1DE5@20451@@80BDU90P1D
E5@2069RHP80M7Ad0P20P8000`1SHf<0EeMG05MGE`0207moO`80d=3@0P3Ti>@209NGU`80Xj>S0P2N
WYh209fMW@80Y:BT1P2QXJ420:2PX080Y:BT0P2KVi/00`2SXj<0XJ6Q0:6QX@020:2PX080Y:BT0P2Q
XJ420:BTY080WIfM0P2QXJ420:2PX080Y:BT0P2QXJ420:2PX0@0Y:BT0P2MWId=0:6QX@80Zj^[0P2N
WYh20:6QX@80Zj^[0P2NWYh209^KV`80Xj>S5@2QXJ4E0?ooo`004`3ooolW0:6QX@80Y:BT0P2MWId;
0:6QX@80Zj^[0P2NWYh20:j^[P80Y:BT0P2NWYh20:^[Z`80WYjN0P2QXJ420:>SX`80Kfm_0P1ADE42
065QH@0306=SH`2<S8`0S8b<0080Ng]k0P22PX8207moO`80RXZ:0P2CTi<2092@T080Ti>C0P2:RXX2
0:>SX`80UIFE0P2=SHd209BDU080V9RH0P22PX800`23Ph<0Ng]k07]kN`0207YjNP80FEUI0P1PH602
06ATI080BTY:0P1BDU820492@P80J6QX0P0j>SX206a/K080NWYj0P1dM7@2075aL@80FEUI00<0KFe]
0;6a/@2a/K400P3=cLd20<[:bP80XJ6Q0P2JVYX20:FUY@80X:2P0P2TY:@20:^[Z`80WYjN0P2[Zj/2
09jNWP80XJ6Q0P2KVi/20:6QX@030:BTY02QXJ40XJ6Q00`0XJ6Q0P2[Zj/209jNWP`0XJ6Q00<0Zj^[
09jNWP2NWYh01P2QXJ420:^[Z`80XJ6Q0P2MWId20:6QX@80Y:BT0P2VYZH209fMW@80Y:BT5@2QXJ4E
0?ooo`004`3ooolW0:6QX@80Y:BT0P2MWId;0:6QX@80Zj^[0P2NWYh20:j^[P80Y:BT0P2NWYh20:^[
Z`80WYjN0P2QXJ420:>SX`80Kfm_0P1ADE42065QH@0306=SH`2<S8`0S8b<0080Ng]k0P22PX8207mo
O`80RXZ:0P2CTi<2092@T080Ti>C0P2:RXX20:>SX`80UIFE0P2=SHd209BDU080V9RH0P22PX800`23
Ph<0Ng]k07]kN`0207YjNP80FEUI0P1PH60206ATI080BTY:0P1BDU820492@P80J6QX0P0j>SX206a/
K080NWYj0P1dM7@2075aL@80FEUI00<0KFe]0;6a/@2a/K400P3=cLd20<[:bP80XJ6Q0P2JVYX20:FU
Y@80X:2P0P2TY:@20:^[Z`80WYjN0P2[Zj/209jNWP80XJ6Q0P2KVi/20:6QX@030:BTY02QXJ40XJ6Q
00`0XJ6Q0P2[Zj/209jNWP`0XJ6Q00<0Zj^[09jNWP2NWYh01P2QXJ420:^[Z`80XJ6Q0P2MWId20:6Q
X@80Y:BT0P2VYZH209fMW@80Y:BT5@2QXJ4E0?ooo`004`3ooolf0:6QX@80Y:BT0P2MWId20:BTY080
WinO0P2MWId20:BTY080WIfM0P2KVi/20:FUY@80XZ:R0P23Ph<20;Zj^P0305UIF@1FEUH0EUIF0080
EUIF0P29RHT208j>SP80V9RH0P2CTi<208f=S@80R8R80P21PH4209NGU`80Ogmo0P20P80207QhN080
Jf][0P1KFe/00`1JFUX0K6a/06a/K00207AdM080F5QH0P1GEeL204=3@`80DE5A0P1dM7@205aLG080
Rh^;0P1aLG4209>CT`80O7al0P1GEeL207emO@80`<3000<0`L710<O7a`37alL00P2^[Zh40:6QX@80
X:2P0P2^[Zh209jNWP80XJ6Q0P2TY:@209fMW@@0WYjN0P2QXJ420:VYZ@80XJ6Q00<0Zj^[09jNWP2N
WYh0102QXJ4209^KV`80Xj>S0P2[Zj/209jNWP80Y:BT0P2MWId40:6QX@80Zj^[0P2NWYh40:6QX@03
0:BTY02MWId0WIfM00H0XJ6Q0P2TY:@209fMW@80XJ6Q0P2[Zj/20:RXZ080Zj^[0P2DU9@20:>SX`T0
XJ6Q0P2[Zj/209jNWPP0XJ6Q5@3oool001<0oooo=P2QXJ420:BTY080WIfM0P2TY:@209nOW`80WIfM
0P2TY:@209fMW@80Vi^K0P2UYJD20::RXP80Ph>30P2j^[X00`1IFET0EUIF05IFEP0205IFEP80RHV9
0P2>SXh209RHV080Ti>C0P2=SHd208R8R080PH610P2GUiL207moO`80P8200P1hN7P206][J`80Fe]K
00<0FUYJ06a/K01/K6`00P1dM7@205QHF080EeMG0P13@d<2055AD@80M7Ad0P1LG5`208^;R`80LG5a
0P2CTi<207alO080EeMG0P1mOGd20<30`0030<71`@37alL0alO70080[Zj^102QXJ420:2PX080[Zj^
0P2NWYh20:6QX@80Y:BT0P2MWId409jNWP80XJ6Q0P2YZJT20:6QX@030:^[Z`2NWYh0WYjN00@0XJ6Q
0P2KVi/20:>SX`80Zj^[0P2NWYh20:BTY080WIfM102QXJ420:^[Z`80WYjN102QXJ400`2TY:@0WIfM
09fMW@060:6QX@80Y:BT0P2MWId20:6QX@80Zj^[0P2XZ:P20:^[Z`80U9BD0P2SXj<90:6QX@80Zj^[
0P2NWYh80:6QXAD0oooo000C0?ooobD0XJ6Q0P2[Zj/209jNWQL0XJ6Q0P2KVi/20:f][@80WIfM0P2T
Y:@20:j^[P80VYZJ0P2QXJ400`24Q8@0[Zj^0:j^[P020;no_`80J6QX0P1SHf<20820P080MWIf0P1m
OGd209FEU@80SXj>0P2EUID208b<S080Shn?0P2>SXh207EeM@80Ogmo00<0K6a/07IfMP1fMWH00P1R
HV8207inOP80Ti>C0P1NGUh209fMW@80WYjN0P1oOgl206m_K`80GemO0P2>SXh20:b/[080][Jf0P3<
c<`20<k>cPD0XJ6Q0P2[Zj/209jNWP80XJ6Q0P2TY:@209fMW@80XJ6Q0P2[Zj/209jNWP80X:2P0P2T
Y:@20:6QX@80Y:BT0P2MWId309jNWP@0XJ6Q0P2PX:040:BTY080WIfM0P2[Zj/209jNWP80Zj^[0P2X
Z:P20:^[Z`80Y:BT0P2XZ:P209jNWPL0XJ6Q0P2[Zj/209jNWP@0XJ6Q0P2^[Zh20:JVYP80WIfM0P2U
YJD;0:6QX@80Y:BT0P2MWId80:6QXAD0oooo000C0?ooobD0XJ6Q0P2[Zj/209jNWQL0XJ6Q0P2KVi/2
0:f][@80WIfM0P2TY:@20:j^[P80VYZJ0P2QXJ400`24Q8@0[Zj^0:j^[P020;no_`80J6QX0P1SHf<2
0820P080MWIf0P1mOGd209FEU@80SXj>0P2EUID208b<S080Shn?0P2>SXh207EeM@80Ogmo00<0K6a/
07IfMP1fMWH00P1RHV8207inOP80Ti>C0P1NGUh209fMW@80WYjN0P1oOgl206m_K`80GemO0P2>SXh2
0:b/[080][Jf0P3<c<`20<k>cPD0XJ6Q0P2[Zj/209jNWP80XJ6Q0P2TY:@209fMW@80XJ6Q0P2[Zj/2
09jNWP80X:2P0P2TY:@20:6QX@80Y:BT0P2MWId309jNWP@0XJ6Q0P2PX:040:BTY080WIfM0P2[Zj/2
09jNWP80Zj^[0P2XZ:P20:^[Z`80Y:BT0P2XZ:P209jNWPL0XJ6Q0P2[Zj/209jNWP@0XJ6Q0P2^[Zh2
0:JVYP80WIfM0P2UYJD;0:6QX@80Y:BT0P2MWId80:6QXAD0oooo000C0?ooob<0XJ6Q0P2KVi/20:FU
Y@80WIfM5`2QXJ420:2PX080YZJV0P2MWId20:6QX@80Y:BT0P2MWId20:6QX@030:^[Z`2NWYh0WYjN
0080Zj^[0P24Q8@20;:b/P80KVi^0P1/K6`208V9R@80KVi^0P20P80208^;R`80QhN70P2GUiL208f=
S@80V9RH0P2ZZZX00`2GUiL0Ti>C09>CT`0208V9R@80YZJV0P2ATI4207alO080LW9b0P1VIVH207Yj
NP80RHV90P2/[:`20<S8b080^[Zj0P2f][H20:JVYP80UiNG00<0WYjN0:6QX@2QXJ400P2QXJ420:BT
Y080WIfM102QXJ4209^KV`80Xj>S0P2TY:@209NGU`80Xj>S102QXJ4209^KV`80Xj>S00<0X:2P0:BT
Y02TY:@0202QXJ4209^KV`80Xj>S0P2TY:@209fMW@80Y:BT1P2OWil209ZJVP80WYjN00<0Zj^[09VI
V@2IVIT00P2SXj<20:6QX@80Y:BT0P2MWId20:6QX@80Vi^K0P2UYJD209nOW`80WIfM0P2TY:@209NG
U`80Xj>S4`2QXJ4E0?ooo`004`3ooolS0:6QX@80Vi^K0P2UYJD209fMWAL0XJ6Q0P2PX:020:JVYP80
WIfM0P2QXJ420:BTY080WIfM0P2QXJ400`2[Zj/0WYjN09jNWP020:^[Z`80Q8B40P2b/[8206i^KP80
K6a/0P29RHT206i^KP80P8200P2;Rh/208N7Q`80UiNG0P2=SHd209RHV080ZZZZ00<0UiNG09>CT`2C
Ti<00P29RHT20:JVYP80TI6A0P1lO7`2079bLP80IVIV0P1jNWX208V9R@80[:b/0P38b<P20;Zj^P80
][Jf0P2VYZH209NGU`0309jNWP2QXJ40XJ6Q0080XJ6Q0P2TY:@209fMW@@0XJ6Q0P2KVi/20:>SX`80
Y:BT0P2GUiL20:>SX`@0XJ6Q0P2KVi/20:>SX`030:2PX02TY:@0Y:BT00P0XJ6Q0P2KVi/20:>SX`80
Y:BT0P2MWId20:BTY0H0WinO0P2JVYX209jNWP030:^[Z`2IVIT0VIVI0080Xj>S0P2QXJ420:BTY080
WIfM0P2QXJ4209^KV`80YJFU0P2OWil209fMW@80Y:BT0P2GUiL20:>SXa<0XJ6Q5@3oool001<0oooo
8`2QXJ420:2PX080[Zj^0P2NWYhO0:6QX@80Vi^K0P2SXj<20:6QX@030:j^[P2DU9@0U9BD0080WinO
0P2NWYh20:6QX@80Rh^;0P2YZJT20;Jf]P80XZ:R0P2YZJT20:JVYP80Ti>C0P2][Jd209JFUP80Ph>3
0P1gMgL00`1eMGD0Ph>308>3P`0208F5Q@80QXJ60P21PH4208^;R`80VYZJ0P2^[Zh20;jn_P80]kNg
0P2b/[820:VYZ@80XJ6Q0P2^[Zh20:JVYP80V9RH00<0[Zj^0:RXZ02XZ:P00P2XZ:P209jNWPH0XJ6Q
0P2PX:0209jNWP80WIfM0P2QXJ420:BTY0@0XJ6Q0P2PX:020:BTY00309^KV`2SXj<0Xj>S0080Zj^[
0P2IVIT20:>SX`80XJ6Q0P2PX:020:j^[P80WYjN2P2QXJ420:2PX0<0Y:BT0P2UYJD20:6QX@80Zj^[
0P2NWYh40:6QX@80X:2P0P2TY:@60:6QX@80ZJVY3@2QXJ420:^[Z`80WYjN102QXJ4E0?ooo`004`3o
oolS0:6QX@80X:2P0P2^[Zh209jNWQl0XJ6Q0P2KVi/20:>SX`80XJ6Q00<0[Zj^09BDU02DU9@00P2O
Wil209jNWP80XJ6Q0P2;Rh/20:VYZ@80][Jf0P2RXZ820:VYZ@80YZJV0P2CTi<20:f][@80UYJF0P23
Ph<207MgM`0307EeM@23Ph<0Ph>30080QHF50P26QXH20861P@80Rh^;0P2JVYX20:j^[P80_[jn0P2g
]kL20;:b/P80ZJVY0P2QXJ420:j^[P80YZJV0P2HV9P00`2^[Zh0Z:RX0:RXZ0020:RXZ080WYjN1P2Q
XJ420:2PX080WYjN0P2MWId20:6QX@80Y:BT102QXJ420:2PX080Y:BT00<0Vi^K0:>SX`2SXj<00P2[
Zj/209VIV@80Xj>S0P2QXJ420:2PX080[Zj^0P2NWYh:0:6QX@80X:2P0`2TY:@20:FUY@80XJ6Q0P2[
Zj/209jNWP@0XJ6Q0P2PX:020:BTY0H0XJ6Q0P2YZJT=0:6QX@80Zj^[0P2NWYh40:6QXAD0oooo000C
0?ooobD0XJ6Q0P2TY:@209NGU`80Xj>S4`2QXJ420:^[Z`80VIVI0P2SXj<40:6QX@80X:2P0P2NWYh2
0:>SX`030:BTY02KVi/0Vi^K0080XZ:R0P2TY:@40:6QX@80X:2P0P2RXZ820:b/[080WIfM0P2TY:@2
0:6QX@80[:b/0P2PX:0209NGU`80XZ:R00<0ZJVY0:f][@2][Jd00P2f][H20:JVYP80Zj^[0P2][Jd2
0;6a/@80YjNW0P2TY:@20:^[Z`80Z:RX0P2NWYh20:6QX@80Y:BT0P2YZJT209ZJVP030:BTY02OWil0
WinO0080WinO0P2GUiL20:>SX`80Zj^[0P2NWYh20:6QX@80ZJVY0P2PX:020:BTY080XJ6Q0P2[Zj/2
09jNWP80Zj^[0P2NWYh00`2YZJT0XJ6Q0:6QX@0209jNWP80WIfM0P2TY:@209^KV`80Xj>S0P2TY:@2
09fMW@l0XJ6Q102NWYh20:BTY080YZJV0P2NWYh60:6QX@80Zj^[0P2NWYh20:6QX@80Y:BT0P2MWId;
0:6QX@80Y:BT0P2MWId40:6QXAD0oooo000C0?ooobD0XJ6Q0P2TY:@209NGU`80Xj>S4`2QXJ420:^[
Z`80VIVI0P2SXj<40:6QX@80X:2P0P2NWYh20:>SX`030:BTY02KVi/0Vi^K0080XZ:R0P2TY:@40:6Q
X@80X:2P0P2RXZ820:b/[080WIfM0P2TY:@20:6QX@80[:b/0P2PX:0209NGU`80XZ:R00<0ZJVY0:f]
[@2][Jd00P2f][H20:JVYP80Zj^[0P2][Jd20;6a/@80YjNW0P2TY:@20:^[Z`80Z:RX0P2NWYh20:6Q
X@80Y:BT0P2YZJT209ZJVP030:BTY02OWil0WinO0080WinO0P2GUiL20:>SX`80Zj^[0P2NWYh20:6Q
X@80ZJVY0P2PX:020:BTY080XJ6Q0P2[Zj/209jNWP80Zj^[0P2NWYh00`2YZJT0XJ6Q0:6QX@0209jN
WP80WIfM0P2TY:@209^KV`80Xj>S0P2TY:@209fMW@l0XJ6Q102NWYh20:BTY080YZJV0P2NWYh60:6Q
X@80Zj^[0P2NWYh20:6QX@80Y:BT0P2MWId;0:6QX@80Y:BT0P2MWId40:6QXAD0oooo000C0?ooobL0
XJ6Q0P2PX:020:BTY1<0XJ6Q0P2TY:@209^KV`80Y:BT102QXJ4209^KV`80XJ6Q0P2TY:@00`2KVi/0
[Jf]0:f][@0209jNWP@0XJ6Q0P2KVi/20:>SX`80Vi^K0P2UYJD209fMW@80Zj^[0P2IVIT20:>SX`80
XJ6Q0P2PX:050::RXP80/;2`0P2JVYX20:6QX@80Vi^K0P2SXj<40:6QX@80Y:BT0P2OWil209fMW@80
Zj^[0P2NWYh20:j^[P80VYZJ0`2QXJ4209^KV`80Zj^[0P2QXJ420:j^[P80Y:BT0P2NWYh20:BTY080
WIfM102QXJ420:BTY080WIfM0P2TY:@209fMW@030:j^[P2DU9@0U9BD0080Vi^K0P2UYJD209^KV`80
XJ6Q0P2TY:@<0:6QX@80Zj^[0P2NWYh30:6QX@80X:2P0P2TY:@20:6QX@80[Zj^0P2JVYX40:6QX@80
Vi^K0P2UYJD20:JVYP80Z:RX0P2NWYh=0:6QX@80Zj^[0P2NWYh209^KV`80Xj>S5@3oool001<0oooo
9`2QXJ420:2PX080Y:BT4`2QXJ420:BTY080Vi^K0P2TY:@40:6QX@80Vi^K0P2QXJ420:BTY00309^K
V`2][Jd0[Jf]0080WYjN102QXJ4209^KV`80Xj>S0P2KVi/20:FUY@80WIfM0P2[Zj/209VIV@80Xj>S
0P2QXJ420:2PX0D0XZ:R0P2`/;0209ZJVP80XJ6Q0P2KVi/20:>SX`@0XJ6Q0P2TY:@209nOW`80WIfM
0P2[Zj/209jNWP80[Zj^0P2JVYX30:6QX@80Vi^K0P2[Zj/20:6QX@80[Zj^0P2TY:@209jNWP80Y:BT
0P2MWId40:6QX@80Y:BT0P2MWId20:BTY080WIfM00<0[Zj^09BDU02DU9@00P2KVi/20:FUY@80Vi^K
0P2QXJ420:BTY0`0XJ6Q0P2[Zj/209jNWP<0XJ6Q0P2PX:020:BTY080XJ6Q0P2^[Zh209ZJVP@0XJ6Q
0P2KVi/20:FUY@80YZJV0P2XZ:P209jNWPd0XJ6Q0P2[Zj/209jNWP80Vi^K0P2SXj<E0?ooo`004`3o
oolY0:6QX@80Zj^[0P2NWYhK0:6QX@80X:2P0P2TY:@20:^[Z`030:NWY`2TY:@0Y:BT0080WIfM0P2Q
XJ4209^KV`80XJ6Q0P2TY:@20:VYZ@@0XJ6Q0P2TY:@20:FUY@@0XJ6Q0P2[Zj/209jNWP<0XJ6Q102N
WYh20:6QX@80X:2P0P2TY:@40:6QX@80Vi^K0P2SXj<20:^[Z`80XJ6Q0P2MWId20:j^[P80Y:BT00<0
WYjN0:6QX@2QXJ400P2PX:020:6QX@80WYjN0P2TY:@209ZJVP80WYjN0P2[Zj/209jNWPH0XJ6Q0P2[
Zj/209jNWP80XJ6Q00<0Y:BT09^KV`2KVi/00P2RXZ820:BTY080X:2P0P2TY:@20:6QX@80Zj^[0P2I
VIT20:>SX`H0XJ6Q0P2^[Zh209ZJVP80XJ6Q00<0Zj^[09jNWP2NWYh00P2QXJ4209^KV`80YJFU0P2M
WId40:6QX@80X:2P0P2TY:@209jNWP80Zj^[0P2JVYX=0:6QX@80Y:BT0P2MWId20:VYZ@80XJ6Q5@3o
ool001<0oooo:@2QXJ420:^[Z`80WYjN6`2QXJ420:2PX080Y:BT0P2[Zj/00`2WYjL0Y:BT0:BTY002
09fMW@80XJ6Q0P2KVi/20:6QX@80Y:BT0P2YZJT40:6QX@80Y:BT0P2UYJD40:6QX@80Zj^[0P2NWYh3
0:6QX@@0WYjN0P2QXJ420:2PX080Y:BT102QXJ4209^KV`80Xj>S0P2[Zj/20:6QX@80WIfM0P2^[Zh2
0:BTY00309jNWP2QXJ40XJ6Q0080X:2P0P2QXJ4209jNWP80Y:BT0P2JVYX209jNWP80Zj^[0P2NWYh6
0:6QX@80Zj^[0P2NWYh20:6QX@030:BTY02KVi/0Vi^K0080XZ:R0P2TY:@20:2PX080Y:BT0P2QXJ42
0:^[Z`80VIVI0P2SXj<60:6QX@80[Zj^0P2JVYX20:6QX@030:^[Z`2NWYh0WYjN0080XJ6Q0P2KVi/2
0:FUY@80WIfM102QXJ420:2PX080Y:BT0P2NWYh20:^[Z`80VYZJ3@2QXJ420:BTY080WIfM0P2YZJT2
0:6QXAD0oooo000C0?ooob40XJ6Q0P2[Zj/209jNWP80XJ6Q0P2KVi/20:FUY@80WIfM0P2KVi/00`2S
Xj<0XJ6Q0:6QX@0B0:6QX@80Vi^K0P2][Jd209jNWP80XJ6Q0P2TY:@00`2JVYX0WYjN09jNWP040:6Q
X@80X:2P0P2NWYh20:f][@80Vi^K0P2NWYh40:6QX@80[Zj^0P2JVYX20:6QX@80Y:BT0P2VYZH00`2N
WYh0Vi^K09^KV`020:6QX@80Y:BT0P2KVi/20:>SX`H0XJ6Q0P2PX:040:BTY080WIfM0P2QXJ420:BT
Y080ZJVY00<0VYZJ0:6QX@2QXJ400P2KVi/20:6QX@80[Zj^0P2NWYh20:2PX080Y:BT0P2NWYh40:RX
Z080WYjN0P2QXJ4209jNWP80Z:RX0P2NWYh50:6QX@80Zj^[0P2NWYh40:6QX@80[Zj^0P2HV9P20:BT
Y080XJ6Q0P2[Zj/209jNWP80Y:BT0P2VYZH209jNWP030:BTY02VYZH0YZJV0080Z:RX0P2MWId20:BT
Y080Zj^[0P2NWYh40:6QX@80Vi^K0P2QXJ420:JVYP80WIfM2@2QXJ420:^[Z`80WYjN102QXJ420:BT
Y080WIfM5@3oool001<0oooo8@2QXJ420:BTY080WIfM0P2QXJ420:2PX080Y:BT0P2[Zj/209fMW@03
0:BTY02QXJ40XJ6Q0180XJ6Q0P2PX:020:JVYP80WIfM102QXJ400`2PX:00Y:BT0:BTY0060:6QX@80
VYZJ0P2XZ:P209^KV`80Y:BT0P2[Zj/209VIV@80YJFU0P2VYZH209jNWP80XJ6Q0P2TY:@00`2MWId0
ZJVY0:VYZ@020:6QX@80Zj^[0P2MWId20:BTY0P0XJ6Q0P2KVi/20:>SX`80Zj^[0P2NWYh20:6QX@80
Y:BT00<0WIfM0:6QX@2QXJ400P2PX:040:BTY080WIfM102QXJ420:2PX080YZJV0P2JVYX209jNWP80
XJ6Q0P2PX:020:JVYP80WIfM00<0XJ6Q09^KV`2KVi/00P2][Jd209^KV`80Z:RX0P2NWYh20:6QX@80
[Zj^0P2JVYX20:6QX@80Vi^K0P2UYJD209fMW@80XJ6Q0P2TY:@209fMW@030:6QX@2TY:@0Y:BT0080
WinO0P2MWId20:6QX@80Y:BT0P2MWId209^KV`80Xj>S0P2PX:020:BTY0/0XJ6Q0P2KVi/20:n_[`80
VYZJ202QXJ4E0?ooo`004`3ooolQ0:6QX@80Y:BT0P2MWId20:6QX@80X:2P0P2TY:@20:^[Z`80WIfM
00<0Y:BT0:6QX@2QXJ404P2QXJ420:2PX080YZJV0P2MWId40:6QX@030:2PX02TY:@0Y:BT00H0XJ6Q
0P2JVYX20:RXZ080Vi^K0P2TY:@20:^[Z`80VIVI0P2UYJD20:JVYP80WYjN0P2QXJ420:BTY00309fM
W@2YZJT0ZJVY0080XJ6Q0P2[Zj/209fMW@80Y:BT202QXJ4209^KV`80Xj>S0P2[Zj/209jNWP80XJ6Q
0P2TY:@00`2MWId0XJ6Q0:6QX@020:2PX0@0Y:BT0P2MWId40:6QX@80X:2P0P2VYZH209ZJVP80WYjN
0P2QXJ420:2PX080YZJV0P2MWId00`2QXJ40Vi^K09^KV`020:f][@80Vi^K0P2XZ:P209jNWP80XJ6Q
0P2^[Zh209ZJVP80XJ6Q0P2KVi/20:FUY@80WIfM0P2QXJ420:BTY080WIfM00<0XJ6Q0:BTY02TY:@0
0P2OWil209fMW@80XJ6Q0P2TY:@209fMW@80Vi^K0P2SXj<20:2PX080Y:BT2`2QXJ4209^KV`80[jn_
0P2JVYX80:6QXAD0oooo000C0?ooobL0XJ6Q0P2[Zj/209jNWP80Y:BT0P2MWIdC0:6QX@80Vi^K0P2S
Xj<A0:6QX@80VYZJ0P2PX:020:>SX`80XJ6Q0P2TY:@209^KV`80WYjN0P2_[jl20:BTY080WYjN0P2Q
XJ400`2[Zj/0Vi^K09^KV`0209jNWP80Y:BT0P2MWId40:6QX@80Zj^[0P2NWYh409^KV`80YJFU0P2T
Y:@20:JVYP80VIVI0P2SXj<00`2[Zj/0WYjN09jNWP020:^[Z`80WYjN0P2QXJ420:^[Z`80WYjN0P2[
Zj/209jNWP80XJ6Q0P2PX:020:BTY080XJ6Q0P2[Zj/209jNWP<0XJ6Q0P2PX:020:JVYP80UIFE0P2X
Z:P20:JVYP80WYjN0P2TY:@209fMW@80Zj^[0P2MWId20:BTY080XJ6Q0P2[Zj/209jNWP80Zj^[00<0
WYjN0:6QX@2QXJ400P2[Zj/209VIV@80Xj>S102QXJ420:2PX080Y:BT0P2[Zj/209jNWP80XJ6Q0P2[
Zj/209jNWPD0XJ6Q0P2PX:020:JVYP80WIfM102QXJ4209^KV`80WIfM5@3oool001<0oooo9`2QXJ42
0:^[Z`80WYjN0P2TY:@209fMWA<0XJ6Q0P2KVi/20:>SXa40XJ6Q0P2JVYX20:2PX080Xj>S0P2QXJ42
0:BTY080Vi^K0P2NWYh20:n_[`80Y:BT0P2NWYh20:6QX@030:^[Z`2KVi/0Vi^K0080WYjN0P2TY:@2
09fMW@@0XJ6Q0P2[Zj/209jNWP@0Vi^K0P2UYJD20:BTY080YZJV0P2IVIT20:>SX`030:^[Z`2NWYh0
WYjN0080Zj^[0P2NWYh20:6QX@80Zj^[0P2NWYh20:^[Z`80WYjN0P2QXJ420:2PX080Y:BT0P2QXJ42
0:^[Z`80WYjN0`2QXJ420:2PX080YZJV0P2EUID20:RXZ080YZJV0P2NWYh20:BTY080WIfM0P2[Zj/2
09fMW@80Y:BT0P2QXJ420:^[Z`80WYjN0P2[Zj/00`2NWYh0XJ6Q0:6QX@020:^[Z`80VIVI0P2SXj<4
0:6QX@80X:2P0P2TY:@20:^[Z`80WYjN0P2QXJ420:^[Z`80WYjN1@2QXJ420:2PX080YZJV0P2MWId4
0:6QX@80Vi^K0P2MWIdE0?ooo`004`3ooolW0:6QX@80Y:BT0P2MWId20:^[Z`80WYjN4`2QXJ420:2P
X080[Zj^0P2NWYh20:6QX@80Vi^K0P2SXj<00`2KVi/0Xj>S0:>SX`060:6QX@80X:2P0P2RXZ820:j^
[P80WYjN102QXJ420:2PX080YZJV0P2OWil209fMW@80Vi^K00<0[jn_09RHV02HV9P00P2TY:@80:6Q
X@80Y:BT0P2MWId20:2PX080XZ:R0P2TY:@209^KV`@0YJFU0P2QXJ400`2^[Zh0VYZJ09ZJVP020:BT
Y080WIfM0P2KVi/20:n_[`80U9BD0P2_[jl209ZJVP@0XJ6Q0P2KVi/20:>SX`80Y:BT0P2MWId70:6Q
X@80X:2P0P2^[Zh209^KV`80V9RH0P2SXj<20:6QX@80Y:BT0P2GUiL20:>SX`80XJ6Q0P2TY:@209fM
W@80[Zj^00<0VYZJ0:6QX@2QXJ400P2TY:@209^KV`80Y:BT102QXJ420:^[Z`80WYjN0P2TY:@209fM
W@80XJ6Q0P2TY:@209fMW@/0XJ6Q0P2KVi/20:>SX`80ZJVY0P2PX:0E0?ooo`004`3ooolW0:6QX@80
Y:BT0P2MWId20:^[Z`80WYjN4`2QXJ420:2PX080[Zj^0P2NWYh20:6QX@80Vi^K0P2SXj<00`2KVi/0
Xj>S0:>SX`060:6QX@80X:2P0P2RXZ820:j^[P80WYjN102QXJ420:2PX080YZJV0P2OWil209fMW@80
Vi^K00<0[jn_09RHV02HV9P00P2TY:@80:6QX@80Y:BT0P2MWId20:2PX080XZ:R0P2TY:@209^KV`@0
YJFU0P2QXJ400`2^[Zh0VYZJ09ZJVP020:BTY080WIfM0P2KVi/20:n_[`80U9BD0P2_[jl209ZJVP@0
XJ6Q0P2KVi/20:>SX`80Y:BT0P2MWId70:6QX@80X:2P0P2^[Zh209^KV`80V9RH0P2SXj<20:6QX@80
Y:BT0P2GUiL20:>SX`80XJ6Q0P2TY:@209fMW@80[Zj^00<0VYZJ0:6QX@2QXJ400P2TY:@209^KV`80
Y:BT102QXJ420:^[Z`80WYjN0P2TY:@209fMW@80XJ6Q0P2TY:@209fMW@/0XJ6Q0P2KVi/20:>SX`80
ZJVY0P2PX:0E0?ooo`004`3oool[0:6QX@80Y:BT0P2GUiL00`2SXj<0XJ6Q0:6QX@0<0:6QX@80Vi^K
0P2][Jd209jNWP80Y:BT0P2GUiL20:>SX`80X:2P0P2NWYh00`2KVi/0YJFU0:FUY@040:6QX@80Zj^[
0P2XZ:P209jNWP80Y:BT0P2MWId209^KV`80Xj>S1P2QXJ4209^KV`80XJ6Q0`2VYZH209jNWP80Vi^K
0P2][Jd209jNWPP0XJ6Q0P2[Zj/209jNWP80ZJVY0P2QXJ4209jNWP80Z:RX00<0XJ6Q09NGU`2GUiL0
0P2SXj<209^KV`80XJ6Q0P2VYZH20:FUY@80Y:BT0P2MWId209^KV`80Xj>S0P2PX:020:j^[P80VIVI
0P2][Jd209jNWP0309^KV`2SXj<0Xj>S0080Vi^K0P2][Jd20:6QX@80YJFU0P2PX:020:BTY080XJ6Q
0P2KVi/20:6QX@80Y:BT1P2QXJ420:BTY00309fMW@2QXJ40XJ6Q00X0XJ6Q0P2TY:@209fMW@80Vi^K
0P2SXj<A0:6QX@80X:2P102TY:@209fMWAD0oooo000C0?ooob/0XJ6Q0P2TY:@209NGU`030:>SX`2Q
XJ40XJ6Q00`0XJ6Q0P2KVi/20:f][@80WYjN0P2TY:@209NGU`80Xj>S0P2PX:0209jNWP0309^KV`2U
YJD0YJFU00@0XJ6Q0P2[Zj/20:RXZ080WYjN0P2TY:@209fMW@80Vi^K0P2SXj<60:6QX@80Vi^K0P2Q
XJ430:JVYP80WYjN0P2KVi/20:f][@80WYjN202QXJ420:^[Z`80WYjN0P2YZJT20:6QX@80WYjN0P2X
Z:P00`2QXJ40UiNG09NGU`020:>SX`80Vi^K0P2QXJ420:JVYP80YJFU0P2TY:@209fMW@80Vi^K0P2S
Xj<20:2PX080[Zj^0P2IVIT20:f][@80WYjN00<0Vi^K0:>SX`2SXj<00P2KVi/20:f][@80XJ6Q0P2U
YJD20:2PX080Y:BT0P2QXJ4209^KV`80XJ6Q0P2TY:@60:6QX@80Y:BT00<0WIfM0:6QX@2QXJ402P2Q
XJ420:BTY080WIfM0P2KVi/20:>SXa40XJ6Q0P2PX:040:BTY080WIfM5@3oool001<0oooo;@2QXJ42
0:2PX0030:BTY02QXJ40XJ6Q00`0XJ6Q0P2PX:020:JVYP80WIfM0P2QXJ420:VYZ@80XJ6Q0P2[Zj/3
09fMW@80[jn_0P2XZ:P409jNWP80Zj^[0P2JVYX40:6QX@80X:2P0P2TY:@60:6QX@80ZJVY0P2[Zj/0
0`2NWYh0Y:BT0:BTY00209fMW@80X:2P0P2`/;0209ZJVPP0XJ6Q0P2TY:@20:JVYP80XJ6Q0P2MWId2
0:2PX080YZJV00<0WIfM0:VYZ@2YZJT00P2[Zj/20:NWY`80Zj^[0P2NWYh20:BTY080WIfM0P2QXJ42
09ZJVP80YJFU0P2[Zj/20:6QX@80Vi^K102VYZH00`2WYjL0Zj^[0:^[Z`020:NWY`80Y:BT0P2MWId2
0:BTY080WIfM102QXJ420:VYZ@80Zj^[0P2NWYh60:6QX@80Vi^K00<0Xj>S0:6QX@2QXJ40202QXJ42
0:^[Z`80WYjN0P2QXJ420:2PX080Y:BT0P2[Zj/209jNWPH0XJ6Q00<0Zj^[09jNWP2NWYh00P2[Zj/2
09jNWP80XJ6Q0P2[Zj/209jNWP80XJ6Q5@3oool001<0oooo;@2QXJ420:2PX0030:BTY02QXJ40XJ6Q
00`0XJ6Q0P2PX:020:JVYP80WIfM0P2QXJ420:VYZ@80XJ6Q0P2[Zj/309fMW@80[jn_0P2XZ:P409jN
WP80Zj^[0P2JVYX40:6QX@80X:2P0P2TY:@60:6QX@80ZJVY0P2[Zj/00`2NWYh0Y:BT0:BTY00209fM
W@80X:2P0P2`/;0209ZJVPP0XJ6Q0P2TY:@20:JVYP80XJ6Q0P2MWId20:2PX080YZJV00<0WIfM0:VY
Z@2YZJT00P2[Zj/20:NWY`80Zj^[0P2NWYh20:BTY080WIfM0P2QXJ4209ZJVP80YJFU0P2[Zj/20:6Q
X@80Vi^K102VYZH00`2WYjL0Zj^[0:^[Z`020:NWY`80Y:BT0P2MWId20:BTY080WIfM102QXJ420:VY
Z@80Zj^[0P2NWYh60:6QX@80Vi^K00<0Xj>S0:6QX@2QXJ40202QXJ420:^[Z`80WYjN0P2QXJ420:2P
X080Y:BT0P2[Zj/209jNWPH0XJ6Q00<0Zj^[09jNWP2NWYh00P2[Zj/209jNWP80XJ6Q0P2[Zj/209jN
WP80XJ6Q5@3oool001<0oooo8`2QXJ420:^[Z`80WYjN0P2[Zj/209jNWP80XJ6Q0P2KVi/00`2SXj<0
Vi^K09^KV`020:>SX`P0XJ6Q0P2[Zj/209jNWPH0XJ6Q0P2TY:@209fMW@@0WYjN00<0VYZJ0:RXZ02X
Z:P00P2JVYX209jNWP80X:2P0P2VYZH209fMW@H0XJ6Q0P2KVi/20:>SX`@0XJ6Q0P2TY:@209nOW`03
09fMW@2[Zj/0Zj^[0080WYjN0P2QXJ420:BTY080WIfM0P2[Zj/209VIV@80Xj>S0P2[Zj/20:RXZ080
XJ6Q0P2MWId70:6QX@80Y:BT1P2OWil209fMW@80Zj^[0P2NWYh20:6QX@80X:2P102TY:@209NGU`80
Xj>S0P2QXJ420:BTY0D0WinO0P2VYZH209jNWP80Zj^[0P2NWYh20:6QX@80Vi^K0P2UYJD20:VYZ@80
VYZJ102QXJ420:^[Z`80WIfM00<0Y:BT0:6QX@2QXJ40202QXJ420:BTY080UiNG0P2SXj<209^KV`80
Xj>S0P2TY:@209fMW@H0XJ6Q00<0Y:BT09fMW@2MWId00P2TY:@209fMW@80XJ6Q0P2TY:@209fMW@80
XJ6Q5@3oool001<0oooo8`2QXJ420:^[Z`80WYjN0P2[Zj/209jNWP80XJ6Q0P2KVi/00`2SXj<0Vi^K
09^KV`020:>SX`P0XJ6Q0P2[Zj/209jNWPH0XJ6Q0P2TY:@209fMW@@0WYjN00<0VYZJ0:RXZ02XZ:P0
0P2JVYX209jNWP80X:2P0P2VYZH209fMW@H0XJ6Q0P2KVi/20:>SX`@0XJ6Q0P2TY:@209nOW`0309fM
W@2[Zj/0Zj^[0080WYjN0P2QXJ420:BTY080WIfM0P2[Zj/209VIV@80Xj>S0P2[Zj/20:RXZ080XJ6Q
0P2MWId70:6QX@80Y:BT1P2OWil209fMW@80Zj^[0P2NWYh20:6QX@80X:2P102TY:@209NGU`80Xj>S
0P2QXJ420:BTY0D0WinO0P2VYZH209jNWP80Zj^[0P2NWYh20:6QX@80Vi^K0P2UYJD20:VYZ@80VYZJ
102QXJ420:^[Z`80WIfM00<0Y:BT0:6QX@2QXJ40202QXJ420:BTY080UiNG0P2SXj<209^KV`80Xj>S
0P2TY:@209fMW@H0XJ6Q00<0Y:BT09fMW@2MWId00P2TY:@209fMW@80XJ6Q0P2TY:@209fMW@80XJ6Q
5@3oool001<0oooo8`2QXJ420:j^[P80VYZJ0P2TY:@20:JVYP80WYjN0P2PX:000`2TY:@0X:2P0:2P
X0020:BTY0P0XJ6Q0P2TY:@209fMW@H0XJ6Q0P2KVi/20:>SX`80X:2P0P2TY:@00`2PX:00Y:BT0:BT
Y0020:2PX080[Zj^0P2NWYh20:^[Z`80WYjN1P2QXJ420:2PX080Y:BT202QXJ430:^[Z`80VYZJ102Q
XJ4209^KV`80YJFU0P2KVi/20:j^[P80Zj^[102MWIdA0:6QX@@0Zj^[0P2TY:@209jNWPH0XJ6Q0P2P
X:020:BTY0T0XJ6Q0P2^[Zh20:BTY080Zj^[0P2JVYX20:6QX@80X:2P102TY:@209fMW@@0XJ6Q0P2T
Y:@209fMW@T0XJ6Q0P2[Zj/209jNWP80VYZJ0P2UYJD209ZJVP80YJFU0P2QXJ420:^[Z`80WYjN0P2Q
XJ420:^[Z`0309VIV@2SXj<0Xj>S00`0XJ6Q5@3oool001<0oooo8`2QXJ420:j^[P80VYZJ0P2TY:@2
0:JVYP80WYjN0P2PX:000`2TY:@0X:2P0:2PX0020:BTY0P0XJ6Q0P2TY:@209fMW@H0XJ6Q0P2KVi/2
0:>SX`80X:2P0P2TY:@00`2PX:00Y:BT0:BTY0020:2PX080[Zj^0P2NWYh20:^[Z`80WYjN1P2QXJ42
0:2PX080Y:BT202QXJ430:^[Z`80VYZJ102QXJ4209^KV`80YJFU0P2KVi/20:j^[P80Zj^[102MWIdA
0:6QX@@0Zj^[0P2TY:@209jNWPH0XJ6Q0P2PX:020:BTY0T0XJ6Q0P2^[Zh20:BTY080Zj^[0P2JVYX2
0:6QX@80X:2P102TY:@209fMW@@0XJ6Q0P2TY:@209fMW@T0XJ6Q0P2[Zj/209jNWP80VYZJ0P2UYJD2
09ZJVP80YJFU0P2QXJ420:^[Z`80WYjN0P2QXJ420:^[Z`0309VIV@2SXj<0Xj>S00`0XJ6Q5@3oool0
0?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool0
0?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool0
09D0oooo0T0000290?ooo`00U`3oool00d000000oooo0?ooo`260?ooo`00OP3oool2@00000@0oooo
00=000000?ooo`3oool0103oool3@0000080oooo0T0000030?ooo`=000001@3oool00d000000oooo
0?ooo`200?ooo`00OP3oool00d000000oooo@00000020?ooo`03@000003ooom0000000@0oooo00I0
00000?ooo`3ooom000000?oood0000040?ooo`04@000003oool0oooo@00008P0oooo001n0?ooo`03
@000003ooom000000080oooo00=000000?oood000000103oool01D000000oooo0?oood000000oooo
00=000000P3oool014000000oooo0?oood0000280?ooo`00OP3oool2@00000<0oooo00=000000?oo
od0000001@3oool3@00000040?oood0000100000@00000<0oooo0d0000280?ooo`00OP3oool00d00
0000oooo0?ooo`020?ooo`03@000003ooom0000000L0oooo00=000000?ooo`3oool0T03oool007l0
oooo0T0000030?ooo`03@000003oool0oooo00D0oooo0T00002B0?ooo`00o`3ooolQ0?ooo`00o`3o
oolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3o
oolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.0250052, -0.0250052, 
  0.00365857, 0.00365857}, {{6.8125, 280.125}, {280.125, 
  6.8125}} -> {-10.161, -6.11446, 0.516914, 0.516914}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0238095 0.952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0238095 0.97619 0.97619 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00751202 0.0192308 0.00751202 [
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(120) show
81.000000 12.812500 moveto
(deg) show
99.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(.) show
105.000000 12.812500 moveto
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
128 string
128 128 8 [128 0 0 128 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
7273787670737172786F735F6666666A65666666667A6E38
6F6860625D64635C656362635D5F64636765626362636363
5B6663636967676767676764686163656861636363636263
636363636164636263636272766940685F64635D5F5F6362
62626262686562666C656B6969646B6460625A5D605F5E5C
746B4F6C75767770
7275736A6E7B7E777177777B6F67676463666665655C6450
7C686062645E585B5E606363666A60616861606262575860
66605F635F5B61615D5C645F5E6766625E5E636664636263
63646363646259606362635C607356455967635D5F5F5D59
61656565686066636160625F5F6966626062666B635F6689
8B52536271766F6E
706F6D72746F6B6E7370767E837065656562646561646F84
3A4860635C565D676966636263625D58626665625C5E605A
52535557606361646363605E62605E696E6E6B676B666364
6363636363636768636363635C5280A94848585B6768615F
645A5760676769676966666C706C646362636463646F766A
696A65606E6E7876
7575777D757B7E737A7E736B6D798B776365615E5F61596A
81755A616563625C5858606363625D60645E60635E66605A
5E625E595960626160626362626268726A6768716C6A6B6D
6E666364646464646463636363615B6D8F565A6B68646770
6A666C686660646165676E6D6862696362626A6482786B78
545E63607C74676C
7275727177756F6F7976787D767B777C756B6A6668656C7B
76566966695F5F5F67615C606263656A68635B595B64656C
6D6A655F605C605753535F636464625C615E5C686B616564
656464696A6564696A6A65696563615B6D5A635D686A6A63
6063686A68686C6868686C68696B66656B646F8883747E7F
667C585A797F7D75
727470746F6D737A706D6F6A757A737B7F7969696A68685E
68807869696468615C636867645B58605A525A605D636363
6363666C6259555B5C6861606363636360626D6A59616865
66686A6C66686A6364616162606865615B7E78575B656667
65686868696A6865686763666969655E585568707454564C
55785A758C787172
727A7D7E727A7270727C71797C6E757978828A766E717070
69726C6665696B67685E5958565A584D5058595A57636369
6A6A6A6D696D60615F61555A57545E626362635D5E615D5E
5F5D5C6364605F61615F6262625F5F635E607B9272605E5E
5F666467676466656E686C6C695A574A44577F6F6F596565
685C4E7E80727874
72706E6F727A747C736E6C706B7675747676737B7A747474
71697575365361615C5B5F5F5F514F5C605C5C5A595E6061
6465656861645C5B565658615A5755505657565C5A575958
5F595F5E545A6061595757575758595F5B55596960616163
63625F646665656D6E64646158533E45536A6A5039425F54
66615A7976706F6E
727B74787B79706F71767C79736E7474747670797A878583
8A8D827EA279586263615F5F5961606563666D70695C5C60
66656564686B6861646D63626365655D594E4C4A434B4B4B
49434846494B4746494D4D59595C5E5B5556553B516C4C2E
3D53575E5D5C64645F68685E343550635B53575B62655B76
6F5571807474726F
7E75777373767978756F6E6D717479706C72707873797271
7670707279866B3D6161525B616158574F5458595C5A5F63
61676669655E6160635D5E6962676A6C6970706D6D686965
64666C65646B6B6C6C6B74725E696A6A646D6564645D6D8B
7F193B4D535E5E5B442114172E606E6A5B656359696A5368
674F706B72757B77
686C7670726A6A6F747B74747C7D7571777A737972777074
736E78737271554A523F50615E5E61675E5F6060605A5F64
63605C6263676A66626066666566636365605765696C6D64
6365646A6F6660615F676763676A5C605E65656B695D5E5E
678EB55A3A2D3829223C43495C535C514D88695D5F436983
55746E73756D6B75
80767076747A7F72706F7778776E7573737276717579797D
73716E6B746F5B724D4E553D535F5A5D546061585D5F6165
62626361645F636165625D606363636363656A5D585A6065
6A605F5C555A66685D636363635C5C645D645A5F6265675A
5655606C8B822D204041435550473F465C763A4860506763
5582818573777479
6B767D726E786E777F7D7275797371767D7B797173747670
6F72767573726265584C5036213B5B5C5C645A5F5D575D65
636362626661615F6365686663636363636363606260645C
5A63605A60625D585B666363635965665E5E5D65635B585B
5E5141331C122F50453E534D4B4D6364585E485D5F527861
647C727A6D797E75
7E756C70747870786C7270786E75737876766E707A796E75
7471717976736C83804C4537391E41525F5450585E616165
636363636260636363635C5A5A5A605B6063635E60605D5C
5D5A5A626260605E615E6059595E67635E5D5F5D5A545C51
4C433F2B2A435653584F3F484F5C62586656415653666A5B
6D82777375786F6C
6B6F7A777077797B727973717672767B6E6B7072766C7575
6F7B79736C7260775A3B3C3A342A122D515165625F595C5C
606363635C606363636365686266605C5D606365685C585E
6062625C5E5D595B5D5A635F68625B606562615D5757524F
4949392E4C584346574D4A4D5B4C51494C4968726A83535C
837E746F706F7777
73726E6D72796C6B6C77787C7376736C76757A767177746D
7973757573726972576749493B2D20163A595C515D5F5C66
6763636365605A60635C5A5A5C58585F6666635C5A5E625C
5A565D61625B5E555B5E5F5C5D5C605F574A49453F3F4145
371F163D655633484C5E6969493E45485C55635E86615B7E
7A69697177737972
6F7A78737A726E767C766F747378737B7A73797273717678
706B716E7472796D6C523C43302A282411335E525F595E61
605C5A5A5A63625D605E606662615E5C5C5A5862625A565A
5A5959555A5859555650575E525B4E57575653524F493B2B
18263B554F484F665A594B4B584F4D5B5757646054527380
78656C7775737878
756F747C7B6E7A7D7970707670716C706C6D76787C777376
74737374736A685768373A412F2B302B1E07245357575A5D
5B5B606060645E66605C605D5A5F615E5A5A5A5D5C5F615F
5B5E5751525A5756615B6159545157574F52524D402F292B
32435A624D444C56483935433F54655D5467686066858671
6D7D817F7B7C7B76
6F7A76747679746E747878716B737B7E7C7E756C6E707477
737676727178736670414642352D2E27181B0A3058635E60
5E606060605D63665E6060606061605E60635D5E595A5858
5A5B575A5B57514F5054525C505555524A4E4A341F2A1C34
46505A4B454D4858555B616563605B596A6A605F6D6B626F
7A76797574706C73
807C6E767074787C746F6C737C756C6D6F7478747579736E
6F797572736F6A6A633D44353137301F17142080585C5E61
5F5E656266625D5A5C605A5E605C5E5B5E5B575952585A5C
5C565655504E4E5259655A46414948493E3E3037232F3745
30404B414246555658635556695E5A6667605E6F766C7F80
817F75707770797B
76707072706F736E7573727B79737C7678746F717A716E7B
7D74767475727062423A443D333D2E2C20212D1F3B636168
615E655E5D5C6060605D61605759605E5D5B605761575961
5D585952534548596A58383F4E494D4738392C2B484B5152
5B65574C4E4C544342444957474062665E5E6C757B7C807B
7269747B74717970
7678737A747473777A717B7B767871707870736F6D767572
7470716F6F686B5A4C3D4137413F2629222C2D1665616065
5C5E5E565A5E5A5A5E605D5A5E5F5B5F5B5A5960555C5852
4F52504B434C5469663B425754463528233C3A3837424936
434D4C484434594F63506B5655706E5E5E66657778707777
6E7B7C7670787978
766E7673767D7B797673787676767373777977757377737B
716D797C766E6F46494038332F2D222A3337220D7E605D5B
5C5F605C5C605C5C5A58595C5E5F5E595C5D5C5150545557
56584E4C45445B5C343241403A3334273749393C3E393135
4A4F4D4546575E464F464348584F595F6075908370757E79
747A766E70717376
76797B70787670747076747476767876736F70747B7C7277
707B7B76706C5F464940413C3D272130342A1D208E5C6962
585E5E5E645D5B605E555A5D545051535B515354585B524F
5048493D424E513E384346443B292F383F534A4C3E39524F
4E46444B685F54484A494D5067727462767C717071737169
747970777D7C7B76
767074797B70707778747679767670767574797B74747272
71736F6D6E6D634F4740393638303347311819187C5B5D4D
5B6360544F575A5351555351555554584F53534F51505054
4C4C4946465446332E3B3639293B413C3C43494D404B453E
4A38444C5B5A604E4D605152655E6273858477736D76747B
7C76726F6E6C6E74
76787970747875777678747476767879787B797672777274
797370797D6F513E4D483C393A26362D1E15211A7F5F6163
66585D605C5F56535855515550545350515857554F4B524D
4D514B424F4B35333C3732273138242D3A53504B594B433C
3647574453554C4460645163695E737B75626673797B7578
7074787C77757B74
76767678746F76746C73787976707476767676707679726F
706C7A756D724845423E2C322B28392B23212B1F83535A59
5D5A5459575755575250534D4B514C4D5352504A4E4F4E4C
504443424F4237363333303C3E2C2D383C41464346444D3F
3E353D555A4A57636243475A6268786C6F7C7E6F73797577
7879767672797972
76706F74727477787C756C7376727776706F6D6D7670707B
7E777A6E715A444F413B37462D383A3118161B1F7F555C52
58595856545153504C524F4F524642454A4A4D4D50484747
42444446362A2F2F353C3E3530343D4340454C61616D5334
353D51424A5C5C55424349666E676F736C706A7C7C777879
7670747678717372
6F767B7470726E6B6E767C7B6E7574747279747B7B787B79
706E7170744F4944423B2E332C40271E13171E1D7B555D5E
605656514E505252504E4C504F514F4D4B474D4F49494D41
40413A42362F2A39363A3A1D1A21354A4C4846474A455755
47514C5044535744434D4C67648079717272747D6E6E7376
7076797670777B78
7B797678757A7D7E7D79767679737077707773787074706D
707A727361474F403932362E2C3426201D26252572515551
5353505657564D4C4F4847463C3F43414A4D4044494D4140
46463A4D3724383C332D1B1C163C55383D363E4D5A565F43
4C5A4C504E6043434144617777746868727A787874777876
7871737076747476
7676707472726C6E6F74707476787C797070706F7579727A
7C717172524644343C353636322F1A1C1D2121206F575867
5F5B595E595B5F5D5B554A3F47413F42423D474B3F3D403D
3B3237472C22363A251D1C28384245474243384B50584843
474746465E61485451696364846E687A76797D7A78757776
76797B7879727770
6F74786F6A77767B7B747077766E73707776747378767272
6C6E72695650453B3C3834432D30112422221D32796E7773
6F74756A6668605E61606260453E4140403C393640413C40
3C3637412027392C1F1A1E42293448423D353B50515B6068
54523C2F5556474A5C616896816E7A797677747074787976
707476767678746E
7B746F78807C727776787B797673797874777C7177707673
7175765846423F3C3C2A302B3025162A26221E5D9772746B
6864646B6F6E6364625C5A595D5D473A3D424546373A4241
3C39303B2D3E4C241D1C2B4726393A3F37373F4744565855
514E384E5D484E586E4F5F7D665C6C6F79777770716C6E6F
767970747676787C
6F767377706D757173767676706E7770707770727A726F6D
7375745D4C414137353C3A3036141E2E201F6ABA93746B6B
68716B6C6764666E62615D5D595C5E60433A383843403F3A
3233261C3A344E1F1B12163943343A52395345495962656C
603043504D404C5D584E927B5872817B7D7872767D7C7D75
7274787976707476
7B74777A787C7A70726D7376787472767572707477787C7E
756A554E41443B2F292E323025142D2C1FB1D38D6A6B6B6B
6D6E6163626B6663666D665A585F5B56574137363A343834
3533212255225039252F182340243D42344A494D4C4A5E60
524A46444C4C615D56687B5E6B7E74797273737876706F76
7572747676787976
767879766E7376797D7C7A766E7073777875797B79767670
6D6D5B523D413C3935372E2E1C1B281D57A46C5F6665676A
6A6A6C7368635F63645B5561645C5A59564C633E34363634
302726254B43503A1C11254953565E494D3A454A4E525459
624539483D47646961545870857F777A7378727770707979
787B747476767074
6B737074797B6E73706F74707175727870707073766C7270
70645A4B40463A33262C252F141F2739A78A666A6C676B5E
665E5B676265626263666C5F5A5E59595959544C3936362E
32262616355C264D3F5B263A223E2F3C414D4C4C3C58485D
6F433B4B4C5A4F4A4D64827D6D706F707674767972747770
6F74727274707679
7679727776767373767B797875747A75767B7C7A76797667
69585C433F3336302F332C1C19323AAFA0686A676762605C
5C5A605C59545157605959575C5356595A595552593C2731
28261E1F2F43423D54284B403B40413C3F492A3F47574D57
4660583941514756677E8B6D7277717A74707770767B7476
7577787B74767976
7B79727776767279746F6F6F767B7476746D6B6E6F74786F
5F5A4D3A37362E292F31161B1E1C9EA36B695F5C5F5E5850
4B49464545444D4D494854575B5F62595754525458584E35
292A2522272D4A58415F604925334B484A313E48564F4E59
687041566950435962886F767D7371787875777071747272
7679767678797670
7670767976707679787B7579797678797274767B7B746F6A
63604E45393C38282F2A1A222FBCBE6A6A64626361584F50
4D4841414143444D4B4F544C575B5C5758545451494A4C31
24261E141D34563423573F5652413348463E524457495E50
4D5D595F524F596264766D7A70757C76747871767D797279
7970747676767678
767277767076797676767277767676767875726F73726F5B
58614331342F322B281A1D252A81635E5D5D6062572B1F2C
323C42454545332B27283F5558595B5E5B5A5750534F4551
2D1E1A131E2C375559525B5A5B64563E41503733444E4153
5E5F61505C4C4F69736C6B736B6E6E75716E777574767874
7478747476707476
76727770767474767676727776706D7376727A7D73756D67
6B49393733312D222C26222BBAAD62626268653B2D3D5690
886055677B55505451483A435356595D57585957534B4C49
4B301717152D0F4A6931533554624E4E592F434B4D4A4B54
52646743363E53537B837F756D7D7F727075777277706F76
7970767970707770
6F76747674767474706F76746F7074736F6E777670785C54
3D313537252A263216191F5A98676A6562615F3A464B4533
202C422F211C292C4F45442F46595E5B5E625A5250535052
4B4827260F1B355839394D5A4B508357364453343B4B4B51
4D5F5D48525A4A557D70766D6D7B76797D7B797874767B79
76787976787B7978
7B79787972727674707477727474797B7574787071735F59
4345362A2331281821203AB093666060623C2B221A161E2E
282528231F161C23111118161D2D535C5C53535A52515257
474134100C2428253C602B4A374F5976675E354649474435
53685E655C62556776726D707B7372767074707478797676
7676767074707476
6F6F6F7478757276757974767579746F7074726E736A5F55
3E3527222E2A242B2E2BB9A960636A666264876757574948
3F4C5C464850544E4F85929AA1896C5C5657595A57535150
4E4C3F21110D192E394C553A48415A5A733D42503F4A473E
60515A6745564F808A746C6D7375756F7679787970747670
7476707679727776
7B75747770767B79727772777879787B73787570716B5B48
352C33332A262327262E8A5F65685F63646C757EA7B8AEAB
BCAF9FAAC4B4AEA2978F706A6764605D5E5C575752585350
4B50452F1C0A3B2C292D372C442C384E5A4E614C3B374355
5A415D63494F3C76756E6F6F7C7B7B757776767678797076
7474787970767976
6F767B797879707478797277706F7476737170756D4C493F
2F2C25242719262A258FA56869636A64696566676B646D70
705F63615A4D4F53595F5A616D615B615E595B5954554F45
484D3D3013142E2B56465C332846555D5A716A4849573F35
314368634A5F508A76666B787D7676727776706F6F747879
7879767678797670
7477706F6F6F76727376787972797474727473737764412A
253528281C282D2829927461646965636A676B6765636563
625D6362625961655E615B695A63615B54565E58544F5656
504D473A28260E24252627303A453444595A3C4F4B473A4E
3E57575752464B7669716477757476727770767B7B797074
7676706F74767678
7B7476757479797875747676787978797875747350493D35
35242C1F271D252A1E8161616767686B6566686767646667
5E5E545E554F585C5A5D61685B5B646F62615A575557504C
4841413E2713172E373E40503B2B27493C3D6D6B3F493250
4E5E4D5F524077807470767F767976787978747476767277
7074787B79767676
767879787B797676787474767676706F6F767B6C53413C30
2F3627262C2A2D1D5A9A6063696867676F6C64666768605C
5048444E4B4D5253575B605C646E6A57585D585652554F51
54534437302127252E26372D382A352152784A4346544042
41514F655A4C885D77737F81797676767074787976767874
7077767074767676
6F74767676767074707077767074787B73777074573D2D28
2423231E1C26291C978A6566696767676563646767676157
515D50514F4A4F5453595A5E595F6266616A645D5A574F51
50414344311C071023293A263E363B2461333D7C52494C46
494143625E6B77686B4F7276767676767277767676767678
7B79767277767676
7B79767676767874767B797076797676787A786B42342823
271D25252D2A1A188761616167626B6F696768646A3E2454
706659281A2F4C2F3C515A686A6A6464675D55575A555853
504E493736260F191B23282A3A35293C2C3264484B49452A
393A556A5C8956714F808E76767676767879767676767676
7676767879767074
6F6F74706F74767879706F767474767676767060352D2D38
29292123291E193594646A6E726A6366606563676E738E88
6868626E8D87786854495A676463636357636D645B59574F
494944463F34090E1420293129382A2F0F614C3E673A4535
404B5050605C404E7F9E7074767676767074767676707476
767676706F747879
7B7B79787B797074767274777879766E7376786137292B18
1F2B262C2C17185288656662686B71706C6B6864695F6D73
716968635E5C56555D63676763666463675E54575D5C5A53
4848433E363408150F2B3139223728321A5C3B606E374A3C
48474A5C676160778F767277767676767879707476787976
7676767875777676
767676707470767970767577766E7373737470592A262E2E
2D282A2F251520A2906C6B72706A6869686C645E6B6E7073
6C62625F5A545658545E64666367636664666D615E5A5A56
5852473F382D1605122912302D412029364A415A4D4E4549
403E3A54685369958E767879767676706F74787976767676
7676767678797676
767676787978797070777272747875767B79702D1A301B1C
21272A270E16127F676861696968696A6A6A6D6E6A5D6566
63676452494F565058636E6B64686B656162636761585959
5854473F3D3B2C0A101E36362E37252F2439474856703D3D
334155796E415F807474706F6F7476787577767676767676
7676707476767676
6F6F7476767074787B79787B74747277767670302B241B32
2F2D280A131621936A70706E676868676767696B64656367
605B5357545B5B5B65706B6363646762676463635B605C5A
5257514C3E3729091D1A2222292737312E4A4F4F5C713B3E
333E40515C72A78E7879787B7B7976767879767676707476
7676727274767676
7B7B79767076797676767670767476746F6F71352B242A32
26272A18151896B5686A686969697275756C6A696D6C626B
6D655A53565C60636768696666666E6A676364635B5B5D59
534E4E4638363714091A172C36282F372F3E585B5F6C2F4F
2E473C6B7568837976767676767676767676767676787976
7676787B79767074
6F6F6F7478797676767670707276797274794E1E28222D2E
2A29130E0EACCD776E766B69726C666161646867676B6B6F
696368625B60605C6066626D75686B606E6C6C66676C625F
5B57535646393427222A302E362E3B30273F6254585E3E3E
213F3F626A878D7676767676767676707476706F74767074
7074767676767879
74797577767676767670767B757776787B79181324162E26
252A1625279D696B6F6664727267696A726C6969696A646A
696D695A565E62646262676F636B6F6E6561666866645F5D
575A5250403D302522231F2D2C35392F43595E4D4D4D3D34
2344556677857C7676767676767676787976787B79767874
7679767074767676
7477787976767676767879767277767670742C36251F382F
2A2320185BA46B6E686872726465696A676472756C686C6E
685E5E5856565D5F68696964626A685F5E6F6A6662636663
58585452443B2F2B1A192027273535362F5B5C5050545D3B
414A42598882767676767676767676767676707470747678
7976767879767676
7B7970747074767670747676787976767874273B2E2B2428
2A192437B094696A696966616468696961666661646A6A5C
646C73615B595D5E5C5E61646664676671685B5E6063615C
635D52504F443B2E2621221F2D323228236754474E4C5725
3C40435C8379767676767676767676767676787978797074
7676767676767676
6F7478797277707472777676767676707434122B2635322E
1C1B27A5B7656B6D696969726C696A625D5C5F61686A5E64
6E696A635A5755505A505B645F6A6663645C5E636363635E
5F565A584946383028162021273C3230355E405055285A1C
344E5B648C7A767676767676767676767676767670747879
7676767676767676
7B79767076797277787976767676767277244345253D2629
192A2E8362596A68726C69676463604F5861605E62676469
6B696A6050565155545F6C63685E5654585C606062646162
575F5B5252483C312917131E29303332315C4C4C4E1D5928
34445C7B9376767074767676767676767676767672777676
7676767676767676
7676767277767874747676706F6F6F76791444293A342F29
143F97A44F5C6F69666469625D5C5E635447535D6062595D
67686A54504D5453515760615754504E4B47404648535859
5E635652484239392F280F181E302F3A2D51523A3B1E7B34
2A5764788776767879767676707476767676767678797676
7074767676767676
767676787976767879707472797B7B797F2D47212D273210
2E317E423F6B6E686969635A482D2234413C4D4C64696365
6D6B6A64594D4948675E66514B433A2D2D3D4445495E5F52
4E4F51524E46412F282725221C2D29312E4C3E373E2B7C23
2660516E8979767676767676787976767676767676767676
7879767676767676
6F747676767074707478797879767676271B3D202A23311A
3C999343596E6466695D482426566927162B4739304D6060
6C69695F5B5058494B110E1F446E361930322B2C32464B51
585950514943373634283218162F2D313B4E4F3B4029732B
4677618B8170767676767676767676767676767074767676
7676767676767676
7B7976767678797879767670747676762E5140361929361B
1473595764736E6758482A377A952920263534494D5B465B
6E69615D595446383C593581B12C1C335028553E2C36484D
5557524D4F423A3728241706113033213649412D3B386D19
566D578F7F76767676767676767676767074767874747676
7676767676767676
7676767676767676707476787976767F9C521C1D16312B2F
459E4C445365605B4B35260E2D412B7D0A2F192533405671
6F6966625E614B47343D5536371374092221590C193B3F3C
4C4E504444413C2C282A110E15152525483A363E4837631F
514E69927676767676767676767676767879767678797676
7676767676767676
76767676767676767879767676767620262C3E312C342D35
55793E4D5D6A6853463C1A31370800051B4E355058707670
676765615F5C58524F3F2B42450C080B211D151E3746443F
46494C463F38262931272216252821233B3C362C3D3E672F
58548B8E7676767676767676767676767676767676767676
7074767676767676
767676767074767670747676767676263F402B2038322527
4D5F49535B695F616C6C6956372E383C3440597A8382716D
6D6D6561656B645F5F59532D314F694F2F23284A66634F56
5D55464948392C302B2C2719221B192441473D35454F6831
515B8A7C7676767676767676767676767676767676767676
7879767676767676
767676767879767678797676707476925C24172023201C3F
574945455064686D787C839CA7ABABB1BAAA74625B64726E
69676B6C6B6559494F496179835F59647994A0907F777669
5D534C43434131352D1C1B16202D2C233B4E37324F536334
5694AD7F7676767676767676767676767676767676767676
7676767676767074
76767074767074767676767076797F89111E141C1D3A1C2B
34464A4155715B636C6C717679805B341E151B59757E726B
756C6A6A697265604224232030698B908D7F766D68635A52
433444463C35363129301A16171B102634373033514F6C3B
5C8B7C707676767676767676767676767676767676767676
7676767676767879
76767879767879767676767879766371112517222B2F2643
3E3D3F424F655E5A576568685E231722326AA3A17770716C
6E676A6A6C6769706B593222222134485B666B6063564E40
2E4B4A3E3732352F1B19131D1914314042473C2F4C445446
5D937F767676767676767676767676767676767676767676
7676767676767676
767676767676767676767670747F38691E282A2F1A2A2832
2D28343E516B6B3B33342C23101C5CA9C7B4937F7977716F
68646867696A686A768A95937045201711121D23231E2131
4E554B4B3C3738294214262D261A142E3C3F343352593F23
739F76767676767676767676767676767676707476767676
7676767676767676
76767676767676767676767277733E1804263B332C2C252C
2F343C3A5A6F677890624A4771B6BE967773716D6D6D6D6E
67697275746C6C6D6E6A6B7789A1B4B87A4C38353751655C
545751473A3B422C192327180B0B113B3E2B3D3C59542B49
A28B76767676767676767676767676767676787970747676
7676767676767676
767676767074767670747678797660352C294B4034322934
3334413E56696364687F9AA29B7E6F6D6D6D6D6D6D6E6D6C
6672726D64636768686B68696E666465698EA596857A6358
604B3E383741403B2C21110B0D0F1464382C683D3F59345D
9E7F76767676767676767676767676767676767678797676
7676767676767676
76767074787976707679767676764717223156382A303233
2E2F423A586A6868676C6968727569636A6D6D656A6C6C6D
68666A6464726C6A6B6A6C66676263605C6656565650504F
4F464E4D3D3C3C2B3C2A181A1621186443345237375B2F78
A47976767676767676767676767676767676767676767676
7676767676767676
767678797676767879767676767663273F3C3C2A383A312C
2A293637465C60646563676A666A706D6E6D6D6F716D6D6D
6F74727075696468636161656A616261665F5B5D565A5756
5353513B38453B392313201F0F0D11603C39653C304A2BAA
957076767676767676767676767676767676767676767676
7676767676767676
76767676767074767676767676767F2F2C25242B32272C2C
312E484A58685B6366686C6968666A6F716D6D65636A6D6D
6D6D64616164695F636767635D5E635858595F5C56585554
44463F46463D3325211E28120D0F20435354623D3E2F5FB6
797676767676767676767676767676767676767074767676
7676767676767676
7676767676787976767676767676811B3830383D3C373230
2D36404C525A5D6A676D6D696A727265636A6D687171646A
6D6D6769696A6B6E726967646263635B5A58585959595253
53504542434137301E281310141016404E2E464549358A96
767676767676767676767676767676767676767879767676
7676767676767676
76767676767676767676767676767C332D2C3D3A2B302A2C
3D393D464C5760636666616769676A6F6A676A6F68636D6A
626165696A6A69636765675F696662666563645D55565354
444845434432332F2821120E0909384138355B4F6C66BF8E
767676767676767676767676767676767676767676767676
7676767676767676
76767676767676767676767676767C154155332F31312E3B
202C45504855636566666D6D697171646D7471656D6D666C
6C6968696967696B6D6B606266606357615C585154585354
4855474434302A1F2B1A0D09180B3F3F382C4A484C88AA76
767676767676767676767676767676767676767676767676
7676767676767676
767670747074767676767676767673906125242927282E29
353D424A565F6465676E6D68696E6D686F656A686665716A
64686A6A6A6B6969695E656D6260635B65595C5657575A56
4F563F39363C3D331E170E10190F483B3D3555535D9B8676
767676767676767676767676767676767676767676767676
7676767676767676
7676787978797676767676767676768926262C242A2A242C
363B4F4D565C65656A6166686A676365666C716F746B656C
6C6B6A6969696A6A5E636A67616C666669605E5658515652
57493D47443129181610120A110E503A32305B6881987676
767676767676767676767676767676767676767676767676
7676767676767676
7676767676767676767676767676767361412E2E2F2D2F2C
29373F46515C656669686E6868706A7074726D6D646D6D66
6C6A6968696969696770696264625E6263575857585A5351
4647483C3A3C321B1B13170F1515514E324257679B907074
767676767676767676767676767676767676767676767676
7676767676767676
767074767676767676767676767676768738252428292C30
2B394A545F5F6A68616264686B6866686A656A6465686469
66646A6A6A68696965656067666163635B5C635F5958534E
5045433D382C261B1C16141A1C0F3E423756687C89767879
767676767676767676767676767676767676767676767676
7676767676767676
7678797676767676767676767676767678333F3134322B2E
313D384A5E6B64616B6C6E6D696867707166676669676868
696B6969696A6A63636764645F6062635D5E585454585458
4B414238342C231B1F1814190E094137314E63918B767676
767676767676767676767676767676767676767676767676
7676767676767676
7676767676767676767676767676767676AEA25B46404333
2E39494D4D5965686064626166686966636669706C696A6B
6A696468636161636D6466605F626357595E5A565F524F52
3F423A3B302721291D1C140E07246941425B5E8A76747676
767676767676767676767676767676767676767676767676
7676767676767676
76707476767676767676767074767676767C95BB4D382B32
37353B4E535863636369686E6D6567696A696A68656A6969
69696B6D6567676D675D5E5F646363605B585A5E57485343
454A3929222D241C1C15170C095E562B424C7A9678797676
767676767676767676767676767676767676767676767676
7676767676767676
7678797676767676767676787976767676736D7F522D2E28
3134434A525E60555F6064615D6265696A69636769696468
616160616367635B585E636263626259595C5C5455555157
48362E313231331C1B170E097469332F52759B89706F7476
767676767676767676767676767676767676767676767676
7676767676767676
767676767676767676767676767676767676767C671B2B4A
3445474B515A6166696260656A6F69636763696D69696B67
646E695F645E65636362636363625A5D5C5B545353404A47
3A3B3B3B2F232643150C1142383337435B708A7D72837C76
767676767676767676767676767676767676767676767676
7676767676767676
767676767676767676767676767676767676767C43353725
2A473F4B565D5559616263645D6862666663656161616760
605B585E545A5F5D62626263626357565855545751464839
32332D272A2E30182328372C49454A586F6B84837B767076
767676767676767676767676767676767676767676767676
7676767676767676
767676767676767676767676767676767676767C3E53242A
2D2A32424746565D5A5F5761666561605C5F65676D61605C
6060565154585E635C55585451514C54534C4E483E434440
3B413A282723242026195A4E4733605771A49A736B74767F
79767676767676767676767676767676767F797676767676
7676767676767676
767676767676767676767676767676767676767373881721
3D2E3C4445595E5458575764605D5D6564625E5D5A5A6060
5B524E535559584B4A4F50484E544C544E4F4A4C483F3D41
3D39292C322D41382D46613A45566B74717D747678837973
707676767676767676767670747676767673707676767676
7676767676767676
76767676767676767676767676767676767676767F453B41
3238373537434C635A5559575F6464615D59575757524945
484E4B4B45423F40464543453E3A3D403E3838423F403E2F
2734392E3C43262F44443930504860669199797676737076
767676767676767676767678797676767676767676767676
7676767676767676
767676767676767676767676767676767676767676937847
343337464C3D3936495B636C68595757574D4D454A5B504F
4E4E3F453B433D4C3740333733343D3A393C41364050454D
4C4A32334147331D2143514C5267715F857A767676767670
74767676767676767676767676767676767F797676767676
7676767676767676
7676767676767676767676767676767676767676767692C3
6E492C363A2844556B706E665B5B554F454A4F51524A4953
433F3C403C433E3037412F2D3E3840323438383B29232935
3236394329233047524A3B51787248929A76767074767678
797676767676767676767676767074767673707676767676
7676767676767676
76767676767676707470747676767676767676767676767B
39404B474C707B575A4445505550504E4F544145514A4146
45433E41324A3C524D3B4D49365045474640454B31384342
33384332393C3D333A4A727C605079A0767676817C767676
767676767676767676767676767879767676767676767676
7676767676767676
767670747676767879787976767676767676767676767676
A94A433C31333539455561564C4A524747473E473C3F4046
3C4A3C323C2C363A41373A38435729313247402E302E2418
1C2C2220272631426378854B4F35878E7676767370767676
767676767676767676767676767676767676767676767676
7676767676767676
767678797676767676767676767676767676767676767676
73AD75444663606272685C5B49454648474D4B4F413F4A41
3536264249311D33243C443F40242A461C152227282C393D
473C382F3A42826D70711C2D3574BB797676767676767074
767676767676767676767676767676767676767676767676
7676767676767676
767676767676767676767676767676767676767676767676
767345462B2D212B455356595149453E454940393F4A393C
472E564B295341303F34252E2427281723333B2A2C363027
21293E585F6F596870302E5F3EA48C707676707476707679
7676767676767676767676767074767F7976767676767676
7676767676767676
767676767676767676767676767676767676767676767676
76769E2A396A4D49484E574F4C34393A4A4B413442423B4C
3D4A2B283A2D3532302D2D2F2C282A2F31251E262E2A272A
39504B3F38516632192D6559A4B46F74767076797076797F
797676767F79767676767676787976737076767676767676
7676767676767676
767676767676767676767676767676767676767676767676
767673AD6418395E5B46565F5B394B3D38393534433F3439
313B29463837241B4529292E2C2C26241B1822231F294035
3749615F8C804D3C365A2F87BF8E79777678797678797673
707676767370767676767676767676767676767676767676
7676767676767676
767676767676767676767676767676767676767676767676
76767074AF66211F31425F5F54372F48444C5450363D402F
3C43323E403E3B1A1E244E312B1B2B251F1B1D1817242D4B
6C574E6446111C38463357B87C6D72797670747F79767676
76767676767676707476767676767676767F797676767676
7676767676767676
767676767670747676767676767676767676767676767676
7676787973714431263B47485740373C45362A32302D323A
362E41412D3C3F4248291E292E303A304A3B3941545D575A
5A825A492C1A37424F5AC8A8767676767F7B747170767676
7F79767676767678797F7976767676767673707676767676
7676767676767676
767676767678797676767676767676767676767676767676
7676767676848058452F1D292D5C373136433E332728272A
2E37392C2F4247404031543329434239383B525F735D5C7A
5B412F3C1E3C5E4A3AB8B97F8379707D70787B74747F7976
73707676767676767673707676767F797676767676767676
7676767676767676
767676767676767676767676767676767676767676767676
76767F7976768A6E433F464C464C5B43333F443A4F32302F
3A3A3C2846404B424F64422C34413D525A5E596C675D3C29
221A0D153A543E4ED6C47073767D7B767C79707879737076
767676767676767676767676767673707676767676767676
7676767676767676
767676767676767676767676767676767676767676767676
76766D6E76707492863A3749515453694A482A413C43452E
261C2A293F38534D8B96887D978B7E7891987B6F3B1D2A32
2425396167433EC9B4707F79736D707673707074767F8379
767676767676767676767676767676767676767676767676
7676767676767676
767676767676767676767676767676767676767676767676
76767879767883798DCB68391F325C63695353514C475A7F
5D333D2A3C566A573A45596979848972472A2D2A24343721
25414D5D3C4ACDC170707170706F74767670767976736D70
707476767676767676767676767676767676767676767676
7676767676767676
767676767676767676767676767676767676767676767676
7676767676767C747679B15833473A456C67718376988F61
8CCAFFF3DEB194788E8668686F4F2131322F30342B312647
64594B3CBFEDB57F747679767875777676787474767F7976
72777670747F797676767676767676767676767676767676
7676767676767676
76767676767676767676767676767676767676767F797676
7676767676767C747676739FD9422C3F40567B857A766877
825B4E4B506676776F6A5338493A47552B382D2D40537178
534264D1C26B746D70797676767879707476787976737076
78797678797370767676767676767F79767F797074767676
7676767676767676
767676767676767676767676767676767676767673707676
767676767F797C7D797F797689AD69443A524E4C51606E71
6E6D867D736F6C605F555B4B363C322C2E4D32536966573D
4EA4D5A876727778797F797F797670767976767676767676
7F797676767676767F797676767F767076737A7B79767676
7676767676767676
767676767676767676767676767676767676767676767676
767676767370736D70737070717FADEC6D32244A63716E67
62585F55544C3929263645404227305C55727B8D6C4257B7
DAB78576767883797673706D6E76817C7F79767670747F79
737076767F79767673707676767370767F837F6E74767676
76767F7976767676
767676767676767676767676767676767676767F79767676
767676767676767676707D7B797C74769AE2F16A333C4048
6471706B73786A716359425C8D719596835C3C5C94D4E7B5
7C76767F79767370767F7978797673706D6E767678797370
7F797F837F7D8379767676767F7976767C7A707C7C767676
7676737076767676
767676767676767676767676767676767676707170767676
767676767676767676787670767370767F797F9AD3714759
4241575C6A6A819FA0998E9575735B374673B0C59F867A6B
6E7676737076767074736B74767670747879767676767074
7370736D6D6D686E7F74747673707670716D70736B747676
7676767676767676
767676767676767676767676767676767676788379767676
767676767676767676767676767074767C6E6B6E7692BDB6
AEA8917D887D5E3F394E5F5D59648DBDC5AF967F767C7A75
8383837976767678746F76797676787970747F7474767883
7976767676767879737C7C7F7976767879767676817C7676
767676767F797676
76767676767676767676767676767676767676736B747676
76767676767676767F7474767678747473727B797676787B
858285888880899DA6A0A8A3A3A19481797F837976737674
736D6D6B747F7976817E79767F797F79817C6D7079707473
7076767676767676766D6E737A797676767F797673707676
7676767673707676
767676767676767676767676767676767676767678797676
76767676767676767372797676707679707D797676707470
71707F747476787B7B7B7F747670747676736D707F797C74
7676707F7C7C7D7973707676737073707C6E707770767976
76767676767F7976767879767C74767670717A8379767676
767676767F797074
7676767676767676767676767676767676767676767F7976
7676767676767676767676767678797F8579707670767981
7C76737C7C767F7976766D6E767879767670747F76707C7D
797678706E73686E7F797676767F797673727B797879767F
74747676767C74767F7976707170767678796D7474767676
767676767370817C
76767676767676767676767676767676767F797670717070
7476767676767676767676707D797673686E767678747D70
6E76767C7476737A79707679707476767678797370767376
74767076837978796D788379766D78797676767F7976767C
7579767F79737A79737A837B797F79767670767670767676
76767F7976767370
767676767676767676767676767676767673707678797F7B
797676767676767676767678767076767879767676727472
797F74717A79767370817C7F7B797676767670747F797673
70767879737076767876686E7678767076707D707879767C
747670717076737076736D70767370707478797676767676
76707A7476767676
76767676767676767676767676767676767676767F797370
767676767676767676767074767676767676767676727274
767372747A7D79767F706E737076767F79707077737A7474
7F797F79767F797F79767879767F79767678766D747A7973
707F7B79767F797F79767F7474767678797F79767F797676
767876707676706F
767676767676767676767676767676767676767673707F79
767676767676767676767883797670747074767676787B83
79767678766D70707A7579767676767370787B7970717C7C
7C747370707A6E7A74767670747370767676767883706974
76736B747673707C747673727976767F7973707673707676
767676767074817E
76767676767676767676767676767676767676767676736B
7476767676767676707D79736B747874707776767F837973
7070747676767076767A79707D79767676767F79817C6D78
766B747076767C797070747883747D797074707D767C7E79
767076797676767370767676767676737070747676767676
7676767678797370
767676767676767676767676767676767676767676767678
797676767676767678767076817C7F7B758183796D747476
7678797676768186797370787F7476767676737A76707876
70818685867973707672777F7672767A8586857970737076
76818679767676707476767676767F797678797F79767676
7F797F79767F7976
7676767676767676767676767676767676767F797F797670
747074767676767F7976767673706D6E7274686E78767076
767670747676736D707F797673707F74747F837670767676
76736D6D6D707F79767879736B7476736D6D6D7A797F7976
7071767476767F7B797676767676736B7470747370767676
7370737076737076
7676767676767676767676767676767676767C74737A7978
7978797676767673707676767074787978797883797F7976
76767879767676767F7F747676707172837F707076767676
76767676767F7F7D79767676787976767676767C7D7F7476
787973707676737076767676767F7972777277767F79767F
7474767676767676
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[40]:=",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`004`3oool2079bLP80Lg=c0P1hN7P207IfMP80L71`
0P1cLg<2075aL@80LW9b00<0N7Qh06m_K`1_Kfl00P1cLg<205mOG`H0IVIV0P1ZJVX206EUI@P0IVIV
0P1jNWX206i^KP80>3Ph00<0Kfm_06QXJ01XJ6P00P1PH602069RHP80GEeM0P1TI6@206=SH`80G5aL
0P1UIFD206=SH`80HV9R0P1SHf<205eMG@80GemO0P1TI6@206=SH`0306MWI`1UIFD0IFEU0080HV9R
0P1SHf<2069RHPH0Hf=S0P1KFe/206IVIP@0Hf=S0P1YJFT;06MWI`80I6AT0P1XJ6P2065QH@80Hf=S
0P1UIFD206QXJ080HF5Q201SHf<2069RHPT0Hf=S0P1QHF4206ATI080Hf=S0P1RHV8406=SH`80HV9R
0P1bLW8207IfMP80JFUY0P10@40206QXJ00305mOG`1TI6@0I6AT0080Hf=S0P1MGEd405mOG`80Hf=S
2P1RHV8206QXJ080IFEU0P1RHV8206IVIP0306a/K01UIFD0IFEU0080Jf][101YJFT206ATI080Jf][
0P1TI6@2061PH080HV9R0P1JFUX205eMG@80H61P0P1OGel205iNGP80G5aL00<0M7Ad06][J`1[Jf/0
0P1?Cdl206a/K080MGEe0P1fMWH207MgM`80L71`5@3oool001<0oooo0P1bLW8207=cL`80N7Qh0P1f
MWH2071`L080Lg=c0P1aLG42079bLP0307QhN01_Kfl0Kfm_0080Lg=c0P1OGel606IVIP80JVYZ0P1U
IFD806IVIP80NWYj0P1^KVh203Ph>00306m_K`1XJ6P0J6QX0080H61P0P1RHV8205eMG@80I6AT0P1S
Hf<205aLG080IFEU0P1SHf<2069RHP80Hf=S0P1MGEd205mOG`80I6AT0P1SHf<00`1WIfL0IFEU06EU
I@02069RHP80Hf=S0P1RHV8606=SH`80Fe]K0P1VIVH406=SH`80JFUY2`1WIfL206ATI080J6QX0P1Q
HF4206=SH`80IFEU0P1XJ6P2065QH@P0Hf=S0P1RHV8906=SH`80HF5Q0P1TI6@206=SH`80HV9R101S
Hf<2069RHP80LW9b0P1fMWH206UYJ@80@4100P1XJ6P00`1OGel0I6AT06ATI00206=SH`80GEeM101O
Gel206=SH`X0HV9R0P1XJ6P206EUI@80HV9R0P1VIVH00`1/K6`0IFEU06EUI@0206][J`@0JFUY0P1T
I6@206][J`80I6AT0P1PH602069RHP80FUYJ0P1MGEd2061PH080GemO0P1NGUh205aLG00307AdM01[
Jf/0Jf][0080Cdm?0P1/K6`207EeM@80MWIf0P1gMgL2071`L1D0oooo000C0?ooo`80LW9b0P1eMGD2
07=cL`80JVYZ0P1^KVh207]kN`80OWin0P1gMgL00`1aLG40MgMg07MgM`0207MgM`80Ng]k0P1_Kfl4
06MWI`80I6AT0P1SHf<406IVIP@0IFEU0P1LG5`206ATI080D51@00<0O7al06QXJ01XJ6P00P1PH602
069RHP80I6AT0P1NGUh205QHF080Fe]K0P1NGUh2061PH0@0Hf=S0P1VIVH206YZJP80H61P0P1QHF40
0`1XJ6P0HF5Q065QH@02061PH0@0HV9R0P1GEeL205QHF080H61P0P1VIVH2061PH080GemO0P1SHf<2
05mOG`80Fe]K101QHF400`1MGEd0G5aL05aLG00206ATI080GemO0P1NGUh206MWI`80IVIV0P1RHV84
05iNGP80Hf=S0P1VIVH206ATI080Hf=S0P1RHV8306=SH`80I6AT101SHf<206ATI080HV9R0P1IFET2
061PH080Hf=S0P1RHV8206=SH`80G5aL0P1PH60207=cL`80EUIF0P15ADD00`1IFET0IfMW06MWI`02
06=SH`80GEeM101OGel205eMG@80FEUI0P1QHF4606EUI@80J6QX0P1PH60206IVIP80Hf=S00<0HF5Q
061PH01PH6000P1RHV8405mOG`80JFUY0P1VIVH2069RHP80H61P0P1RHV8206IVIP80Jf][0P1SHf<2
05mOG`80IVIV0P29RHT00`2;Rh/0DU9B059BDP0205=CD`80HV9R0P1aLG4207IfMP80Kfm_0P1^KVhE
0?ooo`004`3oool2079bLP80MGEe0P1cLg<206YZJP80KVi^0P1kNg/207inOP80MgMg00<0LG5a07Mg
M`1gMgL00P1gMgL207]kN`80Kfm_101WIfL206ATI080Hf=S101VIVH406EUI@80G5aL0P1TI6@2051@
D00307alO01XJ6P0J6QX0080H61P0P1RHV8206ATI080GUiN0P1HF5P205]KF`80GUiN0P1PH60406=S
H`80IVIV0P1ZJVX2061PH080HF5Q00<0J6QX065QH@1QHF400P1PH604069RHP80EeMG0P1HF5P2061P
H080IVIV0P1PH60205mOG`80Hf=S0P1OGel205]KF`@0HF5Q00<0GEeM05aLG01LG5`00P1TI6@205mO
G`80GUiN0P1WIfL206IVIP80HV9R101NGUh206=SH`80IVIV0P1TI6@206=SH`80HV9R0`1SHf<206AT
I0@0Hf=S0P1TI6@2069RHP80FEUI0P1PH60206=SH`80HV9R0P1SHf<205aLG080H61P0P1cLg<205IF
EP80ADE500<0FEUI06MWI`1WIfL00P1SHf<205eMG@@0GemO0P1MGEd205UIF@80HF5Q1P1UIFD206QX
J080H61P0P1VIVH206=SH`03065QH@1PH600H61P0080HV9R101OGel206UYJ@80IVIV0P1RHV82061P
H080HV9R0P1VIVH206][J`80Hf=S0P1OGel206IVIP80RHV900<0Rh^;059BDP1BDU800P1CDe<2069R
HP80LG5a0P1fMWH206m_K`80KVi^5@3oool001<0oooo0P1`L70206m_K`80KFe]0P1bLW8207AdM080
Kfm_0P1[Jf/206i^KP0307=cL`1`L700L71`0080MWIf0P1nOWh208>3P`80L71`1P1UIFD2069RHP80
I6AT0P1UIFD2065QH@80I6AT0P1_Kfl208B4Q00303Xj>P18B4P0B4Q80080H61P0P1SHf<205aLG080
EUIF0P1MGEd206MWI`80JFUY0P1VIVH206=SH`80HV9R0P1SHf<2069RHP80GEeM0P1HF5P00`1RHV80
IVIV06IVIP0206EUI@80HV9R0P1LG5`205iNGP80H61P0P1JFUX2059BDP80De=C0P1EEED205MGE`80
H61P0P1SHf<2065QH@80I6AT0`1SHf<2061PH080GUiN0P1RHV82061PH080GUiN0P1YJFT406i^KP80
Jf][0P1WIfL206][J`80IVIV0P1SHf<206ATI0/0Hf=S0P1WIfL206QXJ0P0Hf=S0P1LG5`2059BDP80
P8200P2YZJT304Q8B080F5QH0P1KFe/206MWI`80J6QX0P1QHF4205mOG`80I6AT0P1JFUX205MGE`80
H61P101WIfL206UYJ@80IfMW00<0JFUY06IVIP1VIVH00P1VIVH206a/K080L71`0P1/K6`206ATI080
Hf=S0P1RHV8206=SH`80I6AT0P1SHf<206ATI080Kfm_0P1fMWH206YZJP0306UYJ@1ZJVX0JVYZ0080
IFEU0P1PH60406i^KP80N7Qh0P1fMWHE0?ooo`004`3oool2071`L080Kfm_0P1]KFd2079bLP80M7Ad
0P1_Kfl206][J`80KVi^00<0Lg=c071`L01`L7000P1fMWH207inOP80Ph>30P1`L70606EUI@80HV9R
0P1TI6@206EUI@80HF5Q0P1TI6@206m_K`80Q8B400<0>SXj04Q8B018B4P00P1PH60206=SH`80G5aL
0P1FEUH205eMG@80IfMW0P1YJFT206IVIP80Hf=S0P1RHV8206=SH`80HV9R0P1MGEd205QHF003069R
HP1VIVH0IVIV0080IFEU0P1RHV8205aLG080GUiN0P1PH60205YJFP80DU9B0P1CDe<205EEE@80EeMG
0P1PH60206=SH`80HF5Q0P1TI6@306=SH`80H61P0P1NGUh2069RHP80H61P0P1NGUh206UYJ@@0KVi^
0P1[Jf/206MWI`80Jf][0P1VIVH206=SH`80I6AT2`1SHf<206MWI`80J6QX201SHf<205aLG080DU9B
0P20P8020:VYZ@<0B4Q80P1HF5P205]KF`80IfMW0P1XJ6P2065QH@80GemO0P1TI6@205YJFP80EeMG
0P1PH60406MWI`80JFUY0P1WIfL00`1YJFT0IVIV06IVIP0206IVIP80K6a/0P1`L70206a/K080I6AT
0P1SHf<2069RHP80Hf=S0P1TI6@206=SH`80I6AT0P1_Kfl207IfMP80JVYZ00<0JFUY06YZJP1ZJVX0
0P1UIFD2061PH0@0KVi^0P1hN7P207IfMQD0oooo000C0?ooo`@0MGEe0P1gMgL207emO@80MGEe0P1k
Ng/207inOP80Lg=c00<0NWYj07inOP1nOWh00P1cLg<206][J`80KFe]0P1iNGT208^;R`80MgMg0P1S
Hf<206EUI@80HF5Q0P1NGUh205mOG`80HF5Q0P1IFET206YZJP030861P@1eMGD0MGEe0080FUYJ0P1Q
HF4206EUI@80Hf=S0P1RHV8205aLG0@0F5QH0P1PH60406=SH`80HV9R0P1MGEd2061PH00306ATI01N
GUh0GUiN0080H61P0P1SHf<205iNGP80IVIV0P1PH60205YJFP80GUiN0P1RHV8205iNGP@0FEUI0P1P
H602069RHP80HF5Q00<0H61P069RHP1RHV800P1SHf<6069RHP80J6QX0P1bLW8206YZJP80IfMW0P1X
J6P2075aL@80K6a/0P1ZJVX206][J`80KFe]00<0KVi^06IVIP1VIVH00P1SHf<<06ATI0P0Hf=S0P1Q
HF4205]KF`80KFe]00<0Shn?05IFEP1FEUH00P1JFUX206][J`80J6QX0P1TI6@206MWI`80L71`0P1Z
JVX206IVIP80K6a/0P1XJ6P206IVIP80H61P0P1TI6@2065QH@0306EUI@1WIfL0IfMW0080KVi^0P1]
KFd206QXJ080HV9R0P1YJFT206=SH`@0HV9R0P1ZJVX206ATI080PX:20P1hN7P206][J`80N7Qh00<0
E5AD05iNGP1NGUh00P1SHf<2061PH080O7al0P1dM7@206MWI`80K6a/5@3oool001<0oooo101eMGD2
07MgM`80OGem0P1eMGD207]kN`80OWin0P1cLg<00`1jNWX0OWin07inOP0207=cL`80Jf][0P1]KFd2
07UiN@80Rh^;0P1gMgL206=SH`80IFEU0P1QHF4205iNGP80GemO0P1QHF4205UIF@80JVYZ00<0PH61
07EeM@1eMGD00P1JFUX2065QH@80IFEU0P1SHf<2069RHP80G5aL101HF5P2061PH0@0Hf=S0P1RHV82
05eMG@80H61P00<0I6AT05iNGP1NGUh00P1PH60206=SH`80GUiN0P1VIVH2061PH080FUYJ0P1NGUh2
069RHP80GUiN101IFET2061PH080HV9R0P1QHF400`1PH600HV9R069RHP0206=SH`H0HV9R0P1XJ6P2
079bLP80JVYZ0P1WIfL206QXJ080LG5a0P1/K6`206YZJP80Jf][0P1]KFd00`1^KVh0IVIV06IVIP02
06=SH``0I6AT201SHf<2065QH@80Fe]K0P1]KFd00`2?Shl0EUIF05IFEP0205YJFP80Jf][0P1XJ6P2
06ATI080IfMW0P1`L70206YZJP80IVIV0P1/K6`206QXJ080IVIV0P1PH60206ATI080HF5Q00<0IFEU
06MWI`1WIfL00P1^KVh206e]K@80J6QX0P1RHV8206UYJ@80Hf=S101RHV8206YZJP80I6AT0P22PX82
07QhN080Jf][0P1hN7P00`1DE5@0GUiN05iNGP0206=SH`80H61P0P1lO7`207AdM080IfMW0P1/K6`E
0?ooo`004`3oool2079bLP80MGEe0P1bLW82075aL@80MgMg0P1eMGD406m_K`0307UiN@1fMWH0MWIf
0080N7Qh0P1mOGd207IfMP80Ng]k0P1gMgL207alO080MGEe0P1[Jf/206YZJP80IVIV0P1XJ6P206EU
I@80K6a/0P1kNg/00`1fMWH0EUIF05IFEP0206UYJ@80IVIV0P1YJFT605mOG`80IfMW0P1QHF4205aL
G080H61P0P1RHV8206=SH`80IFEU0P1ZJVX00`1XJ6P0Hf=S06=SH`0205]KF`80FEUI0P1KFe/206AT
I080IFEU0P1/K6`206e]K@80JVYZ0P1UIFD205mOG`80H61P0P1LG5`2061PH080EeMG0`1CDe<205mO
G`80Hf=S101TI6@2069RHP80G5aL0P1QHF4205iNGP80G5aL0P1XJ6P206][J`80HF5Q0P1UIFD206AT
I00306EUI@1TI6@0I6AT0080I6AT0P1YJFT206YZJP80IFEU0P1TI6@206UYJ@@0JVYZ0P1UIFD206UY
J@80IFEU0P1SHf<2065QH@80Fe]K00<0KFe]05YJFP1JFUX00P1SHf<205eMG@80J6QX101ZJVX206=S
H`80H61P0P1SHf<206QXJ080JVYZ101XJ6P206a/K0D0J6QX0P1/K6`206QXJ080JFUY0P1[Jf/206IV
IP80IFEU0P1[Jf/206ATI080Kfm_0P28R8P208>3P`80M7Ad0P1nOWh207moO`0306IVIP1lO7`0O7al
0080F5QH0P1JFUX207UiN@80Ogmo0P1mOGd207EeMAD0oooo000C0?ooo`80LW9b0P1eMGD2079bLP80
LG5a0P1gMgL207EeM@@0Kfm_00<0NGUi07IfMP1fMWH00P1hN7P207emO@80MWIf0P1kNg/207MgM`80
O7al0P1eMGD206][J`80JVYZ0P1VIVH206QXJ080IFEU0P1/K6`207]kN`0307IfMP1FEUH0EUIF0080
JFUY0P1VIVH206UYJ@H0GemO0P1WIfL2065QH@80G5aL0P1PH602069RHP80Hf=S0P1UIFD206YZJP03
06QXJ01SHf<0Hf=S0080Fe]K0P1IFET205]KF`80I6AT0P1UIFD206a/K080KFe]0P1ZJVX206EUI@80
GemO0P1PH60205aLG080H61P0P1GEeL305=CD`80GemO0P1SHf<406ATI080HV9R0P1LG5`2065QH@80
GUiN0P1LG5`206QXJ080Jf][0P1QHF4206EUI@80I6AT00<0IFEU06ATI01TI6@00P1TI6@206UYJ@80
JVYZ0P1UIFD206ATI080JFUY101ZJVX206EUI@80JFUY0P1UIFD206=SH`80HF5Q0P1KFe/00`1]KFd0
FUYJ05YJFP0206=SH`80GEeM0P1XJ6P406YZJP80Hf=S0P1PH60206=SH`80J6QX0P1ZJVX406QXJ080
K6a/1@1XJ6P206a/K080J6QX0P1YJFT206][J`80IVIV0P1UIFD206][J`80I6AT0P1_Kfl208R8R080
Ph>30P1dM7@207inOP80Ogmo00<0IVIV07alO01lO7`00P1HF5P205YJFP80NGUi0P1oOgl207emO@80
MGEe5@3oool001<0oooo0P1bLW8207AdM080L71`0P1dM7@206m_K`80KFe]0P1cLg<207YjNP03071`
L01]KFd0KFe]0080Kfm_0P1ZJVX207EeM@80NWYj0P1cLg<207]kN`80Ogmo0P1iNGT406UYJ@80JVYZ
101XJ6P205iNGP0306QXJ020P800P8200080N7Qh101YJFT206ATI080J6QX0P1QHF4205aLG080Hf=S
0P1XJ6P206MWI`80I6AT0P1KFe/205QHF080H61P00<0FUYJ059BDP1BDU800P1JFUX2061PH080GEeM
2P1SHf<206IVIP80K6a/0P1RHV8205UIF@80EEEE0P1KFe/00`1LG5`0J6QX06QXJ002065QH@80H61P
201SHf<2061PH080HV9R0P1]KFd206YZJP80FEUI0P1QHF4206QXJ080IFEU00<0IVIV06QXJ01XJ6P0
0P1ZJVX206a/K080IVIV0P1XJ6P206YZJP80Hf=S0P1TI6@4065QH@80HV9R0P1PH60206QXJ080IFEU
0P1QHF400`1KFe/0OWin07inOP0207QhN080EeMG0P1KFe/206EUI@80IVIV0P1WIfL206EUI@H0J6QX
0P1YJFT206YZJP80J6QX0P1UIFD00`1XJ6P0IfMW06MWI`0206=SH`80IVIV101YJFT206EUI@80GUiN
0P1HF5P205EEE@80J6QX0P1`L70207AdM080E5AD0P1FEUH204a<C00305EEE@1hN7P0N7Qh0080FUYJ
0P1eMGD208b<S080N7Qh0P1aLG42079bLQD0oooo000C0?ooo`80LW9b0P1dM7@2071`L080M7Ad0P1_
Kfl206e]K@80Lg=c0P1jNWX00`1`L700KFe]06e]K@0206m_K`80JVYZ0P1eMGD207YjNP80Lg=c0P1k
Ng/207moO`80NGUi101YJFT206YZJP@0J6QX0P1NGUh00`1XJ6P0P8200820P00207QhN0@0JFUY0P1T
I6@206QXJ080HF5Q0P1LG5`206=SH`80J6QX0P1WIfL206ATI080Fe]K0P1HF5P2061PH00305YJFP1B
DU80DU9B0080FUYJ0P1PH60205eMG@X0Hf=S0P1VIVH206a/K080HV9R0P1IFET205EEE@80Fe]K00<0
G5aL06QXJ01XJ6P00P1QHF42061PH0P0Hf=S0P1PH602069RHP80KFe]0P1ZJVX205UIF@80HF5Q0P1X
J6P206EUI@0306IVIP1XJ6P0J6QX0080JVYZ0P1/K6`206IVIP80J6QX0P1ZJVX206=SH`80I6AT101Q
HF42069RHP80H61P0P1XJ6P206EUI@80HF5Q00<0Fe]K07inOP1nOWh00P1hN7P205MGE`80Fe]K0P1U
IFD206IVIP80IfMW0P1UIFD606QXJ080JFUY0P1ZJVX206QXJ080IFEU00<0J6QX06MWI`1WIfL00P1S
Hf<206IVIP@0JFUY0P1UIFD205iNGP80F5QH0P1EEED206QXJ080L71`0P1dM7@205ADE080EUIF0P1<
C4`00`1EEED0N7Qh07QhN00205YJFP80MGEe0P2<S8`207QhN080LG5a0P1bLW8E0?ooo`004`3oool2
079bLP80NWYj0P1mOGd207inOP80LW9b0P1jNWX2079bLP80L71`00<0LW9b07alO01lO7`00P1aLG42
07UiN@80O7al0P1^KVh207EeM@80NGUi0P1hN7P208:2PP80RXZ:0P1fMWH206i^KP80LG5a101`L700
0`1YJFT0LW9b079bLP0206a/K080IVIV0P1UIFD206UYJ@80Jf][0P1WIfL206QXJ080GUiN0P1IFET2
05QHF080EUIF0P1JFUX205QHF080CDe=00<0D51@05QHF01HF5P00P1IFET205YJFP80EeMG101SHf<2
06UYJ@H0JVYZ0P1]KFd206UYJ@80KFe]0P1PH602065QH@0305mOG`1QHF40HF5Q0080EEEE0P1JFUX2
05MGE`80E5AD0P1NGUh2069RHP80Hf=S0P1RHV8206=SH`80GEeM0P1NGUh2065QH@80GEeM0P1NGUh0
0`1OGel0GEeM05eMG@0205aLG080Hf=S0P1TI6@2061PH080GemO101QHF4205mOG`H0HV9R101OGel2
06=SH`0305iNGP1PH600H61P0080Ng]k0P2BTY82079bLP80H61P101NGUh205mOG`80IVIV0P1TI6@4
06MWI`80I6AT0P1VIVH206EUI@0306i^KP1XJ6P0J6QX00@0K6a/0P1YJFT205YJFP80EeMG0P1:BTX2
04A4A080EeMG0P1oOgl406m_K`80FEUI101UIFD00`1XJ6P0G5aL05aLG00204i>CP80OWin0P20P802
079bLP80N7Qh0P1dM7@E0?ooo`004`3oool2079bLP80NWYj0P1mOGd207inOP80LW9b0P1jNWX2079b
LP80L71`00<0LW9b07alO01lO7`00P1aLG4207UiN@80O7al0P1^KVh207EeM@80NGUi0P1hN7P208:2
PP80RXZ:0P1fMWH206i^KP80LG5a101`L7000`1YJFT0LW9b079bLP0206a/K080IVIV0P1UIFD206UY
J@80Jf][0P1WIfL206QXJ080GUiN0P1IFET205QHF080EUIF0P1JFUX205QHF080CDe=00<0D51@05QH
F01HF5P00P1IFET205YJFP80EeMG101SHf<206UYJ@H0JVYZ0P1]KFd206UYJ@80KFe]0P1PH602065Q
H@0305mOG`1QHF40HF5Q0080EEEE0P1JFUX205MGE`80E5AD0P1NGUh2069RHP80Hf=S0P1RHV8206=S
H`80GEeM0P1NGUh2065QH@80GEeM0P1NGUh00`1OGel0GEeM05eMG@0205aLG080Hf=S0P1TI6@2061P
H080GemO101QHF4205mOG`H0HV9R101OGel206=SH`0305iNGP1PH600H61P0080Ng]k0P2BTY82079b
LP80H61P101NGUh205mOG`80IVIV0P1TI6@406MWI`80I6AT0P1VIVH206EUI@0306i^KP1XJ6P0J6QX
00@0K6a/0P1YJFT205YJFP80EeMG0P1:BTX204A4A080EeMG0P1oOgl406m_K`80FEUI101UIFD00`1X
J6P0G5aL05aLG00204i>CP80OWin0P20P802079bLP80N7Qh0P1dM7@E0?ooo`004`3oool2079bLP80
L71`0P1^KVh206m_K`80LW9b0P1jNWX207AdM080O7al00<0Lg=c06i^KP1^KVh00P1/K6`2071`L080
Jf][0P1fMWH207EeM@80M7Ad101fMWH207=cL`80Ng]k0P1jNWX607AdM003075aL@1YJFT0JFUY00@0
MGEe0P0f=SH205=CD`@0HF5Q0P1LG5`205]KF`H0GemO0P1ADE4204m?C`80G5aL00<0H61P05aLG01L
G5`00P1LG5`205YJFP80FEUI0P1NGUh2061PH080HF5Q0P1TI6@406EUI@80J6QX0P1QHF4206ATI080
G5aL0P1KFe/305IFEP80F5QH0P1QHF4205YJFP80EeMG0P1EEED2051@D080EUIF0P1GEeL205IFEP80
G5aL0P1JFUX205MGE`80FEUI0P1HF5P00`1OGel0FEUI05UIF@0205mOG`80GUiN0P1DE5@205YJFP80
H61P0P1QHF4205UIF@P0EeMG0P1HF5P205UIF@80GemO00<0Fe]K05EEE@1EEED00P1IFET206UYJ@80
H61P101QHF4406=SH`80HV9R0P1OGel206ATI080IVIV101UIFD206e]K@0306i^KP1TI6@0I6AT0080
I6AT0P1QHF4205QHF080De=C0P0n?Sh204E5A@80De=C101ZJVX2051@D080>CTi0P12@T8205mOG`80
E5AD00<0IVIV065QH@1QHF400P1JFUX207UiN@80MWIf0P1`L70206m_K`80KVi^5@3oool001<0oooo
0P1bLW82071`L080KVi^0P1_Kfl2079bLP80NWYj0P1dM7@207alO00307=cL`1^KVh0KVi^0080K6a/
0P1`L70206][J`80MWIf0P1eMGD207AdM0@0MWIf0P1cLg<207]kN`80NWYj1P1dM7@00`1aLG40JFUY
06UYJ@0407EeM@80=SHf0P1CDe<4065QH@80G5aL0P1KFe/605mOG`80DE5A0P1?Cdl205aLG003061P
H01LG5`0G5aL0080G5aL0P1JFUX205UIF@80GUiN0P1PH602065QH@80I6AT101UIFD206QXJ080HF5Q
0P1TI6@205aLG080Fe]K0`1FEUH205QHF080HF5Q0P1JFUX205MGE`80EEEE0P1@D50205IFEP80EeMG
0P1FEUH205aLG080FUYJ0P1GEeL205UIF@80F5QH00<0GemO05UIF@1IFET00P1OGel205iNGP80E5AD
0P1JFUX2061PH080HF5Q0P1IFET805MGE`80F5QH0P1IFET205mOG`0305]KF`1EEED0EEEE0080FEUI
0P1YJFT2061PH0@0HF5Q101SHf<2069RHP80GemO0P1TI6@206IVIP@0IFEU0P1]KFd00`1^KVh0I6AT
06ATI00206ATI080HF5Q0P1HF5P205=CD`80?Shn0P15ADD205=CD`@0JVYZ0P1@D50203Ti>@80@T92
0P1OGel205ADE00306IVIP1QHF40HF5Q0080FUYJ0P1iNGT207IfMP80L71`0P1_Kfl206i^KQD0oooo
000C0?ooo`80LW9b0P1kNg/207AdM080N7Qh0P1kNg/207UiN@80L71`0P1_Kfl00`1aLG40MWIf07If
MP0207alO080NGUi0P1cLg<206i^KPH0M7Ad0P1fMWH2071`L080NGUi0P1jNWX208N7Q`80QHF50P23
Ph<00`2:RXX0SHf=08f=S@0208:2PP80OWin0P2RXZ8207UiN@80F5QH0P1RHV8206=SH`80HF5Q101O
Gel205UIF@80HF5Q0P1PH60206EUI@0306=SH`1VIVH0IVIV0080KFe]0P1`L70206UYJ@@0G5aL0P1P
H60206IVIP@0IFEU0P1TI6@206QXJ080Jf][0P1XJ6P2065QH@0306ATI01]KFd0KFe]0080Hf=S0P1R
HV8206=SH`@0IFEU0P1MGEd205UIF@80CTi>0P1<C4`204Y:BP80@d=31P1;Bd/00`19BDT0@d=304=3
@`0204Q8B080ATI60P19BDT204];B`80AdM70P16ATH204U9B@@0CDe=101IFET205aLG080GUiN0P1K
Fe/00`1EEED0EUIF05IFEP0205EEE@80>c/k0P1ADE4206a/K080C4a<0P0^;Rh203dm?@80De=C0P1G
EeL205iNGP80GEeM0P1LG5`406ATI00305mOG`1XJ6P0J6QX0080J6QX0P1NGUh203@d=080=CDe0P1@
D50206=SH`80Fe]K0P1CDe<205MGE`80Fe]K0P1RHV8206EUI@80Fe]K0P1fMWH00`1_Kfl0EEEE05EE
E@02075aL@80P820101dM7@2079bLP80Kfm_5@3oool001<0oooo0P1nOWh207EeM@80MgMg101cLg<2
07IfMP80NGUi0P1hN7P00`1eMGD0Kfm_06m_K`0206i^KP80KFe]0P1aLG4207AdM080NGUi0P1`L702
06a/K080LW9b0P1`L70207QhN080Lg=c0P1iNGT2079bLP80LG5a00<0MWIf071`L01`L7000P1`L702
079bLP80NGUi0P26QXH206][J`80?Cdm101QHF42059BDP80Fe]K101QHF4205QHF080EeMG00<0Cdm?
05ADE01DE5@00P1HF5P205UIF@80G5aL0P1JFUX205mOG`80Hf=S0P1QHF4206MWI`80IVIV0P1YJFT2
06EUI@80GUiN0P1QHF42061PH00306=SH`1MGEd0GEeM0080GUiN0P1YJFT2069RHP80IfMW0P1ZJVX2
06a/K080JFUY101`L70406e]K@80J6QX0P1YJFT206EUI@0306ATI01VIVH0IVIV0080K6a/0P1UIFD2
06ATI0@0Jf][101/K6`206][J`80M7Ad0P1bLW8205iNGP80JFUY101ZJVX00`1TI6@0KFe]06e]K@02
06EUI@@0I6AT0P1MGEd206e]K@80Rh^;0P1oOgl201TI6@80>c/k0P1=CDd205=CD`@0GUiN0P1KFe/0
0`14A4@08B4Q024Q8@0201@D50805aLG0P0^;Rh2061PH080KVi^0P1ZJVX205]KF`80IFEU0P1SHf<2
05UIF@80JFUY0P1ZJVX205=CD`80J6QX00<0IfMW04m?C`1?Cdl00P1`L70206][J`80LW9b0P1eMGD2
07]kN`80MgMg5@3oool001<0oooo0P1nOWh207EeM@80MgMg101cLg<207IfMP80NGUi0P1hN7P00`1e
MGD0Kfm_06m_K`0206i^KP80KFe]0P1aLG4207AdM080NGUi0P1`L70206a/K080LW9b0P1`L70207Qh
N080Lg=c0P1iNGT2079bLP80LG5a00<0MWIf071`L01`L7000P1`L702079bLP80NGUi0P26QXH206][
J`80?Cdm101QHF42059BDP80Fe]K101QHF4205QHF080EeMG00<0Cdm?05ADE01DE5@00P1HF5P205UI
F@80G5aL0P1JFUX205mOG`80Hf=S0P1QHF4206MWI`80IVIV0P1YJFT206EUI@80GUiN0P1QHF42061P
H00306=SH`1MGEd0GEeM0080GUiN0P1YJFT2069RHP80IfMW0P1ZJVX206a/K080JFUY101`L70406e]
K@80J6QX0P1YJFT206EUI@0306ATI01VIVH0IVIV0080K6a/0P1UIFD206ATI0@0Jf][101/K6`206][
J`80M7Ad0P1bLW8205iNGP80JFUY101ZJVX00`1TI6@0KFe]06e]K@0206EUI@@0I6AT0P1MGEd206e]
K@80Rh^;0P1oOgl201TI6@80>c/k0P1=CDd205=CD`@0GUiN0P1KFe/00`14A4@08B4Q024Q8@0201@D
50805aLG0P0^;Rh2061PH080KVi^0P1ZJVX205]KF`80IFEU0P1SHf<205UIF@80JFUY0P1ZJVX205=C
D`80J6QX00<0IfMW04m?C`1?Cdl00P1`L70206][J`80LW9b0P1eMGD207]kN`80MgMg5@3oool001<0
oooo0P1XJ6P206a/K080MWIf0P1`L702079bLP@0JVYZ0P1_Kfl00`1dM7@0Ng]k07]kN`0407AdM080
O7al0P1mOGd207EeM@80LG5a0P1gMgL207YjNP80Lg=c0P1iNGT2079bLP80MgMg0P1`L70207AdM003
07=cL`1^KVh0KVi^0080N7Qh0P1cLg<2079bLP80LG5a0P1EEED204Y:BP80DU9B0P0o?cl2051@D080
HF5Q101NGUh2065QH@80IfMW00<0GUiN05mOG`1OGel01P1PH60205YJFP80GemO0P1TI6@206=SH`80
H61P0P1LG5`2069RHP80Hf=S0P1WIfL206YZJP80IVIV00<0HV9R061PH01PH600101VIVH206EUI@80
IVIV101SHf<206EUI@80H61P0P1GEeL206EUI@80JFUY0P1/K6`206e]K@80I6AT00<0Hf=S06EUI@1U
IFD00P1TI6@206YZJP80Kfm_0P1VIVH2061PH080HF5Q0P1OGel406MWI`80Hf=S0P1WIfL206YZJP80
G5aL0P1PH6000`1NGUh0IFEU06EUI@0206EUI@80Jf][0P1YJFT205eMG@@0GUiN0P1WIfL208j>SP80
]KFe0P1JFUX203Xj>P80;Bd]0P0h>3P202TY:@03028R8P0l?3`0?3`l0080@d=30P19BDT205aLG080
De=C0P1LG5`2055AD@80CDe=0P28R8P206UYJ@80GEeM0P1OGel204=3@`80JFUY0P23Ph<00`1EEED0
M7Ad07AdM00206i^KP80Lg=c0P1eMGD206e]K@80Jf][0P1eMGDE0?ooo`004`3oool206QXJ080K6a/
0P1fMWH2071`L080LW9b101ZJVX206m_K`0307AdM01kNg/0Ng]k00@0M7Ad0P1lO7`207emO@80MGEe
0P1aLG4207MgM`80NWYj0P1cLg<207UiN@80LW9b0P1gMgL2071`L080M7Ad00<0Lg=c06i^KP1^KVh0
0P1hN7P207=cL`80LW9b0P1aLG4205EEE@80BTY:0P1BDU8203lo?`80D51@0P1QHF4405iNGP80HF5Q
0P1WIfL00`1NGUh0GemO05mOG`06061PH080FUYJ0P1OGel206ATI080Hf=S0P1PH60205aLG080HV9R
0P1SHf<206MWI`80JVYZ0P1VIVH00`1RHV80H61P061PH00406IVIP80IFEU0P1VIVH406=SH`80IFEU
0P1PH60205MGE`80IFEU0P1YJFT206a/K080KFe]0P1TI6@00`1SHf<0IFEU06EUI@0206ATI080JVYZ
0P1_Kfl206IVIP80H61P0P1QHF4205mOG`@0IfMW0P1SHf<206MWI`80JVYZ0P1LG5`2061PH00305iN
GP1UIFD0IFEU0080IFEU0P1[Jf/206UYJ@80GEeM101NGUh206MWI`80SXj>0P2e]KD205YJFP80>SXj
0P0];Bd203Ph>080:BTY00<08R8R03`l?00l?3`00P13@d<204U9B@80G5aL0P1CDe<205aLG080DE5A
0P1=CDd208R8R080JFUY0P1MGEd205mOG`80@d=30P1YJFT208>3P`0305EEE@1dM7@0M7Ad0080KVi^
0P1cLg<207EeM@80KFe]0P1[Jf/207EeMAD0oooo000C0?ooo`80P8200P1fMWH2071`L080MWIf0P1d
M7@207YjNP80Ogmo0P1bLW800`1`L700Kfm_06m_K`0207MgM`80N7Qh0P1gMgL206i^KP80MGEe101c
Lg<2079bLP80MWIf0P1aLG4207EeM@@0NGUi0P1mOGd00`1cLg<0LG5a075aL@0206i^KP80Jf][0P1d
M7@206m_K`80Fe]K0P1bLW8204e=C@80CTi>0P1EEED203dm?@80De=C0P1OGel205YJFP80GEeM00<0
E5AD061PH01PH6000P1QHF4205QHF080GEeM0P1OGel2065QH@80IFEU101RHV8206=SH`80HF5Q0P1T
I6@205mOG`80Hf=S0P1QHF400`1UIFD0HV9R069RHP0205eMG@80H61P2P1SHf<206EUI@80JVYZ0P1M
GEd205QHF080FUYJ0P1PH60206EUI@0306YZJP1PH600H61P0080GemO0P1LG5`205EEE@80FUYJ0P1V
IVH206QXJ080GEeM201SHf<405aLG080I6AT00<0GEeM06ATI01TI6@00P1JFUX205mOG`80HV9R0P1U
IFD206MWI`80FUYJ0P1FEUH205EEE@80H61P0P1/K6`208^;R`80PX:20P0];Bd2020P80030410@011
@D40@D510080@d=30P1EEED2051@D080AdM70P0o?cl204I6AP80G5aL0P1fMWH203Xj>P80B4Q80P1P
H602051@D080IfMW0P1SHf<00`1EEED0PX:208:2PP020861P@80QHF50P1cLg<207MgM`80M7Ad0P1i
NGTE0?ooo`004`3oool20820P080MWIf0P1`L70207IfMP80M7Ad0P1jNWX207moO`80LW9b00<0L71`
06m_K`1_Kfl00P1gMgL207QhN080MgMg0P1^KVh207EeM@@0Lg=c0P1bLW8207IfMP80LG5a0P1eMGD4
07UiN@80OGem00<0Lg=c075aL@1aLG400P1^KVh206][J`80M7Ad0P1_Kfl205]KF`80LW9b0P1=CDd2
04i>CP80EEEE0P0m?Cd205=CD`80GemO0P1JFUX205eMG@0305ADE01PH600H61P0080HF5Q0P1HF5P2
05eMG@80GemO0P1QHF4206EUI@@0HV9R0P1SHf<2065QH@80I6AT0P1OGel206=SH`80HF5Q00<0IFEU
069RHP1RHV800P1MGEd2061PH0X0Hf=S0P1UIFD206YZJP80GEeM0P1HF5P205YJFP80H61P0P1UIFD0
0`1ZJVX0H61P061PH00205mOG`80G5aL0P1EEED205YJFP80IVIV0P1XJ6P205eMG@P0Hf=S101LG5`2
06ATI00305eMG@1TI6@0I6AT0080FUYJ0P1OGel2069RHP80IFEU0P1WIfL205YJFP80EUIF0P1EEED2
061PH080K6a/0P2;Rh/208:2PP80;Bd]0P0P82000`10@400@D510451@@0204=3@`80EEEE0P1@D502
04M7A`80?clo0P16ATH205aLG080MWIf0P0j>SX204Q8B080H61P0P1@D50206MWI`80Hf=S00<0EEEE
08:2PP22PX800P21PH4208F5Q@80Lg=c0P1gMgL207AdM080NGUi5@3oool001<0oooo0P1[Jf/207If
MP80OGem0P1bLW8206i^KP80N7Qh0P1^KVh207MgM`0307moO`1mOGd0OGem0080LW9b0P1eMGD207Ui
N@80Lg=c0P1aLG4207IfMP80OGem0P1kNg/207UiN@80LG5a0P1cLg<207AdM080MWIf0P1`L7000`1_
Kfl0LW9b079bLP0207IfMP80MGEe0P1cLg<2079bLP80HV9R0P1UIFD205QHF080C4a<0P1@D50203Hf
=P808B4Q0P0k>c/205]KF`<0G5aL0P1TI6@205YJFP80GemO0P1MGEd205MGE`80GEeM0P1UIFD406=S
H`@0HV9R0P1VIVH4065QH@80GemO00<0Hf=S06EUI@1UIFD00P1XJ6P206IVIPh0Hf=S0P1PH602069R
HP80H61P0P1TI6@205aLG00305YJFP1SHf<0Hf=S0080H61P0P1JFUX2061PH080HV9R0P1MGEd205QH
F080Fe]K0P1VIVH606=SH`80FEUI0P1UIFD206IVIP<0GUiN0P1MGEd206EUI@80Hf=S0P1KFe/205QH
F080Fe]K0P1NGUh2055AD@80@D510P0c<c<201`L70804Q8B0P0_;bl2051@D00304E5A@0n?Sh0?Shn
0080De=C0P1=CDd204];B`80CDe=0P1SHf<206ATI080F5QH0P1NGUh204Q8B080GEeM0P1OGel2059B
DP80N7Qh0P1QHF400`1TI6@0O7al07alO002079bLP80NWYj0P1]KFd207UiN@80OWin0P1eMGDE0?oo
o`004`3oool206][J`80MWIf0P1mOGd2079bLP80KVi^0P1hN7P206i^KP80MgMg00<0Ogmo07emO@1m
OGd00P1bLW8207EeM@80NGUi0P1cLg<2075aL@80MWIf0P1mOGd207]kN`80NGUi0P1aLG4207=cL`80
M7Ad0P1fMWH2071`L00306m_K`1bLW80LW9b0080MWIf0P1eMGD207=cL`80LW9b0P1RHV8206EUI@80
F5QH0P1<C4`2051@D080=SHf0P0Q8B4203/k>`80Fe]K0`1LG5`206ATI080FUYJ0P1OGel205eMG@80
EeMG0P1MGEd206EUI@@0Hf=S101RHV8206IVIP@0HF5Q0P1OGel00`1SHf<0IFEU06EUI@0206QXJ080
IVIV3P1SHf<2061PH080HV9R0P1PH60206ATI080G5aL00<0FUYJ06=SH`1SHf<00P1PH60205YJFP80
H61P0P1RHV8205eMG@80F5QH0P1KFe/206IVIPH0Hf=S0P1IFET206EUI@80IVIV0`1NGUh205eMG@80
IFEU0P1SHf<205]KF`80F5QH0P1KFe/205iNGP80DE5A0P11@D4203<c<`8071`L0P0B4Q8202l_;`80
D51@00<0ADE503hn?P0n?Sh00P1CDe<204e=C@80Bd];0P1=CDd206=SH`80I6AT0P1HF5P205iNGP80
B4Q80P1MGEd205mOG`80DU9B0P1hN7P2065QH@0306ATI01lO7`0O7al0080LW9b0P1jNWX206e]K@80
NGUi0P1nOWh207EeMAD0oooo000C0?ooo`80OWin0P1eMGD206a/K080L71`0P1dM7@207QhN080L71`
0P1hN7P00`1/K6`0LW9b079bLP02071`L080N7Qh0P1^KVh207EeM@80Lg=c0P1hN7P407IfMP80KVi^
0P1`L70207YjNP80NGUi0P1^KVh207EeM@0307AdM01aLG40LG5a0080LG5a0P1iNGT207IfMP80Lg=c
0P1/K6`208>3P`80P8200P1<C4`204E5A@80=cLg0P0i>CT201hN7P80@D510P1BDU800`1OGel0E5AD
05ADE002051@D080F5QH0P1NGUh4065QH@80IFEU201SHf<2069RHP80H61P1`1SHf<205aLG0H0FUYJ
0P1PH60205]KF`80H61P101SHf<205iNGP@0H61P0P1MGEd205aLG00305eMG@1JFUX0FUYJ0080FUYJ
101RHV84061PH080GUiN0P1QHF4205iNGP80H61P101IFET205iNGP80IfMW0P1SHf<00`1NGUh0GEeM
05eMG@0205mOG`80GEeM0P1JFUX205ADE080G5aL0P1ADE4204a<C080@d=30P0o?cl202/[:`80:RXZ
0P13@d<205IFEP80De=C00<0F5QH04m?C`1?Cdl00P0o?cl204Q8B080Cdm?0P1LG5`2069RHP80F5QH
0P1VIVH205IFEP80@D510P1FEUH205=CD`80IVIV0P1ZJVX205]KF`0306e]K@22PX80PX:20080MgMg
0P1cLg<207EeM@80N7Qh0P1_Kfl206a/K1D0oooo000C0?ooo`80OWin0P1eMGD206a/K080L71`0P1d
M7@207QhN080L71`0P1hN7P00`1/K6`0LW9b079bLP02071`L080N7Qh0P1^KVh207EeM@80Lg=c0P1h
N7P407IfMP80KVi^0P1`L70207YjNP80NGUi0P1^KVh207EeM@0307AdM01aLG40LG5a0080LG5a0P1i
NGT207IfMP80Lg=c0P1/K6`208>3P`80P8200P1<C4`204E5A@80=cLg0P0i>CT201hN7P80@D510P1B
DU800`1OGel0E5AD05ADE002051@D080F5QH0P1NGUh4065QH@80IFEU201SHf<2069RHP80H61P1`1S
Hf<205aLG0H0FUYJ0P1PH60205]KF`80H61P101SHf<205iNGP@0H61P0P1MGEd205aLG00305eMG@1J
FUX0FUYJ0080FUYJ101RHV84061PH080GUiN0P1QHF4205iNGP80H61P101IFET205iNGP80IfMW0P1S
Hf<00`1NGUh0GEeM05eMG@0205mOG`80GEeM0P1JFUX205ADE080G5aL0P1ADE4204a<C080@d=30P0o
?cl202/[:`80:RXZ0P13@d<205IFEP80De=C00<0F5QH04m?C`1?Cdl00P0o?cl204Q8B080Cdm?0P1L
G5`2069RHP80F5QH0P1VIVH205IFEP80@D510P1FEUH205=CD`80IVIV0P1ZJVX205]KF`0306e]K@22
PX80PX:20080MgMg0P1cLg<207EeM@80N7Qh0P1_Kfl206a/K1D0oooo000C0?ooo`80Jf][0P1_Kfl2
07YjNP80MgMg0P1`L70207MgM`80NGUi0P1kNg/00`1bLW80NGUi07UiN@0207=cL`80LG5a0P1fMWH2
079bLP80MWIf0P1kNg/206i^KP80Jf][0P1`L702079bLP80MWIf0P1/K6`407EeM@0306m_K`1kNg/0
Ng]k0080NGUi0P1cLg<206a/K080LW9b0P1PH60207MgM`80FUYJ0P0k>c/203`l?080>SXj0P0d=3@2
02XZ:P804Q8B0P0];Bd3055AD@80IFEU0P1RHV8205mOG`80FEUI101LG5`2061PH0H0Hf=S0P1LG5`2
061PH0L0Hf=S0P1UIFD206QXJ080HV9R0P1VIVH2061PH080G5aL0P1MGEd2061PH080Hf=S0P1UIFD2
06QXJ080G5aL0P1HF5P205iNGP03061PH01RHV80HV9R0080HV9R0P1LG5`205iNGP80GEeM0P1IFET2
05]KF`80GEeM0P1JFUX206=SH`80GemO0P1XJ6P2069RHP80Fe]K0P1PH6000`1UIFD0HV9R069RHP02
065QH@80GEeM101GEeL2059BDP80Cdm?1019BDT203Ti>@80;Rh^0P1<C4`205QHF080@d=30P16ATH0
0`1GEeL0CDe=04e=C@0204Y:BP80CDe=0P1KFe/204a<C080DE5A0P19BDT204a<C080BDU90P1XJ6P2
079bLP80JVYZ0P23Ph<205=CD`80G5aL00<0Ph>307inOP1nOWh00P1dM7@206m_K`80L71`0P1_Kfl4
07MgMaD0oooo000C0?ooo`80Jf][0P1_Kfl207YjNP80MgMg0P1`L70207MgM`80NGUi0P1kNg/00`1b
LW80NGUi07UiN@0207=cL`80LG5a0P1fMWH2079bLP80MWIf0P1kNg/206i^KP80Jf][0P1`L702079b
LP80MWIf0P1/K6`407EeM@0306m_K`1kNg/0Ng]k0080NGUi0P1cLg<206a/K080LW9b0P1PH60207Mg
M`80FUYJ0P0k>c/203`l?080>SXj0P0d=3@202XZ:P804Q8B0P0];Bd3055AD@80IFEU0P1RHV8205mO
G`80FEUI101LG5`2061PH0H0Hf=S0P1LG5`2061PH0L0Hf=S0P1UIFD206QXJ080HV9R0P1VIVH2061P
H080G5aL0P1MGEd2061PH080Hf=S0P1UIFD206QXJ080G5aL0P1HF5P205iNGP03061PH01RHV80HV9R
0080HV9R0P1LG5`205iNGP80GEeM0P1IFET205]KF`80GEeM0P1JFUX206=SH`80GemO0P1XJ6P2069R
HP80Fe]K0P1PH6000`1UIFD0HV9R069RHP02065QH@80GEeM101GEeL2059BDP80Cdm?1019BDT203Ti
>@80;Rh^0P1<C4`205QHF080@d=30P16ATH00`1GEeL0CDe=04e=C@0204Y:BP80CDe=0P1KFe/204a<
C080DE5A0P19BDT204a<C080BDU90P1XJ6P2079bLP80JVYZ0P23Ph<205=CD`80G5aL00<0Ph>307in
OP1nOWh00P1dM7@206m_K`80L71`0P1_Kfl407MgMaD0oooo000C0?ooo`80Lg=c0P1bLW8206i^KP80
KFe]0P1bLW8207UiN@80K6a/0P1[Jf/00`1/K6`0MgMg07MgM`0207QhN080O7al0P1cLg<207IfMP80
Lg=c0P1/K6`207IfMP80MGEe0P1jNWX207IfMP80LG5a0P1gMgL207AdM080KFe]00<0NGUi07=cL`1c
Lg<0101eMGD207=cL`80LW9b0P1YJFT2079bLP80EeMG0P1WIfL404U9B@80>c/k0P0];Bd2020P8080
5QHF00<0>SXj05UIF@1IFET00P1LG5`2055AD@80GEeM0P1OGel205aLG080IVIV0P1WIfL606=SH`80
IFEU0P1PH60205YJFP80H61P00<0Hf=S05aLG01LG5`0101JFUX205aLG0@0F5QH0P1OGel406IVIP80
Hf=S0P1LG5`205YJFP80GUiN0P1RHV8205aLG00305YJFP1FEUH0EUIF0080GEeM0P1QHF42069RHP80
Fe]K0P1NGUh205EEE@80Fe]K0P1NGUh205mOG`80G5aL0P1MGEd205aLG080H61P0P1OGel00`1GEeL0
BTY:04Y:BP0204U9B@80ADE5100o?cl20451@@80ADE50P0g=cL201lO7`805QHF0P0m?Cd206EUI@80
EUIF0P0c<c<204Q8B00304a<C01NGUh0GUiN00@0JFUY0P19BDT203hn?P80ADE50P18B4P205aLG080
EEEE0P1SHf<205iNGP80QXJ60P1QHF4205]KF`80OWin00<0NWYj06UYJ@1YJFT00P1YJFT2075aL@80
MgMg0P1cLg<207UiN@80LW9b5@3oool001<0oooo0P1cLg<2079bLP80KVi^0P1]KFd2079bLP80NGUi
0P1/K6`206][J`0306a/K01gMgL0MgMg0080N7Qh0P1lO7`207=cL`80MWIf0P1cLg<206a/K080MWIf
0P1eMGD207YjNP80MWIf0P1aLG4207MgM`80M7Ad0P1]KFd00`1iNGT0Lg=c07=cL`0407EeM@80Lg=c
0P1bLW8206UYJ@80LW9b0P1GEeL206MWI`@0BDU90P0k>c/202d];@80820P0P0F5QH00`0j>SX0FEUI
05UIF@0205aLG080DE5A0P1MGEd205mOG`80G5aL0P1VIVH206MWI`H0Hf=S0P1UIFD2061PH080FUYJ
0P1PH6000`1SHf<0G5aL05aLG00405YJFP80G5aL101HF5P205mOG`@0IVIV0P1SHf<205aLG080FUYJ
0P1NGUh2069RHP80G5aL00<0FUYJ05IFEP1FEUH00P1MGEd2065QH@80HV9R0P1KFe/205iNGP80EEEE
0P1KFe/205iNGP80GemO0P1LG5`205eMG@80G5aL0P1PH60205mOG`0305MGE`1:BTX0BTY:0080BDU9
0P15ADD403lo?`80@D510P15ADD203Lg=`807alO0P0F5QH203dm?@80IFEU0P1FEUH203<c<`80B4Q8
00<0C4a<05iNGP1NGUh0101YJFT204U9B@80?Shn0P15ADD204Q8B080G5aL0P1EEED206=SH`80GUiN
0P26QXH2065QH@80Fe]K0P1nOWh00`1jNWX0JFUY06UYJ@0206UYJ@80LG5a0P1gMgL207=cL`80NGUi
0P1bLW8E0?ooo`004`3oool206m_K`80NWYj0P1hN7P207=cL`80NWYj0P1bLW8206i^KP80MWIf00<0
O7al07IfMP1fMWH00P1_Kfl207AdM080Lg=c0P1hN7P207=cL`80Ng]k0P1jNWX207=cL`80NGUi0P1b
LW8207=cL`80LG5a0P1fMWH207QhN003071`L01[Jf/0Jf][0080LG5a0P1^KVh207AdM080LW9b0P1i
NGT206e]K@80K6a/0P1BDU8203`l?080@d=30P0`<30202XZ:P80:2PX0P0T92@00`0A4A40<c<c03<c
<`0205iNGP80DU9B0P1OGel205UIF@80GUiN0P1QHF42061PH080G5aL1P1JFUX206=SH`80HV9R0P1M
GEd00`1PH600GUiN05iNGP02061PH080IVIV0P1RHV82065QH@80GUiN101LG5`205YJFP80F5QH101R
HV8205YJFP80EUIF0`1JFUX405UIF@80EEEE0P1JFUX205QHF080FEUI0P1EEED205IFEP80D51@0P1G
EeL205iNGP80DU9B0P1KFe/204i>CP<0EeMG0P1FEUH205=CD`80DU9B0P1?Cdl204U9B@80>c/k0P0[
:b/201PH60809RHV0P0k>c/205EEE@80Cdm?0P18B4P204m?C`80IVIV00<0FUYJ05UIF@1IFET0101;
Bd/205QHF080Cdm?0P1=CDd205]KF`@0EeMG0P1TI6@2061PH080E5AD0P1BDU8207=cL`80P82000<0
N7Qh06EUI@1UIFD00P1/K6`207MgM`80MGEe0P1cLg<407QhN1D0oooo000C0?ooo`80Kfm_0P1jNWX2
07QhN080Lg=c0P1jNWX2079bLP80KVi^0P1fMWH00`1lO7`0MWIf07IfMP0206m_K`80M7Ad0P1cLg<2
07QhN080Lg=c0P1kNg/207YjNP80Lg=c0P1iNGT2079bLP80Lg=c0P1aLG4207IfMP80N7Qh00<0L71`
06][J`1[Jf/00P1aLG4206i^KP80M7Ad0P1bLW8207UiN@80KFe]0P1/K6`2059BDP80?3`l0P13@d<2
030`<080:RXZ0P0X:2P202@T9003014A4@0c<c<0<c<c0080GUiN0P1BDU8205mOG`80FEUI0P1NGUh2
065QH@80H61P0P1LG5`605YJFP80Hf=S0P1RHV8205eMG@03061PH01NGUh0GUiN0080H61P0P1VIVH2
069RHP80HF5Q0P1NGUh405aLG080FUYJ0P1HF5P4069RHP80FUYJ0P1FEUH305YJFP@0FEUI0P1EEED2
05YJFP80F5QH0P1IFET205EEE@80EUIF0P1@D50205MGE`80GUiN0P1BDU8205]KF`80CTi>0`1GEeL2
05IFEP80De=C0P1BDU8204m?C`80BDU90P0k>c/202/[:`8061PH0P0V9RH203/k>`80EEEE0P1?Cdl2
04Q8B080Cdm?0P1VIVH00`1JFUX0FEUI05UIF@0404];B`80F5QH0P1?Cdl204e=C@80Fe]K101GEeL2
06ATI080H61P0P1DE5@2059BDP80Lg=c0P20P8000`1hN7P0IFEU06EUI@0206a/K080MgMg0P1eMGD2
07=cL`@0N7Qh5@3oool001<0oooo0P1eMGD206m_K`80M7Ad0P1lO7`207]kN`80KVi^0P1jNWX207em
O@0307UiN@1`L700L71`0080L71`0P1fMWH2071`L080LG5a0P1/K6`2071`L080K6a/0P1]KFd207If
MP80N7Qh0P1lO7`207MgM`80Lg=c0P1fMWH00`1dM7@0Lg=c07=cL`0207=cL`80M7Ad0P1cLg<206YZ
JP80J6QX0P1GEeL206QXJ080=cLg0P0j>SX20451@@80;bl_0P0[:b/2030`<080:b/[00<07QhN00L7
1`071`L00P0T92@205=CD`@0EeMG0P1JFUX205eMG@@0Fe]K1P1PH60206ATI080GUiN0P1VIVH00`1P
H600G5aL05aLG002061PH080GEeM0P1JFUX205mOG`80HF5Q0P1NGUh605YJFP80GEeM0P1LG5`205mO
G`80HF5Q0P1OGel00`1KFe/0GUiN05iNGP0205MGE`80DE5A0P1BDU8205YJFP80EeMG0P1FEUH2065Q
H@80Fe]K0P1QHF4205UIF@80E5AD0P1ADE4405MGE`0304m?C`1BDU80DU9B0080DU9B0P1=CDd20410
@080;bl_0P0Y:BT202/[:`80<S8b0P13@d<205YJFP80HV9R0P1=CDd204A4A080C4a<0P1FEUH00`18
B4P0>CTi03Ti>@0203De=@80@d=30P0o?cl205ADE080IFEU0P1MGEd205ADE080IfMW0P1XJ6P2061P
H080IVIV0P25QHD208J6QP80LG5a00<0KFe]07emO@1mOGd00P21PH4207moO`80Ng]k0P1lO7`207]k
N`80MWIf5@3oool001<0oooo0P1eMGD206m_K`80M7Ad0P1lO7`207]kN`80KVi^0P1jNWX207emO@03
07UiN@1`L700L71`0080L71`0P1fMWH2071`L080LG5a0P1/K6`2071`L080K6a/0P1]KFd207IfMP80
N7Qh0P1lO7`207MgM`80Lg=c0P1fMWH00`1dM7@0Lg=c07=cL`0207=cL`80M7Ad0P1cLg<206YZJP80
J6QX0P1GEeL206QXJ080=cLg0P0j>SX20451@@80;bl_0P0[:b/2030`<080:b/[00<07QhN00L71`07
1`L00P0T92@205=CD`@0EeMG0P1JFUX205eMG@@0Fe]K1P1PH60206ATI080GUiN0P1VIVH00`1PH600
G5aL05aLG002061PH080GEeM0P1JFUX205mOG`80HF5Q0P1NGUh605YJFP80GEeM0P1LG5`205mOG`80
HF5Q0P1OGel00`1KFe/0GUiN05iNGP0205MGE`80DE5A0P1BDU8205YJFP80EeMG0P1FEUH2065QH@80
Fe]K0P1QHF4205UIF@80E5AD0P1ADE4405MGE`0304m?C`1BDU80DU9B0080DU9B0P1=CDd20410@080
;bl_0P0Y:BT202/[:`80<S8b0P13@d<205YJFP80HV9R0P1=CDd204A4A080C4a<0P1FEUH00`18B4P0
>CTi03Ti>@0203De=@80@d=30P0o?cl205ADE080IFEU0P1MGEd205ADE080IfMW0P1XJ6P2061PH080
IVIV0P25QHD208J6QP80LG5a00<0KFe]07emO@1mOGd00P21PH4207moO`80Ng]k0P1lO7`207]kN`80
MWIf5@3oool001<0oooo0P1_Kfl207YjNP80MWIf0P1dM7@207IfMP80NGUi0P1dM7@206i^KP0307Ad
M01hN7P0N7Qh0080N7Qh0P1aLG4206][J`80Lg=c0P1kNg/207inOP80O7al0P1nOWh207EeM@80K6a/
0P1^KVh2071`L080M7Ad0P1gMgL00`1cLg<0MWIf07IfMP0207IfMP80LW9b0P1aLG4207QhN080Lg=c
0P1VIVH2071`L080@D510P16ATH20492@P80=CDe0P0];Bd202h^;P809bLW00<061PH01/K6`0K6a/0
0P0:2PX2030`<080F5QH0P1SHf<205iNGP80H61P0P1NGUh8061PH080GEeM0P1SHf<206IVIP0305iN
GP1PH600H61P00H0H61P0P1QHF42061PH080GUiN0P1PH60206=SH`80GEeM0P1NGUh205UIF@80FUYJ
101HF5P00`1JFUX0Fe]K05]KF`0205MGE`80FUYJ0P1KFe/205MGE`80DE5A0P1?Cdl2051@D080E5AD
0P1BDU8205aLG080D51@101EEED2059BDP0304Y:BP1>CTh0CTi>0080BTY:0P0d=3@201lO7`80:RXZ
0P0L71`203@d=080ATI60P1@D50205YJFP80Bd];0P15ADD204e=C@80B4Q80P1HF5P00`1EEED0Fe]K
05]KF`02065QH@80IFEU0P1SHf<2061PH080Fe]K0P1IFET406YZJP80H61P0P1OGel206e]K@80Jf][
0P1RHV8206m_K`0307YjNP1fMWH0MWIf0080NGUi0P1eMGD207AdM080L71`0P1/K6`207=cLaD0oooo
000C0?ooo`80Kfm_0P1jNWX207IfMP80M7Ad0P1fMWH207UiN@80M7Ad0P1^KVh00`1dM7@0N7Qh07Qh
N00207QhN080LG5a0P1[Jf/207=cL`80Ng]k0P1nOWh207alO080OWin0P1eMGD206a/K080KVi^0P1`
L70207AdM080MgMg00<0Lg=c07IfMP1fMWH00P1fMWH2079bLP80LG5a0P1hN7P207=cL`80IVIV0P1`
L7020451@@80ATI60P12@T8203De=@80;Bd]0P0^;Rh202LW9`0301PH600K6a/06a/K00802PX:0P0`
<30205QHF080Hf=S0P1NGUh2061PH080GUiN201PH60205eMG@80Hf=S0P1VIVH00`1NGUh0H61P061P
H006061PH080HF5Q0P1PH60205iNGP80H61P0P1SHf<205eMG@80GUiN0P1IFET205YJFP@0F5QH00<0
FUYJ05]KF`1KFe/00P1GEeL205YJFP80Fe]K0P1GEeL2055AD@80Cdm?0P1@D50205ADE080DU9B0P1L
G5`2051@D0@0EEEE0P1BDU800`1:BTX0CTi>04i>CP0204Y:BP80=3@d0P0O7al202XZ:P8071`L0P0d
=3@204I6AP80D51@0P1JFUX204];B`80ADE50P1=CDd204Q8B080F5QH00<0EEEE05]KF`1KFe/00P1Q
HF4206EUI@80Hf=S0P1PH60205]KF`80FEUI101ZJVX2061PH080GemO0P1]KFd206][J`80HV9R0P1_
Kfl00`1jNWX0MWIf07IfMP0207UiN@80MGEe0P1dM7@2071`L080K6a/0P1cLg<E0?ooo`004`3oool2
0820P080O7al0P1^KVh207IfMP80L71`0P1dM7@207QhN080O7al00<0M7Ad06m_K`1_Kfl00P1/K6`2
07=cL`80O7al0P1eMGD206a/K080KFe]0P1_Kfl207AdM080N7Qh0P1dM7@207EeM@80NGUi0P1cLg<2
06i^KP0306m_K`1iNGT0NGUi0080MGEe0P1bLW8207=cL`80Kfm_101ZJVX206=SH`80?Cdm0P14A4@2
03De=@80<C4a0P0g=cL2030`<0807alO00<05aLG01@D500D51@00P0P82020820P080F5QH0P1LG5`2
05iNGP80HF5Q0P1OGel205iNGP80IFEU0P1RHV8206IVIP80HV9R0P1MGEd205YJFP0305aLG01PH600
H61P0080FUYJ0P1NGUh2061PH080G5aL0P1NGUh205]KF`80GUiN0P1KFe/205MGE`80FEUI0P1BDU82
05QHF080FUYJ0`1LG5`405IFEP80EEEE0P1@D50404i>CP80DU9B0P1IFET206EUI@80FUYJ0P16ATH2
0451@@80BDU90P18B4P204U9B@<0?Shn0P0`<30203Lg=`808b<S0P0_;bl203Lg=`80ADE50P0`<302
0410@080Bd];0P11@D420492@P80ATI60P1EEED205IFEP0305QHF01SHf<0Hf=S0080EEEE0P1FEUH2
06UYJ@80GUiN0P1JFUX206IVIP80IfMW0P1PH60205iNGP80Kfm_0P1fMWH206a/K080Ogmo0P20P800
0`21PH40Ogmo07moO`0207EeM@80L71`0P1gMgL2071`L080NGUi0P1kNg/E0?ooo`004`3oool20820
P080O7al0P1^KVh207IfMP80L71`0P1dM7@207QhN080O7al00<0M7Ad06m_K`1_Kfl00P1/K6`207=c
L`80O7al0P1eMGD206a/K080KFe]0P1_Kfl207AdM080N7Qh0P1dM7@207EeM@80NGUi0P1cLg<206i^
KP0306m_K`1iNGT0NGUi0080MGEe0P1bLW8207=cL`80Kfm_101ZJVX206=SH`80?Cdm0P14A4@203De
=@80<C4a0P0g=cL2030`<0807alO00<05aLG01@D500D51@00P0P82020820P080F5QH0P1LG5`205iN
GP80HF5Q0P1OGel205iNGP80IFEU0P1RHV8206IVIP80HV9R0P1MGEd205YJFP0305aLG01PH600H61P
0080FUYJ0P1NGUh2061PH080G5aL0P1NGUh205]KF`80GUiN0P1KFe/205MGE`80FEUI0P1BDU8205QH
F080FUYJ0`1LG5`405IFEP80EEEE0P1@D50404i>CP80DU9B0P1IFET206EUI@80FUYJ0P16ATH20451
@@80BDU90P18B4P204U9B@<0?Shn0P0`<30203Lg=`808b<S0P0_;bl203Lg=`80ADE50P0`<3020410
@080Bd];0P11@D420492@P80ATI60P1EEED205IFEP0305QHF01SHf<0Hf=S0080EEEE0P1FEUH206UY
J@80GUiN0P1JFUX206IVIP80IfMW0P1PH60205iNGP80Kfm_0P1fMWH206a/K080Ogmo0P20P8000`21
PH40Ogmo07moO`0207EeM@80L71`0P1gMgL2071`L080NGUi0P1kNg/E0?ooo`004`3oool207IfMP@0
L71`0P1bLW82071`L080Kfm_0P1cLg<206i^KP0307EeM@1cLg<0Lg=c0080LW9b0P1kNg/207UiN@80
Lg=c0P1lO7`207IfMP80N7Qh0P1dM7@206m_K`80LG5a0P1jNWX2075aL@80KVi^0P1kNg/00`1mOGd0
M7Ad07AdM00207IfMP80M7Ad0P1eMGD2079bLP80L71`0P1RHV820492@P80>SXj0P14A4@203dm?@80
<c<c0P0m?Cd202h^;P80;2`/00<0820P024Q8@0Q8B400P0];Bd201lO7`80>c/k0P1SHf<2065QH@80
J6QX0P1QHF4205iNGP80IFEU0P1NGUh205eMG@80G5aL1@1PH60205eMG@80HF5Q0P1PH60205MGE`80
FEUI0P1PH60205iNGP80GEeM0P1KFe/2061PH080EeMG0P1QHF4205MGE`80FEUI0P1QHF400`1MGEd0
F5QH05QHF00205UIF@80DU9B0P1CDe<204E5A@80B4Q80P1IFET206YZJP80F5QH0P0h>3P203lo?`80
CTi>0P19BDT204e=C@80AdM700<0>3Ph03Ti>@0i>CT00P0/;2`202/[:`80B4Q80P1;Bd/2055AD@80
DU9B0P1KFe/206EUI@80EeMG0P1<C4`204i>CP80C4a<0P1DE5@204=3@`030492@P14A4@0A4A40080
BDU90P1GEeL204M7A`80@4100P1RHV8206IVIP@0GUiN0P1/K6`207EeM@80Ng]k0P1lO7`20820P080
Ng]k00<0LW9b06UYJ@1YJFT00P1dM7@207]kN`80M7Ad0P1aLG4207UiN@80L71`5@3oool001<0oooo
0P1fMWH4071`L080LW9b0P1`L70206m_K`80Lg=c0P1^KVh00`1eMGD0Lg=c07=cL`02079bLP80Ng]k
0P1iNGT207=cL`80O7al0P1fMWH207QhN080M7Ad0P1_Kfl2075aL@80NWYj0P1aLG4206i^KP80Ng]k
00<0OGem07AdM01dM7@00P1fMWH207AdM080MGEe0P1bLW82071`L080HV9R0P12@T8203Xj>P80A4A4
0P0m?Cd203<c<`80?Cdm0P0^;Rh202`/;003020P800Q8B408B4Q0080;Bd]0P0O7al203/k>`80Hf=S
0P1QHF4206QXJ080HF5Q0P1NGUh206EUI@80GUiN0P1MGEd205aLG0D0H61P0P1MGEd2065QH@80H61P
0P1GEeL205UIF@80H61P0P1NGUh205eMG@80Fe]K0P1PH60205MGE`80HF5Q0P1GEeL205UIF@80HF5Q
00<0GEeM05QHF01HF5P00P1IFET2059BDP80De=C0P15ADD204Q8B080FEUI0P1ZJVX205QHF080>3Ph
0P0o?cl204i>CP80BDU90P1=CDd204M7A`0303Ph>00i>CT0>CTi0080;2`/0P0[:b/204Q8B080Bd];
0P1ADE42059BDP80Fe]K0P1UIFD205MGE`80C4a<0P1>CTh204a<C080E5AD0P13@d<00`12@T80A4A4
04A4A00204U9B@80EeMG0P17AdL20410@080HV9R0P1VIVH405iNGP80K6a/0P1eMGD207]kN`80O7al
0P20P80207]kN`03079bLP1YJFT0JFUY0080M7Ad0P1kNg/207AdM080LG5a0P1iNGT2071`L1D0oooo
000C0?ooo`80MWIf0P1hN7P207=cL`80NWYj101dM7@207=cL`80MgMg00<0NWYj075aL@1aLG40101k
Ng/207IfMP80N7Qh0P1aLG42071`L080N7Qh0P1`L70207=cL`80Kfm_0P1]KFd207IfMP80MGEe0P1b
LW800`1dM7@0L71`071`L002075aL@@0Kfm_0P1XJ6P206][J`80FUYJ0P1<C4`203dm?@80@D510P0g
=cL20451@@80?clo0P0V9RH202TY:@03028R8P0/;2`0;2`/0080;Bd]0P0F5QH206EUI@80HF5Q0P1P
H60206EUI@80G5aL101NGUh205IFEP80FUYJ0P1NGUh405YJFP0305iNGP1PH600H61P0080GEeM0P1J
FUX205iNGP80GemO0P1KFe/205mOG`80Fe]K0P1JFUX205UIF@80H61P0P1EEED205aLG080F5QH0P1B
DU800`1?Cdl0DU9B059BDP02051@D080Bd];0P13@d<204a<C080E5AD0P1YJFT206IVIP80>c/k0P12
@T8205MGE`80E5AD0P16ATH203De=@80:2PX00<08b<S03`l?00l?3`00P0j>SX203Ph>080=cLg0P12
@T8204U9B@80=SHf0P13@d<204e=C@80C4a<0P18B4P204A4A080=3@d0P1IFET204m?C`0306=SH`1@
D500D51@0080Jf][0P1FEUH205EEE@80L71`0P1^KVh405iNGP80IVIV0P1UIFD207MgM`80N7Qh0P1`
L70407MgM`0306i^KP1kNg/0Ng]k0080O7al0P1fMWH2071`L080N7Qh0P1iNGT207QhN1D0oooo000C
0?ooo`80MWIf0P1hN7P207=cL`80NWYj101dM7@207=cL`80MgMg00<0NWYj075aL@1aLG40101kNg/2
07IfMP80N7Qh0P1aLG42071`L080N7Qh0P1`L70207=cL`80Kfm_0P1]KFd207IfMP80MGEe0P1bLW80
0`1dM7@0L71`071`L002075aL@@0Kfm_0P1XJ6P206][J`80FUYJ0P1<C4`203dm?@80@D510P0g=cL2
0451@@80?clo0P0V9RH202TY:@03028R8P0/;2`0;2`/0080;Bd]0P0F5QH206EUI@80HF5Q0P1PH602
06EUI@80G5aL101NGUh205IFEP80FUYJ0P1NGUh405YJFP0305iNGP1PH600H61P0080GEeM0P1JFUX2
05iNGP80GemO0P1KFe/205mOG`80Fe]K0P1JFUX205UIF@80H61P0P1EEED205aLG080F5QH0P1BDU80
0`1?Cdl0DU9B059BDP02051@D080Bd];0P13@d<204a<C080E5AD0P1YJFT206IVIP80>c/k0P12@T82
05MGE`80E5AD0P16ATH203De=@80:2PX00<08b<S03`l?00l?3`00P0j>SX203Ph>080=cLg0P12@T82
04U9B@80=SHf0P13@d<204e=C@80C4a<0P18B4P204A4A080=3@d0P1IFET204m?C`0306=SH`1@D500
D51@0080Jf][0P1FEUH205EEE@80L71`0P1^KVh405iNGP80IVIV0P1UIFD207MgM`80N7Qh0P1`L704
07MgM`0306i^KP1kNg/0Ng]k0080O7al0P1fMWH2071`L080N7Qh0P1iNGT207QhN1D0oooo000C0?oo
o`80MWIf0P1^KVh207IfMP80Lg=c0P1fMWH207emO@80Ng]k0P1iNGT00`1fMWH0Lg=c07=cL`0207Qh
N0H0MWIf101cLg<207MgM`80NGUi0P1gMgL207EeM@80Lg=c0P1gMgL207=cL`80Ng]k00<0LG5a06e]
K@1]KFd00P1iNGT207alO080MWIf0P1^KVh206m_K`80ATI60P19BDT20410@080>3Ph0P0c<c<202l_
;`80;Bd]0P0R8R8202XZ:P0303<c<`0g=cL0=cLg00808R8R0P0=3@d207inOP80H61P0P1MGEd205]K
F`80G5aL0P1OGel2061PH0@0G5aL0P1PH60405aLG00305YJFP1HF5P0F5QH0080FEUI0P1LG5`205iN
GP80GemO0P1NGUh205UIF@80G5aL0P1MGEd205aLG080DE5A0P1@D50205ADE080EEEE0P1GEeL00`1F
EUH0F5QH05QHF00204i>CP80C4a<0P15ADD204A4A080Fe]K0P1LG5`203@d=080<S8b0P11@D420410
@080>SXj0P0c<c<203@d=0809bLW00<0=cLg04U9B@19BDT00P0i>CT203`l?080?Shn0P0i>CT2034a
<@80=CDe0P1:BTX204m?C`80CDe=0P15ADD204I6AP80EeMG0P1NGUh204I6AP0304m?C`16ATH0ATI6
0080@d=30P18B4P205QHF080Cdm?0P1IFET205mOG`80H61P0P1eMGD2092@T080Ph>30P1`L70207Ee
M@80OWin0P1iNGT00`1dM7@0NWYj07YjNP0207IfMP80KVi^0P1`L702075aL@80Lg=c0P1fMWHE0?oo
o`004`3oool207IfMP80KVi^0P1fMWH207=cL`80MWIf0P1mOGd207]kN`80NGUi00<0MWIf07=cL`1c
Lg<00P1hN7P607IfMP@0Lg=c0P1gMgL207UiN@80MgMg0P1eMGD207=cL`80MgMg0P1cLg<207]kN`03
075aL@1]KFd0KFe]0080NGUi0P1lO7`207IfMP80KVi^0P1_Kfl204I6AP80BDU90P10@40203Ph>080
<c<c0P0_;bl202d];@808R8R0P0Z:RX00`0c<c<0=cLg03Lg=`02028R8P803@d=0P1nOWh2061PH080
GEeM0P1KFe/205aLG080GemO0P1PH60405aLG080H61P101LG5`00`1JFUX0F5QH05QHF00205UIF@80
G5aL0P1NGUh205mOG`80GUiN0P1IFET205aLG080GEeM0P1LG5`2055AD@80D51@0P1DE5@205EEE@80
EeMG00<0EUIF05QHF01HF5P00P1>CTh204a<C080ADE50P14A4@205]KF`80G5aL0P0d=3@2038b<P80
@D510P10@40203Xj>P80<c<c0P0d=3@202LW9`0303Lg=`19BDT0BDU90080>CTi0P0l?3`203hn?P80
>CTi0P0a<C4203De=@80BTY:0P1?Cdl204e=C@80ADE50P16ATH205MGE`80GUiN0P16ATH00`1?Cdl0
ATI604I6AP0204=3@`80B4Q80P1HF5P204m?C`80FEUI0P1OGel2061PH080MGEe0P2@T90208>3P`80
L71`0P1eMGD207inOP80NGUi00<0M7Ad07YjNP1jNWX00P1fMWH206i^KP80L71`0P1aLG4207=cL`80
MWIf5@3oool001<0oooo0P1fMWH207UiN@80Ng]k0P1`L70207QhN080MWIf0P1`L70207AdM003071`
L01fMWH0MWIf00@0M7Ad101fMWH207QhN080MWIf0P1cLg<206m_K`80L71`0P1dM7@207]kN`80O7al
0P1bLW8207MgM`03071`L01kNg/0Ng]k0080Ng]k0P1fMWH2071`L080K6a/0P1OGel204I6AP80BDU9
0P10@4020451@@80?3`l0P0m?Cd202LW9`808B4Q0P0`<3000`0d=3@0:RXZ02XZ:P0201dM7@80820P
0P2>SXh205aLG080JFUY0P1RHV8205QHF0H0GUiN0P1TI6@205eMG@80Fe]K0P1PH6000`1NGUh0EEEE
05EEE@0205YJFP80GEeM0P1DE5@2051@D080DE5A0P1CDe<205]KF`80DE5A0P1CDe<205ADE080F5QH
0P1KFe/2059BDP80Cdm?00<0D51@04Q8B018B4P00P19BDT203dm?@80@T920P1>CTh2055AD@80?Shn
0P0h>3P204=3@`80ATI60P14A4@203/k>`80:BTY0P0_;bl203Ph>00303lo?`1CDe<0De=C0080BTY:
0P1<C4`203hn?P80>CTi0P1BDU8204m?C`80CTi>0P16ATH204A4A080Bd];0P1XJ6P205mOG`80E5AD
0P18B4P00`1:BTX0BDU904U9B@0204e=C@80D51@0P1WIfL2079bLP80M7Ad0P1RHV8207IfMP80O7al
0P1aLG42071`L080LG5a0P1cLg<2075aL@80JFUY00<0M7Ad07UiN@1iNGT00P1`L70207MgM`80OGem
0P1lO7`207]kN`80MWIf5@3oool001<0oooo0P1fMWH207UiN@80Ng]k0P1`L70207QhN080MWIf0P1`
L70207AdM003071`L01fMWH0MWIf00@0M7Ad101fMWH207QhN080MWIf0P1cLg<206m_K`80L71`0P1d
M7@207]kN`80O7al0P1bLW8207MgM`03071`L01kNg/0Ng]k0080Ng]k0P1fMWH2071`L080K6a/0P1O
Gel204I6AP80BDU90P10@4020451@@80?3`l0P0m?Cd202LW9`808B4Q0P0`<3000`0d=3@0:RXZ02XZ
:P0201dM7@80820P0P2>SXh205aLG080JFUY0P1RHV8205QHF0H0GUiN0P1TI6@205eMG@80Fe]K0P1P
H6000`1NGUh0EEEE05EEE@0205YJFP80GEeM0P1DE5@2051@D080DE5A0P1CDe<205]KF`80DE5A0P1C
De<205ADE080F5QH0P1KFe/2059BDP80Cdm?00<0D51@04Q8B018B4P00P19BDT203dm?@80@T920P1>
CTh2055AD@80?Shn0P0h>3P204=3@`80ATI60P14A4@203/k>`80:BTY0P0_;bl203Ph>00303lo?`1C
De<0De=C0080BTY:0P1<C4`203hn?P80>CTi0P1BDU8204m?C`80CTi>0P16ATH204A4A080Bd];0P1X
J6P205mOG`80E5AD0P18B4P00`1:BTX0BDU904U9B@0204e=C@80D51@0P1WIfL2079bLP80M7Ad0P1R
HV8207IfMP80O7al0P1aLG42071`L080LG5a0P1cLg<2075aL@80JFUY00<0M7Ad07UiN@1iNGT00P1`
L70207MgM`80OGem0P1lO7`207]kN`80MWIf5@3oool001<0oooo0P1fMWH2071`L080M7Ad0P1iNGT2
07]kN`@0L71`0P1gMgL00`1hN7P0M7Ad07AdM00207IfMP80NGUi101fMWH2071`L080MWIf0P1eMGD2
07AdM080NGUi0P1kNg/407AdM0@0LW9b00<0LG5a07=cL`1cLg<00P1_Kfl206e]K@80KVi^0P1]KFd2
06=SH`80Cdm?0P17AdL20410@080>CTi0P0f=SH203Ph>080<30`0P0c<c<204M7A`03034a<@0H61P0
61PH00806ATI0P0H61P207alO080Fe]K0P1MGEd204e=C@80Fe]K0P1SHf<2061PH080E5AD0P1?Cdl2
05MGE`80FUYJ0P1CDe<00`1ADE40EEEE05EEE@0205=CD`80DE5A101EEED205ADE080F5QH0P1?Cdl4
05=CD`80Cdm?0P1ADE44051@D080E5AD0`1<C4`204U9B@@0ATI60P1DE5@204I6AP80<c<c0P0^;Rh2
03/k>`80=SHf0P0i>CT202TY:@80>c/k0P11@D4303`l?080@d=30P19BDT204e=C@80@4100P1;Bd/2
04E5A@80?Shn0P1:BTX203Ph>080A4A40P1<C4`205]KF`80FUYJ0P1PH60204i>CP0304e=C@1PH600
H61P0080DE5A0P1BDU8206EUI@80GUiN0P1RHV8207=cL`80QHF50P24Q8@207MgM`80Lg=c0P1]KFd2
07IfMP80M7Ad0P1kNg/00`1lO7`0MWIf07IfMP02079bLP80Kfm_0P1^KVh206a/K080KVi^0P1dM7@E
0?ooo`004`3oool207IfMP80N7Qh0P1iNGT2071`L080M7Ad0P1hN7P207EeM@80MgMg00<0MWIf07Qh
N01hN7P0101dM7@407IfMP80N7Qh0P1iNGT207QhN080Ng]k0P1iNGT207IfMP80LW9b0P1gMgL2079b
LP80M7Ad00<0NGUi07=cL`1cLg<00P1`L70207UiN@80OGem0P1_Kfl2055AD@80?Shn0P1=CDd204Q8
B080?3`l0P0i>CT203Xj>P809RHV0P0f=SH202d];@0301hN7P0E5AD05ADE00808B4Q0P0J6QX207mo
O`80GemO0P1QHF4206=SH`80IVIV0P1HF5P205eMG@80H61P0P1LG5`205mOG`80EUIF0P1CDe<00`1H
F5P0EEEE05EEE@02055AD@80EEEE0P1@D50205ADE080De=C0P1@D502055AD@80F5QH0P1GEeL205EE
E@80Cdm?0P1;Bd/2059BDP<0CDe=0P1ADE4204];B`80@T920P1?Cdl204];B`80=CDe0P0c<c<203`l
?080=cLg0P0b<S8202LW9`80<C4a0P0h>3P202@T9080;Bd]00<0>SXj05=CD`1CDe<00P1@D50204];
B`80FEUI0P1;Bd/204=3@`80?3`l0P0f=SH204M7A`80EeMG0P14A4@205=CD`80EEEE0P1<C4`204A4
A003061PH01TI6@0I6AT0080DE5A0P1SHf<206UYJ@80GUiN0P1cLg<207]kN`80MGEe0P1RHV8206IV
IP80Lg=c0P1iNGT207]kN`80MGEe0P1hN7P00`1`L700M7Ad07AdM00207QhN080O7al0P1gMgL207Ee
M@80Ng]k0P1dM7@E0?ooo`004`3oool207IfMP80N7Qh0P1iNGT2071`L080M7Ad0P1hN7P207EeM@80
MgMg00<0MWIf07QhN01hN7P0101dM7@407IfMP80N7Qh0P1iNGT207QhN080Ng]k0P1iNGT207IfMP80
LW9b0P1gMgL2079bLP80M7Ad00<0NGUi07=cL`1cLg<00P1`L70207UiN@80OGem0P1_Kfl2055AD@80
?Shn0P1=CDd204Q8B080?3`l0P0i>CT203Xj>P809RHV0P0f=SH202d];@0301hN7P0E5AD05ADE0080
8B4Q0P0J6QX207moO`80GemO0P1QHF4206=SH`80IVIV0P1HF5P205eMG@80H61P0P1LG5`205mOG`80
EUIF0P1CDe<00`1HF5P0EEEE05EEE@02055AD@80EEEE0P1@D50205ADE080De=C0P1@D502055AD@80
F5QH0P1GEeL205EEE@80Cdm?0P1;Bd/2059BDP<0CDe=0P1ADE4204];B`80@T920P1?Cdl204];B`80
=CDe0P0c<c<203`l?080=cLg0P0b<S8202LW9`80<C4a0P0h>3P202@T9080;Bd]00<0>SXj05=CD`1C
De<00P1@D50204];B`80FEUI0P1;Bd/204=3@`80?3`l0P0f=SH204M7A`80EeMG0P14A4@205=CD`80
EEEE0P1<C4`204A4A003061PH01TI6@0I6AT0080DE5A0P1SHf<206UYJ@80GUiN0P1cLg<207]kN`80
MGEe0P1RHV8206IVIP80Lg=c0P1iNGT207]kN`80MGEe0P1hN7P00`1`L700M7Ad07AdM00207QhN080
O7al0P1gMgL207EeM@80Ng]k0P1dM7@E0?ooo`004`3oool607IfMP80N7Qh0P1dM7@206m_K`80MWIf
0P1dM7@00`1/K6`0Lg=c07=cL`0207QhN080NGUi0P1fMWH2071`L080M7Ad201fMWH2071`L080MWIf
0P1iNGT2079bLP80Kfm_00<0L71`06a/K01/K6`00P1jNWX207EeM@80KFe]0P1bLW8204Q8B080ADE5
0P12@T8203hn?P80;2`/0P0b<S8202/[:`80:2PX0P0i>CT202/[:`0302<S8`0Q8B408B4Q0080:b/[
0P0O7al208>3P`80De=C0P1JFUX205UIF@80GEeM0P1JFUX205ADE080FEUI101GEeL205EEE@80EeMG
00<0DU9B051@D01@D5000P1CDe<204e=C@80Bd];0P1ADE4204a<C080CDe=0P1CDe<2059BDP80D51@
0P1:BTX204i>CP80Cdm?0P1>CTh204a<C003051@D014A4@0A4A40080@d=30P12@T8204m?C`80@T92
0P0g=cL203Hf=P@0<c<c0P0`<30203`l?080?Shn0P0/;2`202d];@80>3Ph00<0?3`l0451@@11@D40
0P16ATH204=3@`80ATI60P14A4@204e=C@80?clo0P0n?Sh203De=@80?Cdm0P1EEED205YJFP80BTY:
0P1GEeL206=SH`03069RHP13@d<0@d=30080AdM70P1JFUX2069RHP80J6QX0P1hN7P206a/K080Kfm_
0P1lO7`207inOP80Kfm_0P1cLg<207UiN@80MGEe0P1gMgL00`1hN7P0NGUi07UiN@0407IfMP80LW9b
101iNGT2079bLQD0oooo000C0?ooo`H0MWIf0P1hN7P207AdM080Kfm_0P1fMWH207AdM00306a/K01c
Lg<0Lg=c0080N7Qh0P1iNGT207IfMP80L71`0P1dM7@807IfMP80L71`0P1fMWH207UiN@80LW9b0P1_
Kfl00`1`L700K6a/06a/K00207YjNP80MGEe0P1]KFd2079bLP80B4Q80P15ADD20492@P80?Shn0P0/
;2`2038b<P80:b/[0P0X:2P203Ti>@80:b/[00<08b<S024Q8@0Q8B400P0[:b/201lO7`80Ph>30P1C
De<205YJFP80FEUI0P1MGEd205YJFP80E5AD0P1IFET405MGE`80EEEE0P1GEeL00`1BDU80D51@051@
D00205=CD`80CDe=0P1;Bd/2055AD@80C4a<0P1=CDd205=CD`80DU9B0P1@D50204Y:BP80CTi>0P1?
Cdl204i>CP80C4a<00<0D51@04A4A014A4@00P13@d<20492@P80Cdm?0P12@T8203Lg=`80=SHf100c
<c<2030`<080?3`l0P0n?Sh202`/;080;Bd]0P0h>3P00`0l?3`0@D510451@@0204I6AP80@d=30P16
ATH204A4A080CDe=0P0o?cl203hn?P80=CDe0P0m?Cd205EEE@80FUYJ0P1:BTX205MGE`80Hf=S00<0
HV9R04=3@`13@d<00P17AdL205YJFP80HV9R0P1XJ6P207QhN080K6a/0P1_Kfl207alO080OWin0P1_
Kfl207=cL`80NGUi0P1eMGD207MgM`0307QhN01iNGT0NGUi00@0MWIf0P1bLW8407UiN@80LW9b5@3o
ool001<0oooo0P1fMWH2071`L080Kfm_0P1dM7@2079bLP80M7Ad0P1gMgL207QhN00307alO01eMGD0
MGEe0080K6a/0P1cLg<207IfMP80LW9b0P1gMgL207IfMP80L71`0P1_Kfl406e]K@80MWIf101`L702
07]kN`0307inOP1gMgL0MgMg0080NWYj0P1^KVh2075aL@80FUYJ0P14A4@204m?C`80@D510P0k>c/2
03Lg=`80ATI60P0];Bd203Ph>080>SXj0P0a<C400`0H61P05QHF01HF5P0201/K6`807alO0P1oOgl2
05EEE@80G5aL0P1BDU8205QHF080FEUI0P1HF5P205IFEP80E5AD0P1ADE4205=CD`80D51@00<0C4a<
059BDP1BDU80101?Cdl2059BDP80ATI60P12@T8204E5A@@0BTY:101=CDd2051@D080B4Q81017AdL0
0`12@T80A4A404A4A00204A4A080ATI60P0f=SH202XZ:P@0;bl_0P0e=CD203`l?080?Shn0P0e=CD2
030`<080=3@d0P0m?Cd204=3@`030410@015ADD0ADE50080C4a<101QHF4206e]K@80De=C0P0d=3@2
03De=@80?Cdm0P1ADE420492@P80BTY:101LG5`205EEE@030492@P13@d<0@d=30080BDU90P1VIVH2
06i^KP80IfMW0P1_Kfl207=cL`80K6a/0P1`L70206YZJP@0O7al0P1gMgL207QhN080NGUi00<0MWIf
071`L01`L7000P1dM7@207IfMP80N7Qh0P1aLG4207=cL`80LW9b5@3oool001<0oooo0P1fMWH2071`
L080Kfm_0P1dM7@2079bLP80M7Ad0P1gMgL207QhN00307alO01eMGD0MGEe0080K6a/0P1cLg<207If
MP80LW9b0P1gMgL207IfMP80L71`0P1_Kfl406e]K@80MWIf101`L70207]kN`0307inOP1gMgL0MgMg
0080NWYj0P1^KVh2075aL@80FUYJ0P14A4@204m?C`80@D510P0k>c/203Lg=`80ATI60P0];Bd203Ph
>080>SXj0P0a<C400`0H61P05QHF01HF5P0201/K6`807alO0P1oOgl205EEE@80G5aL0P1BDU8205QH
F080FEUI0P1HF5P205IFEP80E5AD0P1ADE4205=CD`80D51@00<0C4a<059BDP1BDU80101?Cdl2059B
DP80ATI60P12@T8204E5A@@0BTY:101=CDd2051@D080B4Q81017AdL00`12@T80A4A404A4A00204A4
A080ATI60P0f=SH202XZ:P@0;bl_0P0e=CD203`l?080?Shn0P0e=CD2030`<080=3@d0P0m?Cd204=3
@`030410@015ADD0ADE50080C4a<101QHF4206e]K@80De=C0P0d=3@203De=@80?Cdm0P1ADE420492
@P80BTY:101LG5`205EEE@030492@P13@d<0@d=30080BDU90P1VIVH206i^KP80IfMW0P1_Kfl207=c
L`80K6a/0P1`L70206YZJP@0O7al0P1gMgL207QhN080NGUi00<0MWIf071`L01`L7000P1dM7@207If
MP80N7Qh0P1aLG4207=cL`80LW9b5@3oool001<0oooo0P1_Kfl207IfMP80Ng]k0P1dM7@2071`L080
LW9b0P1^KVh206][J`0306i^KP1fMWH0MWIf0080O7al0P1kNg/206i^KP80MGEe101dM7@2079bLP80
NGUi0P1dM7@407]kN`80N7Qh0P1kNg/207UiN@03071`L01^KVh0KVi^0080LG5a0P1`L70207AdM080
Cdm?0P19BDT204A4A080@T920P0k>c/202h^;P80<c<c0P0/;2`20410@0809bLW0P0N7Qh00`0C4a<0
5aLG01LG5`0201hN7P807AdM0P1kNg/205EEE@80GEeM0P1NGUh2061PH0@0EUIF0P1ADE4204i>CP80
D51@101BDU800`1@D500CTi>04i>CP0204a<C080D51@0P1?Cdl2055AD@80Cdm?0P1=CDd204];B`80
AdM70P1=CDd204m?C`@0BDU90P1=CDd20451@@030410@011@D40@D510080>SXj0P12@T8203Hf=P80
;bl_0P0Z:RX203Ti>@80=SHf100j>SX201dM7@806QXJ0P0Q8B4203De=@80BTY:00<0C4a<04Q8B018
B4P00P16ATH204M7A`80BTY:0P15ADD205MGE`80EEEE0P17AdL2055AD@80C4a<0P1@D50204A4A080
De=C0P1GEeL204A4A00304=3@`1=CDd0CDe=0080C4a<0P1WIfL206ATI080P8200P1iNGT2075aL@@0
LW9b0P1dM7@207emO@@0KVi^0P1cLg<207IfMP03071`L01fMWH0MWIf0080NGUi0P1fMWH2071`L080
MgMg0P1kNg/207QhN1D0oooo000C0?ooo`80Kfm_0P1fMWH207]kN`80M7Ad0P1`L702079bLP80KVi^
0P1[Jf/00`1^KVh0MWIf07IfMP0207alO080Ng]k0P1^KVh207EeM@@0M7Ad0P1bLW8207UiN@80M7Ad
101kNg/207QhN080Ng]k0P1iNGT00`1`L700KVi^06i^KP02075aL@80L71`0P1dM7@204m?C`80BDU9
0P14A4@20492@P80>c/k0P0^;Rh203<c<`80;2`/0P10@40202LW9`807QhN00<04a<C01LG5`0G5aL0
0P0N7Qh201dM7@80Ng]k0P1EEED205eMG@80GUiN0P1PH60405IFEP80DE5A0P1>CTh2051@D0@0DU9B
00<0D51@04i>CP1>CTh00P1<C4`2051@D080Cdm?0P1ADE4204m?C`80CDe=0P1;Bd/204M7A`80CDe=
0P1?Cdl404U9B@80CDe=0P11@D400`10@400@D510451@@0203Xj>P80@T920P0f=SH202l_;`80:RXZ
0P0i>CT203Hf=P@0>SXj0P0M7Ad201XJ6P808B4Q0P0e=CD204Y:BP0304a<C018B4P0B4Q80080ATI6
0P17AdL204Y:BP80ADE50P1GEeL205EEE@80AdM70P1ADE4204a<C080D51@0P14A4@205=CD`80EeMG
0P14A4@00`13@d<0CDe=04e=C@0204a<C080IfMW0P1TI6@20820P080NGUi0P1aLG44079bLP80M7Ad
0P1mOGd406i^KP80Lg=c0P1fMWH00`1`L700MWIf07IfMP0207UiN@80MWIf0P1`L70207MgM`80Ng]k
0P1hN7PE0?ooo`004`3oool207]kN`80NGUi0P1fMWH207QhN080MGEe0P1jNWX207emO@80OWin00<0
OGem07UiN@1iNGT0101fMWH207UiN@80Lg=c0P1`L70207MgM`80L71`0P1gMgL207=cL`80N7Qh0P1`
L70207AdM080L71`0P1]KFd00`1`L700NWYj07YjNP02079bLP80Lg=c0P1QHF4204M7A`80Cdm?0P10
@40203Ti>@80<S8b0P0f=SH202h^;P80;2`/0P0d=3@202HV9P80820P00<07AdM02HV9P0V9RH0100U
9BD2079bLP80DE5A0P1EEED2055AD@@0De=C0P1@D50205IFEP80EeMG0P1FEUH204e=C@80C4a<00<0
Cdm?04Q8B018B4P00P17AdL204I6AP80?3`l0P0o?cl204=3@`80@D510P1:BTX204e=C@80@4100P14
A4@204U9B@80CDe=0P11@D420410@0<0ATI60P0j>SX204e=C@80=cLg0P0T92@203Ph>080?3`l0P0c
<c<202d];@806a/K0P0L71`201HF5P80?3`l0P1EEED203Ph>00303dm?@0f=SH0=SHf0080?Shn0P1=
CDd205YJFP80EUIF0P1OGel204=3@`80C4a<0P1JFUX204a<C080D51@0P1>CTh2061PH0@0@d=300<0
@D5104A4A014A4@00P1QHF4407MgM`80M7Ad101XJ6P2079bLP80NWYj101hN7P207AdM080MgMg0P1h
N7P207IfMP0307QhN01aLG40LG5a0080Lg=c0P1`L70207IfMP@0M7Ad0P1fMWHE0?ooo`004`3oool2
07]kN`80NGUi0P1fMWH207QhN080MGEe0P1jNWX207emO@80OWin00<0OGem07UiN@1iNGT0101fMWH2
07UiN@80Lg=c0P1`L70207MgM`80L71`0P1gMgL207=cL`80N7Qh0P1`L70207AdM080L71`0P1]KFd0
0`1`L700NWYj07YjNP02079bLP80Lg=c0P1QHF4204M7A`80Cdm?0P10@40203Ti>@80<S8b0P0f=SH2
02h^;P80;2`/0P0d=3@202HV9P80820P00<07AdM02HV9P0V9RH0100U9BD2079bLP80DE5A0P1EEED2
055AD@@0De=C0P1@D50205IFEP80EeMG0P1FEUH204e=C@80C4a<00<0Cdm?04Q8B018B4P00P17AdL2
04I6AP80?3`l0P0o?cl204=3@`80@D510P1:BTX204e=C@80@4100P14A4@204U9B@80CDe=0P11@D42
0410@0<0ATI60P0j>SX204e=C@80=cLg0P0T92@203Ph>080?3`l0P0c<c<202d];@806a/K0P0L71`2
01HF5P80?3`l0P1EEED203Ph>00303dm?@0f=SH0=SHf0080?Shn0P1=CDd205YJFP80EUIF0P1OGel2
04=3@`80C4a<0P1JFUX204a<C080D51@0P1>CTh2061PH0@0@d=300<0@D5104A4A014A4@00P1QHF44
07MgM`80M7Ad101XJ6P2079bLP80NWYj101hN7P207AdM080MgMg0P1hN7P207IfMP0307QhN01aLG40
LG5a0080Lg=c0P1`L70207IfMP@0M7Ad0P1fMWHE0?ooo`004`3oool407IfMP80L71`0P1dM7@4079b
LP80K6a/0P1^KVh00`1_Kfl0M7Ad07AdM002071`L080M7Ad0P1fMWH207QhN080O7al0P1iNGT6071`
L080Kfm_0P1eMGD207UiN@80LW9b0P1jNWX00`1lO7`0LG5a075aL@02075aL@80LW9b0P1BDU8204I6
AP80A4A40P0d=3@203`l?080=CDe100f=SH2038b<P80;bl_0P0J6QX201`L700301dM7@0Q8B408B4Q
00808B4Q0P0P820206m_K`80EeMG0P1HF5P206MWI`80GemO0P1KFe/205UIF@80GUiN0P1IFET205]K
F`80GemO0P1MGEd00`1KFe/0EEEE05EEE@0204Y:BP80?clo0P17AdL20451@@80?clo1012@T8203dm
?@80AdM70P1;Bd/203lo?`80?Cdm0P10@40203dm?@0303/k>`0b<S80<S8b0080=cLg0P17AdL202`/
;0808R8R0P0f=SH203Xj>P809BDU0P0M7Ad201`L7080:2PX0P0h>3P20492@P80ADE50P17AdL00`12
@T80@d=304=3@`0203Ph>080Bd];0P1@D50205QHF080B4Q80P13@d<404M7A`@0ATI60P1NGUh2065Q
H@80B4Q80P1DE5@00`1ADE40JFUY06UYJ@0206=SH`80I6AT0P24Q8@206i^KP80J6QX0P1jNWX207If
MP80NGUi0P1mOGd207YjNP80N7Qh0P1eMGD207MgM`<0MWIf0P1iNGT207]kN`80N7Qh0P1iNGT2079b
LP80MgMg0P1`L70E0?ooo`004`3oool407IfMP80L71`0P1dM7@4079bLP80K6a/0P1^KVh00`1_Kfl0
M7Ad07AdM002071`L080M7Ad0P1fMWH207QhN080O7al0P1iNGT6071`L080Kfm_0P1eMGD207UiN@80
LW9b0P1jNWX00`1lO7`0LG5a075aL@02075aL@80LW9b0P1BDU8204I6AP80A4A40P0d=3@203`l?080
=CDe100f=SH2038b<P80;bl_0P0J6QX201`L700301dM7@0Q8B408B4Q00808B4Q0P0P820206m_K`80
EeMG0P1HF5P206MWI`80GemO0P1KFe/205UIF@80GUiN0P1IFET205]KF`80GemO0P1MGEd00`1KFe/0
EEEE05EEE@0204Y:BP80?clo0P17AdL20451@@80?clo1012@T8203dm?@80AdM70P1;Bd/203lo?`80
?Cdm0P10@40203dm?@0303/k>`0b<S80<S8b0080=cLg0P17AdL202`/;0808R8R0P0f=SH203Xj>P80
9BDU0P0M7Ad201`L7080:2PX0P0h>3P20492@P80ADE50P17AdL00`12@T80@d=304=3@`0203Ph>080
Bd];0P1@D50205QHF080B4Q80P13@d<404M7A`@0ATI60P1NGUh2065QH@80B4Q80P1DE5@00`1ADE40
JFUY06UYJ@0206=SH`80I6AT0P24Q8@206i^KP80J6QX0P1jNWX207IfMP80NGUi0P1mOGd207YjNP80
N7Qh0P1eMGD207MgM`<0MWIf0P1iNGT207]kN`80N7Qh0P1iNGT2079bLP80MgMg0P1`L70E0?ooo`00
4`3oool206m_K`80M7Ad0P1hN7P206m_K`80JVYZ0P1gMgL207IfMP<0Ng]k0P1dM7@2071`L080MgMg
0P1fMWH206i^KP80Lg=c0P1`L70207MgM`80MWIf0P1dM7@207=cL`80N7Qh0P1fMWH4079bLP0306a/
K01^KVh0KVi^0080LW9b0P1YJFT205IFEP80D51@0P15ADD203/k>`80?3`l0P0h>3P203@d=080@d=3
0P0];Bd2030`<0804A4A0P0T92@3028R8P807AdM0P0b<S8207UiN@80KVi^0P1gMgL207=cL`80Kfm_
0P1dM7@207EeM@80JVYZ0P1VIVH206QXJ080H61P0P1NGUh00`1QHF40H61P061PH002069RHP80H61P
0P15ADD203hn?P80@D511010@40203`l?080>CTi0P0f=SH20410@080@D510P0l?3`20410@00303`l
?00f=SH0=SHf0080=cLg0P11@D42020P80809bLW0P0i>CT202`/;0807alO0P0J6QX201hN7P80@T92
0P0Y:BT203@d=080B4Q80P12@T800`0m?Cd0=CDe03De=@0203/k>`80D51@0P1ADE4205]KF`80H61P
0P1XJ6P205ADE080DU9B0P0l?3`202l_;`80EEEE0P1FEUH204M7A`80BTY:00<0G5aL065QH@1QHF40
0P1XJ6P209JFUP80PH610P1^KVh207YjNP80NGUi0P1fMWH207MgM`80M7Ad0P1`L70207AdM080N7Qh
0P1iNGT207IfMP03071`L01dM7@0M7Ad00H0MWIf0P1hN7P207AdM080KVi^5@3oool001<0oooo0P1_
Kfl207AdM080N7Qh0P1_Kfl206YZJP80MgMg0P1fMWH307]kN`80M7Ad0P1`L70207MgM`80MWIf0P1^
KVh207=cL`80L71`0P1gMgL207IfMP80M7Ad0P1cLg<207QhN080MWIf101bLW800`1/K6`0KVi^06i^
KP02079bLP80JFUY0P1FEUH2051@D080ADE50P0k>c/203`l?080>3Ph0P0d=3@204=3@`80;Bd]0P0`
<302014A4@8092@T0`0R8R8201dM7@80<S8b0P1iNGT206i^KP80MgMg0P1cLg<206m_K`80M7Ad0P1e
MGD206YZJP80IVIV0P1XJ6P2061PH080GUiN00<0HF5Q061PH01PH6000P1RHV82061PH080ADE50P0n
?Sh20451@@@0@4100P0l?3`203Ti>@80=SHf0P10@4020451@@80?3`l0P10@4000`0l?3`0=SHf03Hf
=P0203Lg=`80@D510P0P820202LW9`80>CTi0P0/;2`201lO7`806QXJ0P0N7Qh20492@P80:BTY0P0d
=3@204Q8B080@T9200<0?Cdm03De=@0e=CD00P0k>c/2051@D080DE5A0P1KFe/2061PH080J6QX0P1D
E5@2059BDP80?3`l0P0_;bl205EEE@80EUIF0P17AdL204Y:BP0305aLG01QHF40HF5Q0080J6QX0P2F
UYH20861P@80KVi^0P1jNWX207UiN@80MWIf0P1gMgL207AdM080L71`0P1dM7@207QhN080NGUi0P1f
MWH00`1`L700M7Ad07AdM00607IfMP80N7Qh0P1dM7@206i^KQD0oooo000C0?ooo`80Ng]k0P1dM7@2
06m_K`80N7Qh0P20P80207alO080LW9b0P1gMgL00`1fMWH0N7Qh07QhN00207]kN`80NGUi0P1fMWH2
07=cL`80NGUi0P1hN7P207AdM080MgMg0P1lO7`2075aL@80MgMg0P1`L70207IfMP80Lg=c00<0LG5a
07EeM@1eMGD00P1fMWH205QHF080ATI60P12@T8203lo?`@0?3`l0P0Z:RX2030`<080:b/[0P0`<302
02DU9@805QHF0P0Z:RX00`0V9RH08R8R028R8P0201hN7P80GEeM0P2GUiL2079bLP80M7Ad0P1[Jf/2
06QXJ0@0I6AT0P1[Jf/206m_K`80KVi^0P1SHf<206ATI003069RHP1LG5`0G5aL0080FUYJ0P1IFET4
05eMG@80AdM70P0j>SX203dm?@80@T920P15ADD204I6AP80=cLg0P0j>SX20492@P80@D5100<0?3`l
03Ti>@0i>CT00P0`<30203/k>`80;Bd]0P0n?Sh204a<C08092@T0P0M7Ad201`L7080:b/[0P17AdL2
02HV9P80>CTi0P0j>SX203lo?`<0=cLg0P0o?cl204M7A`80A4A40P1FEUH205QHF080EEEE0P1ADE42
04i>CP80>3Ph0P1>CTh205eMG@80B4Q80P1>CTh205QHF00306i^KP1?Cdl0Cdm?0080GemO0P1mOGd2
06IVIP80G5aL0P1/K6`206m_K`80NGUi101gMgL2071`L080LG5a0P1/K6`206i^KP80Kfm_00<0MWIf
07UiN@1iNGT00P1`L70207AdM0@0MWIf0P1hN7P207alO1D0oooo000C0?ooo`80Ng]k0P1dM7@206m_
K`80N7Qh0P20P80207alO080LW9b0P1gMgL00`1fMWH0N7Qh07QhN00207]kN`80NGUi0P1fMWH207=c
L`80NGUi0P1hN7P207AdM080MgMg0P1lO7`2075aL@80MgMg0P1`L70207IfMP80Lg=c00<0LG5a07Ee
M@1eMGD00P1fMWH205QHF080ATI60P12@T8203lo?`@0?3`l0P0Z:RX2030`<080:b/[0P0`<30202DU
9@805QHF0P0Z:RX00`0V9RH08R8R028R8P0201hN7P80GEeM0P2GUiL2079bLP80M7Ad0P1[Jf/206QX
J0@0I6AT0P1[Jf/206m_K`80KVi^0P1SHf<206ATI003069RHP1LG5`0G5aL0080FUYJ0P1IFET405eM
G@80AdM70P0j>SX203dm?@80@T920P15ADD204I6AP80=cLg0P0j>SX20492@P80@D5100<0?3`l03Ti
>@0i>CT00P0`<30203/k>`80;Bd]0P0n?Sh204a<C08092@T0P0M7Ad201`L7080:b/[0P17AdL202HV
9P80>CTi0P0j>SX203lo?`<0=cLg0P0o?cl204M7A`80A4A40P1FEUH205QHF080EEEE0P1ADE4204i>
CP80>3Ph0P1>CTh205eMG@80B4Q80P1>CTh205QHF00306i^KP1?Cdl0Cdm?0080GemO0P1mOGd206IV
IP80G5aL0P1/K6`206m_K`80NGUi101gMgL2071`L080LG5a0P1/K6`206i^KP80Kfm_00<0MWIf07Ui
N@1iNGT00P1`L70207AdM0@0MWIf0P1hN7P207alO1D0oooo000C0?ooo`80Kfm_0P1fMWH207=cL`80
MgMg0P1`L70206e]K@80MGEe0P1aLG400`1cLg<0MWIf07IfMP0407IfMP80L71`0P1^KVh207MgM`@0
L71`0P1gMgL2071`L080LW9b0P1jNWX2079bLP80Kfm_0P1]KFd00`1cLg<0MGEe07EeM@0207AdM080
GEeM0P1<C4`40451@@80=cLg0P0e=CD203`l?080>SXj0P0`<30203Hf=P8051@D0P0N7Qh202h^;P03
020P800O7al07alO0080JVYZ0P2j^[X209>CT`80M7Ad101[Jf/206QXJ080LG5a0P1[Jf/206a/K080
IfMW0P1TI6@206IVIP80KVi^00<0HV9R065QH@1QHF40101MGEd205UIF@80G5aL0P1NGUh2061PH080
@d=30P0j>SX403Ph>080@d=30P10@40203lo?`80>SXj00<0<S8b03<c<`0c<c<00P0V9RH201`L7080
>SXj0P0d=3@204i>CP807alO0P0K6a/2018B4P805QHF0P0i>CT204=3@`80=3@d0P0j>SX2059BDP03
03Ti>@1CDe<0De=C0080ADE50P19BDT205UIF@80HV9R0P1UIFD206a/K080H61P0P0`<30204=3@`80
D51@0P1=CDd20410@080C4a<0P1MGEd00`1HF5P0CTi>04i>CP0209:BTP80Ng]k0P1HF5P2079bLP80
PH610P1kNg/207emO@80N7Qh0P1bLW8207IfMP80OGem0P1lO7`207emO@80MGEe00<0LW9b07AdM01d
M7@00P1hN7P207UiN@80MWIf0P1`L70207AdM080MWIf5@3oool001<0oooo0P1_Kfl207IfMP80Lg=c
0P1gMgL2071`L080KFe]0P1eMGD2075aL@0307=cL`1fMWH0MWIf00@0MWIf0P1`L70206i^KP80MgMg
101`L70207MgM`80L71`0P1bLW8207YjNP80LW9b0P1_Kfl206e]K@0307=cL`1eMGD0MGEe0080M7Ad
0P1MGEd204a<C0@0@D510P0g=cL203De=@80?3`l0P0j>SX2030`<080=SHf0P0D51@201hN7P80;Rh^
00<0820P01lO7`0O7al00P1ZJVX20;Zj^P80Ti>C0P1dM7@406][J`80J6QX0P1aLG4206][J`80K6a/
0P1WIfL206ATI080IVIV0P1^KVh00`1RHV80HF5Q065QH@0405eMG@80FEUI0P1LG5`205iNGP80H61P
0P13@d<203Xj>P@0>3Ph0P13@d<20410@080?clo0P0j>SX00`0b<S80<c<c03<c<`0202HV9P8071`L
0P0j>SX203@d=080CTi>0P0O7al201/K6`804Q8B0P0F5QH203Ti>@80@d=30P0d=3@203Xj>P80DU9B
00<0>CTi05=CD`1CDe<00P15ADD204U9B@80FEUI0P1RHV8206EUI@80K6a/0P1PH602030`<080@d=3
0P1@D50204e=C@80@4100P1<C4`205eMG@0305QHF01>CTh0CTi>0080TY:B0P1kNg/205QHF080LW9b
0P21PH4207]kN`80OGem0P1hN7P2079bLP80MWIf0P1mOGd207alO080OGem0P1eMGD00`1bLW80M7Ad
07AdM00207QhN080NGUi0P1fMWH2071`L080M7Ad0P1fMWHE0?ooo`004`3oool207]kN`80M7Ad0P1g
MgL207YjNP80N7Qh0P1lO7`207YjNP80L71`00<0LW9b06e]K@1]KFd00P1cLg<207IfMP80N7Qh0P1d
M7@2079bLP80MWIf0P1eMGD2079bLP80L71`0P1dM7@207MgM`80N7Qh0P1lO7`207inOP0307EeM@1Z
JVX0JVYZ0080EEEE0P1>CTh20451@@80A4A40P0k>c/202l_;`80:BTY0P0^;Rh2038b<P80<30`0P0U
9BD201@D5080;Bd]0P0/;2`00`0O7al0/K6a0;6a/@020=?Cd`80SHf=0P1ZJVX606][J`80KFe]0P1^
KVh2065QH@80Hf=S0P1RHV8206][J`80IVIV0P1SHf<00`1VIVH0KFe]06e]K@0206IVIP80FUYJ0P1H
F5P205mOG`80Fe]K0P1FEUH205MGE`80@D510P0g=cL203Hf=P80>SXj0P0d=3@203Ph>080=3@d00<0
=CDe03<c<`0c<c<00P0Q8B42028R8P80EEEE0P0R8R82051@D080>CTi0P0U9BD202l_;`8061PH0P0S
8b<20410@08092@T0P0m?Cd20492@P0303@d=01:BTX0BTY:0080BDU90P1=CDd204a<C080BTY:0P1N
GUh2061PH080DU9B0P1:BTX204I6AP80A4A4101<C4`2065QH@80GEeM00<0EUIF06QXJ01XJ6P00P1k
Ng/205iNGP80Jf][0P1nOWh207AdM080NGUi0P1bLW8407=cL`80N7Qh0P1fMWH2071`L080Kfm_0P1f
MWH00`1eMGD0LW9b079bLP0207AdM0@0MWIf0P1hN7P207UiN@80MWIf5@3oool001<0oooo0P1kNg/2
07AdM080MgMg0P1jNWX207QhN080O7al0P1jNWX2071`L003079bLP1]KFd0KFe]0080Lg=c0P1fMWH2
07QhN080M7Ad0P1bLW8207IfMP80MGEe0P1bLW82071`L080M7Ad0P1gMgL207QhN080O7al0P1nOWh0
0`1eMGD0JVYZ06YZJP0205EEE@80CTi>0P11@D4204A4A080>c/k0P0_;bl202TY:@80;Rh^0P0b<S82
030`<0809BDU0P0D51@202d];@80;2`/00<07alO0;6a/@2a/K400P3Cdm<208f=S@80JVYZ1P1[Jf/2
06e]K@80KVi^0P1QHF4206=SH`80HV9R0P1[Jf/206IVIP80Hf=S00<0IVIV06e]K@1]KFd00P1VIVH2
05YJFP80F5QH0P1OGel205]KF`80EUIF0P1GEeL20451@@80=cLg0P0f=SH203Xj>P80=3@d0P0h>3P2
03@d=00303De=@0c<c<0<c<c00808B4Q0P0R8R8205EEE@808R8R0P1@D50203Ti>@809BDU0P0_;bl2
01PH60808b<S0P10@40202@T9080?Cdm0P12@T800`0d=3@0BTY:04Y:BP0204U9B@80CDe=0P1<C4`2
04Y:BP80GUiN0P1PH602059BDP80BTY:0P16ATH204A4A0@0C4a<0P1QHF4205eMG@0305IFEP1XJ6P0
J6QX0080Ng]k0P1NGUh206][J`80OWin0P1dM7@207UiN@80LW9b101cLg<207QhN080MWIf0P1`L702
06m_K`80MWIf00<0MGEe079bLP1bLW800P1dM7@407IfMP80N7Qh0P1iNGT207IfMQD0oooo000C0?oo
o`80MWIf0P1hN7P207UiN@80MWIf0P1^KVh207=cL`80MWIf0P1iNGT00`1mOGd0O7al07alO00207Yj
NP80MWIf0P1^KVh2071`L080Lg=c0P1gMgL207QhN080MGEe0P1iNGT207]kN`80NGUi101fMWH2071`
L0<0KFe]0P1KFe/2059BDP80?Cdm0P11@D4203`l?080>CTi0P0e=CD203Lg=`@0;Rh^0P0L71`201/K
6`80:2PX0P0M7Ad00`1GEeL0Y:BT0:BTY00206a/K080GemO0P1VIVH206EUI@80IfMW1P1ZJVX206a/
K080Lg=c0P1XJ6P206=SH`80GemO0P1SHf<00`1TI6@0Fe]K05]KF`0205EEE@80HF5Q0P1TI6@205aL
G080FUYJ0P1IFET205IFEP80C4a<0P1SHf<203hn?P80=3@d100f=SH203@d=003030`<00W9bL09bLW
00809RHV0P0U9BD204];B`80@d=30P1@D50203Xj>P8071`L0P0A4A4202DU9@80BDU90P1CDe<205IF
EP80GUiN0P19BDT00`1=CDd0>SXj03Xj>P0204E5A@80BTY:0P1>CTh2059BDP80E5AD0P1IFET2069R
HP80ADE50P0i>CT204Q8B080?Cdm0P17AdL206ATI080JFUY00<0HF5Q05ADE01DE5@00P1HF5P2071`
L080QHF50P1oOgl207MgM`80NWYj0P1cLg<207QhN080LW9b0P1gMgL4071`L0@0NGUi00<0N7Qh07]k
N`1kNg/0101dM7@407IfMP80L71`0P1dM7@E0?ooo`004`3oool207IfMP80N7Qh0P1iNGT207IfMP80
KVi^0P1cLg<207IfMP80NGUi00<0OGem07alO01lO7`00P1jNWX207IfMP80KVi^0P1`L70207=cL`80
MgMg0P1hN7P207EeM@80NGUi0P1kNg/207UiN@@0MWIf0P1`L70306e]K@80Fe]K0P1BDU8203dm?@80
@D510P0l?3`203Ti>@80=CDe0P0g=cL402h^;P8071`L0P0K6a/202PX:0807AdM00<0EeMG0:BTY02T
Y:@00P1/K6`205mOG`80IVIV0P1UIFD206MWI`H0JVYZ0P1/K6`207=cL`80J6QX0P1SHf<205mOG`80
Hf=S00<0I6AT05]KF`1KFe/00P1EEED2065QH@80I6AT0P1LG5`205YJFP80FEUI0P1FEUH204a<C080
Hf=S0P0n?Sh203@d=0@0=SHf0P0d=3@00`0`<3009bLW02LW9`0202HV9P809BDU0P1;Bd/204=3@`80
D51@0P0j>SX201`L70804A4A0P0U9BD204U9B@80De=C0P1FEUH205iNGP80BDU900<0CDe=03Xj>P0j
>SX00P15ADD204Y:BP80CTi>0P1BDU8205ADE080FEUI0P1RHV8204E5A@80>CTi0P18B4P203dm?@80
AdM70P1TI6@206UYJ@03065QH@1DE5@0E5AD0080F5QH0P1`L70208F5Q@80Ogmo0P1gMgL207YjNP80
Lg=c0P1hN7P2079bLP80MgMg101`L70407UiN@0307QhN01kNg/0Ng]k00@0M7Ad101fMWH2071`L080
M7Ad5@3oool001<0oooo0P1[Jf/207=cL`80L71`0P1dM7@207UiN@80Ng]k0P1^KVh207=cL`03071`
L01_Kfl0Kfm_0080M7Ad0P1`L702075aL@80MGEe0P1bLW8207QhN0H0L71`0P1cLg<207IfMP80K6a/
0P1bLW83071`L080I6AT0P1JFUX204];B`80@4100P16ATH203Xj>P80<c<c0P0V9RH202`/;0809BDU
0P0_;bl201@D50807alO0P0W9bL203Ti>@030:NWY`2:RXX0RXZ:0080IVIV0P1ZJVX206a/K080IfMW
0P1[Jf/205iNGP80IVIV0P1NGUh205]KF`80IfMW0P1RHV8206EUI@@0HV9R00<0Hf=S06IVIP1VIVH0
0P1/K6`205mOG`80FUYJ0P1NGUh805UIF@80E5AD0P1<C4`203Ti>@@0=SHf0P0^;Rh00`0b<S809RHV
02HV9P0202HV9P805QHF0P0e=CD205aLG0809RHV0P1=CDd203lo?`80Fe]K0P0V9RH203Xj>P808R8R
0P0n?Sh202l_;`80?3`l00<0@D5104e=C@1=CDd0101<C4`203`l?080F5QH0P18B4P205eMG@80Kfm_
0P13@d<203/k>`80Bd];0P1<C4`205YJFP80Cdm?0P1:BTX00`1=CDd0I6AT06ATI00208:2PP80OGem
0P1]KFd2071`L080Kfm_0P1`L70207IfMP80M7Ad0P1fMWH207UiN@80LW9b0P1dM7@207MgM`80L71`
00<0Kfm_07AdM01dM7@0101bLW8207AdM080L71`0P1fMWH207UiNAD0oooo000C0?ooo`80Jf][0P1c
Lg<2071`L080M7Ad0P1iNGT207]kN`80KVi^0P1cLg<00`1`L700Kfm_06m_K`0207AdM080L71`0P1a
LG4207EeM@80LW9b0P1hN7P6071`L080Lg=c0P1fMWH206a/K080LW9b0`1`L70206ATI080FUYJ0P1;
Bd/20410@080ATI60P0j>SX203<c<`809RHV0P0/;2`202DU9@80;bl_0P0D51@201lO7`809bLW0P0i
>CT00`2WYjL0RXZ:08Z:RP0206IVIP80JVYZ0P1/K6`206MWI`80Jf][0P1NGUh206IVIP80GUiN0P1K
Fe/206MWI`80HV9R0P1UIFD4069RHP0306=SH`1VIVH0IVIV0080K6a/0P1OGel205YJFP80GUiN201I
FET205ADE080C4a<0P0i>CT403Hf=P80;Rh^00<0<S8b02HV9P0V9RH00P0V9RH201HF5P80=CDe0P1L
G5`202HV9P80CDe=0P0o?cl205]KF`809RHV0P0j>SX2028R8P80?Shn0P0_;bl203`l?0030451@@1=
CDd0CDe=00@0C4a<0P0l?3`205QHF080B4Q80P1MGEd206m_K`80@d=30P0k>c/204];B`80C4a<0P1J
FUX204m?C`80BTY:00<0CDe=06ATI01TI6@00P22PX8207emO@80KFe]0P1`L70206m_K`80L71`0P1f
MWH207AdM080MWIf0P1iNGT2079bLP80M7Ad0P1gMgL2071`L00306m_K`1dM7@0M7Ad00@0LW9b0P1d
M7@2071`L080MWIf0P1iNGTE0?ooo`004`3oool207IfMP80NGUi0P1bLW8207MgM`@0MWIf101cLg<0
0`1fMWH0Ng]k07]kN`0207UiN@80N7Qh0P1eMGD207AdM080NWYj0P1eMGD207IfMP80Ng]k0P1lO7`2
07YjNP80MWIf0P1iNGT207IfMP80IfMW00<0JFUY05QHF01HF5P00P1LG5`204=3@`80?clo0P0c<c<2
03Hf=P80<30`0P0_;bl203<c<`80;2`/0P0L71`201TI6@80<S8b0P0j>SX20:n_[`030:2PX01XJ6P0
J6QX0080JVYZ101WIfL2069RHP80H61P101LG5`205YJFP80H61P0P1LG5`205UIF@80E5AD0P1ADE42
05MGE`03061PH01IFET0FEUI0080FEUI0P1GEeL205aLG080De=C0P1FEUH205UIF@80FUYJ0P1IFET2
05EEE@80DU9B0P1IFET203`l?0809bLW0P0a<C400`0X:2P09RHV02HV9P0201hN7P807alO0P0_;bl2
04=3@`80@T920P0m?Cd205ADE080:2PX0P1;Bd/20410@080>c/k0P10@4020451@@80?3`l00<0?clo
04U9B@19BDT00P0Z:RX203lo?`80AdM70P1GEeL204e=C@80EeMG0P16ATH2061PH080F5QH0P0i>CT2
0451@@80DE5A0P17AdL205IFEP0306MWI`1nOWh0OWin0080Rh^;0P1]KFd2079bLP80MgMg0P1aLG42
07YjNP80M7Ad0P1`L70207MgM`80L71`0P1fMWH207]kN`80M7Ad0P1fMWH00`1eMGD0MgMg07MgM`02
07QhN080Ng]k0P1dM7@207IfMP80NGUi0P1fMWHE0?ooo`004`3oool207IfMP80NGUi0P1bLW8207Mg
M`@0MWIf101cLg<00`1fMWH0Ng]k07]kN`0207UiN@80N7Qh0P1eMGD207AdM080NWYj0P1eMGD207If
MP80Ng]k0P1lO7`207YjNP80MWIf0P1iNGT207IfMP80IfMW00<0JFUY05QHF01HF5P00P1LG5`204=3
@`80?clo0P0c<c<203Hf=P80<30`0P0_;bl203<c<`80;2`/0P0L71`201TI6@80<S8b0P0j>SX20:n_
[`030:2PX01XJ6P0J6QX0080JVYZ101WIfL2069RHP80H61P101LG5`205YJFP80H61P0P1LG5`205UI
F@80E5AD0P1ADE4205MGE`03061PH01IFET0FEUI0080FEUI0P1GEeL205aLG080De=C0P1FEUH205UI
F@80FUYJ0P1IFET205EEE@80DU9B0P1IFET203`l?0809bLW0P0a<C400`0X:2P09RHV02HV9P0201hN
7P807alO0P0_;bl204=3@`80@T920P0m?Cd205ADE080:2PX0P1;Bd/20410@080>c/k0P10@4020451
@@80?3`l00<0?clo04U9B@19BDT00P0Z:RX203lo?`80AdM70P1GEeL204e=C@80EeMG0P16ATH2061P
H080F5QH0P0i>CT20451@@80DE5A0P17AdL205IFEP0306MWI`1nOWh0OWin0080Rh^;0P1]KFd2079b
LP80MgMg0P1aLG4207YjNP80M7Ad0P1`L70207MgM`80L71`0P1fMWH207]kN`80M7Ad0P1fMWH00`1e
MGD0MgMg07MgM`0207QhN080Ng]k0P1dM7@207IfMP80NGUi0P1fMWHE0?ooo`004`3oool207]kN`80
NGUi0P1bLW8207MgM`@0MWIf0P1bLW8207UiN@0307AdM01_Kfl0Kfm_00@0Kfm_0P1fMWH207]kN`80
M7Ad0P1fMWH207AdM080KFe]0P1[Jf/206i^KP80Kfm_0P1dM7@207QhN080Kfm_00<0GemO05YJFP1J
FUX00P1=CDd203Xj>P80=cLg0P0f=SH202h^;P80:BTY0P0_;bl2034a<@805QHF0P0K6a/201hN7P80
71`L0P2NWYh20:>SX`0306][J`1YJFT0JFUY0080GemO0P1LG5`205mOG`80GUiN0P1HF5P2051@D080
Bd];0P19BDT204I6AP@0ADE50P14A4@404e=C@0304U9B@18B4P0B4Q80080E5AD0P1GEeL205]KF`80
GemO0P1RHV8205UIF@80EeMG0P1DE5@2059BDP80E5AD101HF5P204i>CP80=CDe00<0:BTY02XZ:P0Z
:RX00P0U9BD2028R8P809bLW0P0];Bd204Y:BP80F5QH0P11@D4205mOG`80H61P0P19BDT202DU9@80
<c<c0P1;Bd/204Q8B00304Y:BP0a<C40<C4a0080?Shn0P18B4P205IFEP80Cdm?0P1>CTh205UIF@80
J6QX0P1`L7020451@@80EUIF0P1YJFT2051@D080@d=30P1IFET00`1RHV80R8R808R8R00206m_K`80
MWIf0P1mOGd207=cL`80LG5a101hN7P207EeM@80MgMg0P1`L702075aL@80M7Ad101bLW800`1fMWH0
NGUi07UiN@0407IfMP80N7Qh0P1iNGT207IfMP80L71`5@3oool001<0oooo0P1kNg/207UiN@80LW9b
0P1gMgL407IfMP80LW9b0P1iNGT00`1dM7@0Kfm_06m_K`0406m_K`80MWIf0P1kNg/207AdM080MWIf
0P1dM7@206e]K@80Jf][0P1^KVh206m_K`80M7Ad0P1hN7P206m_K`0305mOG`1JFUX0FUYJ0080CDe=
0P0j>SX203Lg=`80=SHf0P0^;Rh202TY:@80;bl_0P0a<C4201HF5P806a/K0P0N7Qh201`L7080WYjN
0P2SXj<00`1[Jf/0JFUY06UYJ@0205mOG`80G5aL0P1OGel205iNGP80F5QH0P1@D50204];B`80BDU9
0P16ATH404E5A@80A4A4101=CDd00`19BDT0B4Q804Q8B00205ADE080EeMG0P1KFe/205mOG`80HV9R
0P1IFET205MGE`80E5AD0P1BDU8205ADE0@0F5QH0P1>CTh203De=@0302TY:@0Z:RX0:RXZ00809BDU
0P0R8R8202LW9`80;Bd]0P1:BTX205QHF080@D510P1OGel2061PH080BDU90P0U9BD203<c<`80Bd];
0P18B4P00`1:BTX0<C4a034a<@0203hn?P80B4Q80P1FEUH204m?C`80CTi>0P1IFET206QXJ080L71`
0P11@D4205IFEP80JFUY0P1@D50204=3@`80FEUI00<0HV9R08R8R028R8P00P1_Kfl207IfMP80OGem
0P1cLg<2075aL@@0N7Qh0P1eMGD207MgM`80L71`0P1aLG4207AdM0@0LW9b00<0MWIf07UiN@1iNGT0
101fMWH207QhN080NGUi0P1fMWH2071`L1D0oooo000C0?ooo`80MWIf0P1`L70207IfMP80NGUi0P1f
MWH2071`L080MWIf0P1iNGT00`1hN7P0Ng]k07]kN`0207EeM@@0NGUi0P1fMWH207QhN080NGUi0P1b
LW8207AdM080MWIf101kNg/207AdM080Kfm_0P1ZJVX00`1SHf<0H61P061PH00204i>CP80ADE50P0i
>CT203`l?080>3Ph0P0X:2P202l_;`80:RXZ0P0J6QX2028R8P80;bl_0P2l_;`20;jn_P<0JVYZ0P1T
I6@2069RHP80Hf=S0P1QHF4205QHF080Cdm?0P1@D50204e=C@80B4Q81P11@D4204=3@`80A4A40P1=
CDd00`1;Bd/0Cdm?04m?C`0205ADE080C4a<0P1GEeL205]KF`80G5aL0P1GEeL205QHF0@0E5AD0P1A
DE4204U9B@80BTY:0P1<C4`2034a<@0302@T900V9RH09RHV00807QhN0P0D51@201dM7@80=3@d0P1F
EUH203@d=0808b<S0P1GEeL203lo?`80EUIF0P1BDU820451@@80<c<c0P18B4P00`16ATH0?Shn03hn
?P02059BDP80A4A40P1GEeL204U9B@80GUiN0P1@D50204e=C@80GEeM0P1IFET205mOG`80DU9B0P1?
Cdl205UIF@80HV9R00<0I6AT07IfMP1fMWH00P1]KFd207YjNP80L71`0P1eMGD207alO080MWIf0P1d
M7@207QhN080LG5a0P1fMWH207emO@80NGUi0P1bLW8307UiN@80L71`0P1dM7@807IfMP80N7Qh5@3o
ool001<0oooo0P1fMWH2071`L080MWIf0P1iNGT207IfMP80L71`0P1fMWH207UiN@0307QhN01kNg/0
Ng]k0080MGEe101iNGT207IfMP80N7Qh0P1iNGT2079bLP80M7Ad0P1fMWH407]kN`80M7Ad0P1_Kfl2
06YZJP0306=SH`1PH600H61P0080CTi>0P15ADD203Ti>@80?3`l0P0h>3P202PX:080;bl_0P0Z:RX2
01XJ6P808R8R0P0_;bl20;bl_080_[jn0`1ZJVX206ATI080HV9R0P1SHf<2065QH@80F5QH0P1?Cdl2
051@D080CDe=0P18B4P60451@@80@d=30P14A4@204e=C@0304];B`1?Cdl0Cdm?0080E5AD0P1<C4`2
05MGE`80Fe]K0P1LG5`205MGE`80F5QH101DE5@2055AD@80BDU90P1:BTX204a<C080<C4a00<092@T
02HV9P0V9RH00P0N7Qh201@D50807AdM0P0d=3@205IFEP80=3@d0P0S8b<205MGE`80?clo0P1FEUH2
059BDP80@D510P0c<c<204Q8B00304I6AP0n?Sh0?Shn0080DU9B0P14A4@205MGE`80BDU90P1NGUh2
051@D080CDe=0P1MGEd205UIF@80GemO0P1BDU8204m?C`80FEUI0P1RHV800`1TI6@0MWIf07IfMP02
06e]K@80NWYj0P1`L70207EeM@80O7al0P1fMWH207AdM080N7Qh0P1aLG4207IfMP80OGem0P1iNGT2
079bLP<0NGUi0P1`L70207AdM0P0MWIf0P1hN7PE0?ooo`004`3oool207IfMP80LW9b0P1gMgL207If
MP80L71`0P1fMWH207UiN@D0MWIf0P1bLW8207MgM`P0MWIf0P1hN7P207EeM@80LW9b0P1_Kfl207=c
L`80LW9b0P1_Kfl205]KF`0305QHF01QHF40HF5Q0080@d=30P0a<C4203@d=080;bl_0P0b<S8202/[
:`80:2PX0P0J6QX201dM7@809BDU0P0Z:RX20861P@80Hf=S0P1NGUh305eMG@80H61P0P1RHV8205MG
E`80:b/[0P0O7al202`/;080<S8b0P0l?3`20492@PH0ADE50P0c<c<202/[:`0302LW9`0X:2P0:2PX
0080?clo0P1EEED205QHF080FEUI0P1KFe/205iNGP80Fe]K0P1JFUX205MGE`80D51@0P1CDe<204m?
C`80ADE50P1ADE400`0];Bd07QhN01hN7P0201XJ6P804a<C0P0N7Qh202`/;080=cLg0P1EEED205UI
F@80DU9B0P1KFe/205YJFP80Fe]K0P1TI6@205IFEP80?Shn00<0@D51051@D01@D5000P0g=cL203<c
<`80A4A40P1>CTh20451@@80De=C0P1NGUh205mOG`80HF5Q0P1@D50205aLG080C4a<0P1?Cdl206UY
J@0307=cL`1/K6`0K6a/0080Jf][0P1cLg<206][J`@0KVi^0P1eMGD2075aL@80KVi^0P1gMgL207Ee
M@80M7Ad0P1fMWH207QhN0<0M7Ad0P1hN7P407AdM080MWIf0P1`L70207AdM080MWIf5@3oool001<0
oooo0P1fMWH2079bLP80MgMg0P1`L70207IfMP@0M7Ad1@1fMWH2079bLP80MgMg0P1fMWH2071`L080
KFe]0P1cLg<207IfMP80LW9b0P1jNWX207emO@80Lg=c0P1eMGD206e]K@80IfMW00<0Jf][04U9B@19
BDT00P0i>CT203Lg=`80<c<c0P0a<C4202d];@808R8R0P0/;2`202HV9P808R8R0P0[:b/20;Zj^P80
[Jf]1@1RHV8206QXJ080IFEU0P0k>c/202d];@80?Cdm0P1FEUH2092@T080R8R80P1PH60205EEE@80
IfMW0P1kNg/205EEE@80D51@0P1DE5@00`1ADE40B4Q804Q8B00203Xj>P80@d=30P1CDe<205IFEP80
FEUI0P1MGEd205MGE`80F5QH0P1IFET205MGE`80De=C0P1;Bd/204a<C080BDU900<0Bd];030`<00`
<300100G5aL201DE5@80;Bd]0P0?3`l204Y:BP80JFUY0P0a<C4205=CD`80=CDe0P1DE5@2069RHP@0
CTi>00<0FEUI02l_;`0_;bl00P13@d<204];B`80CDe=0P1:BTX204];B`80E5AD0P1BDU8206ATI080
IfMW0P13@d<203Hf=P80?Shn101CDe<00`1kNg/0Ph>308>3P`0207moO`80MGEe0P1]KFd207emO@80
Ogmo0P1bLW82071`L080MGEe0P1gMgL2079bLP80MgMg0P1`L70206m_K`80MWIf00<0NGUi071`L01`
L7000P1fMWH207UiN@@0L71`0P1gMgL2071`L1D0oooo000C0?ooo`80MWIf0P1bLW8207MgM`80L71`
0P1fMWH407AdM0D0MWIf0P1bLW8207MgM`80MWIf0P1`L70206e]K@80Lg=c0P1fMWH2079bLP80NWYj
0P1mOGd207=cL`80MGEe0P1]KFd206MWI`0306][J`19BDT0BDU90080>CTi0P0g=cL203<c<`80<C4a
0P0];Bd2028R8P80;2`/0P0V9RH2028R8P80:b/[0P2j^[X20:f][@D0HV9R0P1XJ6P206EUI@80>c/k
0P0];Bd203dm?@80EUIF0P2@T90208R8R080H61P0P1EEED206MWI`80Ng]k0P1EEED2051@D080E5AD
00<0DE5A04Q8B018B4P00P0j>SX204=3@`80De=C0P1FEUH205UIF@80GEeM0P1GEeL205QHF080FEUI
0P1GEeL205=CD`80Bd];0P1<C4`204U9B@0304];B`0`<300<30`00@05aLG0P0E5AD202d];@803`l?
0P1:BTX206UYJ@80<C4a0P1CDe<203De=@80E5AD0P1RHV8404i>CP0305UIF@0_;bl0;bl_0080@d=3
0P1;Bd/204e=C@80BTY:0P1;Bd/205ADE080DU9B0P1TI6@206MWI`80@d=30P0f=SH203hn?P@0De=C
00<0Ng]k08>3P`23Ph<00P1oOgl207EeM@80KFe]0P1mOGd207moO`80LW9b0P1`L70207EeM@80MgMg
0P1bLW8207MgM`80L71`0P1_Kfl207IfMP0307UiN@1`L700L71`0080MWIf0P1iNGT4071`L080MgMg
0P1`L70E0?ooo`004`3oool206m_K`80MWIf0P1dM7@207IfMP80M7Ad0P1fMWH407AdM003071`L01_
Kfl0Kfm_0080MWIf0P1dM7@206m_K`80L71`0P1dM7@207=cL`80Kfm_0P1^KVh207MgM`80MWIf0P1`
L70207QhN080G5aL0P1DE5@00`0m?Cd0<C4a034a<@0203De=@80=cLg0P0U9BD202XZ:P809RHV0P0b
<S8201HF5P806ATI0P0O7al205YJFP80V9RH0P1WIfL206YZJP80IFEU00<0HV9R065QH@1QHF400P1O
Gel203Xj>P80ATI60P1;Bd/204E5A@80<c<c0P0P820202`/;080@T920P0_;bl2024Q8@8071`L0P0Y
:BT202`/;00304m?C`15ADD0ADE50080A4A40P0_;bl204I6AP80FEUI0P1NGUh205]KF`80GUiN0P1R
HV8205YJFP80DU9B0P1@D50205=CD`80D51@0P1BDU800`1;Bd/0B4Q804Q8B00202LW9`809RHV0P0?
3`l201/K6`80=CDe0P1HF5P403Ti>@80CDe=0P1JFUX204];B`80D51@0P23Ph<205MGE`0303Hf=P14
A4@0A4A40080De=C0P0d=3@203/k>`@0Bd];0P1ADE4204e=C@80GemO0P1MGEd204Q8B080DU9B0P1J
FUX204Y:BP80EEEE00<0OGem071`L01`L7000P1fMWH406e]K@80Ng]k0P1fMWH207UiN@80OGem0P1k
Ng/207UiN@80N7Qh0P1dM7@207IfMP80Ng]k0P1iNGT00`1fMWH0N7Qh07QhN00207UiN@80MWIf0P1h
N7P207]kN`80NGUi0P1hN7PE0?ooo`004`3oool206m_K`80MWIf0P1dM7@207IfMP80M7Ad0P1fMWH4
07AdM003071`L01_Kfl0Kfm_0080MWIf0P1dM7@206m_K`80L71`0P1dM7@207=cL`80Kfm_0P1^KVh2
07MgM`80MWIf0P1`L70207QhN080G5aL0P1DE5@00`0m?Cd0<C4a034a<@0203De=@80=cLg0P0U9BD2
02XZ:P809RHV0P0b<S8201HF5P806ATI0P0O7al205YJFP80V9RH0P1WIfL206YZJP80IFEU00<0HV9R
065QH@1QHF400P1OGel203Xj>P80ATI60P1;Bd/204E5A@80<c<c0P0P820202`/;080@T920P0_;bl2
024Q8@8071`L0P0Y:BT202`/;00304m?C`15ADD0ADE50080A4A40P0_;bl204I6AP80FEUI0P1NGUh2
05]KF`80GUiN0P1RHV8205YJFP80DU9B0P1@D50205=CD`80D51@0P1BDU800`1;Bd/0B4Q804Q8B002
02LW9`809RHV0P0?3`l201/K6`80=CDe0P1HF5P403Ti>@80CDe=0P1JFUX204];B`80D51@0P23Ph<2
05MGE`0303Hf=P14A4@0A4A40080De=C0P0d=3@203/k>`@0Bd];0P1ADE4204e=C@80GemO0P1MGEd2
04Q8B080DU9B0P1JFUX204Y:BP80EEEE00<0OGem071`L01`L7000P1fMWH406e]K@80Ng]k0P1fMWH2
07UiN@80OGem0P1kNg/207UiN@80N7Qh0P1dM7@207IfMP80Ng]k0P1iNGT00`1fMWH0N7Qh07QhN002
07UiN@80MWIf0P1hN7P207]kN`80NGUi0P1hN7PE0?ooo`004`3oool207]kN`80NGUi0P1hN7P207Ui
N@@0LW9b0P1fMWH207AdM003071`L01dM7@0M7Ad0080MgMg0P1bLW8407AdM080NGUi0P1kNg/207Ee
M@80M7Ad0P1hN7P2071`L080LG5a0P1cLg<205mOG`80FEUI00<0@d=304E5A@15ADD00P0f=SH202XZ
:P808b<S0P0a<C4202PX:08061PH0P0Q8B42020P8080>SXj0P2`/;0209>CT`80IVIV101PH6000`1R
HV80?3`l03`l?00202/[:`808R8R0P0J6QX201HF5P807QhN0P0^;Rh202PX:0809BDU0P0X:2P202<S
8`807alO0P0F5QH201`L70808b<S0`0A4A4201PH60805QHF0P0M7Ad202d];@80De=C101LG5`405=C
D`80FUYJ0P1BDU82055AD@80DU9B0P1GEeL00`17AdL0@D510451@@0203@d=080410@0P0<30`202@T
9080:2PX0P0U9BD203`l?080H61P0P0[:b/204Y:BP80=cLg0P1?Cdl205UIF@80MWIf00<0IfMW05iN
GP1NGUh00P0e=CD204I6AP80BDU90P17AdL204A4A080=CDe0P1CDe<206QXJ080GUiN0P1UIFD205aL
G080HV9R0P1EEED206MWI`0307IfMP1bLW80LW9b0080KFe]0P1`L70207]kN`80Lg=c0P1bLW8207If
MP80L71`0P1dM7@2071`L080M7Ad0P1hN7P207UiN@T0MWIf0P1`L70207AdM080L71`0P1dM7@207If
MQD0oooo000C0?ooo`80Ng]k0P1iNGT207QhN080NGUi101bLW8207IfMP80M7Ad00<0L71`07AdM01d
M7@00P1gMgL2079bLP@0M7Ad0P1iNGT207]kN`80MGEe0P1dM7@207QhN080L71`0P1aLG4207=cL`80
GemO0P1IFET00`13@d<0ADE504E5A@0203Hf=P80:RXZ0P0S8b<2034a<@80:2PX0P0H61P2024Q8@80
820P0P0j>SX20;2`/080Ti>C0P1VIVH4061PH003069RHP0l?3`0?3`l0080:b/[0P0R8R8201XJ6P80
5QHF0P0N7Qh202h^;P80:2PX0P0U9BD202PX:0808b<S0P0O7al201HF5P8071`L0P0S8b<3014A4@80
61PH0P0F5QH201dM7@80;Bd]0P1CDe<405aLG0@0De=C0P1JFUX2059BDP80DE5A0P1BDU8205MGE`03
04M7A`11@D40@D510080=3@d0P0@410200`<308092@T0P0X:2P202DU9@80?3`l0P1PH60202/[:`80
BTY:0P0g=cL204m?C`80FEUI0P1fMWH00`1WIfL0GUiN05iNGP0203De=@80ATI60P19BDT204M7A`80
A4A40P0e=CD205=CD`80J6QX0P1NGUh206EUI@80G5aL0P1RHV8205EEE@80IfMW00<0MWIf079bLP1b
LW800P1]KFd2071`L080Ng]k0P1cLg<2079bLP80MWIf0P1`L70207AdM080L71`0P1dM7@207QhN080
NGUi2@1fMWH2071`L080M7Ad0P1`L70207AdM080MWIf5@3oool001<0oooo1P1_Kfl207AdM080N7Qh
0P1eMGD2079bLP80MWIf00<0MGEe07UiN@1iNGT00P1dM7@207IfMP80MGEe0P1iNGT207AdM080Kfm_
0P1`L70207AdM080LW9b0P1^KVh207=cL`80JVYZ0P1OGel205EEE@0303hn?P0e=CD0=CDe00809bLW
0P0R8R8202h^;P80:RXZ0P0T92@202/[:`80;Rh^0P0[:b/20;Vi^@80ZJVY0P1PH60206=SH`80JVYZ
0P1VIVH00`1RHV80I6AT06ATI00208N7Q`80IfMW101GEeL204U9B@80B4Q80P0o?cl204a<C080G5aL
0P16ATH204Q8B080D51@0P1DE5@204i>CP0304m?C`25QHD0QHF50080TY:B0P2JVYX20:6QX@80RHV9
0P1/K6`205aLG080EUIF0P1GEeL205UIF@80FUYJ0P1GEeL205=CD`80DE5A0P1@D5000`1>CTh0C4a<
04a<C00203lo?`808B4Q0P0A4A4200d=3@806ATI0P0^;Rh203Ti>@80C4a<0P1EEED203Xj>P80B4Q8
0P11@D4405YJFP0307=cL`0m?Cd0?Cdm0080@T920P1@D50203lo?`80BTY:0P17AdL203hn?P80H61P
0P1ADE4205YJFP80IfMW0P15ADD205IFEP80Cdm?0P20P8000`2:RXX0M7Ad07AdM00206a/K080KFe]
0P1cLg<407EeM@80Kfm_0P1fMWH207UiN@80N7Qh0P1iNGT2071`L080M7Ad0P1fMWH2071`L00307Ad
M01fMWH0MWIf0080L71`0P1fMWH207UiN@80LW9b0P1gMgL207IfMQD0oooo000C0?ooo`H0Kfm_0P1d
M7@207QhN080MGEe0P1bLW8207IfMP0307EeM@1iNGT0NGUi0080M7Ad0P1fMWH207EeM@80NGUi0P1d
M7@206m_K`80L71`0P1dM7@2079bLP80KVi^0P1cLg<206YZJP80GemO0P1EEED00`0n?Sh0=CDe03De
=@0202LW9`808R8R0P0^;Rh202XZ:P8092@T0P0[:b/202h^;P80:b/[0P2i^KT20:VYZ@80H61P0P1S
Hf<206YZJP80IVIV00<0HV9R06ATI01TI6@00P27QhL206MWI`@0EeMG0P19BDT204Q8B080?clo0P1<
C4`205aLG080ATI60P18B4P2051@D080E5AD0P1>CTh00`1?Cdl0QHF508F5Q@0209:BTP80VYZJ0P2Q
XJ4208V9R@80K6a/0P1LG5`205IFEP80EeMG0P1IFET205YJFP80EeMG0P1CDe<2055AD@80D51@00<0
CTi>04a<C01<C4`00P0o?cl2024Q8@804A4A0P0=3@d201TI6@80;Rh^0P0i>CT204a<C080EEEE0P0j
>SX204Q8B080@D51101JFUX00`1cLg<0?Cdm03dm?@020492@P80D51@0P0o?cl204Y:BP80AdM70P0n
?Sh2061PH080DE5A0P1JFUX206MWI`80ADE50P1FEUH204m?C`80P82000<0RXZ:07AdM01dM7@00P1/
K6`206e]K@80Lg=c101eMGD206m_K`80MWIf0P1iNGT207QhN080NGUi0P1`L70207AdM080MWIf0P1`
L7000`1dM7@0MWIf07IfMP02071`L080MWIf0P1iNGT2079bLP80MgMg0P1fMWHE0?ooo`004`3oool2
07]kN`80MGEe0P1dM7@207MgM`80L71`0P1fMWH207]kN`80NGUi00<0LW9b07MgM`1gMgL00P1bLW82
07MgM`80N7Qh0P1iNGT207QhN080Ng]k0P1cLg<207QhN080MGEe0P1`L702075aL@80Jf][0P1KFe/2
04Q8B00303De=@0/;2`0;2`/00@0<c<c0P0Z:RX202HV9P808b<S0P0W9bL202HV9P80;Rh^0P2:RXX2
05mOG`80IFEU0P1XJ6P205mOG`80Hf=S00<0I6AT06a/K01/K6`00P1eMGD207inOP80YjNW0P2h^;P2
0:j^[P80Zj^[0P2l_;`20:n_[`80WinO0P2ZZZX20<C4a080];Bd0P2^[Zh20::RXP0309NGU`2?Shl0
Shn?0080L71`0P1ZJVX206MWI`80I6AT0P1PH60205eMG@80GUiN0P1LG5`405MGE`80DU9B0P1HF5P2
05=CD`80D51@00<0Bd];051@D01@D5000P15ADD202l_;`8071`L0P0:2PX203/k>`80;2`/0P0Y:BT2
02d];@80=cLg0P0/;2`204A4A080;2`/0P0h>3P204i>CP0305YJFP1>CTh0CTi>0080HF5Q0P1<C4`2
03/k>`80=cLg0P13@d<205EEE@80FUYJ0P11@D4205eMG@80Hf=S0P19BDT204m?C`80?3`l0P1fMWH0
0`1eMGD0KVi^06i^KP0406m_K`80O7al101kNg/207EeM@80MgMg1P1fMWH207QhN080NGUi0P1`L702
07IfMP<0M7Ad0P1hN7P207UiN@80L71`0P1fMWH207UiN@80MWIf5@3oool001<0oooo0P1kNg/207Ee
M@80M7Ad0P1gMgL2071`L080MWIf0P1kNg/207UiN@03079bLP1gMgL0MgMg0080LW9b0P1gMgL207Qh
N080NGUi0P1hN7P207]kN`80Lg=c0P1hN7P207EeM@80L71`0P1aLG4206][J`80Fe]K0P18B4P00`0e
=CD0;2`/02`/;00403<c<`80:RXZ0P0V9RH202<S8`809bLW0P0V9RH202h^;P80RXZ:0P1OGel206EU
I@80J6QX0P1OGel206=SH`0306ATI01/K6`0K6a/0080MGEe0P1nOWh20:NWY`80^;Rh0P2^[Zh20:^[
Z`80_;bl0P2_[jl209nOW`80ZZZZ0P34a<@20;Bd]080[Zj^0P2RXZ800`2GUiL0Shn?08n?S`02071`
L080JVYZ0P1WIfL206ATI080H61P0P1MGEd205iNGP80G5aL101GEeL2059BDP80F5QH0P1CDe<2051@
D00304];B`1@D500D51@0080ADE50P0_;bl201`L70802PX:0P0k>c/202`/;080:BTY0P0];Bd203Lg
=`80;2`/0P14A4@202`/;080>3Ph0P1>CTh00`1JFUX0CTi>04i>CP02065QH@80C4a<0P0k>c/203Lg
=`80@d=30P1EEED205YJFP80@D510P1MGEd206=SH`80BDU90P1?Cdl203`l?080MWIf00<0MGEe06i^
KP1^KVh0101_Kfl207alO0@0Ng]k0P1eMGD207MgM`H0MWIf0P1hN7P207UiN@80L71`0P1fMWH307Ad
M080N7Qh0P1iNGT2071`L080MWIf0P1iNGT207IfMQD0oooo000C0?ooo`80Kfm_0P1fMWH207]kN`80
NGUi0P1hN7P207UiN@80L71`0P1dM7@00`1hN7P0NGUi07UiN@02079bLP80MgMg0P1`L70206m_K`80
M7Ad0P1fMWH207=cL`80LG5a0P1`L70207EeM@80KFe]0P1<C4`204U9B@80?clo00<0;bl_02`/;00/
;2`00P0U9BD202@T90809bLW0P0I6AT202HV9P80:RXZ0P0U9BD208n?S`80YJFU0P1XJ6P206UYJ@80
Hf=S0P1ZJVX206ATI00306UYJ@1UIFD0IFEU0080IVIV0P1WIfL206][J`80I6AT0P1]KFd4071`L080
GemO0P1SHf<2065QH@80FUYJ0P1=CDd204m?C`80De=C00<0FEUI05mOG`1OGel00P1JFUX2065QH@80
KFe]0P1QHF4205]KF`80HF5Q0P1NGUh205UIF@80Fe]K0P1IFET205ADE080EEEE0P1?Cdl204E5A@03
04Q8B01=CDd0CDe=0080?Cdm0P0`<30201<C4`8051@D0P0^;Rh202/[:`80EUIF0P16ATH205aLG080
<c<c0P0X:2P204I6AP80EEEE0P1MGEd00`1JFUX0LG5a075aL@0206YZJP80B4Q80P19BDT205MGE`80
?clo0P0e=CD2034a<@80@d=30P1XJ6P206=SH`80BTY:0P1OGel2051@D080RXZ:00<0MWIf06IVIP1V
IVH00P1[Jf/207QhN080OGem101fMWH2079bLP80MgMg0P1fMWH2071`L0@0Kfm_0P1dM7@207QhN080
NGUi00<0N7Qh07UiN@1iNGT0101fMWH207QhN080NGUi0P1fMWH2071`L1D0oooo000C0?ooo`80Kfm_
0P1fMWH207]kN`80NGUi0P1hN7P207UiN@80L71`0P1dM7@00`1hN7P0NGUi07UiN@02079bLP80MgMg
0P1`L70206m_K`80M7Ad0P1fMWH207=cL`80LG5a0P1`L70207EeM@80KFe]0P1<C4`204U9B@80?clo
00<0;bl_02`/;00/;2`00P0U9BD202@T90809bLW0P0I6AT202HV9P80:RXZ0P0U9BD208n?S`80YJFU
0P1XJ6P206UYJ@80Hf=S0P1ZJVX206ATI00306UYJ@1UIFD0IFEU0080IVIV0P1WIfL206][J`80I6AT
0P1]KFd4071`L080GemO0P1SHf<2065QH@80FUYJ0P1=CDd204m?C`80De=C00<0FEUI05mOG`1OGel0
0P1JFUX2065QH@80KFe]0P1QHF4205]KF`80HF5Q0P1NGUh205UIF@80Fe]K0P1IFET205ADE080EEEE
0P1?Cdl204E5A@0304Q8B01=CDd0CDe=0080?Cdm0P0`<30201<C4`8051@D0P0^;Rh202/[:`80EUIF
0P16ATH205aLG080<c<c0P0X:2P204I6AP80EEEE0P1MGEd00`1JFUX0LG5a075aL@0206YZJP80B4Q8
0P19BDT205MGE`80?clo0P0e=CD2034a<@80@d=30P1XJ6P206=SH`80BTY:0P1OGel2051@D080RXZ:
00<0MWIf06IVIP1VIVH00P1[Jf/207QhN080OGem101fMWH2079bLP80MgMg0P1fMWH2071`L0@0Kfm_
0P1dM7@207QhN080NGUi00<0N7Qh07UiN@1iNGT0101fMWH207QhN080NGUi0P1fMWH2071`L1D0oooo
000C0?ooo`80M7Ad0P1gMgL2071`L0H0Kfm_0P1fMWH2079bLP0307=cL`1fMWH0MWIf0080N7Qh0P1i
NGT2079bLP80NGUi101dM7@2079bLP80M7Ad101cLg<207MgM`80I6AT0P11@D4202XZ:P0302DU9@0e
=CD0=CDe00@0:2PX0P0L71`202PX:080;Bd]0P0X:2P202TY:@80TY:B0P1dM7@2065QH@80I6AT0P1Y
JFT206EUI@80Hf=S00<0JVYZ06MWI`1WIfL00P1[Jf/206MWI`80IFEU0P1SHf<206EUI@80Hf=S0P1R
HV8205eMG@80Hf=S101RHV8205UIF@80HF5Q0P1UIFD00`1NGUh0HF5Q065QH@0205]KF`80JFUY0P1J
FUX206=SH`80HF5Q0P1KFe/205ADE080EUIF0P1NGUh205QHF080E5AD0P1?Cdl405IFEP03051@D01=
CDd0CDe=0080AdM70P0j>SX202PX:0809RHV0P0>3Ph202@T90809BDU0P0V9RH202LW9`80<30`0P0j
>SX204E5A@80=3@d0P14A4@00`1IFET0FUYJ05YJFP0203`l?080Cdm?0P1;Bd/204M7A`80>SXj0P1>
CTh203hn?PH0EeMG0P1BDU8204I6AP80Bd];0P1fMWH00`1YJFT0LG5a075aL@0206ATI080MgMg0P1e
MGD207AdM080MWIf0P1bLW8207MgM`80L71`0P1fMWH407]kN`80NGUi0P1`L70207AdM0<0MWIf0P1`
L70206m_K`80M7Ad101fMWH207QhN1D0oooo000C0?ooo`80M7Ad0P1gMgL2071`L0H0Kfm_0P1fMWH2
079bLP0307=cL`1fMWH0MWIf0080N7Qh0P1iNGT2079bLP80NGUi101dM7@2079bLP80M7Ad101cLg<2
07MgM`80I6AT0P11@D4202XZ:P0302DU9@0e=CD0=CDe00@0:2PX0P0L71`202PX:080;Bd]0P0X:2P2
02TY:@80TY:B0P1dM7@2065QH@80I6AT0P1YJFT206EUI@80Hf=S00<0JVYZ06MWI`1WIfL00P1[Jf/2
06MWI`80IFEU0P1SHf<206EUI@80Hf=S0P1RHV8205eMG@80Hf=S101RHV8205UIF@80HF5Q0P1UIFD0
0`1NGUh0HF5Q065QH@0205]KF`80JFUY0P1JFUX206=SH`80HF5Q0P1KFe/205ADE080EUIF0P1NGUh2
05QHF080E5AD0P1?Cdl405IFEP03051@D01=CDd0CDe=0080AdM70P0j>SX202PX:0809RHV0P0>3Ph2
02@T90809BDU0P0V9RH202LW9`80<30`0P0j>SX204E5A@80=3@d0P14A4@00`1IFET0FUYJ05YJFP02
03`l?080Cdm?0P1;Bd/204M7A`80>SXj0P1>CTh203hn?PH0EeMG0P1BDU8204I6AP80Bd];0P1fMWH0
0`1YJFT0LG5a075aL@0206ATI080MgMg0P1eMGD207AdM080MWIf0P1bLW8207MgM`80L71`0P1fMWH4
07]kN`80NGUi0P1`L70207AdM0<0MWIf0P1`L70206m_K`80M7Ad101fMWH207QhN1D0oooo000C0?oo
o`80Ng]k0P1dM7@207IfMP80MGEe0P1dM7@407UiN@80N7Qh00<0MGEe07AdM01dM7@0101fMWH207Qh
N080NGUi0P1hN7P207UiN@80N7Qh0P1eMGD207AdM080Lg=c0P1@D50204U9B@80?Cdm0`0e=CD202@T
9080;2`/0P0O7al202LW9`807AdM0P0U9BD202XZ:P807QhN0P21PH44065QH@@0IfMW0P1XJ6P206][
J`0306EUI@1VIVH0IVIV0080J6QX101WIfL206ATI080IVIV0P1WIfL405iNGP80E5AD0P1NGUh205EE
E@80Cdm?0P1HF5P205aLG00305YJFP1MGEd0GEeM0080HF5Q0P1XJ6P405]KF`80I6AT0P1_Kfl2069R
HP80HF5Q0P1JFUX205MGE`80EEEE0P1GEeL2051@D080C4a<00<0B4Q80451@@11@D400P11@D4203hn
?P809bLW0P0C4a<201LG5`80;Rh^0P0g=cL203hn?P80@4100P1@D50203/k>`80:b/[0P0W9bL204U9
B@0303`l?00m?Cd0?Cdm0080KFe]0P1[Jf/203lo?`80BDU90P0b<S82051@D080CTi>0P1NGUh204e=
C@80GemO0P1BDU820410@080MgMg0P20P8000`1dM7@0L71`071`L00207IfMP80Ogmo0P1fMWH207Ui
N@80MWIf0P1hN7P207UiN@80N7Qh101dM7@407IfMP80LW9b0P1gMgL00`1`L700M7Ad07AdM00207Qh
N080Ng]k0P1iNGT607IfMQD0oooo000C0?ooo`80Ng]k0P1dM7@207IfMP80MGEe0P1dM7@407UiN@80
N7Qh00<0MGEe07AdM01dM7@0101fMWH207QhN080NGUi0P1hN7P207UiN@80N7Qh0P1eMGD207AdM080
Lg=c0P1@D50204U9B@80?Cdm0`0e=CD202@T9080;2`/0P0O7al202LW9`807AdM0P0U9BD202XZ:P80
7QhN0P21PH44065QH@@0IfMW0P1XJ6P206][J`0306EUI@1VIVH0IVIV0080J6QX101WIfL206ATI080
IVIV0P1WIfL405iNGP80E5AD0P1NGUh205EEE@80Cdm?0P1HF5P205aLG00305YJFP1MGEd0GEeM0080
HF5Q0P1XJ6P405]KF`80I6AT0P1_Kfl2069RHP80HF5Q0P1JFUX205MGE`80EEEE0P1GEeL2051@D080
C4a<00<0B4Q80451@@11@D400P11@D4203hn?P809bLW0P0C4a<201LG5`80;Rh^0P0g=cL203hn?P80
@4100P1@D50203/k>`80:b/[0P0W9bL204U9B@0303`l?00m?Cd0?Cdm0080KFe]0P1[Jf/203lo?`80
BDU90P0b<S82051@D080CTi>0P1NGUh204e=C@80GemO0P1BDU820410@080MgMg0P20P8000`1dM7@0
L71`071`L00207IfMP80Ogmo0P1fMWH207UiN@80MWIf0P1hN7P207UiN@80N7Qh101dM7@407IfMP80
LW9b0P1gMgL00`1`L700M7Ad07AdM00207QhN080Ng]k0P1iNGT607IfMQD0oooo000C0?ooo`80MWIf
0P1hN7P207UiN@80N7Qh0P1kNg/207UiN@@0MWIf00<0N7Qh07AdM01dM7@00P1dM7@607IfMP80L71`
101_Kfl207IfMP80Ng]k0P1/K6`205=CD`80@D510P0l?3`2030`<00302l_;`0f=SH0=SHf00809bLW
0P0V9RH202`/;080:RXZ0P0];Bd201dM7@80FUYJ0P2JVYX2061PH080Hf=S0P1YJFT206QXJ0@0IfMW
00<0Kfm_06a/K01/K6`00P1TI6@206IVIP80IfMW0P1XJ6P2061PH080G5aL0P1@D50204Q8B080A4A4
0P1>CTh204];B`80CDe=0P1BDU8205=CD`0305MGE`1KFe/0Fe]K0080H61P0P1LG5`206ATI080KVi^
0P1ZJVX205MGE`80F5QH0P1MGEd205QHF080EUIF0P1BDU8205EEE@80Cdm?0P1ADE400`1DE5@0De=C
05=CD`0204A4A080=cLg0P0`<302024Q8@809bLW0P0U9BD202h^;P809RHV0P0g=cL202d];@80>3Ph
0P0Z:RX203De=@808B4Q00<0DU9B07QhN01hN7P00P1:BTX204=3@`80ATI60P1DE5@20410@080@T92
0P11@D42055AD@80Cdm?0P1UIFD205YJFP80C4a<0P28R8P205eMG@0307MgM`1cLg<0Lg=c0080Ogmo
0P21PH4207UiN@H0MWIf0P1`L70207AdM080N7Qh0P1iNGT407IfMP80N7Qh0P1dM7@00`1`L700MgMg
07MgM`0207IfMP80L71`0P1dM7@607IfMQD0oooo000C0?ooo`80MWIf0P1hN7P207UiN@80N7Qh0P1k
Ng/207UiN@@0MWIf00<0N7Qh07AdM01dM7@00P1dM7@607IfMP80L71`101_Kfl207IfMP80Ng]k0P1/
K6`205=CD`80@D510P0l?3`2030`<00302l_;`0f=SH0=SHf00809bLW0P0V9RH202`/;080:RXZ0P0]
;Bd201dM7@80FUYJ0P2JVYX2061PH080Hf=S0P1YJFT206QXJ0@0IfMW00<0Kfm_06a/K01/K6`00P1T
I6@206IVIP80IfMW0P1XJ6P2061PH080G5aL0P1@D50204Q8B080A4A40P1>CTh204];B`80CDe=0P1B
DU8205=CD`0305MGE`1KFe/0Fe]K0080H61P0P1LG5`206ATI080KVi^0P1ZJVX205MGE`80F5QH0P1M
GEd205QHF080EUIF0P1BDU8205EEE@80Cdm?0P1ADE400`1DE5@0De=C05=CD`0204A4A080=cLg0P0`
<302024Q8@809bLW0P0U9BD202h^;P809RHV0P0g=cL202d];@80>3Ph0P0Z:RX203De=@808B4Q00<0
DU9B07QhN01hN7P00P1:BTX204=3@`80ATI60P1DE5@20410@080@T920P11@D42055AD@80Cdm?0P1U
IFD205YJFP80C4a<0P28R8P205eMG@0307MgM`1cLg<0Lg=c0080Ogmo0P21PH4207UiN@H0MWIf0P1`
L70207AdM080N7Qh0P1iNGT407IfMP80N7Qh0P1dM7@00`1`L700MgMg07MgM`0207IfMP80L71`0P1d
M7@607IfMQD0oooo000C0?ooo`80Kfm_0P1dM7@807IfMP80L71`0P1dM7@3071`L080MgMg0P1fMWH2
071`L080M7Ad0P1hN7P207]kN`80Lg=c0P1gMgL2071`L080M7Ad0P1GEeL203dm?@80;Bd]0P0X:2P0
0`0T92@08b<S02<S8`0202<S8`807QhN0P0L71`202HV9P80:BTY0P0L71`209NGU`80RXZ:0P1UIFD2
06IVIP80JFUY1P1WIfL00`1UIFD0Hf=S06=SH`0206ATI0H0IfMW0P1QHF4205MGE`80DE5A0P1MGEd2
051@D080DE5A0P1?Cdl204Y:BP80Cdm?0P1DE5@00`1CDe<0FEUI05UIF@0205YJFP80GUiN0P1IFET2
05mOG`80HV9R0P1VIVH2065QH@80JVYZ0P1TI6@205eMG@80FUYJ0P1GEeL204m?C`80DE5A00<0D51@
0451@@11@D400P13@d<204A4A080<C4a0P0L71`200L71`80410@0P0S8b<202TY:@80>SXj0P0V9RH2
03hn?P80=SHf0P0k>c/202@T9003065QH@0c<c<0<c<c0080?Cdm0P1lO7`2059BDP80BDU90P1<C4`2
04I6AP80BDU90P11@D4204=3@`80HV9R0P1NGUh206][J`80MgMg0P1XJ6P00`1[Jf/0Cdm?04m?C`02
079bLPX0MWIf0P1bLW8207MgM`X0MWIf0P1hN7P00`1kNg/0NGUi07UiN@0207IfMP80LW9b0P1gMgL6
07IfMQD0oooo000C0?ooo`80Kfm_0P1dM7@807IfMP80L71`0P1dM7@3071`L080MgMg0P1fMWH2071`
L080M7Ad0P1hN7P207]kN`80Lg=c0P1gMgL2071`L080M7Ad0P1GEeL203dm?@80;Bd]0P0X:2P00`0T
92@08b<S02<S8`0202<S8`807QhN0P0L71`202HV9P80:BTY0P0L71`209NGU`80RXZ:0P1UIFD206IV
IP80JFUY1P1WIfL00`1UIFD0Hf=S06=SH`0206ATI0H0IfMW0P1QHF4205MGE`80DE5A0P1MGEd2051@
D080DE5A0P1?Cdl204Y:BP80Cdm?0P1DE5@00`1CDe<0FEUI05UIF@0205YJFP80GUiN0P1IFET205mO
G`80HV9R0P1VIVH2065QH@80JVYZ0P1TI6@205eMG@80FUYJ0P1GEeL204m?C`80DE5A00<0D51@0451
@@11@D400P13@d<204A4A080<C4a0P0L71`200L71`80410@0P0S8b<202TY:@80>SXj0P0V9RH203hn
?P80=SHf0P0k>c/202@T9003065QH@0c<c<0<c<c0080?Cdm0P1lO7`2059BDP80BDU90P1<C4`204I6
AP80BDU90P11@D4204=3@`80HV9R0P1NGUh206][J`80MgMg0P1XJ6P00`1[Jf/0Cdm?04m?C`02079b
LPX0MWIf0P1bLW8207MgM`X0MWIf0P1hN7P00`1kNg/0NGUi07UiN@0207IfMP80LW9b0P1gMgL607If
MQD0oooo000C0?ooo`80Ng]k0P1iNGT807IfMP80N7Qh0P1dM7@00`1fMWH0Ng]k07]kN`0207UiN@80
L71`0P1fMWH207UiN@@0MWIf0P1hN7P207YjNP80N7Qh0P1[Jf/20492@P80=3@d0P0X:2P202<S8`03
02LW9`0M7Ad07AdM00@09BDU0P0];Bd202XZ:P806QXJ0P0H61P208N7Q`H0HF5Q0P1WIfL2069RHP80
Jf][0P1_Kfl00`1YJFT0IfMW06MWI`0206QXJ080I6AT0P1ZJVX203hn?P8092@T0P1DE5@2071`L080
IVIV0P1IFET202PX:0806QXJ0P0_;bl204a<C080;bl_00<0?3`l055AD@1ADE400P1JFUX206QXJ0@0
JVYZ101TI6@206MWI`80GEeM0P1EEED205MGE`80FUYJ0P1EEED205QHF080De=C00<0D51@04i>CP1>
CTh00P19BDT203Lg=`80=SHf0P0V9RH200l?3`806ATI0P0K6a/202<S8`80:2PX0P0Z:RX203Xj>P80
=CDe0P0Y:BT203`l?00302`/;00b<S80<S8b0080I6AT0P18B4P204];B`80BDU90P15ADD202XZ:P80
>CTi0P0j>SX205EEE@80JVYZ0P1LG5`208V9R@80EUIF0P1aLG400`1?Cdl0P8200820P00208j>SPX0
MWIf0P1hN7P207UiNA40MWIf0P1hN7P207UiN@80MWIf0P1`L70207AdM1D0oooo000C0?ooo`80Ng]k
0P1iNGT807IfMP80N7Qh0P1dM7@00`1fMWH0Ng]k07]kN`0207UiN@80L71`0P1fMWH207UiN@@0MWIf
0P1hN7P207YjNP80N7Qh0P1[Jf/20492@P80=3@d0P0X:2P202<S8`0302LW9`0M7Ad07AdM00@09BDU
0P0];Bd202XZ:P806QXJ0P0H61P208N7Q`H0HF5Q0P1WIfL2069RHP80Jf][0P1_Kfl00`1YJFT0IfMW
06MWI`0206QXJ080I6AT0P1ZJVX203hn?P8092@T0P1DE5@2071`L080IVIV0P1IFET202PX:0806QXJ
0P0_;bl204a<C080;bl_00<0?3`l055AD@1ADE400P1JFUX206QXJ0@0JVYZ101TI6@206MWI`80GEeM
0P1EEED205MGE`80FUYJ0P1EEED205QHF080De=C00<0D51@04i>CP1>CTh00P19BDT203Lg=`80=SHf
0P0V9RH200l?3`806ATI0P0K6a/202<S8`80:2PX0P0Z:RX203Xj>P80=CDe0P0Y:BT203`l?00302`/
;00b<S80<S8b0080I6AT0P18B4P204];B`80BDU90P15ADD202XZ:P80>CTi0P0j>SX205EEE@80JVYZ
0P1LG5`208V9R@80EUIF0P1aLG400`1?Cdl0P8200820P00208j>SPX0MWIf0P1hN7P207UiNA40MWIf
0P1hN7P207UiN@80MWIf0P1`L70207AdM1D0oooo000C0?ooo`@0Kfm_0P1dM7@2071`L080Kfm_0P1d
M7@207IfMP80N7Qh00<0NGUi071`L01`L7000P1_Kfl207IfMP@0M7Ad201fMWH2071`L080H61P0P0e
=CD402d];@80>3Ph0`0Y:BT2024Q8@808b<S0P0Y:BT201hN7P806ATI0P0e=CD209BDU080I6AT0P1Z
JVX206i^KP80LW9b0P1ZJVX206=SH`80IVIV00<0H61P06EUI@1UIFD00P1SHf<206MWI`80KVi^0P1c
Lg<208j>SP80R8R8101XJ6P2069RHP80KVi^0P2=SHd208N7Q`80N7Qh0P1XJ6P00`1DE5@0BDU904U9
B@0205YJFP80IfMW0P1TI6@606=SH`80EeMG0P1SHf<206e]K@80I6AT0P1KFe/205UIF@80EeMG0P1?
Cdl304U9B@80A4A40P16ATH203lo?`80=3@d0P092@T200h>3P8051@D0P0P820202TY:@80<C4a0P0Y
:BT203Ph>080:RXZ0P0_;bl00`0?3`l0HF5Q065QH@0204a<C080?Shn0P1WIfL203Xj>P80ADE50P0e
=CD20410@080Bd];101@D502061PH080G5aL0P10@40204i>CP0307moO`2NWYh0WYjN0080L71`0P1d
M7@807IfMP80L71`0P1dM7@607IfMP80L71`0P1dM7@707IfMP80L71`0P1_Kfl207AdM080N7Qh0P1i
NGTE0?ooo`004`3oool406m_K`80M7Ad0P1`L70206m_K`80M7Ad0P1fMWH207QhN00307UiN@1`L700
L71`0080Kfm_0P1fMWH407AdM0P0MWIf0P1`L702061PH080=CDe100];Bd203Ph>0<0:BTY0P0Q8B42
02<S8`80:BTY0P0N7Qh201TI6@80=CDe0P2DU9@206ATI080JVYZ0P1^KVh2079bLP80JVYZ0P1SHf<2
06IVIP03061PH01UIFD0IFEU0080Hf=S0P1WIfL206i^KP80Lg=c0P2>SXh208R8R0@0J6QX0P1RHV82
06i^KP80SHf=0P27QhL207QhN080J6QX00<0E5AD04U9B@19BDT00P1JFUX206MWI`80I6AT1P1SHf<2
05MGE`80Hf=S0P1]KFd206ATI080Fe]K0P1IFET205MGE`80Cdm?0`19BDT204A4A080ATI60P0o?cl2
03@d=0802@T90P0>3Ph201@D5080820P0P0Y:BT2034a<@80:BTY0P0h>3P202XZ:P80;bl_00<03`l?
065QH@1QHF400P1<C4`203hn?P80IfMW0P0j>SX204E5A@80=CDe0P10@40204];B`@0D51@0P1PH602
05aLG080@4100P1>CTh00`1oOgl0WYjN09jNWP02071`L080M7Ad201fMWH2071`L080M7Ad1P1fMWH2
071`L080M7Ad1`1fMWH2071`L080Kfm_0P1dM7@207QhN080NGUi5@3oool001<0oooo101kNg/207Ui
N@80N7Qh0P1kNg/207UiN@80L71`0P1dM7@00`1fMWH0LW9b079bLP0207AdM080MgMg0P1hN7P207Ui
N@80MWIf0P1^KVh207=cL`80MWIf0P1hN7P2065QH@80=cLg0P0Y:BT202/[:`8061PH00<07alO02/[
:`0[:b/00P0V9RH402`/;0805aLG0P0H61P2059BDP80R8R80P1UIFD206IVIP80HV9R0P1XJ6P206][
J`80LG5a0P1`L7000`1/K6`0Jf][06][J`0206QXJ080I6AT0P1YJFT205mOG`80KFe]0P1cLg<2075a
L@80JFUY0P1XJ6P206=SH`80GUiN0P1LG5`205IFEP80EEEE00<0GEeM06=SH`1SHf<0101WIfL206=S
H`80IVIV0P1TI6@206=SH`80IfMW0P1NGUh205ADE080EeMG0P1MGEd205aLG080FUYJ0P1CDe<304Q8
B080@d=30P0n?Sh203Hf=P80=3@d0P0820P201DE5@803`l?0P0[:b/2034a<@80>CTi0P0R8R8203Lg
=`80:2PX0P0b<S800`0J6QX0G5aL05aLG00203/k>`80H61P0P1^KVh203Lg=`80BTY:0P0l?3`204Q8
B080AdM70P1:BTX205aLG080IfMW0P1QHF42061PH080MgMg00<0Shn?07IfMP1fMWH00P1bLW8207Mg
M`P0MWIf0P1hN7P207UiN@80L71`0P1dM7@207IfMP80N7Qh0P1iNGT707IfMP80N7Qh0P1eMGD207Mg
M`@0MWIf5@3oool001<0oooo101kNg/207UiN@80N7Qh0P1kNg/207UiN@80L71`0P1dM7@00`1fMWH0
LW9b079bLP0207AdM080MgMg0P1hN7P207UiN@80MWIf0P1^KVh207=cL`80MWIf0P1hN7P2065QH@80
=cLg0P0Y:BT202/[:`8061PH00<07alO02/[:`0[:b/00P0V9RH402`/;0805aLG0P0H61P2059BDP80
R8R80P1UIFD206IVIP80HV9R0P1XJ6P206][J`80LG5a0P1`L7000`1/K6`0Jf][06][J`0206QXJ080
I6AT0P1YJFT205mOG`80KFe]0P1cLg<2075aL@80JFUY0P1XJ6P206=SH`80GUiN0P1LG5`205IFEP80
EEEE00<0GEeM06=SH`1SHf<0101WIfL206=SH`80IVIV0P1TI6@206=SH`80IfMW0P1NGUh205ADE080
EeMG0P1MGEd205aLG080FUYJ0P1CDe<304Q8B080@d=30P0n?Sh203Hf=P80=3@d0P0820P201DE5@80
3`l?0P0[:b/2034a<@80>CTi0P0R8R8203Lg=`80:2PX0P0b<S800`0J6QX0G5aL05aLG00203/k>`80
H61P0P1^KVh203Lg=`80BTY:0P0l?3`204Q8B080AdM70P1:BTX205aLG080IfMW0P1QHF42061PH080
MgMg00<0Shn?07IfMP1fMWH00P1bLW8207MgM`P0MWIf0P1hN7P207UiN@80L71`0P1dM7@207IfMP80
N7Qh0P1iNGT707IfMP80N7Qh0P1eMGD207MgM`@0MWIf5@3oool001<0oooo1P1fMWH2071`L080M7Ad
0P1`L70207IfMP80NGUi00<0L71`07IfMP1fMWH00P1eMGD207MgM`80MWIf0P1^KVh607=cL`80M7Ad
0P1`L70205UIF@80:RXZ0P0V9RH402h^;P0302d];@0X:2P0:2PX0080:RXZ0P0_;bl202DU9@805ADE
0P0P82020::RXP80T92@0P1/K6`206][J`80LW9b0P1`L70206YZJP80J6QX0P1YJFT00`1XJ6P0K6a/
06a/K00206ATI080GUiN0P1[Jf/206i^KP80L71`0P1cLg<206a/K0@0HV9R0P1OGel205YJFP80E5AD
0P1FEUH205QHF00305ADE01NGUh0GUiN0080I6AT0P1VIVH206=SH`80IfMW0P1SHf<206IVIP80I6AT
0P1VIVH206e]K@80HF5Q0P1NGUh405YJFP80EUIF00<0F5QH059BDP1BDU800P17AdL203lo?`80>3Ph
0P0];Bd201HF5P801@D50P0B4Q8202TY:@804Q8B0P0`<30202d];@80@D510P0P820202TY:@0303Hf
=P1:BTX0BTY:0080@D510P1JFUX204e=C@80CTi>0P15ADD204U9B@80@4100P0n?Sh203Xj>P80E5AD
0P1XJ6P205=CD`80JFUY0P2EUID00`2>SXh0MWIf07IfMP0207QhN080NGUi1P1fMWH2071`L080Kfm_
0P1dM7@207QhN080NGUi3`1fMWH207QhN080NGUi101fMWHE0?ooo`004`3oool607IfMP80L71`0P1d
M7@2071`L080MWIf0P1iNGT00`1`L700MWIf07IfMP0207EeM@80MgMg0P1fMWH206i^KPH0Lg=c0P1d
M7@2071`L080FEUI0P0Z:RX202HV9P@0;Rh^00<0;Bd]02PX:00X:2P00P0Z:RX202l_;`809BDU0P0E
5AD2020P8080XZ:R0P2@T90206a/K080Jf][0P1bLW82071`L080JVYZ0P1XJ6P206UYJ@0306QXJ01/
K6`0K6a/0080I6AT0P1NGUh206][J`80KVi^0P1`L70207=cL`80K6a/101RHV8205mOG`80FUYJ0P1D
E5@205IFEP80F5QH00<0E5AD05iNGP1NGUh00P1TI6@206IVIP80Hf=S0P1WIfL206=SH`80IVIV0P1T
I6@206IVIP80KFe]0P1QHF4205iNGP@0FUYJ0P1FEUH00`1HF5P0DU9B059BDP0204M7A`80?clo0P0h
>3P202d];@805QHF0P051@D2018B4P80:BTY0P0B4Q82030`<080;Bd]0P11@D42020P8080:BTY00<0
=SHf04Y:BP1:BTX00P11@D4205YJFP80CDe=0P1>CTh204E5A@80BDU90P10@40203hn?P80>SXj0P1D
E5@206QXJ080De=C0P1YJFT209FEU@0308j>SP1fMWH0MWIf0080N7Qh0P1iNGT607IfMP80L71`0P1_
Kfl207AdM080N7Qh0P1iNGT?07IfMP80N7Qh0P1iNGT407IfMQD0oooo000C0?ooo`H0MWIf0P1hN7P2
07UiN@80N7Qh0P1iNGT3071`L080MgMg101bLW8207AdM080N7Qh0P1eMGD207IfMP80Ng]k0P1iNGT2
071`L080;Bd]0P0J6QX2030`<0806a/K0P0L71`00`0Q8B409bLW02LW9`0202XZ:P809bLW0P0>3Ph2
01HF5P804Q8B0P1oOgl206MWI`80J6QX0P1QHF4406UYJ@80J6QX0P1YJFT506YZJP80KFe]0P1^KVh2
06YZJP80GEeM0P1UIFD206IVIP80Hf=S0P1WIfL206ATI080DU9B0P19BDT204m?C`80EUIF0P1@D500
0`1HF5P0Hf=S06=SH`0206i^KP80Jf][0P1TI6@206QXJ080Jf][0P1UIFD2065QH@80HV9R0P1SHf<2
06MWI`80HF5Q0P1HF5P405UIF@0305QHF01DE5@0E5AD0080AdM70P0o?cl203dm?@80>c/k0P0/;2`2
00X:2P80410@0P0N7Qh403Hf=P80;Rh^0P0g=cL202DU9@80;bl_00<092@T03Ti>@0i>CT00P17AdL2
04Q8B080EUIF0P1`L70403dm?@80<c<c0P11@D4205EEE@80NGUi0P1^KVh20451@@80GemO0P20P803
07AdM080L71`101_Kfl207AdM080MWIf0P1hN7P207EeM@80MgMg3`1fMWH2071`L080M7Ad201fMWHE
0?ooo`004`3oool607IfMP80N7Qh0P1iNGT207QhN080NGUi0`1`L70207MgM`@0LW9b0P1dM7@207Qh
N080MGEe0P1fMWH207]kN`80NGUi0P1`L70202d];@806QXJ0P0`<30201/K6`8071`L00<08B4Q02LW
9`0W9bL00P0Z:RX202LW9`803Ph>0P0F5QH2018B4P80Ogmo0P1WIfL206QXJ080HF5Q101YJFT206QX
J080JFUY1@1ZJVX206e]K@80KVi^0P1ZJVX205eMG@80IFEU0P1VIVH206=SH`80IfMW0P1TI6@2059B
DP80BDU90P1?Cdl205IFEP80D51@00<0F5QH06=SH`1SHf<00P1^KVh206][J`80I6AT0P1XJ6P206][
J`80IFEU0P1QHF42069RHP80Hf=S0P1WIfL2065QH@80F5QH101IFET00`1HF5P0E5AD05ADE00204M7
A`80?clo0P0m?Cd203/k>`80;2`/0P0:2PX2010@40807QhN100f=SH202h^;P80=cLg0P0U9BD202l_
;`0302@T900i>CT0>CTi0080AdM70P18B4P205IFEP80L71`100m?Cd203<c<`80@D510P1EEED207Ui
N@80KVi^0P11@D4205mOG`80P8200`1dM7@2071`L0@0Kfm_0P1dM7@207IfMP80N7Qh0P1eMGD207Mg
M`l0MWIf0P1`L70207AdM0P0MWIf5@3oool001<0oooo101_Kfl207AdM0@0MWIf0P1`L70207AdM080
N7Qh00<0Ng]k07UiN@1iNGT00P1hN7P207]kN`@0M7Ad0P1bLW8207MgM`@0MWIf0P1`L702030`<080
:b/[0P0T92@201/K6`80<S8b00<0;bl_02d];@0];Bd00P0X:2P200X:2P804a<C0P0F5QH2024Q8@80
Ti>C0P1ZJVX4071`L080KVi^0P1WIfL406QXJ0D0IfMW0P1YJFT206][J`80I6AT0P1UIFD206=SH`80
IfMW0P1PH60205]KF`80De=C0P1GEeL205ADE0H0Fe]K00<0IFEU071`L01`L7000P1[Jf/406=SH`80
I6AT0P1WIfL2069RHP80IfMW0P1TI6@406=SH`80Fe]K0P1PH60205aLG080FUYJ00<0DU9B05MGE`1G
EeL00P1ADE4204a<C080?Shn0P0g=cL202TY:@802@T90P0M7Ad201XJ6P@08R8R0P0Y:BT202LW9`80
=cLg0P0a<C400`0^;Rh0BTY:04Y:BP0404m?C`80G5aL0P1aLG4203/k>`80?Shn0P0c<c<203hn?P80
@4100P1ADE4205aLG080LW9b0P2WYjL208j>SP0307QhN01iNGT0NGUi0080N7Qh101kNg/207UiN@@0
MWIf0P1hN7P207UiN@H0MWIf0P1`L70207AdM0D0MWIf101bLW8207AdM0H0MWIf5@3oool001<0oooo
101kNg/207UiN@80MWIf0P1`L70207IfMP80NGUi1`1fMWH2071`L080MWIf0P1dM7@207IfMP80M7Ad
101_Kfl2075aL@80=CDe0P0[:b/202@T9080:RXZ0P0b<S800`0V9RH09bLW02LW9`0202XZ:P8061PH
0P0E5AD201PH6080UYJF0P2e]KD206QXJ080JVYZ0P1XJ6P606UYJ@80LW9b0`1eMGD206a/K080JVYZ
0P1YJFT206e]K@80K6a/0P1RHV8206][J`80KFe]0P1UIFD205YJFP80De=C0P1FEUH205aLG080H61P
0P1SHf<00`1WIfL0J6QX06QXJ00206UYJ@H0IVIV0P1^KVh206YZJP80IfMW0P1SHf<206ATI080Hf=S
101KFe/205eMG@80FEUI00<0De=C04i>CP1>CTh00P1>CTh204I6AP80>3Ph0P0f=SH203Lg=`8051@D
0P092@T201XJ6P805aLG0P0/;2`203Hf=P80:2PX0P0_;bl203Lg=`0302l_;`0n?Sh0?Shn0080F5QH
0P1KFe/205mOG`80K6a/0P0_;bl204m?C`80;Rh^0P17AdL203`l?080Jf][0P1eMGD206QXJ080Ph>3
0P1iNGTI07IfMP80N7Qh0P1iNGT507IfMP80N7Qh0P1kNg/207UiN@80MWIf0P1`L70207AdM1D0oooo
000C0?ooo`@0Ng]k0P1iNGT207IfMP80L71`0P1fMWH207UiN@L0MWIf0P1`L70207IfMP80M7Ad0P1f
MWH207AdM0@0Kfm_0P1aLG4203De=@80:b/[0P0T92@202XZ:P80<S8b00<09RHV02LW9`0W9bL00P0Z
:RX201PH60805ADE0P0H61P209JFUP80]KFe0P1XJ6P206YZJP80J6QX1P1YJFT2079bLP<0MGEe0P1/
K6`206YZJP80JFUY0P1]KFd206a/K080HV9R0P1[Jf/206e]K@80IFEU0P1JFUX205=CD`80EUIF0P1L
G5`2061PH080Hf=S00<0IfMW06QXJ01XJ6P00P1YJFT606IVIP80KVi^0P1ZJVX206MWI`80Hf=S0P1T
I6@206=SH`@0Fe]K0P1MGEd205UIF@0305=CD`1>CTh0CTi>0080CTi>0P16ATH203Ph>080=SHf0P0g
=cL201@D50802@T90P0J6QX201LG5`80;2`/0P0f=SH202PX:080;bl_0P0g=cL00`0_;bl0?Shn03hn
?P0205QHF080Fe]K0P1OGel206a/K080;bl_0P1?Cdl202h^;P80AdM70P0l?3`206][J`80MGEe0P1X
J6P208>3P`80NGUi6@1fMWH207QhN080NGUi1@1fMWH207QhN080Ng]k0P1iNGT207IfMP80L71`0P1d
M7@E0?ooo`004`3oool606m_K`80M7Ad0P1hN7P207UiN@L0MWIf101`L702079bLP80MWIf0P1iNGT2
079bLP80M7Ad0P1iNGT204i>CP807QhN0P0X:2P2028R8P80;Bd]0P0^;Rh00`0Z:RX0:BTY02TY:@02
01<C4`@03Ph>0P2/[:`20<g=c@80MgMg0P1^KVh207IfMP80Jf][0P1YJFT2079bLP80K6a/0P1VIVH3
065QH@80I6AT0P1XJ6P406MWI`@0Jf][0P1_Kfl206UYJ@80Hf=S0P1XJ6P2069RHP80Fe]K101PH602
05aLG003061PH01VIVH0IVIV0080HV9R0P1]KFd207EeM@80J6QX0P1[Jf/2061PH080KVi^101/K6`2
06IVIP80IfMW0P1/K6`2069RHP80GemO00<0Fe]K05MGE`1GEeL00P1CDe<205IFEP80ATI60P0i>CT2
03@d=0809bLW0P0R8R8202XZ:P80<30`0P0^;Rh203Hf=P80;Rh^0P0k>c/2030`<00302LW9`0o?cl0
?clo0080HV9R0P1DE5@205QHF080GUiN100n?Sh2024Q8@@0?clo0P1RHV8206YZJP80QhN70P2=SHd?
07IfMP80L71`0P1dM7@207IfMP80L71`0P1_Kfl207AdM080MWIf0P1`L70207AdM003071`L01dM7@0
M7Ad00P0MWIf0P1hN7P207UiNAD0oooo000C0?ooo`H0Kfm_0P1dM7@207QhN080NGUi1`1fMWH4071`
L080LW9b0P1fMWH207UiN@80LW9b0P1dM7@207UiN@80CTi>0P0N7Qh202PX:0808R8R0P0];Bd202h^
;P0302XZ:P0Y:BT0:BTY00804a<C100>3Ph20:b/[080cLg=0P1gMgL206i^KP80MWIf0P1[Jf/206UY
J@80LW9b0P1/K6`206IVIP<0HF5Q0P1TI6@206QXJ0@0IfMW101[Jf/206m_K`80JFUY0P1SHf<206QX
J080HV9R0P1KFe/4061PH080G5aL00<0H61P06IVIP1VIVH00P1RHV8206e]K@80MGEe0P1XJ6P206][
J`80H61P0P1^KVh406a/K080IVIV0P1WIfL206a/K080HV9R0P1OGel00`1KFe/0EeMG05MGE`0205=C
D`80EUIF0P16ATH203Ti>@80=3@d0P0W9bL2028R8P80:RXZ0P0`<30202h^;P80=SHf0P0^;Rh203/k
>`80<30`00<09bLW03lo?`0o?cl00P1RHV8205ADE080F5QH0P1NGUh403hn?P808B4Q100o?cl2069R
HP80JVYZ0P27QhL208f=S@l0MWIf0P1`L70207AdM080MWIf0P1`L70206m_K`80M7Ad0P1fMWH2071`
L080M7Ad00<0L71`07AdM01dM7@0201fMWH207QhN080NGUi5@3oool001<0oooo0P1dM7@207UiN@80
MGEe0P1gMgL907IfMP80L71`0P1fMWH207]kN`80MGEe0P1gMgL207IfMP80N7Qh0P1kNg/207UiN@80
61PH0P0C4a<202@T90805QHF0P0^;Rh202HV9P0302DU9@0Z:RX0:RXZ00805QHF0P0U9BD202LW9`80
WIfM0P1YJFT206][J`80Kfm_0P1VIVH206ATI0@0LW9b0P1WIfL206UYJ@80JVYZ00<0LW9b06a/K01/
K6`01P1YJFT206YZJP80I6AT0P1ZJVX206UYJ@80KFe]0P1YJFT205YJFP80EUIF0P1NGUh2069RHP80
I6AT0`1RHV8206MWI`80Kfm_0P1SHf<206][J`80Kfm_0P1^KVh206EUI@80HF5Q0P1VIVH206QXJ080
IVIV0P1TI6@205mOG`80GEeM00<0EeMG05YJFP1JFUX00P1BDU82051@D080@4100P0m?Cd2030`<080
9BDU0P0R8R8202<S8`807alO0P0];Bd202`/;080=CDe0P0i>CT202l_;`0304=3@`1IFET0FEUI0080
GUiN1P1=CDd203dm?@80=3@d0P0S8b<204A4A080EEEE0P1VIVH207MgM`80QHF50P1lO7`?07IfMP80
N7Qh0P1iNGT207IfMP80N7Qh0P1kNg/207UiN@80MWIf0P1hN7P207AdM00307IfMP1iNGT0NGUi0080
MWIf0P1`L70207AdM0H0MWIf5@3oool001<0oooo0P1dM7@207UiN@80MGEe0P1gMgL907IfMP80L71`
0P1fMWH207]kN`80MGEe0P1gMgL207IfMP80N7Qh0P1kNg/207UiN@8061PH0P0C4a<202@T90805QHF
0P0^;Rh202HV9P0302DU9@0Z:RX0:RXZ00805QHF0P0U9BD202LW9`80WIfM0P1YJFT206][J`80Kfm_
0P1VIVH206ATI0@0LW9b0P1WIfL206UYJ@80JVYZ00<0LW9b06a/K01/K6`01P1YJFT206YZJP80I6AT
0P1ZJVX206UYJ@80KFe]0P1YJFT205YJFP80EUIF0P1NGUh2069RHP80I6AT0`1RHV8206MWI`80Kfm_
0P1SHf<206][J`80Kfm_0P1^KVh206EUI@80HF5Q0P1VIVH206QXJ080IVIV0P1TI6@205mOG`80GEeM
00<0EeMG05YJFP1JFUX00P1BDU82051@D080@4100P0m?Cd2030`<0809BDU0P0R8R8202<S8`807alO
0P0];Bd202`/;080=CDe0P0i>CT202l_;`0304=3@`1IFET0FEUI0080GUiN1P1=CDd203dm?@80=3@d
0P0S8b<204A4A080EEEE0P1VIVH207MgM`80QHF50P1lO7`?07IfMP80N7Qh0P1iNGT207IfMP80N7Qh
0P1kNg/207UiN@80MWIf0P1hN7P207AdM00307IfMP1iNGT0NGUi0080MWIf0P1`L70207AdM0H0MWIf
5@3oool001<0oooo0P1dM7@207MgM`80N7Qh0P1iNGT907IfMP80N7Qh0P1iNGT207IfMP80LW9b0P1g
MgL407IfMP80L71`0P1dM7@202`/;080=SHf0P0U9BD201lO7`80>3Ph0P0_;bl00`0Z:RX08b<S02<S
8`02020P808061PH0P1KFe/20:BTY080Jf][0P1^KVh406QXJ0@0LW9b0P1TI6@206EUI@80JFUY0P1Z
JVX00`1WIfL0I6AT06ATI002079bLP80MGEe0P1/K6`206QXJ080K6a/0P1^KVh206QXJ0@0GUiN0P1H
F5P405IFEP80GEeM0P1OGel00`1XJ6P0JFUY06UYJ@0206UYJ@80I6AT0P1RHV8206YZJP80J6QX0P1O
Gel205iNGP80Kfm_0P1ZJVX206IVIP80HV9R0P1SHf<206IVIP80Hf=S0`1HF5P205ADE080DU9B0P14
A4@203/k>`80;bl_0P0[:b/201XJ6P806ATI0P0P820402LW9`@0=CDe0P0f=SH00`0_;bl0Fe]K05]K
F`0205aLG0@0D51@0P1DE5@205eMG@80>c/k0P11@D4204Y:BP80@T920P1IFET208R8R080PX:25`1f
MWH2071`L080M7Ad0P1`L70207AdM080MWIf0P1hN7P00`1iNGT0MWIf07IfMP0207IfMP80N7Qh0P1i
NGT607IfMQD0oooo000C0?ooo`80M7Ad0P1gMgL207QhN080NGUi2@1fMWH207QhN080NGUi0P1fMWH2
079bLP80MgMg101fMWH2071`L080M7Ad0P0/;2`203Hf=P809BDU0P0O7al203Ph>080;bl_00<0:RXZ
02<S8`0S8b<00P0P820201PH6080Fe]K0P2TY:@206][J`80KVi^101XJ6P4079bLP80I6AT0P1UIFD2
06UYJ@80JVYZ00<0IfMW06ATI01TI6@00P1bLW8207EeM@80K6a/0P1XJ6P206a/K080KVi^0P1XJ6P4
05iNGP80F5QH101FEUH205eMG@80GemO00<0J6QX06UYJ@1YJFT00P1YJFT206ATI080HV9R0P1ZJVX2
06QXJ080GemO0P1NGUh206m_K`80JVYZ0P1VIVH2069RHP80Hf=S0P1VIVH206=SH`<0F5QH0P1DE5@2
059BDP80A4A40P0k>c/202l_;`80:b/[0P0J6QX201TI6@80820P100W9bL403De=@80=SHf00<0;bl_
05]KF`1KFe/00P1LG5`4051@D080E5AD0P1MGEd203/k>`80@D510P1:BTX20492@P80FEUI0P28R8P2
08:2PQL0MWIf0P1`L70207AdM080L71`0P1dM7@207IfMP80N7Qh00<0NGUi07IfMP1fMWH00P1fMWH2
07QhN080NGUi1P1fMWHE0?ooo`004`3oool207]kN`80NGUi0P1`L70207AdM080L71`0P1dM7@407If
MP03071`L01dM7@0M7Ad00@0MWIf0P1hN7P207UiN@@0MWIf0P1hN7P207AdM0809bLW0P0k>c/202h^
;P80:b/[0P0T92@202PX:00302XZ:P0I6AT06ATI008092@T0P0g=cL20;2`/080U9BD0P1YJFT206YZ
JP@0JFUY0P1VIVH2065QH@80I6AT0P1XJ6P406UYJ@03065QH@1VIVH0IVIV0080IVIV0P1QHF4206AT
I0@0JVYZ0P1LG5`206ATI080K6a/0P1cLg<2065QH@80Fe]K0P1IFET205eMG@80GUiN00<0G5aL05iN
GP1NGUh00P1QHF4206ATI080IVIV0P1TI6@206MWI`80IVIV0P1aLG4206QXJ080Fe]K0P1NGUh2061P
H080Hf=S0P1QHF4205aLG00306=SH`1MGEd0GEeM0080DU9B0P1@D50204m?C`80A4A40P0k>c/202h^
;P809RHV0P0Q8B42028R8P807alO0P0];Bd4038b<P80:2PX00<08b<S06MWI`1WIfL00P1DE5@204M7
A`80CTi>0P1<C4`205MGE`809BDU0P0l?3`20410@080@d=30P1LG5`208>3P`80NGUi5`1fMWH207Qh
N080NGUi0P1hN7P207UiN@80L71`0P1dM7@?07IfMQD0oooo000C0?ooo`80Ng]k0P1iNGT2071`L080
M7Ad0P1`L70207AdM0@0MWIf00<0L71`07AdM01dM7@0101fMWH207QhN080NGUi101fMWH207QhN080
M7Ad0P0W9bL203/k>`80;Rh^0P0[:b/202@T9080:2PX00<0:RXZ01TI6@0I6AT00P0T92@203Lg=`80
/;2`0P2DU9@206UYJ@80JVYZ101YJFT206IVIP80HF5Q0P1TI6@206QXJ0@0JFUY00<0HF5Q06IVIP1V
IVH00P1VIVH2065QH@80I6AT101ZJVX205aLG080I6AT0P1/K6`207=cL`80HF5Q0P1KFe/205UIF@80
GEeM0P1NGUh00`1LG5`0GUiN05iNGP02065QH@80I6AT0P1VIVH206ATI080IfMW0P1VIVH2075aL@80
J6QX0P1KFe/205iNGP80H61P0P1SHf<2065QH@80G5aL00<0Hf=S05eMG@1MGEd00P1BDU82051@D080
Cdm?0P14A4@203/k>`80;Rh^0P0V9RH2024Q8@808R8R0P0O7al202d];@@0<S8b0P0X:2P00`0S8b<0
IfMW06MWI`0205ADE080AdM70P1>CTh204a<C080EeMG0P0U9BD203`l?080@4100P13@d<205aLG080
Ph>30P1iNGTG07IfMP80N7Qh0P1iNGT207QhN080NGUi0P1`L70207AdM0l0MWIf5@3oool001<0oooo
0P1_Kfl207AdM080N7Qh0P1iNGT2079bLP80MgMg0P1`L70207AdM003079bLP1gMgL0MgMg00X0MWIf
0P1`L70207AdM080=3@d0P0B4Q8202/[:`809RHV0P0e=CD2038b<P80;Rh^00<071`L01/K6`0K6a/0
0P0W9bL20:FUY@80]kNg0P1UIFD206][J`80KFe]1P1YJFT2079bLP80K6a/0P1YJFT206YZJP80HV9R
00<0GEeM05aLG01LG5`00P1OGel2065QH@80J6QX0P1ZJVX205iNGP80I6AT0P1^KVh206UYJ@80JVYZ
0P1SHf<205YJFP80EeMG0P1EEED2051@D00305YJFP1@D500D51@0080Fe]K0P1TI6@205mOG`80JVYZ
0P1VIVH206=SH`80I6AT0P1LG5`205iNGPP0Hf=S0P1NGUh00`1OGel0EUIF05IFEP0205YJFP80F5QH
0P19BDT204I6AP80>3Ph0P0`<30202PX:0805QHF0P0P8202024Q8@809bLW0P0l?3`2038b<P80<30`
00<0=CDe05iNGP1NGUh00P10@402051@D080EEEE0P0X:2P205YJFP8071`L0P0d=3@204i>CP80Fe]K
0P1TI6@208b<S080NWYj6`1fMWH2071`L080M7Ad0P1hN7P207UiN@l0MWIf5@3oool001<0oooo0P1_
Kfl207AdM080N7Qh0P1iNGT2079bLP80MgMg0P1`L70207AdM003079bLP1gMgL0MgMg00X0MWIf0P1`
L70207AdM080=3@d0P0B4Q8202/[:`809RHV0P0e=CD2038b<P80;Rh^00<071`L01/K6`0K6a/00P0W
9bL20:FUY@80]kNg0P1UIFD206][J`80KFe]1P1YJFT2079bLP80K6a/0P1YJFT206YZJP80HV9R00<0
GEeM05aLG01LG5`00P1OGel2065QH@80J6QX0P1ZJVX205iNGP80I6AT0P1^KVh206UYJ@80JVYZ0P1S
Hf<205YJFP80EeMG0P1EEED2051@D00305YJFP1@D500D51@0080Fe]K0P1TI6@205mOG`80JVYZ0P1V
IVH206=SH`80I6AT0P1LG5`205iNGPP0Hf=S0P1NGUh00`1OGel0EUIF05IFEP0205YJFP80F5QH0P19
BDT204I6AP80>3Ph0P0`<30202PX:0805QHF0P0P8202024Q8@809bLW0P0l?3`2038b<P80<30`00<0
=CDe05iNGP1NGUh00P10@402051@D080EEEE0P0X:2P205YJFP8071`L0P0d=3@204i>CP80Fe]K0P1T
I6@208b<S080NWYj6`1fMWH2071`L080M7Ad0P1hN7P207UiN@l0MWIf5@3oool001<0oooo0P1kNg/2
07UiN@80MWIf0P1`L70207IfMP80NGUi0P1bLW8207MgM`0307QhN01iNGT0NGUi00X0MWIf0P1bLW82
07MgM`8092@T0P13@d<204E5A@809BDU0P0m?Cd202HV9P80:BTY00<06ATI02XZ:P0Z:RX00P0^;Rh2
08>3P`80HV9R0P1IFET206YZJP80J6QX0P1bLW8206a/K080JFUY0P1WIfL206ATI080Hf=S0P1PH602
04m?C`0305QHF01QHF40HF5Q0080H61P0P1NGUh2069RHP80IfMW0P1TI6@206UYJ@80Jf][0P1YJFT2
06YZJP80H61P0P1@D50205IFEP80DE5A0P1EEED00`1DE5@0GemO05mOG`0206a/K080Hf=S0P1XJ6P2
05iNGP80EUIF0P1DE5@205QHF080G5aL101PH602069RHP80I6AT0P1QHF42069RHP0305MGE`1OGel0
GemO0080Fe]K101BDU8204Q8B080?3`l0P0a<C4202TY:@805aLG0P0C4a<201hN7P80:BTY0P0`<302
03<c<`80<S8b00<0<C4a05aLG01LG5`0101<C4`204i>CP807AdM0P1IFET202PX:080=3@d0P14A4@2
05aLG080Ng]k0P2CTi<407IfMP80L71`00<0M7Ad07IfMP1fMWH0501fMWH2079bLP80MgMg4`1fMWHE
0?ooo`004`3oool207]kN`80NGUi0P1fMWH2071`L080MWIf0P1iNGT2079bLP80MgMg00<0N7Qh07Ui
N@1iNGT02P1fMWH2079bLP80MgMg0P0T92@204=3@`80ADE50P0U9BD203dm?@809RHV0P0Y:BT00`0I
6AT0:RXZ02XZ:P0202h^;P80Ph>30P1RHV8205UIF@80JVYZ0P1XJ6P2079bLP80K6a/0P1YJFT206MW
I`80I6AT0P1SHf<2061PH080Cdm?00<0F5QH065QH@1QHF400P1PH60205iNGP80HV9R0P1WIfL206AT
I080JFUY0P1[Jf/206UYJ@80JVYZ0P1PH602051@D080EUIF0P1ADE4205EEE@0305ADE01OGel0GemO
0080K6a/0P1SHf<206QXJ080GUiN0P1FEUH205ADE080F5QH0P1LG5`4061PH080HV9R0P1TI6@2065Q
H@80HV9R00<0EeMG05mOG`1OGel00P1KFe/4059BDP80B4Q80P0l?3`2034a<@80:BTY0P0G5aL201<C
4`807QhN0P0Y:BT2030`<080<c<c0P0b<S800`0a<C40G5aL05aLG00404a<C080CTi>0P0M7Ad205UI
F@80:2PX0P0d=3@204A4A080G5aL0P1kNg/209>CT`@0MWIf0P1`L7000`1dM7@0MWIf07IfMP0D07If
MP80LW9b0P1gMgLC07IfMQD0oooo000C0?ooo`H0MWIf0P1bLW8207MgM`80MWIf0P1hN7P307AdM0@0
MWIf0P1`L70606m_K`80MWIf0P1iNGT201@D5080A4A40P0Y:BT203Xj>P80=3@d0P0_;bl202TY:@03
01@D500o?cl0?clo0080UiNG0P2TY:@204m?C`80G5aL0P1_Kfl206UYJ@80IVIV0P1TI6@206UYJ@80
HV9R0P1MGEd205aLG080GUiN0P1SHf<00`1DE5@0AdM704M7A`0205=CD`80GEeM0P1PH602069RHP80
FEUI0P1MGEd206MWI`80J6QX0P1ZJVX205ADE080D51@0P1=CDd205ADE080De=C00<0DE5A05MGE`1G
EeL00P1PH602065QH@80EeMG0P1DE5@2051@D080CTi>0P1;Bd/204M7A`80@4100P16ATH204Q8B080
De=C0P1HF5P205UIF@0305iNGP1SHf<0Hf=S0080EUIF0P1BDU8204Q8B080@T92100i>CT202l_;`80
:2PX0P0?3`l201PH60807QhN0P0`<30202l_;`80>SXj00<0;Bd]055AD@1ADE400P1BDU8203Xj>P80
>c/k0P0N7Qh207]kN`80=3@d0P0Z:RX205MGE`80I6AT0P1hN7P208N7Q`@0MWIf0P1hN7P00`1iNGT0
MWIf07IfMP0407IfMP80L71`0P1dM7@<07IfMP80N7Qh0P1iNGT407IfMP03071`L01dM7@0M7Ad00`0
MWIf5@3oool001<0oooo1P1fMWH2079bLP80MgMg0P1fMWH207QhN0<0M7Ad101fMWH2071`L0H0Kfm_
0P1fMWH207UiN@8051@D0P14A4@202TY:@80>SXj0P0d=3@202l_;`80:BTY00<051@D03lo?`0o?cl0
0P2GUiL20:BTY080Cdm?0P1LG5`206m_K`80JFUY0P1VIVH206ATI080JFUY0P1RHV8205eMG@80G5aL
0P1NGUh206=SH`0305ADE017AdL0AdM70080De=C0P1MGEd2061PH080HV9R0P1IFET205eMG@80IfMW
0P1XJ6P206YZJP80E5AD0P1@D50204e=C@80E5AD0P1CDe<00`1ADE40EeMG05MGE`02061PH080HF5Q
0P1GEeL205ADE080D51@0P1>CTh204];B`80AdM70P10@40204I6AP80B4Q80P1CDe<205QHF080FEUI
00<0GUiN06=SH`1SHf<00P1FEUH2059BDP80B4Q80P12@T8403Ti>@80;bl_0P0X:2P200l?3`8061PH
0P0N7Qh2030`<080;bl_0P0j>SX00`0];Bd0DE5A055AD@02059BDP80>SXj0P0k>c/201hN7P80Ng]k
0P0d=3@202XZ:P80EeMG0P1TI6@207QhN080QhN7101fMWH207QhN00307UiN@1fMWH0MWIf00@0MWIf
0P1`L70207AdM0`0MWIf0P1hN7P207UiN@@0MWIf00<0L71`07AdM01dM7@0301fMWHE0?ooo`004`3o
ool607IfMP80N7Qh0P1iNGT407IfMP80N7Qh00<0NGUi071`L01`L7000P1dM7@2079bLP80NGUi101k
Ng/207UiN@80Ogmo0P0];Bd204M7A`808B4Q0P0];Bd202LW9`80<S8b0P0@41000`0^;Rh0<C4a034a
<@0207inOP80@T920P0o?cl206][J`80KVi^0P1XJ6P406UYJ@80Hf=S0P1JFUX204Q8B080;Bd]0P0R
8R8203@d=0030451@@0l?3`0?3`l0080CDe=0P1<C4`206ATI080JFUY0P1SHf<206EUI@80KFe]0P1[
Jf/206YZJP80I6AT0P1IFET204e=C@80BDU90P18B4P00`1WIfL0GUiN05iNGP0206IVIP80DE5A0P1;
Bd/204=3@`80>SXj100];Bd203dm?@80A4A40P15ADD204U9B@80GUiN0P1OGel2059BDP0304i>CP1?
Cdl0Cdm?0080DE5A0P1BDU8204i>CP80ATI60P11@D4202l_;`80:2PX0P0W9bL202DU9@808R8R0P0L
71`202d];@80:BTY0P0a<C400`0^;Rh0C4a<04a<C00203hn?P80=cLg0P0n?Sh202/[:`80O7al0P0S
8b<202HV9P80H61P0P1ADE4206i^KP80RHV90P1iNGT;07IfMP80N7Qh0P1iNGTD07IfMP0307QhN01i
NGT0NGUi00`0MWIf5@3oool001<0oooo1P1fMWH207QhN080NGUi101fMWH207QhN00307UiN@1`L700
L71`0080M7Ad0P1bLW8207UiN@@0Ng]k0P1iNGT207moO`80;Bd]0P17AdL2024Q8@80;Bd]0P0W9bL2
038b<P80410@00<0;Rh^034a<@0a<C400P1nOWh20492@P80?clo0P1[Jf/206i^KP80J6QX101YJFT2
06=SH`80FUYJ0P18B4P202d];@808R8R0P0d=3@00`11@D40?3`l03`l?00204e=C@80C4a<0P1TI6@2
06UYJ@80Hf=S0P1UIFD206e]K@80Jf][0P1ZJVX206ATI080FEUI0P1=CDd204U9B@80B4Q800<0IfMW
05iNGP1NGUh00P1VIVH2055AD@80Bd];0P13@d<203Xj>P@0;Bd]0P0m?Cd204A4A080ADE50P19BDT2
05iNGP80GemO0P1BDU800`1>CTh0Cdm?04m?C`02055AD@80DU9B0P1>CTh204I6AP80@D510P0_;bl2
02PX:0809bLW0P0U9BD2028R8P8071`L0P0];Bd202TY:@80<C4a00<0;Rh^04a<C01<C4`00P0n?Sh2
03Lg=`80?Shn0P0[:b/207alO0808b<S0P0V9RH2061PH080DE5A0P1^KVh208V9R@80NGUi2`1fMWH2
07QhN080NGUi501fMWH00`1hN7P0NGUi07UiN@0<07IfMQD0oooo000C0?ooo`80Kfm_0P1dM7@607If
MP80L71`0P1dM7@2071`L00307AdM01hN7P0N7Qh0080NGUi0P1hN7P207UiN@H0MWIf0P0W9bL201/K
6`80?Cdm0P0P820202XZ:P808b<S0P0a<C4201XJ6P0303`l?02IVIT0VIVI0080Ti>C0P13@d<205UI
F@80KVi^0P1TI6@206IVIP80JFUY0P1MGEd204Q8B08092@T0P0V9RH205IFEP80JFUY0P0W9bL00`0F
5QH0:b/[02/[:`0204M7A`80>CTi0P0`<30204e=C@@0H61P0P1/K6`406UYJ@80GemO0P1KFe/2051@
D080F5QH0P19BDT00`1;Bd/04A4A014A4@0200h>3P807alO0P14A4@206i^KP80=SHf0P0I6AT2030`
<080<S8b0P0[:b/202`/;080<S8b0P16ATH204];B`80DE5A00<0F5QH05UIF@1IFET00P1@D502055A
D@80BDU90P13@d<203Lg=`80=SHf0P0d=3@202PX:080<S8b0P0H61P201HF5P80;bl_0P0];Bd2034a
<@0303/k>`1>CTh0CTi>0080Cdm?0P0k>c/20410@080:BTY0P1cLg<202/[:`80ATI60P1gMgL2065Q
H@80Rh^;0P21PH42071`L1T0MWIf0P1`L70207AdM1D0MWIf5@3oool001<0oooo0P1_Kfl207AdM0H0
MWIf0P1`L70207AdM080L71`00<0M7Ad07QhN01hN7P00P1iNGT207QhN080NGUi1P1fMWH202LW9`80
6a/K0P0m?Cd2020P8080:RXZ0P0S8b<2034a<@806QXJ00<0?3`l09VIV@2IVIT00P2CTi<204=3@`80
FEUI0P1^KVh206ATI080IVIV0P1YJFT205eMG@80B4Q80P0T92@202HV9P80EUIF0P1YJFT202LW9`03
01HF5P0[:b/0:b/[0080AdM70P0i>CT2030`<080CDe=101PH60206a/K0@0JFUY0P1OGel205]KF`80
D51@0P1HF5P204U9B@0304];B`0A4A404A4A00803Ph>0P0O7al204A4A080KVi^0P0f=SH201TI6@80
<30`0P0b<S8202/[:`80;2`/0P0b<S8204I6AP80Bd];0P1ADE400`1HF5P0FEUI05UIF@02051@D080
DE5A0P19BDT204=3@`80=cLg0P0f=SH203@d=080:2PX0P0b<S8201PH60805QHF0P0_;bl202d];@80
<C4a00<0>c/k04i>CP1>CTh00P1?Cdl203/k>`80@4100P0Y:BT207=cL`80:b/[0P16ATH207MgM`80
HF5Q0P2;Rh/20861P@80L71`6@1fMWH2071`L080M7Ad5@1fMWHE0?ooo`004`3oool207]kN`80NGUi
1P1fMWH207QhN080NGUi0P1hN7P00`1iNGT0MWIf07IfMP0207IfMP80L71`0P1dM7@607IfMP80;Rh^
0P1ADE420410@080=SHf0P0I6AT202TY:@80=SHf0P0K6a/00`0D51@0Lg=c07=cL`0205UIF@80EeMG
0P1TI6@207=cL`80KVi^0P1WIfL205QHF080B4Q80P0Z:RX203Lg=`80NWYj0P2EUID202TY:@80820P
00<09RHV03De=@0e=CD00P0d=3@204U9B@80CDe=0P1KFe/204I6AP80Fe]K0P1^KVh206UYJ@80HF5Q
0P1MGEd205UIF@80E5AD0P16ATH203Ph>00303`l?01IFET0FEUI0080=CDe0P21PH420;6a/@80;2`/
0P0L71`203<c<`80D51@0P0X:2P205EEE@80?Shn0P0/;2`203Hf=P80B4Q80P1=CDd00`1EEED0EeMG
05MGE`02059BDP80CDe=0P1?Cdl20492@P80>SXj0P0g=cL202PX:08092@T0P0G5aL200H61P804A4A
0P0`<30203<c<`808B4Q00<0=SHf04U9B@19BDT00P11@D4202d];@80>c/k0P0h>3P206e]K@806ATI
0P1FEUH206e]K@80EeMG0P2?Shl207moOaD0MWIf0P1`L70207AdM080MWIf0P1hN7P407AdM1<0MWIf
5@3oool001<0oooo0P1kNg/207UiN@H0MWIf0P1hN7P207UiN@80N7Qh00<0NGUi07IfMP1fMWH00P1f
MWH2071`L080M7Ad1P1fMWH202h^;P80DE5A0P10@40203Hf=P806ATI0P0Y:BT203Hf=P806a/K00<0
51@D07=cL`1cLg<00P1IFET205MGE`80I6AT0P1cLg<206i^KP80IfMW0P1HF5P204Q8B080:RXZ0P0g
=cL207YjNP80UIFE0P0Y:BT2020P800302HV9P0e=CD0=CDe0080=3@d0P19BDT204e=C@80Fe]K0P16
ATH205]KF`80KVi^0P1YJFT2065QH@80GEeM0P1IFET205ADE080ATI60P0h>3P00`0l?3`0FEUI05UI
F@0203De=@80PH610P2a/K4202`/;08071`L0P0c<c<2051@D080:2PX0P1EEED203hn?P80;2`/0P0f
=SH204Q8B080CDe=00<0EEEE05MGE`1GEeL00P1BDU8204e=C@80Cdm?0P12@T8203Xj>P80=cLg0P0X
:2P202@T90805aLG0P061PH2014A4@80<30`0P0c<c<2024Q8@0303Hf=P19BDT0BDU90080@D510P0]
;Bd203/k>`80>3Ph0P1]KFd201TI6@80EUIF0P1]KFd205MGE`80Shn?0P1oOglE07IfMP80L71`0P1d
M7@207IfMP80N7Qh101dM7@C07IfMQD0oooo000C0?oooa00MWIf00<0L71`07AdM01dM7@00P1fMWH2
07QhN080NGUi101fMWH207moO`80W9bL0P1BDU8201`L70807AdM0P0F5QH2034a<@80:b/[0P0_;bl0
0`15ADD0WYjN09jNWP0204a<C080A4A40P1CDe<206EUI@80H61P0P1KFe/204];B`80=CDe0P0V9RH2
00h>3P80;Bd]0P11@D4202/[:`80OGem00<02PX:02l_;`0_;bl00P0I6AT202DU9@80<c<c0P10@402
05IFEP80LG5a0P1_Kfl206UYJ@80IVIV0P1RHV8205iNGP80HF5Q0P1;Bd/204M7A`0303@d=00m?Cd0
?Cdm0080EEEE0P0f=SH203Lg=`804a<C0P1dM7@200T92@808R8R0P0Q8B4205UIF@8030`<0P0I6AT2
03/k>`80?clo0P0l?3`00`1<C4`0CTi>04i>CP02051@D0@0A4A40P11@D4203`l?080;2`/0P0X:2P2
02XZ:P804A4A0P0>3Ph401DE5@@09BDU00<0B4Q803Xj>P0j>SX00P0f=SH203hn?P80B4Q80P0g=cL2
06=SH`807alO0P1ADE4204i>CP80JFUY0P2BTY8G07IfMP80N7Qh0P1iNGT407IfMP80N7Qh0P1iNGTC
07IfMQD0oooo000C0?oooa00MWIf00<0L71`07AdM01dM7@00P1fMWH207QhN080NGUi101fMWH207mo
O`80W9bL0P1BDU8201`L70807AdM0P0F5QH2034a<@80:b/[0P0_;bl00`15ADD0WYjN09jNWP0204a<
C080A4A40P1CDe<206EUI@80H61P0P1KFe/204];B`80=CDe0P0V9RH200h>3P80;Bd]0P11@D4202/[
:`80OGem00<02PX:02l_;`0_;bl00P0I6AT202DU9@80<c<c0P10@40205IFEP80LG5a0P1_Kfl206UY
J@80IVIV0P1RHV8205iNGP80HF5Q0P1;Bd/204M7A`0303@d=00m?Cd0?Cdm0080EEEE0P0f=SH203Lg
=`804a<C0P1dM7@200T92@808R8R0P0Q8B4205UIF@8030`<0P0I6AT203/k>`80?clo0P0l?3`00`1<
C4`0CTi>04i>CP02051@D0@0A4A40P11@D4203`l?080;2`/0P0X:2P202XZ:P804A4A0P0>3Ph401DE
5@@09BDU00<0B4Q803Xj>P0j>SX00P0f=SH203hn?P80B4Q80P0g=cL206=SH`807alO0P1ADE4204i>
CP80JFUY0P2BTY8G07IfMP80N7Qh0P1iNGT407IfMP80N7Qh0P1iNGTC07IfMQD0oooo000C0?oooa00
MWIf00<0N7Qh07UiN@1iNGT02P1fMWH2020P80809RHV0P0/;2`203hn?P80<C4a0P0/;2`203@d=080
;Bd]0P0e=CD00`1EEED0NGUi07UiN@0203hn?P80CDe=0P1MGEd206YZJP80J6QX0P1CDe<204I6AP80
?3`l0P0J6QX2034a<@80=cLg0P0820P2000000801@D500<06a/K04i>CP1>CTh00P0e=CD2051@D080
F5QH0P1`L70207IfMP80L71`101WIfL206EUI@80HF5Q0P1OGel205aLG080F5QH0P1BDU800`1?Cdl0
?clo03lo?`0202/[:`80@T920P15ADD200`<308020P80P0;2`/2024Q8@807AdM0P0E5AD201hN7P80
=cLg0P16ATH204A4A080?clo00<0ATI604U9B@19BDT00P1<C4`204I6AP80?clo0P0h>3P202HV9P80
:BTY0P0a<C4202LW9`808R8R0P0F5QH202DU9@80:2PX0P0Q8B4202<S8`0303/k>`0l?3`0?3`l0080
=SHf0P0/;2`203dm?@80?Shn0P1WIfL202l_;`80F5QH0P1DE5@208^;R`80SXj>9`1fMWH00`1`L700
M7Ad07AdM00<07IfMQD0oooo000C0?oooa00MWIf00<0N7Qh07UiN@1iNGT02P1fMWH2020P80809RHV
0P0/;2`203hn?P80<C4a0P0/;2`203@d=080;Bd]0P0e=CD00`1EEED0NGUi07UiN@0203hn?P80CDe=
0P1MGEd206YZJP80J6QX0P1CDe<204I6AP80?3`l0P0J6QX2034a<@80=cLg0P0820P2000000801@D5
00<06a/K04i>CP1>CTh00P0e=CD2051@D080F5QH0P1`L70207IfMP80L71`101WIfL206EUI@80HF5Q
0P1OGel205aLG080F5QH0P1BDU800`1?Cdl0?clo03lo?`0202/[:`80@T920P15ADD200`<308020P8
0P0;2`/2024Q8@807AdM0P0E5AD201hN7P80=cLg0P16ATH204A4A080?clo00<0ATI604U9B@19BDT0
0P1<C4`204I6AP80?clo0P0h>3P202HV9P80:BTY0P0a<C4202LW9`808R8R0P0F5QH202DU9@80:2PX
0P0Q8B4202<S8`0303/k>`0l?3`0?3`l0080=SHf0P0/;2`203dm?@80?Shn0P1WIfL202l_;`80F5QH
0P1DE5@208^;R`80SXj>9`1fMWH00`1`L700M7Ad07AdM00<07IfMQD0oooo000C0?ooo`P0MWIf0P1`
L70207AdM0@0MWIf00<0L71`07AdM01dM7@02P1fMWH202HV9P80?clo0P10@40202/[:`80820P0P0h
>3P2038b<P809BDU0P0W9bL00`1=CDd0GemO05mOG`0204U9B@80De=C0P1KFe/206UYJ@80GemO0P1Q
HF4406a/K080JFUY0P1FEUH203Lg=`80;Rh^0P0h>3P203`l?00303@d=010@400@4100080FEUI0P1j
NWX208>3P`80PX:20P1aLG4606e]K@80IFEU0P1QHF4206EUI@80Jf][0P1TI6@305mOG`80FEUI0P1C
De<202d];@80<C4a0P1?Cdl206UYJ@80Cdm?0P0_;bl202<S8`80:2PX0P1:BTX206IVIP80Hf=S0P1?
Cdl205IFEP0305eMG@1EEED0EEEE0080ATI60P19BDT204Q8B080>CTi0P0/;2`2030`<080:b/[0P0/
;2`202LW9`806ATI0P0R8R8201/K6`806ATI0P0T92@00`11@D40AdM704M7A`0203dm?@80=CDe0P15
ADD204m?C`80J6QX0P0a<C42055AD@80Fe]K0P2:RXX207alO2L0MWIf00<0N7Qh07UiN@1iNGT0301f
MWHE0?ooo`004`3oool807IfMP80L71`0P1dM7@407IfMP03071`L01dM7@0M7Ad00X0MWIf0P0V9RH2
03lo?`80@4100P0[:b/2020P8080>3Ph0P0b<S8202DU9@809bLW00<0CDe=05mOG`1OGel00P19BDT2
05=CD`80Fe]K0P1YJFT205mOG`80HF5Q101/K6`206UYJ@80EUIF0P0g=cL202h^;P80>3Ph0P0l?3`0
0`0d=3@0@4100410@00205UIF@80NWYj0P23Ph<208:2PP80LG5a1P1]KFd206EUI@80HF5Q0P1UIFD2
06][J`80I6AT0`1OGel205UIF@80De=C0P0];Bd2034a<@80Cdm?0P1YJFT204m?C`80;bl_0P0S8b<2
02PX:080BTY:0P1VIVH206=SH`80Cdm?0P1FEUH00`1MGEd0EEEE05EEE@0204I6AP80BDU90P18B4P2
03Ti>@80;2`/0P0`<30202/[:`80;2`/0P0W9bL201TI6@808R8R0P0K6a/201TI6@8092@T00<0@D51
04M7A`17AdL00P0m?Cd203De=@80ADE50P1?Cdl206QXJ080<C4a0P1ADE4205]KF`80RXZ:0P1lO7`W
07IfMP0307QhN01iNGT0NGUi00`0MWIf5@3oool001<0oooo201fMWH207QhN080NGUi101fMWH00`1h
N7P0NGUi07UiN@0407IfMP80L71`0P1dM7@207IfMP80TY:B0P1LG5`202@T90805aLG0P0P820202<S
8`80820P0P0L71`203lo?`0305MGE`19BDT0BDU900@0ADE50P1@D50206ATI080J6QX0P1]KFd207Qh
N080O7al0P23Ph<209bLW080YjNW102[Zj/20;6a/@030;Zj^P2ZZZX0ZZZZ0080M7Ad0P1RHV8205]K
F`80I6AT0P1bLW8206i^KP80JFUY0P1WIfL206][J`80K6a/0P1[Jf/206EUI@80FEUI0P19BDT00`1?
Cdl0BDU904U9B@02065QH@80NGUi0P23Ph<205mOG`80FEUI0P1TI6@207UiN@80U9BD0P2PX:02092@
T080Ogmo0P1gMgL207IfMP80JFUY00<0GEeM05=CD`1CDe<00P1<C4`404=3@`80@D510P0a<C4203De
=@80;Bd]0P0L71`201/K6`805QHF0P0P820202d];@80;2`/0P0S8b<00`0k>c/0CTi>04i>CP0203Lg
=`80<S8b0P1?Cdl205=CD`80Hf=S0P0d=3@205IFEP80U9BD0P2][Jd207moOc80MWIf0P1`L70207Ad
M1D0oooo000C0?ooo`P0MWIf0P1hN7P207UiN@@0MWIf00<0N7Qh07UiN@1iNGT0101fMWH2071`L080
M7Ad0P1fMWH209:BTP80G5aL0P0T92@201LG5`80820P0P0S8b<2020P808071`L0P0o?cl00`1GEeL0
BDU904U9B@0404E5A@80D51@0P1TI6@206QXJ080KFe]0P1hN7P207alO080Ph>30P2LW9`20:NWY`@0
Zj^[0P2a/K400`2j^[X0ZZZZ0:ZZZP0207AdM080HV9R0P1KFe/206ATI080LW9b0P1^KVh206UYJ@80
IfMW0P1[Jf/206a/K080Jf][0P1UIFD205UIF@80BDU900<0Cdm?04U9B@19BDT00P1QHF4207UiN@80
Ph>30P1OGel205UIF@80I6AT0P1iNGT209BDU080X:2P0P2@T90207moO`80MgMg0P1fMWH206UYJ@03
05eMG@1CDe<0De=C0080C4a<1013@d<20451@@80<C4a0P0e=CD202d];@8071`L0P0K6a/201HF5P80
820P0P0];Bd202`/;0808b<S00<0>c/k04i>CP1>CTh00P0g=cL2038b<P80Cdm?0P1CDe<206=SH`80
=3@d0P1FEUH209BDU080[Jf]0P1oOglb07IfMP80L71`0P1dM7@E0?ooo`004`3oool407IfMP80L71`
0P1dM7@207IfMP80L71`0P1dM7@707IfMP80L71`0P1fMWH207UiN@80Ogmo0P29RHT2014A4@807QhN
0P0D51@201`L70807AdM0P0j>SX201`L7080:b/[00<0=3@d04I6AP16ATH00P1:BTX20451@@80EEEE
0P1aLG4205]KF`80Hf=S101/K6`2075aL@80MWIf0P1iNGT20820P080Fe]K0P0d=3@00`0N7Qh05ADE
01DE5@0201/K6`80FEUI0P1eMGD207inOP80LW9b0P1[Jf/207EeM@80K6a/101ZJVX206UYJ@80LW9b
0P1UIFD2061PH0030492@P0T92@092@T00808b<S0P0P8202030`<080JFUY0P2;Rh/2092@T080SHf=
0P1oOgl207IfMP80KFe]0P1XJ6P206=SH`80FUYJ0P1BDU800`13@d<0=3@d03@d=00204A4A080ATI6
0P0l?3`203De=@80=SHf0P0a<C4202TY:@80<30`0P0J6QX201HF5P805aLG0P0K6a/2010@40809RHV
00<0=3@d03Lg=`0g=cL00P0`<30203<c<`80DE5A0P1?Cdl206a/K080>c/k0P1LG5`208^;R`80O7al
0P1`L70b07IfMP80N7Qh0P1iNGTE0?ooo`004`3oool407IfMP80N7Qh0P1iNGT207IfMP80N7Qh0P1i
NGT707IfMP80N7Qh0P1iNGT207IfMP80Hf=S0P1aLG42014A4@809BDU0P0G5aL2028R8P80:b/[0P0_
;bl202HV9P80@d=300<0?Shn03dm?@0m?Cd00P0o?cl20492@P80Cdm?0P1UIFD205iNGP80FUYJ0P1G
EeL206EUI@@0J6QX0P1NGUh202<S8`805aLG0P0R8R800`0b<S80JVYZ06YZJP020:>SX`80XJ6Q0P1g
MgL2071`L080LG5a0P1/K6`206i^KP80IfMW101ZJVX206a/K080IfMW0P1YJFT2071`L00306][J`1I
FET0FEUI0080<S8b100R8R82024Q8@80=3@d0P18B4P205]KF`80IVIV0P1[Jf/2061PH080Hf=S0P1F
EUH204i>CP80@41000<0;Rh^04];B`1;Bd/00P1:BTX203hn?P80=cLg0P0b<S8203De=@80;bl_0P0K
6a/201TI6@804a<C0P0M7Ad201TI6@8051@D0P0a<C420410@0030492@P17AdL0AdM70080?3`l0P0_
;bl204a<C080A4A40P1DE5@204I6AP80GEeM0P2CTi<207moOcP0MWIf5@3oool001<0oooo101fMWH2
07QhN080NGUi0P1fMWH207QhN080NGUi1`1fMWH207QhN080NGUi0P1fMWH206=SH`80LG5a0P0A4A42
02DU9@805aLG0P0R8R8202/[:`80;bl_0P0V9RH204=3@`0303hn?P0m?Cd0?Cdm0080?clo0P12@T82
04m?C`80IFEU0P1NGUh205YJFP80EeMG0P1UIFD406QXJ080GUiN0P0S8b<201LG5`808R8R00<0<S8b
06YZJP1ZJVX00P2SXj<20:6QX@80MgMg0P1`L702075aL@80K6a/0P1^KVh206MWI`@0JVYZ0P1/K6`2
06MWI`80JFUY0P1`L7000`1[Jf/0FEUI05UIF@02038b<P@08R8R0P0Q8B4203@d=080B4Q80P1KFe/2
06IVIP80Jf][0P1PH60206=SH`80EUIF0P1>CTh20410@00302h^;P1;Bd/0Bd];0080BTY:0P0n?Sh2
03Lg=`80<S8b0P0e=CD202l_;`806a/K0P0I6AT201<C4`807AdM0P0I6AT201@D5080<C4a0P10@400
0`12@T80AdM704M7A`0203`l?080;bl_0P1<C4`204A4A080E5AD0P16ATH205eMG@80Ti>C0P1oOglh
07IfMQD0oooo000C0?oooaD0MWIf0P1`L70207AdM080Ogmo0P0h>3P206UYJ@807QhN0P0X:2P202XZ
:P80;bl_0P0J6QX202XZ:P80:2PX0P0b<S800`0];Bd0:2PX02PX:00203@d=080?Shn0P1ADE4406][
J`80>c/k0P0c<c<203@d=080;2`/0P0S8b<2010@408071`L0P1LG5`20:VYZ@030<O7a`2d];@0];Bd
0080Ti>C0P1oOgl207UiN@80MgMg0P1aLG4206m_K`80J6QX0P1TI6@206QXJ080IfMW0P1YJFT206YZ
JP80J6QX0P1ZJVX00`1fMWH0RXZ:08Z:RP0209FEU@80Ti>C0P1`L70204E5A@80820P0P0G5aL2014A
4@804Q8B0P0M7Ad402<S8`807QhN0P0Q8B42034a<@0304i>CP1EEED0EEEE00@0Bd];0P0l?3`203Lg
=`80>3Ph0P0Y:BT20492@P8051@D0P0V9RH202d];@809RHV0P0J6QX201@D5080;Rh^00<0?3`l03lo
?`0o?cl00P0d=3@203<c<`80DU9B0P1IFET203lo?`808b<S0P1cLg<209nOWal0MWIf0P1`L70207Ad
M1L0MWIf5@3oool001<0oooo5@1fMWH2071`L080M7Ad0P1oOgl203Ph>080JFUY0P0N7Qh202PX:080
:RXZ0P0_;bl201XJ6P80:RXZ0P0X:2P2038b<P0302d];@0X:2P0:2PX0080=3@d0P0n?Sh2055AD@@0
Jf][0P0k>c/203<c<`80=3@d0P0/;2`202<S8`80410@0P0L71`205aLG080ZJVY00<0alO70;Bd]02d
];@00P2CTi<207moO`80NGUi0P1gMgL2075aL@80Kfm_0P1XJ6P206ATI080J6QX0P1WIfL206UYJ@80
JVYZ0P1XJ6P206YZJP0307IfMP2:RXX0RXZ:0080UIFE0P2CTi<2071`L080ADE50P0P820201LG5`80
4A4A0P0B4Q8201dM7@@08b<S0P0N7Qh2024Q8@80<C4a00<0CTi>05EEE@1EEED0101;Bd/203`l?080
=cLg0P0h>3P202TY:@80@T920P0D51@202HV9P80;Bd]0P0V9RH201XJ6P8051@D0P0^;Rh00`0l?3`0
?clo03lo?`0203@d=080<c<c0P1BDU8205UIF@80?clo0P0S8b<207=cL`80WinO7`1fMWH2071`L080
M7Ad5`1fMWHE0?ooo`004`3ooolE07IfMP80LW9b0P1gMgL207=cL`80?Shn0P0H61P200@410809RHV
0P0k>c/203<c<`@0;2`/0P0U9BD202`/;00302l_;`0d=3@0=3@d0080?3`l0P0j>SX205YJFP80Kfm_
0P1WIfL207QhN080T92@0P1RHV8204Y:BP80AdM70P1aLG420;Jf]P80_[jn0P2FUYH00`1gMgL0Lg=c
07=cL`02075aL@P0KFe]0P1^KVh206MWI`80JFUY0P1bLW8207EeM@80M7Ad101/K6`206e]K@0306i^
KP1ZJVX0JVYZ0080Jf][0P1gMgL208V9R@80XJ6Q0P2d];@20;Rh^080NWYj0P1<C4`203Ph>080=CDe
0P0g=cL2055AD@80IFEU0P1LG5`00`1DE5@0EeMG05MGE`02055AD@80AdM70P0j>SX203/k>`80@T92
0P0/;2`201TI6@808b<S0P0W9bL201PH60@02`/;0P0A4A4203/k>`0303hn?P0[:b/0:b/[0080?Cdm
0P0l?3`205UIF@80E5AD0P0[:b/204U9B@80XZ:R0P2;Rh/O07IfMP80N7Qh0P1iNGT2071`L080M7Ad
4`1fMWHE0?ooo`004`3ooolE07IfMP80LW9b0P1gMgL207=cL`80?Shn0P0H61P200@410809RHV0P0k
>c/203<c<`@0;2`/0P0U9BD202`/;00302l_;`0d=3@0=3@d0080?3`l0P0j>SX205YJFP80Kfm_0P1W
IfL207QhN080T92@0P1RHV8204Y:BP80AdM70P1aLG420;Jf]P80_[jn0P2FUYH00`1gMgL0Lg=c07=c
L`02075aL@P0KFe]0P1^KVh206MWI`80JFUY0P1bLW8207EeM@80M7Ad101/K6`206e]K@0306i^KP1Z
JVX0JVYZ0080Jf][0P1gMgL208V9R@80XJ6Q0P2d];@20;Rh^080NWYj0P1<C4`203Ph>080=CDe0P0g
=cL2055AD@80IFEU0P1LG5`00`1DE5@0EeMG05MGE`02055AD@80AdM70P0j>SX203/k>`80@T920P0/
;2`201TI6@808b<S0P0W9bL201PH60@02`/;0P0A4A4203/k>`0303hn?P0[:b/0:b/[0080?Cdm0P0l
?3`205UIF@80E5AD0P0[:b/204U9B@80XZ:R0P2;Rh/O07IfMP80N7Qh0P1iNGT2071`L080M7Ad4`1f
MWHE0?ooo`004`3oool807IfMP80L71`0P1dM7@407IfMP03071`L01dM7@0M7Ad0080MWIf0P1hN7P2
07UiN@80MWIf0P1PH60203De=@80;2`/0P0Y:BT204];B`80@4100P0d=3@2038b<P80:BTY0P0d=3@0
0`0c<c<0=3@d03@d=0020451@@80?Shn0P1FEUH206UYJ@80Hf=S0P1TI6@206QXJ080Ogmo0P2JVYX2
0::RXP80Vi^K0P1nOWh206m_K`/0KFe]0P1^KVh206e]K@80K6a/0P1VIVH4079bLP80KFe]0P1TI6@2
06=SH`80IfMW0`1XJ6P206][J`80J6QX0P1YJFT206i^KP80IVIV0P1TI6@206EUI@80JFUY0P2>SXh2
0:FUY@80UYJF0P25QHD207YjNP80Hf=S0P1HF5P00`1PH600Bd];04];B`0203hn?P80>3Ph0P0g=cL2
0451@@80@4100P0k>c/202`/;0808B4Q0P0A4A4200/;2`803@d=0P0?3`l201@D5080I6AT00<0>3Ph
02`/;00/;2`00P1XJ6P203dm?@80?clo0P1IFET203@d=080GEeM0P2NWYh207moOb<0MWIf0P1hN7P2
07UiNA<0MWIf5@3oool001<0oooo201fMWH2071`L080M7Ad101fMWH00`1`L700M7Ad07AdM00207If
MP80N7Qh0P1iNGT207IfMP80H61P0P0e=CD202`/;080:BTY0P1;Bd/20410@080=3@d0P0b<S8202TY
:@80=3@d00<0<c<c03@d=00d=3@00P11@D4203hn?P80EUIF0P1YJFT206=SH`80I6AT0P1XJ6P207mo
O`80VYZJ0P2RXZ8209^KV`80OWin0P1_Kfl;06e]K@80KVi^0P1]KFd206a/K080IVIV101bLW8206e]
K@80I6AT0P1SHf<206MWI`<0J6QX0P1[Jf/206QXJ080JFUY0P1^KVh206IVIP80I6AT0P1UIFD206UY
J@80SXj>0P2UYJD209JFUP80QHF50P1jNWX206=SH`80F5QH00<0H61P04];B`1;Bd/00P0n?Sh203Ph
>080=cLg0P11@D420410@080>c/k0P0/;2`2024Q8@804A4A0P0;2`/200d=3@803`l?0P0D51@206AT
I00303Ph>00/;2`0;2`/0080J6QX0P0m?Cd203lo?`80FEUI0P0d=3@205eMG@80WYjN0P1oOglS07If
MP80N7Qh0P1iNGTC07IfMQD0oooo000C0?ooo`@0MWIf0P1`L70207AdM080N7Qh0P1iNGT207IfMP80
L71`00<0MWIf07UiN@1iNGT0201fMWH204M7A`805aLG0P0R8R82034a<@80EUIF0P0h>3P202XZ:P80
<30`0P0b<S8203<c<`0302h^;P0_;bl0;bl_0080@T920P0j>SX205QHF080JVYZ101XJ6P206MWI`80
K6a/0P1YJFT206QXJ080LW9b0P1eMGD206UYJ@80Hf=S00<0JVYZ06e]K@1]KFd00P1]KFd206EUI@80
JVYZ101/K6`206e]K@80J6QX0P1VIVH206YZJP@0I6AT0P1bLW8206a/K080JVYZ00<0Jf][06YZJP1Z
JVX00P1/K6`206IVIP80IfMW0P1RHV8206=SH`80H61P0P1LG5`206IVIPH0EUIF101@D50304m?C`80
ATI60P1>CTh204e=C@80?Cdm100l?3`202/[:`80?3`l0P0Z:RX201PH60806QXJ0P0F5QH2024Q8@80
61PH0P1TI6@00`13@d<0=3@d03@d=002059BDP@0=cLg0P1KFe/202l_;`80N7Qh0P2TY:@207UiNCX0
MWIf5@3oool001<0oooo101fMWH2071`L080M7Ad0P1hN7P207UiN@80MWIf0P1`L7000`1fMWH0NGUi
07UiN@0807IfMP80AdM70P0G5aL2028R8P80<C4a0P1FEUH203Ph>080:RXZ0P0`<302038b<P80<c<c
00<0;Rh^02l_;`0_;bl00P12@T8203Xj>P80F5QH0P1ZJVX406QXJ080IfMW0P1/K6`206UYJ@80J6QX
0P1bLW8207EeM@80JFUY0P1SHf<00`1ZJVX0KFe]06e]K@0206e]K@80IFEU0P1ZJVX406a/K080KFe]
0P1XJ6P206IVIP80JVYZ101TI6@2079bLP80K6a/0P1ZJVX00`1[Jf/0JVYZ06YZJP0206a/K080IVIV
0P1WIfL2069RHP80Hf=S0P1PH60205aLG080IVIV1P1FEUH4051@D0<0Cdm?0P16ATH204i>CP80CDe=
0P0m?Cd403`l?080:b/[0P0l?3`202XZ:P8061PH0P0J6QX201HF5P808B4Q0P0H61P206ATI00304=3
@`0d=3@0=3@d0080DU9B100g=cL205]KF`80;bl_0P1hN7P20:BTY080NGUi>P1fMWHE0?ooo`004`3o
ool407IfMP80N7Qh0P1iNGT607IfMP80N7Qh00<0NGUi07IfMP1fMWH0201fMWH206=SH`809bLW0P0o
?cl403`l?080:RXZ0P0h>3P203Xj>P80<C4a0P0/;2`00`0Z:RX0:BTY02TY:@0203Hf=P80=cLg0P16
ATH205aLG080H61P0P1TI6@206EUI@80Hf=S0P1WIfL206YZJP80IVIV0P1ZJVX2071`L080KFe]00<0
KVi^06e]K@1]KFd00P1]KFd206m_K`80LG5a1P1]KFd206m_K`80M7Ad0P1bLW82071`L080MGEe0P1Y
JFT206ATI080J6QX00<0Hf=S065QH@1QHF400P1QHF4206EUI@80JVYZ0P1QHF42069RHP80HF5Q0P1V
IVH205mOG`80Fe]K0P1MGEd205IFEP80FUYJ0P1GEeL205IFEP<0De=C0P1ADE4203/k>`80>3Ph0P15
ADD203/k>`80>CTi0P0S8b<201<C4`80820P0P0O7al200l?3`803@d=0P0A4A42061PH00303`l?00i
>CT0>CTi0080IFEU0P0l?3`2030`<080BTY:0P0[:b/20:ZZZP80UIFE0P1`L70j07IfMQD0oooo000C
0?ooo`@0MWIf0P1hN7P207UiN@H0MWIf0P1hN7P00`1iNGT0MWIf07IfMP0807IfMP80Hf=S0P0W9bL2
03lo?`@0?3`l0P0Z:RX203Ph>080>SXj0P0a<C4202`/;00302XZ:P0Y:BT0:BTY0080=SHf0P0g=cL2
04I6AP80G5aL0P1PH60206ATI080IFEU0P1SHf<206MWI`80JVYZ0P1VIVH206YZJP80L71`0P1]KFd0
0`1^KVh0KFe]06e]K@0206e]K@80Kfm_0P1aLG4606e]K@80Kfm_0P1dM7@2079bLP80L71`0P1eMGD2
06UYJ@80I6AT0P1XJ6P00`1SHf<0HF5Q065QH@02065QH@80IFEU0P1ZJVX2065QH@80HV9R0P1QHF42
06IVIP80GemO0P1KFe/205eMG@80EUIF0P1JFUX205MGE`80EUIF0`1CDe<2055AD@80>c/k0P0h>3P2
04E5A@80>c/k0P0i>CT202<S8`804a<C0P0P820201lO7`803`l?0P0=3@d2014A4@80H61P00<0?3`l
03Ti>@0i>CT00P1UIFD203`l?080<30`0P1:BTX202/[:`80ZZZZ0P2EUID2071`L3X0MWIf5@3oool0
01<0oooo2P1fMWH2071`L080M7Ad3@1fMWH207moO`80;bl_0P0/;2`202DU9@8092@T0P0[:b/2038b
<P809bLW100/;2`00`0a<C40;Rh^02h^;P0204Q8B080BTY:0P1HF5P206QXJ080Fe]K0P1SHf<206IV
IP80J6QX0P1/K6`206UYJ@80J6QX0P1VIVH206YZJP80Kfm_00<0LG5a06e]K@1]KFd00P1]KFd206EU
I@80Hf=S0P1ZJVX806e]K@80I6AT101QHF4206ATI080JFUY0P1OGel00`1SHf<0IfMW06MWI`0206MW
I`80Hf=S0P1MGEd205iNGP80Hf=S101HF5P205UIF@80GemO0P1LG5`205IFEP80F5QH0P1EEED205AD
E00304A4A016ATH0ATI60080?clo1016ATH203dm?@80<c<c0P0U9BD2024Q8@807QhN0P0X:2P2018B
4P803@d=0P0?3`l2020P8080@d=300<0De=C05ADE01DE5@00P1RHV8203dm?@80?Shn0P0_;bl205mO
G`80][Jf0P1iNGTS07IfMP80L71`0P1dM7@E07IfMQD0oooo000C0?ooo`X0MWIf0P1`L70207AdM0d0
MWIf0P1oOgl202l_;`80;2`/0P0U9BD202@T9080:b/[0P0b<S8202LW9`@0;2`/00<0<C4a02h^;P0^
;Rh00P18B4P204Y:BP80F5QH0P1XJ6P205]KF`80Hf=S0P1VIVH206QXJ080K6a/0P1YJFT206QXJ080
IVIV0P1ZJVX206m_K`03075aL@1]KFd0KFe]0080KFe]0P1UIFD206=SH`80JVYZ201]KFd206ATI0@0
HF5Q0P1TI6@206UYJ@80GemO00<0Hf=S06MWI`1WIfL00P1WIfL206=SH`80GEeM0P1NGUh206=SH`@0
F5QH0P1IFET205mOG`80G5aL0P1FEUH205QHF080EEEE0P1DE5@00`14A4@0ATI604I6AP0203lo?`@0
ATI60P0m?Cd203<c<`809BDU0P0Q8B4201hN7P80:2PX0P0B4Q8200d=3@803`l?0P0P820204=3@`03
05=CD`1DE5@0E5AD0080HV9R0P0m?Cd203hn?P80;bl_0P1OGel20;Jf]P80NGUi8`1fMWH2071`L080
M7Ad5@1fMWHE0?ooo`004`3oool:07IfMP80N7Qh0P1iNGT=07IfMP80PH610P0K6a/203Ph>080<30`
0P0h>3P203dm?@80?3`l0P0g=cL2038b<P80<30`00<0;Bd]03Hf=P0f=SH00P10@40204a<C080DU9B
0P1JFUX205eMG@80JVYZ0P1WIfL406e]K@80JFUY0P1ZJVX4079bLP80IFEU00<0Hf=S06YZJP1ZJVX0
0P1]KFd206QXJ0@0LG5a0P1TI6@206YZJP@0KFe]0P1WIfL406UYJ@80JVYZ0P1[Jf/206i^KP03079b
LP1YJFT0JFUY0080IfMW0P1TI6@2069RHP@0Hf=S0P1KFe/205YJFP@0F5QH1P1IFET2059BDP<0De=C
0P1@D50204E5A@80@T920P13@d<20451@@80=cLg0P0`<30201hN7P80:2PX0P0C4a<2010@408051@D
0P0@410201HF5P80@41000<0CTi>02h^;P0^;Rh00P16ATH204E5A@80BDU90P0e=CD208Z:RP80UYJF
9@1fMWH207QhN080NGUi5@1fMWHE0?ooo`004`3oool:07IfMP80N7Qh0P1iNGT=07IfMP80PH610P0K
6a/203Ph>080<30`0P0h>3P203dm?@80?3`l0P0g=cL2038b<P80<30`00<0;Bd]03Hf=P0f=SH00P10
@40204a<C080DU9B0P1JFUX205eMG@80JVYZ0P1WIfL406e]K@80JFUY0P1ZJVX4079bLP80IFEU00<0
Hf=S06YZJP1ZJVX00P1]KFd206QXJ0@0LG5a0P1TI6@206YZJP@0KFe]0P1WIfL406UYJ@80JVYZ0P1[
Jf/206i^KP03079bLP1YJFT0JFUY0080IfMW0P1TI6@2069RHP@0Hf=S0P1KFe/205YJFP@0F5QH1P1I
FET2059BDP<0De=C0P1@D50204E5A@80@T920P13@d<20451@@80=cLg0P0`<30201hN7P80:2PX0P0C
4a<2010@408051@D0P0@410201HF5P80@41000<0CTi>02h^;P0^;Rh00P16ATH204E5A@80BDU90P0e
=CD208Z:RP80UYJF9@1fMWH207QhN080NGUi5@1fMWHE0?ooo`004`3ooolK07IfMP80O7al0P0c<c<2
02d];@80;2`/0P0m?Cd203Xj>P80:b/[0P0`<30202XZ:P80;2`/00<0?Cdm03Ti>@0i>CT00P0m?Cd2
04I6AP80C4a<0P1GEeL2061PH080Hf=S101VIVH2065QH@80IfMW0P1YJFT206MWI`80JVYZ0P1_Kfl0
0`1ZJVX0IfMW06MWI`0206YZJP80Kfm_0P1XJ6P206=SH`80KFe]0P1ZJVX2069RHP80HF5Q0P1UIFD2
06UYJ@@0JVYZ0P1YJFT206=SH`0306MWI`1UIFD0IFEU0080IfMW0P1OGel206UYJ@80IVIV0P1RHV82
06IVIP80IFEU0P1SHf<206ATI080GEeM0P1EEED205IFEP80De=C0P1DE5@00`14A4@0B4Q804Q8B002
04E5A@80@d=30P14A4@2038b<P80<c<c0P0_;bl202PX:0808B4Q0P0B4Q8200h>3P@02@T90P0h>3P2
0451@@0303Ph>00e=CD0=CDe0080Fe]K0P1?Cdl206a/K080IVIV0P2o_kl208j>SSh0MWIf5@3oool0
01<0oooo6`1fMWH207alO080<c<c0P0];Bd202`/;080?Cdm0P0j>SX202/[:`80<30`0P0Z:RX202`/
;00303dm?@0i>CT0>CTi0080?Cdm0P16ATH204a<C080EeMG0P1PH60206=SH`@0IVIV0P1QHF4206MW
I`80JFUY0P1WIfL206YZJP80Kfm_00<0JVYZ06MWI`1WIfL00P1ZJVX206m_K`80J6QX0P1SHf<206e]
K@80JVYZ0P1RHV82065QH@80IFEU0P1YJFT406YZJP80JFUY0P1SHf<00`1WIfL0IFEU06EUI@0206MW
I`80GemO0P1YJFT206IVIP80HV9R0P1VIVH206EUI@80Hf=S0P1TI6@205eMG@80EEEE0P1FEUH205=C
D`80E5AD00<0A4A404Q8B018B4P00P15ADD204=3@`80A4A40P0b<S8203<c<`80;bl_0P0X:2P2024Q
8@804Q8B0P0>3Ph400T92@80>3Ph0P11@D400`0h>3P0=CDe03De=@0205]KF`80Cdm?0P1/K6`206IV
IP80_kno0P2>SXhn07IfMQD0oooo000C0?oooa/0MWIf0P1lO7`201DE5@80@D510P1EEED203<c<`80
;bl_100a<C4202h^;P80>c/k00<0820P02`/;00/;2`00P15ADD2051@D080B4Q80P1EEED206=SH`80
IFEU101VIVH406e]K@80JFUY101aLG4206ATI00306e]K@1dM7@0M7Ad0080LG5a0P1UIFD406e]K@80
IVIV101/K6`206UYJ@80J6QX101YJFT206MWI`80JFUY0P1[Jf/00`1]KFd0Jf][06][J`02061PH080
HV9R0P1VIVH2061PH080Hf=S0P1GEeL2065QH@80G5aL0P1HF5P2055AD@80E5AD0P1HF5P205=CD`80
E5AD00<0B4Q805EEE@1EEED00P17AdL204A4A080=3@d0P0`<30202XZ:P807alO0P0[:b/201XJ6P80
3@d=0P092@T201PH60802`/;100o?cl00`0h>3P0;2`/02`/;00204Y:BP80B4Q80P1<C4`208R8R080
ZZZZ@01fMWHE0?ooo`004`3ooolK07IfMP80O7al0P0E5AD20451@@80EEEE0P0c<c<202l_;`@0<C4a
0P0^;Rh203/k>`03020P800/;2`0;2`/0080ADE50P1@D50204Q8B080EEEE0P1SHf<206EUI@@0IVIV
101]KFd206UYJ@@0LG5a0P1TI6@00`1]KFd0M7Ad07AdM002075aL@80IFEU101]KFd206IVIP@0K6a/
0P1YJFT206QXJ0@0JFUY0P1WIfL206UYJ@80Jf][00<0KFe]06][J`1[Jf/00P1PH602069RHP80IVIV
0P1PH60206=SH`80EeMG0P1QHF4205aLG080F5QH0P1ADE4205ADE080F5QH0P1CDe<205ADE00304Q8
B01EEED0EEEE0080AdM70P14A4@203@d=080<30`0P0Z:RX201lO7`80:b/[0P0J6QX200d=3@802@T9
0P0H61P200/;2`@0?clo00<0>3Ph02`/;00/;2`00P1:BTX204Q8B080C4a<0P28R8P20:ZZZT00MWIf
5@3oool001<0oooo101fMWH2071`L080M7Ad0P1`L70207AdM0l0MWIf0P1cLg<2092@T080HF5Q0P0U
9BD202@T9080:BTY0P0W9bL202PX:080;Rh^0P0Y:BT00`0e=CD0?Cdm03dm?@020492@P80BTY:0P1F
EUH205mOG`80I6AT0P1UIFD206MWI`80KVi^0P1]KFd206QXJ080JFUY0P1^KVh206e]K@80J6QX00<0
Kfm_06EUI@1UIFD00P1ZJVX206QXJ080IVIV0P1UIFD2075aL@80JVYZ0P1TI6@206QXJ0H0JVYZ0P1[
Jf/506UYJ@80GUiN0P1UIFD206e]K@80HV9R0P1PH60206=SH`80Fe]K0P1UIFD205UIF@80G5aL0P1F
EUH405MGE`80FUYJ0P1FEUH00`1?Cdl0EUIF05IFEP0203lo?`80>CTi0P0f=SH203`l?080?Cdm0P0c
<c<201hN7P805aLG0P0>3Ph2010@40806ATI0P0?3`l204Q8B080>c/k00<0?Cdm03De=@0e=CD00P1E
EED205=CD`80GEeM0P2KVi/208J6QT00MWIf5@3oool001<0oooo101fMWH2071`L080M7Ad0P1`L702
07AdM0l0MWIf0P1cLg<2092@T080HF5Q0P0U9BD202@T9080:BTY0P0W9bL202PX:080;Rh^0P0Y:BT0
0`0e=CD0?Cdm03dm?@020492@P80BTY:0P1FEUH205mOG`80I6AT0P1UIFD206MWI`80KVi^0P1]KFd2
06QXJ080JFUY0P1^KVh206e]K@80J6QX00<0Kfm_06EUI@1UIFD00P1ZJVX206QXJ080IVIV0P1UIFD2
075aL@80JVYZ0P1TI6@206QXJ0H0JVYZ0P1[Jf/506UYJ@80GUiN0P1UIFD206e]K@80HV9R0P1PH602
06=SH`80Fe]K0P1UIFD205UIF@80G5aL0P1FEUH405MGE`80FUYJ0P1FEUH00`1?Cdl0EUIF05IFEP02
03lo?`80>CTi0P0f=SH203`l?080?Cdm0P0c<c<201hN7P805aLG0P0>3Ph2010@40806ATI0P0?3`l2
04Q8B080>c/k00<0?Cdm03De=@0e=CD00P1EEED205=CD`80GEeM0P2KVi/208J6QT00MWIf5@3oool0
01<0oooo101fMWH207QhN080NGUi0P1hN7P207UiNA40MWIf0P29RHT402HV9P80;2`/0P0T92@402XZ
:P8092@T0P0/;2`00`0f=SH0>c/k03/k>`0204m?C`80CDe=0P1FEUH205aLG0@0IFEU0P1ZJVX2065Q
H@80IVIV0P1XJ6P206YZJP80IfMW0P1SHf<206EUI@0306IVIP1/K6`0K6a/0080LG5a0P1_Kfl207Ad
M080Jf][0P1UIFD406a/K080Jf][0P1ZJVX606UYJ@@0JVYZ00<0GUiN06=SH`1SHf<00P1ZJVX206MW
I`80HF5Q0P1/K6`406IVIP80JFUY0P1PH60205iNGP80EUIF0P1HF5P2055AD@80EUIF0P1BDU800`1G
EeL0BDU904U9B@0203dm?@80AdM70P14A4@2034a<@80:BTY0P0H61P201HF5P80410@0P0B4Q8200X:
2P804A4A0P0>3Ph2051@D080>SXj00<0<S8b030`<00`<3000P1KFe/206QXJ080PH610P2HV9Q207If
MQD0oooo000C0?ooo`@0MWIf0P1hN7P207UiN@80N7Qh0P1iNGTA07IfMP80RHV9100V9RH202`/;080
92@T100Z:RX202@T9080;2`/00<0=SHf03/k>`0k>c/00P1?Cdl204e=C@80EUIF0P1LG5`406EUI@80
JVYZ0P1QHF4206IVIP80J6QX0P1ZJVX206MWI`80Hf=S0P1UIFD00`1VIVH0K6a/06a/K002075aL@80
Kfm_0P1dM7@206][J`80IFEU101/K6`206][J`80JVYZ1P1YJFT406YZJP0305iNGP1SHf<0Hf=S0080
JVYZ0P1WIfL2065QH@80K6a/101VIVH206UYJ@80H61P0P1NGUh205IFEP80F5QH0P1ADE4205IFEP80
DU9B00<0EeMG04U9B@19BDT00P0m?Cd204M7A`80A4A40P0a<C4202TY:@8061PH0P0F5QH2010@4080
4Q8B0P0:2PX2014A4@803Ph>0P1@D50203Xj>P03038b<P0`<300<30`0080Fe]K0P1XJ6P20861P@80
V9RH@P1fMWHE0?ooo`004`3ooolM07IfMP80Lg=c0P1QHF420451@@@0;Rh^0P0_;bl202d];@80;bl_
0P0/;2`00`0Y:BT0=cLg03Lg=`0203lo?`80ATI60P1ADE4205aLG080IFEU0P1VIVH206UYJ@80J6QX
0P1^KVh406QXJ080L71`0P1ZJVX2071`L00307AdM01bLW80LW9b00@0KFe]0P1TI6@406e]K@80IVIV
0P1/K6`206YZJP80JFUY0P1XJ6P806UYJ@0306MWI`1`L700L71`0080JFUY0P1RHV8206ATI080HV9R
0P1NGUh2069RHP80Hf=S0P1GEeL205QHF080EeMG0P1HF5P205YJFP80De=C0P1ADE400`16ATH0AdM7
04M7A`0204Q8B080?3`l0P0j>SX203`l?080<S8b100K6a/201<C4`805aLG0P0?3`l401DE5@80DE5A
0P1>CTh00`0b<S80@T920492@P0205MGE`80IfMW0P2KVi/2092@T080L71`0P1dM7@n07IfMQD0oooo
000C0?oooad0MWIf0P1cLg<2065QH@80@D51100^;Rh202l_;`80;Bd]0P0_;bl202`/;00302TY:@0g
=cL0=cLg0080?clo0P16ATH2055AD@80G5aL0P1UIFD206IVIP80JFUY0P1XJ6P206i^KP@0J6QX0P1`
L70206YZJP80L71`00<0M7Ad079bLP1bLW80101]KFd206ATI0@0KFe]0P1VIVH206a/K080JVYZ0P1Y
JFT206QXJ0P0JFUY00<0IfMW071`L01`L7000P1YJFT2069RHP80I6AT0P1RHV8205iNGP80HV9R0P1S
Hf<205MGE`80F5QH0P1GEeL205QHF080FUYJ0P1CDe<2055AD@0304I6AP17AdL0AdM70080B4Q80P0l
?3`203Xj>P80?3`l0P0b<S8401/K6`804a<C0P0G5aL200l?3`@05ADE0P1ADE4204i>CP03038b<P12
@T80@T920080EeMG0P1WIfL209^KV`80T92@0P1`L70207AdM3h0MWIf5@3oool001<0oooo0P1fMWH2
071`L080M7Ad6@1fMWH208N7Q`80>3Ph0P0U9BD202@T9080:2PX0P0Y:BT202`/;080<30`00<0:b/[
03Ti>@0i>CT00P1:BTX205ADE0@0GemO0P1ZJVX206QXJ080HF5Q0P1RHV8206ATI080J6QX0P1[Jf/2
06QXJ080IVIV0P1XJ6P00`1ZJVX0IFEU06EUI@0206YZJP80I6AT0P1UIFD206QXJ080I6AT0P1YJFT2
06IVIP80I6AT1P1ZJVX206QXJ0@0JFUY0`1UIFD2061PH080IfMW0P1VIVH2065QH@@0Hf=S0P1KFe/2
05aLG080Hf=S0P1OGel205UIF@80F5QH0P1CDe<204i>CP03051@D015ADD0ADE50080@d=30P0m?Cd2
03Ph>080;2`/0P0V9RH201/K6`8071`L0P0F5QH201@D50806QXJ0P0L71`200l?3`80?Shn0P12@T80
0`0g=cL0EUIF05IFEP0206QXJ080O7al0P29RHT207IfMP80N7Qh0P1iNGTn07IfMQD0oooo000C0?oo
o`80MWIf0P1`L70207AdM1T0MWIf0P27QhL203Ph>0809BDU0P0T92@202PX:080:BTY0P0/;2`2030`
<00302/[:`0i>CT0>CTi0080BTY:0P1DE5@405mOG`80JVYZ0P1XJ6P2065QH@80HV9R0P1TI6@206QX
J080Jf][0P1XJ6P206IVIP80J6QX00<0JVYZ06EUI@1UIFD00P1ZJVX206ATI080IFEU0P1XJ6P206AT
I080JFUY0P1VIVH206ATI0H0JVYZ0P1XJ6P406UYJ@<0IFEU0P1PH60206MWI`80IVIV0P1QHF4406=S
H`80Fe]K0P1LG5`206=SH`80GemO0P1IFET205QHF080De=C0P1>CTh00`1@D500ADE504E5A@0204=3
@`80?Cdm0P0h>3P202`/;0809RHV0P0K6a/201`L70805QHF0P0D51@201XJ6P8071`L0P0?3`l203hn
?P80@T9200<0=cLg05IFEP1FEUH00P1XJ6P207alO080RHV90P1fMWH207QhN080NGUi?P1fMWHE0?oo
o`004`3oool207IfMP80N7Qh0P1iNGTI07IfMP80N7Qh0P0c<c<203lo?`80<C4a0P0d=3@2038b<P80
:b/[0P0^;Rh00`0a<C40?Cdm03dm?@0203Ph>080BTY:0P1NGUh206][J`80I6AT0P1QHF4206][J`80
K6a/0P1^KVh206e]K@80JFUY0P1XJ6P206MWI`80L71`00<0LG5a06IVIP1VIVH00P1WIfL206IVIP80
JFUY0P1WIfL406QXJ080JFUY0P1[Jf/606UYJ@@0JVYZ0`1SHf<206MWI`@0I6AT0P1OGel2061PH080
HV9R0P1SHf<205eMG@80GUiN0P1HF5P405ADE080F5QH0P1DE5@205QHF00304];B`11@D40@D510080
@T920P0h>3P203@d=080;2`/0P0S8b<201/K6`807alO0P0H61P201@D50806ATI0P0>3Ph200T92@80
@D510P0g=cL00`0a<C40CTi>04i>CP0206=SH`80TI6A0P2;Rh]407IfMQD0oooo000C0?ooo`80MWIf
0P1hN7P207UiNAT0MWIf0P1hN7P203<c<`80?clo0P0a<C4203@d=080<S8b0P0[:b/202h^;P03034a
<@0m?Cd0?Cdm0080>3Ph0P1:BTX205iNGP80Jf][0P1TI6@2065QH@80Jf][0P1/K6`206i^KP80KFe]
0P1YJFT206QXJ080IfMW0P1`L7000`1aLG40IVIV06IVIP0206MWI`80IVIV0P1YJFT206MWI`@0J6QX
0P1YJFT206][J`H0JFUY101ZJVX306=SH`80IfMW101TI6@205mOG`80H61P0P1RHV8206=SH`80GEeM
0P1NGUh205QHF0@0E5AD0P1HF5P205ADE080F5QH00<0Bd];0451@@11@D400P12@T8203Ph>080=3@d
0P0/;2`202<S8`806a/K0P0O7al201PH608051@D0P0I6AT200h>3P802@T90P11@D4203Lg=`03034a
<@1>CTh0CTi>0080Hf=S0P2ATI4208^;Rd@0MWIf5@3oool001<0oooo8@1fMWH20:j^[P80XZ:R0P1K
Fe/204I6AP80@4100P13@d<203<c<`0302h^;P0i>CT0>CTi0080BDU9101=CDd205UIF@80IFEU0P1X
J6P2061PH080I6AT0P1RHV82065QH@80IVIV0P1XJ6P206UYJ@80IVIV00<0Hf=S06IVIP1VIVH00P1Y
JFT2071`L080K6a/0P1YJFT206YZJP80Jf][0P1ZJVX206UYJ@80I6AT0P1XJ6P206=SH`@0HF5Q0P1S
Hf<00`1]KFd0I6AT06ATI00206IVIP80H61P0P1OGel2069RHP80Hf=S0P1GEeL205UIF@80GUiN0P1J
FUX205IFEP80GemO0P1BDU8204m?C`80DU9B00<0?clo0492@P12@T800P0j>SX203/k>`80<30`0P0W
9bL2024Q8@80:BTY0P0M7Ad201`L708051@D0P0>3Ph200L71`8092@T0P1YJFT20451@@030492@P1K
Fe/0Fe]K0080GUiN0P2:RXX207IfMP80M7Ad@P1fMWHE0?ooo`004`3oool207IfMP80L71`0P1dM7@?
07IfMP80L71`0P1dM7@807IfMP80O7al0P2EUID20;^k^`80CDe=0P0h>3P202/[:`80<S8b00<0=cLg
03De=@0e=CD00P0k>c/204i>CP80De=C0P1HF5P606=SH`80JFUY0P1XJ6P206i^KP80KFe]0P1UIFD2
06MWI`80JFUY00<0JVYZ06UYJ@1YJFT00P1ZJVX206QXJ080IFEU0P1ZJVX806UYJ@80Jf][0P1]KFd2
06EUI@@0IfMW0P1]KFd00`1WIfL0GEeM05eMG@0205iNGP80GemO0P1TI6@406=SH`80H61P0P1KFe/2
05QHF080FUYJ0P1NGUh205MGE`80B4Q80P1CDe<204=3@`0304E5A@1:BTX0BTY:0080>CTi0P0Y:BT2
028R8P80;Bd]0P0T92@401`L70805ADE0P0G5aL200`<30802@T90P1NGUh205IFEP80:b/[00<0@T92
04a<C01<C4`00P1jNWX209JFUP80N7Qh0P1iNGU207IfMQD0oooo000C0?ooo`80MWIf0P1`L70207Ad
M0l0MWIf0P1`L70207AdM0P0MWIf0P1lO7`209FEU@80^k^k0P1=CDd203Ph>080:b/[0P0b<S800`0g
=cL0=CDe03De=@0203/k>`80CTi>0P1CDe<205QHF0H0Hf=S0P1YJFT206QXJ080KVi^0P1]KFd206EU
I@80IfMW0P1YJFT00`1ZJVX0JFUY06UYJ@0206YZJP80J6QX0P1UIFD206YZJPP0JFUY0P1[Jf/206e]
K@80IFEU101WIfL206e]K@0306MWI`1MGEd0GEeM0080GUiN0P1OGel206ATI0@0Hf=S0P1PH60205]K
F`80F5QH0P1JFUX205iNGP80EeMG0P18B4P205=CD`80@d=300<0ADE504Y:BP1:BTX00P0i>CT202TY
:@808R8R0P0];Bd202@T90@071`L0P0E5AD201LG5`8030`<0P092@T205iNGP80EUIF0P0[:b/00`12
@T80C4a<04a<C00207YjNP80UYJF0P1hN7P207UiND80MWIf5@3oool001<0oooo0P1fMWH207QhN080
NGUi3`1fMWH207QhN080NGUi201fMWH207=cL`80KFe]0P1oOgl2059BDP80;Bd]0P0^;Rh202PX:003
034a<@0d=3@0=3@d0080@d=30P1:BTX2059BDP80GUiN0P1PH60205EEE@80GemO0P1PH60206ATI080
HF5Q0P1MGEd2069RHP80IFEU0P1YJFT00`1ZJVX0JFUY06UYJ@0206=SH`80IfMW101YJFT206ATI080
J6QX101QHF42061PH080HF5Q0P1SHf<206MWI`80Hf=S0P1KFe/00`1HF5P0GUiN05iNGP0206=SH`80
HV9R0P1SHf<4069RHP@0FEUI101LG5`205ADE0@0EEEE0P1ADE4205MGE`0304Q8B00f=SH0=SHf0080
;Rh^0P0a<C42038b<P80<C4a0P0c<c<201`L70806a/K0P0G5aL200h>3P802@T90P1dM7@206UYJ@80
<c<c0P0_;bl00`1BDU80MGEe07EeM@0209^KV`80RHV90P1`L70206m_K`80M7Ad@01fMWHE0?ooo`00
4`3oool207IfMP80N7Qh0P1iNGT?07IfMP80N7Qh0P1iNGT807IfMP80Lg=c0P1]KFd207moO`80DU9B
0P0];Bd202h^;P80:2PX00<0<C4a03@d=00d=3@00P13@d<204Y:BP80DU9B0P1NGUh2061PH080EEEE
0P1OGel2061PH080I6AT0P1QHF4205eMG@80HV9R0P1UIFD206UYJ@0306YZJP1YJFT0JFUY0080Hf=S
0P1WIfL406UYJ@80I6AT0P1XJ6P4065QH@80H61P0P1QHF4206=SH`80IfMW0P1SHf<205]KF`0305QH
F01NGUh0GUiN0080Hf=S0P1RHV8206=SH`@0HV9R101IFET405aLG080E5AD101EEED2055AD@80EeMG
00<0B4Q803Hf=P0f=SH00P0^;Rh2034a<@80<S8b0P0a<C4203<c<`8071`L0P0K6a/201LG5`803Ph>
0P092@T207AdM080JFUY0P0c<c<202l_;`03059BDP1eMGD0MGEe0080Vi^K0P29RHT2071`L080Kfm_
0P1dM7A007IfMQD0oooo000C0?ooobD0MWIf0P1lO7`206MWI`806a/K0P0[:b/204Y:BP0303@d=015
ADD0ADE50080AdM70P1;Bd/2055AD@80FUYJ0P1QHF4206IVIP80JFUY0P1RHV82061PH080IFEU0P1Z
JVX206m_K`80JFUY0P1SHf<00`1WIfL0Hf=S06=SH`0206UYJ@80KFe]101YJFT206][J`80IfMW0P1T
I6@206i^KP80JFUY0P1OGel206ATI080GUiN0P1UIFD306=SH`80HV9R1P1SHf<2069RHP80FUYJ0P1M
GEd205aLG080Fe]K0P1DE5@405=CD`80@4100P1:BTX204M7A`0303Xj>P0k>c/0>c/k00@0>c/k0P0_
;bl202<S8`809RHV0P13@d<201DE5@8030`<0P0A4A420492@P80>3Ph0P0c<c<203Lg=`80@d=300<0
Fe]K071`L01`L7000P2:RXX207emO@80LW9b0P23Ph<207alO400MWIf5@3oool001<0oooo9@1fMWH2
07alO080IfMW0P0K6a/202/[:`80BTY:00<0=3@d04E5A@15ADD00P17AdL204];B`80DE5A0P1JFUX2
065QH@80IVIV0P1YJFT2069RHP80H61P0P1UIFD206YZJP80Kfm_0P1YJFT206=SH`0306MWI`1SHf<0
Hf=S0080JFUY0P1]KFd406UYJ@80Jf][0P1WIfL206ATI080KVi^0P1YJFT205mOG`80I6AT0P1NGUh2
06EUI@<0Hf=S0P1RHV8606=SH`80HV9R0P1JFUX205eMG@80G5aL0P1KFe/205ADE0@0De=C0P10@402
04Y:BP80AdM700<0>SXj03/k>`0k>c/0100k>c/202l_;`808b<S0P0V9RH204=3@`805ADE0P0<30`2
014A4@80@T920P0h>3P203<c<`80=cLg0P13@d<00`1KFe/0L71`071`L00208Z:RP80OGem0P1bLW82
08>3P`80O7al@01fMWHE0?ooo`004`3ooolU07IfMP80O7al0P13@d<203De=@80=cLg0P0U9BD00`0Z
:RX0AdM704M7A`0203lo?`80Bd];0P1FEUH205eMG@80EEEE0P1IFET2065QH@80HV9R0P1SHf<206AT
I080GEeM0P1XJ6P2069RHP<0IVIV0P1SHf<206EUI@H0HF5Q0P1WIfL4061PH080Fe]K0P1HF5P205iN
GP80E5AD0P1JFUX205mOG`80GEeM1@1RHV8206=SH`80HV9R0P1SHf<205MGE`80EUIF0P1HF5P205EE
E@80E5AD0P1GEeL2055AD@80ATI60P18B4P203Ti>@03038b<P0c<c<0<c<c0080;Bd]0P0W9bL202XZ
:P80;Rh^0P0`<30201PH60808b<S0P0X:2P203Lg=`80;2`/0P19BDT204E5A@80BTY:0P1HF5P00`1_
Kfl0Jf][06][J`0208B4Q080Ph>30P1kNg/207IfMP80L71`@01fMWHE0?ooo`004`3ooolU07IfMP80
O7al0P13@d<203De=@80=cLg0P0U9BD00`0Z:RX0AdM704M7A`0203lo?`80Bd];0P1FEUH205eMG@80
EEEE0P1IFET2065QH@80HV9R0P1SHf<206ATI080GEeM0P1XJ6P2069RHP<0IVIV0P1SHf<206EUI@H0
HF5Q0P1WIfL4061PH080Fe]K0P1HF5P205iNGP80E5AD0P1JFUX205mOG`80GEeM1@1RHV8206=SH`80
HV9R0P1SHf<205MGE`80EUIF0P1HF5P205EEE@80E5AD0P1GEeL2055AD@80ATI60P18B4P203Ti>@03
038b<P0c<c<0<c<c0080;Bd]0P0W9bL202XZ:P80;Rh^0P0`<30201PH60808b<S0P0X:2P203Lg=`80
;2`/0P19BDT204E5A@80BTY:0P1HF5P00`1_Kfl0Jf][06][J`0208B4Q080Ph>30P1kNg/207IfMP80
L71`@01fMWHE0?ooo`004`3ooolU07IfMP80O7al0P0n?Sh205=CD`8092@T0P0Z:RX00`0];Bd0:RXZ
02XZ:P02038b<P80@T920P17AdL204I6AP80EUIF0P1MGEd205YJFP80GemO0P1GEeL2065QH@80IVIV
0P1UIFD2065QH@80H61P00<0G5aL05mOG`1OGel00P1UIFD206MWI`80KFe]0P1QHF42061PH080G5aL
101PH60205IFEP80DE5A0P1DE5@205QHF080GUiN0P1SHf<00`1LG5`0EEEE05EEE@0205QHF080E5AD
101ADE4204a<C080E5AD0P1CDe<204a<C080CTi>0P18B4P203hn?P80@d=30P14A4@20410@00303/k
>`11@D40@D510080>SXj0P0X:2P202LW9`808b<S0P0T92@2020P80809RHV0P0I6AT205YJFP80CTi>
0P17AdL203<c<`80H61P0P1GEeL00`1aLG40Y:BT0:BTY00209ZJVP80Lg=c0P1[Jf/207AdM080MWIf
0P1oOgl207UiNAl0MWIf0P1oOgl207UiNAT0MWIf5@3oool001<0oooo9@1fMWH207alO080?Shn0P1C
De<202@T9080:RXZ00<0;Bd]02XZ:P0Z:RX00P0b<S820492@P80AdM70P16ATH205IFEP80GEeM0P1J
FUX205mOG`80EeMG0P1QHF4206IVIP80IFEU0P1QHF42061PH00305aLG01OGel0GemO0080IFEU0P1W
IfL206e]K@80HF5Q0P1PH60205aLG0@0H61P0P1FEUH2055AD@80E5AD0P1HF5P205iNGP80Hf=S00<0
G5aL05EEE@1EEED00P1HF5P205ADE0@0DE5A0P1<C4`205ADE080De=C0P1<C4`204i>CP80B4Q80P0n
?Sh204=3@`80A4A40P10@4000`0k>c/0@D510451@@0203Xj>P80:2PX0P0W9bL202<S8`8092@T0P0P
820202HV9P806ATI0P1JFUX204i>CP80AdM70P0c<c<2061PH080EeMG00<0LG5a0:BTY02TY:@00P2J
VYX207=cL`80Jf][0P1dM7@207IfMP80Ogmo0P1iNGTO07IfMP80Ogmo0P1iNGTI07IfMQD0oooo000C
0?ooobD0MWIf101cLg<208R8R0805aLG0P0Q8B400`0m?Cd0;Rh^02h^;P0203`l?080A4A40P15ADD2
05UIF@80GUiN0P1DE5@205QHF0@0EeMG0P1TI6@2061PH0@0GEeM0P1UIFD00`1TI6@0HV9R069RHP02
05iNGP80GEeM101JFUX4061PH080Fe]K0P1BDU8204i>CP80De=C0P1EEED205UIF@80F5QH0P1;Bd/0
0`1:BTX0Cdm?04m?C`02051@D080B4Q80P1>CTh205ADE080C4a<0P1DE5@204i>CP80Cdm?0P1:BTX2
04a<C080B4Q80P0o?cl203dm?@80@D5100<0?Cdm03Ti>@0i>CT00P0Y:BT202`/;080<S8b0P0];Bd2
0451@@80>3Ph0P0];Bd204I6AP80HF5Q0P0j>SX204E5A@80EUIF0P1[Jf/207AdM003075aL@1mOGd0
OGem0080M7Ad0P1fMWH207QhN080Ph>30P1iNGT207=cL`80L71`4`1fMWH2071`L080M7Ad201fMWH2
07=cL`80L71`6@1fMWHE0?ooo`004`3ooolU07IfMP@0Lg=c0P28R8P201LG5`808B4Q00<0?Cdm02h^
;P0^;Rh00P0l?3`204A4A080ADE50P1IFET205iNGP80E5AD0P1HF5P405MGE`80I6AT0P1PH60405eM
G@80IFEU00<0I6AT069RHP1RHV800P1NGUh205eMG@@0FUYJ101PH60205]KF`80DU9B0P1>CTh205=C
D`80EEEE0P1IFET205QHF080Bd];00<0BTY:04m?C`1?Cdl00P1@D50204Q8B080CTi>0P1DE5@204a<
C080E5AD0P1>CTh204m?C`80BTY:0P1<C4`204Q8B080?clo0P0m?Cd20451@@0303dm?@0i>CT0>CTi
0080:BTY0P0/;2`2038b<P80;Bd]0P11@D4203Ph>080;Bd]0P16ATH2065QH@80>SXj0P15ADD205IF
EP80Jf][0P1dM7@00`1aLG40OGem07emO@0207AdM080MWIf0P1hN7P208>3P`80NGUi0P1cLg<2071`
L1<0MWIf0P1`L70207AdM0P0MWIf0P1cLg<2071`L1T0MWIf5@3oool001<0oooo9`1fMWH207moO`80
ADE50P0k>c/20451@@03038b<P0h>3P0>3Ph0080=cLg0P0e=CD203Lg=`80@d=30P1<C4`206=SH`80
FUYJ0P1EEED205UIF@80EeMG0P1OGel406ATI080HF5Q00<0GEeM05UIF@1IFET01P1GEeL2059BDP80
BDU90P15ADD204Q8B080CTi>101;Bd/204E5A@80@T920P0o?cl20410@00304I6AP15ADD0ADE50080
@d=30P15ADD203hn?P80>SXj0P0m?Cd20410@080?Shn100h>3P20492@P80?clo0P10@40203hn?P80
;bl_00<09bLW03@d=00d=3@00P0i>CT202h^;P80?3`l0P13@d<202HV9P80;bl_1014A4@203Ti>@80
<30`0P1@D50204Q8B080H61P0P1VIVH00`2ATI40VIVI09VIV@0207UiN@@0MWIf0P1cLg<2071`L1L0
MWIf0P1hN7P207UiNBD0MWIf5@3oool001<0oooo9`1fMWH207moO`80ADE50P0k>c/20451@@03038b
<P0h>3P0>3Ph0080=cLg0P0e=CD203Lg=`80@d=30P1<C4`206=SH`80FUYJ0P1EEED205UIF@80EeMG
0P1OGel406ATI080HF5Q00<0GEeM05UIF@1IFET01P1GEeL2059BDP80BDU90P15ADD204Q8B080CTi>
101;Bd/204E5A@80@T920P0o?cl20410@00304I6AP15ADD0ADE50080@d=30P15ADD203hn?P80>SXj
0P0m?Cd20410@080?Shn100h>3P20492@P80?clo0P10@40203hn?P80;bl_00<09bLW03@d=00d=3@0
0P0i>CT202h^;P80?3`l0P13@d<202HV9P80;bl_1014A4@203Ti>@80<30`0P1@D50204Q8B080H61P
0P1VIVH00`2ATI40VIVI09VIV@0207UiN@@0MWIf0P1cLg<2071`L1L0MWIf0P1hN7P207UiNBD0MWIf
5@3oool001<0oooo:@1fMWH209>CT`80N7Qh0P17AdL00`0d=3@0<c<c03<c<`0203Lg=`80ATI60P1<
C4`203dm?@80>CTi0P0f=SH204U9B@80Fe]K0P1SHf<206a/K080J6QX0P1IFET505MGE`@0CDe=0P15
ADD204Y:BP80Fe]K0P1@D50204m?C`@0CTi>0P0o?cl204E5A@80>c/k0P13@d<203dm?@80C4a<00<0
=cLg0410@010@4000P0c<c<203Lg=`80<c<c0P0d=3@203dm?@80>SXj0P0i>CT203`l?080@D510P0f
=SH20410@080D51@0P15ADD204e=C@0304a<C01:BTX0BTY:0080<S8b0P0c<c<20451@@80AdM70P0c
<c<201dM7@808B4Q0P13@d<2055AD@80C4a<0P1BDU8206MWI`80LG5a0P1OGel00`25QHD0NWYj07Yj
NP0:07IfMP80L71`0P1dM7@O07IfMP80Ogmo0P1iNGTI07IfMQD0oooo000C0?ooobT0MWIf0P2CTi<2
07QhN080AdM700<0=3@d03<c<`0c<c<00P0g=cL204I6AP80C4a<0P0m?Cd203Ti>@80=SHf0P19BDT2
05]KF`80Hf=S0P1/K6`206QXJ080FEUI1@1GEeL404e=C@80ADE50P1:BTX205]KF`80D51@0P1?Cdl4
04i>CP80?clo0P15ADD203/k>`80@d=30P0m?Cd204a<C00303Lg=`10@400@4100080<c<c0P0g=cL2
03<c<`80=3@d0P0m?Cd203Xj>P80>CTi0P0l?3`20451@@80=SHf0P10@402051@D080ADE50P1=CDd0
0`1<C4`0BTY:04Y:BP02038b<P80<c<c0P11@D4204M7A`80<c<c0P0M7Ad2024Q8@80@d=30P1ADE42
04a<C080DU9B0P1WIfL2075aL@80GemO00<0QHF507YjNP1jNWX02P1fMWH2071`L080M7Ad7`1fMWH2
07moO`80NGUi6@1fMWHE0?ooo`004`3oool[07IfMP80TY:B0P33`l<00`1^KVh0BDU904U9B@0202`/
;080=SHf0P0j>SX202PX:080A4A40P1EEED206][J`80L71`0P1^KVh206IVIP@0Fe]K0P1EEED204m?
C`0304E5A@1:BTX0BTY:0080Cdm?0P1ADE42059BDP80BTY:0P19BDT205=CD`80@d=30P0o?cl203`l
?080@4100P0l?3`204=3@`80?Shn0P0`<3000`0g=cL0@D510451@@0202l_;`80;Bd]0P0n?Sh203Ph
>080@4100P0b<S8203@d=0@0>3Ph0P0k>c/202TY:@808b<S0P0Y:BT203De=@03038b<P0f=SH0=SHf
0080>CTi0P13@d<202TY:@808b<S0P0`<30204M7A`80DU9B0P1:BTX203/k>`80DE5A0P1hN7P2079b
LP80B4Q80P2BTY800`2JVYX0MWIf07IfMP0207IfMP80L71`0P1dM7@407IfMP80N7Qh0P1iNGTG07If
MP80L71`0P1dM7@407IfMP80Lg=c0P1`L70I07IfMQD0oooo000C0?ooob/0MWIf0P2BTY820<?3``03
06i^KP19BDT0BDU90080;2`/0P0f=SH203Xj>P80:2PX0P14A4@205EEE@80Jf][0P1`L70206i^KP80
IVIV101KFe/205EEE@80Cdm?00<0ADE504Y:BP1:BTX00P1?Cdl2055AD@80DU9B0P1:BTX204U9B@80
De=C0P13@d<203lo?`80?3`l0P10@40203`l?080@d=30P0n?Sh2030`<00303Lg=`11@D40@D510080
;bl_0P0];Bd203hn?P80>3Ph0P10@402038b<P80=3@d100h>3P203/k>`80:BTY0P0S8b<202TY:@80
=CDe00<0<S8b03Hf=P0f=SH00P0i>CT204=3@`80:BTY0P0S8b<2030`<080AdM70P1BDU8204Y:BP80
>c/k0P1ADE4207QhN080LW9b0P18B4P209:BTP0309ZJVP1fMWH0MWIf0080MWIf0P1`L70207AdM0@0
MWIf0P1hN7P207UiNAL0MWIf0P1`L70207AdM0@0MWIf0P1cLg<2071`L1T0MWIf5@3oool001<0oooo
3P1fMWH2071`L00307AdM01`L700L71`0080M7Ad601fMWH207]kN`0303Ti>@10@400@4100080Bd];
0P17AdL204a<C080L71`0P1kNg/205MGE`80FUYJ0P14A4@204E5A@80D51@0P1EEED4051@D080CTi>
00<0Cdm?05ADE01DE5@00P11@D4204E5A@80DE5A0P1:BTX20451@@80ATI60P15ADD204=3@`80?Shn
0P11@D42038b<P80BTY:0P0l?3`2059BDP0304e=C@0k>c/0>c/k0080CDe=0P19BDT203Hf=P80D51@
0P15ADD204M7A`80ATI60P10@40204E5A@80Bd];0P0a<C4203Ph>080@d=30P12@T800`0c<c<0>3Ph
03Ph>00204=3@`80<S8b0P0i>CT203`l?080?Cdm0P0c<c<203Xj>P80BTY:0P1bLW8207alO080H61P
0P1@D50207UiN@80X:2P1@1fMWH20861P@80O7al7`1fMWH207QhN080NGUi8@1fMWHE0?ooo`004`3o
ool>07IfMP80L71`00<0M7Ad071`L01`L7000P1dM7@H07IfMP80Ng]k00<0>CTi0410@010@4000P1;
Bd/204M7A`80C4a<0P1`L70207]kN`80EeMG0P1JFUX204A4A080ADE50P1@D50205EEE@@0D51@0P1>
CTh00`1?Cdl0E5AD05ADE0020451@@80ADE50P1ADE4204Y:BP80@D510P16ATH204E5A@80@d=30P0n
?Sh20451@@80<S8b0P1:BTX203`l?080DU9B00<0CDe=03/k>`0k>c/00P1=CDd204U9B@80=SHf0P1@
D50204E5A@80AdM70P16ATH20410@080ADE50P1;Bd/2034a<@80>3Ph0P13@d<20492@P0303<c<`0h
>3P0>3Ph0080@d=30P0b<S8203Ti>@80?3`l0P0m?Cd203<c<`80>SXj0P1:BTX2079bLP80O7al0P1P
H602051@D080NGUi0P2PX:0507IfMP80PH610P1lO7`O07IfMP80N7Qh0P1iNGTQ07IfMQD0oooo000C
0?ooo`@0MWIf0P1`L70207AdM0H0MWIf0P1hN7P00`1iNGT0N7Qh07QhN00207UiNAX0MWIf00<0ZJVY
04Y:BP1:BTX00P13@d<203`l?080<C4a0P0c<c<203De=@80>CTi0P15ADD205EEE@80HF5Q0P1FEUH2
04a<C080BTY:0P1BDU8504M7A`80?Shn0P17AdL203`l?080?clo0P10@40204I6AP80?3`l0P1:BTX2
03`l?080<S8b0P0l?3`202`/;080=SHf0P0j>SX00`11@D40=cLg03Lg=`0203Xj>P80>3Ph0P13@d<2
05MGE`80:BTY0P0a<C42038b<P80AdM70P10@40202h^;P80<30`0P0^;Rh202@T908061PH00<071`L
02`/;00/;2`00P0R8R82020P80809bLW0P0V9RH2034a<@80@T920P1SHf<207QhN080QHF50P1;Bd/2
04m?C`80=CDe0P27QhL208j>SPD0MWIf0P1cLg<2071`L4@0MWIf5@3oool001<0oooo101fMWH2071`
L080M7Ad1P1fMWH207QhN00307UiN@1hN7P0N7Qh0080NGUi6P1fMWH00`2YZJT0BTY:04Y:BP0204=3
@`80?3`l0P0a<C4203<c<`80=CDe0P0i>CT204E5A@80EEEE0P1QHF4205IFEP80C4a<0P1:BTX2059B
DPD0AdM70P0n?Sh204M7A`80?3`l0P0o?cl20410@080ATI60P0l?3`204Y:BP80?3`l0P0b<S8203`l
?080;2`/0P0f=SH203Xj>P030451@@0g=cL0=cLg0080>SXj0P0h>3P204=3@`80EeMG0P0Y:BT2034a
<@80<S8b0P17AdL20410@080;Rh^0P0`<30202h^;P8092@T0P0H61P00`0L71`0;2`/02`/;002028R
8P80820P0P0W9bL202HV9P80<C4a0P12@T8206=SH`80N7Qh0P25QHD204];B`80Cdm?0P0e=CD208N7
Q`80SXj>1@1fMWH207=cL`80L71`A01fMWHE0?ooo`004`3oool407IfMP80N7Qh0P1iNGTW07IfMP03
07=cL`2][Jd0[Jf]0080MGEe0P14A4@204I6AP80Hf=S0P1PH602069RHP80LW9b0P1XJ6P205aLG080
Fe]K0P19BDT204E5A@80ATI60P18B4P00`17AdL0CDe=04e=C@0204];B`80Cdm?0P11@D4203lo?`80
BTY:0P11@D4203De=@80=SHf0P0V9RH20492@P80BDU90P0a<C4201dM7@80<c<c00<092@T03`l?00l
?3`00P14A4@203lo?`80@4100P0T92@202XZ:P80ATI60P0L71`201DE5@808R8R0P0W9bL202PX:080
;2`/0P0i>CT203dm?@0304M7A`0l?3`0?3`l0080>3Ph0P0_;bl203Xj>P80@T920P22PX8206e]K@80
L71`0P1aLG4201`L7080;Bd]0P0e=CD207AdM080^k^k0P1iNGT;07IfMP80L71`0P1dM7@n07IfMQD0
oooo000C0?ooo`@0MWIf0P1hN7P207UiNBL0MWIf00<0Lg=c0:f][@2][Jd00P1eMGD204A4A080ATI6
0P1SHf<2061PH080HV9R0P1bLW8206QXJ080G5aL0P1KFe/204U9B@80ADE50P16ATH204Q8B00304M7
A`1=CDd0CDe=0080Bd];0P1?Cdl20451@@80?clo0P1:BTX20451@@80=CDe0P0f=SH202HV9P80@T92
0P19BDT2034a<@807AdM0P0c<c<00`0T92@0?3`l03`l?00204A4A080?clo0P10@40202@T9080:RXZ
0P16ATH201`L70805ADE0P0R8R8202LW9`80:2PX0P0/;2`203Ti>@80?Cdm00<0AdM703`l?00l?3`0
0P0h>3P202l_;`80>SXj0P12@T8208:2PP80KFe]0P1`L702075aL@8071`L0P0];Bd203De=@80M7Ad
0P2k^k/207UiN@/0MWIf0P1`L70207AdM3h0MWIf5@3oool001<0oooo<01fMWH207=cL`80ADE50P16
ATH202/[:`80;Bd]0P0Q8B4202/[:`80ADE50P1CDe<205IFEP80FEUI0P1ADE4204U9B@80ADE50P0n
?Sh00`15ADD0BDU904U9B@020410@080>CTi0P0o?cl204Y:BP80>CTi0P0l?3`204M7A`80;Rh^0P1F
EUH204];B`80:BTY0P1CDe<20451@@80<30`00<0?clo03@d=00d=3@00P0U9BD202h^;P8092@T0P0W
9bL202PX:0805aLG0P0S8b<203<c<`80>c/k0P0Z:RX202`/;080=SHf0P0`<30202LW9`03024Q8@0Y
:BT0:BTY0080?Shn0P1HF5P205mOG`80Kfm_0P1IFET206QXJ080L71`0P0`<30202h^;P80GemO0P0n
?Sh20:BTY080S8b<0P1`L70307IfMP80L71`0P1dM7@207IfMP80L71`0P1fMWH207UiNAL0MWIf0P1`
L70207AdM080MWIf0P1oOgl207UiNAd0MWIf5@3oool001<0oooo<01fMWH207=cL`80ADE50P16ATH2
02/[:`80;Bd]0P0Q8B4202/[:`80ADE50P1CDe<205IFEP80FEUI0P1ADE4204U9B@80ADE50P0n?Sh0
0`15ADD0BDU904U9B@020410@080>CTi0P0o?cl204Y:BP80>CTi0P0l?3`204M7A`80;Rh^0P1FEUH2
04];B`80:BTY0P1CDe<20451@@80<30`00<0?clo03@d=00d=3@00P0U9BD202h^;P8092@T0P0W9bL2
02PX:0805aLG0P0S8b<203<c<`80>c/k0P0Z:RX202`/;080=SHf0P0`<30202LW9`03024Q8@0Y:BT0
:BTY0080?Shn0P1HF5P205mOG`80Kfm_0P1IFET206QXJ080L71`0P0`<30202h^;P80GemO0P0n?Sh2
0:BTY080S8b<0P1`L70307IfMP80L71`0P1dM7@207IfMP80L71`0P1fMWH207UiNAL0MWIf0P1`L702
07AdM080MWIf0P1oOgl207UiNAd0MWIf5@3oool001<0oooo<P1fMWH209jNWP80:RXZ0P0i>CT206YZ
JP80CDe=0P19BDT204Q8B080CTi>0P1GEeL204m?C`80C4a<0P0d=3@203Ti>@80>SXj00<0BTY:04];
B`1;Bd/00P11@D4203@d=0@0@T920P0k>c/204a<C080?Cdm0P1:BTX202/[:`80:2PX0P0j>SX202d]
;@80=CDe0P0b<S800`0`<300;Bd]02d];@0202d];@80;bl_0P0/;2`202PX:080:RXZ0P0_;bl2034a
<@809BDU0P0N7Qh202HV9P80;Rh^0P0Z:RX202LW9`80:RXZ00<0>CTi051@D01@D5000P1;Bd/203lo
?`80>3Ph0P1ADE4206IVIP80<S8b0P0I6AT202d];@80IFEU0P1IFET20:BTY080];Bd0P1_Kfl207Ad
M00307IfMP1`L700L71`0080MWIf0P1iNGT2071`L080MWIf0P1iNGT207moO`80NGUi1P1fMWH207mo
O`80NGUi2`1fMWH207QhN080NGUi0P1fMWH207=cL`80L71`7@1fMWHE0?ooo`004`3ooolb07IfMP80
WYjN0P0Z:RX203Ti>@80JVYZ0P1=CDd204U9B@80B4Q80P1>CTh205MGE`80Cdm?0P1<C4`203@d=080
>CTi0P0j>SX00`1:BTX0Bd];04];B`020451@@80=3@d1012@T8203/k>`80C4a<0P0m?Cd204Y:BP80
:b/[0P0X:2P203Xj>P80;Bd]0P0e=CD2038b<P03030`<00];Bd0;Bd]0080;Bd]0P0_;bl202`/;080
:2PX0P0Z:RX202l_;`80<C4a0P0U9BD201hN7P809RHV0P0^;Rh202XZ:P809bLW0P0Z:RX00`0i>CT0
D51@051@D00204];B`80?clo0P0h>3P2055AD@80IVIV0P0b<S8201TI6@80;Bd]0P1UIFD205UIF@80
Y:BT0P2d];@206m_K`80M7Ad00<0MWIf071`L01`L7000P1fMWH207UiN@80L71`0P1fMWH207UiN@80
Ogmo0P1iNGT607IfMP80Ogmo0P1iNGT;07IfMP80N7Qh0P1iNGT207IfMP80Lg=c0P1`L70M07IfMQD0
oooo000C0?oooc80MWIf0P1cLg<20:f][@80I6AT0P0H61P203Ti>@80GUiN0P1KFe/204I6AP80EUIF
0P1OGel205]KF`80>CTi0P1;Bd/203dm?@0303Ph>00i>CT0>CTi0080=CDe0P0d=3@204=3@`80?clo
0P0d=3@203Ti>@80<C4a0P0k>c/202TY:@80ATI60P0h>3P203Lg=`8092@T0P0K6a/00`15ADD0:BTY
02TY:@0202TY:@80;Rh^100/;2`202HV9P8092@T0P0K6a/201PH60808R8R0P0S8b<201lO7`80:BTY
0P10@40203De=@0303Lg=`19BDT0BDU90080HF5Q0P1OGel208b<S080P8200P1=CDd203`l?080=SHf
0P1JFUX202l_;`80QhN70P2o_kl208j>SP80NGUi0P1gMgL00`1fMWH0N7Qh07QhN00207UiN@80MWIf
0P1hN7P207UiN@80MWIf0P1cLg<2071`L0H0MWIf0P1cLg<2071`L380MWIf5@3oool001<0oooo<P1f
MWH207=cL`80[Jf]0P1TI6@201PH6080>CTi0P1NGUh205]KF`80ATI60P1FEUH205mOG`80Fe]K0P0i
>CT204];B`80?Cdm00<0>3Ph03Ti>@0i>CT00P0e=CD203@d=080@d=30P0o?cl203@d=080>CTi0P0a
<C4203/k>`80:BTY0P16ATH203Ph>080=cLg0P0T92@201/K6`0304E5A@0Y:BT0:BTY0080:BTY0P0^
;Rh402`/;0809RHV0P0T92@201/K6`8061PH0P0R8R8202<S8`807alO0P0Y:BT20410@080=CDe00<0
=cLg04U9B@19BDT00P1QHF4205mOG`80S8b<0P20P80204e=C@80?3`l0P0f=SH205YJFP80;bl_0P27
QhL20;no_`80SXj>0P1iNGT207MgM`0307IfMP1hN7P0N7Qh0080NGUi0P1fMWH207QhN080NGUi0P1f
MWH207=cL`80L71`1P1fMWH207=cL`80L71`<P1fMWHE0?ooo`004`3ooolb07IfMP80L71`0P1dM7@2
0:n_[`80IVIV0P0Q8B4201lO7`80<C4a0P12@T8405mOG`80E5AD0P0g=cL202l_;`80B4Q800<0A4A4
04a<C01<C4`00P1DE5@2051@D080=SHf0P0m?Cd20410@080;bl_0P0l?3`204=3@`80<S8b0P0n?Sh2
0410@080?Shn0P0k>c/201XJ6P0301hN7P0T92@092@T0080CTi>0P0a<C4202/[:`806a/K0P0[:b/2
02DU9@807alO0P0K6a/201dM7@8061PH0P0G5aL202@T9080;Bd]0P1;Bd/00`1/K6`0EeMG05MGE`02
04i>CP80I6AT0P16ATH2014A4@8071`L0P0h>3P204I6AP80<c<c0P1GEeL20;Rh^080O7al0P1]KFd2
079bLP80NGUi00<0MWIf071`L01`L7000P1dM7@207moO`80NGUi501fMWH2071`L00307AdM01fMWH0
MWIf00h0MWIf0P1oOgl207UiNAT0MWIf5@3oool001<0oooo2P1fMWH2071`L080M7Ad901fMWH207Qh
N080NGUi0P1cLg<2075aL@80A4A40P0a<C4202HV9P80>c/k0P17AdL204Q8B080EeMG0P10@40203Lg
=`80?3`l00<0ADE503Hf=P0f=SH00P0Z:RX2038b<P80<30`0P0];Bd2038b<P80>SXj0P0f=SH202h^
;P@0@D510P0];Bd203`l?080?clo0P12@T800`18B4P0:BTY02TY:@0201hN7P80:BTY0P0^;Rh2030`
<080>SXj0P0`<30204Y:BP80>c/k0P0i>CT20451@@80E5AD0P1MGEd205MGE`<0FUYJ0P22PX8205YJ
FP80BDU90P0/;2`201XJ6P80=cLg0P12@T8204m?C`80FUYJ0P38b<P20:RXZ0P0MWIf00<0Ogmo07]k
N`1kNg/00P1dM7@2075aL@80L71`1P1fMWH207moO`80NGUi2P1fMWH207QhN00307UiN@1oOgl0Ogmo
0080NGUi301fMWH207=cL`80L71`6@1fMWHE0?ooo`004`3oool:07IfMP80L71`0P1dM7@T07IfMP80
N7Qh0P1iNGT207=cL`80LG5a0P14A4@2034a<@809RHV0P0k>c/204M7A`80B4Q80P1GEeL20410@080
=cLg0P0l?3`00`15ADD0=SHf03Hf=P0202XZ:P80<S8b0P0`<30202d];@80<S8b0P0j>SX203Hf=P80
;Rh^1011@D4202d];@80?3`l0P0o?cl20492@P0304Q8B00Y:BT0:BTY00807QhN0P0Y:BT202h^;P80
<30`0P0j>SX2030`<080BTY:0P0k>c/203Ti>@80@D510P1DE5@205eMG@80EeMG0`1JFUX208:2PP80
FUYJ0P19BDT202`/;0806QXJ0P0g=cL20492@P80Cdm?0P1JFUX20<S8b080Z:RX201fMWH00`1oOgl0
Ng]k07]kN`0207AdM080LG5a0P1`L70607IfMP80Ogmo0P1iNGT:07IfMP80N7Qh00<0NGUi07moO`1o
Ogl00P1iNGT<07IfMP80Lg=c0P1`L70I07IfMQD0oooo000C0?ooo`X0MWIf0P1hN7P207UiNBX0MWIf
0P24Q8@20820P080F5QH0P15ADD202l_;`807AdM0P0Y:BT202d];@80G5aL0P0g=cL2034a<@0303Hf
=P13@d<0@d=30080?Shn0P0c<c<202LW9`80:2PX0P0W9bL202XZ:P80;Rh^0P0g=cL203Ti>@80;2`/
0P0_;bl20492@P80AdM70`10@402034a<@80E5AD0P0c<c<202TY:@80@d=30P12@T8203Ti>@80>3Ph
0P0k>c/2059BDP80GemO0P1cLg<205eMG@80G5aL0P1jNWX00`1KFe/0@D510451@@0202l_;`80?3`l
0P0N7Qh203`l?080GUiN0P1:BTX203Xj>P80^;Rh0P2i^KT207moO`80Ph>30P1iNGT2071`L080OGem
00<0L71`07QhN01hN7P00P1kNg/407AdM080Ogmo0P1iNGT207IfMP80Lg=c0P1`L70=07IfMP80Lg=c
0P1`L70607IfMP80Ogmo0P1iNGTO07IfMQD0oooo000C0?ooo`X0MWIf0P1hN7P207UiNBX0MWIf0P24
Q8@20820P080F5QH0P15ADD202l_;`807AdM0P0Y:BT202d];@80G5aL0P0g=cL2034a<@0303Hf=P13
@d<0@d=30080?Shn0P0c<c<202LW9`80:2PX0P0W9bL202XZ:P80;Rh^0P0g=cL203Ti>@80;2`/0P0_
;bl20492@P80AdM70`10@402034a<@80E5AD0P0c<c<202TY:@80@d=30P12@T8203Ti>@80>3Ph0P0k
>c/2059BDP80GemO0P1cLg<205eMG@80G5aL0P1jNWX00`1KFe/0@D510451@@0202l_;`80?3`l0P0N
7Qh203`l?080GUiN0P1:BTX203Xj>P80^;Rh0P2i^KT207moO`80Ph>30P1iNGT2071`L080OGem00<0
L71`07QhN01hN7P00P1kNg/407AdM080Ogmo0P1iNGT207IfMP80Lg=c0P1`L70=07IfMP80Lg=c0P1`
L70607IfMP80Ogmo0P1iNGTO07IfMQD0oooo000C0?oooc80MWIf0P1oOgl207UiN@@0MWIf0P2:RXX2
06i^KP80@d=30P0o?cl204I6AP80C4a<0P16ATH204a<C080Fe]K0P13@d<00`0c<c<0?clo03lo?`02
04A4A080>SXj0P1?Cdl2038b<P80<30`0P0_;bl403Xj>P80?3`l0P0X:2P204I6AP80@4100P1;Bd/2
0492@P0304m?C`1TI6@0I6AT0080@T920P0/;2`203@d=080@D510P0m?Cd2059BDP80FUYJ0P1NGUh2
05UIF@80K6a/0P1WIfL205eMG@80?3`l0P0Y:BT00`0R8R806QXJ01XJ6P0200d=3@805ADE0P0j>SX2
05ADE080?Shn0P1>CTh20=KFeP80a<C40P1`L70207=cL`80MWIf0P1mOGd207]kN`80MWIf00<0O7al
07UiN@1iNGT00P1`L70207QhN080NGUi0P1cLg<2071`L1d0MWIf0P1cLg<2071`L1l0MWIf5@3oool0
01<0oooo<P1fMWH207moO`80NGUi101fMWH208Z:RP80KVi^0P13@d<203lo?`80ATI60P1<C4`204I6
AP80C4a<0P1KFe/204=3@`0303<c<`0o?cl0?clo0080A4A40P0j>SX204m?C`80<S8b0P0`<30202l_
;`@0>SXj0P0l?3`202PX:080ATI60P10@40204];B`80@T9200<0Cdm?06ATI01TI6@00P12@T8202`/
;080=3@d0P11@D4203dm?@80DU9B0P1JFUX205iNGP80FEUI0P1/K6`206MWI`80GEeM0P0l?3`202TY
:@03028R8P0J6QX06QXJ00803@d=0P0E5AD203Xj>P80E5AD0P0n?Sh204i>CP80e]KF0P34a<@2071`
L080Lg=c0P1fMWH207emO@80Ng]k0P1fMWH00`1lO7`0NGUi07UiN@02071`L080N7Qh0P1iNGT207=c
L`80L71`7@1fMWH207=cL`80L71`7`1fMWHE0?ooo`004`3ooolb07IfMP80KFe]0P1^KVh207IfMP80
L71`0P1dM7@209:BTP80QXJ60P0j>SX203Lg=`80BDU90P1ADE4205ADE080De=C0P1YJFT00`1:BTX0
B4Q804Q8B00202XZ:P80@D510P0l?3`204=3@`80ADE50P0^;Rh202HV9P8071`L0P0Z:RX202TY:@80
?clo0P0h>3P205=CD`80CDe=00<0Rh^;09JFUP2FUYH00P28R8P207emO@80UiNG0P2;Rh/207inOP80
N7Qh0P2ATI4209RHV080Ng]k0P1_Kfl203/k>`807AdM0P0Z:RX2038b<P0302@T900U9BD09BDU0080
>CTi0P1QHF4206MWI`80@d=30P0n?Sh20<W9b@80];Bd0P1`L70207moO`80NGUi0P1cLg<206e]K@80
L71`0P1fMWH00`1cLg<0L71`071`L002071`L080M7Ad0P1fMWH207moO`80Ph>30P1iNGTn07IfMQD0
oooo000C0?oooc80MWIf0P1]KFd206i^KP80MWIf0P1`L70207AdM080TY:B0P26QXH203Xj>P80=cLg
0P19BDT2055AD@80E5AD0P1CDe<206UYJ@0304Y:BP18B4P0B4Q80080:RXZ0P11@D4203`l?080@d=3
0P15ADD202h^;P809RHV0P0L71`202XZ:P80:BTY0P0o?cl203Ph>080De=C0P1=CDd00`2;Rh/0UYJF
09JFUP0208R8R080OGem0P2GUiL208^;R`80OWin0P1hN7P2096AT@80V9RH0P1kNg/206m_K`80>c/k
0P0M7Ad202XZ:P80<S8b00<092@T02DU9@0U9BD00P0i>CT2065QH@80IfMW0P13@d<203hn?P80bLW9
0P2d];@2071`L080Ogmo0P1iNGT207=cL`80KFe]0P1`L70207IfMP0307=cL`1`L700L71`0080L71`
0P1dM7@207IfMP80Ogmo0P23Ph<207UiNCh0MWIf5@3oool001<0oooo<P1fMWH207QhN080NGUi0P1f
MWH207QhN080Ph>30P1iNGT208f=S@80bl_;0P1XJ6P203Ti>@807alO0P0b<S8205aLG080Hf=S00<0
JFUY05=CD`1CDe<00P1CDe<2055AD@80C4a<0P17AdL205YJFP80Ogmo0P1MGEd203<c<`80?Cdm0P0Z
:RX203`l?080EUIF0P1ZJVX205MGE`0303Xj>P15ADD0ADE50080FEUI0P1YJFT207UiN@80Q8B40P29
RHT2079bLP80AdM70P0Z:RX202d];@80:RXZ0P0T92@203@d=080=cLg0P0Q8B400`0U9BD0@D510451
@@0204e=C@80GEeM0P0l?3`204Y:BP80cLg=0P31`L44071`L080LG5a101`L70206m_K`80M7Ad0`1f
MWH2071`L080MWIf0P1iNGT207IfMP80Lg=c0P1]KFd4071`L080M7Ad>P1fMWHE0?ooo`004`3ooolb
07IfMP80N7Qh0P1iNGT207IfMP80N7Qh0P23Ph<207UiN@80SHf=0P3;bl/206QXJ080>CTi0P0O7al2
038b<P80G5aL0P1SHf<00`1YJFT0De=C05=CD`0205=CD`80DE5A0P1<C4`204M7A`80FUYJ0P1oOgl2
05eMG@80<c<c0P0m?Cd202XZ:P80?3`l0P1FEUH206YZJP80EeMG00<0>SXj04E5A@15ADD00P1IFET2
06UYJ@80NGUi0P24Q8@208V9R@80LW9b0P17AdL202XZ:P80;Bd]0P0Z:RX202@T9080=3@d0P0g=cL2
024Q8@0302DU9@11@D40@D510080CDe=0P1MGEd203`l?080BTY:0P3=cLd20<71`@@0L71`0P1aLG44
071`L080Kfm_0P1dM7@307IfMP80L71`0P1fMWH207UiN@80MWIf0P1cLg<206e]K@@0L71`0P1dM7@j
07IfMQD0oooo000C0?ooocX0MWIf0P1lO7`207AdM080MWIf0P1iNGT20;6a/@80F5QH0P0c<c<204M7
A`80>SXj0P15ADD00`1/K6`0IfMW06MWI`02075aL@80Ph>30P1fMWH209RHV080Shn?0P1QHF4208b<
S080b/[:0P3oool20??cl`80g]kN0P2a/K4209BDU080N7Qh00<0SXj>08J6QP26QXH0101XJ6P206m_
K`80Cdm?0P0Q8B42034a<@80<S8b0P0_;bl2030`<080=3@d0P0[:b/2034a<@809RHV0P17AdL00`1T
I6@0FEUI05UIF@0204];B`80?3`l0P2o_kl20>g]k@80]KFe0P1oOgl207AdM080MWIf0P1iNGT207If
MP80N7Qh0P1eMGD207MgM`<0MWIf0P1hN7P407AdM080MWIf0P1oOgl207UiN@80MWIf0P1bLW8207Mg
M`80MWIf0P1`L70207AdM080Ogmo0P1iNGT`07IfMQD0oooo000C0?ooocX0MWIf0P1lO7`207AdM080
MWIf0P1iNGT20;6a/@80F5QH0P0c<c<204M7A`80>SXj0P15ADD00`1/K6`0IfMW06MWI`02075aL@80
Ph>30P1fMWH209RHV080Shn?0P1QHF4208b<S080b/[:0P3oool20??cl`80g]kN0P2a/K4209BDU080
N7Qh00<0SXj>08J6QP26QXH0101XJ6P206m_K`80Cdm?0P0Q8B42034a<@80<S8b0P0_;bl2030`<080
=3@d0P0[:b/2034a<@809RHV0P17AdL00`1TI6@0FEUI05UIF@0204];B`80?3`l0P2o_kl20>g]k@80
]KFe0P1oOgl207AdM080MWIf0P1iNGT207IfMP80N7Qh0P1eMGD207MgM`<0MWIf0P1hN7P407AdM080
MWIf0P1oOgl207UiN@80MWIf0P1bLW8207MgM`80MWIf0P1`L70207AdM080Ogmo0P1iNGT`07IfMQD0
oooo000C0?ooobL0MWIf0P1oOgl207UiN@l0MWIf0P1lO7`207AdM0@0MWIf0P1cLg<209nOW`80fMWI
0P12@T8202`/;080?clo00<0@41005IFEP1FEUH00P1kNg/208F5Q@80NWYj0P1fMWH206QXJ080MgMg
0P22PX8205]KF`80CTi>0P1;Bd/2051@D080IVIV0P1fMWH207MgM`0306m_K`1ZJVX0JVYZ0080De=C
0P0h>3P204U9B@80>SXj0P17AdL205EEE@80:b/[0P0h>3P402d];@80@4100P1CDe<2075aL@80N7Qh
00<0De=C0492@P12@T800P1TI6@20=7Ad@80`/;20P1[Jf/207AdM080KFe]0P1`L70207UiN@H0MWIf
0P1hN7P207UiN@80L71`00<0M7Ad07IfMP1fMWH00P1hN7P207UiN@80MWIf0P1cLg<2071`L080MWIf
0P1hN7P207UiN@80MWIf0P1hN7P207UiN@80Lg=c0P1`L70=07IfMP80Ogmo0P1iNGT207IfMP80Ogmo
0P1iNGT2071`L080M7Ad5@1fMWHE0?ooo`004`3ooolW07IfMP80Ogmo0P1iNGT?07IfMP80O7al0P1d
M7@407IfMP80Lg=c0P2OWil20=WIf@80@T920P0/;2`203lo?`030410@01FEUH0EUIF0080Ng]k0P25
QHD207YjNP80MWIf0P1XJ6P207MgM`80PX:20P1KFe/204i>CP80Bd];0P1@D50206IVIP80MWIf0P1g
MgL00`1_Kfl0JVYZ06YZJP0205=CD`80>3Ph0P19BDT203Xj>P80AdM70P1EEED202/[:`80>3Ph100]
;Bd20410@080De=C0P1aLG4207QhN00305=CD`12@T80@T920080I6AT0P3AdM420<;2`P80Jf][0P1d
M7@206e]K@80L71`0P1iNGT607IfMP80N7Qh0P1iNGT2071`L00307AdM01fMWH0MWIf0080N7Qh0P1i
NGT207IfMP80Lg=c0P1`L70207IfMP80N7Qh0P1iNGT207IfMP80N7Qh0P1iNGT207=cL`80L71`3@1f
MWH207moO`80NGUi0P1fMWH207moO`80NGUi0P1`L70207AdM1D0MWIf5@3oool001<0oooo9`1fMWH2
07=cL`80L71`2`1fMWH207moO`80NGUi0P1lO7`207emO@80NGUi0P1oOgl207UiN@80MWIf0P29RHT2
0:f][@80JFUY0P14A4@00`0j>SX0DU9B059BDP0204i>CP80C4a<0P1ADE42061PH080KVi^0P1aLG42
06i^KP80KFe]0P26QXH207emO@80Lg=c0P1_Kfl206a/K080H61P00<0GemO05EEE@1EEED00P1KFe/2
04];B`80=SHf0P0l?3`2038b<P80;2`/0P0^;Rh204e=C@80<S8b0P1CDe<206UYJ@80IVIV0P1GEeL2
03dm?@0304i>CP2TY:@0Y:BT0080eMGE0P2XZ:P207IfMP80LW9b0P1gMgL207QhN080NGUi0P1oOgl2
07UiN@80Ogmo0P1iNGT207IfMP80L71`0P1fMWH00`1iNGT0MWIf07IfMP0<07IfMP80Ogmo0P1iNGT<
07IfMP0307moO`1iNGT0NGUi00H0MWIf0P1oOgl207IfMP80L71`0P1fMWH207=cL`80NWYj0P1kNg/2
07UiNAD0MWIf5@3oool001<0oooo9`1fMWH207=cL`80L71`2`1fMWH207moO`80NGUi0P1lO7`207em
O@80NGUi0P1oOgl207UiN@80MWIf0P29RHT20:f][@80JFUY0P14A4@00`0j>SX0DU9B059BDP0204i>
CP80C4a<0P1ADE42061PH080KVi^0P1aLG4206i^KP80KFe]0P26QXH207emO@80Lg=c0P1_Kfl206a/
K080H61P00<0GemO05EEE@1EEED00P1KFe/204];B`80=SHf0P0l?3`2038b<P80;2`/0P0^;Rh204e=
C@80<S8b0P1CDe<206UYJ@80IVIV0P1GEeL203dm?@0304i>CP2TY:@0Y:BT0080eMGE0P2XZ:P207If
MP80LW9b0P1gMgL207QhN080NGUi0P1oOgl207UiN@80Ogmo0P1iNGT207IfMP80L71`0P1fMWH00`1i
NGT0MWIf07IfMP0<07IfMP80Ogmo0P1iNGT<07IfMP0307moO`1iNGT0NGUi00H0MWIf0P1oOgl207If
MP80L71`0P1fMWH207=cL`80NWYj0P1kNg/207UiNAD0MWIf5@3oool001<0oooo=P1fMWH207=cL`80
L71`0P1cLg<206e]K@80L71`0P1cLg<4071`L080LG5a0P1oOgl20:f][@80k>c/00<0KFe]038b<P0b
<S800P0T92@204Y:BP80Hf=S0P1aLG4206i^KP80IfMW0P1RHV8205QHF080GemO0P1EEED205ADE080
C4a<0P0i>CT202TY:@0302HV9P0f=SH0=SHf0080ADE50P10@4020492@P809bLW0P0`<30205aLG080
EEEE0P1bLW8207]kN`80SHf=0P1/K6`20492@P80EeMG0P2g]kL00`3Jf]X0]kNg0;Ng]`0208F5Q@@0
MWIf0P1hN7P208>3P`80NGUi0P1fMWH207=cL`80L71`0P1]KFd206i^KP80MWIf0P21PH4207alO003
07moO`1iNGT0NGUi00@0MWIf0P1`L70207AdM080Ogmo0P1iNGT207=cL`80L71`101fMWH207moO`80
NGUi101fMWH00`1cLg<0L71`071`L00607IfMP80Lg=c0P1`L70207IfMP80Ogmo0P23Ph<207moO`80
KVi^0P1dM7@907IfMP80Ogmo0P1iNGT807IfMQD0oooo000C0?ooocH0MWIf0P1cLg<2071`L080Lg=c
0P1]KFd2071`L080Lg=c101`L702075aL@80Ogmo0P2][Jd20>c/k00306e]K@0b<S80<S8b008092@T
0P1:BTX206=SH`80LG5a0P1^KVh206MWI`80HV9R0P1HF5P205mOG`80EEEE0P1DE5@204a<C080>CTi
0P0Y:BT00`0V9RH0=SHf03Hf=P0204E5A@80@4100P12@T8202LW9`80<30`0P1LG5`205EEE@80LW9b
0P1kNg/208f=S@80K6a/0P12@T8205MGE`80]kNg00<0f][J0;Ng]`2g]kL00P25QHD407IfMP80N7Qh
0P23Ph<207UiN@80MWIf0P1cLg<2071`L080KFe]0P1^KVh207IfMP80PH610P1lO7`00`1oOgl0NGUi
07UiN@0407IfMP80L71`0P1dM7@207moO`80NGUi0P1cLg<2071`L0@0MWIf0P1oOgl207UiN@@0MWIf
00<0Lg=c071`L01`L7001P1fMWH207=cL`80L71`0P1fMWH207moO`80Ph>30P1oOgl206i^KP80M7Ad
2@1fMWH207moO`80NGUi201fMWHE0?ooo`004`3ooolU07IfMP80Ogmo0P1iNGTG07IfMP80L71`0P1m
OGd207]kN`80NGUi0P1lO7`207AdM080MWIf00<0VYZJ0>;RhP3Rh^800P3alO4206YZJP80<c<c0P0l
?3`20410@080B4Q80P1TI6@2075aL@80L71`0P1[Jf/207=cL`80N7Qh0P1ZJVX2075aL@0306=SH`1I
FET0FEUI0080@T920P1LG5`208f=S@80LG5a0P2EUID209JFUP80Ph>30P1LG5`203`l?080G5aL0P2D
U9@20=CDe080inOW0P2e]KD00`1lO7`0MWIf07IfMP0207IfMP80Ogmo0P1iNGT207IfMP80Lg=c0P1`
L70207IfMP80Ogmo0P1iNGT207QhN080NGUi0P1fMWH207=cL`80L71`00<0KFe]06i^KP1^KVh0101f
MWH207QhN080NGUi0P1cLg<2071`L080Ogmo0P1iNGT207moO`80Ph>30P1oOgl207emO@80Ph>30P1i
NGT707IfMP80Ogmo0P1iNGT407IfMP80O7al0P1jNWX2071`L0@0O7al2@1fMWH207=cL`80L71`201f
MWHE0?ooo`004`3ooolU07IfMP80Ogmo0P1iNGTG07IfMP80L71`0P1mOGd207]kN`80NGUi0P1lO7`2
07AdM080MWIf00<0VYZJ0>;RhP3Rh^800P3alO4206YZJP80<c<c0P0l?3`20410@080B4Q80P1TI6@2
075aL@80L71`0P1[Jf/207=cL`80N7Qh0P1ZJVX2075aL@0306=SH`1IFET0FEUI0080@T920P1LG5`2
08f=S@80LG5a0P2EUID209JFUP80Ph>30P1LG5`203`l?080G5aL0P2DU9@20=CDe080inOW0P2e]KD0
0`1lO7`0MWIf07IfMP0207IfMP80Ogmo0P1iNGT207IfMP80Lg=c0P1`L70207IfMP80Ogmo0P1iNGT2
07QhN080NGUi0P1fMWH207=cL`80L71`00<0KFe]06i^KP1^KVh0101fMWH207QhN080NGUi0P1cLg<2
071`L080Ogmo0P1iNGT207moO`80Ph>30P1oOgl207emO@80Ph>30P1iNGT707IfMP80Ogmo0P1iNGT4
07IfMP80O7al0P1jNWX2071`L0@0O7al2@1fMWH207=cL`80L71`201fMWHE0?ooo`004`3ooolS07If
MP80L71`0P1aLG42071`L1L0MWIf0P1hN7P207IfMP80L71`0P1fMWH207=cL`80L71`0P1fMWH00`1o
Ogl0NGUi07UiN@0207moO`80VYZJ0P3Cdm<2075aL@80AdM70P1IFET20492@P80@D510P1GEeL205aL
G0@0JVYZ0P21PH4209nOW`030:2PX02IVIT0VIVI0080SXj>0P2EUID207EeM@80Lg=c0P1KFe/203Lg
=`80ATI60P1cLg<20;2`/080aLG50P2OWil208J6QP80NWYj0P1[Jf/00`1^KVh0MWIf07IfMP0207If
MP80Lg=c0P1`L70407IfMP80L71`0P1dM7@207=cL`80Jf][0P1dM7@407IfMP80L71`0P1dM7@00`1h
N7P0NGUi07UiN@0807IfMP80L71`0P1dM7@207=cL`80L71`0P1cLg<606e]K@80J6QX0P1^KVh00`1o
Ogl0M7Ad07AdM00207AdM080MWIf0P1cLg<2071`L080MWIf0P1`L702075aL@80KFe]0P1`L70207=c
L`80Jf][0P1dM7@C07IfMQD0oooo000C0?ooob<0MWIf0P1`L702075aL@80L71`5`1fMWH207QhN080
MWIf0P1`L70207IfMP80Lg=c0P1`L70207IfMP0307moO`1iNGT0NGUi0080Ogmo0P2JVYX20=?Cd`80
LG5a0P17AdL205UIF@80@T920P11@D4205MGE`80G5aL101ZJVX20861P@80WinO00<0X:2P09VIV@2I
VIT00P2>SXh209FEU@80MGEe0P1cLg<205]KF`80=cLg0P16ATH207=cL`80/;2`0P35aLD209nOW`80
QXJ60P1jNWX206][J`0306i^KP1fMWH0MWIf0080MWIf0P1cLg<2071`L0@0MWIf0P1`L70207AdM080
Lg=c0P1[Jf/207AdM0@0MWIf0P1`L70207AdM00307QhN01iNGT0NGUi00P0MWIf0P1`L70207AdM080
Lg=c0P1`L70207=cL`H0KFe]0P1XJ6P206i^KP0307moO`1dM7@0M7Ad0080M7Ad0P1fMWH207=cL`80
L71`0P1fMWH2071`L080LG5a0P1]KFd2071`L080Lg=c0P1[Jf/207AdM1<0MWIf5@3oool001<0oooo
8`1fMWH207QhN080Ph>30P1iNGTO07IfMP80L71`0P1dM7@207IfMP0307alO01^KVh0KVi^0080Jf][
0P1^KVh207IfMP80TY:B0P2m_Kd20;Jf]P80[Zj^0P2XZ:P2096AT@80OGem0P28R8P207emO@80GUiN
0P0o?cl00`0i>CT0CTi>04i>CP0205mOG`80GEeM0P1IFET206ATI080SHf=0P2m_Kd20<G5a@80[jn_
0P2FUYH207moO`80MWIf0P1lO7`207YjNP80MGEe1@23Ph<207UiN@H0MWIf0P1hN7P207AdM080Kfm_
0P1fMWH207UiN@@0MWIf0P1hN7P207UiN@03071`L01dM7@0M7Ad0080Ogmo101dM7@207IfMP80N7Qh
0P23Ph<207UiN@X0MWIf0P1hN7P207UiN@0307=cL`1lO7`0O7al0080O7al0P1oOgl207UiN@@0MWIf
0P1hN7P207UiN@H0MWIf0P21PH4207alO0/0MWIf0P1oOgl207UiN@@0MWIf5@3oool001<0oooo8`1f
MWH207QhN080Ph>30P1iNGTO07IfMP80L71`0P1dM7@207IfMP0307alO01^KVh0KVi^0080Jf][0P1^
KVh207IfMP80TY:B0P2m_Kd20;Jf]P80[Zj^0P2XZ:P2096AT@80OGem0P28R8P207emO@80GUiN0P0o
?cl00`0i>CT0CTi>04i>CP0205mOG`80GEeM0P1IFET206ATI080SHf=0P2m_Kd20<G5a@80[jn_0P2F
UYH207moO`80MWIf0P1lO7`207YjNP80MGEe1@23Ph<207UiN@H0MWIf0P1hN7P207AdM080Kfm_0P1f
MWH207UiN@@0MWIf0P1hN7P207UiN@03071`L01dM7@0M7Ad0080Ogmo101dM7@207IfMP80N7Qh0P23
Ph<207UiN@X0MWIf0P1hN7P207UiN@0307=cL`1lO7`0O7al0080O7al0P1oOgl207UiN@@0MWIf0P1h
N7P207UiN@H0MWIf0P21PH4207alO0/0MWIf0P1oOgl207UiN@@0MWIf5@3oool001<0oooo9@1fMWH2
07=cL`80Jf][0P1dM7@C07IfMP80Ogmo101dM7@407IfMP80N7Qh101dM7@00`1cLg<0LW9b079bLP02
07]kN`80NGUi101fMWH207QhN080Ng]k0P25QHD208:2PP80QHF51028R8P20820P080RHV90P2MWId0
0`2VYZH0X:2P0:2PX0020:RXZ0@0Xj>S0P2QXJ4209BDU080PH610P1iNGT207moO`80Ph>30P1iNGT2
07IfMP80Lg=c0P1fMWH207AdM00307=cL`1]KFd0KFe]0080KFe]0P1[Jf/207AdM080Ogmo0P1iNGT2
07IfMP80PH610P1nOWh207UiN@80MWIf0P1oOgl207UiN@80Ogmo0P1iNGT00`21PH40O7al07alO002
06e]K@80L71`0P1iNGT2071`L080M7Ad0P1cLg<2071`L0l0MWIf0P1]KFd206i^KP80Lg=c0P1jNWX2
07UiN@H0MWIf0P1oOgl207UiN@80MWIf0P1cLg<2071`L0/0MWIf0P1cLg<2071`L0@0MWIf5@3oool0
01<0oooo9@1fMWH207=cL`80Jf][0P1dM7@C07IfMP80Ogmo101dM7@407IfMP80N7Qh101dM7@00`1c
Lg<0LW9b079bLP0207]kN`80NGUi101fMWH207QhN080Ng]k0P25QHD208:2PP80QHF51028R8P20820
P080RHV90P2MWId00`2VYZH0X:2P0:2PX0020:RXZ0@0Xj>S0P2QXJ4209BDU080PH610P1iNGT207mo
O`80Ph>30P1iNGT207IfMP80Lg=c0P1fMWH207AdM00307=cL`1]KFd0KFe]0080KFe]0P1[Jf/207Ad
M080Ogmo0P1iNGT207IfMP80PH610P1nOWh207UiN@80MWIf0P1oOgl207UiN@80Ogmo0P1iNGT00`21
PH40O7al07alO00206e]K@80L71`0P1iNGT2071`L080M7Ad0P1cLg<2071`L0l0MWIf0P1]KFd206i^
KP80Lg=c0P1jNWX207UiN@H0MWIf0P1oOgl207UiN@80MWIf0P1cLg<2071`L0/0MWIf0P1cLg<2071`
L0@0MWIf5@3oool001<0oooo9`1fMWH207QhN080NGUi4`1fMWH207=cL`80LW9b0P1iNGT407IfMP80
L71`0P1fMWH207UiN@03071`L01mOGd0OGem0080NGUi101fMWH2071`L080M7Ad0P1`L702075aL@80
L71`0P1oOgl407AdM080MWIf0P1hN7P507]kN`80Ogmo0P1dM7@207IfMP80L71`0P1dM7@407IfMP80
Lg=c0P1]KFd2071`L080Ogmo0P1iNGT207alO080M7Ad0`1fMWH2071`L080Ogmo101lO7`207emO@80
NGUi0P1cLg<2071`L0@0MWIf0P1cLg<2071`L080Lg=c0P1`L7000`1lO7`0KVi^06i^KP02071`L080
MgMg0P1`L70207IfMP80NGUi301fMWH207moO`80NGUi0`1fMWH207QhN080NGUi0P1fMWH207alO080
M7Ad101fMWH2071`L080LG5a0P1jNWX208>3P`80NGUi3@1fMWH207moO`80NGUi0P1`L70207AdM1D0
oooo000C0?ooobL0MWIf0P1hN7P207UiNA<0MWIf0P1cLg<2079bLP80NGUi101fMWH2071`L080MWIf
0P1iNGT00`1`L700OGem07emO@0207UiN@@0MWIf0P1`L70207AdM080L71`0P1aLG42071`L080Ogmo
101dM7@207IfMP80N7Qh1@1kNg/207moO`80M7Ad0P1fMWH2071`L080M7Ad101fMWH207=cL`80KFe]
0P1`L70207moO`80NGUi0P1lO7`207AdM0<0MWIf0P1`L70207moO`@0O7al0P1mOGd207UiN@80Lg=c
0P1`L70407IfMP80Lg=c0P1`L70207=cL`80L71`00<0O7al06i^KP1^KVh00P1`L70207MgM`80L71`
0P1fMWH207UiN@`0MWIf0P1oOgl207UiN@<0MWIf0P1hN7P207UiN@80MWIf0P1lO7`207AdM0@0MWIf
0P1`L702075aL@80NWYj0P23Ph<207UiN@d0MWIf0P1oOgl207UiN@80L71`0P1dM7@E0?ooo`004`3o
oolY07IfMP80Ogmo0P1iNGTK07IfMP80N7Qh0P1iNGT207moO`0308F5Q@1iNGT0NGUi0080L71`0P1f
MWH2071`L080MWIf0P1iNGT20861P@80O7al0P1fMWH207=cL`@0O7al0P1fMWH207moO`80NGUi0`1f
MWH206e]K@80KVi^0P1fMWH207QhN080NGUi101fMWH2071`L080M7Ad0P1oOgl207IfMP80L71`0P1l
O7`207emO@0307UiN@1fMWH0MWIf0080N7Qh0P1`L70206i^KP80Lg=c0P1XJ6P206i^KP80Ogmo0P1i
NGT607IfMP80Ogmo0P1iNGT207IfMP0307=cL`1bLW80LW9b0080Ng]k0P1iNGT207QhN080NGUi0P1f
MWH207moO`@0M7Ad1P1fMWH207alO080M7Ad0P1fMWH00`1oOgl0NGUi07UiN@0207IfMP80L71`0P1a
LG42071`L0@0MWIf0P1hN7P207UiN@80KFe]101dM7@=07IfMP80Lg=c0P1`L7020861P@80O7al5@3o
ool001<0oooo:@1fMWH207moO`80NGUi6`1fMWH207QhN080NGUi0P1oOgl00`25QHD0NGUi07UiN@02
071`L080MWIf0P1`L70207IfMP80NGUi0P21PH4207alO080MWIf0P1cLg<407alO080MWIf0P1oOgl2
07UiN@<0MWIf0P1]KFd206i^KP80MWIf0P1hN7P207UiN@@0MWIf0P1`L70207AdM080Ogmo0P1fMWH2
071`L080O7al0P1mOGd00`1iNGT0MWIf07IfMP0207QhN080L71`0P1^KVh207=cL`80J6QX0P1^KVh2
07moO`80NGUi1P1fMWH207moO`80NGUi0P1fMWH00`1cLg<0LW9b079bLP0207]kN`80NGUi0P1hN7P2
07UiN@80MWIf0P1oOgl407AdM0H0MWIf0P1lO7`207AdM080MWIf00<0Ogmo07UiN@1iNGT00P1fMWH2
071`L080LG5a0P1`L70407IfMP80N7Qh0P1iNGT206e]K@@0M7Ad3@1fMWH207=cL`80L71`0P21PH42
07alO1D0oooo000C0?ooob40MWIf0P1oOgl207UiN@80MWIf0P1`L702075aL@@0L71`00<0M7Ad07If
MP1fMWH04P1fMWH2071`L080OGem0P1iNGT207IfMP80Lg=c00<0J6QX06i^KP1^KVh0101fMWH207Qh
N080M7Ad0P1mOGd2071`L080KVi^101fMWH207alO080M7Ad0P1fMWH207=cL`80NWYj00<0NGUi071`
L01`L7000P1fMWH207UiN@80L71`0P1dM7@607IfMP80N7Qh0P1iNGT207=cL`80L71`0P1fMWH207=c
L`80MWIf00<0M7Ad07IfMP1fMWH00P1`L70207IfMP80Ph>30P1iNGT207QhN080NGUi0P1]KFd207Qh
N080Ph>30P1iNGT207IfMP80KFe]0P1hN7P207UiN@D0MWIf0P1oOgl207UiN@@0MWIf0P1lO7`207Ee
M@80NGUi0P1fMWH207moO`80NGUi0P1cLg<207YjNP80NGUi00<0Lg=c07YjNP1jNWX00P23Ph<207]k
N`80NGUi0P1oOgl207UiN@@0MWIf0P1`L70407IfMP80L71`2@1fMWH207moO`80NGUi101fMWH207=c
L`80L71`5@3oool001<0oooo8@1fMWH207=cL`80L71`0P1fMWH207QhN080NGUi0P1oOgl207]kN`03
07UiN@1fMWH0MWIf0180MWIf0P1hN7P207IfMP80L71`101fMWH00`1hN7P0NGUi07UiN@0607IfMP80
LW9b0P1dM7@2079bLP80NGUi0P1oOgl207AdM080LG5a0P1jNWX207UiN@80MWIf0P1cLg<00`1`L700
PH610861P@0207alO080Ogmo0P1kNg/207UiN@P0MWIf0P1`L70207AdM080Ogmo0P1iNGT207IfMP80
Lg=c00<0L71`07IfMP1fMWH00P1hN7P207UiN@80Lg=c0P1`L70407IfMP80N7Qh0P1fMWH206QXJ080
KVi^0P1fMWH207QhN080MWIf0P1`L7000`1fMWH0L71`071`L00207emO@80L71`0P1hN7P207UiN@80
MWIf0P1lO7`207AdM080MWIf0P1`L702075aL@80L71`0P1fMWH207=cL`80L71`00<0MWIf07=cL`1c
Lg<00P1]KFd2071`L080MWIf0P1cLg<4071`L080M7Ad0P1hN7P207UiN@/0MWIf0P1`L70207YjNP80
M7Ad201fMWHE0?ooo`004`3ooolQ07IfMP80Lg=c0P1`L70207IfMP80N7Qh0P1iNGT207moO`80Ng]k
00<0NGUi07IfMP1fMWH04P1fMWH207QhN080MWIf0P1`L70407IfMP0307QhN01iNGT0NGUi00H0MWIf
0P1bLW8207AdM080LW9b0P1iNGT207moO`80M7Ad0P1aLG4207YjNP80NGUi0P1fMWH207=cL`03071`
L021PH40PH610080O7al0P1oOgl207]kN`80NGUi201fMWH2071`L080M7Ad0P1oOgl207UiN@80MWIf
0P1cLg<00`1`L700MWIf07IfMP0207QhN080NGUi0P1cLg<2071`L0@0MWIf0P1hN7P207IfMP80J6QX
0P1^KVh207IfMP80N7Qh0P1fMWH2071`L00307IfMP1`L700L71`0080OGem0P1`L70207QhN080NGUi
0P1fMWH207alO080M7Ad0P1fMWH2071`L080LG5a0P1`L70207IfMP80Lg=c0P1`L7000`1fMWH0Lg=c
07=cL`0206e]K@80L71`0P1fMWH207=cL`@0L71`0P1dM7@207QhN080NGUi2`1fMWH2071`L080NWYj
0P1dM7@807IfMQD0oooo000C0?ooobL0MWIf0P1oOgl207UiN@80Lg=c0P1`L70C07IfMP80L71`0P1d
M7@A07IfMP@0LW9b0P1dM7@207IfMP80Lg=c0P1bLW8207AdM080NWYj0P1mOGd207UiN@80MWIf00<0
Ogmo071`L01`L7000P1^KVh207=cL`80L71`101fMWH207moO`80NGUi101`L70207MgM`80Lg=c0P1j
NWX407AdM00307moO`1iNGT0NGUi0080Ogmo0P1iNGT207IfMP80Ogmo0P1iNGT207moO`80NGUi0P1f
MWH207QhN080NGUi0P1fMWH207moO`80NGUi0`1fMWH207QhN080MWIf0P1]KFd207AdM080NWYj0P1i
NGT207=cL`80L71`0P1oOgl207]kN`80NGUi0P1fMWH207moO`80NGUi0P1oOgl00`1iNGT0MWIf07If
MP0207moO`@0M7Ad101fMWH207QhN080NGUi0P1oOgl207UiN@80MWIf0P1oOgl207UiN@D0MWIf0P1h
N7P207IfMP80L71`101fMWH2071`L080Kfm_5@3oool001<0oooo9`1fMWH207moO`80NGUi0P1cLg<2
071`L1<0MWIf0P1`L70207AdM140MWIf101bLW8207AdM080MWIf0P1cLg<2079bLP80M7Ad0P1jNWX2
07emO@80NGUi0P1fMWH00`1oOgl0L71`071`L00206i^KP80Lg=c0P1`L70407IfMP80Ogmo0P1iNGT4
071`L080MgMg0P1cLg<207YjNP@0M7Ad00<0Ogmo07UiN@1iNGT00P1oOgl207UiN@80MWIf0P1oOgl2
07UiN@80Ogmo0P1iNGT207IfMP80N7Qh0P1iNGT207IfMP80Ogmo0P1iNGT307IfMP80N7Qh0P1fMWH2
06e]K@80M7Ad0P1jNWX207UiN@80Lg=c0P1`L70207moO`80Ng]k0P1iNGT207IfMP80Ogmo0P1iNGT2
07moO`0307UiN@1fMWH0MWIf0080Ogmo101dM7@407IfMP80N7Qh0P1iNGT207moO`80NGUi0P1fMWH2
07moO`80NGUi1@1fMWH207QhN080MWIf0P1`L70407IfMP80L71`0P1_KflE0?ooo`004`3ooolW07If
MP80Lg=c0P1`L70207moO`80NGUi4`1fMWH207QhN080Ph>30P1iNGT207IfMP80L71`0P1dM7@00`1`
L700M7Ad07AdM00607IfMP80N7Qh0P1kNg/208>3P`80NGUi101fMWH207QhN080MWIf0P1]KFd4071`
L00307YjNP1eMGD0MGEe0080NGUi201fMWH207=cL`80L71`0P1hN7P207]kN`80NGUi0P1`L702075a
L@D0O7al0P1dM7@207=cL`@0L71`0P1jNWX206i^KP80NWYj0P1dM7@407IfMP80L71`0P1dM7@207=c
L`80L71`1`1fMWH207QhN080Ph>30P1`L70206UYJ@80M7Ad0P1fMWH207=cL`80Jf][0P1dM7@207If
MP80Lg=c0P1`L70207alO00307AdM01fMWH0MWIf0080Lg=c0P1bLW8207UiN@@0MWIf0P1oOgl207Ui
N@80Lg=c0P1`L70207IfMP80Lg=c0P1`L70;07IfMP80L71`0P1dM7@20861P@80OWin5@3oool001<0
oooo9`1fMWH207=cL`80L71`0P1oOgl207UiNA<0MWIf0P1hN7P208>3P`80NGUi0P1fMWH2071`L080
M7Ad00<0L71`07AdM01dM7@01P1fMWH207QhN080Ng]k0P23Ph<207UiN@@0MWIf0P1hN7P207IfMP80
KFe]101`L7000`1jNWX0MGEe07EeM@0207UiN@P0MWIf0P1cLg<2071`L080N7Qh0P1kNg/207UiN@80
L71`0P1aLG4507alO080M7Ad0P1cLg<4071`L080NWYj0P1^KVh207YjNP80M7Ad101fMWH2071`L080
M7Ad0P1cLg<2071`L0L0MWIf0P1hN7P208>3P`80L71`0P1YJFT207AdM080MWIf0P1cLg<206][J`80
M7Ad0P1fMWH207=cL`80L71`0P1lO7`00`1dM7@0MWIf07IfMP0207=cL`80LW9b0P1iNGT407IfMP80
Ogmo0P1iNGT207=cL`80L71`0P1fMWH207=cL`80L71`2`1fMWH2071`L080M7Ad0P21PH4207inOQD0
oooo000C0?ooob/0MWIf0P1cLg<206][J`0307AdM01fMWH0MWIf00`0MWIf0P1`L70207emO@80NGUi
0P1cLg<206][J`80M7Ad0P1hN7P207AdM003071`L01gMgL0MgMg00@0MWIf0P1oOgl208>3P`80NGUi
0P1cLg<4071`L080M7Ad1P1fMWH2071`L0<0MWIf0P1jNWX207UiN@80L71`0P1mOGd207UiN@P0MWIf
0P1oOgl207UiN@80PH610P1lO7`206e]K@80N7Qh00<0MWIf06][J`1[Jf/00P1dM7@2071`L0@0MWIf
0P1lO7`207UiN@@0L71`0P1dM7@207QhN080Ph>30P1dM7@207emO@80NGUi00<0L71`07AdM01dM7@0
0P1`L70207emO@80MWIf0P1lO7`207inOP80NGUi0P1fMWH2071`L080MWIf0P1iNGT607IfMP80Lg=c
00<0L71`07IfMP1fMWH02P1fMWH207=cL`@0L71`0P1dM7@A07IfMP80N7Qh0P1iNGT207=cL`80L71`
5@3oool001<0oooo:`1fMWH207=cL`80Jf][00<0M7Ad07IfMP1fMWH0301fMWH2071`L080OGem0P1i
NGT207=cL`80Jf][0P1dM7@207QhN080M7Ad00<0L71`07MgM`1gMgL0101fMWH207moO`80Ph>30P1i
NGT207=cL`@0L71`0P1dM7@607IfMP80L71`0`1fMWH207YjNP80NGUi0P1`L70207emO@80NGUi201f
MWH207moO`80NGUi0P21PH4207alO080KFe]0P1hN7P00`1fMWH0Jf][06][J`0207AdM080L71`101f
MWH207alO080NGUi101`L70207AdM080N7Qh0P23Ph<207AdM080OGem0P1iNGT00`1`L700M7Ad07Ad
M002071`L080OGem0P1fMWH207alO080OWin0P1iNGT207IfMP80L71`0P1fMWH207UiN@H0MWIf0P1c
Lg<00`1`L700MWIf07IfMP0:07IfMP80Lg=c101`L70207AdM140MWIf0P1hN7P207UiN@80Lg=c0P1`
L70E0?ooo`004`3oool]07IfMP80N7Qh00<0NGUi07IfMP1fMWH0301fMWH207QhN080MWIf0P1`L702
07IfMP80PH610P1lO7`207moO`80Ng]k00<0MGEe0861P@21PH400P23Ph<207UiN@80KFe]101dM7@4
07IfMP80N7Qh0P1iNGT607IfMP80PH610P26QXH00`1iNGT0Lg=c07=cL`02071`L080N7Qh0P1oOgl2
07AdM0P0MWIf0P1cLg<207YjNP80MWIf0P1`L70207QhN080MWIf00<0L71`0861P@21PH400P26QXH2
08F5Q@80QXJ60P1iNGT207=cL`80L71`0P1fMWH2079bLP80MgMg0P1oOgl207IfMP80LW9b0P1fMWH2
07YjNP0308F5Q@26QXH0QXJ60080QHF50P1iNGT2071`L080Lg=c0P1`L70407IfMP80PH610P26QXH2
07UiN@H0MWIf0P1`L7000`1dM7@0MWIf07IfMP0807IfMP80Ogmo0P1iNGT207IfMP80N7Qh0P1iNGT2
07moO`80NGUi1P1fMWH00`1oOgl0NGUi07UiN@0207moO`80NGUi0P1fMWH207moO`80NGUi0P1fMWHE
0?ooo`004`3oool]07IfMP80N7Qh00<0NGUi07IfMP1fMWH0301fMWH207QhN080MWIf0P1`L70207If
MP80PH610P1lO7`207moO`80Ng]k00<0MGEe0861P@21PH400P23Ph<207UiN@80KFe]101dM7@407If
MP80N7Qh0P1iNGT607IfMP80PH610P26QXH00`1iNGT0Lg=c07=cL`02071`L080N7Qh0P1oOgl207Ad
M0P0MWIf0P1cLg<207YjNP80MWIf0P1`L70207QhN080MWIf00<0L71`0861P@21PH400P26QXH208F5
Q@80QXJ60P1iNGT207=cL`80L71`0P1fMWH2079bLP80MgMg0P1oOgl207IfMP80LW9b0P1fMWH207Yj
NP0308F5Q@26QXH0QXJ60080QHF50P1iNGT2071`L080Lg=c0P1`L70407IfMP80PH610P26QXH207Ui
N@H0MWIf0P1`L7000`1dM7@0MWIf07IfMP0807IfMP80Ogmo0P1iNGT207IfMP80N7Qh0P1iNGT207mo
O`80NGUi1P1fMWH00`1oOgl0NGUi07UiN@0207moO`80NGUi0P1fMWH207moO`80NGUi0P1fMWHE0?oo
o`004`3ooolS07IfMP80Ogmo0P1iNGT207moO`80NGUi0P1fMWH2071`L00307AdM01`L700L71`0080
M7Ad201fMWH207moO`80NGUi1P1fMWH207=cL`80L71`0P1]KFd206i^KP03079bLP1dM7@0M7Ad0080
J6QX0P1^KVh207QhN080MWIf0P1`L70607IfMP80L71`0P1dM7@407IfMP80Lg=c0P1]KFd00`1`L700
Ogmo07moO`0207UiN@80MWIf0P1cLg<2071`L080Ogmo101dM7@207moO`80Ph>30P1fMWH2071`L0L0
MWIf0P1cLg<606e]K@80L71`0P1oOgl207UiN@80MWIf0P1hN7P207UiN@80Lg=c0P1[Jf/207AdM080
MWIf0P1cLg<506e]K@80NWYj0P1iNGT207moO`80NGUi0P1fMWH2071`L080LG5a0P1fMWH207AdM0@0
MWIf0P1oOgl207]kN`0307UiN@1fMWH0MWIf00P0MWIf0P1cLg<206][J`80M7Ad0P1`L70207AdM080
Lg=c0P1`L70607IfMP0307=cL`1`L700L71`0080Lg=c0P1`L70207IfMP80Lg=c0P1`L70207IfMQD0
oooo000C0?ooob<0MWIf0P1oOgl207UiN@80Ogmo0P1iNGT207IfMP80L71`00<0M7Ad071`L01`L700
0P1dM7@807IfMP80Ogmo0P1iNGT607IfMP80Lg=c0P1`L70206e]K@80KVi^00<0LW9b07AdM01dM7@0
0P1XJ6P206i^KP80N7Qh0P1fMWH2071`L0H0MWIf0P1`L70207AdM0@0MWIf0P1cLg<206e]K@03071`
L01oOgl0Ogmo0080NGUi0P1fMWH207=cL`80L71`0P1oOgl407AdM080Ogmo0P23Ph<207IfMP80L71`
1`1fMWH207=cL`H0KFe]0P1`L70207moO`80NGUi0P1fMWH207QhN080NGUi0P1cLg<206][J`80M7Ad
0P1fMWH207=cL`D0KFe]0P1jNWX207UiN@80Ogmo0P1iNGT207IfMP80L71`0P1aLG4207IfMP80M7Ad
101fMWH207moO`80Ng]k00<0NGUi07IfMP1fMWH0201fMWH207=cL`80Jf][0P1dM7@2071`L080M7Ad
0P1cLg<2071`L0H0MWIf00<0Lg=c071`L01`L7000P1cLg<2071`L080MWIf0P1cLg<2071`L080MWIf
5@3oool001<0oooo8`1fMWH207alO080M7Ad0P1cLg<207YjNP80NGUi0P1hN7P00`1iNGT0N7Qh07Qh
N00207UiN@P0MWIf0P1cLg<2071`L0H0MWIf0P1`L70207AdM080N7Qh0P1iNGT00`1hN7P0NGUi07Ui
N@0207QhN080Ph>30P1iNGT207moO`80NGUi1P1fMWH207QhN080NGUi201fMWH307moO`80M7Ad101f
MWH2071`L080LG5a0P1bLW8208>3P`80Ogmo101`L70A07IfMP@0Ogmo0P1mOGd207UiN@H0MWIf0P1h
N7P207UiN@T0MWIf0P1lO7`207emO@80Ogmo0P1dM7@207IfMP80N7Qh0P1iNGT207=cL`80L71`101f
MWH207=cL`80L71`2@1fMWH207moO`80NGUi0P1bLW8207MgM`80LW9b0P1gMgL207IfMP80Ogmo0P1i
NGT207IfMP80Ogmo0`1dM7@<07IfMQD0oooo000C0?ooob<0MWIf0P1lO7`207AdM080Lg=c0P1jNWX2
07UiN@80N7Qh00<0NGUi07QhN01hN7P00P1iNGT807IfMP80Lg=c0P1`L70607IfMP80L71`0P1dM7@2
07QhN080NGUi00<0N7Qh07UiN@1iNGT00P1hN7P208>3P`80NGUi0P1oOgl207UiN@H0MWIf0P1hN7P2
07UiN@P0MWIf0`1oOgl207AdM0@0MWIf0P1`L702075aL@80LW9b0P23Ph<207moO`@0L71`4@1fMWH4
07moO`80OGem0P1iNGT607IfMP80N7Qh0P1iNGT907IfMP80O7al0P1mOGd207moO`80M7Ad0P1fMWH2
07QhN080NGUi0P1cLg<2071`L0@0MWIf0P1cLg<2071`L0T0MWIf0P1oOgl207UiN@80LW9b0P1gMgL2
079bLP80MgMg0P1fMWH207moO`80NGUi0P1fMWH207moO`<0M7Ad301fMWHE0?ooo`00o`3ooolQ0?oo
o`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?oo
o`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00V03oool2@000
08H0oooo002J0?ooo`03@000003oool0oooo08<0oooo001j0?ooo`E0000000@0oooo@00004000010
00000`3oool00d000000oooo0?ooo`050?ooo`=000000P3oool2@00000<0oooo0d0000050?ooo`03
@000003oool0oooo07d0oooo001l0?ooo`05@000003oool0oooo0?oood000000103oool00d000000
oooo@00000050?ooo`06@000003oool0oooo@000003ooom00000103oool014000000oooo0?oood00
00250?ooo`00O03oool00d000000oooo0?ooo`020?ooo`07@000003oool0oooo0?oood000000oooo
@00000050?ooo`05@000003oool0oooo@000003oool00d0000020?ooo`04@000003oool0oooo@000
08D0oooo001l0?ooo`03@000003oool0oooo0080oooo00M000000?ooo`3oool0oooo@000003ooom0
000000H0oooo0d000000103ooom00000@000040000030?ooo`=00000Q@3oool007`0oooo00M00000
0?ooo`3oool0oooo@000003ooom000000080oooo00=000000?oood000000203oool00d000000oooo
0?ooo`2=0?ooo`00N`3oool2@00000@0oooo00=000000?ooo`3oool00P3oool00d000000oooo0?oo
o`060?ooo`900000S`3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo
8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo
8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.0250052, -0.0250052, 
  0.00365857, 0.00365857}, {{6.8125, 280.125}, {280.125, 
  6.8125}} -> {-10.161, -6.11446, 0.516914, 0.516914}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0238095 0.952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0238095 0.97619 0.97619 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00751202 0.0192308 0.00751202 [
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(180) show
81.000000 12.812500 moveto
(deg) show
99.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(.) show
105.000000 12.812500 moveto
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
128 string
128 128 8 [128 0 0 128 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
81817F85868182807E877F867272727277737373736C837A
486D746E6F6A6F70696F706F706B6A6F6E72736F706F6F6F
71676F6F6E7474747474747471756F6F70756F6F6F6F706F
6F6F6F6F706E6F706F6F706B77847A526B6A6F706B6B6A6E
6E6E6E6E6D73736F7078737777787278736F6F69686B6B6B
62797B5E6D7B8186
81827E7C80858C887B8686958574736F73737372725F6D91
5C6E746F726A666B666A6F6F75756C6B6F706F6F6F69646A
766A696F6A696C6F6C6A6E726A74756D6A6F6F71726F706F
6F706F6F716E696A6F6F6F616181904B536F6F706B6B6767
6B7071716E6F727069716D6E6E777374746F76756F6B6F85
83707361637B7D81
7F7D7D81817B7B81817B848C9C87727272717072706F6BA6
583D6F716B68676F736F6F706F706F64667573706C6F6A65
62645F626B6F6C70736F6A6F6F696F727879787276757070
6F6F6F6F6F71756F6F706F70615B9BB95A45666B6F736F6B
6A6A656A6F767276727272767B76777274706F7072767A6B
718D776A5F718386
8383848686858A85838A817C7F95938975716F6C6F6C6169
BA6D5F6E73736B666666696F6F70706D666C6F70706F7068
6A6D6B6361696E6C6F6F6F6F6F6E71767874767A78797877
79756F707171707071706F6F706B5C76BF63537570717578
737576706E6F6F716F73777775737675707171747E85757D
6A6A806E6A7A737C
8082817D87827E847F858A8A868788908E7878757273746F
8A82627173736B6B6F7066696E6F75746F6F6B676C6B7578
7575746D67656A686162676F70706C666E6F6A6D7B747171
707772727673717276767372736F6B5C769557627275756F
6F6F71767376747772737377767A73777774718B81888880
8E727A6A62858C80
8180827F7D7F8187807B7E7C83858886978F797875767164
6EA280727478736F666F736E706B666A6A63676C6A696F6F
6F7074796F665F6A6B6D6B696F6F6F6F6A7176706C727174
71757874747676706F70716D7072736B5C998D605F6F7376
737372737675747474736E727676776F6869666E80746261
6E728276767E8483
81838C898683847B858584858581838589969C887B7C7C7B
6D788D7470797877736A6765646A675B5E67626567656F73
757675777C7870676F6669626564676E6F6D6C6D6F6B6C6C
6C6B6C6D726F6D706C6F6F6F6F6B6E6F6A5C92A17C6A6C6C
6E6E71707472727475787676766F6963565F6F7973856977
7163726D7B818388
817C7D7E85818985857B817A7B858281858587938A80807F
7E6E868D574B72716C6B6B6B6B635F67676767646761696C
6F727271757072656462676868665E5F616562696A656666
696A696A66686D6E6A656565656765696C5D5877836D6D6F
706C6D6D7274717777786F6F6A6A58576161616A4F5C6666
6B7370627A817A81
818485838985857C83848888837A8182818585858F8F928E
92968794C479656E746F6B6B68706E686E6F74797568626A
6E72727077787A716D74726970706F6B635F5A565757595A
555752565A5756565B5B5B6167676A656764594D63776547
455C65666A6C6F6D6E76776F564562666756576F796A6479
766E76737984817F
8A8287817F858A8782807A7F81837F857A7E867F88818681
7F82828185AA81565B7764626F6B6B605E5E61666C6C6569
6B707474726F70746C676F6F70707479757A7A7679707071
6E7170716D71747475747875706C75757473707463688498
7D372B5B5D6869695D3C2C2D495A6A726C6A646672786759
7B6E5F7375818888
797E7F867D7C7A8082888581878A82848581888186818582
7E8183867D84876A465860626A6A70716E65676A6C6C6668
6F6A6C6C72757577706C6F6F736F6F6F736C696C75787574
6E6F6D7478706D6C6C6F6F6F786F6C6B716B7475746A676C
77BB81754C3C43423D4F524F5752586262708069635E6E75
6F826E727C797983
8C867C8585868A847E7C878681818385807E858183858A89
85817A7F7F808A8760555E4D526B686769666A66666F6A68
6E6F6F6C6F6F6E737370676B6F6F6F6F6F73766964676B74
756E6A6764686F736E676F6F6F6C6C6B6F6A6A686F746E6B
63646487998C453346484F565152435265586951616F5667
766B957B8481827F
7B858A81817F81878A8A818385887D85898985877D818582
838184847F828A747D5655542A3465686C68686B67666769
6F6F6E6E6E736B6F6F73736F6F6F6F706F6F6F736C6C6B6C
67716E686C6C67666C6A6F706F6D6C6F71676D6B6F6B666B
6A634F47372C4F5346495253535663645F53745F5C6E646E
77698082807F8A82
8A827D82837F867F807E867F8183867F8585818285858183
87807E8587818D8C997048544A20286465635F60696D6A69
6F6F6F6F6C706F6F6F6F6C6767676A6C6B6F6F706C6C676C
6A656A6D6C6C6C6C6B676A6A666F6B6F706A6A6767686663
5B5B52423F4B535A5E58454E565E5F636A5E5E5A5A6E666E
7076837E887D7E80
7B808786817E8A85887F887D84818585817C82817F808382
8387887E818080767E6D484B453B101E57636A6B67686665
6A6F6F6F6B6B6F6F6F6F7373706F6C6C676B6F73736D6568
6D6D6D69686A6768686767716F70666973716C6A66675F62
5A5A4F454D564B4C595E564C5B5653594F5D6F7373736F60
777D82807C7E8189
827F7B7F837F807A807E898A8185817C858683887D86817F
8581838685808871818A644F4E3C2D0E20635F63626D676A
6F6F6F6F736C676B6F6C67676C65676A6F6F6F6C676F6E67
6665666F6C6A6A65636B656C676C6D6766605857524E5253
4F342B40575D49424E65726C535048565C635D6A7D6F7875
6F79768082837F86
7E8388828581828288827E818781878685888186837C8587
7D7F7B8182838B7E8572634B443A342A0A1962665E676A65
6B6C6767676F70676B706C6F706F6A666567666D70696567
66676262656964685D5E60686463625F676A615F5F564B3C
2F3643434A56655A5F585B56675E535A5B62616B556E757B
7D79767D84837F89
837B818A8586838985857F7F857D807B7D7F7F898A877E85
86827F82817F77787069524E44383834260504615C636466
656A6C6C6C6B706F6C6C6C676A6A6F6B656668646C6E6D6A
6969665F5C65666469696565685A67605E61635B54433A3A
42425458534F56565647444A4A5F695F5F666B6B6F7D8879
778A8883898A8585
7E858281858C817D818A887D7F7F88898A8A827D7D828281
8884848181888584727A554F493A34312121050963656B67
6A6A6C6C6C676F6F706C6C6C6D6C6C6D6B6C6C6767676666
67666866645F625D58625C64665F5D625B585B4B36392C34
4A4F515252555155646767646C5F62646D6A6A6B6F69707D
7F7E858281827D7F
8C85847E82818A89827E808188857A7B7E8189878185857B
80858683817F8083727155464142392A2118241A635F6A6A
6B696D706F7067676C6C69686C6A696B6967676463626767
676464625E5A5C5F5F686B53565354555447444B3A30463D
383E494F4C4C5B56616A635A6A6D616B6A6A6A7276767D88
878A828281858585
8582857C817D7F81838583838588888583827E8485818185
898285878283837D6461554F40423C3729262A1027666A6F
6F6A6970676C6C6C6C6A6E6A6666686D68696B676A65616A
6A6864626057515E6B63544F565655554E443F36564D5054
5F5B595956535253484E5B5B5054616A6A6972747D877C86
817A818982848182
8589868485827E868586858585898182818580807A85867D
81857D837F7D7C7B72594F4A4C4437302D2E2E1D14626B6A
706A666966696966696D6A686B69656A6B66646D6269645C
5F615E5C535B5B606A5A565B5B57433A373E4B41374A4B43
434F55564F434A64605D65655F6F6A6A6A6E6A727D7E7B81
8685858585838589
858185818589898585878185858588817F8A8685827E8885
8180838A88837C72635F46443938332E39392A160A676765
6C6C6A6C67686C6765656769686B6A646A6A675F625B6462
6263605B574C5A5B4D4F4948484645373E434945433C3B42
444F565452604F5B505B435A5E535E6B6B728C837D808185
89818581827D7F85
858A85867F85828182858281858589877E7E828288858681
86858585868375755B5B524947332D3137322929136C6B70
66686A6C6E69696A6A646369635E5F6162645F6563645F5C
5C57595050564E4E524F4F4C493C38453F4A595249415057
4B4A4D5766665A59515656526578707076797180807B7A7B
81858287898A8585
8582818A858282818982858585858285868285898281867E
847E7E7D81837F775D544A4441423B413A23211E0D6B6263
656A6D665C6367615F645D5D646260625B61605C5D5B605F
5B5A56594F5452463F4143423B454743413C5356504F454A
4D46465254686862566160565869687A7D87837B817D8187
8585867D7D7D7D81
858985828189868185898281858589858989858586818682
85857F848A8875645F5B4E45423639312C2123200D6D6A73
6A6666736B6366626262605D5E5F605B605E66625C585B5B
5C5B5B52564F4A44463E3E323C3A32333E4B535663554D46
3D51544F4B5E5B5A606368626169707A7972767B87848481
8281898A86848582
85858589827E85827D7F8985858281858585858285858680
7B8183827D8879615250423B363736382E2A2A2713646267
676B5F636B5F64645E5D605958595C595C5C5C5B5A5B565A
5A5350534F524A433C3D3944413739383D3D4B4F4C56544E
463B3F5B5754616F6255565A616F6F767688867D7A858681
8985858586858586
85827E81868281898A827D7F85868185827E7D7F7F828288
898981847F75786257494C483D3C3C3C241C1D25166B5F64
5F67685E64605D5F5C5C5C5D5C5350505156575C59565252
4F534F51413B3E3B3D41463C393F414443444B63676F634A
3D4449474E6160605655515B6E6E6A7D79747D8586818985
8582818589817F86
7E85898282817C7B7D858A85818382818685868585898985
82817D85817A6B5B564C3F383E3D33281F1B1F21136B626C
686464605A5F5C5F5F58595A5B5F5B565252545B5656564F
4C4B49484A3D343E3D3D412D22273548514B4846564F666E
524F4C564B4D625756565652697C7F768279827F847A7F85
8285858582878589
8985858986868A8A898585858A818181857F87818281827D
818784807A75665C49444337373536292628262817635E5D
5F635E6364605C585C5752514C49504D50564C4C56564F4F
4F4F4A4A4D333A3E3E33272B1E31493F4143414B5A645C61
5A5757515C5356564F4C5F6576707A737985827F89848185
89817F8285828185
85858281867E7D7D7E818281858A8985867C817D83858686
89818480786C595049453F413A342824232425241D63636B
6C67686468656B676465584C524C484E484852504C484E49
443F44434533303F3327262C3D343D54464D41415160555B
534C534D5C61605A6164605D748174807D7F8A8589868185
858A858985868182
7E8189807D8188858982828185817F82878681837F85867E
7D817F7E7F6E5D5346463D463C351D24282522302C6F7D75
7D7C7F7571716C6B6A6E716D534C49494A4741414A4C474B
47433E40393234332F22233831313E4B4A3D4644535C7070
66584C3D4061605162616A7C7B87837B857D818281898585
8281858585898281
89827E888C8586818589898585888189828689857E828585
818284796B5F5751483938313E2E24252C27233F5372777B
737270797A78756E6D6A686871665545444B4D4E41424B49
49453B394540463327242B35393237444642424347516263
675A4F534A54605F626457617D70737B7F8681857D7D7D7E
858582818585898A
7E85857F827D83817F85858582817F828281828581867D80
818182876E5B534B4149403A3823252B27255374747C747A
78797B7477727777726E6C6A68696F6B504242414D474546
3F3D35223D3D4237221817265238384B4D514E47575A6975
734C4E514C4E526158666E76737A7F8881898185898A8986
7E81898585828185
89828685898A85867D7D7F8589867D85867E828281898A8A
867C6E7267594D4236353C3A2C232A2D286F9C7771737B76
7D76776E7176756F7676776A67686A656B50403E3E413E40
413B302A3638325A30331C173739323D4A42574F4A4E586A
6B6E4A4A4F585B61626C5E747B797E81817F878185827E85
867E818585898585
85898585817F858A898A85858182817F8986858985858582
82817B6B63504F49423B3737282525244B4472726E707378
77787D7D786E7270706B6870706868696565644E3A403E3D
3B33332C2B5D3D512F152A3B3E6A554B574145535055505E
75664C47474B586F6E5B5273888384818781868182828585
8989828185858281
7B7F82818A85817F827E81828482837F82827D7F85807E85
817C7A6960544C42353130332122273A566C6F7974747371
6F716B6F7871726F6F75796D686B6867686B5B65473B3F38
3A332D1F1E553A415E5B2B2C2935423F47594B51494E5652
74704E4757564E505E6A7276777C7F7B8582858586828182
7E81867E81828585
848186818585877E858985898682868285898A85858C827F
7A7872695646453F3C373623262D396E7071717474716B70
666D6D666D666164696A666C68636465676864616C493138
31312628232B64365D39533E43354F41424C3E39574A604F
4F8071434350535469757C7C787F82818282818285898285
8681898982858585
8985868185858685827E7E7E85898285827D7C7D7E818988
7576665F4B483A3737372123231D577074746D6A6C6F6863
5C5857555559585A555A5D67676D6B676363626163715C3C
35302E272623486640755A5A313046564B3D4E435455555A
69706C62605752505F717A82837F827E898681857D81867E
8585858589858582
858285858582858589898685858589858684848589827E84
80746F624F46473533322924307F71767274736F6D6A6461
5F57524F4F524F5559595A5B5E6768696363625F57596046
2F2C271B1E2C3B4936385C586C41334A524E4D4F485A5B5B
4F5D8267595D625B605D8379828088828189818589858685
8582818585858589
858681858285858585858681858585858986817C7F868079
7273684D483B3D3B2C242627291D6D6C6A6C6F6F694C3537
43495050505045353835405E5E62676C68676460605B5665
3F25221A1D24295B6C40666167735C404A59413F3D564B57
635B7569615D55626F64737A7D797A83817D878281858982
8189828185828185
85868182858281858585868185827D7F8586868A81838483
7D665D50403E35303130272C73746F6F6F717359455A6074
8E6E5D677A68605C58523B405A5E6368686366675F5B5A54
663F1F1C1623151A774838534C6C655956424C514A4B5B4F
5A616F69424D555067887F8080808A818282818681827E85
8582858582828182
7E85828582858281827E85827E82847E7E817F85867F7F6D
5C544D4B373131391F2025433E767673706B6E6551545132
36444A3D2D3834394C574E353A6064676C6D68635F605D5D
5B60372914153B2A405E3A69504E897142564F463D4A5554
5357667061595353557D7D7F7E7A858A8989858982858985
8589858589898589
89858985867E8582828281868282858986848182847E8672
665A4B3A3533321F2C24355974736F6F70593F482A222A37
36302F352B24222A181F23241829516767636368635B6060
5A524D18121E24223466403156414F93825E48504E454E42
4E5E6A7E6F63665D58787B7F867C7E858281828189858585
8585858281828185
7E7E7E8189867E85868582858685827E82827E81817D8074
62493E3137302E332F326573706F7875708489836B5A4D47
4D4E58555057524E596B8C958E736267646664646A605C5B
615B5535150D182A2E3E7838504942618C5B514F4E4A4F4F
47575F7168546366787A7E787A857E7E8585898582818582
8185828585868185
89868281828589858681868189858989858386817E827B6B
58424240302F2A2B2C321E6F72726D72737A7897ADB4B0A2
B2AA95ADB8B1A8A0967B76726D6D68686B6865616365605B
5B5D5A48270D272D28263F4733462A49608162574C3D475D
5050526A72515049767C7D7E7D8989868185858589858285
8281898582858585
7E8589858985828189858681827E8185877D81857F6E6662
4F3F2F2F3022292D2B5D62767272767274726E7473757C7D
73786F6A66675F6468676B6B7370686A6B68676563606055
5456544720191D3248484B502B48534662837C5E575A473C
3B4A526A7063644B7D7976817F8585868185827E7E818985
8985858589858582
8281827E7E7E85817F8589858685828186848181898C6049
3F40362E252F2D2D2F2A72706F7571737078727470747074
6F746F6E6E706A6F6C686B6C686F716565656768635C6166
5B565B503C2A0F1E233027454537413A52645F62594E4E4D
4C4A4F5B72545B4871837572828185868182858989858281
8585827E81858589
898285868285858A828185858985898589868481706C674F
462F37282D22272F260E70706F7277777172747474727274
716E6866686460656B656D6B72627179746B656665635B5B
584E50533B1B1D22363E444A4B30303A3E457A775B4D4844
5E5154576C5B616C727E8A77858585898589828185858681
8281898985858585
8589858989858585898281858585827E7E8589827D5E5C4A
3C432E312D322D244D3F6E70707474747A78727274756F6A
685B5A53605F5A5C6466676771776F6A6B6968636360605C
62615249452F2823292D3634423A36243E6D55586555583D
4A4E59577169556F67848589858585858281898585858982
8281858281858585
7E818585858582818282818582818989857F82898461453F
302B302521292D2539707071707474747074747174747569
676A64575C5B565C5E61636865676E767071756B6863605B
5B545353442B0B111E2F333536493C3227454F6C74525C51
4A474A516E805C7C64686985858585858681858585858589
8985858681858585
898585858585898285898582858585858A85898177584032
3125292E302C21200C6E6D6D6E71737B78747671735F3F51
7C73704229374D444055626A766F70707769686866656560
5B615648473717171923283533423442233A574A695E4E41
38454F576A7D6F606F728585858585858985858585858585
8585858985858281
7E7E81827E81858985827E85828185858585827F6B4B4242
333225282C25213222727278777B6D6F7570727574959B72
737A778F8A7A7080584B5966706F6F6F6A6F787569686360
575656564C46110F151E2A332D393B2F1B26524F5B604A4E
3D4D4B4A63596D4385858281858585858281858585828185
858585827E818985
898985898985828185868281898585817F8589856E433823
282F2E2D2F211D363B70706E6F7A7E777D7776716F75767C
7C7A7C766A666167716560676F71726F786A626A6D696864
5A52544C47421215112230382E2D39342A16525B5F654A53
49464C545F6D787466858681858585858985828185898585
8585858986818585
85858582818285858285868185817F877E8182835F3D363C
302C31312B1F22417172777A78777676777A756F6D80777B
7C7772756B626263636564676F707371727776706B6A6668
685E564F473B2907131F18263C36312B422D474F53715254
4B4340465F676E8581858985858585827E81898585858585
8585858589858585
85858589858985828281867E818A828589858564463E2723
282B2F2D171C15007170706F7776777778777E7D706D7070
767A756A5F5C5F5F62666E70717078736F706F77706A6568
67645A4F4B493F0F0F19382E3735362F2A30414659756040
4543555C6962506A8281827E7E8185898681858585858585
8585828185858585
7E7E818585828189898589898281868185858674472F2930
34302D111A18230E71787D75757675757575767B75736D70
726D6A6D68626368686F6F6F6F6E707572726F6F716E6A66
6364665B4D443B111A191E282C2D3F37353A495054686E46
423F40405C8A828189858989898585858985858585828185
8585867E81858585
898985858285858585858582858285827E7E847C4232322F
2E2C2F25161B595F7171777676767A80807C76777E79736E
7E7871656863676C6B6A72747171737C7372716F71686B67
655B605A4C4245220A1A182837302E3F37334B5E595E6551
423F45496D726A8585858585858585858585858585898585
8585898985858281
7E7E7E8189858585858582827E8585868285715B3E2E3032
322E1B16115D7E72757A7C767A7C707070767575757A7D73
777B7A7668686767676A6D767D786F75777C77747878716E
6B675F675C463F3B2824312A343A38373335465F59567345
3A314B3E61877E8585858585858585828185827E81858281
8281858585858985
82858681858585858582858986818589898553373223292E
2B2F22272A166B747671767A7A7C76777B7C767676767772
777E7B7368636B6E6B6870727379777D717173777472736C
6968635B5B4E3D342B25222E2D3C3B39464C495B544F614A
373452525E79858585858585858585898585898985858982
8585858281858585
8281898585858585858985858681858582817945322A2D38
30292B1B4542757275767A7A7677777672777A807C757B77
76707173685E626A6F716F6E737176707174797473707574
6C63675F5D4D3F37241E23262C333C3E33445A5B5B586F59
4F413F4B607E858585858585858585858585828182818589
8585858985858585
89858281828185858281858589858585898270473F33252D
3222273B5172747276767070767577767272707076777770
6E7C7D7D6D655F6765686A6F736F727979736F6D6F706F6F
746C645F62594C3B322624222C3237322C31625555565A4C
3D454447547F858585858585858585858585898589858281
8585858585858585
7E81898586818281868185858585858281624933363A3930
25252663747473777676767A7C76767470686B6F73777175
7376767F71645E5B625F5F6C6E7273736E706F6E706F7170
6B6C69675C594B3F331F212526383A393C2E535B5A403F45
2D4B5B535485858585858585858585858585858582818985
8585858585858585
8985858285858681898585858585858681665F4F3338332E
242B2F1D66706A767A7C767177736E69666D6B6B6A727A72
747776796E625E5E5B6A6A6C736A6865646C6E6C6E706F72
696C6B63655A524035221620292B3C3A37365A52563E215B
3237566B6385858281858585858585858585858586818585
8585858585858585
8585858681858982818585827E7E7E858552354346353C30
1F30746363646F77707676726E6E6C7865565C686A6A6F69
6D7676726B5D5F5D5C5A636C6667625F59565353565C6767
716A6C645A564C483B3515171F2C343F372F594D41412C63
353957636D85858985858585828185858585858589858585
8281858585858585
85858589858585898582818685898985897F373C2F33351B
302A2D58505D71777676736F6049373D59504A5863737670
6F78778171625355646962655D5650423C46534E535B6A64
5C5C63636158533E363130221E252F313C33444F43482D52
34345252718B858585858585898585858585858585858585
8985858585858585
7E818585858281828189858985858585545B42352D2D312B
2C725F6C57596D72767062443B5F753A2437404A3749706E
6B777778766861584730152F4A70572F3039383839405663
6364605F5C5649483F3237211A2533323F40514F463F295E
4B4868617385858585858585858585858585858281858585
8585858585858585
89858585858985898585858281858585745E5348222B342B
150E6E6F675F77746A634D50687C4E3D2F2F364C59465761
6C777274716E564D4076424B934C3E444138474F352F4759
5D62635B60574C43372F1E0C1222372A304146443F4C3244
4254625B8585858585858585858585858281858982818585
8585858585858585
85858585858585858281858985858589DB6E372925282F3C
47286E56575B686F6553471D113E626E1619261E3C3D5669
7077797574746757423B702D1F495215123531231E303B47
4F5A5E584F564D3C36321A1315122331363C3E4D4946394A
2E4A65618585858585858585858585858985858589858585
8585858585858585
8585858585858585898585858585854F336C563D362F3238
4B3C625B5A616F6B62593440281410063E3446414F65686B
70737875726D756360453651352E06281825133933364546
4552585B4D473B3739302E1B23281F292E433E373E4D425D
3D5063798585858585858585858585858585858585858585
8281858585858585
8585858582818585828185858585856C3062442F3A372D2A
3746655B5A5F6B777E828959413C3F3A323957687373746E
77777875747979746B6A5E38366A6C5036262D3D60595359
5B5B545659493F3832363021201F1E2332474A403E544F5B
4154547E8585858585858585858585858585858585858585
8985858585858585
858585858985858589858585828185D76E38302A242A2537
4144545350597278818C96A7ACABA4A5AC99745C5C617678
72757A7D787371625C5C66887867626F7F8D907D72797A6D
635F5D505054433B3725231E202E30252A47493E4353555D
476B7E8B8585858585858585858585858585858585858585
8585858585858281
8585828185828185858585828585899C462A232122362821
2E4252524F5D6B6A737C807F878A754B312A31477377777B
7B7C767A797D7F78573C2A2E38668A908E827A766E6C6863
55474D564945483A343A221C191C16262B31433D3F535967
4B5073858585858585858585858585858585858585858585
8585858585858985
858589858589858585858589858577774D2425232D2A3637
3A3945504A4F7362606E77757049363B3F60917D7A737A7C
757C76787B747F828873412C251D3253637475726C676056
4650504D483F3F3C271F1E201D1630383D41483C384C456E
544E85858585858585858585858585858585858585858585
8585858585858585
85858585858585858585858281896C486B2C32302028302E
322D33464D52755D3D3F433A2D3E5995B8988583837F7A7F
76767575767A777A88A0AC98734B241F1F202C3935353341
5B5358574E433F37491D272E2B1F13263B3F41403D5B473C
526685858585858585858585858585858585828185858585
8585858585858585
858585858585858585858586817E8421352E3939362A2C2C
3339383E4B5A6D9990715B58769FA0837F7F7A7A7A7A7A7B
7C767A807F7D7B7A7A7A818797AAB5A589553E3E43546760
565C5C564E47473D1F34261E100F14233E3440474453484E
507A85858585858585858585858585858585898582818585
8585858585858585
85858585828185858281858985859E5E3F303C4B3E373033
37383F4441576C6F7692A0A48F76747A7A7A7A7A7A7B7B7A
7C7A7A7A76757576757A7A7678757171869BA29688736966
64584F494849464D3A2518101111152F44394A5337505847
4E8585858585858585858585858585858585858589858585
8585858585858585
85858281898585828585858585857F432D383F4A38353934
35343B4441557072737277777A807671757A7A77757A7A7A
7D717476767A7C7778777D777075706E6F6B6968685F5E5F
585B595B4D43453A4636211E19211B1F5C4132563C3C584A
5D8B85858585858585858585858585858585858585858585
8585858585858585
85858985858585898585858585859A583F3F333D423F3932
302F30403946666F726D72787174807C757A7A7F7A7A7A7A
7F807A80807676757370707774746F6F746B6E6A68686463
5F615C4E494945472D212723130E1419534B45573E2F4E45
7A8585858585858585858585858585858585858585858585
8585858585858585
8585858585828185858585858585A06F312E293437323434
36343C4D4F4F6168727473777770747F7A7A7A7772757A7A
7A7A767070767671707474726D6F706B636A6B6C68636460
58505057534541323028281912111E1A55654D5B4E2F5C52
858585858585858585858585858585858585858281858585
8585858585858585
85858585858985858585858585858D5E3C383A3E41423837
323A394A504D616972767777787B7A7772757A7C7A7A7674
7A7A7C767677787E7B787474736F6F71666564686A64625F
655B564C504D453F292E1917171215233C483D5B57454169
858585858585858585858585858585858585858985858585
8585858585858585
8585858585858585858585858585828C35353C3F35373532
403D3C414E505C666F7070737772757F7B71757F76717B77
71707777777777747378747274756F76746E6E6B6663635F
5855554F4D433F3C36251C120B0B2A2F3148495D6D7A5985
858585858585858585858585858585858585858585858585
8585858585858585
8585858585858585858585858585825949543C353C36383D
282F414B4C4F5B696D727777777A7A767A7F7A777B7C7179
7D7775777675767B777B73716F73706A6D6D64646363635F
5E595A504341352C3224130C190E203D393738554C7E7285
858585858585858585858585858585858585858585858585
8585858585858585
85858281828185858585858585857EE96F34322F2F2F332F
403A3C4759595D696F75777676757A7D7577757C71767B77
767677777878767677717677726F6F716770686863636763
635957474645483F262214121714223E42413C595F5F8585
858585858585858585858585858585858585858585858585
8585858585858585
8585898589858585858585858585859C6638322D2F302A31
363F464D525D6069706D6F777672727771797A7F807B7079
7D7877777777787771747474757475776F746C68635F5E63
64585452503D34262016170C11122244393B3F6477678585
858585858585858585858585858585858585858585858585
8585858585858585
8585858585858585858585858585857EBB5936363233362F
2D363C484E5A636A6E77737775797B79807A7A7A767A7D71
797B7676767777777B777871746D6F706F6C686964675E5F
5758594A474C3E2A2119191315172155424242587B858281
858585858585858585858585858585858585858585858585
8585858585858585
85828185858585858585858585858585B170322A2D2F3135
313445515A5D656F6A6D6E74787278727577757677727677
71767678777676777870727573726F706B6F6E6F6863645B
6055504F433A3429211C161D1D1218404F4A586267858985
858585858585858585858585858585858585858585858585
8585858585858585
858985858585858585858585858585858981503935373132
383837435769666A73757777777675797A7B717876757675
777876767778777474747470706F6E6F706A676565636465
5B564D4A413A2F27241E171A110C1A374142536B7E858585
858585858585858585858585858585858585858585858585
8585858585858585
8585858585858585858585858585858585E9BC724B46483A
3337474749556B6F6A6E6F6E72767670717876797D777778
7777757374707074777573716E6F6F68696B6B6668635D5D
58504A483F342C30232119100A22354A484C535682818585
858585858585858585858585858585858585858585858585
8585858585858585
858281858585858585858582818585858582C1DB7041353B
3D36384A5253606F6F6E7577787573767677787277787676
77777B777874747774736A7070706F736965686D63605B55
59544C3731352F21241A1C100B33423E40465F6889858585
858585858585858585858585858585858585858585858585
8585858585858585
85898585858585858585858985858585857E7E94A141372F
343A3E44525A5D64676A6E6E6C7171747777747377777573
726E6F6F747472696A6F6F6F6F706E6D6968686464685B66
594741403C363D261F1D110C4E4B3E3E43646C7A827E8185
858585858585858585858585858585858585858585858585
8585858585858585
8585858585858585858585858585858585858582AE3F294B
3B4247484E5761706E6F69707677786F7274777777777B74
7577796F6E6F70756F6F6F706F6F6A6D6C67636360565453
534C48443B2D2B4A1E101539243745484A57678186898B85
858585858585858585858585858585858585858585858585
8585858585858585
858585858585858585858585858585858585858280723A27
383C4748525A5C5E6A706F6C6C6D76737074707070707375
6E686A6F64676A6E6E6F6E6F706F6D6268646363615E4E4C
45403B333537341E332D342640434F585D5D5E898F7E8585
858585858585858585858585858585858585858585858585
8585858585858585
858585858585858585858585858585858585858284743C2D
302B3640474A5961616A6867736B736E6B6C707477746A71
6D6F6860665F676F6C656464605F6360605F5A5751545050
4B4948352D2B2A2B272240563C3F4D5F5B87857E82818589
8B85858585858585858585858585858585898B8585858585
8585858585858585
858585858585858585858585858585858585857EAF963921
3837364247555C5F5F6069656D6A6A72736D6A6A676E6B6F
6C64636161635F5D5C5F5C5B5A5F615C5E5E59585A4D4A4C
4D423939373440413246414C475853766959818589898B7E
85858585858585858585858281858585857E858585858585
8585858585858585
858585858585858585858585858585858585858597757745
2F4138363C3E4F64675F645F66716F6C6E69656565635B56
595E5D58554E4D51525351554D464E4A4E48484A50504A3D
353B46383E482D3549413840494D4F6284838585857E8585
858585858585858585858589858585858585858585858585
8585858585858585
858585858585858585858585858585858585858585C1A362
3D343E444D423B3B526368736E69656566635B565565665C
5B5A554F4E4B4C514A474640463E4548444A4A4148575458
564C403F3E4A4623233F53554A6563636085858585858582
8185858585858585858585858585858585898B8585858585
8585858585858585
85858585858585858585858585858585858585858585BDDD
8E5036343E393C555C72736E6B6B665E575B5C5F5A525E5D
554B51484D484D3A48454535444540423D414247342C383B
403E474833293D514C4142526B6B596D8585858281858589
85858585858585858585858585828185857E858585858585
8585858585858585
858585858585858281828185858585858585858585858590
7F5257474B716C5D5152515C6661615E5F5D544E5959504F
584F4C4A42474D57534755553B524D514E474B51453A4447
403E473E45413E3B3D4968725F5C7D698585858D8B858585
858585858585858585858585858985858585858585858585
8585858585858585
858582818585858985898585858585858585858585858585
DE72464937313E49445D66605B5C5D5C5353544C474C504C
4D524D3D4832403F4B493C474D4844343E49493942352A24
272F2B2D2C303346586A6E62584D4C858585857E85858585
858585858585858585858585858585858585858585858585
8585858585858585
858589858585858585858585858585858585858585858585
7EF28E554F5561666B6866685E53505954545D545147524D
463C3B444D44243230424B47472E3D442C1A2A3531373D45
473E41373B45656E6169363A436E6B8B8585858585858281
858585858585858585858585858585858585858585858585
8585858585858585
858585858585858585858585858585858585858585858585
857E925D3B2B2F31415B62636A58504C505050474B514448
523E544F3754542D4736323530362D203236353532393630
28303F5A5C674D6A70485447564B7E858585828185828585
858585858585858585858585828185898B85858585858585
8585858585858585
858585858585858585858585858585858585858585858585
8585C657425B5C48414D605E5F4E42484B545145444A4C4B
4A583035472D47402E3B3633372F3137322D222D332E2F32
3C494A42424669412D4661598B777E818582858582858589
8B858585898B8585858585858985857E8585858585858585
8585858585858585
858585858585858585858585858585858585858585858585
85857EFF78243A5F5C4C526D695A4A4C3C4146444149443B
413E403C43422C2A3C37313234342C2A22202625252D3F3E
37405D667C78585E444D3C5E89948C81858985858985857E
858585857E85858585858585858585858585858585858585
8585858585858585
858585858585858585858585858585858585858585858585
85858281EA932420384B4F67695B384B514B5C5C40404E3A
41474639494849261932473C31252E2C27201F1D1C232B4C
645649644D2E2C4557355E547E7E8985858281898B858585
8585858585858582818585858585858585898B8585858585
8585858585858585
858585858582818585858585858585858585858585858585
858589857EC06B302A36414E666547365041343E43313A48
39374B453741495545301F35363A373948443B425054534D
557C6B474A332F415366758585858585898F827A85858585
898B85858585858985898B8585858585857E858585858585
8585858585858585
858585858589858585858585858585858585858585858585
8585858585A2C16F4930252A376A543437504A3A36312B31
383B3B3A3A3D4E4C47404D3A324146423746515A67625D6A
6542514438494F4D41778B89908B828582858F8281898B85
7E85858585858585857E85858585898B8585858585858585
8585858585858585
858585858585858585858585858585858585858585858585
8585898B8585AEA459484A444A417D53373D5247523F3433
3C3F403741434953526B473E3A3A45545C5D5963646C4E2E
382C1F1E464E43509D85857E82908F7E8D858589857E8585
85858585858585858585858585857E858585858585858585
8585858585858585
858585858585858585858585858585858585858585858585
85857C81858281BDB3503A46535258825B433A4742534B37
2A262C393443475C718F9D888B837E738593856A53323E3E
31334153584E49758585898B7E7E85857E8582818589908B
858585858585858585858585858585858585858585858585
8585858585858585
858585858585858585858585858585858585858585858585
858589858589898BB4EF7F3F2C305369875E604F574D5D81
6940373734525B653B426D7C73888E7F533F443C40453B30
2F404C4E4853967E85827A85827E818585828585857E7E85
828185858585858585858585858585858585858585858585
8585858585858585
858585858585858585858585858585858585858585858585
858585858585828B858AE47F443936486D8671827D8E8A6A
90CDD5EEC69F8D87927772737261414051413C423D38324A
60554F3F89D6858989858585898681858589828185898B85
8681858281898B8585858585858585858585858585858585
8585858585858585
8585858585858585858585858585858585858585898B8585
858585858585828B85857EE3E058313640647C7F8D717988
736C555F69717F8B77766A504B5C615248423A354953706A
5B4F5DA67E82817C858585858589858281858985857E8585
89858589857E8585858585858585898B85898B8281858585
8585858585858585
85858585858585858585858585858585858585857E858585
85858585898B82908B898B859CEF7F433E465755626B757C
7580868882757477736771693F4F47374649464B6066584C
578CAE858586818985898B898B8582858585858585858585
898B858585858585898B858585898585857E898F85858585
8585858585858585
858585858585858585858585858585858585858585858585
858585857E857E7E857E85827A94E2DE8839314366737575
726A626D68614E463C4650605535405861608A786D55579C
C39785858589898B857E857C81858D8B898B85858281898B
7E858585898B85857E858585857E85858990898981858585
8585898B85858585
85858585858585858585858585858585858585898B858585
85858585858585858582858F85828B85CEE3DC783F3E5156
6980757C8086827D745C50618C8D7D858F624C548AD2C994
8B8585898B857E8585898B8985857E857C81858589857E85
898B89908990908B85858585898B85858289858D8B858585
85857E8585858585
858585858585858585858585858585858585827A85858585
858585858585858585897E85857E8585898B89CECE835659
504C616A717A8F9EB0A19A85778F6547517FA7A490828982
8185857E85858582817E8281858582818985858585858281
7E857E7E7E7E7C81898981857E8585827A7E857E82818585
8585858585858585
85858585858585858585858585858585858589898B858585
858585858585858585858585858281858289788185BDBFA7
B9A28F8A828D7055516171696B6F9AB9B2A490858582898F
8990908B85858589827E8585858589858281898981858989
8B858585858589857E8D8B898B858589858585858D8B8585
85858585898B8585
858585858585858585858585858585858585857E82818585
858585858585858589898185858982817E89898585858989
8D9690978A91A0A7A79DA4ADA7A290898589908B857E828B
7E7E7E8281898B858D8F8585898B898B8D8B7C858582817E
8585858585858585857C817E898B858585898B857E858585
858585857E858585
858585858585858585858585858585858585858589858585
85858585858585857E8985858582858582858B8585828182
7A858989818589898989828B85828185857E7E85898B828B
858582898B82908B7E8585857E857E858289828182858585
8585858585898B8585898585828B8585827A89908B858585
85858585898B8281
858585858585858585858585858585858585858585898B85
85858585858585858585858585898589948585858285858D
8B857E8D8B85898B85857C81858985858582818985858290
8B85897C817E7C81898B858585898B857E89898589858589
8981858585828B85898B85827A85858589857C7E8B858585
858585857E858D8B
8585858585858585858585858585858585898B85827A8582
818585858585858585858582858B857E7C81858589828582
818585828B857E898B828585828185858589857E85857E82
8B858285898B89857C85908B857C858B858585898B858582
8F8585898B7E898B7E89908F85898B858582857E85858585
8585898B85857E85
85858585858585858585858585858585857E85858985898F
8585858585858585858585897E8585858985858585867A89
8589897A898B857E858D8B898F85858585858281898B857E
858589857E858585897E7C8185897E8585828582858B8582
8B85827A85857E85857E7E85857E85828189858585858585
85827E8B85858585
8585858585858585858585858585858585858585898B7E85
858585858585858585858281858585858585858585867E81
857E89827E908B858982817E858585898B8282817E898981
898B898B85898B898B85898585898B8585897E867A898B7E
85898F8585898B898B8589898185858985898B85898B8585
85897E858585827E
85858585858585858585858585858585858585857E85898B
8585858585858585858589898B8582818281858585898989
8B8585897E7E85827E8F85858585857E85898985827A8D8B
828B7E85827E897E8B858582817E85858585858989827E81
857E8281857E85828B857E89858585898B7E85857E858585
8585858582818D8F
858585858585858585858585858585858585858585857E82
818585858585858582858B7E828189828281858589908B7E
85828185858582857E898B82858B85858585898B8D8B7C85
85828182857E8D85858281898989858B82818285858D8F85
858285858585857E858585858585857E8582818585858585
8585858589857E85
858585858585858585858585858585858585858585858589
8585858585858585897E85858D8B898F8685908B7C7E8B85
8589858585858D908B7E8589828B858585857E898585897E
858D9094908B7E858586818985897E8994909485857E8585
858D908B85858582818585858585898B858985898B858585
898B898B85898B85
858585858585858585858585858585858585898B898B8582
81828185858585898B8585857E857C81867A7C81897E8585
8585828185857E7E85898B857E8589898189908585858585
857E7E7E7E85898B8589857E8281857E7E7E7E898B898B85
827A828B8585898F8585858585857E828182817E85858585
7E857E85857E8585
858585858585858585858585858585858585828B7E898B89
858985858585857E8585858582818985898589898B898B85
858589858585858589898B8585827A898989858585858585
85858585858989908B858585898585858585858290898B85
89857E8585857E858585858585898B8681868185898B8589
8981858585858585
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[40]:=",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`004`3oool40861P@80Ogmo0P25QHD208J6QP80PH61
0P22PX820820P00307inOP27QhL0QhN70080Ogmo0P26QXH8079bLP80MgMg201cLg<206a/K080Ph>3
0P1jNWX00`18B4P0KFe]06e]K@0207AdM080KVi^0P1_Kfl206YZJP80Kfm_0P1`L70206UYJ@80Kfm_
0P1`L70206m_K`80L71`0P1[Jf/206YZJP80Kfm_00<0KVi^079bLP1bLW800P1cLg<206m_K`80L71`
1P1_Kfl2075aL@80IfMW101_Kfl206i^KPd0M7Ad0P1aLG4207EeM@@0Kfm_0P1`L70207EeM@P0Kfm_
0P1`L70906m_K`80L71`0P1^KVh206m_K`80L71`101_Kfl2071`L080Jf][0P1gMgL208B4Q080NWYj
0P1BDU800`1[Jf/0JVYZ06YZJP0206m_K`80L71`101[Jf/206YZJPX0KVi^0P1]KFd407=cL`80Kfm_
00<0L71`07QhN01hN7P00P1cLg<407MgM`80N7Qh0P1bLW8207QhN080Lg=c101_Kfl206UYJ@80J6QX
1P1[Jf/00`1RHV80NGUi07UiN@0207]kN`80GUiN0P1]KFd207]kN`80PH610P26QXHE0?ooo`004`3o
ool40861P@80Ogmo0P25QHD208J6QP80PH610P22PX820820P00307inOP27QhL0QhN70080Ogmo0P26
QXH8079bLP80MgMg201cLg<206a/K080Ph>30P1jNWX00`18B4P0KFe]06e]K@0207AdM080KVi^0P1_
Kfl206YZJP80Kfm_0P1`L70206UYJ@80Kfm_0P1`L70206m_K`80L71`0P1[Jf/206YZJP80Kfm_00<0
KVi^079bLP1bLW800P1cLg<206m_K`80L71`1P1_Kfl2075aL@80IfMW101_Kfl206i^KPd0M7Ad0P1a
LG4207EeM@@0Kfm_0P1`L70207EeM@P0Kfm_0P1`L70906m_K`80L71`0P1^KVh206m_K`80L71`101_
Kfl2071`L080Jf][0P1gMgL208B4Q080NWYj0P1BDU800`1[Jf/0JVYZ06YZJP0206m_K`80L71`101[
Jf/206YZJPX0KVi^0P1]KFd407=cL`80Kfm_00<0L71`07QhN01hN7P00P1cLg<407MgM`80N7Qh0P1b
LW8207QhN080Lg=c101_Kfl206UYJ@80J6QX1P1[Jf/00`1RHV80NGUi07UiN@0207]kN`80GUiN0P1]
KFd207]kN`80PH610P26QXHE0?ooo`004`3oool20861P@80PX:20P1nOWh207alO080P8200P25QHD2
08b<S080R8R800<0Ng]k08J6QP26QXH00P26QXH209FEU@80QHF50P1dM7@207=cL`80Kfm_1P1cLg<4
079bLP80GemO0P1]KFd2096AT@0305aLG01^KVh0KVi^0080M7Ad0P1_Kfl2079bLP80JVYZ0P1VIVH2
06][J`80IVIV0P1ZJVX406m_K`@0MGEe0P1/K6`206][J`0306m_K`1`L700L71`00H0Kfm_0P1YJFT2
06ATI080JVYZ0P1fMWH206YZJP80JFUY0P1_Kfl206YZJP80JFUY0P1/K6`206m_K`0306a/K01ZJVX0
JVYZ0080KVi^0P1bLW8206YZJP80M7Ad0P1eMGD206e]K@80JVYZ101_Kfl2075aL@80LW9b0P1_Kfl2
071`L0<0Kfm_0P1`L70406m_K`80LG5a0P1^KVh206UYJ@80JVYZ1P1_Kfl4065QH@80PH610P2@T902
04];B`0305=CD`1_Kfl0Kfm_0080Kfm_0P1`L70406][J`@0IfMW0P1[Jf/2071`L0@0LG5a0P1^KVh2
06m_K`80LW9b0P1`L7000`1YJFT0LG5a075aL@0206e]K@@0KVi^0P1gMgL207=cL`@0M7Ad0P1_Kfl2
07IfMP80MGEe0P1_Kfl206][J`80Kfm_0P25QHD00`23Ph<0L71`071`L00207=cL`80HF5Q0P1SHf<2
07]kN`80OGem0P21PH4E0?ooo`004`3oool20861P@80PX:20P1nOWh207alO080P8200P25QHD208b<
S080R8R800<0Ng]k08J6QP26QXH00P26QXH209FEU@80QHF50P1dM7@207=cL`80Kfm_1P1cLg<4079b
LP80GemO0P1]KFd2096AT@0305aLG01^KVh0KVi^0080M7Ad0P1_Kfl2079bLP80JVYZ0P1VIVH206][
J`80IVIV0P1ZJVX406m_K`@0MGEe0P1/K6`206][J`0306m_K`1`L700L71`00H0Kfm_0P1YJFT206AT
I080JVYZ0P1fMWH206YZJP80JFUY0P1_Kfl206YZJP80JFUY0P1/K6`206m_K`0306a/K01ZJVX0JVYZ
0080KVi^0P1bLW8206YZJP80M7Ad0P1eMGD206e]K@80JVYZ101_Kfl2075aL@80LW9b0P1_Kfl2071`
L0<0Kfm_0P1`L70406m_K`80LG5a0P1^KVh206UYJ@80JVYZ1P1_Kfl4065QH@80PH610P2@T90204];
B`0305=CD`1_Kfl0Kfm_0080Kfm_0P1`L70406][J`@0IfMW0P1[Jf/2071`L0@0LG5a0P1^KVh206m_
K`80LW9b0P1`L7000`1YJFT0LG5a075aL@0206e]K@@0KVi^0P1gMgL207=cL`@0M7Ad0P1_Kfl207If
MP80MGEe0P1_Kfl206][J`80Kfm_0P25QHD00`23Ph<0L71`071`L00207=cL`80HF5Q0P1SHf<207]k
N`80OGem0P21PH4E0?ooo`004`3oool207moO`@0OGem1021PH4407]kN`<0PH610P1kNg/208B4Q080
S8b<0P2LW9`208N7Q`H0LW9b0P1aLG42071`L080LW9b0P1`L70206m_K`80Jf][0P2VYZH00`1HF5P0
?Cdm03dm?@0206m_K`80LG5a0P1[Jf/206QXJ080IfMW0P1_Kfl207=cL`@0Kfm_0P1`L70206m_K`80
L71`0P1_Kfl206ATI00306IVIP1eMGD0MGEe0080Lg=c0P1`L70206a/K080Kfm_0P1ZJVX206EUI@80
HV9R0P1TI6@205mOG`80HV9R0P1[Jf/206m_K`80K6a/0P1`L7000`1cLg<0Kfm_06m_K`0206YZJP@0
Kfm_0P1YJFT206m_K`80LW9b0P1hN7P207UiN@80N7Qh0P1bLW8207IfMP80MGEe101`L70906m_K`80
LG5a0P1eMGD406m_K`80L71`0P1_Kfl2071`L080HF5Q0P1KFe/209^KV`80^KVi00<0FUYJ04E5A@15
ADD00P1VIVH206][J`80Kfm_0P1cLg<206m_K`80Jf][101ZJVX206EUI@80JVYZ0P1_Kfl207IfMP80
LW9b0P1fMWH5079bLP80MWIf0P1kNg/207IfMP80MgMg0P1bLW8207AdM080L71`0P1_Kfl2071`L080
LW9b0P1fMWH207YjNP80Jf][00<0LG5a08f=S@2=SHd00P1gMgL206YZJP80GemO0P1aLG4208>3P`80
QXJ65@3oool001<0oooo0P1oOgl407emO@@0PH61101kNg/30861P@80Ng]k0P24Q8@208b<S080W9bL
0P27QhL6079bLP80LG5a0P1`L702079bLP80L71`0P1_Kfl206][J`80YZJV00<0F5QH03dm?@0m?Cd0
0P1_Kfl2075aL@80Jf][0P1XJ6P206MWI`80Kfm_0P1cLg<406m_K`80L71`0P1_Kfl2071`L080Kfm_
0P1TI6@00`1VIVH0MGEe07EeM@0207=cL`80L71`0P1/K6`206m_K`80JVYZ0P1UIFD2069RHP80I6AT
0P1OGel2069RHP80Jf][0P1_Kfl206a/K080L71`00<0Lg=c06m_K`1_Kfl00P1ZJVX406m_K`80JFUY
0P1_Kfl2079bLP80N7Qh0P1iNGT207QhN080LW9b0P1fMWH207EeM@@0L71`2@1_Kfl2075aL@80MGEe
101_Kfl2071`L080Kfm_0P1`L702065QH@80Fe]K0P2KVi/20;Vi^@0305YJFP15ADD0ADE50080IVIV
0P1[Jf/206m_K`80Lg=c0P1_Kfl206][J`@0JVYZ0P1UIFD206YZJP80Kfm_0P1fMWH2079bLP80MWIf
1@1bLW8207IfMP80Ng]k0P1fMWH207MgM`80LW9b0P1dM7@2071`L080Kfm_0P1`L702079bLP80MWIf
0P1jNWX206][J`03075aL@2=SHd0SHf=0080MgMg0P1ZJVX205mOG`80LG5a0P23Ph<208J6QQD0oooo
000C0?ooo`@0Ph>30P24Q8@408J6QP80QHF50P2:RXX208F5Q@0308>3P`2:RXX0RXZ:0080PH610P1l
O7`207moO`80UIFE0P2CTi<208V9R@80MGEe0P1aLG4206m_K`80K6a/0P1_Kfl206a/K080HF5Q0P1Y
JFT00`2j^[X0KFe]06e]K@0205mOG`80KVi^101cLg<206][J`H0IVIV0P1YJFT406m_K`@0L71`0P1]
KFd00`1VIVH0K6a/06a/K00206m_K`@0L71`0P1_Kfl2071`L080J6QX0P1ZJVX206e]K@80Jf][0P1S
Hf<2065QH@80JFUY0P1^KVh206a/K0T0Kfm_0P1^KVh2075aL@80MWIf0P1hN7P207AdM080MWIf0P1j
NWX207QhN080NGUi0P1hN7P207MgM`0307UiN@1eMGD0MGEe0080Kfm_0P1`L704075aL@@0L71`0P1a
LG42071`L0@0Kfm_0P1`L70206][J`80G5aL0P1fMWH00`2o_kl0Hf=S06=SH`0205=CD`80MGEe0P1`
L702075aL@80MGEe0P1hN7P207=cL`80MGEe0P1fMWH2071`L080KVi^101_Kfl2075aL@0306m_K`1c
Lg<0Lg=c00@0MgMg0P1eMGD207=cL`80MWIf0P1eMGD2071`L0@0LG5a0P1dM7@207inOP80QHF50P1e
MGD207emO@<0JVYZ0P20P80206i^KP80JVYZ0P1jNWX207=cL`80O7al5@3oool001<0oooo1023Ph<2
08B4Q0@0QXJ60P25QHD208Z:RP80QHF500<0Ph>308Z:RP2:RXX00P21PH4207alO080Ogmo0P2EUID2
09>CT`80RHV90P1eMGD2075aL@80Kfm_0P1/K6`206m_K`80K6a/0P1QHF4206UYJ@030;Zj^P1]KFd0
KFe]0080GemO0P1^KVh407=cL`80Jf][1P1VIVH206UYJ@@0Kfm_101`L70206e]K@0306IVIP1/K6`0
K6a/0080Kfm_101`L70206m_K`80L71`0P1XJ6P206YZJP80KFe]0P1[Jf/206=SH`80HF5Q0P1YJFT2
06i^KP80K6a/2@1_Kfl206i^KP80LG5a0P1fMWH207QhN080M7Ad0P1fMWH207YjNP80N7Qh0P1iNGT2
07QhN080MgMg00<0NGUi07EeM@1eMGD00P1_Kfl2071`L0@0LG5a101`L702075aL@80L71`101_Kfl2
071`L080Jf][0P1LG5`207IfMP030;no_`1SHf<0Hf=S0080De=C0P1eMGD2071`L080LG5a0P1eMGD2
07QhN080Lg=c0P1eMGD207IfMP80L71`0P1^KVh406m_K`80LG5a00<0Kfm_07=cL`1cLg<0101gMgL2
07EeM@80Lg=c0P1fMWH207EeM@80L71`101aLG4207AdM080OWin0P25QHD207EeM@80OGem0`1ZJVX2
0820P080KVi^0P1ZJVX207YjNP80Lg=c0P1lO7`E0?ooo`004`3oool20820P080PX:20P21PH4207em
O@80QhN70P22PX8207inOP80Q8B400<0Ogmo08F5Q@25QHD0102:RXX208J6QP80QhN70P28R8P2092@
T080SXj>101hN7P207EeM@80LW9b0P1cLg<207AdM080Kfm_00<0RXZ:08:2PP22PX800P1RHV82075a
L@@0Lg=c101[Jf/206m_K`80L71`0P1VIVH206UYJ@80KVi^0P1_Kfl207EeM@80M7Ad0`1_Kfl206][
J`80IfMW0P1/K6`206][J`80MGEe0P1hN7P407EeM@80M7Ad0P1]KFd206MWI`80IFEU0P1ZJVX206QX
J003065QH@1RHV80HV9R0080IfMW0P1_Kfl4071`L080K6a/0P1VIVH206i^KP80Kfm_0P1ZJVX206e]
K@80Ng]k0P1dM7@4075aL@03071`L01gMgL0MgMg00@0LW9b0P1fMWH207=cL`80LG5a0P1bLW8407If
MP80Lg=c0P1bLW8207=cL`80Kfm_0P1[Jf/205aLG00307IfMP2EUID0UIFE0080EeMG0P1RHV82079b
LP@0MGEe1P1_Kfl2075aL@80MWIf0P1cLg<207IfMP80M7Ad0P1gMgL00`1bLW80Lg=c07=cL`0207=c
L`80MgMg0P1fMWH207YjNP80Lg=c101gMgL207AdM080LG5a0P2;Rh/20861P@@0R8R80P20P8000`2>
SXh0LW9b079bLP0207YjNP80JVYZ0P1RHV8208F5Q@80S8b<0P20P80E0?ooo`004`3oool20820P080
PX:20P21PH4207emO@80QhN70P22PX8207inOP80Q8B400<0Ogmo08F5Q@25QHD0102:RXX208J6QP80
QhN70P28R8P2092@T080SXj>101hN7P207EeM@80LW9b0P1cLg<207AdM080Kfm_00<0RXZ:08:2PP22
PX800P1RHV82075aL@@0Lg=c101[Jf/206m_K`80L71`0P1VIVH206UYJ@80KVi^0P1_Kfl207EeM@80
M7Ad0`1_Kfl206][J`80IfMW0P1/K6`206][J`80MGEe0P1hN7P407EeM@80M7Ad0P1]KFd206MWI`80
IFEU0P1ZJVX206QXJ003065QH@1RHV80HV9R0080IfMW0P1_Kfl4071`L080K6a/0P1VIVH206i^KP80
Kfm_0P1ZJVX206e]K@80Ng]k0P1dM7@4075aL@03071`L01gMgL0MgMg00@0LW9b0P1fMWH207=cL`80
LG5a0P1bLW8407IfMP80Lg=c0P1bLW8207=cL`80Kfm_0P1[Jf/205aLG00307IfMP2EUID0UIFE0080
EeMG0P1RHV82079bLP@0MGEe1P1_Kfl2075aL@80MWIf0P1cLg<207IfMP80M7Ad0P1gMgL00`1bLW80
Lg=c07=cL`0207=cL`80MgMg0P1fMWH207YjNP80Lg=c101gMgL207AdM080LG5a0P2;Rh/20861P@@0
R8R80P20P8000`2>SXh0LW9b079bLP0207YjNP80JVYZ0P1RHV8208F5Q@80S8b<0P20P80E0?ooo`00
4`3oool20861P@80P8200P22PX8207moO`80OGem0P1oOgl20861P@80QhN700<0P82007]kN`1kNg/0
0P1nOWh207alO080Ph>30P25QHD208R8R080QXJ60P2GUiL208n?S`80NGUi0P1hN7P207EeM@80MWIf
0P1aLG4206ATI00306i^KP2RXZ80XZ:R0080P8200P1bLW8207AdM080N7Qh0P1cLg<206m_K`80IVIV
0P1_Kfl207=cL`80KVi^0P1`L70206][J`80IVIV0`1ZJVX206=SH`80IfMW0P1/K6`206YZJP80JFUY
1P1_Kfl2071`L080M7Ad0P1iNGT206m_K`80IVIV0P1OGel206YZJP0306][J`1]KFd0KFe]0080Jf][
0P1YJFT806m_K`80JVYZ0P1aLG4207IfMP80L71`0P1/K6`2079bLP80LG5a0P1dM7@00`1aLG40MGEe
07EeM@0207QhN0@0M7Ad101fMWH2071`L080Kfm_0P1`L702075aL@80KFe]0P1`L702079bLP80Lg=c
0P1[Jf/00`1LG5`0VIVI09VIV@0208f=S@80H61P0P1OGel206m_K`80Lg=c0P1fMWH407=cL`80LW9b
0P1cLg<207IfMP80MGEe1@1dM7@207=cL`80KVi^0P1bLW8407IfMP80MgMg0P1_Kfl206QXJ080JFUY
0P1VIVH206i^KP80P8200P1dM7@2069RHP80HF5Q00<0KVi^079bLP1bLW800P22PX8407IfMP80OWin
0P24Q8@208>3PaD0oooo000C0?ooo`80PH610P20P80208:2PP80Ogmo0P1mOGd207moO`80PH610P27
QhL00`20P800Ng]k07]kN`0207inOP80O7al0P23Ph<208F5Q@80R8R80P26QXH209NGU`80Shn?0P1i
NGT207QhN080MGEe0P1fMWH2075aL@80I6AT00<0KVi^0::RXP2RXZ800P20P802079bLP80M7Ad0P1h
N7P207=cL`80Kfm_0P1VIVH206m_K`80Lg=c0P1^KVh2071`L080Jf][0P1VIVH306YZJP80Hf=S0P1W
IfL206a/K080JVYZ0P1YJFT606m_K`80L71`0P1dM7@207UiN@80Kfm_0P1VIVH205mOG`80JVYZ00<0
Jf][06e]K@1]KFd00P1[Jf/206UYJ@P0Kfm_0P1ZJVX2075aL@80MWIf0P1`L70206a/K080LW9b0P1a
LG4207AdM003075aL@1eMGD0MGEe0080N7Qh101dM7@407IfMP80L71`0P1_Kfl2071`L080LG5a0P1]
KFd2071`L080LW9b0P1cLg<206][J`0305aLG02IVIT0VIVI0080SHf=0P1PH60205mOG`80Kfm_0P1c
Lg<207IfMP@0Lg=c0P1bLW8207=cL`80MWIf0P1eMGD507AdM080Lg=c0P1^KVh2079bLP@0MWIf0P1g
MgL206m_K`80J6QX0P1YJFT206IVIP80KVi^0P20P80207AdM080HV9R0P1QHF400`1^KVh0LW9b079b
LP0208:2PP@0MWIf0P1nOWh208B4Q080Ph>35@3oool001<0oooo0P21PH4208>3P`80S8b<0P29RHT2
08J6QP80Ph>30P24Q8@207]kN`<0QHF50P24Q8@408F5Q@80PH610P23Ph<208F5Q@80RHV90P2FUYH2
09bLW080R8R80P1kNg/407alO080Ng]k00<0KFe]07QhN01hN7P00P2=SHd207AdM080L71`0P1iNGT2
07QhN080MgMg0P1cLg<206YZJP80IfMW0P1UIFD206ATI080JVYZ0P1WIfL205]KF`0305iNGP1WIfL0
IfMW0080HV9R0P1UIFD206MWI`80IFEU0P1_Kfl207=cL`80MGEe0P1fMWH207EeM@80MgMg0P1lO7`2
07QhN080L71`0P1WIfL00`1_Kfl0IVIV06IVIP0206UYJ@80HV9R0P1UIFD206ATI080IfMW0P1^KVh2
06m_K`80KFe]0P1/K6`206e]K@80Kfm_0P1[Jf/506a/K080Jf][0P1/K6`206e]K@80LW9b0P1_Kfl2
06e]K@80L71`0P1/K6`806m_K`80Jf][0P1^KVh206m_K`0306YZJP1LG5`0G5aL0080TY:B0P2QXJ42
07alO080JVYZ101/K6`406i^KP80LG5a0P1`L70207AdM0@0LW9b0P1dM7@00`1eMGD0N7Qh07QhN006
07IfMP80Kfm_0P1YJFT206=SH`80EUIF0P1OGel206m_K`80NGUi0P1cLg<208F5Q@80JFUY0P1gMgL0
0`1aLG40Hf=S06=SH`02079bLP80KFe]0P1kNg/20861P@80Ph>30P28R8PE0?ooo`004`3oool20861
P@80Ph>30P2<S8`208V9R@80QXJ60P23Ph<208B4Q080Ng]k0`25QHD208B4Q0@0QHF50P21PH4208>3
P`80QHF50P29RHT209JFUP80W9bL0P28R8P207]kN`@0O7al0P1kNg/00`1]KFd0N7Qh07QhN00208f=
S@80M7Ad0P1`L70207UiN@80N7Qh0P1gMgL207=cL`80JVYZ0P1WIfL206EUI@80I6AT0P1ZJVX206MW
I`80Fe]K00<0GUiN06MWI`1WIfL00P1RHV8206EUI@80IfMW0P1UIFD206m_K`80Lg=c0P1eMGD207If
MP80MGEe0P1gMgL207alO080N7Qh0P1`L70206MWI`0306m_K`1VIVH0IVIV0080JFUY0P1RHV8206EU
I@80I6AT0P1WIfL206i^KP80Kfm_0P1]KFd206a/K080KFe]0P1_Kfl206][J`D0K6a/0P1[Jf/206a/
K080KFe]0P1bLW8206m_K`80KFe]0P1`L70206a/K0P0Kfm_0P1[Jf/206i^KP80Kfm_00<0JVYZ05aL
G01LG5`00P2BTY820:6QX@80O7al0P1ZJVX406a/K0@0KVi^0P1aLG42071`L080M7Ad101bLW8207Ad
M00307EeM@1hN7P0N7Qh00H0MWIf0P1_Kfl206UYJ@80Hf=S0P1FEUH205mOG`80Kfm_0P1iNGT207=c
L`80QHF50P1YJFT207MgM`03075aL@1SHf<0Hf=S0080LW9b0P1]KFd207]kN`80PH610P23Ph<208R8
R1D0oooo000C0?ooo`80PH610P1lO7`207emO@80OWin0P25QHD20861P@80RHV90`25QHD207]kN`80
PH610P1jNWX207]kN`80QHF50P22PX820861P@@0QHF50P27QhL209>CT`80RXZ:1020P80207moO`03
07inOP1^KVh0KVi^0080QXJ60P2=SHd205MGE`80Bd];0P1bLW82075aL@80K6a/201[Jf/206=SH`80
GemO1`1WIfL206ATI080IfMW0P1QHF4206UYJ@80K6a/0P1_Kfl4079bLP80LG5a0P1eMGD2071`L080
LW9b0P1UIFD00`1TI6@0HV9R069RHP0206MWI`@0J6QX0P1VIVH205iNGP80GemO0P1QHF4206EUI@80
HV9R0P1YJFT206YZJP80IFEU101VIVH00`1YJFT0JVYZ06YZJP0206UYJ@80JVYZ0P1VIVH206QXJ080
KFe]0P1^KVh206YZJPP0IFEU0P1WIfL206EUI@80JFUY00<0K6a/05eMG@1MGEd00P1HF5P207MgM`80
Ph>3101]KFd206m_K`80L71`0P1/K6`406e]K@80LW9b0P1dM7@2075aL@<0MgMg0P1hN7P406m_K`@0
JVYZ0P1HF5P205MGE`H0HF5Q0P1ZJVX204m?C`80G5aL101VIVH00`1[Jf/0Lg=c07=cL`02071`L080
HV9R0P1jNWX20861P@80NWYj0P21PH4E0?ooo`004`3oool20861P@80O7al0P1mOGd207inOP80QHF5
0P21PH4208V9R@<0QHF50P1kNg/20861P@80NWYj0P1kNg/208F5Q@80PX:20P21PH4408F5Q@80QhN7
0P2CTi<208Z:RP@0P8200P1oOgl00`1nOWh0KVi^06i^KP0208J6QP80SHf=0P1GEeL204];B`80LW9b
0P1aLG4206a/K0P0Jf][0P1SHf<205mOG`L0IfMW0P1TI6@206MWI`80HF5Q0P1YJFT206a/K080Kfm_
101bLW82075aL@80MGEe0P1`L702079bLP80IFEU00<0I6AT069RHP1RHV800P1WIfL406QXJ080IVIV
0P1NGUh205mOG`80HF5Q0P1UIFD2069RHP80JFUY0P1ZJVX206EUI@@0IVIV00<0JFUY06YZJP1ZJVX0
0P1YJFT206YZJP80IVIV0P1XJ6P206e]K@80KVi^0P1ZJVX806EUI@80IfMW0P1UIFD206UYJ@0306a/
K01MGEd0GEeM0080F5QH0P1gMgL208>3P`@0KFe]0P1_Kfl2071`L080K6a/101]KFd2079bLP80M7Ad
0P1aLG4307MgM`80N7Qh101_Kfl406YZJP80F5QH0P1GEeL6065QH@80JVYZ0P1?Cdl205aLG0@0IVIV
00<0Jf][07=cL`1cLg<00P1`L702069RHP80NWYj0P21PH4207YjNP80PH615@3oool001<0oooo0P21
PH4208B4Q080QHF50P23Ph<208V9R@@0QHF50P1lO7`00`23Ph<0Q8B408B4Q00408R8R080Ph>30P1j
NWX20861P@80PX:20P21PH4608F5Q@@0Shn?0P2BTY8208j>SP0309:BTP2FUYH0UYJF0080QhN70P2D
U9@20<C4a080NGUi0P1UIFD206i^KP80M7Ad0P1_Kfl406][J`80J6QX0P1`L70206i^KP80J6QX00<0
KVi^06m_K`1_Kfl00P1dM7@207UiN@80MGEe0P1XJ6P2069RHP80JVYZ0P1^KVh4079bLP80L71`0P1g
MgL207QhN080NWYj0P1aLG400`1]KFd0M7Ad07AdM002079bLP80JFUY101`L70206m_K`80Jf][0P1S
Hf<205mOG`80FUYJ0P1FEUH405MGE`80FEUI0P1JFUX00`1EEED0EeMG05MGE`02059BDP80EUIF0P1J
FUX205MGE`@0EUIF1P1KFe/2065QH@@0IfMW0P1ZJVX206EUI@0306MWI`1TI6@0I6AT0080FEUI0P1=
CDd206=SH`80MgMg0P1UIFD204M7A`80ADE50P1LG5`206EUI@80IVIV0P1ZJVX206a/K080Kfm_0P1]
KFd00`1^KVh0MWIf07IfMP0207MgM`80Kfm_0P1FEUH204E5A@80HV9R0P1VIVH206MWI`80EUIF0P1G
EeL206m_K`80NGUi0P1ZJVX206ATI080NGUi00<0MWIf06i^KP1^KVh00P1fMWH207=cL`80NGUi0P24
Q8@20861P@80Ogmo5@3oool001<0oooo0P2:RXX208:2PP80QhN70P21PH4207moO`80QHF50P2:RXX2
08N7Q`0308:2PP20P800P8200080NWYj0P1oOgl20861P@80Ph>30P1oOgl208F5Q@80NWYj0P1nOWh2
08J6QP80Ogmo0P28R8P20861P@80QXJ60P21PH400`1oOgl0PX:208:2PP0208:2PP80PH610P25QHD2
0:ZZZP80PH610P1FEUH205]KF`80MgMg0P1TI6@2069RHP80Kfm_101[Jf/2061PH0<0GUiN0P1QHF42
06IVIP@0K6a/0P1UIFD206UYJ@80Jf][0P1`L70407AdM080LW9b0P1_Kfl2071`L080M7Ad00<0K6a/
06MWI`1WIfL0101_Kfl4071`L080M7Ad0P1iNGT207EeM@@0NWYj0P1fMWH207UiN@@0L71`0P1aLG40
0`1^KVh0LG5a075aL@02071`L080LG5a0P1]KFd2075aL@@0M7Ad0P1eMGD207AdM080N7Qh0P1eMGD2
071`L080K6a/101eMGD00`1dM7@0Lg=c07=cL`02071`L080M7Ad0P1SHf<206QXJ080Q8B40P2HV9P2
07emO@80=cLg0P0[:b/205]KF`80GEeM0P1XJ6P406UYJ@0305eMG@0l?3`0?3`l0080;2`/0P0];Bd2
04U9B@80FUYJ0P1ZJVX2079bLP80K6a/0P1ZJVX206ATI080IVIV0P1bLW8207QhN080IfMW0P1IFET0
0`1kNg/0KVi^06i^KP0205mOG`80Lg=c0P1eMGD20861P@@0R8R85@3oool001<0oooo0P2:RXX208:2
PP80QhN70P21PH4207moO`80QHF50P2:RXX208N7Q`0308:2PP20P800P8200080NWYj0P1oOgl20861
P@80Ph>30P1oOgl208F5Q@80NWYj0P1nOWh208J6QP80Ogmo0P28R8P20861P@80QXJ60P21PH400`1o
Ogl0PX:208:2PP0208:2PP80PH610P25QHD20:ZZZP80PH610P1FEUH205]KF`80MgMg0P1TI6@2069R
HP80Kfm_101[Jf/2061PH0<0GUiN0P1QHF4206IVIP@0K6a/0P1UIFD206UYJ@80Jf][0P1`L70407Ad
M080LW9b0P1_Kfl2071`L080M7Ad00<0K6a/06MWI`1WIfL0101_Kfl4071`L080M7Ad0P1iNGT207Ee
M@@0NWYj0P1fMWH207UiN@@0L71`0P1aLG400`1^KVh0LG5a075aL@02071`L080LG5a0P1]KFd2075a
L@@0M7Ad0P1eMGD207AdM080N7Qh0P1eMGD2071`L080K6a/101eMGD00`1dM7@0Lg=c07=cL`02071`
L080M7Ad0P1SHf<206QXJ080Q8B40P2HV9P207emO@80=cLg0P0[:b/205]KF`80GEeM0P1XJ6P406UY
J@0305eMG@0l?3`0?3`l0080;2`/0P0];Bd204U9B@80FUYJ0P1ZJVX2079bLP80K6a/0P1ZJVX206AT
I080IVIV0P1bLW8207QhN080IfMW0P1IFET00`1kNg/0KVi^06i^KP0205mOG`80Lg=c0P1eMGD20861
P@@0R8R85@3oool001<0oooo0P1iNGT207inOP80Ogmo0P26QXH207emO@80O7al0P1jNWX20820P003
08:2PP28R8P0R8R80080QHF50P21PH4208N7Q`80RXZ:0P22PX8208B4Q080QHF50P21PH4208R8R080
PH610P26QXH20861P@80QHF50P22PX800`1nOWh0PH610861P@0208>3P`80QXJ60P1mOGd208B4Q080
QhN70P1ZJVX204I6AP80F5QH0P1PH602069RHP@0JVYZ0P1`L702075aL@0306i^KP1UIFD0IFEU0080
IfMW0P1ZJVX406a/K080IVIV0P1XJ6P206m_K`80JVYZ101/K6`2079bLP@0MGEe0P1gMgL00`1`L700
K6a/06a/K00406m_K`80Lg=c1P1_Kfl207=cL`80K6a/0P1YJFT206a/K080MGEe0P1hN7P207EeM@80
M7Ad00<0KVi^06m_K`1_Kfl00P1]KFd207AdM080N7Qh0P1`L70206e]K@@0K6a/1P1_Kfl207QhN080
Kfm_0P1/K6`206][J`03075aL@1[Jf/0Jf][0080M7Ad0P1eMGD207AdM080JVYZ0P1WIfL206a/K080
MgMg0P2k^k/20861P@80MGEe0P1<C4`203`l?080@d=30P12@T800`0m?Cd0Cdm?04m?C`02059BDP80
Cdm?0P1GEeL2059BDP80F5QH101RHV82071`L080P8200P1YJFT206=SH`80GUiN0P1^KVh207EeM@03
06m_K`22PX80PX:20080KVi^0P1bLW8207alO0@0NGUi0P23Ph<E0?ooo`004`3oool207UiN@80OWin
0P1oOgl208J6QP80OGem0P1lO7`207YjNP80P82000<0PX:208R8R028R8P00P25QHD20861P@80QhN7
0P2:RXX208:2PP80Q8B40P25QHD20861P@80R8R80P21PH4208J6QP80PH610P25QHD208:2PP0307in
OP21PH40PH610080Ph>30P26QXH207emO@80Q8B40P27QhL206YZJP80ATI60P1HF5P2061PH080HV9R
101ZJVX2071`L080LG5a00<0KVi^06EUI@1UIFD00P1WIfL206YZJP@0K6a/0P1VIVH206QXJ080Kfm_
0P1ZJVX406a/K080LW9b101eMGD207MgM`03071`L01/K6`0K6a/00@0Kfm_0P1cLg<606m_K`80Lg=c
0P1/K6`206UYJ@80K6a/0P1eMGD207QhN080MGEe0P1dM7@00`1^KVh0Kfm_06m_K`0206e]K@80M7Ad
0P1hN7P2071`L080KFe]101/K6`606m_K`80N7Qh0P1_Kfl206a/K080Jf][00<0LG5a06][J`1[Jf/0
0P1dM7@207EeM@80M7Ad0P1ZJVX206MWI`80K6a/0P1gMgL20;^k^`80PH610P1eMGD204a<C080?3`l
0P13@d<20492@P0303dm?@1?Cdl0Cdm?0080DU9B0P1?Cdl205MGE`80DU9B0P1HF5P4069RHP80L71`
0P20P80206UYJ@80Hf=S0P1NGUh206i^KP80MGEe00<0Kfm_08:2PP22PX800P1^KVh2079bLP80O7al
101iNGT208>3PaD0oooo000C0?ooo`80S8b<0P26QXH207alO0@0QHF50P26QXH208Z:RP80Q8B400<0
OWin07alO01lO7`00P27QhL208J6QP@0PH610P23Ph<208F5Q@80P8200P1nOWh208F5Q@80PH610P23
Ph<208F5Q@80RXZ:0P29RHT00`25QHD0PH610861P@0207YjNP@0Ogmo0P20P80208Z:RP80QhN70P1P
H60205EEE@80GUiN0P1=CDd2059BDP80Jf][0P1XJ6P206MWI`0306UYJ@1VIVH0IVIV0080JVYZ101V
IVH206m_K`80JVYZ0P1XJ6P206i^KP@0Kfm_0P1/K6`406m_K`80KVi^0`1cLg<2071`L080IfMW0P1[
Jf/:06m_K`80Lg=c0P1fMWH206UYJ@80I6AT0P1WIfL206][J`80M7Ad00<0MGEe06i^KP1^KVh00P1Z
JVX206MWI`80I6AT0P1XJ6P206m_K`80Lg=c0P1^KVh206MWI`H0Kfm_101/K6`206][J`0306m_K`1Z
JVX0JVYZ0080JVYZ0P1XJ6P206m_K`80M7Ad0P1^KVh206][J`80Hf=S101TI6@208N7Q`80VIVI0P2<
S8`204E5A@80<c<c00<0ATI604Q8B018B4P00P1?Cdl205IFEP80DE5A0P1BDU8204=3@`80DU9B0P1U
IFD205QHF080JFUY0P1ADE42065QH@80Kfm_0P1FEUH206MWI`0307IfMP1[Jf/0Jf][0080UIFE0P1k
Ng/208B4Q080PH610P22PX8207moOaD0oooo000C0?ooo`80S8b<0P26QXH207alO0@0QHF50P26QXH2
08Z:RP80Q8B400<0OWin07alO01lO7`00P27QhL208J6QP@0PH610P23Ph<208F5Q@80P8200P1nOWh2
08F5Q@80PH610P23Ph<208F5Q@80RXZ:0P29RHT00`25QHD0PH610861P@0207YjNP@0Ogmo0P20P802
08Z:RP80QhN70P1PH60205EEE@80GUiN0P1=CDd2059BDP80Jf][0P1XJ6P206MWI`0306UYJ@1VIVH0
IVIV0080JVYZ101VIVH206m_K`80JVYZ0P1XJ6P206i^KP@0Kfm_0P1/K6`406m_K`80KVi^0`1cLg<2
071`L080IfMW0P1[Jf/:06m_K`80Lg=c0P1fMWH206UYJ@80I6AT0P1WIfL206][J`80M7Ad00<0MGEe
06i^KP1^KVh00P1ZJVX206MWI`80I6AT0P1XJ6P206m_K`80Lg=c0P1^KVh206MWI`H0Kfm_101/K6`2
06][J`0306m_K`1ZJVX0JVYZ0080JVYZ0P1XJ6P206m_K`80M7Ad0P1^KVh206][J`80Hf=S101TI6@2
08N7Q`80VIVI0P2<S8`204E5A@80<c<c00<0ATI604Q8B018B4P00P1?Cdl205IFEP80DE5A0P1BDU82
04=3@`80DU9B0P1UIFD205QHF080JFUY0P1ADE42065QH@80Kfm_0P1FEUH206MWI`0307IfMP1[Jf/0
Jf][0080UIFE0P1kNg/208B4Q080PH610P22PX8207moOaD0oooo000C0?ooo`80Ng]k0P25QHD208Z:
RP@0PH610P1oOgl20861P@80QhN70`2:RXX20861P@80Ph>30P25QHD208R8R080OGem0P25QHD408V9
R@80QHF50P27QhL207emO@80PH610P25QHD208:2PP0308>3P`21PH40PH6100@0Q8B40P1oOgl208:2
PP80RXZ:0P1dM7@207emO@80EUIF0P1EEED205ADE080:RXZ0P0d=3@206EUI@80J6QX00<0K6a/06QX
J01XJ6P00P1XJ6P206][J`80IfMW0P1VIVH206MWI`80JFUY101_Kfl606i^KP80Lg=c0P1[Jf/306m_
K`@0Lg=c201_Kfl2071`L0H0Kfm_0P1cLg<406a/K080Jf][0P1/K6`00`1WIfL0LG5a075aL@0206i^
KP80J6QX101/K6`206MWI`80IVIV0P1/K6`206YZJP80Kfm_0P1`L70206m_K`80KFe]0P1/K6`206m_
K`03075aL@1WIfL0IfMW0080KFe]0P1[Jf/206m_K`80Jf][0P1VIVH206][J`80JVYZ0P1SHf<204m?
C`80AdM70P0g=cL202`/;080Cdm?0P1CDe<00`16ATH0BDU904U9B@02059BDP@0De=C0P1FEUH206=S
H`80I6AT0P1OGel205=CD`80M7Ad0P1OGel205aLG080KVi^0P1TI6@206i^KP0307MgM`1YJFT0JFUY
0080P8200P22PX820820P080Ogmo0P2:RXX208:2PQD0oooo000C0?ooo`80Ng]k0P25QHD208Z:RP@0
PH610P1oOgl20861P@80QhN70`2:RXX20861P@80Ph>30P25QHD208R8R080OGem0P25QHD408V9R@80
QHF50P27QhL207emO@80PH610P25QHD208:2PP0308>3P`21PH40PH6100@0Q8B40P1oOgl208:2PP80
RXZ:0P1dM7@207emO@80EUIF0P1EEED205ADE080:RXZ0P0d=3@206EUI@80J6QX00<0K6a/06QXJ01X
J6P00P1XJ6P206][J`80IfMW0P1VIVH206MWI`80JFUY101_Kfl606i^KP80Lg=c0P1[Jf/306m_K`@0
Lg=c201_Kfl2071`L0H0Kfm_0P1cLg<406a/K080Jf][0P1/K6`00`1WIfL0LG5a075aL@0206i^KP80
J6QX101/K6`206MWI`80IVIV0P1/K6`206YZJP80Kfm_0P1`L70206m_K`80KFe]0P1/K6`206m_K`03
075aL@1WIfL0IfMW0080KFe]0P1[Jf/206m_K`80Jf][0P1VIVH206][J`80JVYZ0P1SHf<204m?C`80
AdM70P0g=cL202`/;080Cdm?0P1CDe<00`16ATH0BDU904U9B@02059BDP@0De=C0P1FEUH206=SH`80
I6AT0P1OGel205=CD`80M7Ad0P1OGel205aLG080KVi^0P1TI6@206i^KP0307MgM`1YJFT0JFUY0080
P8200P22PX820820P080Ogmo0P2:RXX208:2PQD0oooo000C0?ooo`80RXZ:0P22PX8207emO@80PX:2
0P23Ph<207moO`80QXJ60P1oOgl00`20P800OWin07inOP0208J6QP80Ogmo0P21PH4208>3P`80QXJ6
0P1oOgl408F5Q@80PH610P22PX8408F5Q@80PH610P23Ph<00`27QhL0P8200820P00207inOP80QHF5
0P27QhL20861P@80SHf=0P2<S8`209VIV@80L71`0P18B4P205ADE080BTY:0P0P820202PX:080I6AT
00<0IFEU06=SH`1SHf<00P1OGel2061PH080JFUY0P1]KFd206YZJP80JFUY201_Kfl206a/K080L71`
1`1_Kfl206a/K0H0IfMW0P1ZJVX206a/K080Jf][101_Kfl2071`L0@0K6a/0P1WIfL206a/K00306YZ
JP1UIFD0IFEU0080JVYZ0P1]KFd806a/K080Jf][0P1WIfL406YZJP80IVIV0P1_Kfl206][J`80Kfm_
00<0L71`06YZJP1ZJVX00P1ZJVX406MWI`80J6QX0P1VIVH206=SH`@0Fe]K0P1BDU820492@P80?clo
0P1;Bd/205=CD`80FUYJ00<0GUiN05QHF01HF5P00P15ADD204i>CP80EUIF0P1NGUh205mOG`80Hf=S
0P1ZJVX405iNGP@0FUYJ0P1^KVh206IVIP80KVi^00<0L71`07IfMP1fMWH00P23Ph<207inOP80R8R8
0P1mOGd207inOP80P8205@3oool001<0oooo0P2:RXX208:2PP80OGem0P22PX8208>3P`80Ogmo0P26
QXH207moO`030820P01nOWh0OWin0080QXJ60P1oOgl20861P@80Ph>30P26QXH207moO`@0QHF50P21
PH4208:2PP@0QHF50P21PH4208>3P`0308N7Q`20P800P8200080OWin0P25QHD208N7Q`80PH610P2=
SHd208b<S080VIVI0P1`L70204Q8B080E5AD0P1:BTX2020P8080:2PX0P1TI6@00`1UIFD0Hf=S06=S
H`0205mOG`80H61P0P1YJFT206e]K@80JVYZ0P1YJFT806m_K`80K6a/0P1`L70706m_K`80K6a/1P1W
IfL206YZJP80K6a/0P1[Jf/406m_K`80L71`101/K6`206MWI`80K6a/00<0JVYZ06EUI@1UIFD00P1Z
JVX206e]K@P0K6a/0P1[Jf/206MWI`@0JVYZ0P1VIVH206m_K`80Jf][0P1_Kfl00`1`L700JVYZ06YZ
JP0206YZJP@0IfMW0P1XJ6P206IVIP80Hf=S101KFe/2059BDP80@T920P0o?cl204];B`80De=C0P1J
FUX00`1NGUh0F5QH05QHF00204E5A@80CTi>0P1FEUH205iNGP80GemO0P1SHf<206YZJP@0GUiN101J
FUX206i^KP80IVIV0P1^KVh00`1`L700MWIf07IfMP0208>3P`80OWin0P28R8P207emO@80OWin0P20
P80E0?ooo`004`3oool207]kN`80P8200P27QhL208J6QP80PH610P1nOWh208Z:RP80QHF500<0R8R8
07moO`1oOgl00P28R8P207emO@80Q8B40P21PH4408F5Q@80PH610P1lO7`208:2PP80PH610P1oOgl2
0820P080Ph>30P22PX800`23Ph<0QhN708N7Q`0208R8R080OWin0P21PH440820P080MWIf0P1nOWh2
06e]K@80B4Q80P1;Bd/204E5A@80>c/k0P0@410201hN7P0305MGE`1SHf<0Hf=S0080JVYZ0P1[Jf/2
06MWI`80J6QX0P1VIVH206EUI@80JVYZ1P1_Kfl406][J`L0Kfm_101cLg<2071`L080Kfm_101/K6`2
06MWI`80Jf][0P1_Kfl407=cL`80KFe]0P1UIFD206QXJ0D0KFe]0P1YJFT206QXJ080JVYZ0P1WIfL4
06QXJ0@0IfMW0P1aLG4206m_K`80L71`0P1VIVH206UYJ@0307=cL`1aLG40LG5a0080K6a/0P1ZJVX2
06IVIP80IfMW0P1OGel2069RHP@0FUYJ0P1?Cdl204E5A@80CDe=0P1FEUH204];B`80C4a<00<0FEUI
05iNGP1NGUh00P1FEUH204a<C080Fe]K0P1FEUH205=CD`80FEUI0P1?Cdl205eMG@80Kfm_1P1cLg<2
06m_K`80H61P00<0MgMg07emO@1mOGd00P22PX820820P080O7al0P1nOWh20861P@80RHV95@3oool0
01<0oooo0P1kNg/20820P080QhN70P26QXH20861P@80OWin0P2:RXX208F5Q@0308R8R01oOgl0Ogmo
0080R8R80P1mOGd208B4Q080PH611025QHD20861P@80O7al0P22PX820861P@80Ogmo0P20P80208>3
P`80PX:200<0Ph>308N7Q`27QhL00P28R8P207inOP80PH611020P80207IfMP80OWin0P1]KFd204Q8
B080Bd];0P15ADD203/k>`80410@0P0N7Qh00`1GEeL0Hf=S06=SH`0206YZJP80Jf][0P1WIfL206QX
J080IVIV0P1UIFD206YZJPH0Kfm_101[Jf/706m_K`@0Lg=c0P1`L70206m_K`@0K6a/0P1WIfL206][
J`80Kfm_101cLg<206e]K@80IFEU0P1XJ6P506e]K@80JFUY0P1XJ6P206YZJP80IfMW101XJ6P406MW
I`80LG5a0P1_Kfl2071`L080IVIV0P1YJFT00`1cLg<0LG5a075aL@0206a/K080JVYZ0P1VIVH206MW
I`80GemO0P1RHV8405YJFP80Cdm?0P15ADD204e=C@80EUIF0P1;Bd/204a<C00305UIF@1NGUh0GUiN
0080EUIF0P1<C4`205]KF`80EUIF0P1CDe<205UIF@80Cdm?0P1MGEd206m_K`H0Lg=c0P1_Kfl2061P
H00307MgM`1mOGd0OGem0080PX:20P20P80207alO080OWin0P21PH4208V9RAD0oooo000C0?ooo`80
PX:20P1oOgl207]kN`80Ogmo0P23Ph<207moO`80P8200P1jNWX00`20P800OWin07inOP0208V9R@80
RXZ:0P21PH4208F5Q@80PH610P1lO7`208F5Q@80QXJ60P23Ph<208R8R080OGem0P26QXH20861P@80
Ogmo00<0QHF50861P@21PH400P23Ph<208J6QP80QHF50P20P80208R8R080LG5a0P21PH4208Z:RP80
I6AT0P1?Cdl204i>CP80?3`l0P0];Bd200h>3P03020P801SHf<0Hf=S0080GemO0P1SHf<2069RHP80
KFe]0P1WIfL206YZJPP0Kfm_0P1cLg<206a/K080IfMW0P1[Jf/00`1_Kfl0K6a/06a/K00406MWI`80
K6a/0P1UIFD206MWI`80JVYZ1P1_Kfl206a/K080IfMW0P1_Kfl206i^KP80IfMW00<0IVIV06EUI@1U
IFD00P1VIVH206m_K`80K6a/101ZJVX206EUI@80Hf=S0P1[Jf/206EUI@80K6a/0P1WIfL206a/K080
KFe]0P1WIfL00`1VIVH0H61P061PH00205QHF080EeMG0P1BDU8204i>CP80DU9B0P1CDe<204m?C`80
=3@d0P0[:b/20410@080EeMG0P1MGEd204U9B@80@T9200<0CTi>06EUI@1UIFD00P1bLW8206a/K080
De=C0P1@D50204Q8B080EUIF0P1LG5`206=SH`80GEeM0P1ZJVX207emO@80Kfm_0P1hN7P207EeM@03
06m_K`1iNGT0NGUi0080MWIf0P20P80208:2PP80Ph>30P1oOgl208J6QQD0oooo000C0?ooo`80PX:2
0P1oOgl207]kN`80Ogmo0P23Ph<207moO`80P8200P1jNWX00`20P800OWin07inOP0208V9R@80RXZ:
0P21PH4208F5Q@80PH610P1lO7`208F5Q@80QXJ60P23Ph<208R8R080OGem0P26QXH20861P@80Ogmo
00<0QHF50861P@21PH400P23Ph<208J6QP80QHF50P20P80208R8R080LG5a0P21PH4208Z:RP80I6AT
0P1?Cdl204i>CP80?3`l0P0];Bd200h>3P03020P801SHf<0Hf=S0080GemO0P1SHf<2069RHP80KFe]
0P1WIfL206YZJPP0Kfm_0P1cLg<206a/K080IfMW0P1[Jf/00`1_Kfl0K6a/06a/K00406MWI`80K6a/
0P1UIFD206MWI`80JVYZ1P1_Kfl206a/K080IfMW0P1_Kfl206i^KP80IfMW00<0IVIV06EUI@1UIFD0
0P1VIVH206m_K`80K6a/101ZJVX206EUI@80Hf=S0P1[Jf/206EUI@80K6a/0P1WIfL206a/K080KFe]
0P1WIfL00`1VIVH0H61P061PH00205QHF080EeMG0P1BDU8204i>CP80DU9B0P1CDe<204m?C`80=3@d
0P0[:b/20410@080EeMG0P1MGEd204U9B@80@T9200<0CTi>06EUI@1UIFD00P1bLW8206a/K080De=C
0P1@D50204Q8B080EUIF0P1LG5`206=SH`80GEeM0P1ZJVX207emO@80Kfm_0P1hN7P207EeM@0306m_
K`1iNGT0NGUi0080MWIf0P20P80208:2PP80Ph>30P1oOgl208J6QQD0oooo000C0?ooo`80OWin0P23
Ph<208R8R080PX:20P25QHD20861P@@0PX:200<0R8R808:2PP22PX800P1nOWh20861P@80QhN70P21
PH4208N7Q`80QXJ60P25QHD208R8R080PH610P26QXH208>3P`80O7al0P25QHD208N7Q`0307emO@1o
Ogl0Ogmo0080Ng]k0P21PH4208:2PP80Ph>30P2;Rh/207inOP80QHF50P1bLW8206=SH`80Bd];0P14
A4@203Xj>P80=3@d0P0Z:RX00`0:2PX06ATI01TI6@02069RHP80IVIV0P1NGUh206MWI`80JVYZ0P1U
IFD206][J`80K6a/1P1WIfL206m_K`80L71`0P1WIfL00`1[Jf/0L71`071`L00206a/K080Kfm_0P1`
L70206m_K`80JVYZ0P1VIVH206EUI@80IfMW0P1VIVH206e]K@80L71`0P1YJFT206EUI@80IfMW00<0
IVIV06MWI`1WIfL0101RHV8206EUI@80JFUY0P1TI6@206QXJ080GEeM0P1NGUh2061PH080J6QX0P1T
I6@206=SH`80HV9R0P1OGel00`1WIfL0JVYZ06YZJP02065QH@@0GemO0P1FEUH204];B`80?3`l0P0_
;bl203Hf=P@0@d=30P1:BTX205IFEP80IFEU0P1JFUX00`1OGel0F5QH05QHF00205]KF`80EUIF0P1W
IfL205iNGP80De=C0P1JFUX205]KF`80HV9R0P1QHF4206][J`80EEEE0P1^KVh207EeM@80Ng]k00<0
OGem07UiN@1iNGT00P1fMWH207emO@80Q8B40P23Ph<207moO`80RHV95@3oool001<0oooo0P1nOWh2
08>3P`80R8R80P22PX8208F5Q@80PH611022PX800`28R8P0PX:208:2PP0207inOP80PH610P27QhL2
0861P@80QhN70P26QXH208F5Q@80R8R80P21PH4208J6QP80Ph>30P1lO7`208F5Q@80QhN700<0OGem
07moO`1oOgl00P1kNg/20861P@80PX:20P23Ph<208^;R`80OWin0P25QHD2079bLP80Hf=S0P1;Bd/2
04A4A080>SXj0P0d=3@202XZ:P0300X:2P0I6AT06ATI0080HV9R0P1VIVH205iNGP80IfMW0P1ZJVX2
06EUI@80Jf][0P1/K6`606MWI`80Kfm_0P1`L70206MWI`0306][J`1`L700L71`0080K6a/0P1_Kfl2
071`L080Kfm_0P1ZJVX206IVIP80IFEU0P1WIfL206IVIP80KFe]0P1`L70206UYJ@80IFEU0P1WIfL0
0`1VIVH0IfMW06MWI`04069RHP80IFEU0P1YJFT206ATI080J6QX0P1MGEd205iNGP80H61P0P1XJ6P2
06ATI080Hf=S0P1RHV8205mOG`0306MWI`1ZJVX0JVYZ0080HF5Q101OGel205IFEP80Bd];0P0l?3`2
02l_;`80=SHf1013@d<204Y:BP80EUIF0P1UIFD205YJFP0305mOG`1HF5P0F5QH0080Fe]K0P1FEUH2
06MWI`80GUiN0P1CDe<205YJFP80Fe]K0P1RHV82065QH@80Jf][0P1EEED206i^KP80MGEe0P1kNg/0
0`1mOGd0NGUi07UiN@0207IfMP80OGem0P24Q8@208>3P`80Ogmo0P29RHTE0?ooo`004`3oool208>3
P`80Ng]k0P21PH4208Z:RP80QHF50P26QXH208>3P`80RHV90`25QHD407moO`80QHF50P1mOGd20820
P080Ng]k0P1mOGd407moO`80RHV90P2:RXX208N7Q`80OWin0P25QHD00`26QXH0PX:208:2PP0207mo
O`80PX:20P21PH4207moO`80MgMg0P1hN7P2071`L080JFUY0P1BDU8204i>CP80A4A4100h>3P203@d
=00302HV9P051@D01@D5008010@40P1QHF4205aLG080Hf=S0P1TI6@206IVIP80IFEU0P1ZJVX606a/
K080Jf][0P1`L70206m_K`D0K6a/0P1WIfL406YZJP80Kfm_0P1[Jf/206EUI@80IVIV0P1XJ6P206AT
I080K6a/0P1^KVh206e]K@80JVYZ0`1YJFT206IVIP80GemO0P1LG5`206EUI@80IVIV0P1TI6@406UY
J@@0IFEU0P1XJ6P205YJFP80IfMW0P1PH6000`1NGUh0HF5Q065QH@0206=SH`80Fe]K0P1DE5@204=3
@`@0>SXj1012@T8205ADE080F5QH0P1CDe<204m?C`D0EUIF0P17AdL204A4A0@0BTY:0P1OGel206UY
J@@0GemO0P1VIVH406][J`80Kfm_0P1mOGd208R8R080NGUi00<0MgMg08Z:RP2:RXX00P28R8P208>3
P`80RHV90P2:RXX408F5QAD0oooo000C0?ooo`80Ph>30P1kNg/20861P@80RXZ:0P25QHD208J6QP80
Ph>30P29RHT308F5Q@@0Ogmo0P25QHD207emO@80P8200P1kNg/207emO@@0Ogmo0P29RHT208Z:RP80
QhN70P1nOWh208F5Q@0308J6QP22PX80PX:20080Ogmo0P22PX820861P@80Ogmo0P1gMgL207QhN080
L71`0P1YJFT2059BDP80CTi>0P14A4@403Ph>080=3@d00<09RHV00D51@051@D00P0410@2065QH@80
G5aL0P1SHf<206ATI080IVIV0P1UIFD206YZJPH0K6a/0P1[Jf/2071`L080Kfm_1@1/K6`206MWI`@0
JVYZ0P1_Kfl206][J`80IFEU0P1VIVH206QXJ080I6AT0P1/K6`206i^KP80KFe]0P1ZJVX306UYJ@80
IVIV0P1OGel205aLG080IFEU0P1VIVH206ATI0@0JFUY101UIFD206QXJ080FUYJ0P1WIfL2061PH003
05iNGP1QHF40HF5Q0080Hf=S0P1KFe/205ADE080@d=3100j>SX40492@P80E5AD0P1HF5P205=CD`80
Cdm?1@1FEUH204M7A`80A4A4101:BTX205mOG`80JFUY101OGel206IVIP@0Jf][0P1_Kfl207emO@80
R8R80P1iNGT00`1gMgL0RXZ:08Z:RP0208R8R080Ph>30P29RHT208Z:RP@0QHF55@3oool001<0oooo
0P1nOWh208F5Q@80PX:20P21PH4208F5Q@80S8b<0P21PH4207emO@030861P@2:RXX0RXZ:0080R8R8
0P1mOGd407moO`80R8R80P29RHT408Z:RP80PX:2101mOGd408:2PP80PH6100<0R8R808B4Q024Q8@0
0P24Q8@40861P@80R8R80P25QHD208B4Q080LW9b0P1jNWX205EEE@80Cdm?0P19BDT203Xj>P80=3@d
0P0a<C43024Q8@801@D50P092@T206=SH`80IFEU0P1[Jf/206MWI`@0JVYZ1P1/K6`206MWI`@0Kfm_
00<0L71`06a/K01/K6`0101/K6`206e]K@@0K6a/0P1]KFd206][J`@0K6a/1P1WIfL406IVIP0306MW
I`1VIVH0IVIV0080J6QX0P1VIVH206ATI080GemO0P1RHV8205eMG@80F5QH0P1RHV8205aLG080I6AT
0P1VIVH205mOG`80GEeM0P1RHV800`1KFe/0F5QH05QHF00205]KF`80Bd];0P0f=SH203Ti>@80;2`/
0P0d=3@204Y:BP80Cdm?0P1ADE44059BDP80EEEE0P1ADE4205EEE@0306ATI01WIfL0IfMW0080IfMW
0P1TI6@206a/K080GemO0P1RHV8206ATI080KFe]101ZJVX206][J`80Kfm_0P1YJFT2071`L080OGem
00<0Ogmo07inOP1nOWh00P25QHD208:2PP80PH610P22PX8207emO@80Ogmo5@3oool001<0oooo0P1n
OWh208F5Q@80PX:20P21PH4208F5Q@80S8b<0P21PH4207emO@030861P@2:RXX0RXZ:0080R8R80P1m
OGd407moO`80R8R80P29RHT408Z:RP80PX:2101mOGd408:2PP80PH6100<0R8R808B4Q024Q8@00P24
Q8@40861P@80R8R80P25QHD208B4Q080LW9b0P1jNWX205EEE@80Cdm?0P19BDT203Xj>P80=3@d0P0a
<C43024Q8@801@D50P092@T206=SH`80IFEU0P1[Jf/206MWI`@0JVYZ1P1/K6`206MWI`@0Kfm_00<0
L71`06a/K01/K6`0101/K6`206e]K@@0K6a/0P1]KFd206][J`@0K6a/1P1WIfL406IVIP0306MWI`1V
IVH0IVIV0080J6QX0P1VIVH206ATI080GemO0P1RHV8205eMG@80F5QH0P1RHV8205aLG080I6AT0P1V
IVH205mOG`80GEeM0P1RHV800`1KFe/0F5QH05QHF00205]KF`80Bd];0P0f=SH203Ti>@80;2`/0P0d
=3@204Y:BP80Cdm?0P1ADE44059BDP80EEEE0P1ADE4205EEE@0306ATI01WIfL0IfMW0080IfMW0P1T
I6@206a/K080GemO0P1RHV8206ATI080KFe]101ZJVX206][J`80Kfm_0P1YJFT2071`L080OGem00<0
Ogmo07inOP1nOWh00P25QHD208:2PP80PH610P22PX8207emO@80Ogmo5@3oool001<0oooo0P2<S8`2
08F5Q@80Q8B40P1nOWh208:2PP80PH610P2:RXX208V9R@0308:2PP1nOWh0OWin0080P8200P21PH42
08R8R080QHF50P1jNWX207]kN`80OWin0P21PH4208V9R@80QhN70P21PH4408F5Q@80Ng]k00<0P820
08F5Q@25QHD00P26QXH208>3P`80PH610P1oOgl20820P080Ph>30P1bLW82075aL@80EEEE0P16ATH2
0451@@80@T920P0i>CT202XZ:P03024Q8@0H61P061PH008092@T0P0J6QX206=SH`80GemO101ZJVX2
06][J`80JFUY0P1]KFd2071`L080Kfm_0P1`L70406MWI`<0K6a/0P1YJFT206QXJ080K6a/0P1ZJVX2
06UYJ@80Jf][0P1YJFT406MWI`80I6AT0P1SHf<2069RHPD0IfMW101TI6@2069RHP80GUiN0P1JFUX2
05aLG0@0GemO0P1XJ6P206][J`80De=C0P1FEUH205=CD`80E5AD0P1EEED00`1DE5@0AdM704M7A`02
04A4A080Bd];0P0j>SX2030`<080ATI60P0m?Cd203Ph>080?Shn0P19BDT204m?C`@0C4a<0P1KFe/2
05IFEP03065QH@1ZJVX0JVYZ0080Hf=S0P1JFUX206YZJP80KFe]0P1QHF4206][J`H0JVYZ0P1bLW84
07IfMP80OGem0P28R8P00`27QhL0RXZ:08Z:RP0408:2PP80PH611P25QHDE0?ooo`004`3oool208b<
S080QHF50P24Q8@207inOP80PX:20P21PH4208Z:RP80RHV900<0PX:207inOP1nOWh00P20P8020861
P@80R8R80P25QHD207YjNP80Ng]k0P1nOWh20861P@80RHV90P27QhL20861P@@0QHF50P1kNg/00`20
P800QHF508F5Q@0208J6QP80Ph>30P21PH4207moO`80P8200P23Ph<2079bLP80LG5a0P1EEED204I6
AP80@D510P12@T8203Ti>@80:RXZ00<08B4Q01PH600H61P00P0T92@201XJ6P80Hf=S0P1OGel406YZ
JP80Jf][0P1YJFT206e]K@80L71`0P1_Kfl2071`L0@0IfMW0`1/K6`206UYJ@80J6QX0P1/K6`206YZ
JP80JFUY0P1[Jf/206UYJ@@0IfMW0P1TI6@206=SH`80HV9R1@1WIfL406ATI080HV9R0P1NGUh205YJ
FP80G5aL101OGel206QXJ080Jf][0P1CDe<205IFEP80De=C0P1DE5@205EEE@0305ADE017AdL0AdM7
0080A4A40P1;Bd/203Xj>P80<30`0P16ATH203dm?@80>3Ph0P0n?Sh204U9B@80Cdm?101<C4`205]K
F`80EUIF00<0HF5Q06YZJP1ZJVX00P1SHf<205YJFP80JVYZ0P1]KFd2065QH@80Jf][1P1ZJVX2079b
LP@0MWIf0P1mOGd208R8R00308N7Q`2:RXX0RXZ:00@0PX:20P21PH4608F5QAD0oooo000C0?ooo`80
QHF50P22PX8208F5Q@80O7al0P21PH4207emO@80Ogmo0P21PH400`23Ph<0QHF508F5Q@0408>3P`80
QHF51028R8P208F5Q@80Ph>30P22PX8207inOP80Q8B40P25QHD40861P@80QHF500<0RHV908:2PP22
PX800P25QHD208N7Q`80PX:21023Ph<207emO@80I6AT0P1QHF4205EEE@80Cdm?0P10@4020492@P80
?3`l0P0g=cL00`0Y:BT09RHV02HV9P0202XZ:P80410@0P0W9bL206IVIP80JVYZ101_Kfl206YZJP80
JFUY0P1`L70206MWI`L0K6a/0P1ZJVX206i^KP80JVYZ101VIVH206QXJ080KFe]0P1XJ6P206UYJ@80
Jf][0P1WIfL206YZJP80IFEU0P1QHF4306YZJP80J6QX0P1TI6@2069RHP80H61P0P1GEeL2055AD@80
GUiN0P1[Jf/206=SH`80E5AD0P1?Cdl405IFEP@0EEEE00<0CTi>04A4A014A4@00P0o?cl203Hf=P80
EUIF0P1=CDd2051@D080E5AD0P1OGel205]KF`@0FEUI0P1FEUH205=CD`80DU9B0P1CDe<00`18B4P0
CTi>04i>CP0405]KF`80D51@0P1DE5@2065QH@@0JVYZ0P1YJFT2079bLP80M7Ad0P1mOGd208N7Q`80
O7al0P26QXH00`21PH40NWYj07YjNP020861P@80RHV90P22PX8208B4Q080PH610P22PX8E0?ooo`00
4`3oool208F5Q@80PX:20P25QHD207alO080PH610P1mOGd207moO`80PH6100<0Ph>308F5Q@25QHD0
1023Ph<208F5Q@@0R8R80P25QHD208>3P`80PX:20P1nOWh208B4Q080QHF51021PH4208F5Q@0308V9
R@22PX80PX:20080QHF50P27QhL208:2PP@0Ph>30P1mOGd206ATI080HF5Q0P1EEED204m?C`80@410
0P12@T8203`l?080=cLg00<0:BTY02HV9P0V9RH00P0Z:RX2010@40809bLW0P1VIVH206YZJP@0Kfm_
0P1ZJVX206UYJ@80L71`0P1WIfL706a/K080JVYZ0P1^KVh206YZJP@0IVIV0P1XJ6P206e]K@80J6QX
0P1YJFT206][J`80IfMW0P1ZJVX206EUI@80HF5Q0`1ZJVX206QXJ080I6AT0P1RHV82061PH080EeMG
0P1ADE4205iNGP80Jf][0P1SHf<205ADE080Cdm?101FEUH405EEE@0304i>CP14A4@0A4A40080?clo
0P0f=SH205IFEP80CDe=0P1@D50205ADE080GemO0P1KFe/405UIF@80EUIF0P1CDe<2059BDP80De=C
00<0B4Q804i>CP1>CTh0101KFe/2051@D080E5AD0P1QHF4406YZJP80JFUY0P1bLW8207AdM080OGem
0P27QhL207alO080QXJ600<0PH6107YjNP1jNWX00P21PH4208V9R@80PX:20P24Q8@20861P@80PX:2
5@3oool001<0oooo0P25QHD208V9R@80QXJ60P24Q8@208F5Q@80PX:20P1nOWh208J6QP0308F5Q@26
QXH0QXJ600H0QHF50P29RHT20861P@80PX:20P21PH4208F5Q@@0P8200P1jNWX208F5Q@80QXJ60P1m
OGd00`21PH40QHF508F5Q@0207emO@80Ph>30P1oOgl207emO@80O7al0P1kNg/2079bLP80FEUI0P1?
Cdl204Y:BP80C4a<0P14A4@203Lg=`80<30`00<0;Bd]02h^;P0^;Rh00P0^;Rh201dM7@8051@D0P1R
HV8206][J`80JVYZ0P1`L70206YZJP80IVIV0P1YJFT206IVIP@0JFUY0P1VIVH00`1YJFT0KFe]06e]
K@0206YZJP80J6QX0P1[Jf/206UYJ@80IFEU0P1ZJVX206][J`80IVIV0P1TI6@206e]K@80HV9R0P1Y
JFT206ATI080G5aL00<0GemO065QH@1QHF400P1NGUh205aLG080De=C101KFe/2061PH080JVYZ0P1J
FUX205IFEP@0Fe]K0P1GEeL204=3@`80>SXj00<0=cLg03hn?P0n?Sh00P1;Bd/20451@@80=cLg0P1:
BTX204];B`@0@d=30P1?Cdl205EEE@80EUIF0P1?Cdl204=3@`80BTY:0P1TI6@00`1PH600GEeM05eM
G@0406EUI@80GemO0P1_Kfl606YZJP80KVi^0P1ZJVX2079bLP80OGem0P1nOWh207]kN`80PH6100<0
QXJ608F5Q@25QHD01P25QHD208>3P`80QHF50P29RHTE0?ooo`004`3oool208F5Q@80RHV90P26QXH2
08B4Q080QHF50P22PX8207inOP80QXJ600<0QHF508J6QP26QXH01P25QHD208V9R@80PH610P22PX82
0861P@80QHF51020P80207YjNP80QHF50P26QXH207emO@030861P@25QHD0QHF50080OGem0P23Ph<2
07moO`80OGem0P1lO7`207]kN`80LW9b0P1IFET204m?C`80BTY:0P1<C4`204A4A080=cLg0P0`<300
0`0];Bd0;Rh^02h^;P0202h^;P807AdM0P0D51@2069RHP80Jf][0P1ZJVX2071`L080JVYZ0P1VIVH2
06UYJ@80IVIV101YJFT206IVIP0306UYJ@1]KFd0KFe]0080JVYZ0P1XJ6P206][J`80JFUY0P1UIFD2
06YZJP80Jf][0P1VIVH206ATI080KFe]0P1RHV8206UYJ@80I6AT0P1LG5`00`1OGel0HF5Q065QH@02
05iNGP80G5aL0P1CDe<405]KF`80H61P0P1ZJVX205YJFP80EUIF101KFe/205MGE`80@d=30P0j>SX0
0`0g=cL0?Shn03hn?P0204];B`80@D510P0g=cL204Y:BP80Bd];1013@d<204m?C`80EEEE0P1FEUH2
04m?C`80@d=30P1:BTX206ATI003061PH01MGEd0GEeM00@0IFEU0P1OGel206m_K`H0JVYZ0P1^KVh2
06YZJP80LW9b0P1mOGd207inOP80Ng]k0P21PH400`26QXH0QHF508F5Q@0608F5Q@80Ph>30P25QHD2
08V9RAD0oooo000C0?ooo`80QHF50P21PH4208F5Q@80PH610P25QHD408V9R@<0QHF50P27QhL20861
P@H0QHF50P28R8P20861P@80Ogmo0P2:RXX208J6QP80QHF50P22PX8207inOP80R8R80P25QHD00`21
PH40P8200820P00208>3P`80RXZ:0P28R8P208>3P`80O7al0P1bLW8206=SH`80GemO0P16ATH204A4
A080>CTi0P0h>3P203<c<`80;Rh^0`0i>CT202XZ:P805QHF0P0:2PX406MWI`80IFEU101/K6`206YZ
JP80K6a/0P1WIfL206QXJ080K6a/0P1WIfL306EUI@80IfMW0P1YJFT206QXJ080Jf][0P1ZJVX206AT
I0@0JVYZ0P1WIfL205mOG`80HV9R0P1KFe/206ATI0<0HV9R0P1SHf<2061PH080Fe]K0P1GEeL204a<
C080FUYJ0P1KFe/204e=C@80Cdm?0P19BDT404Q8B080ATI60P15ADD203Lg=`0303hn?P13@d<0@d=3
0080BDU90P15ADD204=3@`80?3`l0P0k>c/20492@P80A4A40P1?Cdl205IFEP80E5AD0P1BDU82061P
H080Cdm?0P1KFe/00`1@D500Fe]K05]KF`0204=3@`80FUYJ0P1NGUh205=CD`80GUiN101[Jf/2079b
LP80S8b<0P23Ph<207emO@80P8200P21PH4208F5Q@0308V9R@21PH40PH610080QHF50P21PH4208:2
PP80OGem0P1oOgl208F5QAD0oooo000C0?ooo`80QHF50P21PH4208F5Q@80PH610P25QHD408V9R@<0
QHF50P27QhL20861P@H0QHF50P28R8P20861P@80Ogmo0P2:RXX208J6QP80QHF50P22PX8207inOP80
R8R80P25QHD00`21PH40P8200820P00208>3P`80RXZ:0P28R8P208>3P`80O7al0P1bLW8206=SH`80
GemO0P16ATH204A4A080>CTi0P0h>3P203<c<`80;Rh^0`0i>CT202XZ:P805QHF0P0:2PX406MWI`80
IFEU101/K6`206YZJP80K6a/0P1WIfL206QXJ080K6a/0P1WIfL306EUI@80IfMW0P1YJFT206QXJ080
Jf][0P1ZJVX206ATI0@0JVYZ0P1WIfL205mOG`80HV9R0P1KFe/206ATI0<0HV9R0P1SHf<2061PH080
Fe]K0P1GEeL204a<C080FUYJ0P1KFe/204e=C@80Cdm?0P19BDT404Q8B080ATI60P15ADD203Lg=`03
03hn?P13@d<0@d=30080BDU90P15ADD204=3@`80?3`l0P0k>c/20492@P80A4A40P1?Cdl205IFEP80
E5AD0P1BDU82061PH080Cdm?0P1KFe/00`1@D500Fe]K05]KF`0204=3@`80FUYJ0P1NGUh205=CD`80
GUiN101[Jf/2079bLP80S8b<0P23Ph<207emO@80P8200P21PH4208F5Q@0308V9R@21PH40PH610080
QHF50P21PH4208:2PP80OGem0P1oOgl208F5QAD0oooo000C0?ooo`80QHF50P2:RXX208F5Q@80QXJ6
0P1oOgl208F5Q@80PX:20P21PH400`22PX80QHF508F5Q@0208:2PP80PH611025QHD208V9R@80QhN7
101nOWh408:2PP80R8R80P25QHD208J6QP80PH6100<0QXJ608F5Q@25QHD01025QHD208J6QP80Ph>3
101eMGD405]KF`80DU9B0P19BDT204M7A`80<c<c0P0];Bd2034a<@0303Lg=`0b<S80<S8b00@0:BTY
0P0C4a<206a/K080Jf][0P1`L70206IVIP80J6QX0P1ZJVX206a/K080KVi^101YJFT306YZJP80I6AT
0P1SHf<206UYJ@80Hf=S0P1NGUh205mOG`80HF5Q0P1RHV8206ATI080GemO0P1UIFD206=SH`80I6AT
0P1OGel305aLG080EeMG0P1IFET4051@D080EUIF101>CTh2059BDP@0Cdm?0P1<C4`204U9B@80?3`l
0P0h>3P204E5A@0303lo?`1:BTX0BTY:0080FEUI0P1BDU8204U9B@80@D510P1@D50205MGE`80Bd];
0P1:BTX204e=C@80EeMG101VIVH205YJFP80FEUI00<0DE5A05IFEP1FEUH00P1FEUH2059BDP80IFEU
0P1hN7P4071`L080MWIf0P1iNGT2075aL@@0P8200P1kNg/207YjNP80Ng]k00<0PH6108F5Q@25QHD0
0P22PX8208N7Q`80RHV90P2:RXX408F5QAD0oooo000C0?ooo`80QHF50P2:RXX208F5Q@80QXJ60P1o
Ogl208F5Q@80PX:20P21PH400`22PX80QHF508F5Q@0208:2PP80PH611025QHD208V9R@80QhN7101n
OWh408:2PP80R8R80P25QHD208J6QP80PH6100<0QXJ608F5Q@25QHD01025QHD208J6QP80Ph>3101e
MGD405]KF`80DU9B0P19BDT204M7A`80<c<c0P0];Bd2034a<@0303Lg=`0b<S80<S8b00@0:BTY0P0C
4a<206a/K080Jf][0P1`L70206IVIP80J6QX0P1ZJVX206a/K080KVi^101YJFT306YZJP80I6AT0P1S
Hf<206UYJ@80Hf=S0P1NGUh205mOG`80HF5Q0P1RHV8206ATI080GemO0P1UIFD206=SH`80I6AT0P1O
Gel305aLG080EeMG0P1IFET4051@D080EUIF101>CTh2059BDP@0Cdm?0P1<C4`204U9B@80?3`l0P0h
>3P204E5A@0303lo?`1:BTX0BTY:0080FEUI0P1BDU8204U9B@80@D510P1@D50205MGE`80Bd];0P1:
BTX204e=C@80EeMG101VIVH205YJFP80FEUI00<0DE5A05IFEP1FEUH00P1FEUH2059BDP80IFEU0P1h
N7P4071`L080MWIf0P1iNGT2075aL@@0P8200P1kNg/207YjNP80Ng]k00<0PH6108F5Q@25QHD00P22
PX8208N7Q`80RHV90P2:RXX408F5QAD0oooo000C0?ooo`80QHF50P22PX820861P@80RXZ:0P25QHD4
08:2PP80PH6100<0RHV908:2PP22PX802025QHD208:2PP80QHF50P26QXH208:2PP80QHF50P29RHT2
08:2PP80PH610P26QXH207inOP0308B4Q01nOWh0OWin0080OWin0P1mOGd20861P@80Ph>30P1oOgl2
07MgM`80GEeM0P1DE5@204Y:BP80A4A40P11@D420492@P80>c/k0P11@D400`0j>SX08b<S02<S8`02
024Q8@807QhN0P0=3@d206][J`80HV9R0P1SHf<206EUI@80JVYZ0P1]KFd206IVIP80G5aL0P1SHf<2
06MWI`80HF5Q00<0GemO06ATI01TI6@0101MGEd206ATI080HV9R0P1PH602069RHP80Fe]K0P1QHF42
061PH080G5aL0P1MGEd205]KF`80H61P0P1OGel00`1KFe/0FUYJ05YJFP0205IFEP80FEUI0P1?Cdl2
05ADE080DU9B0P16ATH203lo?`80@D510P13@d<20492@P80>c/k0P15ADD204M7A`80@d=300<0@D51
03`l?00l?3`00P1CDe<205IFEP80D51@0P1?Cdl204E5A@80BTY:0P1=CDd404I6AP80DU9B0P1DE5@4
06QXJ080HV9R00<0EUIF065QH@1QHF400P1PH60205IFEP80F5QH0P1YJFT206QXJ080NWYj0P1mOGd2
08N7Q`80Ph>30P1kNg/20861P@80OGem0P21PH4208N7Q`<0QHF50P26QXH807emO@80PH615@3oool0
01<0oooo0P25QHD208V9R@80QHF50P22PX820861P@80RHV90P26QXH20861P@0308F5Q@29RHT0RHV9
0080PX:20P21PH4408F5Q@80RHV90P25QHD408V9R@@0QHF50P26QXH20861P@80QXJ60P22PX8308F5
Q@80Ogmo0P24Q8@208Z:RP80R8R80P1eMGD206ATI080GemO0P1KFe/204i>CP80ADE50P12@T8203Hf
=P80>CTi0P0a<C400`0/;2`08B4Q024Q8@0202<S8`80820P0P0=3@d206e]K@80JVYZ0P1cLg<206YZ
JP@0IVIV0P1cLg<206][J`80Hf=S0P1VIVH5069RHP80H61P0P1MGEd205iNGP80GemO0P1PH60205]K
F`80H61P0P1NGUh206IVIP80HV9R0P1LG5`205QHF0@0Fe]K00<0G5aL05]KF`1KFe/00P1KFe/2059B
DP80EUIF0P1?Cdl204Y:BP80A4A40P16ATH403hn?P80<S8b0P0l?3`203Xj>P80<S8b0P0c<c<00`0n
?Sh0Bd];04];B`0205=CD`80EUIF0P1SHf<205EEE@80CDe=0P16ATH203dm?@80DE5A0P1DE5@204m?
C`80Bd];0P1NGUh205]KF`80FUYJ00<0H61P06=SH`1SHf<00P1XJ6P2069RHP80HF5Q0P1YJFT2071`
L080NWYj0P1iNGT2079bLP80MWIf0P1kNg/208N7Q`@0Q8B40P21PH400`22PX80PH610861P@0208V9
R@80RXZ:0P26QXH208B4Q080QHF50P22PX8E0?ooo`004`3oool208F5Q@80RHV90P25QHD208:2PP80
PH610P29RHT208J6QP80PH6100<0QHF508V9R@29RHT00P22PX820861P@@0QHF50P29RHT208F5Q@@0
RHV91025QHD208J6QP80PH610P26QXH208:2PP<0QHF50P1oOgl208B4Q080RXZ:0P28R8P207EeM@80
I6AT0P1OGel205]KF`80CTi>0P15ADD20492@P80=SHf0P0i>CT2034a<@0302`/;00Q8B408B4Q0080
8b<S0P0P820200d=3@80KFe]0P1ZJVX207=cL`80JVYZ101VIVH207=cL`80Jf][0P1SHf<206IVIPD0
HV9R0P1PH60205eMG@80GUiN0P1OGel2061PH080Fe]K0P1PH60205iNGP80IVIV0P1RHV8205aLG080
F5QH101KFe/00`1LG5`0Fe]K05]KF`0205]KF`80DU9B0P1FEUH204m?C`80BTY:0P14A4@204I6AP@0
?Shn0P0b<S8203`l?080>SXj0P0b<S8203<c<`0303hn?P1;Bd/0Bd];0080De=C0P1FEUH206=SH`80
EEEE0P1=CDd204I6AP80?Cdm0P1ADE4205ADE080Cdm?0P1;Bd/205iNGP80Fe]K0P1JFUX00`1PH600
Hf=S06=SH`0206QXJ080HV9R0P1QHF4206UYJ@80L71`0P1jNWX207UiN@80LW9b0P1fMWH207]kN`80
QhN71024Q8@20861P@0308:2PP21PH40PH610080RHV90P2:RXX208J6QP80Q8B40P25QHD208:2PQD0
oooo000C0?ooo`H0QHF50P29RHT208:2PP80OWin0P25QHD208:2PP0307emO@1oOgl0Ogmo0080RHV9
1025QHD208:2PP80PH612025QHD208:2PP@0QHF50P26QXH20820P00307]kN`21PH40PH610080Ph>3
0P22PX8207emO@80R8R80P1iNGT2065QH@80DU9B0P1@D5020492@P80>c/k0P0f=SH203Lg=`80=SHf
0P0h>3P00`0^;Rh0:RXZ02XZ:P0202XZ:P809bLW0P0C4a<206ATI080HV9R101WIfL206][J`80GemO
0P1SHf<206][J`80GemO101TI6@00`1NGUh0GEeM05eMG@02061PH080FEUI0P1HF5P205UIF@80G5aL
0P1IFET605aLG080Fe]K0P1JFUX205]KF`80EUIF0`1JFUX205=CD`80D51@0P1CDe<204m?C`80DU9B
0P1:BTX204=3@`80?3`l0P0m?Cd203Ti>@80A4A40P11@D4203Lg=`80>CTi0P0h>3P303dm?@80Bd];
0P1?Cdl204a<C080EUIF0P1DE5@204i>CP80ATI60P0k>c/203lo?`80Fe]K0P1GEeL205ADE080HF5Q
0P1_Kfl00`1RHV80EEEE05EEE@0205IFEP80FUYJ0P1QHF4406m_K`@0MWIf0P28R8P208J6QP80OGem
0P1jNWX208F5Q@80QXJ60P21PH400`29RHT0QHF508F5Q@0408F5Q@80QXJ61025QHD208J6QQD0oooo
000C0?ooo`H0QHF50P29RHT208:2PP80OWin0P25QHD208:2PP0307emO@1oOgl0Ogmo0080RHV91025
QHD208:2PP80PH612025QHD208:2PP@0QHF50P26QXH20820P00307]kN`21PH40PH610080Ph>30P22
PX8207emO@80R8R80P1iNGT2065QH@80DU9B0P1@D5020492@P80>c/k0P0f=SH203Lg=`80=SHf0P0h
>3P00`0^;Rh0:RXZ02XZ:P0202XZ:P809bLW0P0C4a<206ATI080HV9R101WIfL206][J`80GemO0P1S
Hf<206][J`80GemO101TI6@00`1NGUh0GEeM05eMG@02061PH080FEUI0P1HF5P205UIF@80G5aL0P1I
FET605aLG080Fe]K0P1JFUX205]KF`80EUIF0`1JFUX205=CD`80D51@0P1CDe<204m?C`80DU9B0P1:
BTX204=3@`80?3`l0P0m?Cd203Ti>@80A4A40P11@D4203Lg=`80>CTi0P0h>3P303dm?@80Bd];0P1?
Cdl204a<C080EUIF0P1DE5@204i>CP80ATI60P0k>c/203lo?`80Fe]K0P1GEeL205ADE080HF5Q0P1_
Kfl00`1RHV80EEEE05EEE@0205IFEP80FUYJ0P1QHF4406m_K`@0MWIf0P28R8P208J6QP80OGem0P1j
NWX208F5Q@80QXJ60P21PH400`29RHT0QHF508F5Q@0408F5Q@80QXJ61025QHD208J6QQD0oooo000C
0?ooo`80QHF50P22PX8207inOP80PH610P26QXH208:2PP80PH610P29RHT00`2:RXX0PX:208:2PP02
07emO@80Ogmo0P25QHD208J6QP80PH610P25QHD208:2PP80OWin0P1mOGd407moO`@0PX:20P28R8P3
08V9R@80PH610P24Q8@207moO`80MGEe0P1hN7P2069RHP80EeMG0P19BDT204a<C080B4Q80P0m?Cd6
03`l?00302@T900L71`071`L00807AdM0P0U9BD201HF5P80Jf][0P1OGel206ATI080GemO0P1WIfL2
06QXJ080GUiN0P1TI6@2061PH080GEeM0P1OGel505aLG080GEeM0P1LG5`205=CD`@0D51@0P1ADE42
05IFEP80EeMG0P1LG5`205UIF@80EUIF101BDU800`1?Cdl0De=C05=CD`0204m?C`80DE5A0P11@D42
03/k>`80?Shn0P0k>c/203dm?@80@D510P16ATH203`l?080>CTi0P0o?cl20451@@80A4A400<0@d=3
04A4A014A4@00P1;Bd/206=SH`80IfMW0P1_Kfl206=SH`80BTY:0P0m?Cd204A4A080BDU90P17AdL2
04i>CP80HF5Q101PH6000`1FEUH0EEEE05EEE@02055AD@80Fe]K101^KVh206YZJP80OGem0P1iNGT2
07AdM080OGem0P25QHD208J6QP80PH610P29RHT308F5Q@80PX:20P21PH4208F5Q@80RHV90P21PH42
07moO`80QXJ65@3oool001<0oooo0P25QHD208:2PP80OWin0P21PH4208J6QP80PX:20P21PH4208V9
R@0308Z:RP22PX80PX:20080OGem0P1oOgl208F5Q@80QXJ60P21PH4208F5Q@80PX:20P1nOWh207em
O@@0Ogmo1022PX8208R8R0<0RHV90P21PH4208B4Q080Ogmo0P1eMGD207QhN080HV9R0P1GEeL204U9
B@80C4a<0P18B4P203dm?@H0?3`l00<092@T01`L700L71`00P0M7Ad202DU9@805QHF0P1[Jf/205mO
G`80I6AT0P1OGel206MWI`80J6QX0P1NGUh206ATI080H61P0P1MGEd205mOG`D0G5aL0P1MGEd205aL
G080De=C101@D502055AD@80EUIF0P1GEeL205aLG080FEUI0P1FEUH4059BDP0304m?C`1CDe<0De=C
0080Cdm?0P1ADE420451@@80>c/k0P0n?Sh203/k>`80?Cdm0P11@D4204I6AP80?3`l0P0i>CT203lo
?`80@D510P14A4@00`13@d<0A4A404A4A00204];B`80Hf=S0P1WIfL206m_K`80Hf=S0P1:BTX203dm
?@80A4A40P19BDT204M7A`80CTi>0P1QHF44061PH00305IFEP1EEED0EEEE0080DE5A0P1KFe/406i^
KP80JVYZ0P1mOGd207UiN@80M7Ad0P1mOGd208F5Q@80QXJ60P21PH4208V9R@<0QHF50P22PX820861
P@80QHF50P29RHT20861P@80Ogmo0P26QXHE0?ooo`004`3oool207inOP80QHF50P29RHT408:2PP80
PH610P1lO7`207]kN`0307emO@25QHD0QHF50080RXZ:0P25QHD20861P@80Ph>30P22PX820861P@80
QXJ60P25QHD208J6QP@0QHF51029RHT208F5Q@0308:2PP21PH40PH610080OGem0P25QHD20861P@80
NWYj0P1[Jf/205]KF`80EUIF0P1<C4`203lo?`80>3Ph0P0n?Sh203dm?@80<c<c0P0X:2P00`0O7al0
6a/K01/K6`0201lO7`808B4Q0P0C4a<206][J`80HV9R0P1/K6`206QXJ0@0I6AT0P1PH60205YJFP80
GemO0P1LG5`305mOG`80F5QH0P1IFET205YJFP80Fe]K0P1OGel205]KF`80EUIF101BDU8205ADE080
Fe]K1P1FEUH204m?C`0304a<C01;Bd/0Bd];0080BDU90P18B4P204Y:BP80?Cdm0P0d=3@203hn?P@0
?Cdm0P11@D4202d];@808R8R0P0W9bL203De=@80B4Q800<0DE5A04];B`1;Bd/00P18B4P204I6AP80
EUIF0P1?Cdl206IVIP80KVi^0P1BDU8204m?C`80C4a<0P1FEUH204];B`80CDe=0P1RHV8205MGE`D0
EUIF0P1BDU8206UYJ@80O7al0P1oOgl207IfMP80PX:20P1iNGT208:2PP80Ogmo0P24Q8@207YjNP80
Ogmo0P25QHD00`22PX80QHF508F5Q@0408F5Q@80PX:20P27QhL208F5Q@80RHV95@3oool001<0oooo
0P1nOWh208F5Q@80RHV91022PX820861P@80O7al0P1kNg/00`1mOGd0QHF508F5Q@0208Z:RP80QHF5
0P21PH4208>3P`80PX:20P21PH4208J6QP80QHF50P26QXH408F5Q@@0RHV90P25QHD00`22PX80PH61
0861P@0207emO@80QHF50P21PH4207YjNP80Jf][0P1KFe/205IFEP80C4a<0P0o?cl203Ph>080?Shn
0P0m?Cd203<c<`80:2PX00<07alO01/K6`0K6a/00P0O7al2024Q8@804a<C0P1[Jf/2069RHP80K6a/
0P1XJ6P406ATI080H61P0P1JFUX205mOG`80G5aL0`1OGel205QHF080FEUI0P1JFUX205]KF`80GemO
0P1KFe/205IFEP@0DU9B0P1DE5@205]KF`H0EUIF0P1?Cdl00`1<C4`0Bd];04];B`0204U9B@80B4Q8
0P1:BTX203dm?@80=3@d0P0n?Sh403dm?@80@D510P0];Bd2028R8P809bLW0P0e=CD204Q8B003055A
D@1;Bd/0Bd];0080B4Q80P16ATH205IFEP80Cdm?0P1VIVH206i^KP80DU9B0P1?Cdl204a<C080EUIF
0P1;Bd/204e=C@80HV9R0P1GEeL505IFEP80DU9B0P1YJFT207alO080Ogmo0P1fMWH208:2PP80NGUi
0P22PX8207moO`80Q8B40P1jNWX207moO`80QHF500<0PX:208F5Q@25QHD01025QHD208:2PP80QhN7
0P25QHD208V9RAD0oooo000C0?ooo`80RHV91025QHD208V9R@@0QXJ6102:RXX00`29RHT0QHF508F5
Q@0408F5Q@80RXZ:1P21PH4208F5Q@80Ogmo0P27QhL20861P@80PX:20P21PH4208:2PP80OGem00<0
PH6108N7Q`27QhL00P24Q8@20820P080NWYj0P1eMGD206IVIP80G5aL0P19BDT204A4A080@d=3100g
=cL203De=@80=SHf0P0Y:BT00`0V9RH0:2PX02PX:00202HV9P80:2PX0P0G5aL206=SH`80GUiN0P1M
GEd205mOG`80Hf=S0P1NGUh206=SH`80I6AT0P1PH60205aLG080F5QH00<0G5aL05MGE`1GEeL00P1B
DU82055AD@80C4a<0P19BDT2051@D080CDe=0P1@D50205IFEP@0C4a<101FEUH704m?C`@0BTY:0P1=
CDd203<c<`80>SXj100n?Sh203<c<`809bLW0P0[:b/201hN7P80<C4a0P19BDT203lo?`030451@@13
@d<0@d=30080@D510P1;Bd/205YJFP80I6AT0P1LG5`2065QH@80FUYJ101GEeL2055AD@80G5aL0P1C
De<405IFEP0304m?C`1<C4`0C4a<0080GemO0P1UIFD207IfMP80L71`0P1jNWX207=cL`80NGUi0P25
QHD208:2PP80Ogmo0P29RHT208B4Q080PH610P25QHD00`29RHT0PH610861P@0207moO`80PX:20P25
QHD208:2PP80PH610P25QHDE0?ooo`004`3oool208V9R@@0QHF50P29RHT408J6QP@0RXZ:00<0RHV9
08F5Q@25QHD01025QHD208Z:RPH0PH610P25QHD207moO`80QhN70P21PH4208:2PP80PH610P22PX82
07emO@030861P@27QhL0QhN70080Q8B40P20P80207YjNP80MGEe0P1VIVH205aLG080BDU90P14A4@2
04=3@`@0=cLg0P0e=CD203Hf=P80:BTY00<09RHV02PX:00X:2P00P0V9RH202PX:0805aLG0P1SHf<2
05iNGP80GEeM0P1OGel206=SH`80GUiN0P1SHf<206ATI080H61P0P1LG5`205QHF00305aLG01GEeL0
EeMG0080DU9B0P1ADE4204a<C080BDU90P1@D50204e=C@80D51@0P1FEUH404a<C0@0EUIF1`1?Cdl4
04Y:BP80CDe=0P0c<c<203Xj>P@0?Shn0P0c<c<202LW9`80:b/[0P0N7Qh2034a<@80BDU90P0o?cl0
0`11@D40@d=304=3@`020451@@80Bd];0P1JFUX206ATI080G5aL0P1QHF4205YJFP@0EeMG0P1ADE42
05aLG080De=C101FEUH00`1?Cdl0C4a<04a<C00205mOG`80IFEU0P1fMWH2071`L080NWYj0P1cLg<2
07UiN@80QHF50P22PX8207moO`80RHV90P24Q8@20861P@80QHF500<0RHV90861P@21PH400P1oOgl2
08:2PP80QHF50P22PX820861P@80QHF55@3oool001<0oooo1025QHD208:2PP80PH610P26QXH207in
OP@0OGem00<0OWin0861P@21PH400P22PX820861P@80QHF50P2:RXX208V9R@80QHF50P26QXH207al
O080PH610P1mOGd208>3P`80QHF51026QXH00`29RHT0PH610861P@0208B4Q080P8200P1hN7P206a/
K080FEUI0P1@D50204U9B@80ADE50P0o?cl20451@@80>SXj0P0d=3@202PX:08092@T00<08b<S02@T
900T92@00P0U9BD202@T90807AdM101SHf<206][J`80K6a/0P1WIfL206QXJ080I6AT0P1XJ6P206EU
I@80Jf][0P1WIfL00`1TI6@0IFEU06EUI@0205QHF080C4a<0P1BDU8204a<C080B4Q80P1>CTh404Q8
B080DU9B0P1@D50204a<C080B4Q80P1>CTh204U9B@0304A4A00o?cl0?clo0080A4A40P13@d<204E5
A@80<c<c0P0`<30203lo?`80<c<c0P0W9bL202HV9P80;2`/0P0m?Cd203@d=080?Cdm0P1DE5@00`16
ATH0CDe=04e=C@040451@@80DE5A0P1PH60205EEE@80Fe]K0P1CDe<204a<C080De=C0P1=CDd205aL
G080HF5Q0P1PH60205YJFP03065QH@1TI6@0I6AT0080H61P0P1MGEd207AdM080PH610P1dM7@20820
P080OGem0P1oOgl208Z:RP80QHF50P29RHT208J6QP80PH610`25QHD208Z:RP80QHF50P29RHT208F5
Q@80QXJ60P21PH4208:2PQD0oooo000C0?ooo`@0QHF50P22PX820861P@80QXJ60P1nOWh407emO@03
07inOP21PH40PH610080PX:20P21PH4208F5Q@80RXZ:0P29RHT208F5Q@80QXJ60P1lO7`20861P@80
OGem0P23Ph<208F5Q@@0QXJ600<0RHV90861P@21PH400P24Q8@20820P080N7Qh0P1/K6`205UIF@80
D51@0P19BDT204E5A@80?clo0P11@D4203Xj>P80=3@d0P0X:2P202@T900302<S8`0T92@092@T0080
9BDU0P0T92@201dM7@@0Hf=S0P1[Jf/206a/K080IfMW0P1XJ6P206ATI080J6QX0P1UIFD206][J`80
IfMW00<0I6AT06EUI@1UIFD00P1HF5P204a<C080DU9B0P1<C4`204Q8B080CTi>1018B4P2059BDP80
D51@0P1<C4`204Q8B080CTi>0P19BDT00`14A4@0?clo03lo?`0204A4A080@d=30P15ADD203<c<`80
<30`0P0o?cl203<c<`809bLW0P0V9RH202`/;080?Cdm0P0d=3@203dm?@80E5AD00<0ATI604e=C@1=
CDd01011@D42055AD@80H61P0P1EEED205]KF`80De=C0P1<C4`205=CD`80CDe=0P1LG5`2065QH@80
H61P0P1JFUX00`1QHF40I6AT06ATI002061PH080GEeM0P1dM7@20861P@80M7Ad0P20P80207emO@80
Ogmo0P2:RXX208F5Q@80RHV90P26QXH20861P@<0QHF50P2:RXX208F5Q@80RHV90P25QHD208J6QP80
PH610P22PX8E0?ooo`004`3oool207inOP80PH610P29RHT20820P080OGem0P21PH4208R8R080QHF5
00<0RHV908:2PP22PX800P22PX820861P@80QHF50P21PH4207moO`80PX:20P27QhL208J6QP80PH61
0P23Ph<207moO`80QHF50P26QXH207inOP0307emO@21PH40PH610080Ogmo0P1nOWh207moO`80KVi^
0P1MGEd205=CD`@0ATI60P0m?Cd204I6AP80?3`l0P0e=CD201dM7@8092@T00<0:2PX02DU9@0U9BD0
0P0R8R82030`<080;2`/0P1_Kfl207emO@80MGEe0P1mOGd207alO080Ogmo0P1eMGD4075aL@80K6a/
0P1[Jf/00`1ZJVX0KVi^06i^KP02075aL@80KFe]0P1CDe<204a<C0@0BDU90P1:BTX204M7A`@0@D51
0P1:BTX204a<C080AdM70P1;Bd/00`17AdL0@d=304=3@`0203hn?P80@4100P0i>CT2038b<P80=3@d
0P0c<c<202l_;`808R8R0P0S8b<203Ph>0@0<C4a0P0n?Sh204];B`0304Y:BP0m?Cd0?Cdm0080ATI6
0P14A4@205=CD`80G5aL101`L70206IVIP80F5QH0P1<C4`203dm?@80@4100P1QHF42061PH080DE5A
00<0HV9R065QH@1QHF400P1ZJVX207alO080Ng]k0P27QhL208>3P`80Ng]k0P25QHD207emO@80PH61
0P22PX820861P@80RHV91025QHD00`22PX80PH610861P@0608F5Q@80RHV90P22PX820861PAD0oooo
000C0?ooo`80OWin0P21PH4208V9R@80P8200P1mOGd20861P@80R8R80P25QHD00`29RHT0PX:208:2
PP0208:2PP80PH610P25QHD20861P@80Ogmo0P22PX8208N7Q`80QXJ60P21PH4208>3P`80Ogmo0P25
QHD208J6QP80OWin00<0OGem0861P@21PH400P1oOgl207inOP80Ogmo0P1^KVh205eMG@80De=C1016
ATH203dm?@80ATI60P0l?3`203De=@807AdM0P0T92@00`0X:2P09BDU02DU9@02028R8P80<30`0P0/
;2`206m_K`80OGem0P1eMGD207emO@80O7al0P1oOgl207EeM@@0LG5a0P1/K6`206][J`0306YZJP1^
KVh0KVi^0080LG5a0P1]KFd205=CD`80C4a<1019BDT204Y:BP80AdM71011@D4204Y:BP80C4a<0P17
AdL204];B`0304M7A`13@d<0@d=30080?Shn0P10@40203Ti>@80<S8b0P0d=3@203<c<`80;bl_0P0R
8R8202<S8`80>3Ph100a<C4203hn?P80Bd];00<0BTY:03dm?@0m?Cd00P16ATH204A4A080De=C0P1L
G5`4071`L080IVIV0P1HF5P204a<C080?Cdm0P10@402065QH@80H61P0P1ADE400`1RHV80HF5Q065Q
H@0206YZJP80O7al0P1kNg/208N7Q`80Ph>30P1kNg/208F5Q@80OGem0P21PH4208:2PP80PH610P29
RHT408F5Q@0308:2PP21PH40PH6100H0QHF50P29RHT208:2PP80PH615@3oool001<0oooo0P29RHT2
08:2PP80OWin0P28R8P208b<S080QHF50P26QXH20861P@0308F5Q@29RHT0RHV90080RHV91025QHD2
08R8R080PH610P29RHT208:2PP80QXJ60P29RHT208F5Q@80OWin0P22PX8408F5Q@030861P@22PX80
PX:20080Q8B40P1iNGT206][J`80GemO0P1GEeL2055AD@80B4Q80P0i>CT203Ph>080<C4a0P0n?Sh2
02h^;P8092@T0P0U9BD00`0/;2`09bLW02LW9`0202<S8`80?clo0P1CDe<2079bLP80MgMg0P1kNg/2
07=cL`80LW9b0P1`L70207UiN@80NWYj0P1hN7P207EeM@80KVi^00<0KFe]06YZJP1ZJVX0101XJ6P2
075aL@80IVIV0P1EEED204E5A@80A4A40P1;Bd/204e=C@80CTi>0P11@D420492@P80Bd];0`19BDT2
04E5A@80>c/k0P0i>CT204E5A@80@4100P16ATH203<c<`809bLW0P0T92@202/[:`80=CDe0P0i>CT2
038b<P80=cLg0P14A4@00`16ATH0@T920492@P020492@P80@d=30P17AdL2055AD@80HV9R0P1SHf<2
06MWI`80FUYJ0P1?Cdl205=CD`80BTY:0P1DE5@2061PH080GemO00<0HV9R06ATI01TI6@00P1GEeL2
065QH@80OGem0P1`L70207=cL`80Ng]k0P1oOgl208J6QP80PH610P25QHD607emO@80OWin0`25QHD2
08:2PP80PH611025QHD208V9R@80RXZ:5@3oool001<0oooo0P29RHT208:2PP80OWin0P28R8P208b<
S080QHF50P26QXH20861P@0308F5Q@29RHT0RHV90080RHV91025QHD208R8R080PH610P29RHT208:2
PP80QXJ60P29RHT208F5Q@80OWin0P22PX8408F5Q@030861P@22PX80PX:20080Q8B40P1iNGT206][
J`80GemO0P1GEeL2055AD@80B4Q80P0i>CT203Ph>080<C4a0P0n?Sh202h^;P8092@T0P0U9BD00`0/
;2`09bLW02LW9`0202<S8`80?clo0P1CDe<2079bLP80MgMg0P1kNg/207=cL`80LW9b0P1`L70207Ui
N@80NWYj0P1hN7P207EeM@80KVi^00<0KFe]06YZJP1ZJVX0101XJ6P2075aL@80IVIV0P1EEED204E5
A@80A4A40P1;Bd/204e=C@80CTi>0P11@D420492@P80Bd];0`19BDT204E5A@80>c/k0P0i>CT204E5
A@80@4100P16ATH203<c<`809bLW0P0T92@202/[:`80=CDe0P0i>CT2038b<P80=cLg0P14A4@00`16
ATH0@T920492@P020492@P80@d=30P17AdL2055AD@80HV9R0P1SHf<206MWI`80FUYJ0P1?Cdl205=C
D`80BTY:0P1DE5@2061PH080GemO00<0HV9R06ATI01TI6@00P1GEeL2065QH@80OGem0P1`L70207=c
L`80Ng]k0P1oOgl208J6QP80PH610P25QHD607emO@80OWin0`25QHD208:2PP80PH611025QHD208V9
R@80RXZ:5@3oool001<0oooo0P1nOWh408F5Q@80Ogmo0P22PX8207emO@80Ph>30P21PH400`1oOgl0
QHF508F5Q@0408F5Q@80PX:20P21PH4207moO`@0PX:20P21PH4208:2PP80QHF50P21PH4208J6QP80
OGem0P20P8030861P@80PX:20P27QhL206i^KP80Fe]K0P1CDe<204];B`80@D510P19BDT20410@080
>SXj0P0h>3P202<S8`809BDU0P0[:b/00`0W9bL09BDU02DU9@0205=CD`@0M7Ad0P1lO7`207AdM080
NWYj0P1hN7P207UiN@80Ng]k0P1dM7@207MgM`80LW9b101gMgL00`1bLW80KVi^06i^KP0206a/K080
JVYZ0P1XJ6P206UYJ@80Kfm_0P1[Jf/2051@D0@0@T920P11@D4204e=C@80AdM70P15ADD204I6AP03
03lo?`0m?Cd0?Cdm0080=CDe0P0R8R8403dm?@80@T920P0g=cL2028R8P8061PH0P0G5aL202HV9P80
DU9B100h>3P204];B`0304e=C@1ADE40DE5A0080CTi>0P17AdL205MGE`80FUYJ0P1YJFT207EeM@80
Lg=c0P1<C4`204i>CP80DE5A0P1<C4`204i>CP80DU9B0P1QHF400`1HF5P0IVIV06IVIP0206i^KP80
MWIf0P1cLg<207YjNP80Ogmo0P28R8P20861P@80RHV90P21PH4208F5Q@80RHV90P2:RXX208V9R@80
QXJ600<0OWin0861P@21PH400P29RHT408F5Q@80PX:20P21PH4208F5QAD0oooo000C0?ooo`80OWin
1025QHD207moO`80PX:20P1mOGd208>3P`80PH6100<0Ogmo08F5Q@25QHD01025QHD208:2PP80PH61
0P1oOgl408:2PP80PH610P22PX8208F5Q@80PH610P26QXH207emO@80P8200`21PH4208:2PP80QhN7
0P1^KVh205]KF`80De=C0P1;Bd/20451@@80BDU90P10@40203Xj>P80>3Ph0P0S8b<202DU9@80:b/[
00<09bLW02DU9@0U9BD00P1CDe<407AdM080O7al0P1dM7@207YjNP80N7Qh0P1iNGT207]kN`80M7Ad
0P1gMgL2079bLP@0MgMg00<0LW9b06i^KP1^KVh00P1/K6`206YZJP80J6QX0P1YJFT206m_K`80Jf][
0P1@D5040492@P80@D510P1=CDd204M7A`80ADE50P16ATH00`0o?cl0?Cdm03dm?@0203De=@808R8R
100m?Cd20492@P80=cLg0P0R8R8201PH60805aLG0P0V9RH2059BDP@0>3Ph0P1;Bd/00`1=CDd0DE5A
055AD@0204i>CP80AdM70P1GEeL205YJFP80JFUY0P1eMGD207=cL`80C4a<0P1>CTh2055AD@80C4a<
0P1>CTh2059BDP80HF5Q00<0F5QH06IVIP1VIVH00P1^KVh207IfMP80Lg=c0P1jNWX207moO`80R8R8
0P21PH4208V9R@80PH610P25QHD208V9R@80RXZ:0P29RHT208J6QP0307inOP21PH40PH610080RHV9
1025QHD208:2PP80PH610P25QHDE0?ooo`004`3oool208V9R@80PX:20P26QXH208F5Q@80RHV90P2:
RXX208F5Q@80QXJ60`1mOGd207moO`80QHF50P29RHT208J6QP80OGem0P25QHD208J6QP80OWin1022
PX820861P@80RHV9102:RXX00`26QXH0O7al07alO00206i^KP80LW9b0P1WIfL205UIF@80CDe=0P12
@T8203Hf=P80=CDe0P0l?3`203Xj>P80;2`/0P0S8b<202XZ:P80;Bd]00<0:2PX06m_K`1_Kfl00P2L
W9`207MgM`80LG5a0P1cLg<207]kN`80MWIf0P1mOGd207IfMP80MgMg0P1^KVh2075aL@80MWIf0P1e
MGD206m_K`<0MWIf0P1gMgL206YZJP80IfMW0P1XJ6P206YZJP80IFEU0P1[Jf/2051@D080@410100n
?Sh20451@@80?Shn0P10@4000`11@D40>c/k03/k>`02030`<080:RXZ0P0f=SH203Ph>080<S8b0P1J
FUX2030`<080<c<c0P0L71`201LG5`80=cLg0P0i>CT2038b<P80?Cdm00<0BTY:0492@P12@T800P1G
EeL204m?C`80BTY:0P1>CTh205QHF080JVYZ0P1[Jf/206i^KP@0BTY:0P1?Cdl205QHF080Fe]K0P1Q
HF400`1RHV80K6a/06a/K00205iNGP80M7Ad0P1kNg/207UiN@80OWin1021PH4207moO`80QhN70P21
PH4208F5Q@80PX:20P1nOWh208F5Q@0308J6QP1nOWh0OWin0080PH611025QHD208V9R@@0QHF55@3o
ool001<0oooo0P29RHT208:2PP80QXJ60P25QHD208V9R@80RXZ:0P25QHD208J6QP<0OGem0P1oOgl2
08F5Q@80RHV90P26QXH207emO@80QHF50P26QXH207inOP@0PX:20P21PH4208V9R@@0RXZ:00<0QXJ6
07alO01lO7`00P1^KVh2079bLP80IfMW0P1IFET204e=C@80@T920P0f=SH203De=@80?3`l0P0j>SX2
02`/;0808b<S0P0Z:RX202d];@0302PX:01_Kfl0Kfm_0080W9bL0P1gMgL2075aL@80Lg=c0P1kNg/2
07IfMP80OGem0P1fMWH207MgM`80KVi^0P1aLG4207IfMP80MGEe0P1_Kfl307IfMP80MgMg0P1ZJVX2
06MWI`80J6QX0P1ZJVX206EUI@80Jf][0P1@D5020410@0@0?Shn0P11@D4203hn?P80@41000<0@D51
03/k>`0k>c/00P0`<30202XZ:P80=SHf0P0h>3P2038b<P80FUYJ0P0`<30203<c<`8071`L0P0G5aL2
03Lg=`80>CTi0P0b<S8203dm?@0304Y:BP12@T80@T920080EeMG0P1?Cdl204Y:BP80CTi>0P1HF5P2
06YZJP80Jf][0P1^KVh404Y:BP80Cdm?0P1HF5P205]KF`80HF5Q00<0HV9R06a/K01/K6`00P1NGUh2
07AdM080Ng]k0P1iNGT207inOP@0PH610P1oOgl208N7Q`80PH610P25QHD208:2PP80OWin0P25QHD0
0`26QXH0OWin07inOP020861P@@0QHF50P29RHT408F5QAD0oooo000C0?ooo`80QHF50P29RHT408F5
Q@80PH610P1oOgl208F5Q@80RXZ:00<0RHV908Z:RP2:RXX01025QHD20861P@80PX:20P21PH4207mo
O`80RHV90P26QXH208F5Q@80RHV91P25QHD308:2PP80PH610P1kNg/206][J`80Hf=S0P1@D50204m?
C`80BDU90P12@T8203/k>`@0=cLg0P0X:2P402DU9@8092@T00<0Bd];04A4A014A4@0101bLW8206i^
KP80L71`0P1cLg<207QhN080MgMg0P1hN7P407emO@80N7Qh0P1^KVh2079bLP<0L71`0P1[Jf/206QX
J0@0L71`101XJ6P206UYJ@@0IFEU0P1TI6@204i>CP80>SXj0P10@40203hn?P80?Cdm00<0>c/k03<c
<`0c<c<00P0c<c<202`/;080:b/[0P1MGEd203dm?@80DE5A0P0_;bl201DE5@80:RXZ0P0k>c/203hn
?P80JVYZ0P1EEED204];B`0305MGE`11@D40@D510080ADE50P1CDe<2051@D080EEEE0P1@D50205iN
GP80MGEe0P1VIVH204a<C0@0AdM70P1;Bd/205QHF080Kfm_00<0KVi^05]KF`1KFe/00P1BDU8207=c
L`80R8R80P23Ph<208B4Q080PH610P27QhL20861P@80QXJ60P21PH4408:2PP@0QHF50`29RHT208:2
PP80PH611025QHD208:2PP80PH615@3oool001<0oooo0P25QHD208V9R@@0QHF50P21PH4207moO`80
QHF50P2:RXX00`29RHT0RXZ:08Z:RP0408F5Q@80PH610P22PX820861P@80Ogmo0P29RHT208J6QP80
QHF50P29RHT608F5Q@<0PX:20P21PH4207]kN`80Jf][0P1SHf<2051@D080Cdm?0P19BDT20492@P80
>c/k100g=cL202PX:0@09BDU0P0T92@00`1;Bd/0A4A404A4A004079bLP80KVi^0P1`L70207=cL`80
N7Qh0P1gMgL207QhN0@0OGem0P1hN7P206i^KP80LW9b0`1`L70206][J`80J6QX101`L70406QXJ080
JFUY101UIFD206ATI080CTi>0P0j>SX20410@080?Shn0P0m?Cd00`0k>c/0<c<c03<c<`0203<c<`80
;2`/0P0[:b/205eMG@80?Cdm0P1ADE4202l_;`805ADE0P0Z:RX203/k>`80?Shn0P1ZJVX205EEE@80
Bd];00<0EeMG0451@@11@D400P15ADD205=CD`80D51@0P1EEED2051@D080GUiN0P1eMGD206IVIP80
C4a<1017AdL204];B`80F5QH0P1_Kfl00`1^KVh0Fe]K05]KF`02059BDP80Lg=c0P28R8P208>3P`80
Q8B40P21PH4208N7Q`80PH610P26QXH20861P@@0PX:21025QHD308V9R@80PX:20P21PH4408F5Q@80
PX:20P21PH4E0?ooo`004`3oool207]kN`80Ogmo0P22PX820861P@80RXZ:0P25QHD20861P@80Ogmo
00<0PX:207inOP1nOWh00P21PH4208:2PP80Q8B40P22PX8208>3P`80Ogmo1022PX8207emO@80Ogmo
0P25QHD20820P080OWin0P25QHD00`21PH40O7al07alO00207YjNP80JFUY0P1PH60205ADE080C4a<
0P12@T8203De=@80<C4a0P0`<30203<c<`808B4Q0P0R8R8202LW9`80>SXj00<0EUIF06a/K01/K6`0
0P1_Kfl207UiN@@0M7Ad0P1cLg<2075aL@80Kfm_0P1aLG4206][J`80Kfm_0P1hN7P2075aL@80LW9b
0`1_Kfl207EeM@80NGUi0P1]KFd206QXJ080Jf][0P1XJ6P206MWI`80J6QX0P1[Jf/205]KF`80IFEU
0P17AdL203/k>`80?clo0P0h>3P00`0j>SX0<c<c03<c<`0202d];@807alO0P0N7Qh205EEE@80>SXj
0P11@D4205iNGP80Fe]K0P0[:b/202`/;080:BTY0P0e=CD20492@P80?clo00<0AdM705UIF@1IFET0
0P1;Bd/2055AD@80BDU90P1>CTh205IFEP80DU9B0P1dM7@2071`L080CTi>0P17AdL205MGE`80EUIF
0P1>CTh2051@D00305iNGP1ZJVX0JVYZ0080LW9b0P1fMWH207MgM`80O7al0P1oOgl207]kN`80QHF5
0P22PX8408F5Q@80QXJ60P22PX820861P@80PX:200<0OWin0861P@21PH400P26QXH207inOP80PH61
0P22PX8408F5QAD0oooo000C0?ooo`80Ng]k0P1oOgl208:2PP80PH610P2:RXX208F5Q@80PH610P1o
Ogl00`22PX80OWin07inOP020861P@80PX:20P24Q8@208:2PP80Ph>30P1oOgl408:2PP80OGem0P1o
Ogl208F5Q@80P8200P1nOWh208F5Q@030861P@1lO7`0O7al0080NWYj0P1YJFT2061PH080E5AD0P1<
C4`20492@P80=CDe0P0a<C42030`<080<c<c0P0Q8B42028R8P809bLW0P0j>SX00`1FEUH0K6a/06a/
K00206m_K`80NGUi101dM7@207=cL`80LG5a0P1_Kfl2075aL@80Jf][0P1_Kfl207QhN080LG5a0P1b
LW8306m_K`80MGEe0P1iNGT206e]K@80J6QX0P1[Jf/206QXJ080IfMW0P1XJ6P206][J`80Fe]K0P1U
IFD204M7A`80>c/k0P0o?cl203Ph>00303Xj>P0c<c<0<c<c0080;Bd]0P0O7al201hN7P80EEEE0P0j
>SX20451@@80GUiN0P1KFe/202/[:`80;2`/0P0Y:BT203De=@80@T920P0o?cl00`17AdL0FEUI05UI
F@0204];B`80DE5A0P19BDT204i>CP80EUIF0P1BDU8207AdM080L71`0P1>CTh204M7A`80EeMG0P1F
EUH204i>CP80D51@00<0GUiN06YZJP1ZJVX00P1bLW8207IfMP80MgMg0P1lO7`207moO`80Ng]k0P25
QHD208:2PP@0QHF50P26QXH208:2PP80PH610P22PX800`1nOWh0PH610861P@0208J6QP80OWin0P21
PH4208:2PP@0QHF55@3oool001<0oooo0P24Q8@20861P@80QXJ60P21PH4408F5Q@80QhN70P1nOWh0
0`25QHD0RHV908V9R@0208F5Q@80RHV90P26QXH208:2PP80QXJ60P22PX8208F5Q@80RHV90P2:RXX4
08F5Q@80S8b<0P22PX8207moO`0307YjNP1hN7P0N7Qh0080LW9b0P1YJFT205IFEP80ATI60P15ADD2
03lo?`80?3`l0P0g=cL203Hf=P808b<S0P0V9RH202d];@80>CTi0P1^KVh00`1`L700LG5a075aL@02
075aL@@0M7Ad0P1aLG4206][J`80L71`0P1VIVH406e]K@80IVIV0P1]KFd206IVIP80HF5Q0P1TI6@0
0`1YJFT0JVYZ06YZJP0206IVIP80K6a/0P1XJ6P206=SH`80I6AT0P1UIFD206MWI`80J6QX0P1TI6@2
065QH@80K6a/0P19BDT2034a<@80>3Ph0`0a<C4202HV9P80:2PX0P0S8b<202/[:`80I6AT0P0f=SH2
05eMG@80>CTi0P1CDe<203hn?P80@d=30P0e=CD204m?C`80@D5100<0@T9204a<C01<C4`00P0n?Sh2
03Ti>@80EeMG0P1:BTX2061PH0@0Cdm?0P20P802075aL@@0@d=30P1@D50205=CD`80E5AD00<0JFUY
07EeM@1eMGD0101lO7`207QhN080Ogmo0P22PX820861P@@0PX:20P21PH4208:2PP80QHF50P29RHT2
08:2PP80QHF500<0QXJ60861P@21PH401029RHT208:2PPH0QHF55@3oool001<0oooo0P24Q8@20861
P@80QXJ60P21PH4408F5Q@80QhN70P1nOWh00`25QHD0RHV908V9R@0208F5Q@80RHV90P26QXH208:2
PP80QXJ60P22PX8208F5Q@80RHV90P2:RXX408F5Q@80S8b<0P22PX8207moO`0307YjNP1hN7P0N7Qh
0080LW9b0P1YJFT205IFEP80ATI60P15ADD203lo?`80?3`l0P0g=cL203Hf=P808b<S0P0V9RH202d]
;@80>CTi0P1^KVh00`1`L700LG5a075aL@02075aL@@0M7Ad0P1aLG4206][J`80L71`0P1VIVH406e]
K@80IVIV0P1]KFd206IVIP80HF5Q0P1TI6@00`1YJFT0JVYZ06YZJP0206IVIP80K6a/0P1XJ6P206=S
H`80I6AT0P1UIFD206MWI`80J6QX0P1TI6@2065QH@80K6a/0P19BDT2034a<@80>3Ph0`0a<C4202HV
9P80:2PX0P0S8b<202/[:`80I6AT0P0f=SH205eMG@80>CTi0P1CDe<203hn?P80@d=30P0e=CD204m?
C`80@D5100<0@T9204a<C01<C4`00P0n?Sh203Ti>@80EeMG0P1:BTX2061PH0@0Cdm?0P20P802075a
L@@0@d=30P1@D50205=CD`80E5AD00<0JFUY07EeM@1eMGD0101lO7`207QhN080Ogmo0P22PX820861
P@@0PX:20P21PH4208:2PP80QHF50P29RHT208:2PP80QHF500<0QXJ60861P@21PH401029RHT208:2
PPH0QHF55@3oool001<0oooo0P29RHT208F5Q@80QXJ60P21PH4408F5Q@80QXJ60P25QHD00`22PX80
OWin07inOP0407inOP80QHF50P29RHT208:2PP80QHF50P22PX8207emO@80O7al0P1mOGd207inOP80
PH610P29RHT208R8R00307EeM@1fMWH0MWIf0080IVIV0P1OGel204];B`80B4Q80P0j>SX603Lg=`80
8B4Q100S8b<201dM7@80EeMG0P1`L70307AdM080KFe]0P1ZJVX206a/K080Kfm_0P1XJ6P206=SH`80
G5aL0P1HF5P205MGE`@0EEEE0P1IFET205QHF080FUYJ00<0EEEE05YJFP1JFUX00P1MGEd406MWI`80
KFe]0P1[Jf/206MWI`@0Hf=S0P1RHV82065QH@80Hf=S0P1aLG4205aLG080?3`l00<0=CDe030`<00`
<3000P0^;Rh202LW9`809RHV0P0S8b<204Q8B080IVIV0P10@40207EeM@@0FUYJ0P0a<C42030`<080
ATI60P1FEUH00`1;Bd/0?Cdm03dm?@0204i>CP80@d=30P1DE5@405EEE@80FUYJ0P1YJFT2071`L080
K6a/0P1RHV82061PH080EeMG0P1BDU82051@D00305mOG`1aLG40LG5a0080NWYj0P22PX8208>3P`80
Ogmo0P22PX8207inOP80RHV90P26QXH20861P@80QHF50P1mOGd20861P@80QXJ60P1nOWh708F5Q@80
RHV91025QHD208:2PQD0oooo000C0?ooo`80RHV90P25QHD208J6QP80PH611025QHD208J6QP80QHF5
00<0PX:207inOP1nOWh0101nOWh208F5Q@80RHV90P22PX8208F5Q@80PX:20P1mOGd207alO080OGem
0P1nOWh20861P@80RHV90P28R8P00`1eMGD0MWIf07IfMP0206IVIP80GemO0P1;Bd/204Q8B080>SXj
1P0g=cL2024Q8@@08b<S0P0M7Ad205MGE`80L71`0`1dM7@206e]K@80JVYZ0P1/K6`206m_K`80J6QX
0P1SHf<205aLG080F5QH0P1GEeL405EEE@80FEUI0P1HF5P205YJFP0305EEE@1JFUX0FUYJ0080GEeM
101WIfL206e]K@80Jf][0P1WIfL406=SH`80HV9R0P1QHF4206=SH`80LG5a0P1LG5`203`l?00303De
=@0`<300<30`0080;Rh^0P0W9bL202HV9P808b<S0P18B4P206IVIP80@4100P1eMGD405YJFP80<C4a
0P0`<30204I6AP80EUIF00<0Bd];03dm?@0m?Cd00P1>CTh204=3@`80E5AD101EEED205YJFP80JFUY
0P1`L70206a/K080HV9R0P1PH60205MGE`80DU9B0P1@D5000`1OGel0LG5a075aL@0207YjNP80PX:2
0P23Ph<207moO`80PX:20P1nOWh208V9R@80QXJ60P21PH4208F5Q@80OGem0P21PH4208J6QP80OWin
1`25QHD208V9R@@0QHF50P22PX8E0?ooo`004`3oool208F5Q@80PX:21P25QHD208:2PP@0QHF50`29
RHT208J6QPH0QHF50P29RHT208F5Q@80QXJ61024Q8@208F5Q@80RHV90P22PX8207inOP80Q8B400<0
P82007AdM01dM7@00P1_Kfl2069RHP80Cdm?0P16ATH204M7A`80=CDe0P0c<c<2038b<P80:BTY0P0T
92@2030`<080Ogmo0P1aLG4207IfMP03079bLP1dM7@0M7Ad0080Lg=c0P1_Kfl206e]K@80JVYZ0P1T
I6@2065QH@80GemO0P1GEeL2059BDP@0Cdm?0P1BDU8204m?C`80EEEE0`1IFET205YJFP80Fe]K0P1N
GUh206MWI`80J6QX0P1YJFT406=SH`80HV9R0P1OGel205MGE`80FEUI0P1PH60204I6AP0302l_;`0/
;2`0;2`/00809bLW0P0K6a/201hN7P80;2`/0P0k>c/204U9B@80=SHf0P0h>3P205aLG080F5QH0P1/
K6`20451@@80<c<c0P1:BTX00`1BDU80CTi>04i>CP0204e=C@80Cdm?0P18B4P205YJFP@0Fe]K0P1?
Cdl205eMG@80PX:20P1WIfL205UIF@80GEeM0P1RHV8205]KF`03061PH01MGEd0GEeM0080Ph>30P1i
NGT208:2PP80P8200P28R8P208:2PP80PH610P29RHT20861P@80QHF50P29RHT208F5Q@80QXJ60`25
QHD208:2PP80PH612025QHD208V9RAD0oooo000C0?ooo`80QHF50P22PX8608F5Q@80PX:21025QHD3
08V9R@80QXJ61P25QHD208V9R@80QHF50P26QXH408B4Q080QHF50P29RHT208:2PP80OWin0P24Q8@0
0`20P800M7Ad07AdM00206m_K`80HV9R0P1?Cdl204I6AP80AdM70P0e=CD203<c<`80<S8b0P0Y:BT2
02@T9080<30`0P1oOgl2075aL@80MWIf00<0LW9b07AdM01dM7@00P1cLg<206m_K`80KFe]0P1ZJVX2
06ATI080HF5Q0P1OGel205MGE`80DU9B101?Cdl2059BDP80Cdm?0P1EEED305UIF@80FUYJ0P1KFe/2
05iNGP80IfMW0P1XJ6P206UYJ@@0Hf=S0P1RHV8205mOG`80EeMG0P1IFET2061PH080ATI600<0;bl_
02`/;00/;2`00P0W9bL201/K6`807QhN0P0/;2`203/k>`80BDU90P0f=SH203Ph>080G5aL0P1HF5P2
06a/K080@D510P0c<c<204Y:BP03059BDP1>CTh0CTi>0080CDe=0P1?Cdl204Q8B080FUYJ101KFe/2
04m?C`80GEeM0P22PX8206MWI`80FEUI0P1MGEd2069RHP80Fe]K00<0H61P05eMG@1MGEd00P23Ph<2
07UiN@80PX:20P20P80208R8R080PX:20P21PH4208V9R@80PH610P25QHD208V9R@80QHF50P26QXH3
08F5Q@80PX:20P21PH4808F5Q@80RHV95@3oool001<0oooo0P25QHD208J6QP80PH610P25QHD208:2
PPT0QHF50P26QXH20861P@P0QHF50P29RHT208J6QP80PH610P1lO7`207moO`80QXJ60P20P80207Ui
N@03079bLP1cLg<0Lg=c0080J6QX0P1=CDd204Q8B080>c/k0P0m?Cd203/k>`80;2`/0P0T92@202HV
9P809bLW0P0Y:BT201dM7@80KFe]0P1/K6`00`1ZJVX0K6a/06a/K00406m_K`80JFUY0P1<C4`203De
=@80=cLg0P13@d<204U9B@P0D51@0P15ADD203De=@0303Ph>00e=CD0=CDe0080@410101NGUh2069R
HP80IfMW0P1/K6`206QXJ080IfMW0P1TI6@4061PH080Fe]K0P1FEUH206EUI@0303lo?`0U9BD09BDU
00808R8R0P0J6QX201dM7@8092@T0P0Y:BT205]KF`80K6a/0P10@40206IVIP80HF5Q0P1WIfL207=c
L`80G5aL0P10@4000`1:BTX0FEUI05UIF@020451@@80?clo0P0m?Cd205IFEP80Bd];0P1GEeL206=S
H`80Fe]K0P1eMGD206UYJ@80HF5Q0P1MGEd205EEE@80HV9R00<0Kfm_06ATI01TI6@00P1cLg<207Yj
NP80OGem0P1iNGT207YjNP80Ph>30P21PH4207emO@80QhN70P22PX820861P@80QHF50P29RHT208:2
PP030861P@29RHT0RHV90080PX:20P21PH4208F5Q@80PX:20P21PH4208F5QAD0oooo000C0?ooo`80
QHF50P26QXH20861P@80PX:20P25QHD208:2PP80PH611@25QHD208J6QP80PH610P25QHD208:2PP80
OGem0P1oOgl208F5Q@@0QXJ60P2:RXX20861P@80Ph>30P24Q8@208>3P`0307emO@1VIVH0IVIV0080
GEeM0P1@D5020410@080?Shn0P0e=CD2030`<080<C4a0P0`<30202LW9`80;2`/0P1cLg<207AdM0D0
Kfm_0P1aLG4207=cL`80FEUI0P15ADD205YJFP80H61P0P1dM7@208j>SP80KVi^0P1MGEd206MWI`80
NWYj0P1XJ6P2061PH080G5aL00<0F5QH059BDP1BDU800P0k>c/20410@080FUYJ0P1NGUh206=SH`@0
J6QX0P1SHf<206IVIP80IfMW0P1OGel205]KF`80FUYJ0P1DE5@00`1VIVH0?clo03lo?`0201lO7`80
71`L0P0F5QH202<S8`805ADE0P0J6QX207MgM`80B4Q80P0h>3P205=CD`80C4a<0P1/K6`206EUI@80
FEUI00<0EUIF0492@P12@T800P1<C4`2055AD@80BTY:0P1;Bd/205]KF`80Cdm?0P1JFUX2065QH@80
Kfm_0P1YJFT20492@P80CDe=0P1EEED2051@D00306MWI`28R8P0R8R80080Ogmo1P20P80208Z:RP80
PH611022PX820861P@80QXJ60P21PH4208:2PP80OWin0`25QHD208:2PP@0QHF51022PX820861P@80
PX:25@3oool001<0oooo0P25QHD208J6QP80PH610P22PX8208F5Q@80PX:20P21PH4508F5Q@80QXJ6
0P21PH4208F5Q@80PX:20P1mOGd207moO`80QHF51026QXH208Z:RP80PH610P23Ph<208B4Q080Ph>3
00<0OGem06IVIP1VIVH00P1MGEd2051@D080@4100P0n?Sh203De=@80<30`0P0a<C42030`<0809bLW
0P0/;2`207=cL`80M7Ad1@1_Kfl2075aL@80Lg=c0P1IFET204E5A@80FUYJ0P1PH60207AdM080SXj>
0P1^KVh205eMG@80IfMW0P1jNWX206QXJ080H61P0P1LG5`00`1HF5P0DU9B059BDP0203/k>`80@410
0P1JFUX205iNGP80Hf=S101XJ6P206=SH`80IVIV0P1WIfL205mOG`80Fe]K0P1JFUX205ADE00306IV
IP0o?cl0?clo00807alO0P0L71`201HF5P808b<S0P0E5AD201XJ6P80MgMg0P18B4P203Ph>080De=C
0P1<C4`206a/K080IFEU0P1IFET00`1FEUH0@T920492@P0204a<C080DE5A0P1:BTX204];B`80Fe]K
0P1?Cdl205YJFP80HF5Q0P1_Kfl206UYJ@80@T920P1=CDd205EEE@80D51@00<0IfMW08R8R028R8P0
0P1oOgl60820P080RXZ:0P21PH4408:2PP80PH610P26QXH20861P@80PX:20P1nOWh308F5Q@80PX:2
1025QHD408:2PP80PH610P22PX8E0?ooo`004`3oool207inOP80QHF50P22PX8208F5Q@80PX:20P25
QHD208:2PP80PH6100<0PX:207inOP1nOWh00P25QHD208:2PP80OWin0P22PX8208B4Q0@0OWin0P21
PH4207moO`80QHF50P26QXH407moO`80KFe]00<0G5aL05ADE01DE5@00P1=CDd204];B`80=cLg100a
<C4203Ti>@807alO0P0P820202DU9@80@d=30P0n?Sh407IfMP80Lg=c00<0L71`06][J`1[Jf/00P1^
KVh206EUI@80DE5A0P1DE5@2055AD@80<S8b0P0f=SH204A4A080BTY:0P0m?Cd202d];@80>3Ph0P0d
=3@203Ti>@0304a<C01GEeL0EeMG0080CTi>0P0e=CD203Xj>P80H61P0P1TI6@206MWI`80K6a/0P1]
KFd206QXJ080Hf=S0P1OGel2061PH0@0GEeM00<0Fe]K061PH01PH6000P0g=cL202TY:@8051@D0P0E
5AD203/k>`80:RXZ0P10@40205iNGP80>SXj0P1YJFT2051@D080CTi>0P29RHT2075aL@030492@P1F
EUH0EUIF0080Cdm?0P16ATH203dm?@80BTY:0P1EEED205ADE080De=C0P1GEeL206IVIP80L71`0P1Q
HF4205UIF@@0De=C00<0EEEE07emO@1mOGd00P1mOGd207moO`80OWin0P1jNWX208F5Q@80RXZ:1029
RHT208F5Q@80RHV90P22PX8208F5Q@80RHV90`25QHD208V9R@@0QHF51029RHT208F5Q@80RHV95@3o
ool001<0oooo0P1nOWh208F5Q@80PX:20P25QHD208:2PP80QHF50P22PX820861P@0308:2PP1nOWh0
OWin0080QHF50P22PX8207inOP80PX:20P24Q8@407inOP80PH610P1oOgl208F5Q@80QXJ6101oOgl2
06e]K@0305aLG01DE5@0E5AD0080CDe=0P1;Bd/203Lg=`@0<C4a0P0i>CT201lO7`80820P0P0U9BD2
04=3@`80?Shn101fMWH207=cL`03071`L01[Jf/0Jf][0080KVi^0P1UIFD2055AD@80E5AD0P1ADE42
038b<P80=SHf0P14A4@204Y:BP80?Cdm0P0];Bd203Ph>080=3@d0P0i>CT00`1<C4`0EeMG05MGE`02
04i>CP80=CDe0P0j>SX2061PH080I6AT0P1WIfL206a/K080KFe]0P1XJ6P206=SH`80GemO0P1PH604
05eMG@0305]KF`1PH600H61P0080=cLg0P0Y:BT201@D50805ADE0P0k>c/202XZ:P80@4100P1NGUh2
03Xj>P80JFUY0P1@D50204i>CP80RHV90P1aLG400`12@T80EUIF05IFEP0204m?C`80ATI60P0m?Cd2
04Y:BP80EEEE0P1DE5@205=CD`80EeMG0P1VIVH2071`L080HF5Q0P1IFET405=CD`0305EEE@1mOGd0
OGem0080OGem0P1oOgl207inOP80NWYj0P25QHD208Z:RP@0RHV90P25QHD208V9R@80PX:20P25QHD2
08V9R@<0QHF50P29RHT408F5Q@@0RHV90P25QHD208V9RAD0oooo000C0?ooo`80RHV90P25QHD208V9
R@80QHF50P26QXH207inOP80QHF51@22PX820861P@80QXJ61022PX8208F5Q@80RHV90P26QXH208B4
Q080PH610P22PX8208B4Q080OWin0P26QXH2079bLP0306IVIP1JFUX0FUYJ0080Bd];0P0j>SX203De
=@80<c<c0P0b<S8201lO7`80;2`/0P0T92@203De=@80FEUI0P1dM7@207=cL`@0Kfm_00<0L71`05UI
F@1IFET00P0o?cl204Q8B080:RXZ0P0R8R8202XZ:P80=cLg0P0f=SH2030`<080;bl_0P0e=CD202/[
:`8092@T0P0R8R8202XZ:P0301PH600O7al07alO00808b<S0P0T92@201PH6080:BTY0P1ADE4406MW
I`@0Hf=S0P1XJ6P206=SH`80Fe]K101PH6000`1JFUX0DU9B059BDP0204e=C@8061PH0P0B4Q8201hN
7P8092@T0P0R8R8203@d=080IVIV0P10@402034a<@80EUIF0P11@D4204m?C`80Ti>C00<0PX:205iN
GP1NGUh00P18B4P2051@D080CTi>0P15ADD204i>CP80@T920P1>CTh205iNGP80JVYZ0P1nOWh206m_
K`80Hf=S0P1VIVH205eMG@0305QHF01hN7P0N7Qh0080Ng]k0P1oOgl208J6QP80O7al0P1nOWh208F5
Q@80PX:20P21PH4208:2PP80PH610P29RHT;08F5Q@80PX:20P21PH4208:2PP80PH610P25QHDE0?oo
o`004`3oool208V9R@80QHF50P29RHT208F5Q@80QXJ60P1nOWh208F5Q@D0PX:20P21PH4208J6QP@0
PX:20P25QHD208V9R@80QXJ60P24Q8@20861P@80PX:20P24Q8@207inOP80QXJ60P1bLW800`1VIVH0
FUYJ05YJFP0204];B`80>SXj0P0e=CD203<c<`80<S8b0P0O7al202`/;08092@T0P0e=CD205UIF@80
M7Ad0P1cLg<406m_K`03071`L01IFET0FEUI0080?clo0P18B4P202XZ:P808R8R0P0Z:RX203Lg=`80
=SHf0P0`<30202l_;`80=CDe0P0[:b/202@T90808R8R0P0Z:RX00`0H61P07alO01lO7`0202<S8`80
92@T0P0H61P202TY:@80DE5A101WIfL406=SH`80J6QX0P1SHf<205]KF`@0H61P00<0FUYJ059BDP1B
DU800P1=CDd201PH60804Q8B0P0N7Qh202@T90808R8R0P0d=3@206IVIP80@4100P0a<C4205IFEP80
@D510P1?Cdl209>CT`0308:2PP1NGUh0GUiN0080B4Q80P1@D50204i>CP80ADE50P1>CTh20492@P80
CTi>0P1NGUh206YZJP80OWin0P1_Kfl206=SH`80IVIV0P1MGEd00`1HF5P0N7Qh07QhN00207]kN`80
Ogmo0P26QXH207alO080OWin0P25QHD208:2PP80PH610P22PX820861P@80RHV92`25QHD208:2PP80
PH610P22PX820861P@80QHF55@3oool001<0oooo1P1nOWh20861P@80RHV90P26QXH207inOP80QHF5
00<0QXJ608F5Q@25QHD00P22PX8208F5Q@80QXJ60P25QHD208:2PP80OWin1022PX8207inOP@0PH61
0P1mOGd20820P080M7Ad00<0HV9R04U9B@19BDT00P0n?Sh2034a<@80=cLg0P0`<30202h^;P80<c<c
0P0_;bl2038b<P80IFEU0P1cLg<2071`L080Kfm_0P1hN7P207EeM@03071`L024Q8@0Q8B40080RHV9
0P23Ph<206][J`80FUYJ0P1=CDd204M7A`80CDe=0P1>CTh205QHF080EEEE0P1@D50205MGE`80DU9B
0P1>CTh00`1IFET0Jf][06][J`0208b<S080UIFE0P2>SXh207=cL`80HV9R0P1WIfL206ATI080IVIV
101TI6@206YZJP80H61P0P1LG5`205]KF`03065QH@1KFe/0Fe]K0080EEEE0P0e=CD201DE5@803@d=
0P0H61P202XZ:P80;Rh^0P0n?Sh207QhN080>3Ph0P1@D50204U9B@80@T920P1QHF400`2<S8`0Fe]K
05]KF`02055AD@80Cdm?0P1>CTh204Y:BP@0Cdm?0P17AdL205MGE`80GemO0P1aLG4206QXJ080E5AD
0P1SHf<206IVIP0307QhN01jNWX0NWYj0080OWin0P1hN7P207YjNP80QHF5101nOWh408F5Q@80RHV9
0P25QHD208:2PP80PH610P25QHD208:2PP030861P@25QHD0QHF50080PX:21025QHD208J6QP80PH61
0P25QHDE0?ooo`004`3oool607inOP80PH610P29RHT208J6QP80OWin0P25QHD00`26QXH0QHF508F5
Q@0208:2PP80QHF50P26QXH208F5Q@80PX:20P1nOWh408:2PP80OWin1021PH4207emO@80P8200P1d
M7@00`1RHV80BDU904U9B@0203hn?P80<C4a0P0g=cL2030`<080;Rh^0P0c<c<202l_;`80<S8b0P1U
IFD207=cL`80L71`0P1_Kfl207QhN080MGEe00<0L71`08B4Q024Q8@00P29RHT208>3P`80Jf][0P1J
FUX204e=C@80AdM70P1=CDd204i>CP80F5QH0P1EEED2051@D080EeMG0P1BDU8204i>CP0305UIF@1[
Jf/0Jf][0080S8b<0P2EUID208j>SP80Lg=c0P1RHV8206MWI`80I6AT0P1VIVH406ATI080JVYZ0P1P
H60205aLG080Fe]K00<0HF5Q05]KF`1KFe/00P1EEED203De=@805ADE0P0=3@d201PH6080:RXZ0P0^
;Rh203hn?P80N7Qh0P0h>3P2051@D080BDU90P12@T82065QH@0308b<S01KFe/0Fe]K0080DE5A0P1?
Cdl204i>CP80BTY:101?Cdl204M7A`80EeMG0P1OGel2075aL@80J6QX0P1DE5@206=SH`80IVIV00<0
N7Qh07YjNP1jNWX00P1nOWh207QhN080NWYj0P25QHD407inOP@0QHF50P29RHT208F5Q@80PX:20P21
PH4208F5Q@80PX:200<0PH6108F5Q@25QHD00P22PX8408F5Q@80QXJ60P21PH4208F5QAD0oooo000C
0?ooo`80RHV90P26QXH208:2PP80PH610P22PX8208F5Q@80RHV90P25QHD00`26QXH0PH610861P@02
08J6QP80PH610P29RHT208F5Q@@0RHV90P25QHD208>3P`80QXJ60P21PH4207inOP80PX:20P1kNg/2
06][J`0305QHF012@T80@T920080@T920P10@402030`<080;bl_0P0Z:RX202/[:`80;2`/0P0b<S82
01hN7P80Kfm_101bLW8206e]K@80LW9b00<0Lg=c07YjNP1jNWX00P1hN7P209NGU`80[Jf]0P2d];@2
0;2`/080XZ:R0P2b/[820:ZZZP80UIFE0P2][Jd20;Rh^080/K6a0P2XZ:P20:2PX00309JFUP1kNg/0
Ng]k0080MWIf0P1bLW8406e]K@@0J6QX0P1[Jf/206QXJ080IFEU0P1QHF4206=SH`80IFEU0P1PH603
05]KF`80GEeM0P1JFUX204Q8B0809bLW0P0=3@d202LW9`80;Bd]0P0X:2P202HV9P80?clo0P17AdL2
03<c<`80ATI60P0Z:RX204U9B@03061PH021PH40PH610080HV9R0P1GEeL204a<C080?Cdm0P17AdL2
05eMG@@0D51@0P1BDU8206YZJP80LW9b0P1ADE42051@D080BDU900<0MWIf07alO01lO7`00P1mOGd2
07inOP80OGem1029RHT208J6QP80PH611P25QHD208V9R@80QHF50P22PX8208F5Q@0308:2PP21PH40
PH610080RHV90P25QHD208:2PPH0QHF55@3oool001<0oooo0P29RHT208J6QP80PX:20P21PH4208:2
PP80QHF50P29RHT208F5Q@0308J6QP21PH40PH610080QXJ60P21PH4208V9R@80QHF51029RHT208F5
Q@80Ph>30P26QXH20861P@80OWin0P22PX8207]kN`80Jf][00<0F5QH0492@P12@T800P12@T820410
@080<30`0P0_;bl202XZ:P80:b/[0P0/;2`2038b<P807QhN0P1_Kfl4079bLP80KFe]0P1bLW800`1c
Lg<0NWYj07YjNP0207QhN080UiNG0P2][Jd20;Bd]080/;2`0P2RXZ820;:b/P80ZZZZ0P2EUID20:f]
[@80^;Rh0P2a/K420:RXZ080X:2P00<0UYJF07]kN`1kNg/00P1fMWH2079bLP@0KFe]101XJ6P206][
J`80J6QX0P1UIFD2065QH@80Hf=S0P1UIFD2061PH0<0Fe]K0P1MGEd205YJFP80B4Q80P0W9bL200d=
3@809bLW0P0];Bd202PX:0809RHV0P0o?cl204M7A`80<c<c0P16ATH202XZ:P80BDU900<0H61P0861
P@21PH400P1RHV8205MGE`80C4a<0P0m?Cd204M7A`80GEeM101@D502059BDP80JVYZ0P1bLW82055A
D@80D51@0P19BDT00`1fMWH0O7al07alO00207emO@80OWin0P1mOGd408V9R@80QXJ60P21PH4608F5
Q@80RHV90P25QHD208:2PP80QHF500<0PX:20861P@21PH400P29RHT208F5Q@80PX:21P25QHDE0?oo
o`004`3oool207inOP80QHF50P29RHT208F5Q@80RHV90P25QHD208:2PP80PH6100<0RHV908F5Q@25
QHD00P26QXH20861P@80PX:20P1nOWh20861P@80QHF50P27QhL207emO@80PH610P25QHD207moO`80
KVi^0P1VIVH2069RHP0304m?C`0o?cl0?clo00@0;bl_0P0`<302028R8P80:BTY0P0];Bd202/[:`80
GEeM0P1RHV8207IfMP@0LW9b0P1fMWH2079bLP0307AdM01bLW80LW9b0080KVi^0P1dM7@207=cL`80
MGEe0P1lO7`207emO@80Lg=c0P1hN7P206m_K`80JVYZ0P1VIVH206MWI`80GemO0P1TI6@00`1XJ6P0
IfMW06MWI`0406][J`80Lg=c0P1`L70206QXJ080JVYZ0P1[Jf/206QXJ080IfMW0P1UIFD206=SH`@0
H61P0P1EEED00`1DE5@0EUIF05IFEP0205ADE080AdM70P0P820201TI6@807AdM0P0b<S8404Q8B080
Bd];0P1@D50202/[:`80B4Q80P1CDe<204I6AP03069RHP23Ph<0Ph>30080O7al0P1NGUh205MGE`80
FUYJ0P17AdL203`l?080>c/k0P1:BTX2059BDP80JVYZ0P1`L70206=SH`80I6AT0P1;Bd/00`1mOGd0
NGUi07UiN@0207IfMP80PH610P1oOgl408F5Q@80QXJ60P21PH4208F5Q@80PX:2101nOWh20861P@80
RHV90P25QHD00`29RHT0QHF508F5Q@0408F5Q@80RHV91025QHD208:2PQD0oooo000C0?ooo`80OWin
0P25QHD208V9R@80QHF50P29RHT208F5Q@80PX:20P21PH400`29RHT0QHF508F5Q@0208J6QP80PH61
0P22PX8207inOP80PH610P25QHD208N7Q`80OGem0P21PH4208F5Q@80Ogmo0P1^KVh206IVIP80HV9R
00<0Cdm?03lo?`0o?cl0100_;bl2030`<0808R8R0P0Y:BT202d];@80:b/[0P1MGEd2069RHP80MWIf
101bLW8207IfMP80LW9b00<0M7Ad079bLP1bLW800P1^KVh207AdM080Lg=c0P1eMGD207alO080OGem
0P1cLg<207QhN080Kfm_0P1ZJVX206IVIP80IfMW0P1OGel206ATI00306QXJ01WIfL0IfMW00@0Jf][
0P1cLg<2071`L080J6QX0P1ZJVX206][J`80J6QX0P1WIfL206EUI@80Hf=S101PH60205EEE@0305AD
E01FEUH0EUIF0080E5AD0P17AdL2020P80806ATI0P0M7Ad2038b<P@0B4Q80P1;Bd/2051@D080:b/[
0P18B4P205=CD`80ATI600<0HV9R08>3P`23Ph<00P1lO7`205iNGP80EeMG0P1JFUX204M7A`80?3`l
0P0k>c/204Y:BP80DU9B0P1ZJVX2071`L080Hf=S0P1TI6@204];B`0307emO@1iNGT0NGUi0080MWIf
0P21PH4207moO`@0QHF50P26QXH20861P@80QHF50P22PX8407inOP80PH610P29RHT208F5Q@0308V9
R@25QHD0QHF500@0QHF50P29RHT408F5Q@80PX:25@3oool001<0oooo0P22PX820861P@80PX:21P1n
OWh208F5Q@80PH6100<0Ogmo08F5Q@25QHD00P29RHT208F5Q@80QXJ60P25QHD208:2PP80PH610P26
QXH208B4Q0@0PH610P29RHT208b<S080H61P0P19BDT00`0o?cl0@4100410@00203Hf=P80;Rh^0P0U
9BD202l_;`@0;Bd]0P0_;bl202XZ:P80LW9b0P1`L70206m_K`80MGEe0P1aLG4207=cL`03071`L01h
N7P0N7Qh0080LW9b0P1dM7@2071`L080M7Ad0P1`L70207AdM080Kfm_0P1dM7@206m_K`@0KVi^0P1`
L70206YZJP80Kfm_00<0K6a/06QXJ01XJ6P00P1[Jf/206a/K080J6QX0P1_Kfl2075aL@H0IFEU0P1W
IfL206QXJ080Hf=S0P1LG5`2065QH@80IVIV00<0Fe]K05IFEP1FEUH00P1KFe/2051@D080?3`l0P0Z
:RX200l?3`807QhN0P0S8b<2030`<0809bLW1015ADD203Lg=`80@D510P0j>SX00`1BDU80I6AT06AT
I00205mOG`80HV9R0P1IFET404i>CP80CDe=0P1<C4`204Y:BP80Cdm?0P1KFe/2079bLP80E5AD0P1K
Fe/204Q8B003075aL@23Ph<0Ph>30080MGEe0P1bLW8208:2PP80PH610P25QHD208J6QP80PH610P22
PX8208F5Q@@0RHV90P25QHD208:2PP80PH610`25QHD208:2PP80OWin0P21PH4408F5Q@80RHV95@3o
ool001<0oooo0P22PX820861P@80PX:21P1nOWh208F5Q@80PH6100<0Ogmo08F5Q@25QHD00P29RHT2
08F5Q@80QXJ60P25QHD208:2PP80PH610P26QXH208B4Q0@0PH610P29RHT208b<S080H61P0P19BDT0
0`0o?cl0@4100410@00203Hf=P80;Rh^0P0U9BD202l_;`@0;Bd]0P0_;bl202XZ:P80LW9b0P1`L702
06m_K`80MGEe0P1aLG4207=cL`03071`L01hN7P0N7Qh0080LW9b0P1dM7@2071`L080M7Ad0P1`L702
07AdM080Kfm_0P1dM7@206m_K`@0KVi^0P1`L70206YZJP80Kfm_00<0K6a/06QXJ01XJ6P00P1[Jf/2
06a/K080J6QX0P1_Kfl2075aL@H0IFEU0P1WIfL206QXJ080Hf=S0P1LG5`2065QH@80IVIV00<0Fe]K
05IFEP1FEUH00P1KFe/2051@D080?3`l0P0Z:RX200l?3`807QhN0P0S8b<2030`<0809bLW1015ADD2
03Lg=`80@D510P0j>SX00`1BDU80I6AT06ATI00205mOG`80HV9R0P1IFET404i>CP80CDe=0P1<C4`2
04Y:BP80Cdm?0P1KFe/2079bLP80E5AD0P1KFe/204Q8B003075aL@23Ph<0Ph>30080MGEe0P1bLW82
08:2PP80PH610P25QHD208J6QP80PH610P22PX8208F5Q@@0RHV90P25QHD208:2PP80PH610`25QHD2
08:2PP80OWin0P21PH4408F5Q@80RHV95@3oool001<0oooo0P29RHT208:2PP80QHF50P26QXH208:2
PP@0QHF50P2:RXX00`22PX80PH610861P@0408F5Q@80RHV90P25QHD208V9R@80QHF50P29RHT208J6
QP80Q8B40P21PH42071`L080K6a/0P1WIfL204m?C`0304I6AP0_;bl0;bl_0080=cLg0P0X:2P202d]
;@808R8R0P0W9bL202l_;`809RHV0P0>3Ph4071`L080Kfm_0P1bLW8407MgM`03075aL@1bLW80LW9b
00H0M7Ad101bLW8207AdM080LG5a0P1^KVh206QXJ080IVIV0P1XJ6P206ATI080H61P0P1UIFD00`1[
Jf/0IFEU06EUI@0206e]K@80Jf][0P1bLW82069RHP80LG5a0P1iNGT207AdM080Jf][0P1UIFD206IV
IP80IFEU0P1SHf<405]KF`0305QHF01>CTh0CTi>0080D51@0P1CDe<203/k>`806a/K0P0M7Ad2028R
8P80=SHf0P0n?Sh204A4A080BTY:0P1;Bd/4030`<080>SXj00<0?Shn04E5A@15ADD00P1jNWX207Mg
M`80Fe]K0P1=CDd204Q8B080A4A40P1NGUh2055AD@80E5AD0P1GEeL206a/K080Fe]K0P1QHF4206a/
K003079bLP1nOWh0OWin0080RXZ:0P1gMgL608F5Q@80RHV90P25QHD208V9R@80PX:20P21PH4408F5
Q@80QXJ60P21PH400`22PX80PH610861P@0408V9R@P0QHF55@3oool001<0oooo0P29RHT208:2PP80
QHF50P26QXH208:2PP@0QHF50P2:RXX00`22PX80PH610861P@0408F5Q@80RHV90P25QHD208V9R@80
QHF50P29RHT208J6QP80Q8B40P21PH42071`L080K6a/0P1WIfL204m?C`0304I6AP0_;bl0;bl_0080
=cLg0P0X:2P202d];@808R8R0P0W9bL202l_;`809RHV0P0>3Ph4071`L080Kfm_0P1bLW8407MgM`03
075aL@1bLW80LW9b00H0M7Ad101bLW8207AdM080LG5a0P1^KVh206QXJ080IVIV0P1XJ6P206ATI080
H61P0P1UIFD00`1[Jf/0IFEU06EUI@0206e]K@80Jf][0P1bLW82069RHP80LG5a0P1iNGT207AdM080
Jf][0P1UIFD206IVIP80IFEU0P1SHf<405]KF`0305QHF01>CTh0CTi>0080D51@0P1CDe<203/k>`80
6a/K0P0M7Ad2028R8P80=SHf0P0n?Sh204A4A080BTY:0P1;Bd/4030`<080>SXj00<0?Shn04E5A@15
ADD00P1jNWX207MgM`80Fe]K0P1=CDd204Q8B080A4A40P1NGUh2055AD@80E5AD0P1GEeL206a/K080
Fe]K0P1QHF4206a/K003079bLP1nOWh0OWin0080RXZ:0P1gMgL608F5Q@80RHV90P25QHD208V9R@80
PX:20P21PH4408F5Q@80QXJ60P21PH400`22PX80PH610861P@0408V9R@P0QHF55@3oool001<0oooo
0P25QHD208V9R@80QHF51029RHT608F5Q@0308V9R@22PX80PX:20080PH611P25QHD208:2PP@0OWin
0P25QHD208V9R@80PX:20P1mOGd205iNGP80G5aL0P1:BTX00`0l?3`0@d=304=3@`0202h^;P80<C4a
0P0];Bd2038b<P80;Bd]0P0T92@204e=C@80?clo0P1^KVh4071`L0H0M7Ad00<0NWYj07QhN01hN7P0
101bLW8207AdM080MGEe0P1_Kfl206YZJP80J6QX0P1KFe/205YJFP80De=C0P1PH60205mOG`80FUYJ
0P1LG5`00`1TI6@0IVIV06IVIP0406MWI`80LG5a0P1gMgL206m_K`80JVYZ0P1[Jf/206UYJ@80J6QX
101SHf<4061PH080G5aL00<0HV9R065QH@1QHF400P1BDU8204U9B@80ADE50P0_;bl202PX:0808b<S
0P0Y:BT202d];@80=SHf0P0d=3@20492@P80>SXj0P0f=SH202@T900303hn?P1]KFd0KFe]0080EEEE
0P1HF5P206EUI@80EEEE0P1HF5P203dm?@80BTY:0P1>CTh205UIF@80EeMG0P1aLG4206UYJ@80EEEE
0P1_Kfl00`1WIfL0Q8B408B4Q00208F5Q@80RHV92025QHD208:2PP80PH610P29RHT608F5Q@80RHV9
0`22PX820861P@80QHF50P22PX820861P@H0QHF55@3oool001<0oooo0P25QHD208V9R@80QHF51029
RHT608F5Q@0308V9R@22PX80PX:20080PH611P25QHD208:2PP@0OWin0P25QHD208V9R@80PX:20P1m
OGd205iNGP80G5aL0P1:BTX00`0l?3`0@d=304=3@`0202h^;P80<C4a0P0];Bd2038b<P80;Bd]0P0T
92@204e=C@80?clo0P1^KVh4071`L0H0M7Ad00<0NWYj07QhN01hN7P0101bLW8207AdM080MGEe0P1_
Kfl206YZJP80J6QX0P1KFe/205YJFP80De=C0P1PH60205mOG`80FUYJ0P1LG5`00`1TI6@0IVIV06IV
IP0406MWI`80LG5a0P1gMgL206m_K`80JVYZ0P1[Jf/206UYJ@80J6QX101SHf<4061PH080G5aL00<0
HV9R065QH@1QHF400P1BDU8204U9B@80ADE50P0_;bl202PX:0808b<S0P0Y:BT202d];@80=SHf0P0d
=3@20492@P80>SXj0P0f=SH202@T900303hn?P1]KFd0KFe]0080EEEE0P1HF5P206EUI@80EEEE0P1H
F5P203dm?@80BTY:0P1>CTh205UIF@80EeMG0P1aLG4206UYJ@80EEEE0P1_Kfl00`1WIfL0Q8B408B4
Q00208F5Q@80RHV92025QHD208:2PP80PH610P29RHT608F5Q@80RHV90`22PX820861P@80QHF50P22
PX820861P@H0QHF55@3oool001<0oooo0P1nOWh20861P@P0QHF50P22PX820861P@<0PX:20P21PH42
08F5Q@80PX:20P21PH4408V9R@80QHF50P1oOgl208:2PP80RHV90P24Q8@2065QH@80ADE50P0o?cl0
0`0`<300:b/[02/[:`02030`<0809BDU0P0Q8B4202TY:@80;Bd]0P0U9BD203Ti>@@0L71`0P1aLG42
071`L0H0M7Ad00<0L71`07AdM01dM7@00P1dM7@2075aL@@0M7Ad0P1eMGD206UYJ@80IfMW0P1ZJVX2
06ATI080EeMG0P1LG5`205]KF`80EUIF0P1LG5`00`1NGUh0HF5Q065QH@0206=SH`80J6QX0P1UIFD2
06MWI`80KVi^0P1fMWH2071`L080LG5a0P1eMGD206][J`80J6QX0P1SHf<2061PH0<0Fe]K0P1DE5@4
05=CD`80A4A40P0[:b/200/;2`804A4A0P0N7Qh202l_;`80<c<c0P0e=CD203Hf=P80BDU90P0l?3`2
038b<P0302LW9`15ADD0ADE50080Cdm?0P1/K6`207AdM080DU9B0P1LG5`2055AD@80BTY:0P17AdL2
04Y:BP80DE5A0P1^KVh20820P080G5aL0P1lO7`00`1TI6@0J6QX06QXJ00206UYJ@X0QHF50P26QXH2
0861P@X0QHF50`29RHT408F5Q@80QXJ60P21PH4608F5QAD0oooo000C0?ooo`80OWin0P21PH4808F5
Q@80PX:20P21PH4308:2PP80PH610P25QHD208:2PP80PH611029RHT208F5Q@80Ogmo0P22PX8208V9
R@80Q8B40P1QHF4204E5A@80?clo00<0<30`02/[:`0[:b/00P0`<30202DU9@808B4Q0P0Y:BT202d]
;@809BDU0P0i>CT4071`L080LG5a0P1`L70607AdM003071`L01dM7@0M7Ad0080M7Ad0P1aLG4407Ad
M080MGEe0P1YJFT206MWI`80JVYZ0P1TI6@205MGE`80G5aL0P1KFe/205IFEP80G5aL00<0GUiN065Q
H@1QHF400P1SHf<206QXJ080IFEU0P1WIfL206i^KP80MWIf0P1`L702075aL@80MGEe0P1[Jf/206QX
J080Hf=S0P1PH60305]KF`80E5AD101CDe<204A4A080:b/[0P0;2`/2014A4@807QhN0P0_;bl203<c
<`80=CDe0P0f=SH204U9B@80?3`l0P0b<S800`0W9bL0ADE504E5A@0204m?C`80K6a/0P1dM7@2059B
DP80G5aL0P1ADE4204Y:BP80AdM70P1:BTX2055AD@80KVi^0P20P80205aLG080O7al00<0I6AT06QX
J01XJ6P00P1YJFT:08F5Q@80QXJ60P21PH4:08F5Q@<0RHV91025QHD208J6QP80PH611P25QHDE0?oo
o`004`3oool208V9R@X0QHF50P29RHT208:2PP0308F5Q@29RHT0RHV90080QHF50P22PX8808F5Q@80
RXZ:0P25QHD208V9R@80PH610P1gMgL205QHF080@4100P0b<S800`0a<C409BDU02DU9@0202TY:@80
;Rh^0P0`<30202`/;0808B4Q0P0P820200`<3080KVi^101]KFd206i^KP80LG5a0P1cLg<207]kN`03
07QhN01dM7@0M7Ad0080MWIf0P1aLG4207=cL`80GemO0P0o?cl2055AD@80O7al0P1cLg<2071`L080
@T920P0Y:BT203Lg=`80CDe=0P14A4@00`10@400EEEE05EEE@02069RHP80JVYZ0P1fMWH206m_K`@0
L71`0P1gMgL206UYJ@@0J6QX0P1VIVH406EUI@80H61P00<0Fe]K065QH@1QHF400P1FEUH204Q8B080
AdM70P0g=cL401LG5`806ATI0P0S8b<202PX:080=CDe0P0c<c<20492@P80=3@d0P12@T800`0S8b<0
>SXj03Xj>P0205MGE`80BTY:0P1YJFT205iNGP80CTi>0P11@D4203Ph>080ADE50P1?Cdl205MGE`80
JVYZ0P1mOGd206m_K`80H61P00<0Kfm_079bLP1bLW803025QHD208V9RA<0QHF50P29RHT408F5Q@80
PX:20P21PH4E0?ooo`004`3oool208V9R@X0QHF50P29RHT208:2PP0308F5Q@29RHT0RHV90080QHF5
0P22PX8808F5Q@80RXZ:0P25QHD208V9R@80PH610P1gMgL205QHF080@4100P0b<S800`0a<C409BDU
02DU9@0202TY:@80;Rh^0P0`<30202`/;0808B4Q0P0P820200`<3080KVi^101]KFd206i^KP80LG5a
0P1cLg<207]kN`0307QhN01dM7@0M7Ad0080MWIf0P1aLG4207=cL`80GemO0P0o?cl2055AD@80O7al
0P1cLg<2071`L080@T920P0Y:BT203Lg=`80CDe=0P14A4@00`10@400EEEE05EEE@02069RHP80JVYZ
0P1fMWH206m_K`@0L71`0P1gMgL206UYJ@@0J6QX0P1VIVH406EUI@80H61P00<0Fe]K065QH@1QHF40
0P1FEUH204Q8B080AdM70P0g=cL401LG5`806ATI0P0S8b<202PX:080=CDe0P0c<c<20492@P80=3@d
0P12@T800`0S8b<0>SXj03Xj>P0205MGE`80BTY:0P1YJFT205iNGP80CTi>0P11@D4203Ph>080ADE5
0P1?Cdl205MGE`80JVYZ0P1mOGd206m_K`80H61P00<0Kfm_079bLP1bLW803025QHD208V9RA<0QHF5
0P29RHT408F5Q@80PX:20P21PH4E0?ooo`004`3oool407inOP80PH610P22PX8207inOP80PH610P25
QHD208V9R@0308F5Q@22PX80PX:20080OWin0P25QHD208:2PP80PH612025QHD208:2PP80Ogmo0P1[
Jf/204];B`@0@T9200<0<c<c038b<P0b<S800P0U9BD202PX:080;2`/0P0U9BD2024Q8@80<S8b0P0R
8R84079bLP80N7Qh0P1gMgL207]kN`80KFe]0P1_Kfl00`1eMGD0L71`071`L002079bLP80MGEe0P1d
M7@209FEU@80Vi^K0P1bLW8207=cL`80NWYj0P1gMgL208n?S`80RXZ:0P1jNWX2071`L080P82000<0
F5QH04];B`1;Bd/00P1IFET206IVIP80L71`1P1_Kfl206YZJP80Kfm_0P1hN7P207EeM@80JFUY0P1X
J6P206=SH`80H61P00<0EeMG05IFEP1FEUH0101FEUH204a<C080ATI60P0A4A4200l?3`805ADE0P0N
7Qh202XZ:P80<c<c0P0];Bd203Ti>@80>c/k0P0_;bl00`0K6a/09RHV02HV9P02059BDP80Cdm?0P1K
Fe/2061PH080BTY:0P1>CTh203dm?@80CDe=0P1;Bd/204Y:BP80Hf=S0P1IFET206e]K@80@d=30`25
QHD208:2PP80PH612025QHD208:2PP80PH611P25QHD208:2PP80PH611`25QHD208:2PP80OWin0P21
PH4208V9R@80QHF55@3oool001<0oooo101nOWh20861P@80PX:20P1nOWh20861P@80QHF50P29RHT0
0`25QHD0PX:208:2PP0207inOP80QHF50P22PX820861P@P0QHF50P22PX8207moO`80Jf][0P1;Bd/4
0492@P0303<c<`0b<S80<S8b00809BDU0P0X:2P202`/;0809BDU0P0Q8B42038b<P808R8R101bLW82
07QhN080MgMg0P1kNg/206e]K@80Kfm_00<0MGEe071`L01`L7000P1bLW8207EeM@80M7Ad0P2EUID2
09^KV`80LW9b0P1cLg<207YjNP80MgMg0P2?Shl208Z:RP80NWYj0P1`L7020820P00305QHF01;Bd/0
Bd];0080FEUI0P1VIVH2071`L0H0Kfm_0P1ZJVX206m_K`80N7Qh0P1eMGD206UYJ@80J6QX0P1SHf<2
061PH00305MGE`1FEUH0EUIF00@0EUIF0P1<C4`204I6AP804A4A0P0?3`l201DE5@807QhN0P0Z:RX2
03<c<`80;Bd]0P0i>CT203/k>`80;bl_00<06a/K02HV9P0V9RH00P1BDU8204m?C`80Fe]K0P1PH602
04Y:BP80CTi>0P0m?Cd204e=C@80Bd];0P1:BTX206=SH`80FEUI0P1]KFd204=3@`<0QHF50P22PX82
0861P@P0QHF50P22PX820861P@H0QHF50P22PX820861P@L0QHF50P22PX8207inOP80PH610P29RHT2
08F5QAD0oooo000C0?ooo`@0RHV90P25QHD408V9R@80QHF50P22PX820861P@0308F5Q@26QXH0QXJ6
0080PX:20P21PH4208V9R@@0QHF50P21PH4207moO`80QHF50P29RHT208F5Q@80KVi^0P13@d<203Ph
>0808b<S00<0:2PX02l_;`0_;bl00P0^;Rh202d];@80;bl_0P0Q8B4201dM7@80=SHf0P0k>c/4071`
L080KVi^0P1_Kfl207YjNP80OWin0P1gMgL00`1mOGd0MgMg07MgM`0207IfMP80LG5a0P1_Kfl207Ee
M@80MWIf101lO7`207YjNP80O7al0P1fMWH206YZJP80IVIV0P1QHF4206MWI`03075aL@1UIFD0IFEU
0080H61P0P1WIfL206m_K`80LG5a0P1bLW8206m_K`80N7Qh0P1ZJVX2069RHP80JVYZ0P1]KFd206UY
J@80J6QX0P1TI6@00`1JFUX0DU9B059BDP0205ADE080C4a<0P17AdL20492@P804Q8B0P0E5AD2014A
4@808R8R0P0`<30203Ph>080;Rh^0P0];Bd203Ti>@80=3@d00<0:RXZ01HF5P0F5QH00P1BDU8205]K
F`80GemO0P1UIFD204Y:BP80De=C0P19BDT204I6AP80C4a<0P1DE5@205mOG`80KFe]0P1hN7P207Ad
M00306IVIP25QHD0QHF50080QXJ60P21PH4808F5Q@80RHV90P25QHD208:2PP80PH610P25QHD208V9
R@T0QHF50P29RHT208J6QP80PH611025QHDE0?ooo`004`3oool408V9R@80QHF51029RHT208F5Q@80
PX:20P21PH400`25QHD0QXJ608J6QP0208:2PP80PH610P29RHT408F5Q@80PH610P1oOgl208F5Q@80
RHV90P25QHD206i^KP80@d=30P0h>3P202<S8`0302PX:00_;bl0;bl_0080;Rh^0P0];Bd202l_;`80
8B4Q0P0M7Ad203Hf=P80>c/k101`L70206i^KP80Kfm_0P1jNWX207inOP80MgMg00<0OGem07MgM`1g
MgL00P1fMWH2075aL@80Kfm_0P1eMGD207IfMP@0O7al0P1jNWX207alO080MWIf0P1ZJVX206IVIP80
HF5Q0P1WIfL00`1aLG40IFEU06EUI@02061PH080IfMW0P1_Kfl2075aL@80LW9b0P1_Kfl207QhN080
JVYZ0P1RHV8206YZJP80KFe]0P1YJFT206QXJ080I6AT00<0FUYJ059BDP1BDU800P1DE5@204a<C080
AdM70P12@T82018B4P805ADE0P0A4A42028R8P80<30`0P0h>3P202h^;P80;Bd]0P0i>CT203@d=003
02XZ:P0F5QH05QHF0080DU9B0P1KFe/205mOG`80IFEU0P1:BTX205=CD`80BDU90P16ATH204a<C080
E5AD0P1OGel206e]K@80N7Qh0P1dM7@00`1VIVH0QHF508F5Q@0208J6QP80PH612025QHD208V9R@80
QHF50P22PX820861P@80QHF50P29RHT908F5Q@80RHV90P26QXH20861P@@0QHF55@3oool001<0oooo
1P25QHD208:2PP80PH610P22PX8408F5Q@0308:2PP25QHD0QHF50080QXJ60P21PH4208F5Q@80PH61
0P1oOgl208N7Q`80OWin0P21PH4208:2PP80Ph>30P1OGel203dm?@80=SHf0P0l?3`00`0`<300;2`/
02`/;004034a<@80:b/[0P0O7al2028R8P80@D510P1aLG42079bLP80MgMg0P1jNWX207QhN080MgMg
101fMWH00`1gMgL0NWYj07YjNP0207EeM@80Kfm_0P1]KFd20820P080MgMg0P1kNg/207alO080MgMg
0P1bLW8207EeM@80Jf][101RHV8306=SH`80IFEU0P1TI6@206MWI`80Kfm_0P1`L70207=cL`80LG5a
0P1bLW8207MgM`80MWIf0P1`L70206][J`80JVYZ0P1VIVH306QXJ080GUiN0P1FEUH204m?C`80AdM7
0P0k>c/202TY:@801`L70P0C4a<201lO7`8061PH0P0V9RH203`l?080=SHf0P0a<C4202/[:`030492
@P0];Bd0;Bd]0080AdM70P1?Cdl205=CD`80LG5a0P1BDU8205ADE080Bd];0P13@d<20410@080ATI6
0P1OGel206MWI`80KVi^0P25QHD00`21PH40QHF508F5Q@0208V9R@P0QHF50P22PX8207inOP80PH61
0P29RHTA08F5Q@80RHV91P25QHDE0?ooo`004`3oool608F5Q@80PX:20P21PH4208:2PP@0QHF500<0
PX:208F5Q@25QHD00P26QXH20861P@80QHF50P21PH4207moO`80QhN70P1nOWh20861P@80PX:20P23
Ph<205mOG`80?Cdm0P0f=SH203`l?003030`<00/;2`0;2`/00@0<C4a0P0[:b/201lO7`808R8R0P11
@D42075aL@80LW9b0P1gMgL207YjNP80N7Qh0P1gMgL407IfMP0307MgM`1jNWX0NWYj0080MGEe0P1_
Kfl206e]K@80P8200P1gMgL207]kN`80O7al0P1gMgL2079bLP80MGEe0P1[Jf/4069RHP<0Hf=S0P1U
IFD206ATI080IfMW0P1_Kfl2071`L080Lg=c0P1aLG42079bLP80MgMg0P1fMWH2071`L080Jf][0P1Z
JVX206IVIP<0J6QX0P1NGUh205IFEP80Cdm?0P17AdL203/k>`80:BTY0P071`L201<C4`807alO0P0H
61P202HV9P80?3`l0P0f=SH2034a<@80:b/[00<0@T9202d];@0];Bd00P17AdL204m?C`80De=C0P1a
LG42059BDP80E5AD0P1;Bd/204=3@`80@4100P16ATH205mOG`80IfMW0P1^KVh208F5Q@030861P@25
QHD0QHF50080RHV92025QHD208:2PP80OWin0P21PH4208V9RA40QHF50P29RHT608F5QAD0oooo000C
0?ooo`H0QHF50P29RHT208F5Q@80RHV90P25QHD308:2PP80PH610P26QXH207inOP80PH610P2:RXX2
08:2PP80QHF50P29RHT408F5Q@80I6AT0P16ATH203hn?P809bLW0P0S8b<00`0X:2P0:b/[02/[:`02
02l_;`80;Bd]0P0G5aL201`L70805ADE0P000002075aL@@0L71`0P1_Kfl207MgM`80MWIf101gMgL0
0`1hN7P0MgMg07MgM`0207inOP80OGem0P1`L70206e]K@@0L71`0P1fMWH207YjNP80MGEe0P1ZJVX2
05mOG`80G5aL101OGel00`1RHV80IVIV06IVIP0206i^KP80L71`0P1aLG42071`L080N7Qh0P1cLg<2
06m_K`80L71`0P1_Kfl207MgM`80L71`0P1ZJVX206EUI@80J6QX00<0IfMW06ATI01TI6@00P1JFUX2
04m?C`80Bd];0P19BDT203lo?`@03`l?0P0I6AT203Ph>080;Rh^0P0g=cL203De=@80=SHf0P0_;bl0
0`0Z:RX0<30`030`<0020451@@80ATI60P1IFET207EeM@80H61P0P10@40204E5A@80@d=30P1EEED2
05aLG080JFUY0P1RHV82051@D080JVYZ00<0PX:20861P@21PH400P22PX8407inOP80PH610P25QHD2
08V9R@80QXJ60P21PH4?08F5Q@80PX:20P21PH4808F5QAD0oooo000C0?ooo`H0QHF50P29RHT208F5
Q@80RHV90P25QHD308:2PP80PH610P26QXH207inOP80PH610P2:RXX208:2PP80QHF50P29RHT408F5
Q@80I6AT0P16ATH203hn?P809bLW0P0S8b<00`0X:2P0:b/[02/[:`0202l_;`80;Bd]0P0G5aL201`L
70805ADE0P000002075aL@@0L71`0P1_Kfl207MgM`80MWIf101gMgL00`1hN7P0MgMg07MgM`0207in
OP80OGem0P1`L70206e]K@@0L71`0P1fMWH207YjNP80MGEe0P1ZJVX205mOG`80G5aL101OGel00`1R
HV80IVIV06IVIP0206i^KP80L71`0P1aLG42071`L080N7Qh0P1cLg<206m_K`80L71`0P1_Kfl207Mg
M`80L71`0P1ZJVX206EUI@80J6QX00<0IfMW06ATI01TI6@00P1JFUX204m?C`80Bd];0P19BDT203lo
?`@03`l?0P0I6AT203Ph>080;Rh^0P0g=cL203De=@80=SHf0P0_;bl00`0Z:RX0<30`030`<0020451
@@80ATI60P1IFET207EeM@80H61P0P10@40204E5A@80@d=30P1EEED205aLG080JFUY0P1RHV82051@
D080JVYZ00<0PX:20861P@21PH400P22PX8407inOP80PH610P25QHD208V9R@80QXJ60P21PH4?08F5
Q@80PX:20P21PH4808F5QAD0oooo000C0?ooo`@0OWin0P21PH4408F5Q@80PX:20P21PH4308V9R@80
QHF51029RHT208:2PP80PH610P26QXH20861P@@0QHF50P26QXH207AdM080AdM70P0_;bl202TY:@80
<30`00<0=3@d030`<00`<3000P0];Bd2014A4@806QXJ0P0H61P202<S8`803Ph>0P1aLG4207QhN080
OGem101eMGD207IfMPL0MGEe0P1fMWH207]kN`80MGEe0P1cLg<206e]K@80L71`0P1bLW8206e]K@80
JVYZ0P1]KFd206QXJ080HV9R0P1SHf<306QXJ0P0Kfm_0P1^KVh2071`L080MGEe101bLW8406m_K`80
LG5a0P1^KVh206YZJP80IVIV00<0Hf=S06ATI01TI6@00P1VIVH205]KF`80CDe=0P14A4@203/k>`80
4A4A0P0J6QX201TI6@807QhN0P0X:2P202`/;080;Bd]0P0o?cl203Lg=`0303De=@0j>SX0>SXj0080
BDU90P1@D50205ADE080J6QX0P1^KVh204I6AP80@T920P0o?cl40410@080G5aL0P2:RXX208:2PP80
PH6100<0RHV908F5Q@25QHD01P29RHT608F5Q@80RHV92025QHD208:2PP80PH611@25QHD208J6QP80
OWin0P21PH4608F5QAD0oooo000C0?ooo`@0RHV91025QHD208:2PP/0QHF50P22PX8208F5Q@80PX:2
0P25QHD208:2PP@0OWin0P24Q8@207alO080@T92100b<S8202l_;`0302h^;P0/;2`0;2`/0080;bl_
0P0U9BD201HF5P806a/K0P1IFET205mOG`@0LG5a0P1gMgL607IfMP80NWYj0`20P80207alO080MWIf
0P1gMgL207inOP80NGUi0P1cLg<206i^KP80OWin0P1hN7P2075aL@80IFEU0P1XJ6P206=SH`80IfMW
0P1/K6`00`1[Jf/0JVYZ06YZJP02079bLP80M7Ad101aLG4207=cL`80O7al0P1cLg<2079bLP80LG5a
0P1_Kfl2075aL@80J6QX0P1[Jf/206MWI`0306EUI@1KFe/0Fe]K0080H61P0P1JFUX204a<C080@T92
0P15ADD2028R8P802PX:0P0J6QX201PH6080:2PX0P0g=cL2030`<080;Rh^0P0o?cl00`0g=cL0<c<c
03<c<`0204];B`80GUiN0P1IFET205iNGP80IFEU0P1ADE420492@P80?clo0P15ADD204U9B@80KFe]
0P1bLW8206YZJQ/0QHF50P29RHT708F5Q@@0RHV91025QHD208:2PP80PH615@3oool001<0oooo1029
RHT408F5Q@80PX:22`25QHD208:2PP80QHF50P22PX8208F5Q@80PX:2101nOWh208B4Q080O7al0P12
@T84038b<P80;bl_00<0;Rh^02`/;00/;2`00P0_;bl202DU9@805QHF0P0K6a/205UIF@80GemO101a
LG4207MgM`H0MWIf0P1jNWX30820P080O7al0P1fMWH207MgM`80OWin0P1iNGT207=cL`80KVi^0P1n
OWh207QhN080LG5a0P1UIFD206QXJ080Hf=S0P1WIfL206a/K00306][J`1ZJVX0JVYZ0080LW9b0P1d
M7@4075aL@80Lg=c0P1lO7`207=cL`80LW9b0P1aLG4206m_K`80LG5a0P1XJ6P206][J`80IfMW00<0
IFEU05]KF`1KFe/00P1PH60205YJFP80C4a<0P12@T8204E5A@808R8R0P0:2PX201XJ6P8061PH0P0X
:2P203Lg=`80<30`0P0^;Rh203lo?`0303Lg=`0c<c<0<c<c0080Bd];0P1NGUh205UIF@80GUiN0P1U
IFD2055AD@80@T920P0o?cl204E5A@80BDU90P1]KFd2079bLP80JVYZ6`25QHD208V9R@L0QHF51029
RHT408F5Q@80PX:20P21PH4E0?ooo`004`3oool607inOP80PH610P29RHT908F5Q@@0PX:20P1nOWh4
08F5Q@80QXJ60P22PX8208F5Q@80LG5a0P1KFe/203hn?P80;Rh^0P0`<303038b<P80;Rh^0P0K6a/2
01HF5P804A4A0P1MGEd207inOP80LW9b0P1eMGD207YjNP80O7al0P1fMWH207YjNP80O7al1@1`L702
07IfMPH0MGEe0P1jNWX207emO@80Lg=c0P1gMgL207]kN`80NWYj0P1fMWH406QXJ0D0IfMW0P1ZJVX2
06e]K@80MWIf0P1mOGd207QhN080Kfm_0P1eMGD207MgM`80O7al0P1gMgL207AdM0@0N7Qh0P1aLG42
06i^KP0306][J`1WIfL0IfMW0080GemO0P1WIfL205aLG080ATI60P0o?cl203/k>`80:2PX0P0T92@2
034a<@80:RXZ0P0d=3@203Xj>P80>3Ph0P0g=cL00`0c<c<0=CDe03De=@0204I6AP80GemO0P1IFET2
05IFEP80Lg=c0P15ADD203Xj>P80<C4a0P1;Bd/203hn?P80HF5Q0P27QhL207inOPl0QHF50P22PX82
0861P@80QHF50P22PX8207inOP80PH610P25QHD208:2PP80PH6100<0PX:20861P@21PH402025QHD2
08V9R@80QHF55@3oool001<0oooo1P1nOWh20861P@80RHV92@25QHD408:2PP80OWin1025QHD208J6
QP80PX:20P25QHD2075aL@80Fe]K0P0n?Sh202h^;P80<30`0`0b<S8202h^;P806a/K0P0F5QH2014A
4@80GEeM0P1nOWh2079bLP80MGEe0P1jNWX207alO080MWIf0P1jNWX207alO0D0L71`0P1fMWH607Ee
M@80NWYj0P1mOGd207=cL`80MgMg0P1kNg/207YjNP80MWIf101XJ6P506MWI`80JVYZ0P1]KFd207If
MP80OGem0P1hN7P206m_K`80MGEe0P1gMgL207alO080MgMg0P1dM7@407QhN080LG5a0P1^KVh00`1[
Jf/0IfMW06MWI`0205mOG`80IfMW0P1LG5`204I6AP80?clo0P0k>c/202PX:08092@T0P0a<C4202XZ
:P80=3@d0P0j>SX203Ph>080=cLg00<0<c<c03De=@0e=CD00P16ATH205mOG`80FEUI0P1FEUH207=c
L`80ADE50P0j>SX2034a<@80Bd];0P0n?Sh2065QH@80QhN70P1nOWh?08F5Q@80PX:20P21PH4208F5
Q@80PX:20P1nOWh20861P@80QHF50P22PX820861P@0308:2PP21PH40PH6100P0QHF50P29RHT208F5
QAD0oooo000C0?ooo`80PX:20P25QHD208J6QP80PH612@25QHD208:2PP80QHF50P29RHT208J6QP80
PH610P25QHD408V9R@80QHF50P1CDe<203Lg=`80<S8b0P0S8b<202TY:@80;Rh^00<0:b/[02l_;`0_
;bl00P0R8R8202LW9`80:RXZ0P0F5QH206][J`80M7Ad0P1fMWH2075aL@80MWIf101jNWX207alO080
MWIf0P1gMgL00`1kNg/0O7al07alO00807IfMP80MgMg0P1bLW8207MgM`80OWin0P1kNg/207=cL`80
J6QX0P1SHf<206][J`80KVi^00<0Jf][06QXJ01XJ6P00P1`L702079bLP80Lg=c0P1iNGT207MgM`80
OGem101aLG4207=cL`80MgMg0P1dM7@2079bLP80Lg=c0P1/K6`00`1YJFT0J6QX06QXJ00206=SH`@0
Fe]K0P1>CTh203dm?@80=3@d0P0[:b/202DU9@808R8R0P0^;Rh202d];@80?3`l0P0k>c/203Ti>@03
04I6AP1<C4`0C4a<0080BDU90P1KFe/205ADE080Cdm?0P1QHF4204Y:BP80=cLg0P0d=3@4059BDP80
GUiN0P1iNGTA08F5Q@80RHV91025QHD408V9R@@0QHF50P29RHT208:2PPD0QHF50P22PX820861P@H0
QHF55@3oool001<0oooo0P22PX8208F5Q@80QXJ60P21PH4908F5Q@80PX:20P25QHD208V9R@80QXJ6
0P21PH4208F5Q@@0RHV90P25QHD205=CD`80=cLg0P0b<S8202<S8`80:BTY0P0^;Rh00`0[:b/0;bl_
02l_;`02028R8P809bLW0P0Z:RX201HF5P80Jf][0P1dM7@207IfMP80LG5a0P1fMWH407YjNP80O7al
0P1fMWH207MgM`0307]kN`1lO7`0O7al00P0MWIf0P1gMgL2079bLP80MgMg0P1nOWh207]kN`80Lg=c
0P1XJ6P206=SH`80Jf][0P1^KVh00`1[Jf/0J6QX06QXJ002071`L080LW9b0P1cLg<207UiN@80MgMg
0P1mOGd4075aL@80Lg=c0P1gMgL207AdM080LW9b0P1cLg<206a/K00306UYJ@1XJ6P0J6QX0080Hf=S
101KFe/204i>CP80?Cdm0P0d=3@202/[:`809BDU0P0R8R8202h^;P80;Bd]0P0l?3`203/k>`80>CTi
00<0ATI604a<C01<C4`00P19BDT205]KF`80E5AD0P1?Cdl2065QH@80BTY:0P0g=cL203@d=0@0DU9B
0P1NGUh207UiNA40QHF50P29RHT408F5Q@@0RHV91025QHD208V9R@80PX:21@25QHD208:2PP80PH61
1P25QHDE0?ooo`004`3oool208:2PP80PH610P29RHT;08F5Q@80RHV91025QHD208J6QP80PH611025
QHD208:2PP80PH610P1iNGT204E5A@80<S8b0P0Z:RX202d];@80>3Ph00<0<30`02TY:@0Y:BT00P0[
:b/201/K6`80ADE50P12@T8207EeM@80LW9b0P1eMGD207IfMP@0NWYj0P1fMWH407MgM`80MWIf00<0
LW9b07MgM`1gMgL00P1jNWX20820P080O7al0P1eMGD207]kN`80MgMg0P1fMWH2071`L080LG5a0P1c
Lg<206QXJ080GUiN0P1RHV8206YZJP0306m_K`1aLG40LG5a0080Kfm_0P1^KVh207=cL`80LG5a0P1f
MWH2071`L080LG5a0P1dM7@207UiN@80M7Ad0P1cLg<2071`L080MGEe0P1dM7@00`1/K6`0Hf=S06=S
H`0206MWI`80GemO0P1MGEd204e=C@80?clo0P0g=cL202@T90807QhN0P0S8b<202HV9P80;2`/0P0c
<c<203`l?080?Shn00<0<c<c04A4A014A4@00P1JFUX405]KF`80F5QH0P1_Kfl205UIF@80Cdm?0P11
@D4203lo?`80Bd];0P1PH60207inOQL0QHF50P22PX820861P@80PX:20P21PH4208F5Q@80RHV91@25
QHD208V9R@P0QHF55@3oool001<0oooo0P22PX820861P@80RHV92`25QHD208V9R@@0QHF50P26QXH2
0861P@@0QHF50P22PX820861P@80NGUi0P15ADD2038b<P80:RXZ0P0];Bd203Ph>003030`<00Y:BT0
:BTY0080:b/[0P0K6a/204E5A@80@T920P1eMGD2079bLP80MGEe0P1fMWH407YjNP80MWIf101gMgL2
07IfMP03079bLP1gMgL0MgMg0080NWYj0P20P80207alO080MGEe0P1kNg/207MgM`80MWIf0P1`L702
075aL@80Lg=c0P1XJ6P205iNGP80HV9R0P1ZJVX00`1_Kfl0LG5a075aL@0206m_K`80KVi^0P1cLg<2
075aL@80MWIf0P1`L702075aL@80M7Ad0P1iNGT207AdM080Lg=c0P1`L70207EeM@80M7Ad00<0K6a/
06=SH`1SHf<00P1WIfL205mOG`80GEeM0P1=CDd203lo?`80=cLg0P0T92@201hN7P808b<S0P0V9RH2
02`/;080<c<c0P0l?3`203hn?P0303<c<`14A4@0A4A40080FUYJ101KFe/205QHF080Kfm_0P1IFET2
04m?C`80@D510P0o?cl204];B`80H61P0P1nOWhG08F5Q@80PX:20P21PH4208:2PP80PH610P25QHD2
08V9R@D0QHF50P29RHT808F5QAD0oooo000C0?ooo`80RHV90P25QHD208:2PP80PH610P22PX820861
P@@0QHF500<0PX:20861P@21PH401025QHD208V9R@H0QHF50P29RHT208:2PP80L71`0P17AdL203lo
?`80<c<c0P0U9BD202d];@03038b<P0R8R808R8R00809bLW0P0k>c/2055AD@80LW9b0P1dM7@2079b
LP@0MWIf101`L70207IfMP80MGEe0P1gMgL207IfMP<0LW9b101`L70207IfMP@0MgMg0P1`L70206i^
KP80O7al101mOGd206e]K@80IFEU0P1OGel206MWI`0306EUI@1XJ6P0J6QX0080JVYZ0P1_Kfl207=c
L`80Kfm_0P1bLW8407UiN@80Lg=c0P1_Kfl206e]K@80Kfm_0P1`L70406m_K`0307AdM01/K6`0K6a/
0080I6AT0P1OGel2069RHP80FEUI0P1<C4`203/k>`80<S8b0P0V9RH202@T90808R8R0P0/;2`2038b
<P80=cLg0P0b<S800`0/;2`0<C4a034a<@02069RHP@0EEEE0P1FEUH205YJFP80C4a<0P0m?Cd204E5
A@80A4A40P17AdL205ADE080Ogmo5`25QHD208V9R@80QHF50P29RHT208F5Q@80PX:20P21PH4?08F5
QAD0oooo000C0?ooo`80RHV90P25QHD208:2PP80PH610P22PX820861P@@0QHF500<0PX:20861P@21
PH401025QHD208V9R@H0QHF50P29RHT208:2PP80L71`0P17AdL203lo?`80<c<c0P0U9BD202d];@03
038b<P0R8R808R8R00809bLW0P0k>c/2055AD@80LW9b0P1dM7@2079bLP@0MWIf101`L70207IfMP80
MGEe0P1gMgL207IfMP<0LW9b101`L70207IfMP@0MgMg0P1`L70206i^KP80O7al101mOGd206e]K@80
IFEU0P1OGel206MWI`0306EUI@1XJ6P0J6QX0080JVYZ0P1_Kfl207=cL`80Kfm_0P1bLW8407UiN@80
Lg=c0P1_Kfl206e]K@80Kfm_0P1`L70406m_K`0307AdM01/K6`0K6a/0080I6AT0P1OGel2069RHP80
FEUI0P1<C4`203/k>`80<S8b0P0V9RH202@T90808R8R0P0/;2`2038b<P80=cLg0P0b<S800`0/;2`0
<C4a034a<@02069RHP@0EEEE0P1FEUH205YJFP80C4a<0P0m?Cd204E5A@80A4A40P17AdL205ADE080
Ogmo5`25QHD208V9R@80QHF50P29RHT208F5Q@80PX:20P21PH4?08F5QAD0oooo000C0?ooo`80OWin
0P21PH4208V9R@80QHF50P26QXH20861P@80PX:20P21PH400`26QXH0PH610861P@0:08F5Q@80PX:2
0P21PH42069RHP80BDU90P0c<c<203Hf=P80>SXj0P0i>CT2030`<0<09BDU0P0V9RH206=SH`@0M7Ad
0P1cLg<207MgM`H0MWIf0P1jNWX207alO0@0MWIf0P1dM7@00`1`L700J6QX06QXJ00206][J`80Kfm_
0P1cLg<207MgM`80LG5a0P1eMGD207=cL`@0MWIf0P1oOgl2075aL@80I6AT0P1NGUh205]KF`03069R
HP1OGel0GemO0080GemO0P1/K6`206i^KP80LW9b101cLg<206i^KP80L71`0P1_Kfl206i^KP80L71`
0P1_Kfl2075aL@80L71`00<0Jf][06a/K01/K6`00P1YJFT206MWI`80G5aL0P1IFET204];B`80?clo
0P0c<c<201lO7`808B4Q0P0U9BD202HV9P80>3Ph0P0j>SX203Ti>@0303`l?00^;Rh0;Rh^0080De=C
0P1KFe/205YJFP80@4100P0o?cl204E5A@80;Bd]0P1;Bd/205]KF`80De=C0P1DE5@M08F5Q@80PX:2
0P21PH4208V9RA40QHF55@3oool001<0oooo0P1nOWh20861P@80RHV90P25QHD208J6QP80PH610P22
PX820861P@0308J6QP21PH40PH6100X0QHF50P22PX820861P@80HV9R0P19BDT203<c<`80=SHf0P0j
>SX203Ti>@80<30`0`0U9BD202HV9P80Hf=S101dM7@207=cL`80MgMg1P1fMWH207YjNP80O7al101f
MWH207AdM003071`L01XJ6P0J6QX0080Jf][0P1_Kfl207=cL`80MgMg0P1aLG4207EeM@80Lg=c101f
MWH207moO`80LG5a0P1TI6@205iNGP80Fe]K00<0HV9R05mOG`1OGel00P1OGel206a/K080KVi^0P1b
LW8407=cL`80KVi^0P1`L70206m_K`80KVi^0P1`L70206m_K`80LG5a0P1`L7000`1[Jf/0K6a/06a/
K00206UYJ@80IfMW0P1LG5`205UIF@80Bd];0P0o?cl203<c<`807alO0P0Q8B4202DU9@809RHV0P0h
>3P203Xj>P80>CTi00<0?3`l02h^;P0^;Rh00P1CDe<205]KF`80FUYJ0P10@40203lo?`80ADE50P0]
;Bd204];B`80Fe]K0P1CDe<205ADE1d0QHF50P22PX820861P@80RHV94@25QHDE0?ooo`004`3oool2
08V9R@@0QHF50P22PX8408F5Q@80QXJ60P21PH400`29RHT0QHF508F5Q@0:08F5Q@80QXJ60P21PH42
06IVIP80GemO0P1?Cdl203<c<`80>3Ph0P0c<c<202h^;P0302@T900[:b/0:b/[0080;bl_0P0M7Ad2
06IVIP80L71`0P1ZJVX207IfMP80NWYj0P1lO7`207IfMP80LG5a0P1gMgL207=cL`80KVi^0P1YJFT0
0`1VIVH0KFe]06e]K@0406][J`80JVYZ0P1bLW8207YjNP80LW9b0P1dM7@207MgM`80MWIf0P1iNGT2
06i^KP80HV9R101NGUh00`1KFe/0JVYZ06YZJP0206YZJP80K6a/0P1cLg<206YZJP80J6QX0P1UIFD2
06ATI080K6a/0P1^KVh206a/K080KVi^0P1`L70206m_K`80LW9b00<0JFUY06a/K01/K6`00P1[Jf/2
06=SH`80IFEU0P1JFUX2059BDP80@4100P0e=CD2028R8P805QHF0P0P820202TY:@80:b/[0P0l?3`2
03Xj>P0303Lg=`0f=SH0=SHf0080FUYJ0P1BDU8205IFEP80?Shn0P0Q8B4205]KF`80<S8b0P0g=cL2
05IFEP80Jf][0P1SHf<408F5Q@80PX:200<0PH6108F5Q@25QHD05025QHD208J6QP80PH614`25QHDE
0?ooo`004`3oool208V9R@@0QHF50P22PX8408F5Q@80QXJ60P21PH400`29RHT0QHF508F5Q@0:08F5
Q@80QXJ60P21PH4206IVIP80GemO0P1?Cdl203<c<`80>3Ph0P0c<c<202h^;P0302@T900[:b/0:b/[
0080;bl_0P0M7Ad206IVIP80L71`0P1ZJVX207IfMP80NWYj0P1lO7`207IfMP80LG5a0P1gMgL207=c
L`80KVi^0P1YJFT00`1VIVH0KFe]06e]K@0406][J`80JVYZ0P1bLW8207YjNP80LW9b0P1dM7@207Mg
M`80MWIf0P1iNGT206i^KP80HV9R101NGUh00`1KFe/0JVYZ06YZJP0206YZJP80K6a/0P1cLg<206YZ
JP80J6QX0P1UIFD206ATI080K6a/0P1^KVh206a/K080KVi^0P1`L70206m_K`80LW9b00<0JFUY06a/
K01/K6`00P1[Jf/206=SH`80IFEU0P1JFUX2059BDP80@4100P0e=CD2028R8P805QHF0P0P820202TY
:@80:b/[0P0l?3`203Xj>P0303Lg=`0f=SH0=SHf0080FUYJ0P1BDU8205IFEP80?Shn0P0Q8B4205]K
F`80<S8b0P0g=cL205IFEP80Jf][0P1SHf<408F5Q@80PX:200<0PH6108F5Q@25QHD05025QHD208J6
QP80PH614`25QHDE0?ooo`004`3oool608F5Q@80QXJ60P21PH4208F5Q@80RHV90P22PX800`21PH40
QHF508F5Q@0208F5Q@80PX:21P1nOWh408F5Q@80DU9B0P0e=CD204=3@`80ATI60P0e=CD203`l?080
<30`00<07alO030`<00`<3000P1dM7@406=SH`80I6AT0P1_Kfl207MgM`80L71`101fMWH2079bLP@0
KVi^0P1/K6`207QhN00306EUI@1FEUH0EUIF0080G5aL0P1XJ6P406YZJP80Kfm_0P1YJFT206e]K@@0
MWIf0P1bLW8206][J`80GEeM0P1OGel205eMG@0305aLG01JFUX0FUYJ0080Hf=S0P1/K6`206IVIP80
IfMW0P1RHV8205mOG`80FEUI0P1FEUH405=CD`80EUIF0P1LG5`406MWI`03075aL@1ZJVX0JVYZ0080
K6a/0P1TI6@205YJFP80EUIF0P1<C4`204Q8B080>c/k0P0e=CD201DE5@805aLG0P0O7al202`/;080
=3@d0P0o?cl00`0g=cL0;bl_02l_;`0205UIF@80CDe=1011@D4202`/;080Hf=S0P0e=CD203Ti>@80
EeMG0P1SHf<206e]K@@0QHF50P29RHT708F5Q@80PX:20P21PH4<08F5Q@80RHV91P25QHD00`22PX80
PH610861P@0<08F5QAD0oooo000C0?ooo`H0QHF50P26QXH20861P@80QHF50P29RHT208:2PP030861
P@25QHD0QHF50080QHF50P22PX8607inOP@0QHF50P1BDU8203De=@80@d=30P16ATH203De=@80?3`l
0P0`<3000`0O7al0<30`030`<00207AdM0@0Hf=S0P1TI6@206m_K`80MgMg0P1`L70407IfMP80LW9b
101^KVh206a/K080N7Qh00<0IFEU05IFEP1FEUH00P1LG5`206QXJ0@0JVYZ0P1_Kfl206UYJ@80KFe]
101fMWH2079bLP80Jf][0P1MGEd205mOG`80GEeM00<0G5aL05YJFP1JFUX00P1SHf<206a/K080IVIV
0P1WIfL2069RHP80GemO0P1IFET205IFEP@0De=C0P1FEUH205aLG0@0IfMW00<0LG5a06YZJP1ZJVX0
0P1/K6`206ATI080FUYJ0P1FEUH204a<C080B4Q80P0k>c/203De=@805ADE0P0G5aL201lO7`80;2`/
0P0d=3@203lo?`0303Lg=`0_;bl0;bl_0080FEUI0P1=CDd40451@@80;2`/0P1SHf<203De=@80>CTi
0P1GEeL206=SH`80KFe]1025QHD208V9R@L0QHF50P22PX820861P@`0QHF50P29RHT608F5Q@0308:2
PP21PH40PH6100`0QHF55@3oool001<0oooo1P25QHD208V9R@H0QHF50P29RHT00`25QHD0PX:208:2
PP020861P@80QXJ60P25QHD408V9R@80QHF50P29RHT207moO`80=cLg0P0l?3`202l_;`80<c<c0P0e
=CD201/K6`03030`<00Z:RX0:RXZ0080;Bd]0P1HF5P2051@D080GEeM0P1aLG4207MgM`@0MWIf0P1c
Lg<206m_K`80H61P0P19BDT203Lg=`80?Cdm00<0FEUI051@D01@D5000P1:BTX205QHF080Hf=S0P1c
Lg<207IfMP80L71`0P1_Kfl207QhN080MgMg0P21PH42075aL@80HV9R0P1CDe<205EEE@0306ATI01Y
JFT0JFUY0080HV9R0P1UIFD205eMG@80EUIF0P1@D5020492@P80?3`l0P16ATH205=CD`80CTi>0P1C
De<205]KF`80JVYZ0P1TI6@305aLG0@0Hf=S0P1QHF4205QHF080De=C0P0n?Sh203Hf=P80<C4a0P0`
<302028R8P807QhN0P0U9BD202l_;`80<C4a00<0?3`l03<c<`0c<c<00P14A4@204m?C`80@d=30P18
B4P202d];@80DU9B100d=3@4059BDP80LG5a0P2;Rh/;08F5Q@80RHV95P25QHD00`29RHT0QHF508F5
Q@0<08F5QAD0oooo000C0?ooo`H0QHF50P29RHT608F5Q@80RHV900<0QHF508:2PP22PX800P21PH42
08J6QP80QHF51029RHT208F5Q@80RHV90P1oOgl203Lg=`80?3`l0P0_;bl203<c<`80=CDe0P0K6a/0
0`0`<300:RXZ02XZ:P0202d];@80F5QH0P1@D50205eMG@80LG5a0P1gMgL407IfMP80Lg=c0P1_Kfl2
061PH080BDU90P0g=cL203dm?@0305UIF@1@D500D51@0080BTY:0P1HF5P206=SH`80Lg=c0P1fMWH2
071`L080Kfm_0P1hN7P207MgM`80PH610P1aLG42069RHP80De=C0P1EEED00`1TI6@0JFUY06UYJ@02
069RHP80IFEU0P1MGEd205IFEP80D51@0P12@T8203`l?080ATI60P1CDe<204i>CP80De=C0P1KFe/2
06YZJP80I6AT0`1LG5`406=SH`80HF5Q0P1HF5P205=CD`80?Shn0P0f=SH2034a<@80<30`0P0R8R82
01hN7P809BDU0P0_;bl2034a<@0303`l?00c<c<0<c<c0080A4A40P1?Cdl204=3@`80B4Q80P0];Bd2
059BDP@0=3@d101BDU82075aL@80Rh^;2`25QHD208V9RAH0QHF500<0RHV908F5Q@25QHD03025QHDE
0?ooo`004`3oool207inOP80PH611P25QHD208:2PP80PH610P22PX800`21PH40RHV908V9R@0208F5
Q@80RHV92025QHD205ADE080Fe]K0P12@T8203De=@@0;Bd]0P0a<C4202/[:`0302`/;01bLW80LW9b
0080GemO0P1/K6`205MGE`80FEUI0P1]KFd2079bLP80MWIf0P1`L702069RHP80A4A40P0k>c/205mO
G`80MGEe0P0j>SX00`0T92@0=cLg03Lg=`020410@080BTY:0P0g=cL204U9B@80L71`0P1^KVh206][
J`@0MgMg0P1hN7P207IfMP80J6QX0P1QHF4205QHF00304M7A`0`<300<30`00805ADE0P0_;bl204Y:
BP80L71`0P1GEeL202l_;`80<30`0P0i>CT403Ph>080>CTi0P10@40205IFEP<0Hf=S0P1TI6@2061P
H080GemO0P1LG5`205IFEP80BDU90P18B4P203lo?`80<S8b0P0g=cL2024Q8@806QXJ0P0U9BD203<c
<`80<S8b00<0?clo0410@010@4000P1ADE4204m?C`80ATI60P0o?cl202TY:@80GUiN0P1;Bd/204Q8
B080J6QX0P1QHF4207=cLa/0QHF50P22PX820861PAD0QHF55@3oool001<0oooo0P1nOWh20861P@H0
QHF50P22PX820861P@80PX:200<0PH6108V9R@29RHT00P25QHD208V9R@P0QHF50P1DE5@205]KF`80
@T920P0e=CD402d];@80<C4a0P0[:b/00`0/;2`0LW9b079bLP0205mOG`80K6a/0P1GEeL205UIF@80
KFe]0P1bLW8207IfMP80L71`0P1RHV8204A4A080>c/k0P1OGel207EeM@80>SXj00<092@T03Lg=`0g
=cL00P10@40204Y:BP80=cLg0P19BDT2071`L080KVi^0P1[Jf/407MgM`80N7Qh0P1fMWH206QXJ080
HF5Q0P1HF5P00`17AdL0<30`030`<00201DE5@80;bl_0P1:BTX2071`L080EeMG0P0_;bl2030`<080
>CTi100h>3P203Ti>@80@4100P1FEUH306=SH`80I6AT0P1PH60205mOG`80G5aL0P1FEUH204U9B@80
B4Q80P0o?cl2038b<P80=cLg0P0Q8B4201XJ6P809BDU0P0c<c<2038b<P0303lo?`10@400@4100080
DE5A0P1?Cdl204I6AP80?clo0P0Y:BT205iNGP80Bd];0P18B4P206QXJ080HF5Q0P1cLg<K08F5Q@80
PX:20P21PH4E08F5QAD0oooo000C0?ooo`80RHV92025QHD208V9R@80QHF50P29RHT508F5Q@80PX:2
0P21PH4608F5Q@80M7Ad0P1NGUh205=CD`80B4Q80P0R8R8202/[:`80=3@d0P0[:b/00`0E5AD03Ph>
00h>3P0206i^KP80Kfm_0P1WIfL205mOG`80MgMg0P1dM7@206YZJP80Hf=S0P1=CDd2051@D080J6QX
0P1lO7`204i>CP80?Cdm0`0_;bl203Hf=P80C4a<0P1IFET204I6AP80EeMG0P1QHF4206a/K080MgMg
0P1bLW8207AdM080LG5a0P1^KVh205IFEP80CDe=00<0@41007IfMP1fMWH00P12@T8204];B`80Ti>C
0P1<C4`203hn?P80A4A40P11@D4203Ph>080AdM70P1?Cdl203De=@80;bl_0P17AdL205UIF@0305eM
G@1RHV80HV9R0080Hf=S0P1KFe/2061PH080EeMG0P1<C4`204=3@`80=cLg0P0_;bl201hN7P8030`<
0P0B4Q82028R8P80=cLg0P0Z:RX00`0`<300@D510451@@0204I6AP80A4A40P0o?cl204a<C080<S8b
0P14A4@20492@P80E5AD0P1RHV8205]KFaL0QHF50P22PX820861P@80QHF50P29RHT208:2PP80PH61
4`25QHDE0?ooo`004`3oool208V9R@P0QHF50P29RHT208F5Q@80RHV91@25QHD208:2PP80PH611P25
QHD207AdM080GUiN0P1CDe<204Q8B0808R8R0P0[:b/203@d=080:b/[00<05ADE00h>3P0>3Ph00P1^
KVh206m_K`80IfMW0P1OGel207MgM`80M7Ad0P1ZJVX206=SH`80CDe=0P1@D50206QXJ080O7al0P1>
CTh203dm?@<0;bl_0P0f=SH204a<C080FEUI0P16ATH205MGE`80HF5Q0P1/K6`207MgM`80LW9b0P1d
M7@2075aL@80KVi^0P1FEUH204e=C@030410@01fMWH0MWIf0080@T920P1;Bd/209>CT`80C4a<0P0n
?Sh204A4A080@D510P0h>3P204M7A`80Cdm?0P0e=CD202l_;`80AdM70P1IFET00`1MGEd0HV9R069R
HP0206=SH`80Fe]K0P1PH60205MGE`80C4a<0P13@d<203Lg=`80;bl_0P0N7Qh200`<30804Q8B0P0R
8R8203Lg=`80:RXZ00<0<30`0451@@11@D400P16ATH204A4A080?clo0P1<C4`2038b<P80A4A40P12
@T8205ADE080HV9R0P1KFe/G08F5Q@80PX:20P21PH4208F5Q@80RHV90P22PX820861PA<0QHF55@3o
ool001<0oooo4025QHD00`22PX80PH610861P@0208F5Q@80RHV91P25QHD208V9R@80fm_K0P1^KVh2
03Lg=`80:BTY0P0U9BD202PX:080;bl_0P0l?3`00`17AdL0:2PX02PX:00206i^KP80EUIF0P1GEeL2
05]KF`80J6QX0P1_Kfl206EUI@80De=C0P17AdL201dM7@804A4A0P0n?Sh2069RHP80KVi^00<05QHF
01TI6@0I6AT00P0V9RH201hN7P80?3`l0P0m?Cd205IFEP80JFUY0P1`L70207MgM`80NGUi0P1eMGD4
07AdM080IfMW0P1GEeL00`12@T80>c/k03/k>`02071`L080;Bd]0P0O7al204U9B@80DU9B0P0E5AD2
018B4P80=CDe0P0a<C4202<S8`807QhN0P0`<30203/k>`80AdM700<0Cdm?05YJFP1JFUX00P1NGUh2
05QHF080Cdm?0P1FEUH204e=C@80?3`l0P0f=SH2038b<P806QXJ0P0C4a<201DE5@804Q8B0P0S8b<2
034a<@0303Hf=P0l?3`0?3`l0080?Shn0P1=CDd204U9B@80ATI60P0i>CT204Y:BP80;Rh^0P1:BTX2
06EUI@80HF5Q5`25QHD208V9R@H0QHF50P29RHTE08F5QAD0oooo000C0?oooa00QHF500<0PX:20861
P@21PH400P25QHD208V9R@H0QHF50P29RHT20=_Kf`80KVi^0P0g=cL202TY:@809BDU0P0X:2P202l_
;`80?3`l00<0AdM702PX:00X:2P00P1^KVh205IFEP80EeMG0P1KFe/206QXJ080Kfm_0P1UIFD205=C
D`80AdM70P0M7Ad2014A4@80?Shn0P1RHV8206i^KP0301HF5P0I6AT06ATI00809RHV0P0N7Qh203`l
?080?Cdm0P1FEUH206UYJ@80L71`0P1gMgL207UiN@80MGEe101dM7@206MWI`80EeMG00<0@T9203/k
>`0k>c/00P1`L70202d];@807alO0P19BDT2059BDP805ADE0P0B4Q8203De=@80<C4a0P0S8b<201hN
7P80<30`0P0k>c/204M7A`0304m?C`1JFUX0FUYJ0080GUiN0P1HF5P204m?C`80EUIF0P1=CDd203`l
?080=SHf0P0b<S8201XJ6P804a<C0P0E5AD2018B4P808b<S0P0a<C400`0f=SH0?3`l03`l?00203hn
?P80CDe=0P19BDT204I6AP80>CTi0P1:BTX202h^;P80BTY:0P1UIFD2065QHAL0QHF50P29RHT608F5
Q@80RHV95@25QHDE0?ooo`004`3oool@08F5Q@0308V9R@25QHD0QHF500X0QHF50P1?Cdl203<c<`80
K6a/0P1FEUH203dm?@80=SHf0P0_;bl2038b<P80>3Ph00<0Bd];03`l?00l?3`00P1RHV8205]KF`80
FUYJ0P1QHF4206m_K`80Jf][0P1RHV8205UIF@80=3@d0P10@40202PX:08051@D0P0@410200H61P03
03hn?P0d=3@0=3@d0080ATI60P11@D4204m?C`80IFEU0P1XJ6P206][J`80L71`0P1cLg<207QhN080
MGEe0P1bLW8206e]K@80MGEe0P1SHf<00`1PH600ADE504E5A@0203Hf=P80DE5A0P0e=CD202h^;P80
1PH60P0X:2P201PH60809BDU0P0C4a<203Ti>@80<c<c0P0f=SH204E5A@80ATI600<0ADE5059BDP1B
DU800P1HF5P205]KF`80CDe=0P17AdL203/k>`80=cLg0P0i>CT2030`<080;Rh^0P0K6a/202<S8`80
:2PX0P0O7al202TY:@0302h^;P13@d<0@d=30080?Shn0P0g=cL203hn?P80CDe=0P12@T8205eMG@80
?Cdm0P1@D50206=SH`80NGUi9`25QHD00`22PX80PH610861P@0<08F5QAD0oooo000C0?oooa00QHF5
00<0RHV908F5Q@25QHD02P25QHD204m?C`80<c<c0P1/K6`205IFEP80?Cdm0P0f=SH202l_;`80<S8b
0P0h>3P00`1;Bd/0?3`l03`l?002069RHP80Fe]K0P1JFUX2065QH@80Kfm_0P1[Jf/2069RHP80FEUI
0P0d=3@20410@080:2PX0P0D51@2010@40801PH600<0?Shn03@d=00d=3@00P16ATH20451@@80Cdm?
0P1UIFD206QXJ080Jf][0P1`L70207=cL`80N7Qh0P1eMGD2079bLP80KFe]0P1eMGD206=SH`03061P
H015ADD0ADE50080=SHf0P1ADE4203De=@80;Rh^0P061PH202PX:08061PH0P0U9BD201<C4`80>CTi
0P0c<c<203Hf=P80ADE50P16ATH00`15ADD0DU9B059BDP0205QHF080Fe]K0P1=CDd204M7A`80>c/k
0P0g=cL203Ti>@80<30`0P0^;Rh201/K6`808b<S0P0X:2P201lO7`80:BTY00<0;Rh^04=3@`13@d<0
0P0n?Sh203Lg=`80?Shn0P1=CDd20492@P80GEeM0P0m?Cd2051@D080Hf=S0P1iNGTW08F5Q@0308:2
PP21PH40PH6100`0QHF55@3oool001<0oooo2025QHD208:2PP80PH611025QHD00`22PX80PH610861
P@0:08F5Q@80K6a/0P0`<302069RHP80A4A40P0_;bl203Xj>P80=cLg0P0];Bd202XZ:P0303Lg=`16
ATH0ATI60080IFEU0P1KFe/205YJFP80GemO0P1[Jf/207MgM`80OWin0P22PX8208V9R@80FEUI0P11
@D4203`l?080?clo0P0j>SX00`0b<S80>CTi03Ti>@0205MGE`80J6QX101cLg<207AdM080KVi^101g
MgL207QhN080MGEe0P1dM7@407UiN@80M7Ad00<0Jf][06YZJP1ZJVX00P1NGUh203Ph>080=SHf0P1Z
JVX206a/K080D51@0P0f=SH202HV9P80;Bd]0P0m?Cd2061PH080FEUI0P1CDe<205UIF@<0Fe]K0P1D
E5@205IFEP80FEUI0P19BDT203lo?`80>3Ph0P0b<S8203Hf=P80<30`0P0Q8B42020P80807alO0P0N
7Qh202<S8`03038b<P17AdL0AdM70080BTY:0P10@40203hn?P80E5AD0P1?Cdl205]KF`80@D51101D
E5@207inORL0QHF500<0RHV908F5Q@25QHD03025QHDE0?ooo`004`3oool808F5Q@80PX:20P21PH44
08F5Q@0308:2PP21PH40PH6100X0QHF50P1/K6`2030`<080HV9R0P14A4@202l_;`80>SXj0P0g=cL2
02d];@80:RXZ00<0=cLg04I6AP16ATH00P1UIFD205]KF`80FUYJ0P1OGel206][J`80MgMg0P1nOWh2
08:2PP80RHV90P1IFET20451@@80?3`l0P0o?cl203Xj>P03038b<P0i>CT0>CTi0080EeMG0P1XJ6P4
07=cL`80M7Ad0P1^KVh407MgM`80N7Qh0P1eMGD207AdM0@0NGUi0P1dM7@00`1[Jf/0JVYZ06YZJP02
05iNGP80>3Ph0P0f=SH206YZJP80K6a/0P1@D50203Hf=P809RHV0P0];Bd203dm?@80H61P0P1IFET2
05=CD`80FEUI0`1KFe/205ADE080EUIF0P1IFET204U9B@80?clo0P0h>3P2038b<P80=SHf0P0`<302
024Q8@80820P0P0O7al201hN7P808b<S00<0<S8b04M7A`17AdL00P1:BTX20410@080?Shn0P1DE5@2
04m?C`80Fe]K0P11@D4405ADE080OWin9`25QHD00`29RHT0QHF508F5Q@0<08F5QAD0oooo000C0?oo
o`P0QHF50P29RHT608F5Q@0308V9R@25QHD0QHF500@0QHF50P22PX820861P@80QHF50P3GemL206i^
KP80>3Ph0P0`<30202XZ:P8092@T0P0Z:RX202DU9@80=cLg00<0@D5104A4A014A4@00P1DE5@205=C
D`80D51@0P1IFET2079bLP80N7Qh0P21PH4208b<S080UYJF0P2WYjL20:b/[080Zj^[0P2TY:@20:FU
Y@030:b/[02IVIT0VIVI0080M7Ad101LG5`2065QH@80MWIf0P1hN7P2079bLP80MGEe0P1jNWX207em
O@80N7Qh0P1cLg<2075aL@80HV9R0`1LG5`206IVIP80R8R80P1hN7P206MWI`80HV9R0P1_Kfl207mo
O`80SHf=0P2@T90207emO@80LW9b0P1iNGT207YjNP80KFe]00<0Hf=S05mOG`1OGel00P1MGEd4051@
D080E5AD0P13@d<203/k>`80=cLg0P0U9BD202<S8`807QhN0P0P820202h^;P80<30`0P0U9BD00`0Z
:RX0AdM704M7A`0204U9B@80?Shn0P13@d<205=CD`80EEEE0P1MGEd204M7A`80Jf][0P1nOWh208^;
Rc80QHF50P22PX820861PAD0oooo000C0?ooo`P0QHF50P29RHT608F5Q@0308V9R@25QHD0QHF500@0
QHF50P22PX820861P@80QHF50P3GemL206i^KP80>3Ph0P0`<30202XZ:P8092@T0P0Z:RX202DU9@80
=cLg00<0@D5104A4A014A4@00P1DE5@205=CD`80D51@0P1IFET2079bLP80N7Qh0P21PH4208b<S080
UYJF0P2WYjL20:b/[080Zj^[0P2TY:@20:FUY@030:b/[02IVIT0VIVI0080M7Ad101LG5`2065QH@80
MWIf0P1hN7P2079bLP80MGEe0P1jNWX207emO@80N7Qh0P1cLg<2075aL@80HV9R0`1LG5`206IVIP80
R8R80P1hN7P206MWI`80HV9R0P1_Kfl207moO`80SHf=0P2@T90207emO@80LW9b0P1iNGT207YjNP80
KFe]00<0Hf=S05mOG`1OGel00P1MGEd4051@D080E5AD0P13@d<203/k>`80=cLg0P0U9BD202<S8`80
7QhN0P0P820202h^;P80<30`0P0U9BD00`0Z:RX0AdM704M7A`0204U9B@80?Shn0P13@d<205=CD`80
EEEE0P1MGEd204M7A`80Jf][0P1nOWh208^;Rc80QHF50P22PX820861PAD0oooo000C0?ooo`@0QHF5
0P22PX820861P@80QHF50P22PX820861P@L0QHF50P22PX8408F5Q@80RHV90P2LW9`204I6AP80:RXZ
0P0S8b<2024Q8@808R8R0P0f=SH202PX:0808B4Q00<0;Rh^0492@P12@T80101BDU8204m?C`80GEeM
0P1[Jf/206YZJP80Lg=c0P1lO7`20820P080Ogmo0P27QhL208Z:RP80MGEe0P1;Bd/00`0a<C40:RXZ
02XZ:P02034a<@80AdM70P1cLg<407MgM`@0Ng]k0P1lO7`207IfMP80NWYj0P1iNGT207emO@80Ogmo
0P1hN7P00`1GEeL0?3`l03`l?00202XZ:P80;Rh^0P0h>3P206IVIP80RXZ:0P2@T90208j>SP80PX:2
0P1jNWX207IfMP80KVi^0P1/K6`206QXJ080Hf=S00<0EEEE04M7A`17AdL00P1=CDd205IFEP80BDU9
0P15ADD204Q8B080>SXj0P0d=3@203Xj>P808R8R0P0L71`201TI6@8071`L0P0F5QH202HV9P0302/[
:`0a<C40<C4a0080@d=30P0m?Cd203lo?`80De=C0P1IFET206MWI`80Bd];0P1@D50207=cLc@0QHF5
0P29RHT208F5QAD0oooo000C0?ooo`@0QHF50P29RHT408F5Q@80RHV92@25QHD208V9R@@0QHF5101g
MgL204e=C@8092@T0P0U9BD202<S8`80;Bd]0P0Z:RX203Hf=P80=cLg00<0>SXj03Ti>@0i>CT00P15
ADD2051@D080BTY:0P1?Cdl207=cL`80HV9R0P1PH60206i^KP80MgMg0P1eMGD2071`L080BDU90P0f
=SH203/k>`0303lo?`1PH600H61P0080TI6A0P1mOGd207YjNP80Lg=c0P1jNWX207alO080MGEe0P1l
O7`207IfMP80N7Qh0P1kNg/207AdM080Ogmo0P22PX800`28R8P0Lg=c07=cL`020451@@80;2`/0P0U
9BD201dM7@80<S8b0P1CDe<206=SH`80M7Ad0P1eMGD2079bLP80K6a/0P1WIfL2061PH080EUIF00<0
ATI6051@D01@D5000P1@D50204e=C@80B4Q8100o?cl203`l?0809bLW0P0O7al201hN7P80820P0P0M
7Ad201HF5P80<30`0P0h>3P00`0m?Cd0@D510451@@0204Q8B080?3`l0P0h>3P204a<C080ADE50P1^
KVh205ADE080CTi>>P25QHDE0?ooo`004`3oool408F5Q@80RHV91025QHD208V9R@T0QHF50P29RHT4
08F5Q@@0MgMg0P1=CDd202@T90809BDU0P0S8b<202d];@80:RXZ0P0f=SH203Lg=`0303Xj>P0i>CT0
>CTi0080ADE50P1@D50204Y:BP80Cdm?0P1cLg<2069RHP80H61P0P1^KVh207MgM`80MGEe0P1`L702
04U9B@80=SHf0P0k>c/00`0o?cl0H61P061PH002096AT@80OGem0P1jNWX207=cL`80NWYj0P1lO7`2
07EeM@80O7al0P1fMWH207QhN080Ng]k0P1dM7@207moO`80PX:200<0R8R807=cL`1cLg<00P11@D42
02`/;0809BDU0P0M7Ad2038b<P80De=C0P1SHf<207AdM080MGEe0P1bLW8206a/K080IfMW0P1PH602
05IFEP0304I6AP1@D500D51@0080D51@0P1=CDd204Q8B0@0?clo0P0l?3`202LW9`807alO0P0N7Qh2
020P80807AdM0P0F5QH2030`<080>3Ph00<0?Cdm0451@@11@D400P18B4P203`l?080>3Ph0P1<C4`2
04E5A@80KVi^0P1DE5@204i>CSX0QHF55@3oool001<0oooo5@25QHD208:2PP80PH610P29RHT206a/
K080B4Q80P1[Jf/202`/;080<S8b0P0`<302020P8080:2PX0P0`<30202h^;P03038b<P0];Bd0;Bd]
0080<c<c0P16ATH204e=C@80DU9B0P1eMGD205eMG@80?Cdm0P0o?cl204=3@`80>SXj0P0];Bd203hn
?P80FEUI0P2EUID00`2h^;P0V9RH09RHV00208F5Q@@0Ph>30P1oOgl207YjNP80Ogmo101fMWH407Ee
M@80MWIf0P1jNWX207MgM`80NWYj00<0R8R80:2PX02PX:000P2/[:`209RHV080Lg=c0P1;Bd/202@T
90@07alO0P0P820202`/;080>CTi100e=CD203<c<`80@D5100<0Fe]K05=CD`1CDe<00P1HF5P205MG
E`80CTi>0P13@d<203lo?`80=cLg0P19BDT201dM7@809bLW0P0^;Rh202/[:`807alO0P0C4a<202HV
9P0303/k>`0o?cl0?clo0080@D510P10@40203dm?@80Fe]K0P17AdL203`l?080DU9B0P1VIVHO08F5
Q@80PX:20P21PH4G08F5QAD0oooo000C0?oooaD0QHF50P22PX820861P@80RHV90P1/K6`204Q8B080
Jf][0P0/;2`2038b<P80<30`0P0P820202PX:080<30`0P0^;Rh00`0b<S80;Bd]02d];@0203<c<`80
ATI60P1=CDd2059BDP80MGEe0P1MGEd203dm?@80?clo0P13@d<203Xj>P80;Bd]0P0n?Sh205UIF@80
UIFE00<0^;Rh09RHV02HV9P00P25QHD408>3P`80Ogmo0P1jNWX207moO`@0MWIf101eMGD207IfMP80
NWYj0P1gMgL207YjNP0308R8R02PX:00X:2P0080[:b/0P2HV9P207=cL`80Bd];0P0T92@401lO7`80
820P0P0/;2`203Ti>@@0=CDe0P0c<c<20451@@0305]KF`1CDe<0De=C0080F5QH0P1GEeL204i>CP80
@d=30P0o?cl203Lg=`80BDU90P0M7Ad202LW9`80;Rh^0P0[:b/201lO7`804a<C0P0V9RH00`0k>c/0
?clo03lo?`020451@@80@4100P0m?Cd205]KF`80AdM70P0l?3`2059BDP80IVIV7`25QHD208:2PP80
PH615`25QHDE0?ooo`004`3ooolE08F5Q@80QXJ60P21PH4207inOP80Q8B40P0Q8B4203De=@80;Rh^
100i>CT203Hf=P80:RXZ100/;2`00`0c<c<0>CTi03Ti>@0203Ph>080?Shn0P1;Bd/205YJFP80KFe]
0P2IVIT2092@T080LG5a0P1KFe/205QHF080MWIf0P2OWil20:2PX080Ph>30`1oOgl:07YjNP80Ng]k
0P1lO7`207IfMP80NWYj0P20P80207moO`80OGem0P1kNg/507YjNP80PH610P27QhL209NGU`80ZZZZ
0P2e]KD20:FUY@80RHV90P1EEED403hn?P80@d=30P1DE5@206MWI`80H61P00<0EUIF05aLG01LG5`0
0P1LG5`205IFEP80CTi>1017AdL203dm?@807alO0P0d=3@202HV9P807QhN0P0@410200l?3`8051@D
0P0S8b<00`0n?Sh0=3@d03@d=0020410@080AdM70P14A4@205=CD`80B4Q80P1>CTh2051@D080NWYj
7`25QHD208V9R@80QHF50P22PX820861PA<0QHF55@3oool001<0oooo5@25QHD208J6QP80PH610P1n
OWh208B4Q0808B4Q0P0e=CD202h^;P@0>CTi0P0f=SH202XZ:P@0;2`/00<0<c<c03Ti>@0i>CT00P0h
>3P203hn?P80Bd];0P1JFUX206e]K@80VIVI0P2@T902075aL@80Fe]K0P1HF5P207IfMP80WinO0P2P
X:0208>3P`<0Ogmo2P1jNWX207]kN`80O7al0P1fMWH207YjNP80P8200P1oOgl207emO@80Ng]k1@1j
NWX20861P@80QhN70P2GUiL20:ZZZP80]KFe0P2UYJD208V9R@80EEEE100n?Sh204=3@`80E5AD0P1W
IfL2061PH00305IFEP1LG5`0G5aL0080G5aL0P1FEUH204i>CP@0AdM70P0m?Cd201lO7`80=3@d0P0V
9RH201hN7P80410@0P0?3`l201@D50808b<S00<0?Shn03@d=00d=3@00P10@40204M7A`80A4A40P1C
De<204Q8B080CTi>0P1@D50207YjNQl0QHF50P29RHT208F5Q@80PX:20P21PH4C08F5QAD0oooo000C
0?ooo`P0QHF50P22PX820861P@@0QHF500<0PX:20861P@21PH400P25QHD208V9R@@0QHF50P2NWYh2
05iNGP80?clo0P0`<30203`l?080Bd];0P0n?Sh203Lg=`80<30`0P0c<c<00`0g=cL0>3Ph03Ph>002
03lo?`80A4A40P11@D4205MGE`80K6a/0P1_Kfl207IfMP80TY:B0P2PX:020:BTY080Shn?0P1fMWH2
07AdM0/0NWYj101kNg/207YjNP80O7al1P1jNWX207IfMP@0MGEe0P1fMWH00`1eMGD0NWYj07YjNP02
07YjNP80MWIf0P1hN7P207EeM@@0LG5a0P26QXH209^KV`80XZ:R0P2FUYH208R8R080Lg=c0P1YJFT2
06IVIP0306ATI01HF5P0F5QH0080Cdm?0P19BDT204Q8B080BDU90P16ATH204e=C@80>SXj0P0U9BD2
01PH6080410@100A4A4201DE5@80;bl_00<0A4A403Ti>@0i>CT00P1:BTX205=CD`80=cLg0P1@D502
05QHF080AdM70P1>CThU08F5Q@80RHV95@25QHDE0?ooo`004`3oool808F5Q@80PX:20P21PH4408F5
Q@0308:2PP21PH40PH610080QHF50P29RHT408F5Q@80WYjN0P1NGUh203lo?`80<30`0P0l?3`204];
B`80?Shn0P0g=cL2030`<080<c<c00<0=cLg03Ph>00h>3P00P0o?cl204A4A080@D510P1GEeL206a/
K080Kfm_0P1fMWH209:BTP80X:2P0P2TY:@208n?S`80MWIf0P1dM7@;07YjNP@0Ng]k0P1jNWX207al
O0H0NWYj0P1fMWH407EeM@80MWIf00<0MGEe07YjNP1jNWX00P1jNWX207IfMP80N7Qh0P1eMGD4075a
L@80QXJ60P2KVi/20::RXP80UYJF0P28R8P207=cL`80JFUY0P1VIVH00`1TI6@0F5QH05QHF00204m?
C`80BDU90P18B4P204U9B@80ATI60P1=CDd203Xj>P809BDU0P0H61P2010@40@04A4A0P0E5AD202l_
;`0304A4A00i>CT0>CTi0080BTY:0P1CDe<203Lg=`80D51@0P1HF5P204M7A`80CTi>9@25QHD208V9
RAD0QHF55@3oool001<0oooo1025QHD208:2PP80PH610P29RHT408F5Q@80PX:22`25QHD207moO`80
@d=30P0];Bd203Ph>080?clo0P1:BTX203Ph>080=CDe0P0i>CT203@d=00303De=@0d=3@0=3@d0080
>c/k0P14A4@20451@@80EEEE0P1`L702079bLP80Lg=c0P1bLW8407MgM`80NWYj0P20P80207IfMP80
LG5a00<0MGEe07YjNP1jNWX00P1jNWX207MgM`80MGEe1P1jNWX207emO@80LG5a0P1dM7@407IfMP80
NWYj0P1lO7`207MgM`0307QhN01gMgL0MgMg0080OGem0P1gMgL2071`L080MGEe0P1`L70206i^KP80
Kfm_0P1[Jf/206UYJ@@0J6QX0P1OGel205iNGP80GemO00<0F5QH05]KF`1KFe/00P1IFET205]KF`80
CDe=0P13@d<204E5A@80>SXj0P16ATH203Hf=P808B4Q0P0N7Qh201TI6@808B4Q0P0K6a/201lO7`03
05aLG011@D40@D510080<S8b0P1FEUH403`l?080F5QH0P1:BTX205eMG@80Rh^;>P25QHDE0?ooo`00
4`3oool408F5Q@80PX:20P21PH4208V9R@@0QHF50P22PX8;08F5Q@80Ogmo0P13@d<202d];@80>3Ph
0P0o?cl204Y:BP80>3Ph0P0e=CD203Ti>@80=3@d00<0=CDe03@d=00d=3@00P0k>c/204A4A080@D51
0P1EEED2071`L080LW9b0P1cLg<2079bLP@0MgMg0P1jNWX20820P080MWIf0P1aLG400`1eMGD0NWYj
07YjNP0207YjNP80MgMg0P1eMGD607YjNP80OGem0P1aLG4207AdM0@0MWIf0P1jNWX207alO080MgMg
00<0N7Qh07MgM`1gMgL00P1mOGd207MgM`80L71`0P1eMGD2071`L080KVi^0P1_Kfl206][J`80JFUY
101XJ6P205mOG`80GUiN0P1OGel00`1HF5P0Fe]K05]KF`0205UIF@80Fe]K0P1=CDd204=3@`80ADE5
0P0j>SX204I6AP80=SHf0P0Q8B4201hN7P806ATI0P0Q8B4201/K6`807alO00<0G5aL0451@@11@D40
0P0b<S8205IFEP@0?3`l0P1HF5P204Y:BP80GEeM0P2;Rh/j08F5QAD0oooo000C0?ooo`@0QHF50P29
RHT808F5Q@80RHV92`25QHD209ZJVP80F5QH100o?cl203<c<`80?Cdm0P12@T8203lo?`80>CTi0P0b
<S800`0`<300;bl_02l_;`02030`<080@4100P0i>CT204I6AP80IVIV0P1_Kfl2079bLP80KFe]0P1b
LW8207QhN080LG5a0P1dM7@20820P080O7al00<0MGEe07YjNP1jNWX00P1jNWX207moO`P0NWYj0P1o
Ogl20820P080NWYj1020P80407IfMP80MGEe00<0Lg=c071`L01`L7000P1`L70207MgM`@0M7Ad101_
Kfl207AdM080Jf][0P1^KVh206YZJP@0J6QX0P1TI6@206=SH`0305mOG`1QHF40HF5Q0080G5aL0P1>
CTh404U9B@80ADE50P17AdL202d];@808B4Q0P0W9bL202<S8`804a<C0P0>3Ph201@D50806ATI00<0
De=C04];B`1;Bd/00P15ADD205MGE`80?Shn0P0_;bl204i>CP80ADE50P1jNWXl08F5QAD0oooo000C
0?ooo`@0QHF50P29RHT808F5Q@80RHV92`25QHD209ZJVP80F5QH100o?cl203<c<`80?Cdm0P12@T82
03lo?`80>CTi0P0b<S800`0`<300;bl_02l_;`02030`<080@4100P0i>CT204I6AP80IVIV0P1_Kfl2
079bLP80KFe]0P1bLW8207QhN080LG5a0P1dM7@20820P080O7al00<0MGEe07YjNP1jNWX00P1jNWX2
07moO`P0NWYj0P1oOgl20820P080NWYj1020P80407IfMP80MGEe00<0Lg=c071`L01`L7000P1`L702
07MgM`@0M7Ad101_Kfl207AdM080Jf][0P1^KVh206YZJP@0J6QX0P1TI6@206=SH`0305mOG`1QHF40
HF5Q0080G5aL0P1>CTh404U9B@80ADE50P17AdL202d];@808B4Q0P0W9bL202<S8`804a<C0P0>3Ph2
01@D50806ATI00<0De=C04];B`1;Bd/00P15ADD205MGE`80?Shn0P0_;bl204i>CP80ADE50P1jNWXl
08F5QAD0oooo000C0?ooo`X0QHF50P22PX820861P@d0QHF50P2PX:0206m_K`80<C4a0P0^;Rh202TY
:@80=3@d0P0g=cL2038b<P@0=3@d00<0=SHf03@d=00d=3@00P0l?3`204e=C@@0Cdm?0P1QHF4206QX
J080LW9b0P1dM7@207=cL`@0MgMg0P1`L70207AdM080Ogmo1@1jNWX207MgM`80LW9b0P1eMGD807Yj
NP80MWIf101`L70407IfMP80LG5a00<0L71`07AdM01dM7@00P1dM7@2079bLP80KFe]0P1_Kfl2071`
L080Jf][0P1SHf<206YZJP80Jf][0P1/K6`206QXJ080Hf=S0P1TI6@2061PH00305QHF01@D500D51@
0080D51@0P1GEeL205=CD`80ADE50P11@D42038b<P80<30`100X:2P201TI6@804Q8B0P0A4A4201hN
7P806QXJ00<0EEEE06EUI@1UIFD00P1=CDd205]KF`80CTi>0P0_;bl205aLG080DU9B9@25QHD208:2
PP80PH615@25QHDE0?ooo`004`3oool:08F5Q@80PX:20P21PH4=08F5Q@80X:2P0P1_Kfl2034a<@80
;Rh^0P0Y:BT203@d=080=cLg0P0b<S8403@d=00303Hf=P0d=3@0=3@d0080?3`l0P1=CDd404m?C`80
HF5Q0P1XJ6P2079bLP80M7Ad0P1cLg<407MgM`80L71`0P1dM7@207moO`D0NWYj0P1gMgL2079bLP80
MGEe201jNWX207IfMP@0L71`101fMWH2075aL@03071`L01dM7@0M7Ad0080M7Ad0P1bLW8206e]K@80
Kfm_0P1`L70206][J`80Hf=S0P1ZJVX206][J`80K6a/0P1XJ6P206=SH`80I6AT0P1PH6000`1HF5P0
D51@051@D002051@D080EeMG0P1CDe<204E5A@80@D510P0b<S82030`<0@0:2PX0P0I6AT2018B4P80
4A4A0P0N7Qh201XJ6P0305EEE@1UIFD0IFEU0080CDe=0P1KFe/204i>CP80;bl_0P1LG5`2059BDRD0
QHF50P22PX820861PAD0QHF55@3oool001<0oooo2P25QHD208V9R@l0QHF50P2=SHd205iNGP80?3`l
0P0h>3P203Xj>P80?Shn0P11@D420492@P80>3Ph0P0g=cL00`0b<S80>SXj03Xj>P0203Ti>@80BTY:
0P1@D50204e=C@80HF5Q0P1YJFT2079bLP80MWIf101gMgL207QhN080Ng]k0P1jNWX207MgM`03079b
LP1eMGD0MGEe0080NWYj0P1lO7`407YjNP80MWIf0P1dM7@407YjNP80O7al101fMWH207MgM`80N7Qh
0P1nOWh00`1kNg/0N7Qh07QhN00407AdM080Lg=c101_Kfl2075aL@80IVIV0P1UIFD206ATI080J6QX
0P1ZJVX206ATI080HV9R0P1OGel00`1UIFD0Fe]K05]KF`0205IFEP80C4a<0P1@D50204e=C@80ADE5
0P0o?cl202TY:@80;Rh^0P0I6AT401LG5`804Q8B0P0E5AD202<S8`0303`l?018B4P0B4Q80080?Cdm
0P1KFe/205MGE`80ADE50P11@D4206UYJBD0QHF50P29RHTG08F5QAD0oooo000C0?ooo`X0QHF50P29
RHT?08F5Q@80SHf=0P1NGUh203`l?080>3Ph0P0j>SX203hn?P80@D510P12@T8203Ph>080=cLg00<0
<S8b03Xj>P0j>SX00P0i>CT204Y:BP80D51@0P1=CDd2065QH@80JFUY0P1bLW8207IfMP@0MgMg0P1h
N7P207]kN`80NWYj0P1gMgL00`1bLW80MGEe07EeM@0207YjNP80O7al101jNWX207IfMP80M7Ad101j
NWX207alO0@0MWIf0P1gMgL207QhN080OWin00<0Ng]k07QhN01hN7P0101dM7@207=cL`@0Kfm_0P1a
LG4206IVIP80IFEU0P1TI6@206QXJ080JVYZ0P1TI6@2069RHP80GemO00<0IFEU05]KF`1KFe/00P1F
EUH204a<C080D51@0P1=CDd204E5A@80?clo0P0Y:BT202h^;P806ATI100G5aL2018B4P805ADE0P0S
8b<00`0l?3`0B4Q804Q8B00203dm?@80Fe]K0P1GEeL204E5A@80@D510P1YJFTU08F5Q@80RHV95`25
QHDE0?ooo`004`3ooolK08F5Q@80PX:20P2<S8`403De=@80?3`l0P0o?cl203De=@80=cLg0P0e=CD2
038b<P030410@00m?Cd0?Cdm0080?3`l0P11@D4204i>CP80D51@0P1LG5`206IVIP80Kfm_101`L702
07=cL`80MgMg0P1bLW8207EeM@80Ogmo00<0Ng]k075aL@1aLG400P1eMGD207moO`80MWIf0P1aLG42
07]kN`80MgMg0P1aLG42071`L0X0MgMg0P1dM7@00`1cLg<0N7Qh07QhN00207AdM080LW9b0P1dM7@2
07EeM@80Kfm_0P1fMWH207AdM0@0KVi^0P1[Jf/206IVIP@0Hf=S0P1OGel00`1HF5P0EEEE05EEE@02
05EEE@80Cdm?0P1=CDd204=3@`80?clo0P0l?3`203Hf=P809BDU0P0L71`2018B4P@02`/;0P0Z:RX2
02l_;`03034a<@18B4P0B4Q80080BDU90P1MGEd206e]K@80NWYj0P1IFEU008F5QAD0oooo000C0?oo
oa/0QHF50P22PX8208b<S0@0=CDe0P0l?3`203lo?`80=CDe0P0g=cL203De=@80<S8b00<0@41003dm
?@0m?Cd00P0l?3`20451@@80CTi>0P1@D50205aLG080IVIV0P1_Kfl4071`L080Lg=c0P1gMgL2079b
LP80MGEe0P1oOgl00`1kNg/0LG5a075aL@0207EeM@80Ogmo0P1fMWH2075aL@80Ng]k0P1gMgL2075a
L@80L71`2P1gMgL207AdM00307=cL`1hN7P0N7Qh0080M7Ad0P1bLW8207AdM080MGEe0P1_Kfl207If
MP80M7Ad101^KVh206][J`80IVIV101SHf<205mOG`0305QHF01EEED0EEEE0080EEEE0P1?Cdl204e=
C@80@d=30P0o?cl203`l?080=SHf0P0U9BD201`L70804Q8B100;2`/202XZ:P80;bl_00<0<C4a04Q8
B018B4P00P19BDT205eMG@80KFe]0P1jNWX205UIFD00QHF55@3oool001<0oooo6`25QHD208:2PP80
FEUI0P19BDT205ADE080?3`l0P0e=CD203`l?080=SHf0P0h>3P203dm?@0302PX:00_;bl0;bl_0080
@D510P1;Bd/204a<C080Cdm?0P1KFe/206UYJ@80KFe]0P1bLW8607MgM`@0NWYj0P1fMWH00`1jNWX0
Ogmo07moO`0207YjNP80MgMg0P1kNg/207alO080LG5a0P1iNGT207emO@80MgMg0P1eMGD207MgM`80
MWIf0P1eMGD207IfMP80Ng]k00<0MgMg07]kN`1kNg/00P1cLg<2075aL@80Kfm_0P1cLg<2071`L080
JVYZ101]KFd406ATI0H0Hf=S0P1OGel00`1NGUh0FEUI05UIF@0205YJFP80D51@0P13@d<20451@@80
=CDe0P0/;2`2038b<P8092@T0P0C4a<200`<30806ATI0P0>3Ph2020P8080?Cdm00<0>CTi03Lg=`0g
=cL00P0h>3P205EEE@80C4a<0P1nOWh2079bLT00QHF55@3oool001<0oooo6`25QHD208:2PP80FEUI
0P19BDT205ADE080?3`l0P0e=CD203`l?080=SHf0P0h>3P203dm?@0302PX:00_;bl0;bl_0080@D51
0P1;Bd/204a<C080Cdm?0P1KFe/206UYJ@80KFe]0P1bLW8607MgM`@0NWYj0P1fMWH00`1jNWX0Ogmo
07moO`0207YjNP80MgMg0P1kNg/207alO080LG5a0P1iNGT207emO@80MgMg0P1eMGD207MgM`80MWIf
0P1eMGD207IfMP80Ng]k00<0MgMg07]kN`1kNg/00P1cLg<2075aL@80Kfm_0P1cLg<2071`L080JVYZ
101]KFd406ATI0H0Hf=S0P1OGel00`1NGUh0FEUI05UIF@0205YJFP80D51@0P13@d<20451@@80=CDe
0P0/;2`2038b<P8092@T0P0C4a<200`<30806ATI0P0>3Ph2020P8080?Cdm00<0>CTi03Lg=`0g=cL0
0P0h>3P205EEE@80C4a<0P1nOWh2079bLT00QHF55@3oool001<0oooo1025QHD208:2PP80PH610P22
PX820861P@l0QHF50P1nOWh20>WYj@80Kfm_0P0d=3@2038b<PH0;bl_0P0c<c<202l_;`030410@00j
>SX0>SXj0080?3`l0P17AdL405UIF@80GEeM0P1YJFT206m_K`80MGEe0P1gMgL407IfMP80MGEe0P1j
NWX207emO@0307EeM@1gMgL0MgMg0080MGEe0P1lO7`2075aL@80MWIf0P1kNg/207MgM`@0MWIf101g
MgL407QhN0@0MWIf00<0MgMg075aL@1aLG400P1fMWH207MgM`80LW9b101_Kfl2075aL@80IfMW0P1`
L70406QXJ0@0Hf=S0P1WIfL306=SH`80FEUI0P1GEeL204M7A`80ATI60P15ADD204Q8B080?clo0P0V
9RH2028R8P8051@D0P0B4Q8201LG5`8051@D0P0R8R8203hn?P030492@P11@D40@D510080?3`l0P1I
FET405mOGd80QHF55@3oool001<0oooo1025QHD208:2PP80PH610P22PX820861P@l0QHF50P1nOWh2
0>WYj@80Kfm_0P0d=3@2038b<PH0;bl_0P0c<c<202l_;`030410@00j>SX0>SXj0080?3`l0P17AdL4
05UIF@80GEeM0P1YJFT206m_K`80MGEe0P1gMgL407IfMP80MGEe0P1jNWX207emO@0307EeM@1gMgL0
MgMg0080MGEe0P1lO7`2075aL@80MWIf0P1kNg/207MgM`@0MWIf101gMgL407QhN0@0MWIf00<0MgMg
075aL@1aLG400P1fMWH207MgM`80LW9b101_Kfl2075aL@80IfMW0P1`L70406QXJ0@0Hf=S0P1WIfL3
06=SH`80FEUI0P1GEeL204M7A`80ATI60P15ADD204Q8B080?clo0P0V9RH2028R8P8051@D0P0B4Q82
01LG5`8051@D0P0R8R8203hn?P030492@P11@D40@D510080?3`l0P1IFET405mOGd80QHF55@3oool0
01<0oooo1025QHD208V9R@80QHF50P29RHTC08F5Q@80W9bL0P1VIVH203Ph>080<S8b0P0];Bd202l_
;`80<30`0P0Z:RX2034a<@0303Hf=P0o?cl0?clo0080ATI60P1=CDd2059BDP80GEeM0P1PH60206UY
J@80L71`0P1]KFd206m_K`80MgMg0P1fMWH4079bLP80MgMg00<0LG5a07UiN@1iNGT00P1jNWX207mo
O`80P8200P1kNg/2071`L080NGUi0P1mOGd207QhN0P0MgMg0P1hN7P207MgM`03075aL@1dM7@0M7Ad
00@0M7Ad0P1eMGD207AdM080MGEe0P1gMgL206m_K`80M7Ad0P1/K6`206QXJ080Hf=S0P1OGel205iN
GP80Hf=S00<0I6AT05QHF01HF5P00P1DE5@2059BDP80D51@0P0m?Cd203@d=0809RHV0P0P820201HF
5P805aLG0P0<30`2014A4@804Q8B0P0R8R8204A4A00303Ti>@0k>c/0>c/k0080?clo0P1TI6@207Mg
M`80IfMW@P25QHDE0?ooo`004`3oool408F5Q@80RHV90P25QHD208V9RA<0QHF50P2LW9`206IVIP80
>3Ph0P0b<S8202d];@80;bl_0P0`<30202XZ:P80<C4a00<0=SHf03lo?`0o?cl00P16ATH204e=C@80
DU9B0P1MGEd2061PH080JFUY0P1`L70206e]K@80Kfm_0P1gMgL207IfMP@0LW9b0P1gMgL00`1aLG40
NGUi07UiN@0207YjNP80Ogmo0P20P80207]kN`80L71`0P1iNGT207emO@80N7Qh201gMgL207QhN080
MgMg00<0LG5a07AdM01dM7@0101dM7@207EeM@80M7Ad0P1eMGD207MgM`80Kfm_0P1dM7@206a/K080
J6QX0P1SHf<205mOG`80GUiN0P1SHf<00`1TI6@0F5QH05QHF00205ADE080DU9B0P1@D50203dm?@80
=3@d0P0V9RH2020P80805QHF0P0G5aL200`<30804A4A0P0B4Q82028R8P80A4A400<0>CTi03/k>`0k
>c/00P0o?cl206ATI080MgMg0P1WIfM208F5QAD0oooo000C0?oooad0QHF50P1nOWh20;^k^`80FEUI
100f=SH2038b<P80<c<c0P0f=SH202l_;`0302d];@0f=SH0=SHf0080?3`l0P18B4P204i>CP80FUYJ
0P1SHf<206YZJP80KVi^0P1gMgL207=cL`80MgMg0P1eMGD207UiN@80Ng]k0P1iNGT00`20P800NWYj
07YjNP0407YjNP80MWIf0P1jNWX207emO@80LG5a0P1iNGT207]kN`H0MWIf1P1gMgL00`1kNg/0MgMg
07MgM`0207QhN080LG5a0P1dM7@206e]K@80Kfm_0P1`L70206m_K`80K6a/0P1XJ6P206UYJ@80I6AT
0P1WIfL205iNGP80GemO00<0EeMG05QHF01HF5P00P1IFET204Y:BP80AdM70P1<C4`203hn?P80:RXZ
0P0Q8B4401TI6@804a<C0P0E5AD201LG5`808B4Q0P1EEED50492@P80F5QH0P1kNg/208F5Q@80PX:2
0P21PH4n08F5QAD0oooo000C0?oooad0QHF50P1nOWh20;^k^`80FEUI100f=SH2038b<P80<c<c0P0f
=SH202l_;`0302d];@0f=SH0=SHf0080?3`l0P18B4P204i>CP80FUYJ0P1SHf<206YZJP80KVi^0P1g
MgL207=cL`80MgMg0P1eMGD207UiN@80Ng]k0P1iNGT00`20P800NWYj07YjNP0407YjNP80MWIf0P1j
NWX207emO@80LG5a0P1iNGT207]kN`H0MWIf1P1gMgL00`1kNg/0MgMg07MgM`0207QhN080LG5a0P1d
M7@206e]K@80Kfm_0P1`L70206m_K`80K6a/0P1XJ6P206UYJ@80I6AT0P1WIfL205iNGP80GemO00<0
EeMG05QHF01HF5P00P1IFET204Y:BP80AdM70P1<C4`203hn?P80:RXZ0P0Q8B4401TI6@804a<C0P0E
5AD201LG5`808B4Q0P1EEED50492@P80F5QH0P1kNg/208F5Q@80PX:20P21PH4n08F5QAD0oooo000C
0?ooo`80QHF50P22PX820861PAT0QHF50P2a/K42071`L080<S8b0P0Z:RX202d];@80;bl_0P0a<C42
03De=@03034a<@0d=3@0=3@d0080ADE50P1ADE4205YJFP80GEeM0P1UIFD206m_K`80JVYZ0P1]KFd2
06i^KP80M7Ad0P1hN7P2079bLP80N7Qh0P1bLW800`1eMGD0MgMg07MgM`0207EeM@80MWIf0P1gMgL2
079bLP80MWIf0P1gMgL2075aL@@0MWIf0P1hN7P207MgM`@0MWIf0P1gMgL00`1hN7P0L71`071`L002
079bLP80MGEe0P1cLg<2079bLP80Kfm_0P1`L70206][J`80Kfm_0P1^KVh206m_K`80J6QX0P1SHf<2
06ATI080Fe]K00<0H61P05EEE@1EEED00P1@D50204m?C`80@d=30P0j>SX203@d=080:BTY0P0Q8B42
01`L70805QHF100M7Ad2018B4P8061PH0P10@4000`1?Cdl0BTY:04Y:BP0205QHF080HV9R0P1WIfL2
08F5Q@80RHV9@025QHDE0?ooo`004`3oool208F5Q@80PX:20P21PH4I08F5Q@80/K6a0P1`L702038b
<P80:RXZ0P0];Bd202l_;`80<C4a0P0e=CD00`0a<C40=3@d03@d=00204E5A@80DE5A0P1JFUX205eM
G@80IFEU0P1_Kfl206YZJP80KFe]0P1^KVh207AdM080N7Qh0P1bLW8207QhN080LW9b00<0MGEe07Mg
M`1gMgL00P1eMGD207IfMP80MgMg0P1bLW8207IfMP80MgMg0P1aLG4407IfMP80N7Qh0P1gMgL407If
MP80MgMg00<0N7Qh071`L01`L7000P1bLW8207EeM@80Lg=c0P1bLW8206m_K`80L71`0P1[Jf/206m_
K`80KVi^0P1_Kfl206QXJ080Hf=S0P1TI6@205]KF`03061PH01EEED0EEEE0080D51@0P1?Cdl204=3
@`80>SXj0P0d=3@202TY:@808B4Q0P0L71`201HF5P@07AdM0P0B4Q8201PH6080@41000<0Cdm?04Y:
BP1:BTX00P1HF5P2069RHP80IfMW0P25QHD208V9RD00QHF55@3oool001<0oooo0P25QHD208V9RA/0
QHF50P29RHT20861P@80D51@0P0i>CT203De=@80=cLg0P0a<C42038b<P<0>3Ph0P0g=cL204=3@`80
EeMG0P1YJFT206IVIP80JVYZ0P1cLg<207EeM@H0MgMg0P1fMWH207EeM@80NGUi00<0NWYj07]kN`1k
Ng/00P1aLG4207QhN080MWIf0P1eMGD207IfMP80MGEe0P1gMgL207QhN0@0MWIf0P1gMgL207QhN080
MgMg1`1dM7@4071`L080Kfm_0P1^KVh206m_K`80L71`0P1ZJVX206MWI`@0IFEU0P1SHf<206ATI080
IFEU00<0Fe]K05IFEP1FEUH00P1=CDd204Y:BP80@D510P0j>SX202l_;`809bLW0P0T92@201hN7P80
5aLG0P0J6QX2014A4@8030`<0P0J6QX203Lg=`030451@@12@T80@T920080De=C0P1[Jf/207inOT@0
QHF55@3oool001<0oooo0P25QHD208V9RA/0QHF50P29RHT20861P@80D51@0P0i>CT203De=@80=cLg
0P0a<C42038b<P<0>3Ph0P0g=cL204=3@`80EeMG0P1YJFT206IVIP80JVYZ0P1cLg<207EeM@H0MgMg
0P1fMWH207EeM@80NGUi00<0NWYj07]kN`1kNg/00P1aLG4207QhN080MWIf0P1eMGD207IfMP80MGEe
0P1gMgL207QhN0@0MWIf0P1gMgL207QhN080MgMg1`1dM7@4071`L080Kfm_0P1^KVh206m_K`80L71`
0P1ZJVX206MWI`@0IFEU0P1SHf<206ATI080IFEU00<0Fe]K05IFEP1FEUH00P1=CDd204Y:BP80@D51
0P0j>SX202l_;`809bLW0P0T92@201hN7P805aLG0P0J6QX2014A4@8030`<0P0J6QX203Lg=`030451
@@12@T80@T920080De=C0P1[Jf/207inOT@0QHF55@3oool001<0oooo8@25QHD20>WYj@80_;bl0P1b
LW8204];B`80ATI60P18B4P203Xj>P0303<c<`0g=cL0=cLg00@0AdM70P19BDT205EEE@80Jf][0P1_
Kfl206YZJP80KVi^0P1_Kfl206i^KP80LW9b101fMWH2071`L003075aL@1hN7P0N7Qh0080MWIf0P1i
NGT207emO@@0MgMg0P1hN7P407MgM`80MGEe0P1cLg<207AdM0@0L71`0P1dM7@00`1gMgL0MGEe07Ee
M@0207=cL`80LG5a0P1^KVh406m_K`80J6QX0P1YJFT406][J`80IVIV0P1XJ6P206=SH`@0GEeM00<0
F5QH051@D01@D5000P1:BTX204Q8B080?clo0P0d=3@202`/;080<30`0P0S8b<2024Q8@806ATI0P0@
410200X:2P808R8R0P0e=CD204Y:BP0304Q8B01<C4`0C4a<0080De=C0P1FEUH208:2PP80PH61@P25
QHDE0?ooo`004`3oool208F5Q@80PX:20P21PH4?08F5Q@80PX:20P21PH4808F5Q@80PX:20P31`L42
0=_Kf`80L71`0P11@D4203De=@80>c/k00<0?Cdm03Hf=P0f=SH00P0h>3P204Y:BP80DU9B0P1CDe<2
061PH0@0Kfm_0P1^KVh207EeM@80MgMg0P1hN7P207EeM@80Lg=c0`1fMWH207MgM`80N7Qh0P1bLW82
07MgM`80N7Qh101fMWH407MgM`80Ng]k0P1gMgL207QhN0@0M7Ad0P1gMgL00`1dM7@0Lg=c07=cL`02
06YZJPH0L71`0P1_Kfl207=cL`80JFUY0P1UIFD206QXJ080KFe]0P1SHf<2061PH080Fe]K0P1EEED0
0`1IFET0E5AD05ADE00204a<C080=cLg0P0a<C4203De=@80;bl_0P0Q8B4202@T90806QXJ0P0L71`2
010@40802`/;0P0c<c<20492@P80?Shn00<0@41004I6AP16ATH00P1OGel206QXJ080RHV9A025QHDE
0?ooo`004`3oool208F5Q@80PX:20P21PH4?08F5Q@80PX:20P21PH4808F5Q@80PX:20P31`L420=_K
f`80L71`0P11@D4203De=@80>c/k00<0?Cdm03Hf=P0f=SH00P0h>3P204Y:BP80DU9B0P1CDe<2061P
H0@0Kfm_0P1^KVh207EeM@80MgMg0P1hN7P207EeM@80Lg=c0`1fMWH207MgM`80N7Qh0P1bLW8207Mg
M`80N7Qh101fMWH407MgM`80Ng]k0P1gMgL207QhN0@0M7Ad0P1gMgL00`1dM7@0Lg=c07=cL`0206YZ
JPH0L71`0P1_Kfl207=cL`80JFUY0P1UIFD206QXJ080KFe]0P1SHf<2061PH080Fe]K0P1EEED00`1I
FET0E5AD05ADE00204a<C080=cLg0P0a<C4203De=@80;bl_0P0Q8B4202@T90806QXJ0P0L71`2010@
40802`/;0P0c<c<20492@P80?Shn00<0@41004I6AP16ATH00P1OGel206QXJ080RHV9A025QHDE0?oo
o`004`3oool208F5Q@80RHV94@25QHD208V9R@X0QHF5101nOWh209BDU080XJ6Q0P11@D4203Lg=`80
;bl_00<0=3@d03Xj>P0j>SX00P0n?Sh204A4A080DU9B0P1JFUX205eMG@80I6AT0P1WIfL206YZJP@0
KVi^0P1/K6`4075aL@80M7Ad0`1gMgL207AdM080Lg=c101gMgL207EeM@80Lg=c0P1bLW8206i^KP@0
Kfm_101dM7@2079bLP80JFUY00<0JVYZ06m_K`1_Kfl01P1_Kfl2071`L080KVi^0P1]KFd206UYJ@@0
J6QX101TI6@206QXJ080Fe]K0P1VIVH00`1IFET0AdM704M7A`020451@@80@4100P0l?3`203Hf=P80
?Cdm0P0V9RH201lO7`807AdM0P0A4A4200`<3080CTi>0P1;Bd/403hn?P0304=3@`1TI6@0I6AT0080
K6a/0P1jNWX208:2PP80OWin0P21PH5008F5QAD0oooo000C0?ooo`80QHF50P29RHTA08F5Q@80RHV9
2P25QHD407inOP80U9BD0P2QXJ420451@@80=cLg0P0_;bl00`0d=3@0>SXj03Xj>P0203hn?P80A4A4
0P1BDU8205YJFP80GEeM0P1TI6@206MWI`80JVYZ101^KVh206a/K0@0LG5a0P1dM7@307MgM`80M7Ad
0P1cLg<407MgM`80MGEe0P1cLg<2079bLP80KVi^101_Kfl407AdM080LW9b0P1YJFT00`1ZJVX0Kfm_
06m_K`0606m_K`80L71`0P1^KVh206e]K@80JFUY101XJ6P406ATI080J6QX0P1KFe/206IVIP0305UI
F@17AdL0AdM70080@D510P10@40203`l?080=SHf0P0m?Cd202HV9P807alO0P0M7Ad2014A4@8030`<
0P1>CTh204];B`@0?Shn00<0@d=306ATI01TI6@00P1/K6`207YjNP80PX:20P1nOWh20861PD00QHF5
5@3oool001<0oooo9@25QHD208:2PP80[Zj^0P0o?cl202TY:@80Bd];00<0>c/k0492@P12@T800P17
AdL204Q8B080CTi>0P1GEeL2065QH@80L71`0P1^KVh206m_K`80JFUY0P1`L70207IfMP80MgMg0P1h
N7P206m_K`03079bLP1dM7@0M7Ad00P0MgMg0P1kNg/207AdM080MGEe0P1gMgL207UiN@80Kfm_0P1^
KVh206m_K`80L71`0P1eMGD506m_K`80L71`101_Kfl206YZJP80KFe]0P1/K6`206MWI`@0Hf=S0P1P
H60205IFEP80E5AD0`1CDe<204a<C080B4Q80P14A4@203/k>`80;Bd]0P0[:b/204Y:BP807QhN0P0@
410201DE5@80>CTi0P0T92@203Lg=`80ADE50P18B4P00`1:BTX0EeMG05MGE`0206MWI`80PH610P26
QXH208V9R@80Rh^;@025QHDE0?ooo`004`3ooolU08F5Q@80PX:20P2^[Zh203lo?`80:BTY0P1;Bd/0
0`0k>c/0@T920492@P0204M7A`80B4Q80P1>CTh205MGE`80HF5Q0P1`L70206i^KP80Kfm_0P1YJFT2
071`L080MWIf0P1gMgL207QhN080Kfm_00<0LW9b07AdM01dM7@0201gMgL207]kN`80M7Ad0P1eMGD2
07MgM`80NGUi0P1_Kfl206i^KP80Kfm_0P1`L70207EeM@D0Kfm_0P1`L70406m_K`80JVYZ0P1]KFd2
06a/K080IfMW101SHf<2061PH080EUIF0P1DE5@305=CD`80C4a<0P18B4P204A4A080>c/k0P0];Bd2
02/[:`80BTY:0P0N7Qh2010@40805ADE0P0i>CT202@T9080=cLg0P15ADD204Q8B00304Y:BP1GEeL0
EeMG0080IfMW0P21PH4208J6QP80RHV90P2;Rh]008F5QAD0oooo000C0?ooobD0QHF50P22PX820820
P080LW9b0P0j>SX202LW9`0303Ph>00l?3`0?3`l0080AdM70P18B4P2059BDP80FUYJ0P1LG5`205iN
GP80JVYZ0P1`L70206m_K`@0K6a/0P1]KFd207IfMP80Lg=c00<0L71`07AdM01dM7@0201`L70207=c
L`80MGEe0P1^KVh206QXJ080JVYZ0P1_Kfl206ATI080IfMW0P1ZJVX306i^KP80Kfm_0P1^KVh206m_
K`80L71`0P1_Kfl206e]K@80HV9R0P1XJ6P206ATI0@0Hf=S0P1QHF4205iNGP80CTi>0P1<C4`00`15
ADD0@4100410@00203/k>`80<c<c0P0e=CD203Lg=`80=3@d0P0N7Qh203<c<`80;Bd]0P0d=3@202HV
9P80@4100P13@d<204m?C`80F5QH0`1MGEd205iNGP80RHV90P2?Shl207inOT80QHF55@3oool001<0
oooo9@25QHD208:2PP80P8200P1bLW8203Xj>P809bLW00<0>3Ph03`l?00l?3`00P17AdL204Q8B080
DU9B0P1JFUX205aLG080GUiN0P1ZJVX2071`L080Kfm_101/K6`206e]K@80MWIf0P1cLg<00`1`L700
M7Ad07AdM008071`L080Lg=c0P1eMGD206i^KP80J6QX0P1ZJVX206m_K`80I6AT0P1WIfL206YZJP<0
KVi^0P1_Kfl206i^KP80Kfm_0P1`L70206m_K`80KFe]0P1RHV8206QXJ080I6AT101SHf<2065QH@80
GUiN0P1>CTh204a<C00304E5A@10@400@4100080>c/k0P0c<c<203De=@80=cLg0P0d=3@201hN7P80
<c<c0P0];Bd203@d=0809RHV0P10@40204=3@`80Cdm?0P1HF5P305eMG@80GUiN0P29RHT208n?S`80
OWin@P25QHDE0?ooo`004`3ooolU08F5Q@80PX:20P24Q8@207AdM080?3`l0P0];Bd00`0`<300:b/[
02/[:`0203Hf=P80@4100P17AdL204Y:BP80FEUI101QHF4206YZJP80J6QX0P1WIfL207=cL`80Jf][
0P1cLg<206i^KP0306][J`1/K6`0K6a/0080L71`0P1dM7@207MgM`80M7Ad0P1ZJVX2075aL@80KFe]
0P1_Kfl206QXJ080H61P0P1VIVH205mOG`80IfMW0P1_Kfl00`1/K6`0IFEU06EUI@0406ATI080H61P
0P1OGel206=SH`@0H61P0P1OGel205YJFP80EeMG0P1ADE4205ADE0@0D51@00<0Bd];04U9B@19BDT0
0P18B4P203De=@80;Bd]0P0[:b/202XZ:P80:b/[0P0W9bL2028R8P80@4100P1FEUH203`l?080?clo
0P1=CDd205mOG`0305]KF`27QhL0QhN70080QHF50P1nOWh208:2PP80PH610P25QHD208V9R@80Rh^;
7`25QHD208V9R@80Rh^;6@25QHDE0?ooo`004`3ooolU08F5Q@80PX:20P24Q8@207AdM080?3`l0P0]
;Bd00`0`<300:b/[02/[:`0203Hf=P80@4100P17AdL204Y:BP80FEUI101QHF4206YZJP80J6QX0P1W
IfL207=cL`80Jf][0P1cLg<206i^KP0306][J`1/K6`0K6a/0080L71`0P1dM7@207MgM`80M7Ad0P1Z
JVX2075aL@80KFe]0P1_Kfl206QXJ080H61P0P1VIVH205mOG`80IfMW0P1_Kfl00`1/K6`0IFEU06EU
I@0406ATI080H61P0P1OGel206=SH`@0H61P0P1OGel205YJFP80EeMG0P1ADE4205ADE0@0D51@00<0
Bd];04U9B@19BDT00P18B4P203De=@80;Bd]0P0[:b/202XZ:P80:b/[0P0W9bL2028R8P80@4100P1F
EUH203`l?080?clo0P1=CDd205mOG`0305]KF`27QhL0QhN70080QHF50P1nOWh208:2PP80PH610P25
QHD208V9R@80Rh^;7`25QHD208V9R@80Rh^;6@25QHDE0?ooo`004`3ooolU08F5Q@80OWin0P2_[jl2
09JFUP80>CTi0P0Q8B400`0h>3P0=cLg03Lg=`0203Hf=P80@T920P17AdL205EEE@80G5aL101OGel2
061PH080JFUY0P1UIFD206e]K@@0JVYZ0P1bLW800`1cLg<0KFe]06e]K@0406YZJP80IfMW0P1^KVh2
06][J`80Kfm_0P1/K6`206ATI080Hf=S101QHF4206=SH`80GemO0P1MGEd00`1LG5`0GemO05mOG`02
05aLG080Fe]K0P1JFUX205mOG`80HF5Q0P1LG5`405iNGP80FEUI0P1HF5P205YJFP80CDe=0P1:BTX2
04a<C00304e=C@12@T80@T9200@0>CTi0P0g=cL203@d=080@4100P11@D42038b<P80ATI60P11@D42
04a<C080AdM70P1HF5P205=CD`80MWIf00<0JFUY05UIF@1IFET00P21PH4208F5Q@@0RHV90P2;Rh/2
07inOQD0QHF50P22PX820861P@P0QHF50P1nOWhK08F5QAD0oooo000C0?ooobD0QHF50P1nOWh20:n_
[`80UYJF0P0i>CT2024Q8@0303Ph>00g=cL0=cLg0080=SHf0P12@T8204M7A`80EEEE0P1LG5`405mO
G`80H61P0P1YJFT206EUI@80KFe]101ZJVX2079bLP0307=cL`1]KFd0KFe]00@0JVYZ0P1WIfL206i^
KP80Jf][0P1_Kfl206a/K080I6AT0P1SHf<4065QH@80Hf=S0P1OGel205eMG@0305aLG01OGel0GemO
0080G5aL0P1KFe/205YJFP80GemO0P1QHF4205aLG0@0GUiN0P1IFET205QHF080FUYJ0P1=CDd204Y:
BP80C4a<00<0CDe=0492@P12@T80100i>CT203Lg=`80=3@d0P10@4020451@@80<S8b0P16ATH20451
@@80C4a<0P17AdL205QHF080De=C0P1fMWH00`1YJFT0FEUI05UIF@020861P@80QHF51029RHT208^;
R`80OWin5@25QHD208:2PP80PH612025QHD207inOQ/0QHF55@3oool001<0oooo9`25QHD209NGU`80
MGEe0P1gMgL204E5A@0302l_;`11@D40@D510080>3Ph0P0f=SH203`l?080?Shn0P1?Cdl206ATI080
IfMW0P1OGel206ATI080GemO0P1VIVH2075aL@80Kfm_0P1/K6`00`1^KVh0JFUY06UYJ@0606EUI@80
Hf=S0P1KFe/205IFEP80FEUI0P1NGUh205eMG@80F5QH0P1EEED204i>CP80CDe=0P1ADE400`1BDU80
De=C05=CD`02055AD@80EEEE0P1=CDd204I6AP80CTi>0P1:BTX204i>CP@0B4Q80P1:BTX4051@D080
BTY:0P0m?Cd00`0e=CD0>c/k03/k>`0204I6AP80>3Ph0P0n?Sh204Q8B080;Bd]0P0e=CD204U9B@80
@D510P0h>3P20410@080BDU90P1=CDd204m?C`80HV9R00<0Q8B408>3P`23Ph<01P25QHD207inOQT0
QHF50P29RHTW08F5QAD0oooo000C0?ooobL0QHF50P2GUiL207EeM@80MgMg0P15ADD00`0_;bl0@D51
0451@@0203Ph>080=SHf0P0l?3`203hn?P80Cdm?0P1TI6@206MWI`80GemO0P1TI6@205mOG`80IVIV
0P1aLG4206m_K`80K6a/00<0KVi^06UYJ@1YJFT01P1UIFD206=SH`80Fe]K0P1FEUH205UIF@80GUiN
0P1MGEd205QHF080EEEE0P1>CTh204e=C@80DE5A00<0DU9B05=CD`1CDe<00P1ADE4205EEE@80CDe=
0P16ATH204i>CP80BTY:0P1>CTh404Q8B080BTY:101@D50204Y:BP80?Cdm00<0=CDe03/k>`0k>c/0
0P16ATH203Ph>080?Shn0P18B4P202d];@80=CDe0P19BDT20451@@80>3Ph0P10@40204U9B@80CDe=
0P1?Cdl2069RHP0308B4Q023Ph<0Ph>300H0QHF50P1nOWhI08F5Q@80RHV99`25QHDE0?ooo`004`3o
oolY08F5Q@80`L710P2SXj<2069RHP0303dm?@0d=3@0=3@d0080?Shn0P14A4@204e=C@80@T92100k
>c/2059BDP80Hf=S0P1XJ6P207=cL`80KVi^0P1YJFT406EUI@0306IVIP1SHf<0Hf=S0080Fe]K0P1F
EUH205EEE@80IFEU0P1VIVH205aLG080Fe]K0P1JFUX205EEE@80Cdm?0P1>CTh204];B`80C4a<0P1A
DE400`1:BTX0AdM704M7A`0204I6AP80@4100P16ATH203hn?P80ADE50P18B4P204A4A0@0BTY:0P11
@D4204Q8B080EeMG0P1DE5@205QHF00305IFEP1<C4`0C4a<0080@4100P0o?cl203hn?P80BTY:0P16
ATH402<S8`80?clo0P1CDe<205EEE@80BTY:0P1UIFD406=SH`03061PH025QHD0QHF500X0QHF50P22
PX820861PAl0QHF50P29RHT208^;RaT0QHF55@3oool001<0oooo:@25QHD20<71`@80Xj>S0P1RHV80
0`0m?Cd0=3@d03@d=00203hn?P80A4A40P1=CDd20492@P@0>c/k0P1BDU8206=SH`80J6QX0P1cLg<2
06i^KP80JFUY101UIFD00`1VIVH0Hf=S06=SH`0205]KF`80EUIF0P1EEED206EUI@80IVIV0P1LG5`2
05]KF`80FUYJ0P1EEED204m?C`80CTi>0P1;Bd/204a<C080DE5A00<0BTY:04M7A`17AdL00P16ATH2
0410@080ATI60P0n?Sh204E5A@80B4Q80P14A4@404Y:BP80@D510P18B4P205MGE`80E5AD0P1HF5P0
0`1FEUH0C4a<04a<C0020410@080?clo0P0n?Sh204Y:BP80ATI6100S8b<203lo?`80De=C0P1EEED2
04Y:BP80IFEU101SHf<00`1PH600QHF508F5Q@0:08F5Q@80PX:20P21PH4O08F5Q@80RHV90P2;Rh/I
08F5QAD0oooo000C0?ooob/0QHF50P2m_Kd20=gMg@0308j>SP1@D500D51@0080=SHf0P0d=3@203hn
?P80>CTi0P0l?3`205EEE@80G5aL0P1bLW8207=cL`80KVi^101[Jf/206IVIP80GUiN00<0EeMG05]K
F`1KFe/00P1LG5`205mOG`80FUYJ0P1BDU8205iNGP80GEeM0P1EEED204];B`80DE5A0P18B4P204e=
C@80B4Q80P1=CDd203Xj>P0304Q8B015ADD0ADE50080ADE50P0e=CD204A4A080ADE50P10@4020492
@P80?Cdm0P11@D420492@P80AdM70P0d=3@202`/;080>3Ph0P0k>c/00`10@400?Shn03hn?P0204M7
A`80B4Q80P0c<c<202TY:@80?Cdm0P1ADE4204a<C080@D510P12@T82059BDP@0Jf][0P1IFET206e]
K@D0QHF50P22PX820861P@@0QHF50P29RHTI08F5Q@80PX:20P21PH4408F5Q@80OWin6`25QHDE0?oo
o`004`3oool[08F5Q@80_Kfm0P3MgMd00`2>SXh0D51@051@D00203Hf=P80=3@d0P0n?Sh203Ti>@80
?3`l0P1EEED205aLG080LW9b0P1cLg<206i^KP@0Jf][0P1VIVH205iNGP0305MGE`1KFe/0Fe]K0080
G5aL0P1OGel205YJFP80DU9B0P1NGUh205eMG@80EEEE0P1;Bd/2055AD@80B4Q80P1=CDd204Q8B080
CDe=0P0j>SX00`18B4P0ADE504E5A@0204E5A@80=CDe0P14A4@204E5A@80@4100P12@T8203dm?@80
@D510P12@T8204M7A`80=3@d0P0/;2`203Ph>080>c/k00<0@41003hn?P0n?Sh00P17AdL204Q8B080
<c<c0P0Y:BT203dm?@80DE5A0P1<C4`20451@@80@T920P1BDU8406][J`80FEUI0P1]KFd508F5Q@80
PX:20P21PH4408F5Q@80RHV96@25QHD208:2PP80PH611025QHD207inOQ/0QHF55@3oool001<0oooo
3P25QHD208:2PP030861P@22PX80PX:20080PH616025QHD2092@T00307moO`1BDU80DU9B0080EeMG
0P17AdL204];B`80LG5a0P1/K6`205eMG@80DE5A0P1BDU82055AD@80G5aL0P1VIVH4065QH@80GUiN
00<0GemO05eMG@1MGEd00P1DE5@204i>CP@0FEUI0P1@D50204m?C`80F5QH0P1?Cdl204a<C080BTY:
0P12@T8204M7A`80CDe=0P1GEeL00`1CDe<0AdM704M7A`0405EEE@80>c/k0P1BDU8204e=C@80DE5A
0P1>CTh204M7A`80Bd];0P1ADE4204E5A@80>SXj0P14A4@204M7A`030410@00n?Sh0?Shn0080AdM7
0P0n?Sh204E5A@80@D510P0n?Sh203/k>`80?Cdm0P19BDT206QXJ080LW9b0P1OGel205aLG080OGem
0P1YJFT508F5Q@80SHf=0P2;Rh/O08F5Q@80RHV98`25QHDE0?ooo`004`3oool>08F5Q@80PX:200<0
PH6108:2PP22PX800P21PH4H08F5Q@80T92@00<0Ogmo059BDP1BDU800P1GEeL204M7A`80Bd];0P1a
LG4206a/K080GEeM0P1ADE42059BDP80DE5A0P1LG5`206IVIP@0HF5Q0P1NGUh00`1OGel0GEeM05eM
G@0205ADE080CTi>101IFET2051@D080Cdm?0P1HF5P204m?C`80C4a<0P1:BTX20492@P80AdM70P1=
CDd205MGE`0305=CD`17AdL0AdM700@0EEEE0P0k>c/2059BDP80CDe=0P1ADE4204i>CP80AdM70P1;
Bd/2055AD@80ADE50P0j>SX204A4A080AdM700<0@41003hn?P0n?Sh00P17AdL203hn?P80ADE50P11
@D4203hn?P80>c/k0P0m?Cd204U9B@80J6QX0P1bLW8205mOG`80G5aL0P1mOGd206UYJ@D0QHF50P2=
SHd208^;Ral0QHF50P29RHTS08F5QAD0oooo000C0?ooo`@0QHF50P22PX820861P@H0QHF50P29RHT0
0`25QHD0RHV908V9R@0L08F5Q@030=kNgP1bLW80LW9b0080ATI60P19BDT203Lg=`80<C4a0P0n?Sh2
04U9B@80A4A40P1MGEd206IVIP80H61P0P1KFe/205aLG080GEeM0P1LG5`305=CD`80E5AD0P1<C4`2
04M7A`80C4a<0P1@D50204a<C080CDe=0P1BDU8204e=C@80?Cdm0P18B4P2038b<P80@4100P0o?cl0
0`1;Bd/0BDU904U9B@0203`l?080AdM70P1=CDd204Q8B080A4A40P0d=3@203hn?P@0BDU90P0i>CT2
0492@P80=CDe0P0Z:RX202@T900302LW9`0_;bl0;bl_0080:b/[0P0];Bd202`/;080<30`0P0c<c<2
04I6AP80F5QH0P1ZJVX206i^KP80HV9R0P1HF5P204e=C@80C4a<1`25QHD207inOTH0QHF55@3oool0
01<0oooo1025QHD208:2PP80PH611P25QHD208V9R@0308F5Q@29RHT0RHV901`0QHF500<0g]kN079b
LP1bLW800P16ATH204U9B@80=cLg0P0a<C4203hn?P80BDU90P14A4@205eMG@80IVIV0P1PH60205]K
F`80G5aL0P1MGEd205aLG0<0De=C0P1DE5@204a<C080AdM70P1<C4`2051@D080C4a<0P1=CDd2059B
DP80CDe=0P0m?Cd204Q8B080<S8b0P10@40203lo?`0304];B`19BDT0BDU90080?3`l0P17AdL204e=
C@80B4Q80P14A4@203@d=080?Shn1019BDT203Ti>@80@T920P0e=CD202XZ:P8092@T00<09bLW02l_
;`0_;bl00P0[:b/202d];@80;2`/0P0`<30203<c<`80ATI60P1HF5P206YZJP80KVi^0P1RHV8205QH
F080CDe=0P1<C4`708F5Q@80OWinAP25QHDE0?ooo`004`3oool408F5Q@80RHV9:@25QHD00`1nOWh0
l_;b0?;blP0208j>SP80EEEE0P1?Cdl205EEE@80HF5Q0P1VIVH206][J`80J6QX0P1VIVH206QXJ080
GUiN0P1CDe<2051@D080FEUI0`1DE5@205eMG@80E5AD0P1ADE4204M7A`80DU9B0P1=CDd204I6AP80
?3`l0P0k>c/204A4A080CDe=0P14A4@202@T9080<S8b00<0<30`0492@P12@T800P1;Bd/404M7A`80
;Rh^0P0m?Cd204A4A080;2`/0P0J6QX202XZ:P80=CDe0P0a<C4203Lg=`80?Cdm0P15ADD00`17AdL0
?Shn03hn?P020451@@80=cLg0P0k>c/204E5A@80IFEU0P1^KVh2065QH@80JFUY0P0f=SH203Xj>P80
@d=30P1^KVh206][J`80Rh^;2`25QHD208:2PP80PH61?P25QHDE0?ooo`004`3oool408F5Q@80RHV9
:@25QHD00`1nOWh0l_;b0?;blP0208j>SP80EEEE0P1?Cdl205EEE@80HF5Q0P1VIVH206][J`80J6QX
0P1VIVH206QXJ080GUiN0P1CDe<2051@D080FEUI0`1DE5@205eMG@80E5AD0P1ADE4204M7A`80DU9B
0P1=CDd204I6AP80?3`l0P0k>c/204A4A080CDe=0P14A4@202@T9080<S8b00<0<30`0492@P12@T80
0P1;Bd/404M7A`80;Rh^0P0m?Cd204A4A080;2`/0P0J6QX202XZ:P80=CDe0P0a<C4203Lg=`80?Cdm
0P15ADD00`17AdL0?Shn03hn?P020451@@80=cLg0P0k>c/204E5A@80IFEU0P1^KVh2065QH@80JFUY
0P0f=SH203Xj>P80@d=30P1^KVh206][J`80Rh^;2`25QHD208:2PP80PH61?P25QHDE0?ooo`004`3o
ool`08F5Q@80OWin0P2BTY8205eMG@80>c/k0P0[:b/202l_;`80<C4a0P11@D4205]KF`80HV9R0P1S
Hf<206YZJP80F5QH0P1@D50204a<C0D0D51@0P17AdL204];B`80DE5A0P14A4@204Q8B080DU9B0P0n
?Sh205ADE080Cdm?0P0g=cL405ADE080;Bd]00<0AdM703Hf=P0f=SH00P0b<S8203De=@80<30`0P0f
=SH202d];@80820P0P0b<S8203Hf=P@0=CDe0P0b<S8203Ti>@80=SHf0P0`<3000`0X:2P0<30`030`
<00203lo?`80FUYJ0P1LG5`206MWI`80CDe=0P1ZJVX2071`L080B4Q80P1DE5@204M7A`80EUIF0P1;
Bd/207inOPD0QHF50P22PX820861P@80QHF50P22PX8K08F5Q@80PX:20P21PH4208F5Q@80RHV90P2;
Rh/M08F5QAD0oooo000C0?oooc00QHF50P1nOWh209:BTP80GEeM0P0k>c/202/[:`80;bl_0P0a<C42
0451@@80Fe]K0P1RHV8206=SH`80JVYZ0P1HF5P2051@D080C4a<1@1@D50204M7A`80Bd];0P1ADE42
04A4A080B4Q80P1BDU8203hn?P80E5AD0P1?Cdl203Lg=`@0E5AD0P0];Bd00`17AdL0=SHf03Hf=P02
038b<P80=CDe0P0`<30203Hf=P80;Bd]0P0P8202038b<P80=SHf100e=CD2038b<P80>CTi0P0f=SH2
030`<00302PX:00`<300<30`0080?clo0P1JFUX205aLG080IfMW0P1=CDd206YZJP80L71`0P18B4P2
05ADE080AdM70P1FEUH204];B`80OWin1@25QHD208:2PP80PH610P25QHD208:2PQ/0QHF50P22PX82
0861P@80QHF50P29RHT208^;Rad0QHF55@3oool001<0oooo<P25QHD20<K6aP80EeMG0P12@T8205]K
F`80G5aL0P18B4P20451@@80CDe=0P1PH60205iNGP80GemO0P1>CTh20492@P80B4Q800<0Bd];05AD
E01DE5@00P1ADE4204E5A@80A4A40P1:BTX204a<C080Bd];0P1:BTX205QHF080<30`0P0e=CD204M7
A`80;Bd]0P17AdL20410@00302h^;P0k>c/0>c/k0080=SHf0P0c<c<203Lg=`80;bl_0P0a<C4203Lg
=`80<S8b0P0];Bd2028R8P80;Bd]0P0c<c<202h^;P80;bl_0P0b<S800`0l?3`0BDU904U9B@0204Y:
BP@0@T920P16ATH206UYJ@80@D510P0];Bd204I6AP80HF5Q0P1IFET208^;R`80MgMg0P1nOWh20861
P@0308F5Q@22PX80PX:200@0QHF50P22PX8408F5Q@80RHV90P2;Rh/608F5Q@80RHV90P2;Rh/;08F5
Q@80RHV91025QHD207inOQl0QHF55@3oool001<0oooo<P25QHD20<K6aP80EeMG0P12@T8205]KF`80
G5aL0P18B4P20451@@80CDe=0P1PH60205iNGP80GemO0P1>CTh20492@P80B4Q800<0Bd];05ADE01D
E5@00P1ADE4204E5A@80A4A40P1:BTX204a<C080Bd];0P1:BTX205QHF080<30`0P0e=CD204M7A`80
;Bd]0P17AdL20410@00302h^;P0k>c/0>c/k0080=SHf0P0c<c<203Lg=`80;bl_0P0a<C4203Lg=`80
<S8b0P0];Bd2028R8P80;Bd]0P0c<c<202h^;P80;bl_0P0b<S800`0l?3`0BDU904U9B@0204Y:BP@0
@T920P16ATH206UYJ@80@D510P0];Bd204I6AP80HF5Q0P1IFET208^;R`80MgMg0P1nOWh20861P@03
08F5Q@22PX80PX:200@0QHF50P22PX8408F5Q@80RHV90P2;Rh/608F5Q@80RHV90P2;Rh/;08F5Q@80
RHV91025QHD207inOQl0QHF55@3oool001<0oooo<P25QHD207inOP80oooo0P1hN7P202@T9080>SXj
0P1OGel205aLG080C4a<0P1BDU8206e]K@80JFUY0P1JFUX204Y:BP80C4a<00<0?3`l0451@@11@D40
0P16ATH204A4A080@D510P19BDT204A4A080>c/k0P11@D4203hn?P80@4100P0l?3`204=3@`80@T92
0P0/;2`202XZ:P0303`l?00g=cL0=cLg0080<C4a0P0b<S8403@d=080;2`/0P0Z:RX2028R8P80820P
0P0V9RH402DU9@80;Bd]0P0o?cl203hn?P0303Lg=`10@400@4100080GEeM0P1VIVH207alO080N7Qh
0P1HF5P205iNGP80A4A40P1=CDd203`l?080GUiN0P29RHT209BDU080S8b<0P21PH400`25QHD0RHV9
08V9R@0408F5Q@80RHV91025QHD207inOPP0QHF50P1nOWhd08F5QAD0oooo000C0?oooc80QHF50P1n
OWh20?ooo`80N7Qh0P0T92@203Xj>P80GemO0P1LG5`204a<C080DU9B0P1]KFd206UYJ@80FUYJ0P1:
BTX204a<C00303`l?011@D40@D510080ATI60P14A4@20451@@80BDU90P14A4@203/k>`80@D510P0n
?Sh20410@080?3`l0P13@d<20492@P80;2`/0P0Z:RX00`0l?3`0=cLg03Lg=`02034a<@80<S8b100d
=3@202`/;080:RXZ0P0R8R82020P80809RHV100U9BD202d];@80?clo0P0n?Sh00`0g=cL0@4100410
@00205eMG@80IVIV0P1lO7`207QhN080F5QH0P1NGUh204A4A080CDe=0P0l?3`205iNGP80RHV90P2D
U9@208b<S080PH6100<0QHF508V9R@29RHT01025QHD208V9R@@0QHF50P1nOWh808F5Q@80OWin=025
QHDE0?ooo`004`3ooolb08F5Q@80PX:20P21PH420>[ZjP80Ti>C0P0T92@2020P8080>3Ph0P1;Bd/2
04m?C`80IfMW0P1YJFT205]KF`80>3Ph0P1;Bd/00`1ADE40Bd];04];B`0405aLG0@0@4100P1>CTh2
03Xj>P80@D510P17AdL204I6AP80>CTi0P19BDT204Q8B080BDU90P0V9RH00`0I6AT0<S8b038b<P02
04M7A`80?3`l0P0a<C4202DU9@80;Rh^0P0/;2`202LW9`80820P0P0O7al201dM7@8071`L0P0S8b<2
02/[:`80C4a<00<0I6AT05IFEP1FEUH00P19BDT206ATI080CDe=0P0^;Rh202`/;080ADE50P1GEeL2
03De=@80GUiN0P1DE5@407inOP80RHV90`25QHD208:2PP80PH610P29RHT208^;Ra@0QHF50P22PX80
0`21PH40QHF508F5Q@0>08F5Q@80RHV90P2;Rh/I08F5QAD0oooo000C0?ooo`X0QHF50P22PX820861
PB@0QHF50P29RHT208F5Q@80OWin0P30`<0206][J`80<30`0P0Z:RX203Hf=P80@D510P1>CTh206IV
IP80IFEU0P17AdL203Hf=P03051@D011@D40@D510080=3@d0P0n?Sh204=3@`80<C4a0P0j>SX204Q8
B080>CTi0P0g=cL204];B`80ADE50P0g=cL20451@@80BDU90P1EEED00`15ADD0<30`030`<00201lO
7`80=CDe0P0f=SH203Xj>P80=cLg0P0i>CT204Q8B080A4A40P0k>c/20492@P80D51@0P1DE5@205=C
D`80CDe=00<0EEEE07alO01lO7`00P1[Jf/204M7A`80BTY:0P0c<c<202l_;`80@D510P1CDe<206IV
IP80MGEe2P25QHD00`29RHT0Shn?08n?S`0208:2PP80NWYj2025QHD208V9R@80Rh^;2P25QHD208V9
R@0308F5Q@29RHT0RHV90080Rh^;3025QHD207inOQ/0QHF55@3oool001<0oooo2P25QHD208:2PP80
PH619025QHD208V9R@80QHF50P1nOWh20<30`080Jf][0P0`<30202XZ:P80=SHf0P11@D4204i>CP80
IVIV0P1UIFD204M7A`80=SHf00<0D51@0451@@11@D400P0d=3@203hn?P80@d=30P0a<C4203Xj>P80
B4Q80P0i>CT203Lg=`80Bd];0P15ADD203Lg=`80@D510P19BDT205EEE@0304E5A@0`<300<30`0080
7alO0P0e=CD203Hf=P80>SXj0P0g=cL203Ti>@80B4Q80P14A4@203/k>`80@T920P1@D50205ADE080
De=C0P1=CDd00`1EEED0O7al07alO00206][J`80AdM70P1:BTX203<c<`80;bl_0P11@D4205=CD`80
IVIV0P1eMGD:08F5Q@0308V9R@2?Shl0Shn?0080PX:20P1jNWX808F5Q@80RHV90P2;Rh/:08F5Q@80
RHV900<0QHF508V9R@29RHT00P2;Rh/<08F5Q@80OWin6`25QHDE0?ooo`004`3oool:08F5Q@80RHV9
;025QHD20::RXP80`L710P1_Kfl204U9B@80<30`0P0U9BD202XZ:P80=cLg0P1ZJVX205ADE080=3@d
00<0=cLg051@D01@D5000P1:BTX203Xj>P80=SHf0P0a<C4202/[:`80<C4a0P0h>3P403/k>`@0>SXj
0P0m?Cd204i>CP80C4a<00<0AdM70410@010@4000P1=CDd203Xj>P80<S8b0P11@D4204I6AP80@T92
0P0g=cL204I6AP80DE5A0P1JFUX206MWI`80HV9R0P1MGEd206YZJP0306EUI@12@T80@T920080DE5A
0P14A4@203Ph>080BDU90P1?Cdl204e=C@80@D510P1gMgL208^;R`80RHV90P2@T90208^;R`80PX:2
0P25QHD00`22PX80QHF508F5Q@0208n?S`80PX:20P21PH4208V9R@80Rh^;0P25QHD207inOPl0QHF5
0P1nOWh808F5Q@80RHV90P2;Rh/O08F5QAD0oooo000C0?ooo`X0QHF50P29RHT/08F5Q@80XZ:R0P31
`L4206m_K`80BDU90P0`<30202DU9@80:RXZ0P0g=cL206YZJP80E5AD0P0d=3@00`0g=cL0D51@051@
D00204Y:BP80>SXj0P0f=SH2034a<@80:b/[0P0a<C4203Ph>0@0>c/k100j>SX203dm?@80CTi>0P1<
C4`00`17AdL0@4100410@00204e=C@80>SXj0P0b<S820451@@80ATI60P12@T8203Lg=`80ATI60P1A
DE4205YJFP80IfMW0P1RHV8205eMG@80JVYZ00<0IFEU0492@P12@T800P1ADE4204A4A080>3Ph0P19
BDT204m?C`80CDe=0P11@D4207MgM`80Rh^;0P29RHT2092@T080Rh^;0P22PX8208F5Q@0308:2PP25
QHD0QHF50080Shn?0P22PX820861P@80RHV90P2;Rh/208F5Q@80OWin3`25QHD207inOPP0QHF50P29
RHT208^;Ral0QHF55@3oool001<0oooo<P25QHD208V9R@80Rh^;1025QHD20:j^[P80Y:BT0P1IFET2
04Q8B080BTY:0P14A4@204Y:BP80@D510P1mOGd205=CD`0303Lg=`0m?Cd0?Cdm0080DU9B0P17AdL2
059BDP80?clo0P0d=3@203<c<`80?3`l0P0o?cl20410@080=cLg0P11@D4204=3@`80BDU90P1CDe<0
0`1BDU80Jf][06][J`0204M7A`80?Shn100j>SX204E5A@80E5AD0P1LG5`205eMG@80FEUI0P1SHf<2
06ATI080K6a/0P1>CTh202h^;P0303Ph>00/;2`0;2`/00807alO0P0N7Qh204I6AP80CTi>0P13@d<2
051@D080WIfM1025QHD207inOP80PX:20P2@T90208n?S`80OWin00<0SHf=08F5Q@25QHD00P25QHD2
08V9R@80QHF50P1nOWhO08F5Q@80OWin8@25QHDE0?ooo`004`3ooolb08F5Q@80RHV90P2;Rh/408F5
Q@80[Zj^0P2TY:@205UIF@80B4Q80P1:BTX204A4A080BTY:0P11@D4207emO@80De=C00<0=cLg03dm
?@0m?Cd00P1BDU8204M7A`80DU9B0P0o?cl203@d=080<c<c0P0l?3`203lo?`80@4100P0g=cL20451
@@80@d=30P19BDT205=CD`03059BDP1[Jf/0Jf][0080AdM70P0n?Sh403Xj>P80ADE50P1DE5@205aL
G080GEeM0P1IFET206=SH`80I6AT0P1/K6`204i>CP80;Rh^00<0>3Ph02`/;00/;2`00P0O7al201hN
7P80ATI60P1>CTh204=3@`80D51@0P2MWId408F5Q@80OWin0P22PX82092@T080Shn?0P1nOWh00`2=
SHd0QHF508F5Q@0208F5Q@80RHV90P25QHD207inOQl0QHF50P1nOWhQ08F5QAD0oooo000C0?oooc80
QHF50P1lO7`20861P@80QHF50P22PX820861P@80_Kfm0P2c/k<2051@D080>SXj0P16ATH205=CD`80
DU9B0P1HF5P208:2PP0305]KF`13@d<0@d=30080>SXj0P17AdL20492@P80De=C0P1;Bd/203Lg=`80
:RXZ0P0V9RH202`/;080>CTi0P0d=3@204=3@`80AdM70P1LG5`00`1aLG40Shn?08n?S`0209fMW@80
R8R80P2;Rh/208>3P`80OWin0P1cLg<208F5Q@80Ti>C0P25QHD206YZJP80De=C0P0b<S8403hn?P03
034a<@0c<c<0<c<c0080@D510P1CDe<205QHF080CTi>0P19BDT207EeM@@0QHF50P29RHT208^;R`@0
OWin1025QHD00`1nOWh0QHF508F5Q@0208:2PP80PH610P25QHD208V9R@80T92@0P2;Rh/n08F5QAD0
oooo000C0?oooc80QHF50P1lO7`20861P@80QHF50P22PX820861P@80_Kfm0P2c/k<2051@D080>SXj
0P16ATH205=CD`80DU9B0P1HF5P208:2PP0305]KF`13@d<0@d=30080>SXj0P17AdL20492@P80De=C
0P1;Bd/203Lg=`80:RXZ0P0V9RH202`/;080>CTi0P0d=3@204=3@`80AdM70P1LG5`00`1aLG40Shn?
08n?S`0209fMW@80R8R80P2;Rh/208>3P`80OWin0P1cLg<208F5Q@80Ti>C0P25QHD206YZJP80De=C
0P0b<S8403hn?P03034a<@0c<c<0<c<c0080@D510P1CDe<205QHF080CTi>0P19BDT207EeM@@0QHF5
0P29RHT208^;R`@0OWin1025QHD00`1nOWh0QHF508F5Q@0208:2PP80PH610P25QHD208V9R@80T92@
0P2;Rh/n08F5QAD0oooo000C0?oooc80QHF50P29RHT408F5Q@@0RHV90P2;Rh/20;Bd]080kno_0P1o
Ogl203lo?`80;2`/0P0`<30205=CD`80JFUY00<0QhN705iNGP1NGUh00P1PH60204m?C`80EeMG0P1=
CDd205eMG@80PH610P1YJFT20410@0@0=cLg0P0d=3@2059BDP80Fe]K0P1UIFD00`0k>c/0@T920492
@P0206e]K@80O7al0P1cLg<208R8R080SXj>0P1oOgl205=CD`80?clo0P14A4@203`l?080@4100P15
ADD203/k>`80<30`00<0;bl_0410@010@4000P1<C4`204i>CP80B4Q80P1CDe<209JFUP80OWin0P25
QHD208:2PP80NWYj0P25QHD208:2PP80OWin0P21PH4308F5Q@80PX:21P25QHD407inOP80QHF50P22
PX820861PCX0QHF55@3oool001<0oooo<P25QHD208V9R@@0QHF51029RHT208^;R`80];Bd0P3_knl2
07moO`80?clo0P0/;2`2030`<080De=C0P1YJFT00`27QhL0GUiN05iNGP02061PH080Cdm?0P1GEeL2
04e=C@80GEeM0P21PH4206UYJ@80@410100g=cL203@d=080DU9B0P1KFe/206EUI@0303/k>`12@T80
@T920080KFe]0P1lO7`207=cL`80R8R80P2>SXh207moO`80De=C0P0o?cl204A4A080?3`l0P10@402
04E5A@80>c/k0P0`<3000`0_;bl0@4100410@00204a<C080CTi>0P18B4P205=CD`80UYJF0P1nOWh2
08F5Q@80PX:20P1jNWX208F5Q@80PX:20P1nOWh20861P@<0QHF50P22PX8608F5Q@@0OWin0P25QHD2
08:2PP80PH61>P25QHDE0?ooo`004`3ooolj08F5Q@80PX:20P2;Rh/208F5Q@80RXZ:0P3Ti>@207mo
O`80A4A40P0i>CT203Hf=P80B4Q800<0KFe]08J6QP26QXH00P1aLG4208:2PP80OGem0P2>SXh208Z:
RP80JVYZ0P2@T9020<g=c@80eMGE0P3^k^h20<K6aP80WinO0P2=SHd208N7Q`0309:BTP1gMgL0MgMg
0080LW9b0P1cLg<2079bLP80HF5Q0P11@D420410@080DE5A0P11@D4203`l?080@T920P0m?Cd203Ph
>080<S8b0P1:BTX00`1PH600EEEE05EEE@0204m?C`80?clo0P29RHT20=KFeP80QHF51029RHT608F5
Q@80RHV90P26QXH20861P@<0QHF50P29RHT208:2PP80PH610P25QHD208V9R@80Rh^;0P25QHD208J6
QP80PH610P25QHD208:2PP80PH610P29RHT208^;Rc00QHF55@3oool001<0oooo>P25QHD208:2PP80
Rh^;0P25QHD208Z:RP80i>CT0P1oOgl204A4A080>CTi0P0f=SH204Q8B00306e]K@26QXH0QXJ60080
LG5a0P22PX8207emO@80SXj>0P2:RXX206YZJP80T92@0P3=cLd20=GEe@80k^k^0P36a/H209nOW`80
SHf=0P27QhL00`2BTY80MgMg07MgM`02079bLP80Lg=c0P1bLW82065QH@80@D510P10@402055AD@80
@D510P0l?3`20492@P80?Cdm0P0h>3P2038b<P80BTY:00<0H61P05EEE@1EEED00P1?Cdl203lo?`80
RHV90P3Fe]H208F5Q@@0RHV91P25QHD208V9R@80QXJ60P21PH4308F5Q@80RHV90P22PX820861P@80
QHF50P29RHT208^;R`80QHF50P26QXH20861P@80QHF50P22PX820861P@80RHV90P2;Rh/`08F5QAD0
oooo000C0?ooobL0QHF50P29RHT208^;R`l0QHF50P22PX8208^;R`@0QHF50P1nOWh20>?Sh`80h>3P
0P1HF5P2034a<@80=SHf00<0@41006ATI01TI6@00P1lO7`207moO`80SHf=0P1aLG4207UiN@80R8R8
0P1cLg<206a/K080EEEE0P1OGel206UYJ@80LG5a0P1oOgl208^;R`0307MgM`1fMWH0MWIf0080JVYZ
0P1@D50204];B`80G5aL0P1QHF42059BDP80B4Q80P12@T8203Xj>P80=CDe0P19BDT205=CD`80L71`
0P1ZJVX00`1KFe/0Cdm?04m?C`0205eMG@80YZJV0P1nOWh208:2PP80PH610P1lO7`:08F5Q@80RHV9
0P25QHD208:2PP030861P@25QHD0QHF50080RHV91025QHD207inOP@0QHF50P29RHT408F5Q@80RHV9
0P25QHD207inOPl0QHF50P29RHT208^;R`80QHF50P29RHT208^;R`80PX:20P21PH4E08F5QAD0oooo
000C0?ooobL0QHF50P29RHT208^;R`l0QHF50P22PX8208^;R`@0QHF50P1nOWh20>?Sh`80h>3P0P1H
F5P2034a<@80=SHf00<0@41006ATI01TI6@00P1lO7`207moO`80SHf=0P1aLG4207UiN@80R8R80P1c
Lg<206a/K080EEEE0P1OGel206UYJ@80LG5a0P1oOgl208^;R`0307MgM`1fMWH0MWIf0080JVYZ0P1@
D50204];B`80G5aL0P1QHF42059BDP80B4Q80P12@T8203Xj>P80=CDe0P19BDT205=CD`80L71`0P1Z
JVX00`1KFe/0Cdm?04m?C`0205eMG@80YZJV0P1nOWh208:2PP80PH610P1lO7`:08F5Q@80RHV90P25
QHD208:2PP030861P@25QHD0QHF50080RHV91025QHD207inOP@0QHF50P29RHT408F5Q@80RHV90P25
QHD207inOPl0QHF50P29RHT208^;R`80QHF50P29RHT208^;R`80PX:20P21PH4E08F5QAD0oooo000C
0?ooobL0QHF50P1nOWh=08F5Q@80RHV90P2;Rh/208:2PP80T92@0P2;Rh/208V9R@80Rh^;0P25QHD2
09bLW080kno_0P1oOgl204=3@`0303hn?P16ATH0ATI60080EeMG0P1EEED2069RHP80Jf][0P1eMGD2
07alO080MGEe0P20P80208J6QP80R8R80P22PX8207EeM@80M7Ad0P1gMgL00`1cLg<0IfMW06MWI`02
075aL@80JFUY0P0o?cl204m?C`80AdM70P0g=cL204I6AP80BDU90P16ATH204];B`80H61P0P1VIVH2
05QHF080C4a<00<0EeMG08b<S02<S8`00P2^[Zh408F5Q@80QXJ60P21PH4208V9R@80QHF50P29RHT2
08^;R`80RHV90P2;Rh/208F5Q@80PX:24@25QHD208V9R@80Rh^;3025QHD00`29RHT0Rh^;08^;R`06
08F5Q@80RHV91P25QHD207inOP80RHV90P2?ShlG08F5QAD0oooo000C0?ooobL0QHF50P1nOWh=08F5
Q@80RHV90P2;Rh/208:2PP80T92@0P2;Rh/208V9R@80Rh^;0P25QHD209bLW080kno_0P1oOgl204=3
@`0303hn?P16ATH0ATI60080EeMG0P1EEED2069RHP80Jf][0P1eMGD207alO080MGEe0P20P80208J6
QP80R8R80P22PX8207EeM@80M7Ad0P1gMgL00`1cLg<0IfMW06MWI`02075aL@80JFUY0P0o?cl204m?
C`80AdM70P0g=cL204I6AP80BDU90P16ATH204];B`80H61P0P1VIVH205QHF080C4a<00<0EeMG08b<
S02<S8`00P2^[Zh408F5Q@80QXJ60P21PH4208V9R@80QHF50P29RHT208^;R`80RHV90P2;Rh/208F5
Q@80PX:24@25QHD208V9R@80Rh^;3025QHD00`29RHT0Rh^;08^;R`0608F5Q@80RHV91P25QHD207in
OP80RHV90P2?ShlG08F5QAD0oooo000C0?ooocH0QHF50P1nOWh208F5Q@@0OWin0P25QHD207inOP80
QHF50P22PX8207YjNP80U9BD0P3Rh^820=kNgP0308R8R00i>CT0>CTi0080<C4a0P13@d<206IVIP80
Lg=c101eMGD2079bLP80JVYZ0P1RHV8206e]K@80J6QX0P1QHF4204i>CP80ATI600<0?3`l04I6AP16
ATH00P1@D502061PH080EEEE0P0e=CD20410@080F5QH0P1QHF42061PH080RXZ:0P1hN7P206e]K@80
EEEE0P1GEeL209bLW0030<?3``2GUiL0UiNG00H0QHF51029RHT208^;R`80QHF50P1nOWh208F5Q@80
O7al0P21PH4208F5Q@80SHf=0P2;Rh/00`29RHT0Rh^;08^;R`0408F5Q@80PX:20P21PH4208V9R@80
Rh^;0P1nOWh608F5Q@80RHV90P2;Rh/408F5Q@0307inOP25QHD0QHF500H0QHF50P1nOWh408F5Q@80
RHV90P2@T90408V9R@80PH612@25QHD208V9R@80Rh^;2025QHDE0?ooo`004`3ooolf08F5Q@80OWin
0P25QHD407inOP80QHF50P1nOWh208F5Q@80PX:20P1jNWX209BDU080h^;R0P3Ng]h00`28R8P0>CTi
03Ti>@02034a<@80@d=30P1VIVH207=cL`@0MGEe0P1bLW8206YZJP80HV9R0P1]KFd206QXJ080HF5Q
0P1>CTh204I6AP0303`l?016ATH0ATI60080D51@0P1PH60205EEE@80=CDe0P10@40205QHF080HF5Q
0P1PH60208Z:RP80N7Qh0P1]KFd205EEE@80EeMG0P2LW9`00`33`l<0UiNG09NGU`0608F5Q@@0RHV9
0P2;Rh/208F5Q@80OWin0P25QHD207alO080PH610P25QHD208f=S@80Rh^;00<0RHV908^;R`2;Rh/0
1025QHD208:2PP80PH610P29RHT208^;R`80OWin1P25QHD208V9R@80Rh^;1025QHD00`1nOWh0QHF5
08F5Q@0608F5Q@80OWin1025QHD208V9R@80T92@1029RHT20861P@T0QHF50P29RHT208^;R`P0QHF5
5@3oool001<0oooo9@25QHD208V9R@80Rh^;5`25QHD208:2PP80QHF50P2?Shl208F5Q@80PX:20P2;
Rh/208F5Q@030<k>cP3Shn<0hn?S0080g=cL0P1hN7P203lo?`80?Shn0P1ADE4205IFEP80JFUY0P20
P80207EeM@80O7al0P20P80208J6QP80PX:20P1mOGd00`1dM7@0G5aL05aLG002051@D080HF5Q0P2<
S8`208f=S@80OGem0P25QHD208n?S`80HV9R0P1<C4`205ADE080RXZ:0P3Bd]820<W9b@80U9BD00<0
Rh^;08F5Q@25QHD00P25QHD208V9R@80Rh^;0P25QHD207inOP@0QHF50P29RHT208^;R`80RHV91025
QHD207inOP80QHF500<0O7al0861P@21PH401025QHD208V9R@80QHF50P1nOWh208F5Q@80RHV90P2;
Rh/208V9R@80T92@0P29RHT4092@T080Rh^;1`25QHD208V9R@80Rh^;1025QHD208:2PP80RHV90P25
QHD208f=S@80Rh^;2@25QHD207inOPX0QHF55@3oool001<0oooo9@25QHD208V9R@80Rh^;5`25QHD2
08:2PP80QHF50P2?Shl208F5Q@80PX:20P2;Rh/208F5Q@030<k>cP3Shn<0hn?S0080g=cL0P1hN7P2
03lo?`80?Shn0P1ADE4205IFEP80JFUY0P20P80207EeM@80O7al0P20P80208J6QP80PX:20P1mOGd0
0`1dM7@0G5aL05aLG002051@D080HF5Q0P2<S8`208f=S@80OGem0P25QHD208n?S`80HV9R0P1<C4`2
05ADE080RXZ:0P3Bd]820<W9b@80U9BD00<0Rh^;08F5Q@25QHD00P25QHD208V9R@80Rh^;0P25QHD2
07inOP@0QHF50P29RHT208^;R`80RHV91025QHD207inOP80QHF500<0O7al0861P@21PH401025QHD2
08V9R@80QHF50P1nOWh208F5Q@80RHV90P2;Rh/208V9R@80T92@0P29RHT4092@T080Rh^;1`25QHD2
08V9R@80Rh^;1025QHD208:2PP80RHV90P25QHD208f=S@80Rh^;2@25QHD207inOPX0QHF55@3oool0
01<0oooo8`25QHD208:2PP80NWYj6@25QHD208V9R@80OWin1025QHD207inOP@0QHF500<0RHV908^;
R`2;Rh/00P29RHT40<k>cP80Ph>30P1FEUH205UIF@80D51@0P1<C4`2065QH@80JVYZ0P1aLG4207Yj
NP80Shn?0P2NWYh00`2`/;00XJ6Q0:6QX@0209ZJVP80QHF50P1gMgL208n?S`80IFEU0P17AdL2055A
D@80Ogmo0P2WYjL20:BTY080T92@0P22PX8208V9R@80PX:200<0PH6108F5Q@25QHD00P25QHD207in
OPH0QHF50P22PX820861P@80OWin0P22PX820861P@@0QHF50P22PX820861P@0308V9R@25QHD0QHF5
00P0QHF50P22PX820861P@80OWin0P25QHD807inOP80O7al0P21PH4308V9R@80PH610P25QHD207in
OP@0QHF50P22PX8207YjNP80OWin0P25QHD207inOP80PX:20P21PH4C08F5QAD0oooo000C0?ooob<0
QHF50P22PX8207YjNQT0QHF50P29RHT207inOP@0QHF50P1nOWh408F5Q@0308V9R@2;Rh/0Rh^;0080
RHV9103>c/h208>3P`80EUIF0P1IFET2051@D080C4a<0P1QHF4206YZJP80LG5a0P1jNWX208n?S`80
WYjN00<0/;2`0:6QX@2QXJ400P2JVYX208F5Q@80MgMg0P2?Shl206EUI@80AdM70P1ADE4207moO`80
YjNW0P2TY:@2092@T080PX:20P29RHT208:2PP030861P@25QHD0QHF50080QHF50P1nOWh608F5Q@80
PX:20P21PH4207inOP80PX:20P21PH4408F5Q@80PX:20P21PH400`29RHT0QHF508F5Q@0808F5Q@80
PX:20P21PH4207inOP80QHF5201nOWh207alO080PH610`29RHT20861P@80QHF50P1nOWh408F5Q@80
PX:20P1jNWX207inOP80QHF50P1nOWh208:2PP80PH614`25QHDE0?ooo`004`3ooolS08F5Q@@0RHV9
0P2;Rh/O08F5Q@80PX:20P21PH4208F5Q@0308:2PP29RHT0RHV90080N7Qh0P21PH4208F5Q@80_Kfm
0P2o_kl20:NWY`80^KVi0P2RXZ8208n?S`80RXZ:0P22PX8208f=S@80L71`0P1EEED00`1ADE40HF5Q
065QH@02075aL@80JFUY0P1[Jf/206m_K`80VYZJ0P2i^KT20;:b/P80Y:BT0P2@T90408F5Q@80PX:2
0P29RHT208n?S`0308V9R@2@T900T92@0080T92@0P2;Rh/608F5Q@80RHV90P22PX8207inOPP0QHF5
0P29RHT208F5Q@0308:2PP21PH40PH6100@0RHV90P21PH4208F5Q@@0RHV90P2;Rh/:08F5Q@80RHV9
0P25QHD00`1nOWh0SHf=08f=S@0208^;R`80RHV90P2;Rh/408F5Q@80RHV92025QHD208f=S@80Rh^;
2`25QHD208V9R@80Rh^;1025QHDE0?ooo`004`3ooolS08F5Q@@0RHV90P2;Rh/O08F5Q@80PX:20P21
PH4208F5Q@0308:2PP29RHT0RHV90080N7Qh0P21PH4208F5Q@80_Kfm0P2o_kl20:NWY`80^KVi0P2R
XZ8208n?S`80RXZ:0P22PX8208f=S@80L71`0P1EEED00`1ADE40HF5Q065QH@02075aL@80JFUY0P1[
Jf/206m_K`80VYZJ0P2i^KT20;:b/P80Y:BT0P2@T90408F5Q@80PX:20P29RHT208n?S`0308V9R@2@
T900T92@0080T92@0P2;Rh/608F5Q@80RHV90P22PX8207inOPP0QHF50P29RHT208F5Q@0308:2PP21
PH40PH6100@0RHV90P21PH4208F5Q@@0RHV90P2;Rh/:08F5Q@80RHV90P25QHD00`1nOWh0SHf=08f=
S@0208^;R`80RHV90P2;Rh/408F5Q@80RHV92025QHD208f=S@80Rh^;2`25QHD208V9R@80Rh^;1025
QHDE0?ooo`004`3ooolU08F5Q@80OWin0P22PX820861PA<0QHF51029RHT20861P@@0QHF50P29RHT2
08:2PP80PH6100<0OWin08V9R@29RHT00P29RHT608F5Q@@0RHV90P2=SHd209JFUP80T92@0P2GUiL2
08Z:RP80TI6A0P2PX:030:NWY`80WIfM0P2TY:@20:f][@80YjNW0P2RXZ82092@T080RHV90P25QHD2
08V9R@80T92@0P2;Rh/208F5Q@80OWin0P22PX8208^;R`D0OWin0P22PX820861P@80RHV90P2;Rh/2
08F5Q@80SHf=0P2?Shl408F5Q@80RHV90P2;Rh/208V9R@80Rh^;00<0SHf=08^;R`2;Rh/00P1lO7`4
08F5Q@80PX:20P21PH4207inOQ40QHF50P1lO7`20861P@80OWin0P29RHT208^;R`H0QHF50P29RHT2
08^;R`80QHF50P1nOWh=08F5Q@80OWin1P25QHDE0?ooo`004`3ooolU08F5Q@80OWin0P22PX820861
PA<0QHF51029RHT20861P@@0QHF50P29RHT208:2PP80PH6100<0OWin08V9R@29RHT00P29RHT608F5
Q@@0RHV90P2=SHd209JFUP80T92@0P2GUiL208Z:RP80TI6A0P2PX:030:NWY`80WIfM0P2TY:@20:f]
[@80YjNW0P2RXZ82092@T080RHV90P25QHD208V9R@80T92@0P2;Rh/208F5Q@80OWin0P22PX8208^;
R`D0OWin0P22PX820861P@80RHV90P2;Rh/208F5Q@80SHf=0P2?Shl408F5Q@80RHV90P2;Rh/208V9
R@80Rh^;00<0SHf=08^;R`2;Rh/00P1lO7`408F5Q@80PX:20P21PH4207inOQ40QHF50P1lO7`20861
P@80OWin0P29RHT208^;R`H0QHF50P29RHT208^;R`80QHF50P1nOWh=08F5Q@80OWin1P25QHDE0?oo
o`004`3ooolW08F5Q@80RHV95@25QHD207inOP80RHV91P25QHD208:2PP@0QHF500<0PX:208F5Q@25
QHD00P2;Rh/408F5Q@80PX:20P21PH4208:2PP80NWYj0P25QHD408V9R@80PH610P25QHD708V9R@80
PX:20P2;Rh/208F5Q@80PX:20P21PH4408F5Q@@0OWin0P25QHD208V9R@80Rh^;0P22PX8208^;R`<0
QHF50P22PX8208V9R@80Rh^;0P22PX82092@T080Rh^;0P1nOWh608F5Q@80OWin0P25QHD207inOP80
QHF500<0PX:208V9R@29RHT00P22PX820861P@80PX:24025QHD208V9R@80Rh^;0`25QHD208V9R@@0
QHF50P22PX8208^;R`@0QHF50P22PX8207YjNP80RHV90P2@T90208^;R`d0QHF50P29RHT208^;R`80
PX:20P21PH4E0?ooo`004`3ooolW08F5Q@80RHV95@25QHD207inOP80RHV91P25QHD208:2PP@0QHF5
00<0PX:208F5Q@25QHD00P2;Rh/408F5Q@80PX:20P21PH4208:2PP80NWYj0P25QHD408V9R@80PH61
0P25QHD708V9R@80PX:20P2;Rh/208F5Q@80PX:20P21PH4408F5Q@@0OWin0P25QHD208V9R@80Rh^;
0P22PX8208^;R`<0QHF50P22PX8208V9R@80Rh^;0P22PX82092@T080Rh^;0P1nOWh608F5Q@80OWin
0P25QHD207inOP80QHF500<0PX:208V9R@29RHT00P22PX820861P@80PX:24025QHD208V9R@80Rh^;
0`25QHD208V9R@@0QHF50P22PX8208^;R`@0QHF50P22PX8207YjNP80RHV90P2@T90208^;R`d0QHF5
0P29RHT208^;R`80PX:20P21PH4E0?ooo`004`3ooolY08F5Q@80RHV90P2;Rh/K08F5Q@80RHV90P25
QHD208V9R@0309BDU025QHD0QHF500@0QHF50P22PX8408F5Q@80SHf=0P2;Rh/208F5Q@80OWin0P2=
SHd208^;R`80QHF50P29RHT208^;R`<0QHF50P1lO7`20861P@80QHF50P29RHT608F5Q@80PX:20P21
PH4208V9R@@0QHF50P22PX82092@T00308^;R`25QHD0QHF50080RHV90P1lO7`20861P@80OWin0P1l
O7`20861P@80RHV90P2;Rh/608F5Q@80RHV90P2;Rh/208F5Q@0307inOP29RHT0RHV90080RHV90P25
QHD208V9R@@0QHF51029RHT20861P@H0QHF50P22PX8208^;R`80QHF500<0RHV908^;R`2;Rh/00P25
QHD208:2PP80NWYj1P25QHD208V9R@80QHF50P1lO7`207inOP80Rh^;3@25QHD207inOP80QHF50P2=
SHd208^;RaD0oooo000C0?ooobT0QHF50P29RHT208^;Ra/0QHF50P29RHT208F5Q@80RHV900<0U9BD
08F5Q@25QHD01025QHD208:2PP@0QHF50P2=SHd208^;R`80QHF50P1nOWh208f=S@80Rh^;0P25QHD2
08V9R@80Rh^;0`25QHD207alO080PH610P25QHD208V9R@H0QHF50P22PX820861P@80RHV91025QHD2
08:2PP80T92@00<0Rh^;08F5Q@25QHD00P29RHT207alO080PH610P1nOWh207alO080PH610P29RHT2
08^;R`H0QHF50P29RHT208^;R`80QHF500<0OWin08V9R@29RHT00P29RHT208F5Q@80RHV91025QHD4
08V9R@80PH611P25QHD208:2PP80Rh^;0P25QHD00`29RHT0Rh^;08^;R`0208F5Q@80PX:20P1jNWX6
08F5Q@80RHV90P25QHD207alO080OWin0P2;Rh/=08F5Q@80OWin0P25QHD208f=S@80Rh^;5@3oool0
01<0oooo8@25QHD208V9R@80Rh^;0P25QHD208:2PP80NWYj0P25QHD208:2PP030861P@25QHD0QHF5
0180QHF50P22PX8208F5Q@80Rh^;0P25QHD207inOP0307alO021PH40PH6100@0QHF50P29RHT208:2
PP80QHF50P22PX820861P@@0QHF50P22PX8208^;R`80QHF50P1nOWh208V9R@0308^;R`22PX80PX:2
00@0QHF50P22PX820861P@H0QHF50P29RHT208F5Q@80OWin1025QHD207inOP80PX:200<0Rh^;08F5
Q@25QHD00P22PX8208F5Q@80RHV90P2;Rh/208V9R@80QHF50P1lO7`208F5Q@80T92@0P2;Rh/208F5
Q@80O7al0P25QHD208^;R`D0QHF50P29RHT208^;R`@0QHF50P22PX8208n?S`@0QHF50P29RHT208^;
R`80OWin0P29RHT208^;R`0307inOP29RHT0RHV90080T92@0P2?Shl208F5Q@80RHV90P2;Rh/408F5
Q@80PX:20P25QHD207inOP/0QHF50P29RHT208^;R`@0QHF50P1nOWh208F5QAD0oooo000C0?ooob40
QHF50P1nOWh408F5Q@80RHV90P25QHD208V9R@80Shn?5@25QHD208V9R@80OWin1P25QHD00`29RHT0
QHF508F5Q@0608F5Q@80QXJ60P1jNWX208V9R@80QHF51029RHT207YjNP80RHV90P2;Rh/208F5Q@80
OWin00<0QHF508f=S@2=SHd00P2;Rh/208V9R@80Shn?2P25QHD208:2PP80PH610P29RHT208^;R`80
QHF50P1nOWh308F5Q@80RHV90P25QHD207inOPH0QHF50P29RHT207inOP80O7al0P21PH4208F5Q@80
RHV90P1nOWh308F5Q@80PX:20P25QHD208:2PP80QHF50P2;Rh/208F5Q@80PX:20P2;Rh/208F5Q@80
PX:20P1jNWX408F5Q@80OWin0`25QHD407inOP@0QHF50P1nOWh208F5Q@80PX:20P21PH4208V9R@d0
QHF50P22PX8207inOP80Rh^;2025QHDE0?ooo`004`3ooolQ08F5Q@80OWin1025QHD208V9R@80QHF5
0P29RHT208n?SaD0QHF50P29RHT207inOPH0QHF500<0RHV908F5Q@25QHD01P25QHD208J6QP80NWYj
0P29RHT208F5Q@@0RHV90P1jNWX208V9R@80Rh^;0P25QHD207inOP0308F5Q@2=SHd0SHf=0080Rh^;
0P29RHT208n?S`X0QHF50P22PX820861P@80RHV90P2;Rh/208F5Q@80OWin0`25QHD208V9R@80QHF5
0P1nOWh608F5Q@80RHV90P1nOWh207alO080PH610P25QHD208V9R@80OWin0`25QHD208:2PP80QHF5
0P22PX8208F5Q@80Rh^;0P25QHD208:2PP80Rh^;0P25QHD208:2PP80NWYj1025QHD207inOP<0QHF5
101nOWh408F5Q@80OWin0P25QHD208:2PP80PH610P29RHT=08F5Q@80PX:20P1nOWh208^;R`P0QHF5
5@3oool001<0oooo9`25QHD208V9R@80Rh^;0P1nOWhE08F5Q@80PX:20P21PH4A08F5Q@80QXJ60P1n
OWh20861P@80QHF50P1nOWh208V9R@80PX:20P1nOWh2092@T080Rh^;0P25QHD00`29RHT0PX:208:2
PP020861P@80OWin1P25QHD208V9R@80Rh^;1022PX820861P@80OWin1029RHT20861P@0308V9R@2;
Rh/0Rh^;0080RHV90P2;Rh/208F5Q@80RHV90P2;Rh/208V9R@80Rh^;0P25QHD208V9R@@0QHF50P29
RHT208^;R`<0QHF50P29RHT207inOP80QXJ60P1jNWX208V9R@80Rh^;0P1nOWh208F5Q@80RHV90P2?
Shl408F5Q@80RHV90P2;Rh/208V9R@0308^;R`25QHD0QHF500@0RHV90P21PH4408F5Q@80RHV90P25
QHD208V9R@80Rh^;0P25QHD208V9R@80Rh^;1@25QHD208V9R@80OWin1P25QHD208:2PP80OWin5@3o
ool001<0oooo9`25QHD208V9R@80Rh^;0P1nOWhE08F5Q@80PX:20P21PH4A08F5Q@80QXJ60P1nOWh2
0861P@80QHF50P1nOWh208V9R@80PX:20P1nOWh2092@T080Rh^;0P25QHD00`29RHT0PX:208:2PP02
0861P@80OWin1P25QHD208V9R@80Rh^;1022PX820861P@80OWin1029RHT20861P@0308V9R@2;Rh/0
Rh^;0080RHV90P2;Rh/208F5Q@80RHV90P2;Rh/208V9R@80Rh^;0P25QHD208V9R@@0QHF50P29RHT2
08^;R`<0QHF50P29RHT207inOP80QXJ60P1jNWX208V9R@80Rh^;0P1nOWh208F5Q@80RHV90P2?Shl4
08F5Q@80RHV90P2;Rh/208V9R@0308^;R`25QHD0QHF500@0RHV90P21PH4408F5Q@80RHV90P25QHD2
08V9R@80Rh^;0P25QHD208V9R@80Rh^;1@25QHD208V9R@80OWin1P25QHD208:2PP80OWin5@3oool0
01<0oooo9`25QHD207inOP80QHF50P29RHT208^;Ra<0QHF51029RHT208^;R`80QHF50P22PX820861
P@0308:2PP21PH40PH6100H0QHF51P29RHT208^;R`@0QHF50P29RHT407inOP80QHF50P22PX800`1n
OWh0Shn?08n?S`0:08F5Q@80OWin0P25QHD408V9R@80QHF50P22PX8207YjNP80SHf=0P2;Rh/00`22
PX80Rh^;08^;R`0207inOP80QHF50P22PX8207inOP80RHV90P1nOWh208^;R`@0QHF50P22PX820861
P@80OWin2@25QHD408V9R@80PX:20P1nOWh20861P@80QHF50P1nOWh208:2PP80PH610P25QHD207in
OP80QHF50P22PX800`2;Rh/0QHF508F5Q@0207inOP80RHV91P25QHD208V9R@80Rh^;0P1nOWh408F5
Q@80OWin3@25QHD208:2PP80PH610P2=SHd208n?SaD0oooo000C0?ooobL0QHF50P1nOWh208F5Q@80
RHV90P2;Rh/C08F5Q@@0RHV90P2;Rh/208F5Q@80PX:20P21PH400`22PX80PH610861P@0608F5Q@H0
RHV90P2;Rh/408F5Q@80RHV9101nOWh208F5Q@80PX:200<0OWin08n?S`2?Shl02P25QHD207inOP80
QHF51029RHT208F5Q@80PX:20P1jNWX208f=S@80Rh^;00<0PX:208^;R`2;Rh/00P1nOWh208F5Q@80
PX:20P1nOWh208V9R@80OWin0P2;Rh/408F5Q@80PX:20P21PH4207inOPT0QHF51029RHT208:2PP80
OWin0P21PH4208F5Q@80OWin0P22PX820861P@80QHF50P1nOWh208F5Q@80PX:200<0Rh^;08F5Q@25
QHD00P1nOWh208V9R@H0QHF50P29RHT208^;R`80OWin1025QHD207inOPd0QHF50P22PX820861P@80
SHf=0P2?ShlE0?ooo`004`3oool[08F5Q@80OWin0P22PX800`21PH40QHF508F5Q@0<08F5Q@80PX:2
0P25QHD208^;R`80OWin0P22PX820861P@80RHV90`22PX820861P@@0QHF50P29RHT2092@T080Rh^;
0P1nOWh208F5Q@80PX:20P21PH4608F5Q@80PX:20P25QHD00`1nOWh0RHV908V9R@0208^;R`80PX:2
0P25QHD208^;R`P0QHF50P29RHT208^;R`80SHf=0P2;Rh/207alO0<0QHF50P22PX820861P@80PX:2
0P25QHD207inOP80SHf=1025QHD208:2PP80PH611P29RHT208F5Q@80Rh^;00<0PX:20861P@21PH40
0P22PX8408F5Q@80SHf=0P2?Shl408F5Q@80PX:22P25QHD207inOPd0QHF50P1nOWh208F5Q@80PX:2
0P21PH4A08F5Q@80RHV90P25QHD207inOP80QHF55@3oool001<0oooo:`25QHD207inOP80PX:200<0
PH6108F5Q@25QHD03025QHD208:2PP80QHF50P2;Rh/207inOP80PX:20P21PH4208V9R@<0PX:20P21
PH4408F5Q@80RHV90P2@T90208^;R`80OWin0P25QHD208:2PP80PH611P25QHD208:2PP80QHF500<0
OWin08V9R@29RHT00P2;Rh/208:2PP80QHF50P2;Rh/808F5Q@80RHV90P2;Rh/208f=S@80Rh^;0P1l
O7`308F5Q@80PX:20P21PH4208:2PP80QHF50P1nOWh208f=S@@0QHF50P22PX820861P@H0RHV90P25
QHD208^;R`0308:2PP21PH40PH610080PX:21025QHD208f=S@80Shn?1025QHD208:2PPX0QHF50P1n
OWh=08F5Q@80OWin0P25QHD208:2PP80PH614@25QHD208V9R@80QHF50P1nOWh208F5QAD0oooo000C
0?ooobd0QHF50P29RHT?08F5Q@80RHV90P1nOWh408F5Q@80SHf=0P2;Rh/208V9R@80Shn?00<0QXJ6
08F5Q@25QHD00P2@T90208^;R`80O7al0P1nOWh208^;R`@0QHF50P29RHT808F5Q@80SHf=0P2@T900
0`2;Rh/0OWin07inOP0208F5Q@80RHV90P22PX8208^;R`P0QHF50P1nOWh208V9R@@0QHF50P29RHT2
07inOP0308F5Q@2=SHd0SHf=0080T92@0P2DU9@2092@T080Rh^;0P1nOWh408F5Q@80QXJ60P21PH42
08V9R@80QHF50P29RHT207inOP80RHV900<0U9BD092@T02@T9000P2DU9@408F5Q@80OWin1P25QHD2
08f=S@80T92@0P2;Rh/608F5Q@80PX:200<0PH6108F5Q@25QHD02025QHD208V9R@80Rh^;0P25QHD2
08V9R@80QHF50P29RHT208^;R`H0QHF500<0RHV908^;R`2;Rh/00P29RHT208^;R`80QHF50P29RHT2
08^;R`80QHF55@3oool001<0oooo;@25QHD208V9R@l0QHF50P29RHT207inOP@0QHF50P2=SHd208^;
R`80RHV90P2?Shl00`26QXH0QHF508F5Q@02092@T080Rh^;0P1lO7`207inOP80Rh^;1025QHD208V9
R@P0QHF50P2=SHd2092@T00308^;R`1nOWh0OWin0080QHF50P29RHT208:2PP80Rh^;2025QHD207in
OP80RHV91025QHD208V9R@80OWin00<0QHF508f=S@2=SHd00P2@T90209BDU080T92@0P2;Rh/207in
OP@0QHF50P26QXH20861P@80RHV90P25QHD208V9R@80OWin0P29RHT00`2DU9@0T92@092@T00209BD
U0@0QHF50P1nOWh608F5Q@80SHf=0P2@T90208^;R`H0QHF50P22PX800`21PH40QHF508F5Q@0808F5
Q@80RHV90P2;Rh/208F5Q@80RHV90P25QHD208V9R@80Rh^;1P25QHD00`29RHT0Rh^;08^;R`0208V9
R@80Rh^;0P25QHD208V9R@80Rh^;0P25QHDE0?ooo`004`3ooolS08F5Q@80RHV90P2;Rh/208V9R@80
Rh^;0P25QHD208:2PP030861P@22PX80PX:20080PH612025QHD208V9R@80Rh^;1P25QHD207inOP80
QHF50P1lO7`20861P@0308J6QP1jNWX0NWYj0080O7al0P21PH4208V9R@80OWin2025QHD208:2PP80
PH611025QHD407inOP0308F5Q@29RHT0RHV90080Rh^;0P25QHD207inOP80QHF51029RHT20861P@80
RHV90P2@T90;08F5Q@P0OWin0P25QHD208V9R@80Rh^;0P25QHD208V9R@80QHF50P1nOWh208:2PP80
PH610P25QHD707inOP80RHV90P2;Rh/208V9R@80Rh^;0P25QHD208:2PP80NWYj0P22PX8208^;R`@0
QHF50P29RHT208n?S`/0QHF50P1nOWh208:2PP80PH610P22PX820861P@80OWin2025QHD00`1nOWh0
QHF508F5Q@0207inOP@0QHF50P1nOWh408F5QAD0oooo000C0?ooob<0QHF50P29RHT208^;R`80RHV9
0P2;Rh/208F5Q@80PX:200<0PH6108:2PP22PX800P21PH4808F5Q@80RHV90P2;Rh/608F5Q@80OWin
0P25QHD207alO080PH6100<0QXJ607YjNP1jNWX00P1lO7`20861P@80RHV90P1nOWh808F5Q@80PX:2
0P21PH4408F5Q@@0OWin00<0QHF508V9R@29RHT00P2;Rh/208F5Q@80OWin0P25QHD408V9R@80PH61
0P29RHT2092@T0/0QHF5201nOWh208F5Q@80RHV90P2;Rh/208F5Q@80RHV90P25QHD207inOP80PX:2
0P21PH4208F5Q@L0OWin0P29RHT208^;R`80RHV90P2;Rh/208F5Q@80PX:20P1jNWX208:2PP80Rh^;
1025QHD208V9R@80Shn?2`25QHD207inOP80PX:20P21PH4208:2PP80PH610P1nOWh808F5Q@0307in
OP25QHD0QHF50080OWin1025QHD207inOP@0QHF55@3oool001<0oooo8`25QHD208:2PP80Rh^;0P1n
OWh208V9R@80Rh^;0P29RHT00`25QHD0RHV908V9R@0:08F5Q@80OWin2025QHD208:2PP80PH610P29
RHT208F5Q@0308V9R@25QHD0QHF500@0RHV90P2;Rh/208V9R@80Rh^;1P25QHD208V9R@X0QHF50`29
RHT208^;R`@0QHF50P22PX8207YjNPH0RHV95@25QHD408V9R@80T92@0P2;Rh/608F5Q@80RHV92`25
QHD208:2PP80T92@0P29RHT208^;R`80QHF50P29RHT208F5Q@80OWin1P25QHD207inOP/0QHF50P29
RHT208^;R`80QXJ60P21PH4208J6QP80PH610P25QHD208V9R@80Rh^;0P25QHD308V9R@80PH613025
QHDE0?ooo`004`3ooolS08F5Q@80PX:20P2;Rh/207inOP80RHV90P2;Rh/208V9R@0308F5Q@29RHT0
RHV900X0QHF50P1nOWh808F5Q@80PX:20P21PH4208V9R@80QHF500<0RHV908F5Q@25QHD01029RHT2
08^;R`80RHV90P2;Rh/608F5Q@80RHV92P25QHD308V9R@80Rh^;1025QHD208:2PP80NWYj1P29RHTE
08F5Q@@0RHV90P2@T90208^;R`H0QHF50P29RHT;08F5Q@80PX:20P2@T90208V9R@80Rh^;0P25QHD2
08V9R@80QHF50P1nOWh608F5Q@80OWin2`25QHD208V9R@80Rh^;0P26QXH20861P@80QXJ60P21PH42
08F5Q@80RHV90P2;Rh/208F5Q@<0RHV90P21PH4<08F5QAD0oooo003o0?ooob40oooo003o0?ooob40
oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40
oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo002H0?ooo`900000QP3oool009X0
oooo00=000000?ooo`3oool0P`3oool007X0oooo1D0000020?ooo`03@000003oool0oooo0080oooo
00=000000?ooo`3oool01@3oool3@0000080oooo0T0000030?ooo`=000001@3oool00d000000oooo
0?ooo`1m0?ooo`00O03oool01d000000oooo0?ooo`3ooom000000?oood0000000P3oool00d000000
oooo@00000050?ooo`06@000003oool0oooo@000003ooom00000103oool014000000oooo0?oood00
00250?ooo`00O03oool01d000000oooo0?ooo`3ooom000000?oood0000000P3oool00d000000oooo
@00000050?ooo`05@000003oool0oooo@000003oool00d0000020?ooo`04@000003oool0oooo@000
08D0oooo001l0?ooo`03@000003oool0oooo0080oooo00M000000?ooo`3oool0oooo@000003ooom0
000000H0oooo0d000000103ooom00000@000040000030?ooo`=00000Q@3oool007`0oooo00M00000
0?ooo`3oool0oooo@000003ooom000000080oooo00=000000?oood000000203oool00d000000oooo
0?ooo`2=0?ooo`00N`3oool2@00000@0oooo00=000000?ooo`3oool00P3oool00d000000oooo0?oo
o`060?ooo`900000S`3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo
8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo
8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.0250052, -0.0250052, 
  0.00365857, 0.00365857}, {{6.8125, 280.125}, {280.125, 
  6.8125}} -> {-10.161, -6.11446, 0.516914, 0.516914}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0238095 0.952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0238095 0.97619 0.97619 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00751202 0.0192308 0.00751202 [
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(240) show
81.000000 12.812500 moveto
(deg) show
99.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(.) show
105.000000 12.812500 moveto
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
128 string
128 128 8 [128 0 0 128 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
B3B3B1B9BCB3B5B2AEBCB1BB9F9F9F9EA6A0A0A0A096B6AC
6397A2999B939B9C929A9B9A9D95939B999FA09B9B9B9B9A
9D909B9B99A1A1A1A1A1A1A29EA39B9A9CA39B9B9B9B9B9B
9B9B9A9B9C999B9B9A9B9B94A5B8AB7195939B9C95959399
9999999997A0A09B9CA7A0A5A5A79EA7A19A9B9291959595
88A9AD8397ABB3BC
B3B3B2B7B8B4B8B6AFBAB5BFA9A0A09EA4A0A0A0A096ABBD
6D98A29A9C94979A92989B9B9E9995989A9E9E9B9B999698
9F92989B989D9E9F9E9D9EA19BA19E9A9AA09B9C9C9B9B9B
9B9B9B9B9C9999989B9B9B939DB4BA7287969B9C95959396
979A9B9B989F9F9C9AA49EA2A2A5A0A5A19A9D979495969A
96A7A88791ABB3B9
B3B2B3B5B2B1B6B9B4B1B9B8C0ABA0A0A09F9FA09F9E98C5
7F819F9B9997939698979A9B9A9B9C9295A19D9B9A9B9392
95968F95999A9A9E9F9B98A09B98A09C9E9F9F9C9F9E9C9B
9B9B9B9B9B9C9C969B9C9B9C939CC2AB7885979996989795
939997989AA19CA19C9F9FA1A3A1A7A0A29A9A9A9C989995
A7BA9B9389A7B5B6
B3B3B3B3B7B4B7B6B3B7B3B6B8C0ABAAA29F9D9D9E9A97A0
D276919B9D9991929797979B9B9B9C968F9C9E9C9C979893
9493928E91979B999E9B9B9B9B9A9B9CA2A1A2A1A0A49F9E
9F9E9B9B9C9C9B9B9C9C9B9B9C9894AECF798799969C9D99
989E99969A9F9D9F9DA0A0A1A4A5A4A29E9D9A9E9BA39FA4
A0A6AA968CA6ACB6
B4B4B3B2BAB4B7BAAFB9BCB7B6B5B6BAB29FA29E9C9D9C95
B6AE879A9C9D9595969792979B9B9E99969B9A989A949E9A
959899938F9298989596969B9B9B9999A2A09D9CA8A2A09F
9FA49C9C9E9E9C9C9E9E9D9C9D9B9994AEBC73949C9D9D9B
9E9B9B9E9CA19CA29C9F9FA6A4A7A0A69F9E99A69DB5AAA3
BA91AB9887AFB4AF
B3B3B6B2B3B8B5B6B3B5B7B7B8B4BCB4BFB1A3A39DA19B99
A7C3979C9DA39897929B98959B9997989996979695949B9B
9B9B9D9C94928F99939393979B9B9B9B98A19D9AA2A49CA2
9DA2A19CA0A19E9C9E9F9F9A9F9C9D9994C09E8A939D9FA1
9D9C9C9FA1A0A0A2A0A09EA3A4A4A69F9C9D939DB2AEA2A3
AD99B3968FADB9B6
B3B2B9B4B8B2B6B2BAB2B7B5B2B9B8B5BBBFB7AAA4A3A3A2
9BABB99D9EA29E9E98949795969A948D93938E9394909B9C
9D9E9D9EA299958F988F99909696979B9B9A9B9FA0999D9D
9D9C9E9CA19F9E9F9A9E9B9B9C999D9B9993BDAB96989D9D
9E9A9F9DA1A1A0A29FA4A1A1A4A3A09A8F918EA4A7BB96A5
9A98AD8EA0B5B5B9
B3B1B6B7BAB0BCB2B7B2B9AFB6B9B4B7B9B9BBBDADA8A9A7
A8A0B7B08F8BA09F9A989595949190908C90908E938C9799
9D9F9F9EA39B9E8F9390949093938D939497959B9A979797
989A98999A9B9A9B9A979797979895989A9195B0B2999A9B
9C999D9BA0A29FA2A0A79EA2A0A1908F8A838CA995A5969A
9AA09F87ABB6B0B9
B3B3B6B4B7B5BBB2B9B5B5B5B4B0B7B5B7B9BBB5BBB0B3B1
B2B2ACBDC8859A9B9E97959594978F8B9393959796909098
9A9F9F9EA39FA19792959590979493928E908D8B908B8D8E
8B90898F918C8F8F928E8E909393949298928B91A59E9686
879297969C9E9D9DA2A5A29F928592838A818DA2A08C919C
97A29B90AAB6B3B3
B7B4BAB3B6B9BCB6B4B5B2B8B5B4AFBBB2B5BCB0BCB2BBB5
B2B9B9B5B5CA9E8E8F9F92909792958B8F8E91979A978E94
999DA09F9FA09E9E92949B949897999B96989492938C8F90
8E908C908E8F9291929192909891989899959499889AA99F
8566748E9298989B97827A788678838F908C89979A9B9387
AA9F88A2A7B3B7B6
B5B7B2BBB1B7B5B8B5B7B5B3B5B6B4BAB5B0BCB2BBB3BBB5
B2B9B4B8B1BABC957296908894959792928A8F9496978F92
9B989E9CA1A09D9F989697979D979B9B9D9699959A9A9599
93939298979497949696969B9F929A989C949D999895979C
A2BD5D997E7C84817D7E6F6B6E72829091869F939096988A
A4A88CA2A7B0B1B8
B6B5B1B9B5B6B5B5B3B3BAB4B3B9B8B7B4B3B9B5B8B5BCB6
B7B5B0B8B2B5BFA28183857F87949492958C909293989191
9A9B9A9A9D9E9DA09D9894989B9B9B9B9B9D9B929697989D
999695939698979998929B9B9B9A9A949C9499979B9D959A
959995AEA08E69676A67716E6F7A72888B7AA6888D9B7B99
AB8AB599B4AFB3AF
B6B9B6B4B9B0B9BAB5B7B4B8B5BCB2B9B6B7B5BCB1B7B9B9
BAB3B4B4B1B6BC9DA378817E5D799290968B93948F949291
9B9B9A9B9AA0999E9B9D99979B9B9B9B9B9B9B9D9396949A
979B9695959394979A919B9B9B9B95979C939A939B999799
959288897D7282635E6A6C7076787D7D8681A87F849B809A
A58BB2AEB4AFB7B4
B7B4B7B9B4B1BBB1B8B5BCB0B9B8B8B1B9B9B9B8B4B5B9B8
B8B4B2B5B6B4BDA8AE8F707E66456A928F8F8F8C94949092
9B9B9B9B999E9B9B9B9B9A979797989A989B9B9C9696949A
95929995939696969493989A979B919B9C95959497999292
8E8D82716C696671726E6573757B7B898B879381859488A1
9899B0B0B9ABB7B8
B6B8B6B6B6B0BCB4BCAFBCB2B9B4B9B4B9B6B9B3B2B8B8B4
B9B5B5B2B9B3B7A3B29E6D716354306A84918C8E90939191
989B9B9B99999B9B9B9B9D999897969A94989B9D99979394
97959594949594949394939D959893979D99949594948C91
8686776B6667696F767B726979787D857F8E8F8790899C92
96A2B5B3B2B3B4B9
B4B3B2B8B6AFB8B5B8B0BBB8B3B9B3B6B9B7B2B8B2BAB2B8
B5B4B8B7B7B2BB9EB9A97B6B68533F29638A87918D969092
969B9B9B9D9697989B9A97979A93979597979B9A979C9491
93939397939694909095909A949A979297958D8C89838682
7E62596364756B647183827B737C70827E8881939596AB8C
94B0AEB5B0B4AFBB
B3B3B7B4B4B3B9B2B6B2B7B7BBB2BBB5B4BCB2BBB6B1B9B6
B2B8B0B9B5B6B8ACB49E8E6865534638256389908693938E
989A9797979B9894989C9697989892929297979A98959393
90938D9293958F94888F8E949391928F94948988857C756B
5B5C5752687C7F6679788480887973797E89839488AA969A
A5AEAAACB5B5B0BB
B3AFB7B8B4BBB3B6B5BBB4B2BBB3B8B2B7B8B2BBB8B7B2B9
B8B4B1B5B4B6AFB4A39F7F6D61504B423317588E84908E91
9399969696949C97969A969499959893919395909A979491
9290908C8A91908F8D8E8B90958794888E8D8B837F6F655F
5D526063707478737C73757676847D7B84868B949696A1A3
ABB3ACAEB7B8B4B9
B3B4B2B7B9BDB2B6B7BCB7B2B8B2B7B4B8B7B4B7B6B9B5B3
BCB5B4B4B5B7B3B59CAA746E644F4844302C14568B8A928F
9594969696949B979C969696979496979392959094949392
918F928D8A898F88858F88909089868E8684867863634954
5E5F63717674727683807A7782788587898793959494A8AE
A9ADB5B4B7B9B7B6
B6B2BAB2B9B7BCB6B5B7B8B5B5B4B2B5B7B7BBB8B3B5B7B2
B8B5B7B6B3B3B7B4A2A5776761584B3D30232F118A879491
94949698979894979A969594969595969392948F918E9290
908F8F8B89878888848A90818B7E838381757575564D5C4A
555E6774706F79748585837E878B858C8A93949697A1A3AC
AFB5B4B9B3BBB5B4
B9B9BAB0B8B3B6B9B8B7B6B1B5BCB5B4B5B5B7B9B4B5B9B4
B6B5B9B8B4B6B4B1A097776D5A5951493530332A6A8A9095
9795929C949A9696969597929493929791939390918C8D91
91918C8B88817E838889887F7C7C7C7D776B655A6F565F61
6B6370767170717A757D867E7C89858B93939695A1AAA1B5
B4B6B7B7B5BAB2B9
B9BBB8B4B6B5B2BAB4BBB4B4B9BBB5B8B2BBB4B5B1B9B6B1
B7BBB3B9B3B5B1B2A4827469645850453D3A3A2D29899492
9C949199939595939597949595919095949090958B938A8A
8F8D89887F837A7D8B8C83777A7C6D696162675953686163
646F777870696C83787C8084858683939394939AA5AEAAB3
BBB4B2B9BBB4B5BB
B9B9B9B3B9B6B7B5B9BBB2B9B9B9BCB3B3BCB6B7B3B0BCB4
B5B8B3B8B8B5ADAD9885686656584B4249443A220D8C9292
9A95949791929791919394939194928F9591908C91859089
8B8A88837E737D7D84856F7074726A575B58655E5A585E62
5E6E78767377658574846E8C807E8D949493A09FAEAFADB5
BCB0B9B9B9B2B6B9
B9BCB4BBB1B9B9B7B9B9B5B7B9B9BBB8B2B7B9B5B7B2BBB3
BCB4B4B9BBB7ADAE86846F625E4B454349463B3506959098
939494979492959292908F928F8E8F8E8D918C8F898A8888
8684857A7975717E80726E6D6C5F5B5F53607065605B6467
626B7379797B797E757C7876858E899796979FB4B0ACAFB6
B7B5B9BAB6B8B4B9
B9B9B7BCB4B9B9B3BBB5B9B5B9B9B9B9B7B5B5B7B5B7BBB3
BAB2B7B7B9B6B2A7857A6B625C584A4C4C38342C13968D96
929097938D92918F8F90888C908B8A8A878F888887858A84
83827C7D6F747671696667665E635A5B5A59736F6A645D6C
6A686B73748B8482777C7D787993939E97A8ACACB4ACB2B5
B2B9BBB3B6B7B6B7
B9BBB5B9B7BBB7B3B9BBB5B7B9B9BBB5BBB7B5B9BBB3BBB5
B5B7B4B5B7B9AE9C877B6C605B4F4F474732312C0E969198
8C92939A8F8A918E8A8B8A86898988858A848D8784818383
837E7E76756E7468645B60535D53515359606D75786A6964
61706870708684847B7D8B7C7E93939BA3AAB0ACB5AFB5B2
B9B7BBB8B6B6B4B5
B9B9B9BBB5B7B9B5B7B6BBB5B9B9B7B9B9B9B9B9B9B5BBB5
B2B9B3B4B7BCB0917A78635A5251494E4139353311929093
92958C929589908C87888882848286828383868582807C82
7E7B79766E756D61595B555D5451524D555A6F7170786D6A
615B6779717F87897B81847D869590A4A7B2ABAEAEB5B7B3
BBB5B9B9BBB5B5BB
B9B9B7B7BBB5B3BBB8B4B7B6B9BBB3B9B9B7B7B8B2B9B9B7
B4B9B0BAB4B2B4887C6D6A5B53514E52352C2E3618968892
8B939188918A888A86838484807C7D7B7B8181847E7D7A7A
787A727365666259585A5C5355575455585E687A7A80786A
5C60616A788180878281767B8C9594A9A8A8B4B2B0B3BBB5
B9B9B7B9BBB5B6BB
B7B9B7B5B9B5B2B6B6B9B8B4B9B8B5B7BBB5B8B4B4BBB7B5
B9B9B2BAB2B6A0857C6B5D5659504A4330272C2F19968993
8C8F8F8A87898388857E827F80827A78767A7B807C7C7874
72706D6B6A5A515954575B473E44515D6562676D80788B81
646265746C76888282787871929A9FA4B1A7B3ABBAB2B6B9
B9B9B5B9B9BAB4BB
B7B5B9BBB7B6B7B7B6B5B9B9BCB3B8B3BBB3BBB2B9B7B9B7
B8B6B5B4B3B394846F675F4F514D4F3B353130351F91888B
8D8E898B87858381837E7A7977757973757873777C787474
6E6F6A676B4E5352584D44462D4353586362636C78837987
756A726F7B6E828274727B799596AEA5ABB0AFB1BCB3B2B9
BBB5B6B9B9B5B7B9
B9B9B9B7BBB3B7B6B7B7B9B7B9BCB6B5BBB1B8B3B8B5BBB6
B6B5B9B2B6A4887C6C6259584E4B3E3732323433278A8A8C
8E8D8C878C888B8584857973766D6E716B7076707370746B
68646760664C46584C413D3E483D576D5C695C6375857C85
716E766E7A7B877A7E77788394AAA6A9A8AFB7B4BBB7B3B9
B9BCB4BBB5BBB3B9
B7B7BBB5B7B4B8B4B7B5B9B3B9B9B6B9BAB6B3B6B1B9BBB3
B7B9B2B5B79C86776463565C504B2C353532303E2D8D9490
9D969791928F8E8E8A8C8A817070686A6B6966696F6C696C
65615B5E574A464D4935344440495568675C655C767E8F84
80736E6565878775817C8A8799B9A8A6B4ACB7B9B7BBB5B9
B9B7B9B9B9BBB5B9
B7B5B7BBB6B2BBB3B9BBB7B5B9BCB2BBB5BAB6B8B0B9B9B7
B5B4B5B4A99282736556554C5B4235303B353141458E9BA1
9D9D9B9F99989991908F8D8A8A776E656569686961676966
676056575F4E52483D3438414D445265645E5C606D78898A
8B79716C5F81877B7A898085B3AAA8ADAFB6B3BBB2B7B6B7
B9B5B9B7B9B9BBB8
B7B9B7B3B9B7B8B5B6B9B9B9B9B9B3B9B9B3B9BAB0BBB3B8
B4B3B5BD9F887A6C616252514F35363636354D44739F9DA7
A1A0A19CA19C9F989794908D8A878579676263626A606465
5E5B4F3F5D50574B3326273E654752616864626271758B91
917372676E777A817C937994B0A8A2B3ADBBB5B9B6B8B6B7
B3B7BBB5B9B9B7B9
B7B5BAB4BBB8B4BCB1B7B6B9BBB8B1B9B7B3B9B5B3BBB8B7
B6B3AFB29A837165545357514436363B394658799BA0A8A2
A99EA79CA19F9E9B9F98998F8D898A8483675D5C5D625D60
5D55483F444F4A6F3A3D242C564F4A5B6C5C74666B778293
968E626D70797581888B7AADAA9DADB2B5B6BBB2B9B9B7B9
B7B3B7B9B9BBB5B9
B9BBB5B9B9B6B9BCB6B8B4B9B9B8B4B3BBB7B5B7B5B9B9B9
B9B5B1A09477726558504F4F3C353236512B9AA19C9FA3A6
A4A6A8A2A19CA19C9B9A9997908C8E8A84806F61575D595A
564D4A3C3E7449713F243C3D497957626F5C69706E77788E
9A896D656B71758C8E8485A3A7A9B3B0BBB2BBB3B9B9B5B5
BBB7B5B7B9B9B9B7
B6B6B9B7BCB4B9B6B9B7B7B9BAB4B6B1B9B9B3B6B9B8B5BB
B6B3B19B8D756C604F4C494A31323547386E9DA49CA1A0A4
A1A4A1A1A89E9E9B9B9E9B9394928E8C8A8875805B565952
544A422F396D53616B533140465D6362677361726C717C7D
96966E62746E72838E8D8897ABB1B3B2B9B5B9B5BBB5B3B9
B7B7BBB3B7B9B9B5
B5B2BBB3B9B9BBB2B9B7B5BBB7B5B6B4B9B7B8B4B9BDB2B9
B1B3A79A816C695B544A4A37393743495A9B9BA1A1A19DA4
98A39C98A29A97969799979B908F8E8B8C8A847E7E5A4D53
48493838334E82497C4C654459496F596469616177658772
87A8825F6971797A898B92AAAAAEB5B0B5B9B3B9B9B7B5B9
B7B3BBB7B5B9B5B9
B7B5BBB3B9B9BBB5B5B7B7B7B9B7B5B9B5B7B6B6B7B7BBBA
ADAF9A94736B58554F4D3537312D43589D9D9D9D9EA09A99
9391908F8F918B8B8B928E9490938D8D8A8A87827E83664D
4D433F3537406C75598B596F45505F6F605F6E5971737B7D
888D94796A747872848CA5B2AAB1B5AEBBB7B3BBB2B7BBB3
B9B5B9B9BBB5B9B9
B9B9B9B5B9B9B9B5BBB7B7B5B5B9BBB5BBB6B5B4B7B5B7BC
B3A49F8A7164604B4B483A313D4B3F9E9CA2A09B9A9C9791
8D86838080817D838585858A8B9090918A8A87827D7E7B5C
4441382A3041516F5B587D6F794C536B6C696169647F787E
7E8DA67B78807D758485B7A4B6B1B6B2B7BBB5B9B6B5BBB5
B5B9B7B9B9B9B9BB
B9BBB3B9B9B9B5B9B9B9BBB3B9B9B9B9BBB7B5B3B6BBB5B5
ACA39A7A6D595B51413A39343925999D9C9E9E9B99867574
7A7A7A7777776F676E6A7587848D90938D8C8885817B787A
4D3633262A38497A75528774817C655B6F705E66607C7182
82829E8C817E7A7E8A8EA8ABB4AEB2B8B5B6BAB4B7B9BBB5
B7BBB5B7B9B9B7B9
B9BBB3B9B9B5B7B9B9B9BBB3B9B9B7B6B9BBB6B7B4B8B8B7
A89A93755F5A4E494640353B46519C9C9B9B9D91858B7670
8C7F7A7D84807B6F6D6A5E7085878D90918A8B89817F7A72
79482B2821362A468C64607D71877F7069636E64646D7E6E
858595946F7D76788AA3A4AFB4ACB5B4B9B4B3BBB3B9B7B9
B5B9B9B5B9B9B3B9
B7B9B5B9B5B9B5B7B9B7B9B5B7B9B6B2B7B9B3B9BBB1BBAA
9C927B70534E494E2F36354732A29E9D9B999E9578757463
7B7D746B6A7162646E736A596D888A90938E8C8A84817C7A
757140321B254C317485538C6A7B9781667760675F6D7677
7B80929C7C71757A74AEACB3B2A8B9BCB6B7B5BBB5B9B7B5
B9BBB5B9BBB7B5BB
B7B5BBB5BBB3B9B5B9B5B3BBB5B5B5B7B7B6B2B9BAB2BFA4
99846F5C51484733422F413670A09F9F9B90828053525961
5C585A5E4E45444D3B514A4842688190908E8E8C867F817D
7A6F60211C2834415E7E5C5E7F667DB08A6D686E6364736B
777C949F877C837779AAAEB3B1ADB5B9B9B7B9B7BBB5B9B9
B9B9B9B9B7B9B7B9
B7B7B7B7BBB7B3B9B7B5B5B9B7B5B5B7B9B5B3B9B5B5B9A5
9173644E4F4344433B4038599F9EA29E9BA78F8E755E595B
645F63655E5D545660577173696679908F908A8A8E817F7E
82756B411B162B404965914F7C666E8FAD7875646D676F70
61828D97927A89798DA6B2ACAEB7B0B7B9B5BBB5B9B7B9B9
B7B9B9B9B5BBB3B9
B7B7B5B3B9B9B7B5BBB3BBB3BBB5BBB7B7B5B7B6B2B8B1A1
8767605343453D3E3E43209FA09C9EA19D9F96AE9D919083
8B878296898B868582728A8C8A8E8B90928E8C898C88817F
7E7C745A2F122F3A444D7069526F56838FA96F726B5F6B77
687E7D939D747E699FAEAFAEAAB7B7B7B3B9B9B9BBB5B9B9
B5B7BBB5B9B9B5B9
B7B9B7B5BBB5B9B7BBB5BBB3B9B7B7B9BBB2B8B7B3AFA697
7A5F4B4B46343E3E3D4C4AA19C9FA09C9F9C9CA1A0A5A7A2
9AA89B989BA09497948F95929494919092918D8B8A85867C
7B7876602D2226474F575F6B496A656690A08F7C746C6264
687571939C80825CA8AEAAAFABB9B9BBB3B9B9B7B7B7BBB5
BBB5B9B9BBB5B9B9
B5B3B9B7B7B7B9B5B6B9BBB5BBB5B5B7BBB6B4B5B9BA927F
675C4B4239413A3F4023909F9EA19EA29AA49BA19FA59FA5
9FA69B9B9B9D919393909591939B958E928F8D8E8A848685
79787B684A3118383E564C6E584E686480919388736D6F66
6765738C9E7B8564A8B2A7A4B4B7B9BBB3B9B9B7B7B5B9B7
B9B9B9B7B7B9B9BB
B7B5B9B7B5B5B5BCB4B7B9B9BBB5BBB5BBB7B6B4B1AF9874
6348513940303C4137189F9F9B9FA3A09EA0A0A1A1A1A0A1
A19E999698978D91968F96909D8D9C97978F8D908B878083
7D74756F4E28292C494F585C624C555C6B819A887D6D6860
78657B809783767F9EAEB49DB9B5B9BBB5BBB5B7B9B9BBB3
B9B7BBB7B5B9B9B9
B9BBB5BBB7B5B9B9BBB5B7B9B9B9B9B7B7B9B7B7B7958E6C
595940463B423A36532D9E9C9BA0A1A1A4A0A1A0A1A29F9D
9E929286958D878A918F91939C98949A9A91918C8C85867F
827C70695C3A302F3F48535364514D43687B7F91896E7458
706F7E78998B639B95B2AFB1B5B9B9B9B9B7BBB5B9B9BBB5
B9B3B9B9B7B9B9B9
B7B7B9B9B9B9B9B7B9B9B3B9B9B7BBB7B7B3B9BCB6927164
4B464736353D3F3529739A9C9BA1A1A19FA5A29EA1A1A399
98928B8188878086898D8E9492969B9F969597908D87867F
7F7A766D5B3C13223446495051614D493B78868090727A68
666B7475969B72AB8DACA0B9B9B9B9B9BBB3B9B9B9B9B9BB
B7B5B9BBB3B9B9B9
B7B5B9B9B9B9BBB5B9B7B5B9B9B5B9B9BCB4BBB7B488644F
49383F3E3D3A33310C9A9B9B9BA1A0A4A3A1A29FA098858B
9B93956D6270777378828D909B949B9B9F9299928D8B8881
7F82726963471F1E26394050495E4C573D706F769C7B7064
5D696D739494968EA3999FB9B9B9B9B9BBB5B9B9B9B9B9B9
B9B9B9BBB5B9B9B7
B7B7B7B9B7B7B9BBB5B9B7B9B5B7B9B9B9B9B9BBA6786156
4443343B3D37313E159D9A9E9CA59CA1A69FA1A29DB69C78
9DA19AA07B727C936E76838D9B9B9B9B9A9B99978F8E8786
7D7C787263591717212E3E4845555145303E717F7B856B6B
556867758F88AA76AF8EB9B7B9B9B9B9B9B7B9B9B9B9B7B9
B9B9B9B9B7B7BBB5
B7B7B5BBB7B5B9B7B9BBB5B3BBB5B9B9B6B9BBBBA166563B
43413E3B40302B3D3A9B9B9D9EA7A69FA9A0A29F9EA7A0A0
A2A2A2978D8B8A908E7C7E8E9B9C9C9B9F939599948E8C88
7E76776C655A191C182F3F4A4246524839227F76788E6770
5E616E7482989F8B7EB9BBB3B9B9B9B9BBB5B9B7B9BBB5B9
B9B9B9BBB7B3B9B9
B9B9B9B9B7B9B9B5B9B9B7B3B9B9B6BBB2B7B9BE915E4E4E
3D3E43413D2E2E256D9AA0A09FA4A5A5A6A6A3A099AA9DA5
A8A79F9F928C8C8A8A8785909B9B9F9C9C9F989693928D8D
877B766E6455360A1D2A2A425045484252396F6E80996B72
6363646C839697949BB9BBB5B9B9B9B9B7B7BBB5B9B9B9B9
B9B9B9B9BBB5B9B9
B9B9B9BBB5BBB5B9B9B3BBB3B7BCB4B9B7B5BBA67A5A3B3D
3D3E4140262C1F079A9BA09EA5A5A5A4A6A4A9A39AA2A2A1
AAA7A09A9088878989878E949C9AA19D9D9B9B9F96938C8E
89857A6E665F4D13152745384F4A4C403F4B5E6C818D7E61
68606C6887947F91B5B7B9B7B7B7B9BBB7B3B9B9B9B9B9B9
B9B9B9B7B9B9B9B9
B7B7B7B9B9B9B7BBB7B5BBB7B5B7BBB3B9B9BBAA69473E3E
42403F1E2A212F019B9FA59EA5A5A4A5A5A5A5A8A3A19CA1
A4A19E9B8F85878C878D929B9C9A9EA39C9D9B9B9D958F8D
8A888475685E51172122313F434554464748606E75879361
605B626A8CA77E9BBBB5BBB7B7B5B9B9BBB5B9B9B9B9B7B9
B9B9BBB3B7B9B9B9
B7B7B5B9B9B9B5B9B9B9B9B9B9B5B9B5B7B7BAAD5F48423E
423F42301E263A379B9FA6A4A4A4A5A8A8A7A4A5A9A1A19A
A9A29E9191868B8E8C8F9C9D9C9C9DA69D9F9C9B9D92948E
8D82867A6B5E5A2B0E28243C47434555484963767782916A
5B596162889A8EB5B9B9B9B9B9B9B9B9B9B9B9B9B9BBB5B9
B9B9BBB7B5B9B9B7
B7B7B7B7BBB5B9B9B9B9B9B9B3B9B5BBB5B5B2955D424243
453F2B251A323D8B9FA0A8A4A5A7A1A7A7AAA4A5A5A7A69B
A5A9A1998D8C8B908F939AA0A0A19BA6A1A39F9EA0999594
8F898185755F574B2D293B35494C484C4B4A5B7F7C809E60
5B4B69588BA399B9B9B9B9B9B9B9B9B9B7B9B9B7B7B9B9B7
B9B7B9B9B9B9BBB5
B5B5B7B3B9B9B9B9B9B9B9B7B7B3B9BBB7B5936C4E353D41
40422F31300092A09EA3AAA5A5ADA4A4A5A7A4A4A4A4A79F
A5A9A39F9289919291929B9AA4A79FA89EA3A0A29E9C9D94
918C867F7D6855493931324140534D5056545E827B7E8F6A
514968677F9DB2B9B9B9B9B9B9B9B9BBB5B9BBB7B5B9BBB5
B9B5B9B9B7B9B9B9
B5B3BBB5B9B9B9B9B9BBB5B9BBB3B9B9B9B7A95C463B3A4A
413B3B2648299D9BA4A5A5A5AAAAA5A4A3AAA5A8A7A4A8A1
A5A4A4A192888D949697989DA59EA5A3A49DA3A1A19C9E9A
938A8C817F69594B332D3237424853544A5A717F7E7C8E73
624E5F6F79A4B9B9B9B9B9B9B9B9B9B9B9B9B9B7B9B7B9BB
B5B9B9BBB5B9B9B9
B7B5B9B7B9B7B9B9B9B7B9B9BBB5B9B9BBB5A26152423546
45323943296F9F9EA4A4A1A7AAA4A5A4A4A3A1A7AAA4A4A4
A1A8A2A5948B87929298989EA09EA2A7A09EA39F9F9C9B9C
9A8F8B848273624E423031324045504B4643827B7B7C8070
595E606573AFB9B9B9B9B9B9B9B9B9B9B9B9BBB5BBB5B9B7
B9B9B9B9B9B9B9B9
B7B7BBB5BBB3B9B7BBB3B9B9B9B9B9B9B7AB8152504C4740
39363445509EA0A1A4A4A4A5A7A4A4A5A39BA0A2A2A4A4A6
9BA4A4AC998C878B909091999F9EA0A49DA49F9B9C9B9D9B
95978D887F7A6556442C3034374C4E504C3E817E796B6A64
49646B6A6EB4B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B7BBB5
B9B9B9B9B9B9B9B9
B7B5B9B9B9B5BBB3BBB5B9B9B9B9B9BBB3A1845B484B4643
343A3B2094A497A5A5A7A4A1AAA4A1A19A9B999D9BA3A89D
A0A5A4A99D8B888787948B989F999F9B9A9E9B999B9B9B9D
95968F8A87786E56492E21313940554E4C4A7D757C5F437D
4454717B75B9B9B9B7B9B9B9B9B9B9B9B9B9B9B9BBB3B9B9
B9B9B9B9B9B9B9B9
B9B9B9BBB3B9BBB5B7B9B9B9B7B7B7B9B57F5A615B455440
2E3C5A48959796A5A1AAA4A3A2A29DA4918F9298999BA49B
9DA5A4A69B86888387859099989C94938D8F8D8D8F929896
9C8F968B827B6B614D421C2430414B564B487C726D603382
4A4D6E7E8DB9B9BBB5B9B9B9B9B7B9B9B9B9B9B9BBB5B9B9
B9B7B9B9B9B9B9B9
B9B9B9BBB5B9B9BBB5B9B7BBB5B7B7B5B9A84A5C484D4B2B
42353B868D849AA6A4A4A4A399897D8391807D8C929CA39A
99A5A4AD978A7C82848B8996938B8779777B827C83859492
8E8E928B857971584F433B292A38474A54486D7763643278
4D43757895BCB9B9B9B9B9B9BBB5B9B9B9B9B9B9B9B9B9B9
BBB5B9B9B9B9B9B9
B7B7B9B9B9B9B7B9B7BBB5BBB5B9B9B9A29E5A4F4343473A
355B4E9C787C9DA3A4A39D857E89855E5D6D6B7E738B9F9B
97A5A5A8A08E817B74635B777F8F7B595B6268696A738A92
8B8B8A88837A6A635144452C2735464755536D6E655A3982
594983729ABFB9B9B9B9B9B9B9B9B9B9B9B9B9B9B7B9B9B9
B9B9B9B9B9B9B9B9
B7B5B9B9B9BBB5BBB5B9B9B9B7B9B9B9AC7E685D3242463C
24259596817EA0A1A09E8781737A7869484F5D75786B9194
95A5A5A69D957C796B904F537F74785E50566266585C7886
878A8B8385786C5D4F442F161E324A3E4A5A67695E664069
56618872AFB9B9B9B9B9B9B9B9B9B9B9B9B7B9BBB5B7B9B9
B9B9B9B9B9B9B9B9
B9B9B9B9B9B9B9B9B9B7B9BBB5B9B9B9E77D5C473837444E
49129E8583839AA39B8B763D4E7D926B1E3B434D6C6A8588
98A5A8A29F9789776465884771785D1F3D54463D434F6277
7B868881797C6A584F45261C1C203E454557636A5E615069
426F8776B9B9B9B9B9B9B9B9B9B9B9B9BBB5B9B9BBB5B9B9
B9B9B9B9B9B9B9B9
B9B9B9B9B9B9B9B9BBB5B9B9B9B9B99D99A66C4B433B464B
554597837A85999E96845558393E322E65325A4A62747A8E
9DA3A7A39D96987E785E5F735451214B2342305E3B49626A
6E7D8182716E5D544E433D222A2F2D3F435F59575E67557B
4A6F7492B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9
B9B7B9B9B9B9B9B9
B9B9B9B9B9B7B9B9B9B7B9B9B9B9B9A2619260494C464141
4F62917D7D849AA39C958D59544F463D3E4D6464747E9194
A2A2A7A39E9C9A90817D6E545F7C5C4A3E343E47605B6A71
727A7B7C78685C4D494A3F2C2A2D2D35455D6258566C617D
567069AAB9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9
BBB5B9B9B9B9B9B9
B9B9B9B9BBB5B9B9BBB5B9B9B9B7B9E8766554403A433947
4E68827A78819C9EA0A4A1998C83787677717474818B9C9E
9FA5A7A69F9D9D8E847F7E886C747577746C67637082837D
7E81807375715B504B39382C2C3A39313F5F6458586B7080
5C6E7DB6B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9
B9B9B9B9B9B9B9B7
B9B9B9B7B9B9B7B9B9B9B9B9B9B5B9C36D53383434473536
50687678717D999A9EA8A6A1A5A1987E706B6E718B8F9CA8
A3A7A4A7A4A3A4997C695C666F848B8D8D8A8B8E8A8D8E8B
7F7678786B68644F4B4A2E29252D26393C51665655707388
60619FBFB9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9
B9B9B9B9B9B9BBB5
B9B9BBB5B9BBB5B9B9B9B9BBB5B9B5B56F3936303B3B4A3F
4E596D756C77A19098A1A6A4A48B7D6E656E796D969AA6A8
A3ADA4A6A7A1ABA19F82574B4B52788D959C999992918D83
74746D736A5F5C543B362E2B27223C3B4B546154516F6C96
6960AFB9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9
B9B9B9B9B9B9B9B9
B9B9B9B9B9B9B9B9B9B9B9B9B7B9B08C9139413A2E3E4342
4D4D5A6A6D729D907D848C85767C707E86788DA1A7A5A6AD
A5AAA4A5A5A7A3A5A6A79C7C695A4A5E606C777E75746D74
796979736B5E5850582637363528204050585E5950756B6E
6C6CB9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B7B9B9B9B9
B9B9B9B9B9B9B9B9
B9B9B9B9B9B9B9B9B9B9B9BBB3B5C15F6E41464743374140
4B4F505E687798B58D88827D857D7A88A5A8A6AAAAAAAAAA
ADA4A5A8A7A8A7A4A3A5A79F9C968C7780645F65676F7370
70797A766D605D53364B2E2F1C1B1F3153505E5C56716F6C
4997B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9BBB5B9B7B9B9
B9B9B9B9B9B9B9B9
B9B9B9B9B9B7B9B9B9B7B9BBB5B9CD7C56404A5A4D454045
4A4E555D5E7B989EA1AB9D98888EA2AAAAAAAAAAAAAAABAA
ADA5A5AAAAA9A5A5A4A7A5A09E9E9C9BA799888381768083
7D7978706A625F634834271B1B181D2E565354685572765B
54AFB9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9BBB5B9B9
B9B9B9B9B9B9B9B9
B9B9B9B7BBB5B9B9B9B5B9B9B9B9BC6A494B4A624F4A4A45
4B4B535F5C769B9CA09DA5A6A5A8A4A7A8AAAAAAA8AAABAA
ADA2A7AAAAA5A7A4A5A4A8A29EA39C9B9C94989792898884
7D827876675F61565C422C271F28222375534978565C7B55
64BCB9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9
B9B9B9B9B9B9B9B9
B9B9BBB5B9B9B9BBB5B9B9B9B9B9CA744D4E4C5E594F4C47
46464B5E5870949E9F9DA3A6A2A7AEA7A3AAAAADA6AAAAAA
ADA9A5AEA8A4AAA4A4A3A3A79EA39C9B9C959C92918D8686
818279726B6260604337362D1B182021736351755A4F773B
8DBFB9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9
B9B9B9B9B9B9B9B9
B9B9B9B9B9B9B7B9B9B9B9B9B9B9C88E454A45524F4C4C49
49474E60626A8F979FA09FA5A6A1A7ADA6AAAAAAA7A8AAAA
AAAAAAA7A7AAA4A3A2A1A1A19FA09C9A949A9595918A8B85
807978786B60604F483735241B18272976735D7D654B783F
B5B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B7B9B9B9
B9B9B9B9B9B9B9B9
B9B9B9B9B9BBB5B9B9B9B9B9B9B9BB8653494C4F54554A4B
464E4C656A708C919FA0A2A5A6A5A5AAA7A8AAACA6A6AAA7
AAAAADA4A4A4A5A8A1A3A1A2A09B9B9D91929194928A8A85
8879786D6F685F553B3F252420191F345970627F6D5C4479
B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9BBB5B9B9B9
B9B9B9B9B9B9B9B9
B9B9B9B9B9B9B9B9B9B9B9B9B9B9B5B8464F4E554F524C48
524E535C6F7284919D9EA3A3A5A3A8ADA8A2A8ADA5A7ABA4
A7A7AAA5A4A4A5A5A3A7A1A19F9E9B9F97939392908C8A84
807C786F6B635D544834291A11113038536D5E7B7D813C9F
B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9
B9B9B9B9B9B9B9B9
B9B9B9B9B9B9B9B9B9B9B9B9B9B9B58863594F51544B4E4E
3E4E56616B72809299A0A2A2A5A6A6AAAAA7A6AAABA7A3AA
A8A5A4A5A4A5A5A8A2A8A2A19AA29C99999791928E8A8A84
84777A6F6461504649331D122111284E5257597A728E6DB9
B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9
B9B9B9B9B9B9B9B9
B9B9B9B7B9B7B9B9B9B9B9B9B9B9B5F86953524748484A46
55475464747380929A9FA2A5A5A3AAADA2AAA8ACA3A9A6A4
AAA5A4A4A6A5A4A5A5A4A69E9E9E9B9D909D90928A8A8C86
86787B6A665E5C4F37331C191E1B2753595852787A69A8B9
B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9
B9B9B9B9B9B9B9B9
B9B9BBB5BBB5B9B9B9B9B9B9B9B9B9C38E55474244443F47
4A555966707D82929A9DA1A6A4A3A7AAA3AAA6ADA9A7A2AA
A8A5A4A5A5A5A6A4A4A59EA1A39C9E9F949E93928A88878A
877B7A6E6858513E332222121A1A285A5357537C8575B9B9
B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9
B9B9B9B9B9B9B9B9
B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B5E061494843464741
445058686E7D869299A39CA6A4A5A8A5A9A5AAAAAAAAA8A2
AAA8A5A5A5A5A5A5A99FA3A1A29AA09B9B9A95928B8C8488
808078696765523B2F2222191C1F276A56585577879DB9B7
B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9
B9B9B9B9B9B9B9B9
B9B9B7B9B9B9B9B9B9B9B9B9B9B9B9B9D18A473F43434648
44495C68737D8996989E9EA4A5A2AAA2A8AAA8AAAAA2AAA5
A2AAA4A6A4A5A5A5A79FA4A29F9F9B9C9A9B93948D8A8A82
8577756E6059503B2E261F26241A29606A57677585B9BBB5
B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9
B9B9B9B9B9B9B9B9
B9BBB5B9B9B9B9B9B9B9B9B9B9B9B9B9BBAE5F4646484446
4B4A546675868A989C9DA0A2A5A5A5A5A6ACA2AAA4A5A5A4
A5A5A4A5A5A6A4A5A5A1A29EA19D9B9B9D9594928F8A8B87
7F7C6E6B5E554638312920241A122655625A6D7B9AB9B9B9
B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9
B9B9B9B9B9B9B9B9
B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9EB9C725455564A
484D5D5F70809496989E9FA2A3A5A4A1A7AAA4A5A8A5A4A5
A4A5A5A2A5A3A3A5A2A3A19F9E9B9B98999595908D8A8784
81756B685A4E41402F2E2119112A2A5E605E6F71B2B7B9B9
B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9
B9B9B9B9B9B9B9B9
B9B9B7B9B9B9B9B9B9B9B9B9B7B9B9B9B9B5DCC178584F54
4E4B556770798A9A9B99A2A0A2A4A3A4A4A5A6A2AAA6A4A5
A5A5A8A2A7A1A1A2A1A59AA19B9B9B9E929294938A8D827F
81726C56504D413235252816102C455F5C617478BBB5B9B9
B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9
B9B9B9B9B9B9B9B9
B9BBB5B9B9B9B9B9B9B9B9BBB5B9B9B9B9B5BBC5C3565145
4E505560747B859697989E9FA1A4A0A3A4A5A5A3A5A5A5A2
A5A2A3A2A5A1A19DA1A09B9B9B9B9A9B9590908F8F8D7F88
786D645B50494E332D291A1339395C5B576F6D99B9B7B7B9
B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9
B9B9B9B9B9B9B9B9
B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B5DA55425B
4A5759636F7B8896939B989FA0A0A39FA3A5A5A2A5A5A8A1
A6A0A49F9EA09FA19B9B9B9C9B9B999A94908F8F89847F7B
7C6C635B50434357251A1E392A5F5F5E596D80ADBBB5B9B9
B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9
B9B9B9B9B9B9B9B9
B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B5C1954342
574F6363707B868E979B9A999E9CA6A19EA59FA3A3A3A3A6
9F9CA1A0979C98A09B9B9A9B9B9B9B90958F8E8B89857276
6D635A50504B44334A32352F51526765687781B5BEB2BFB9
B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9
B9B9B9B9B9B9B9B9
B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B5C0954E43
4547595F6B768589909898969F98A59D9E9E9FA1A2A29CA5
9C9D9995988D979B9A9796969594968C8D8D8685817E7373
69625F4B44423F3D35324358485D6074708A92B5BFB7B9B9
BCB9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9BCB9B9B9B9B9
B9B9B9B9B9B9B9B9
B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B5D99B4C35
4B4A4E5D68757C8A8C90998E9C9B9C9F9E9A9A9D9CA3999F
9A97968F8E8E8D9392908C8F8B8C8E86898881817F71706D
6B5E565248454C4C3E4D41675C685F897C7FB7B9BBB5BCB5
BFB9B9B9B9B9B9B9B9B9B9B9B7B9B9B9B9B5BFB9B9B9B9B9
B9B9B9B9B9B9B9B9
B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9C2A99946
40594B5660667C898C8D908D969C9A999E99979797969290
92908C8685818386838382847B7B81797F77777478736960
5A5C5D4C51564050564D536260666C839791B5B9B9B5BFB9
B9B9B9B9B9B9B9B9B9B9B9BBB5B9B9B9B9B9B9B9B9B9B9B9
B9B9B9B9B9B9B9B9
B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9D8A66F
4E4B575862606872888A8D949299979798958E8B8B929187
8686837C7A7777797476727071696F706E716C676F736F6E
655C5856505E5835425963675E79728981B4B9B9B9B9B9B9
B7B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9BCB9B9B9B9B9
B9B9B9B9B9B9B9B9
B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9D6BA
845B4D525E5C5E72758F92959A98938F8C8E878981828F83
807A7C6F756B736374666B5969636266616465675659635F
635D625A4B4A5C5B4D51626E727A838292B9B9B9B7B9B9BB
B5B9B9B9B9B9B9B9B9B9B9B9B9B9B7B9B9B5BFB9B9B9B9B9
B9B9B9B9B9B9B9B9
B9B9B9B9B9B9B9B9B7B9B7B9B9B9B9B9B9B9B9B9B9B9B9BF
AD6E67556177677676878C919791918A8983807C81817C7C
8073716C66686D7068686F67566E636D636165685E525B5F
5C5960585D505153576070747A89966EB9B9B9BBB9B9B9B9
B9B9B9B9B9B9B9B9B9B9B9B9B9BBB5B9B9B9B9B9B9B9B9B9
B9B9B9B9B9B9B9B9
B9B9B9B7B9B9B9BBB5BBB5B9B9B9B9B9B9B9B9B9B9B9B9B9
E57D6364565D7178708786898B8C88877F7E7E71727A7772
75746D6168526A5F70675D6A665C66586265645C634C4946
494D4A4F484C4E5C616D7388867B6B9FB9B9B9B5BFB9B9B9
B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9
B9B9B9B9B9B9B9B9
B9B9BBB5B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9
B5F6836D6462737A7A808C8F88807D847A7A7E72736B746E
6C626262635F405B5168626363516558463F55544D515053
504D55494D545C6D6B7D677F6E8A59BCB9B9B9B9B9B9B9B7
B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9
B9B9B9B9B9B9B9B9
B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9
B9B5C8795954606672888C8C917C77757773776E706D666F
6E5A6A5E5A6D5F41634C58575255463E5143464D494E4C4A
444D56645E685F8981788256784A9BBFB9B9B9B7B9B9B9B5
B9B9B9B9B9B9B9B9B9B9B9B9B9B7B9B9BCB9B9B9B9B9B9B9
B9B9B9B9B9B9B9B9
B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9
B9B9D97163606B5E637989888B776B6E6D767368656A6C66
69714A62624A6D53485A4D4D5145484942413A4847454948
4D53595D646783696E7B726C8665B7B7B9B9B9B5B9B9B5B9
BCB9B9B9B9BCB9B9B9B9B9B9BBB5B9B5BFB9B9B9B9B9B9B9
B9B9B9B9B9B9B9B9
B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9
B9B9B5FF6E456B7070707D908A7D656A606B6C645D69645D
655E5D505C5B4649504C4B494B49403F37343A383B44504D
4A556D7376787C875F645D7474B4BBB3B9BBB5B9BBB5B9B5
BFB9B9B9B5BFB9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9
B9B9B9B9B9B9B9B9
B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9
B9B9B9B7EC8B385668746F8E9080596D6866736E5A626955
605F5F4E645D5C353451524C4739443D382E2E2E2E384360
6361678072676A7071527E3FABBBC1B5B9B9B7B9BCB9B9B9
B9B9B9B9B9B9B9B9B7B9B9B9B9B9B9B9B9B9BCB9B9B9B9B9
B9B9B9B9B9B9B9B9
B9B9B9B9B9B9B7B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9
B9B9BBB5B5E373414D5E6A8091866154725F5E67624F5E62
51596558545F606247403B55484A424A4F4841474C4D5659
6D847B6E7A544C5E6E765183B9B9B9B9B9BEB5B3BFB9B9B9
B9BCB9B9B9B9B9BBB5B9BCB9B9B9B9B9B9B5BFB9B9B9B9B9
B9B9B9B9B9B9B9B9
B9B9B9B9B9BBB5B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9
B9B9B9B9B9C8CA6F564B51616F9069515A706057554C4752
54545659555467625B525247495153534B5B595D646B6D70
7A70876C5E635262626978B9BCBCB9B7B9BDBEB5B7B9BCB9
B5BFB9B9B9B9B9B9B9B5BFB9B9B9B9BCB9B9B9B9B9B9B9B9
B9B9B9B9B9B9B9B9
B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9
B9B9B9BCB9B9CFB36A5E5A5768669B5F525D6E5D624F4948
535458515657646C657155594B4D5D636465666E75866D60
715A484A67585E6D7165BFB5BBC2BEB2C1B5BFBBB5B5BFB9
B9B9B9B9B9B9B9B9B9B9B9B9B9B9B5BFB9B9B9B9B9B9B9B9
B9B9B9B9B9B9B9B9
B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9
B9B9B5BDB9B9B7D6B06158606C6E7B9566595B66596C564B
43434C534A605F766F85977C717078727F87897A7C656E5D
515253525A67675576BFB9BCB5BBBFB9B5BFB9B7B9B9BCBC
B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9
B9B9B9B9B9B9B9B9
B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9
B9B9BBB5B9BBB5BCD2C9765A536176879A6B735E6F626F77
664D474C4B66677E65829A98849897937E8183747265544E
4B52575B68746D61BFB9B3BFB9B7B7B9B9B9B9B5B9B5BBBF
B9B7B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9
B9B9B9B9B9B9B9B9
B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9
B9B9B9B9B9B9B5C2B9BCE3835A4F607D8E9B7A8480847F80
969875977A7D8995927A969694938587846D66695D564F5E
5E5B635E748F75B9BCB9B5B9BBB7B3B9B9BBB5B7B9B9BCB9
BBB3B9B9B7B9BCB9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9
B9B9B9B9B9B9B9B9
B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9BCB9B9
B9B9B9B9B9B9B5C2B9B9B5F09F60586075958F8EA389A1A1
859D95A7A7A2A3AA979F988A87948A6E71655856635F6F62
6E6D707A61BFB7B5BFB5B9B9B9BBB5B9B7B9BBB5B9B5BFB9
BBB5B9BBB5B5BFB9B9B9B9B9B9B9B9BCB9B9BCB9B7B9B9B9
B9B9B9B9B9B9B9B9
B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B5BFB9B9
B9B9B9B9B9BCB5C2BCB9BCB9C3E4765C6973898F9C9A9DA1
9DA99EA4A69BA2AAA399A08F6D856F666D5F5F5B66726F74
7B807F83B9BBB3BBB5B9BCB9BCB9B9B9B5B9B9B9B9B9B9B9
B9BCB9B9B9B9B9B9B9BCB9B9B9B9B9BFB9B5BFBEB5B9B9B9
B9B9B9B9B9B9B9B9
B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9
B9B9B9B9B5BFB5BBBFB5BFB9B3C5E09887616F7A8F969DA3
A29F99A9A29C928F83888690785B6C6A70678A6A7B787A89
8E86A8B9B9BBB5BCB9B5BFB5BDB9BBB9B9BCB9B9B9B7B9BC
B5BFB9B9B9BCB9B9B5BFB9B9B9B5BFB9B9BCB9C2B7B9B9B9
B9B9B9BCB9B9B9B9
B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9BCB9B9B9
B9B9B9B9B9B9B9B9B9B9B7BEB5B5C2B9DFA8918079829396
9CA59BA7A3A4A09389787B868E8D6C7A93777B7E94AB8E8A
B9B9B9B9BCB9B5BFB9B9BCBBB5B9B5BFB5BDB9B9BBB5B5BF
B9BCB9BCB9C2BCBCB9B9B9B9B9BCB9B9B5BFBFC1B9B9B9B9
B9B9B5BFB9B9B9B9
B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B3BFB9B9B9
B9B9B9B9B9B9B9B9B9BBB2BFB9B5BFB9B9BCB9DFA38D8486
86919A9FA1A6ADA3AF9D9B8492AD81818C9C948598ABBFBF
BDB9B9B5BFB9B9B9B7B5BFB7B9B9B9B7BBB5B9B9B9B9B9B7
B5BFB5BBBBBBBBBDB9BCB7B9B5BFB9B9B3BBBFB5BFB7B9B9
B9B9B9B9B9B9B9B9
B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9BBB5BCB9B9B9
B9B9B9B9B9B9B9B9B9B9B9B9B9B9B7B9B5C2B3BDB9D6A695
B0989DA79EB0A39DA0A3A299A09CACA1939CA2AFB9B5BFC4
B5BCBCBCB9B9B9BBB5B7B9B5B9B9BBB5B9B7B9BCB7B9BBB5
BCB9B9B9B9B9BBB5B5C1B9B9BCB9B9BBB5B9B9B9BBB9B9B9
B9B9B9B9B9BCB9B9
B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B5BFB7B9B9
B9B9B9B9B9B9B9B9B9BCB7B9B9BBB5B7B5C1B7B5B9B9BBB7
B7BFB5B8ABBABEB1A7A1AAB3ACA9A4B1B5B9BCBCB9B5BBC2
B5BBBBBFB7B9BCB9BBBBB5B9B9BCB9BCBBB9B5BFB5B9B7B5
BFB9B9B9B9B9B9B9B9B5BDB5BFBCB9B9B9B9BCB9B5BFB9B9
B9B9B9B9B5BFB9B9
B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9BBB5B9B9
B9B9B9B9B9B9B9B9B5C1B5B9B9B9B9B5B9B7BCB9B9B9B7B9
B3BFB9BCB7B9BBB7B7B7B2C2B9B9B7B9B9B5BBBFB9BCB5C2
B9B9B9B9B9B5C2BCB5BFB9B9B5BFB5BFB5C2B9B3B9B9B5B9
B9B9B9B9B9B9BCB9B9BBB5B9B5C2B9B9B9B3BFBCBCB9B9B9
B9B9B9B9B9BCB9B7
B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9BCB9
B9B9B9B9B9B9B9B9B9B9B9B9B9BBB5B9BEB5BFB9B9B9B5BB
B9B9B5C1B9B9B9BCB9B9B5BDB9BBB5B9B9B9B7B9B9BFB5C2
BCB9BBB2BDB5BBBDB9BCB9B9B9B9BCB9B5C1B7B5BBB5B9B9
BCB7B9B9B9B5C2B9B9BCB9B9B3BFB9B9BBB5B5B9C2B9B9B9
B9B9B9B9B5BFBBB9
B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9BCB9B9B3BFB9
B7B9B9B9B9B9B9B9B9B9B9B9B7BCB9B5BBBDB9B9BBB5B7B9
BDB9B9B5C2B9B5BFBCB9B9B5B9B7B9B9B9BBB5B5BFB9B5BB
C2B9B9B9B5BCBBB5B5BDBCBCB9B5BDBCB9B9B9B9BCB9B9B5
C4B5B9B9BCB5BFBCB5BFBCBEB5B9BCB9B9B9B9B2BFB9B9B9
B9B9B9BCB9B9B5BF
B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B5BFB9BBB5B9BE
B5B9B9B9B9B9B9B9B9B9B9BBB2BFB9B9BBB5B9B9B9BBB0C1
B5B9BCB3BFBCB9B5BFBBB9B9BEB5B9B9B9B9B9B7B9BCB9B5
BFB9BBB5B5BFB9B9BBB2BBBDB9BBB2BFB9B9B7B9BDBCB9B5
C2B9B9B3BFB9B5BFB9B5BBBFB9B5BFB9B7BBB5B9B9B9B9B9
B9B9B3C2B9B9B9B9
B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9BCB5BF
B9B9B9B9B9B9B9B9B9B9B9B7B9B9B9B9B9B9B9B9B9BBB3B7
B9B5C1B5B3C2BCB9B9B9BDB5BFB9B9B9BCB9B9B3B5BFBCB7
B9BCB9BCB9B9BCB9BCB9BBB5B9B9BCB9B9BBB2C0B0BFBCB5
BFB9BEB5B9B9BCB9BCB9B9BCB7B9B9BBB5B9BCB9B9BCB9B9
B9BBB2BFB9B9B9B7
B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B5BFB9BC
B9B9B9B9B9B9B9B9B9B9BBB5BCB9B9B7B9B7B9B9B9BBB7B5
BCB9B9BBB2BBBFB9B3C4B5B9B9B9B9B5BFBBB7B5B9B3C1B9
B5C2B5BFB9B3C2B3C2B9B9B9B7B5BFB9B9B9B9BBB5B9BDB7
B9B5BFB7B9B5BFB5C2B9B5C1B5B9B9B9BCB5BFB9B5BFB9B9
B9B9B9B9B9B7BBBB
B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B5BF
B7B9B9B9B9B9B9B9B9B7BCB5BFB7BBB5B9B3B9B9B9BCBCB5
BFB9B7B9B9B9B9B9B2BFBCB9B7BCB9B9B9B9B9BCBBB9B5BD
B9BFB7B9B9B2C1B5BFB9B7BBB5BCB7BCB9B7B9B7B9C1BBB5
B9B9B9B5B9B9B9B5BFB9B9B9B9B9B9B5BFB9B7B9B9B9B9B9
B9B9B9B9BBB5B5BF
B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9BB
B5B9B9B9B9B9B9B9BBB2BFB9BBB9B9BEB7B3BCBCB5B9C2B9
B9BBB5B9B9B9BBB9BCB5BFBBB2C2B9B9B9B9B5BFB9BFBBB2
BFBBB9BEB9BCB5BFB9BBB3B9B9C1B2BFBEB9BEB5BFB5BFB9
B9BBB9BCB9B9B9B9B7B9B9B9B9B9B9BCB9BBB5B9BCB9B9B9
B9BCB9BCB9B9BCB9
B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9BCB9BCB9B9
B7B9B7B9B9B9B9B9BCB9B9B9B5BFB5BDBBB0BBBDBBB2BFB9
B9B9B9B7B9B9B5BBBFB9BCB9B5BFB9BCB7B9BCB9BFB9B9B9
B9B5BBBBBBBFB9BCB9BBB5B5BFB7B9B5BBBBBBBFBCB9BCB9
B9B3BBC2B9B9B9BEB5B9B9B9B9B9B5BFB7B9B7B5BFB9B9B9
B5BFB5BFB9B5BFB9
B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B5C2B5BFBCBB
B5BBB5B9B9B9B9B5BFB9B9B9B9B7BBB5BBB5BBB5BCB9BCB9
B9B9BBB5B9B9B9B9B9B9C2B9B9B9B3C1B5B9BFBFB9B9B9B9
B9B9B9B9B9B9B9C2BCB9B9B9BBB5B9B9B9B9B9B5C2B9C2B9
BBB5B5BFB9B9B5BFB9B9B9B9B9B9BCBBB3BBB3B9B9BCB9B9
BCB7B9B9B9B9B9B9
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[40]:=",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`004`3oool40;>c/`80/K6a0P2i^KT20;bl_080/k>c
0P2e]KD20;:b/P030:j^[P2l_;`0_;bl0080/K6a0P2k^k/609nOW`80WYjN0P2VYZH80:2PX080UYJF
0P2f][H20:b/[00306=SH`2GUiL0UiNG0080XZ:R0P2IVIT209^KV`80Ti>C0P2KVi/209bLW080TY:B
0P2JVYX209^KV`80VYZJ0P2MWId209FEU@80Ti>C0P2KVi/00`2IVIT0WinO09nOW`020:2PX0P0Vi^K
0P2JVYX209fMW@80T92@102KVi/209VIV@/0XJ6Q0P2RXZ8209jNWP80Xj>S0P2KVi/209ZJVP80W9bL
0P2SXj<?09^KV`80VYZJ0P2KVi/209bLW080VIVI102KVi/209ZJVP@0Vi^K0P2DU9@20:FUY@80^;Rh
0P2[Zj/2075aL@0309FEU@2CTi<0Ti>C0080Vi^K0P2LW9`409FEU@80Ti>C2P2IVIT209NGU`@0X:2P
0P2KVi/00`2LW9`0YjNW0:NWY`020:2PX0@0YJFU0P2WYjL209jNWP80YjNW0P2QXJ4209ZJVP80Vi^K
0P2BTY82096AT@H0UIFE00<0R8R80:VYZ@2YZJT00P2][Jd208>3P`80UiNG0P2[Zj/20;>c/`80_;bl
5@3oool001<0oooo102c/k<20;6a/@80^KVi0P2l_;`20;>c/`80]KFe0P2b/[800`2^[Zh0_;bl0;bl
_0020;6a/@80^k^k1P2OWil209jNWP80YZJV202PX:0209JFUP80][Jf0P2/[:`00`1SHf<0UiNG09NG
U`020::RXP80VIVI0P2KVi/209>CT`80Vi^K0P2LW9`209:BTP80VYZJ0P2KVi/209ZJVP80WIfM0P2E
UID209>CT`80Vi^K00<0VIVI09nOW`2OWil00P2PX:0809^KV`80VYZJ0P2MWId2092@T0@0Vi^K0P2I
VIT;0:6QX@80XZ:R0P2NWYh20:>SX`80Vi^K0P2JVYX209bLW080Xj>S3`2KVi/209ZJVP80Vi^K0P2L
W9`209VIV@@0Vi^K0P2JVYX409^KV`80U9BD0P2UYJD20;Rh^080Zj^[0P1aLG400`2EUID0Ti>C09>C
T`0209^KV`80W9bL102EUID209>CT`X0VIVI0P2GUiL40:2PX080Vi^K00<0W9bL0:NWY`2WYjL00P2P
X:040:FUY@80YjNW0P2NWYh20:NWY`80XJ6Q0P2JVYX209^KV`80TY:B0P2ATI4609FEU@0308R8R02Y
ZJT0ZJVY0080[Jf]0P23Ph<209NGU`80Zj^[0P2c/k<20;bl_1D0oooo000C0?ooo`@0/k>c0P2b/[82
0;Ng]`80^;Rh0P2d];@20;Rh^080][Jf00<0[jn_0;Zj^P2j^[X00P2e]KD20;no_`80ZJVY102PX:02
09jNWP80Y:BT202PX:0209JFUP80Zj^[0P2m_Kd00`1]KFd0V9RH09RHV0020::RXP80VYZJ0P2LW9`2
09BDU080UiNG0P2JVYX209:BTP80V9RH102KVi/209jNWP80VIVI0P2EUID209RHV00309ZJVP2NWYh0
WYjN0080WYjN102KVi/209VIV@80UYJF0P2HV9P209nOW`80TY:B0P2HV9P209^KV`80V9RH0P2MWId2
09jNWP80WinO00<0WYjN09fMW@2MWId00P2NWYh20:6QX@80Vi^K0P2QXJ4209jNWP@0VYZJ0P2PX:02
09^KV`@0W9bL3@2KVi/209bLW0@0VIVI0P2HV9P609^KV`80Ti>C0P2MWId20;Bd]080^[Zj0P1bLW80
0`27QhL0UYJF09JFUP0209^KV`80W9bL102EUID209>CT`80UYJF0P2GUiL209ZJVP@0Vi^K0P2HV9P4
09nOW`80W9bL00<0VYZJ0:BTY02TY:@00P2NWYh40::RXP80YJFU0P2PX:020:FUY@80XJ6Q0P2JVYX2
09fMW@80UiNG0P2DU9@209FEU@80UYJF0P2JVYX00`2FUYH0YjNW0:NWY`020:RXZ080QhN70P2ATI42
0:^[Z`80/k>c0P2i^KTE0?ooo`004`3oool40;>c/`80/[:b0P2g]kL20;Rh^080];Bd0P2h^;P20;Jf
]P030:n_[`2j^[X0^[Zj0080]KFe0P2o_kl20:VYZ@@0X:2P0P2NWYh20:BTY0P0X:2P0P2FUYH20:^[
Z`80_Kfm00<0KFe]09RHV02HV9P00P2RXZ8209ZJVP80W9bL0P2DU9@209NGU`80VYZJ0P2BTY8209RH
V0@0Vi^K0P2NWYh209VIV@80UIFE0P2HV9P00`2JVYX0WYjN09jNWP0209jNWP@0Vi^K0P2IVIT209JF
UP80V9RH0P2OWil209:BTP80V9RH0P2KVi/209RHV080WIfM0P2NWYh209nOW`0309jNWP2MWId0WIfM
0080WYjN0P2QXJ4209^KV`80XJ6Q0P2NWYh409ZJVP80X:2P0P2KVi/409bLW0d0Vi^K0P2LW9`409VI
V@80V9RH1P2KVi/209>CT`80WIfM0P2d];@20;Zj^P80LW9b00<0QhN709JFUP2FUYH00P2KVi/209bL
W0@0UIFE0P2CTi<209JFUP80UiNG0P2JVYX409^KV`80V9RH102OWil209bLW00309ZJVP2TY:@0Y:BT
0080WYjN102RXZ820:FUY@80X:2P0P2UYJD20:6QX@80VYZJ0P2MWId209NGU`80U9BD0P2EUID209JF
UP80VYZJ00<0UYJF0:NWY`2WYjL00P2XZ:P208N7Q`80TI6A0P2[Zj/20;>c/`80^KVi5@3oool001<0
oooo0P2c/k<20;:b/P80/k>c0P2e]KD20;:b/P80/K6a0P2f][H20;Vi^@030;Bd]02a/K40/K6a0080
^KVi0P2h^;P20<30`080Zj^[1P2PX:0409nOW`80X:2P0P2OWil209jNWP80V9RH0P35aLD00`1oOgl0
PH610861P@0209nOW`80Vi^K0P2IVIT209NGU`80Ti>C0P2FUYH209RHV080UiNG0P2JVYX209^KV`80
VYZJ0P2KVi/209bLW080TY:B00<0UIFE0:6QX@2QXJ400P2MWId209^KV`80VYZJ0P2KVi/209>CT`80
TY:B0P2EUID209JFUP80Shn?0P2EUID209VIV@@0VYZJ0P2NWYh00`2OWil0Vi^K09^KV`0209RHV080
X:2P0P2KVi/209RHV080X:2P0P2LW9`209jNWP@0WinO0P2LW9`209nOW`80WYjN0P2LW9`;09^KV`@0
W9bL0P2FUYH209^KV`80W9bL0P2KVi/209bLW080Ti>C0P2LW9`20<;2`P80Zj^[00<0N7Qh08F5Q@25
QHD00P2GUiL209VIV@80UYJF0P2HV9P209NGU`80UIFE0P2CTi<209VIV@80UiNG0P2HV9P209ZJVP80
XJ6Q0P2LW9`20:6QX@0309bLW02OWil0WinO0080WinO0P2QXJ420:>SX`80XJ6Q0P2WYjL20:2PX080
XZ:R1P2JVYX209bLW080V9RH0P2IVIT209FEU@030:NWY`2j^[X0^[Zj0080Vi^K0P2CTi<208V9R@80
YjNW0P2e]KD20;Jf]QD0oooo000C0?ooo`80/k>c0P2b/[820;>c/`80]KFe0P2b/[820;6a/@80][Jf
0P2i^KT00`2d];@0/K6a0;6a/@020;Vi^@80^;Rh0P30`<020:^[Z`H0X:2P102OWil20:2PX080WinO
0P2NWYh209RHV080aLG500<0Ogmo0861P@21PH400P2OWil209^KV`80VIVI0P2GUiL209>CT`80UYJF
0P2HV9P209NGU`80VYZJ0P2KVi/209ZJVP80Vi^K0P2LW9`209:BTP0309FEU@2QXJ40XJ6Q0080WIfM
0P2KVi/209ZJVP80Vi^K0P2CTi<209:BTP80UIFE0P2FUYH208n?S`80UIFE0P2IVIT409ZJVP80WYjN
00<0WinO09^KV`2KVi/00P2HV9P20:2PX080Vi^K0P2HV9P20:2PX080W9bL0P2NWYh409nOW`80W9bL
0P2OWil209jNWP80W9bL2`2KVi/409bLW080UYJF0P2KVi/209bLW080Vi^K0P2LW9`209>CT`80W9bL
0P32`/820:^[Z`0307QhN025QHD0QHF50080UiNG0P2IVIT209JFUP80V9RH0P2GUiL209FEU@80Ti>C
0P2IVIT209NGU`80V9RH0P2JVYX20:6QX@80W9bL0P2QXJ400`2LW9`0WinO09nOW`0209nOW`80XJ6Q
0P2SXj<20:6QX@80YjNW0P2PX:020::RXPH0VYZJ0P2LW9`209RHV080VIVI0P2EUID00`2WYjL0^[Zj
0;Zj^P0209^KV`80Ti>C0P29RHT20:NWY`80]KFe0P2f][HE0?ooo`004`3oool80;>c/`80]kNg0P2d
];@20;Ng]`80][Jf00<0/k>c0;Ng]`2g]kL00P2c/k<20;Jf]P80^;Rh0P30`<020:^[Z`80ZZZZ0P2R
XZ8209nOW`@0WIfM0P2NWYh209ZJVP80UiNG0P2PX:000`3Bd]80MWIf07IfMP02096AT@80Vi^K0P2M
WId209VIV@80TI6A0P2BTY8609NGU`H0Vi^K0P2LW9`209JFUP0308n?S`2LW9`0W9bL0080WYjN102L
W9`209NGU`80V9RH0P2CTi<209BDU080Ti>C0P2BTY8208j>SP80TI6A0P2GUiL209^KV`80VIVI00<0
WYjN09^KV`2KVi/01P2KVi/209ZJVP80Vi^K0P2LW9`20::RXP80XJ6Q0P2RXZ820:6QX@80X:2P0P2T
Y:@209nOW`80WYjN00<0WinO09jNWP2NWYh0102KVi/409bLW0@0Vi^K102LW9`409^KV`80W9bL0P2H
V9P209BDU080[Zj^00<0clo?07UiN@1iNGT00P27QhL209VIV@80UYJF0P2LW9`209fMW@80VIVI0P2H
V9P209jNWP80VIVI0P2FUYH209ZJVP80WinO0P2MWId209nOW`0309fMW@2PX:00X:2P0080X:2P0P2Q
XJ420:BTY080YJFU0P2TY:@20::RXP80WYjN0P2MWId209ZJVP80WYjN0P2KVi/20:>SX`80WinO0P2T
Y:@00`2PX:00YZJV0:JVYP020:ZZZP80UYJF0P2<S8`20:JVYP80[:b/0P2f][HE0?ooo`004`3oool8
0;>c/`80]kNg0P2d];@20;Ng]`80][Jf00<0/k>c0;Ng]`2g]kL00P2c/k<20;Jf]P80^;Rh0P30`<02
0:^[Z`80ZZZZ0P2RXZ8209nOW`@0WIfM0P2NWYh209ZJVP80UiNG0P2PX:000`3Bd]80MWIf07IfMP02
096AT@80Vi^K0P2MWId209VIV@80TI6A0P2BTY8609NGU`H0Vi^K0P2LW9`209JFUP0308n?S`2LW9`0
W9bL0080WYjN102LW9`209NGU`80V9RH0P2CTi<209BDU080Ti>C0P2BTY8208j>SP80TI6A0P2GUiL2
09^KV`80VIVI00<0WYjN09^KV`2KVi/01P2KVi/209ZJVP80Vi^K0P2LW9`20::RXP80XJ6Q0P2RXZ82
0:6QX@80X:2P0P2TY:@209nOW`80WYjN00<0WinO09jNWP2NWYh0102KVi/409bLW0@0Vi^K102LW9`4
09^KV`80W9bL0P2HV9P209BDU080[Zj^00<0clo?07UiN@1iNGT00P27QhL209VIV@80UYJF0P2LW9`2
09fMW@80VIVI0P2HV9P209jNWP80VIVI0P2FUYH209ZJVP80WinO0P2MWId209nOW`0309fMW@2PX:00
X:2P0080X:2P0P2QXJ420:BTY080YJFU0P2TY:@20::RXP80WYjN0P2MWId209ZJVP80WYjN0P2KVi/2
0:>SX`80WinO0P2TY:@00`2PX:00YZJV0:JVYP020:ZZZP80UYJF0P2<S8`20:JVYP80[:b/0P2f][HE
0?ooo`004`3oool40;Bd]080/k>c0P2b/[820;Zj^P80];Bd0P2g]kL20;Zj^P030:n_[`2i^KT0^KVi
0080_;bl0P2g]kL20;Jf]P80]KFe0P2f][H20;Zj^P80/[:b0P2OWil20::RXP80WYjN0P2LW9`209fM
W@80W9bL0P2EUID00`2f][H0[Zj^0:j^[P0208N7Q`80VYZJ0P2LW9`209fMW@@0UIFE0P2FUYH209NG
U`80TY:B0P2GUiL409^KV`80WYjN0P2IVIT00`2FUYH0Vi^K09^KV`0209ZJVP80V9RH0P2JVYX209BD
U080WYjN0P2JVYX209FEU@80V9RH0P2IVIT209>CT`80Shn?0P2BTY8409RHV00309FEU@2FUYH0UYJF
0080UYJF1P2KVi/409VIV@80XZ:R0P2PX:0209fMW@80W9bL0P2XZ:P20::RXP80X:2P0`2OWil20:BT
Y0@0W9bL102NWYh409bLW0@0WYjN0P2MWId209bLW080WIfM0P2KVi/209VIV@80U9BD00<0[Zj^0;bl
_02l_;`00P1cLg<209BDU080W9bL102MWId209^KV`80WYjN102KVi/209jNWP80W9bL0P2QXJ4209bL
W080XZ:R00<0W9bL09nOW`2OWil00P2OWil20:JVYP80Y:BT0P2WYjL20:2PX080YZJV0P2OWil209jN
WP80VIVI0P2VYZH209fMW@80]KFe0P2ZZZX20:>SX`030;Zj^P2ATI40TI6A0080Zj^[0P2HV9P208N7
Q`80[jn_0P2d];@20:n_[aD0oooo000C0?ooo`@0];Bd0P2c/k<20;:b/P80^[Zj0P2d];@20;Ng]`80
^[Zj00<0[jn_0;Vi^@2i^KT00P2l_;`20;Ng]`80][Jf0P2e]KD20;Jf]P80^[Zj0P2b/[8209nOW`80
XZ:R0P2NWYh209bLW080WIfM0P2LW9`209FEU@030;Jf]P2^[Zh0[Zj^0080QhN70P2JVYX209bLW080
WIfM102EUID209JFUP80UiNG0P2BTY8209NGU`@0Vi^K0P2NWYh209VIV@0309JFUP2KVi/0Vi^K0080
VYZJ0P2HV9P209ZJVP80U9BD0P2NWYh209ZJVP80UIFE0P2HV9P209VIV@80Ti>C0P2?Shl209:BTP@0
V9RH00<0UIFE09JFUP2FUYH00P2FUYH609^KV`@0VIVI0P2RXZ820:2PX080WIfM0P2LW9`20:RXZ080
XZ:R0P2PX:0309nOW`80Y:BT102LW9`409jNWP@0W9bL102NWYh209fMW@80W9bL0P2MWId209^KV`80
VIVI0P2DU9@00`2^[Zh0_;bl0;bl_00207=cL`80U9BD0P2LW9`409fMW@80Vi^K0P2NWYh409^KV`80
WYjN0P2LW9`20:6QX@80W9bL0P2RXZ800`2LW9`0WinO09nOW`0209nOW`80YZJV0P2TY:@20:NWY`80
X:2P0P2VYZH209nOW`80WYjN0P2IVIT20:JVYP80WIfM0P2e]KD20:ZZZP80Xj>S00<0^[Zj096AT@2A
TI400P2[Zj/209RHV080QhN70P2_[jl20;Bd]080[jn_5@3oool001<0oooo102c/k<20;Jf]P80/[:b
0P2c/k<20;Rh^080]KFe0P2f][H00`2c/k<0]KFe0;Fe]@040;Ng]`80^;Rh0P2d];@20;bl_080];Bd
0P2o_kl20;6a/@@0Xj>S0P2MWId20:6QX@80Vi^K0P2IVIT00`2WYjL0`l?30<?3``0209NGU`80W9bL
0P2MWId20:>SX`80V9RH0P2GUiL209:BTP80Vi^K0P2HV9P209FEU@80Vi^K0P2IVIT209NGU`80V9RH
00<0VIVI09JFUP2FUYH00P2GUiL209JFUP80UIFE0P2DU9@809^KV`80WIfM0P2LW9`209BDU080TY:B
0P2?Shl209VIV@D0Ti>C0P2GUiL809^KV`80V9RH0P2QXJ4209fMW@80VYZJ0P2RXZ820:BTY080W9bL
0P2RXZ800`2MWId0XZ:R0::RXP020:6QX@80W9bL0P2PX:020:6QX@80WYjN0P2LW9`209jNWP@0WinO
0P2JVYX209nOW`80W9bL0P2MWId209VIV@0309BDU030`<00`<300080WYjN0P2:RXX209>CT`80WIfM
0P2OWil20:6QX@80WIfM102LW9`209nOW`80XJ6Q102PX:020::RXP<0X:2P0P2NWYh20:>SX`@0Y:BT
0P2VYZH209nOW`80W9bL0P2MWId209>CT`80WIfM0P2b/[820:j^[P80XZ:R0P2SXj<00`2][Jd0VIVI
09VIV@020;>c/`80UYJF0P2?Shl20:f][@80^KVi0P2f][HE0?ooo`004`3oool40;>c/`80][Jf0P2b
/[820;>c/`80^;Rh0P2e]KD20;Jf]P030;>c/`2e]KD0]KFe00@0]kNg0P2h^;P20;Bd]080_;bl0P2d
];@20;no_`80/K6a102SXj<209fMW@80XJ6Q0P2KVi/209VIV@030:NWY`33`l<0`l?30080UiNG0P2L
W9`209fMW@80Xj>S0P2HV9P209NGU`80TY:B0P2KVi/209RHV080UIFE0P2KVi/209VIV@80UiNG0P2H
V9P00`2IVIT0UYJF09JFUP0209NGU`80UYJF0P2EUID209BDU0P0Vi^K0P2MWId209bLW080U9BD0P2B
TY8208n?S`80VIVI1@2CTi<209NGU`P0Vi^K0P2HV9P20:6QX@80WIfM0P2JVYX20::RXP80Y:BT0P2L
W9`20::RXP0309fMW@2RXZ80XZ:R0080XJ6Q0P2LW9`20:2PX080XJ6Q0P2NWYh209bLW080WYjN102O
Wil209ZJVP80WinO0P2LW9`209fMW@80VIVI00<0U9BD0<30`030`<000P2NWYh208Z:RP80Ti>C0P2M
WId209nOW`80XJ6Q0P2MWId409bLW080WinO0P2QXJ440:2PX080XZ:R0`2PX:0209jNWP80Xj>S102T
Y:@20:JVYP80WinO0P2LW9`209fMW@80Ti>C0P2MWId20;:b/P80[Zj^0P2RXZ820:>SX`030:f][@2I
VIT0VIVI0080/k>c0P2FUYH208n?S`80[Jf]0P2i^KT20;Jf]QD0oooo000C0?ooo`80/k>c0P2b/[82
0;Vi^@80];Bd0P2h^;P20;:b/P80][Jf0P2b/[800`2j^[X0/[:b0;:b/P020;Ng]`80]KFe0P2b/[82
0;Vi^@80^;Rh0P2e]KD20;^k^`80_kno0P2g]kL20:ZZZP80Y:BT102SXj<20::RXP0309^KV`2[Zj/0
Zj^[0080^KVi0P2MWId209jNWP80XZ:R102NWYh209RHV080U9BD0P2GUiL209FEU@80UYJF0P2JVYX2
09BDU080SHf=0`2CTi<208j>SP80Ti>C0P2DU9@2092@T080Vi^K0P2LW9`209fMW@80WYjN0P2MWId2
09jNWP80XZ:R0P2IVIT209FEU@80Shn?00<0V9RH08n?S`2?Shl00P2IVIT2092@T0@0UYJF0P2GUiL4
09^KV`80VYZJ0P2KVi/209nOW`80X:2P0P2IVIT509fMW@80W9bL0P2NWYh209bLW080XJ6Q0P2OWil2
09jNWP80WinO0P2JVYX209jNWP@0Vi^K0P2LW9`209VIV@80WIfM0P2KVi/00`2IVIT0Ti>C09>CT`02
0;fm_@80Zj^[0P2FUYH209RHV0@0WIfM0P2NWYh209ZJVP80WinO0P2MWId40:6QX@80X:2P0P2RXZ80
0`2OWil0Y:BT0:BTY0040:6QX@80Y:BT0P2SXj<20:2PX080VYZJ0P2?Shl2096AT@80SXj>0P2TY:@2
0:NWY`80^k^k0P2FUYH20:FUY@0309ZJVP2HV9P0V9RH0080[Jf]0P2>SXh20:2PX0@0]KFe0P2i^KTE
0?ooo`004`3oool20;>c/`80/[:b0P2i^KT20;Bd]080^;Rh0P2b/[820;Jf]P80/[:b00<0^[Zj0;:b
/P2b/[800P2g]kL20;Fe]@80/[:b0P2i^KT20;Rh^080]KFe0P2k^k/20;no_`80]kNg0P2ZZZX20:BT
Y0@0Xj>S0P2RXZ800`2KVi/0Zj^[0:^[Z`020;Vi^@80WIfM0P2NWYh20::RXP@0WYjN0P2HV9P209BD
U080UiNG0P2EUID209JFUP80VYZJ0P2DU9@208f=S@<0Ti>C0P2>SXh209>CT`80U9BD0P2@T90209^K
V`80W9bL0P2MWId209jNWP80WIfM0P2NWYh20::RXP80VIVI0P2EUID208n?S`0309RHV02?Shl0Shn?
0080VIVI0P2@T90409JFUP80UiNG102KVi/209ZJVP80Vi^K0P2OWil20:2PX080VIVI1@2MWId209bL
W080WYjN0P2LW9`20:6QX@80WinO0P2NWYh209nOW`80VYZJ0P2NWYh409^KV`80W9bL0P2IVIT209fM
W@80Vi^K00<0VIVI09>CT`2CTi<00P2m_Kd20:^[Z`80UYJF0P2HV9P409fMW@80WYjN0P2JVYX209nO
W`80WIfM102QXJ420:2PX080XZ:R00<0WinO0:BTY02TY:@0102QXJ420:BTY080Xj>S0P2PX:0209ZJ
VP80Shn?0P2ATI4208j>SP80Y:BT0P2WYjL20;^k^`80UYJF0P2UYJD00`2JVYX0V9RH09RHV0020:f]
[@80SXj>0P2PX:040;Fe]@80^KVi5@3oool001<0oooo0P2c/k<20;6a/@80][Jf0P2g]kL20;Zj^P80
/;2`0P2l_;`20;:b/P030;Ng]`2b/[80/[:b0080^KVi0P2_[jl20;Jf]P80^KVi0P2d];@20;Ng]`@0
^KVi0P2k^k/20;fm_@80[Jf]0P2XZ:P20:VYZ@80YjNW00<0Z:RX0:2PX02PX:000P2g]kL20;2`/080
Shn?0P2;Rh/20:2PX080WinO0P2JVYX209RHV0@0UIFE0P2DU9@2096AT@@0T92@00<0S8b<092@T02@
T9000P2@T90208j>SP80Ti>C0P2<S8`209NGU`80VIVI0P2MWId409nOW`80WYjN0P2SXj<209^KV`80
WYjN0P2?Shl00`2CTi<0T92@092@T00209BDU080T92@102CTi<208f=S@80Ti>C0P2DU9@209NGU`80
UIFE0P2KVi/209ZJVPH0UiNG00<0V9RH09ZJVP2JVYX00P2HV9P209VIV@80VYZJ0P2KVi/209ZJVP80
Vi^K0P2JVYX809NGU`80V9RH0P2EUID209RHV00309ZJVP2ATI40TI6A0080UIFE0P2`/;020;:b/P80
VIVI0P2JVYX209^KV`80W9bL0P2IVIT209fMW@80Vi^K0P2PX:020::RXP80WinO0P2RXZ800`2PX:00
YjNW0:NWY`0209jNWP80XZ:R0P2PX:020:6QX@80T92@0P2?Shl208Z:RP80Ph>30P2<S8`20:VYZ@80
UIFE0P2UYJD209JFUP<0VYZJ0P2PX:0209nOW`80QhN70P2[Zj/20;Jf]P80/;2`0P2i^KTE0?ooo`00
4`3oool20;>c/`80/K6a0P2f][H20;Ng]`80^[Zj0P2`/;020;bl_080/[:b00<0]kNg0;:b/P2b/[80
0P2i^KT20:n_[`80][Jf0P2i^KT20;Bd]080]kNg102i^KT20;^k^`80_Kfm0P2][Jd20:RXZ080ZJVY
0P2WYjL00`2XZ:P0X:2P0:2PX0020;Ng]`80/;2`0P2?Shl208^;R`80X:2P0P2OWil209ZJVP80V9RH
102EUID209BDU080TI6A102@T9000`2<S8`0T92@092@T002092@T080SXj>0P2CTi<208b<S080UiNG
0P2IVIT209fMW@@0WinO0P2NWYh20:>SX`80Vi^K0P2NWYh208n?S`0309>CT`2@T900T92@0080U9BD
0P2@T90409>CT`80SHf=0P2CTi<209BDU080UiNG0P2EUID209^KV`80VYZJ1P2GUiL00`2HV9P0VYZJ
09ZJVP0209RHV080VIVI0P2JVYX209^KV`80VYZJ0P2KVi/209ZJVPP0UiNG0P2HV9P209FEU@80V9RH
00<0VYZJ096AT@2ATI400P2EUID20;2`/080/[:b0P2IVIT209ZJVP80Vi^K0P2LW9`209VIV@80WIfM
0P2KVi/20:2PX080XZ:R0P2OWil20::RXP030:2PX02WYjL0YjNW0080WYjN0P2RXZ820:2PX080XJ6Q
0P2@T90208n?S`80RXZ:0P23Ph<208b<S080ZJVY0P2EUID20:FUY@80UYJF0`2JVYX20:2PX080WinO
0P27QhL20:^[Z`80][Jf0P2`/;020;Vi^AD0oooo000C0?ooo`@0/k>c0P2f][H20;Bd]080]kNg0P2e
]KD20;^k^`80/[:b00<0^KVi0;Fe]@2e]KD0102e]KD20;Bd]080/;2`0P2g]kL20;Fe]@80]kNg0P2i
^KT20;^k^`80]KFe0P2k^k/20;2`/080/k>c0P2a/K430;:b/P80[:b/0P2m_Kd20<S8b080QHF50P2J
VYX209^KV`80WYjN0P2GUiL409FEU@80U9BD0P2GUiL208n?S`80Rh^;0`2CTi<209FEU@80UiNG0P2F
UYH4092@T080V9RH0P2JVYX409nOW`80WYjN0P2SXj<209nOW`80XJ6Q0P2GUiL00`2BTY80UIFE09FE
U@0209FEU@80T92@0P2GUiL209BDU080Ti>C0P2BTY8208j>SP80T92@0P2=SHd208^;R`80T92@0P2;
Rh/208f=S@80SXj>00<0Rh^;092@T02@T9000P29RHT208n?S`80TI6A0P2<S8`408n?S`80TY:B102>
SXh2092@T0@0Ti>C0P2DU9@209:BTP0309RHV02BTY80TY:B0080Rh^;0P2ATI420:FUY@80WYjN0P2F
UYH208J6QP80QhN70P2BTY8209NGU`80UYJF0P2LW9`209jNWP@0WIfM00<0XZ:R0:FUY@2UYJD00P2R
XZ8209nOW`80TY:B0P25QHD209:BTP80Ph>30P2:RXX20861P@80SHf=0P2RXZ820:2PX080S8b<0P2A
TI4209bLW00309NGU`2RXZ80XZ:R0080Vi^K0P2@T9020:ZZZP80][Jf102c/k<E0?ooo`004`3oool2
0;Ng]`80];Bd0P2j^[X20;>c/`80][Jf0P2i^KT20;bl_080][Jf00<0];Bd0;Fe]@2e]KD00P2b/[82
0;Rh^080]KFe0P2d];@20:n_[`80^k^k0P2b/[820;Fe]@80_;bl0P2`/;020;bl_080/[:b0P2k^k/2
0;Fe]@030;:b/P2i^KT0^KVi0080^KVi102e]KD20<[:bP80WYjN0P2>SXh208n?S`80WinO0P2BTY82
092@T080UiNG0P2BTY8209FEU@80Rh^;00<0Shn?08j>SP2>SXh00P2ATI4209NGU`80VYZJ0P2GUiL2
08j>SP80U9BD0P2IVIT209fMW@80X:2P102OWil20:2PX0@0WYjN00<0TY:B09BDU02DU9@00P2KVi/2
09BDU080V9RH0P2GUiL209VIV@80Vi^K0P2FUYH209RHV080U9BD0P2BTY8209>CT`80S8b<0P2?Shl2
092@T00308j>SP2@T900T92@0080S8b<0P2@T90208j>SP80Shn?0P2BTY82096AT@80TY:B0P2ATI42
09:BTP80T92@0P2HV9P2096AT@@0V9RH00<0VIVI09FEU@2EUID00P2DU9@209VIV@80R8R80P2JVYX2
0:VYZ@80WinO0P25QHD206IVIP80M7Ad0P2>SXh209:BTP@0V9RH0P2KVi/00`2GUiL0PX:208:2PP02
07YjNP80N7Qh0P26QXH207QhN080Ph>30P2?Shl2092@T080S8b<0P29RHT209NGU`80VYZJ0P2KVi/2
09>CT`80QhN700<0ZZZZ09nOW`2OWil00P28R8P20::RXP80YjNW0P2c/k<20;Ng]`80][Jf5@3oool0
01<0oooo0P2g]kL20;Bd]080^[Zj0P2c/k<20;Jf]P80^KVi0P2l_;`20;Jf]P030;Bd]02e]KD0]KFe
0080/[:b0P2h^;P20;Fe]@80];Bd0P2_[jl20;^k^`80/[:b0P2e]KD20;bl_080/;2`0P2l_;`20;:b
/P80^k^k0P2e]KD00`2b/[80^KVi0;Vi^@020;Vi^@@0]KFe0P3:b/X209jNWP80SXj>0P2?Shl209nO
W`80TY:B0P2@T90209NGU`80TY:B0P2EUID208^;R`0308n?S`2>SXh0SXj>0080TI6A0P2GUiL209ZJ
VP80UiNG0P2>SXh209BDU080VIVI0P2MWId20:2PX0@0WinO0P2PX:0409jNWP0309:BTP2DU9@0U9BD
0080Vi^K0P2DU9@209RHV080UiNG0P2IVIT209^KV`80UYJF0P2HV9P209BDU080TY:B0P2CTi<208b<
S080Shn?0P2@T9000`2>SXh0T92@092@T00208b<S080T92@0P2>SXh208n?S`80TY:B0P2ATI4209:B
TP80TI6A0P2BTY82092@T080V9RH0P2ATI4409RHV00309VIV@2EUID0UIFE0080U9BD0P2IVIT208R8
R080VYZJ0P2YZJT209nOW`80QHF50P1VIVH207AdM080SXj>0P2BTY8409RHV080Vi^K00<0UiNG08:2
PP22PX800P1jNWX207QhN080QXJ60P1hN7P208>3P`80Shn?0P2@T90208b<S080RHV90P2GUiL209ZJ
VP80Vi^K0P2CTi<208N7Q`030:ZZZP2OWil0WinO0080R8R80P2RXZ820:NWY`80/k>c0P2g]kL20;Jf
]QD0oooo000C0?ooo`80]KFe0P2g]kL20;:b/P80^k^k0P2a/K420;Ng]`80]KFe0P2h^;P00`2e]KD0
]kNg0;Ng]`020;Fe]@80/k>c0P2e]KD20;Jf]P80];Bd0P2j^[X20;Fe]@80/;2`0P2l_;`20;:b/P80
^k^k0P2c/k<20;^k^`80]KFe00<0/[:b0;Vi^@2i^KT00P2d];@20;Rh^080/K6a0P2j^[X20;bl_080
UIFE0P1bLW8209JFUP80T92@0P28R8P209BDU080UIFE0P2GUiL309:BTP80RXZ:0P2?Shl209BDU080
UYJF0P2GUiL208n?S`80TY:B0P2KVi/209RHV080WYjN0P2LW9`20:6QX@80X:2P0P2MWId209nOW`03
09RHV02FUYH0UYJF00@0UiNG0P2MWId209NGU`@0Vi^K0P2MWId209JFUP80VIVI0P2EUID409ZJVP80
UIFE0P2IVIT309>CT`80TY:B0P2HV9P209NGU`80U9BD0P2GUiL209BDU0H0UYJF0P2KVi/209nOW`80
TY:B0P2JVYX209RHV00309bLW02DU9@0U9BD0080WIfM0P2IVIT209RHV080UIFE0P2GUiL209bLW080
XZ:R0P2m_Kd205eMG@80VIVI0P1nOWh207alO080Q8B40P21PH400`1mOGd0OWin07inOP0206m_K`80
Jf][0P1^KVh2079bLP80PX:20P2@T902096AT@80QXJ60P2OWil209>CT`80T92@0P2FUYH209RHV080
RXZ:00<0Y:BT0:RXZ02XZ:P00P2<S8`20::RXP80YjNW0P2`/;020;6a/@80^;Rh5@3oool001<0oooo
0P2e]KD20;Ng]`80/[:b0P2k^k/20;6a/@80]kNg0P2e]KD20;Rh^0030;Fe]@2g]kL0]kNg0080]KFe
0P2c/k<20;Fe]@80][Jf0P2d];@20;Zj^P80]KFe0P2`/;020;bl_080/[:b0P2k^k/20;>c/`80^k^k
0P2e]KD00`2b/[80^KVi0;Vi^@020;Bd]080^;Rh0P2a/K420;Zj^P80_;bl0P2EUID2079bLP80UYJF
0P2@T90208R8R080U9BD0P2EUID209NGU`<0TY:B0P2:RXX208n?S`80U9BD0P2FUYH209NGU`80Shn?
0P2BTY8209^KV`80V9RH0P2NWYh209bLW080XJ6Q0P2PX:0209fMW@80WinO00<0V9RH09JFUP2FUYH0
102GUiL209fMW@80UiNG102KVi/209fMW@80UYJF0P2IVIT209FEU@@0VYZJ0P2EUID209VIV@<0Ti>C
0P2BTY8209RHV080UiNG0P2DU9@209NGU`80U9BD1P2FUYH209^KV`80WinO0P2BTY8209ZJVP80V9RH
00<0W9bL09BDU02DU9@00P2MWId209VIV@80V9RH0P2EUID209NGU`80W9bL0P2RXZ820;fm_@80GEeM
0P2IVIT207inOP80O7al0P24Q8@20861P@0307emO@1nOWh0OWin0080Kfm_0P1[Jf/206i^KP80LW9b
0P22PX82092@T080TI6A0P26QXH209nOW`80Ti>C0P2@T90209JFUP80V9RH0P2:RXX00`2TY:@0Z:RX
0:RXZ00208b<S080XZ:R0P2WYjL20;2`/080/K6a0P2h^;PE0?ooo`004`3oool20;Jf]P80]KFe0P2a
/K420;Vi^@80]KFe0P2f][H40;Fe]@<0/k>c0P2j^[X20;Bd]080/k>c0P2i^KT20;Rh^080]kNg0P2d
];@20;>c/`80^KVi0P2e]KD20;Rh^080]KFe0P2l_;`20;Jf]P030;Ng]`2e]KD0]KFe0080/;2`0P2h
^;P20;:b/P80]KFe0P2o_kl20::RXP80PH610P23Ph<208F5Q@80Ogmo0P27QhL409BDU080TY:B00<0
UIFE08b<S02<S8`00P2@T90209:BTP80Ti>C0P2HV9P4096AT@80VYZJ0P2KVi/409ZJVP80WIfM0P2N
WYh209fMW@80X:2P00<0WIfM09RHV02HV9P00P2DU9@209RHV0X0Vi^K0P2MWId209^KV`80TY:B0P2F
UYH209NGU`80V9RH0P2MWId00`2IVIT0UYJF09JFUP0209FEU@80Ti>C0P2FUYH209RHV080UiNG0P2I
VIT209RHV080TY:B1P2KVi/409ZJVP80U9BD00<0W9bL09BDU02DU9@00P2IVIT209NGU`80Vi^K0P2M
WId209FEU@80VYZJ0P2EUID209VIV@80UIFE0P2^[Zh20:2PX080SXj>0P1YJFT206MWI`0306YZJP1W
IfL0IfMW0080LG5a0P1^KVh206m_K`80NWYj0P1bLW8208R8R080Rh^;0P1jNWX20:JVYP80R8R80P2=
SHd209^KV`80Ng]k0P2IVIT00`2[Zj/0RXZ:08Z:RP020;Fe]@80VIVI0P2d];@20:n_[`80/k>c0P2_
[jlE0?ooo`004`3oool20;Jf]P80]KFe0P2a/K420;Vi^@80]KFe0P2f][H40;Fe]@<0/k>c0P2j^[X2
0;Bd]080/k>c0P2i^KT20;Rh^080]kNg0P2d];@20;>c/`80^KVi0P2e]KD20;Rh^080]KFe0P2l_;`2
0;Jf]P030;Ng]`2e]KD0]KFe0080/;2`0P2h^;P20;:b/P80]KFe0P2o_kl20::RXP80PH610P23Ph<2
08F5Q@80Ogmo0P27QhL409BDU080TY:B00<0UIFE08b<S02<S8`00P2@T90209:BTP80Ti>C0P2HV9P4
096AT@80VYZJ0P2KVi/409ZJVP80WIfM0P2NWYh209fMW@80X:2P00<0WIfM09RHV02HV9P00P2DU9@2
09RHV0X0Vi^K0P2MWId209^KV`80TY:B0P2FUYH209NGU`80V9RH0P2MWId00`2IVIT0UYJF09JFUP02
09FEU@80Ti>C0P2FUYH209RHV080UiNG0P2IVIT209RHV080TY:B1P2KVi/409ZJVP80U9BD00<0W9bL
09BDU02DU9@00P2IVIT209NGU`80Vi^K0P2MWId209FEU@80VYZJ0P2EUID209VIV@80UIFE0P2^[Zh2
0:2PX080SXj>0P1YJFT206MWI`0306YZJP1WIfL0IfMW0080LG5a0P1^KVh206m_K`80NWYj0P1bLW82
08R8R080Rh^;0P1jNWX20:JVYP80R8R80P2=SHd209^KV`80Ng]k0P2IVIT00`2[Zj/0RXZ:08Z:RP02
0;Fe]@80VIVI0P2d];@20:n_[`80/k>c0P2_[jlE0?ooo`004`3oool20;Jf]P80^KVi0P2f][H20;Bd
]080^KVi0P2`/;020;Vi^@80^[Zj00<0]KFe0;Ng]`2g]kL00P2d];@20;Rh^080]KFe0P2l_;`20;:b
/P80^KVi0P2f][H20;Ng]`80]KFe0P2l_;`20;6a/@80]kNg102i^KT00`2j^[X0/k>c0;>c/`040;Bd
]080/K6a0P2f][H20;bl_080WIfM0P2SXj<207QhN080PH610P1nOWh205eMG@80NGUi0P2BTY82092@
T00309JFUP2;Rh/0Rh^;0080Ti>C0P2DU9@208n?S`80U9BD0P2BTY82096AT@@0Vi^K0P2JVYX209^K
V`80VYZJ0P2PX:0209VIV@80WYjN00<0Vi^K09fMW@2MWId00P2IVIT209NGU`h0Vi^K0P2MWId209>C
T`80UYJF0P2DU9@209ZJVP0309NGU`2KVi/0Vi^K0080UYJF102EUID209>CT`80U9BD0P2GUiL209ZJ
VP80TI6A202KVi/209FEU@80UiNG00<0W9bL09>CT`2CTi<00P2JVYX209>CT`80Vi^K0P2IVIT209NG
U`80VIVI0P2EUID209:BTP80R8R80P29RHT207emO@80LW9b0P22PX8206=SH`0305iNGP1ZJVX0JVYZ
0080K6a/0P1`L70207IfMP80N7Qh101mOGd208J6QP80PH610P2XZ:P207moO`80Q8B40P2KVi/20820
P080VYZJ00<0YJFU08^;R`2;Rh/00P2b/[820:j^[P80];Bd0P2_[jl20;Ng]`80];Bd5@3oool001<0
oooo0P2f][H20;Vi^@80][Jf0P2d];@20;Vi^@80/;2`0P2i^KT20;Zj^P030;Fe]@2g]kL0]kNg0080
];Bd0P2h^;P20;Fe]@80_;bl0P2b/[820;Vi^@80][Jf0P2g]kL20;Fe]@80_;bl0P2a/K420;Ng]`@0
^KVi00<0^[Zj0;>c/`2c/k<0102d];@20;6a/@80][Jf0P2l_;`209fMW@80Xj>S0P1hN7P20861P@80
OWin0P1MGEd207UiN@80TY:B0P2@T9000`2FUYH0Rh^;08^;R`0209>CT`80U9BD0P2?Shl209BDU080
TY:B0P2ATI4409^KV`80VYZJ0P2KVi/209ZJVP80X:2P0P2IVIT209jNWP0309^KV`2MWId0WIfM0080
VIVI0P2GUiL>09^KV`80WIfM0P2CTi<209JFUP80U9BD0P2JVYX00`2GUiL0Vi^K09^KV`0209JFUP@0
UIFE0P2CTi<209BDU080UiNG0P2JVYX2096AT@P0Vi^K0P2EUID209NGU`0309bLW02CTi<0Ti>C0080
VYZJ0P2CTi<209^KV`80VIVI0P2GUiL209VIV@80UIFE0P2BTY8208R8R080RHV90P1mOGd2079bLP80
PX:20P1SHf<00`1NGUh0JVYZ06YZJP0206a/K080L71`0P1fMWH207QhN0@0OGem0P26QXH20861P@80
Z:RX0P1oOgl208B4Q080Vi^K0P20P80209ZJVP030:FUY@2;Rh/0Rh^;0080/[:b0P2^[Zh20;Bd]080
[jn_0P2g]kL20;Bd]1D0oooo000C0?ooo`80]kNg0P2d];@20;Ng]`80^KVi0P2d];@20;6a/@80^k^k
0P2a/K400`2h^;P0]KFe0;Fe]@020;bl_080/;2`0P2i^KT40;Rh^080/K6a1P2i^KT20;Rh^080];Bd
0P2e]KD20;Vi^@<0^;Rh0P2d];@20;:b/P80]KFe0P2f][H20;Bd]080_Kfm0P2XZ:P20:j^[P80Shn?
0P1`L70207inOP80IVIV0P15ADD206YZJP80TY:B1@2?Shl208b<S0@0U9BD0P2@T90209:BTPP0Vi^K
0P2IVIT209jNWPL0Vi^K0P2JVYX609NGU`80V9RH0P2JVYX209RHV0@0Vi^K0P2LW9`409JFUP80U9BD
0P2JVYX00`2EUID0TY:B09:BTP0209VIV@80UIFE0P2CTi<609JFUP80U9BD0P2CTi<209RHV080VYZJ
0P2GUiL209^KV`80TI6A0P2KVi/00`2LW9`0UIFE09FEU@0209FEU@80U9BD0P2GUiL209VIV@@0TY:B
0P2>SXh208f=S@80PX:20P1aLG4206a/K080JFUY0P1VIVH2075aL@03079bLP1^KVh0KVi^0080IFEU
0P1cLg<207EeM@@0Ng]k0P29RHT208^;R`80QhN70P2CTi<20861P@80QHF50P2DU9@208R8R080XJ6Q
00<0V9RH09VIV@2IVIT0102`/;020;Vi^@80Zj^[0P2g]kL20;Rh^1D0oooo000C0?ooo`80]kNg0P2d
];@20;Ng]`80^KVi0P2d];@20;6a/@80^k^k0P2a/K400`2h^;P0]KFe0;Fe]@020;bl_080/;2`0P2i
^KT40;Rh^080/K6a1P2i^KT20;Rh^080];Bd0P2e]KD20;Vi^@<0^;Rh0P2d];@20;:b/P80]KFe0P2f
][H20;Bd]080_Kfm0P2XZ:P20:j^[P80Shn?0P1`L70207inOP80IVIV0P15ADD206YZJP80TY:B1@2?
Shl208b<S0@0U9BD0P2@T90209:BTPP0Vi^K0P2IVIT209jNWPL0Vi^K0P2JVYX609NGU`80V9RH0P2J
VYX209RHV0@0Vi^K0P2LW9`409JFUP80U9BD0P2JVYX00`2EUID0TY:B09:BTP0209VIV@80UIFE0P2C
Ti<609JFUP80U9BD0P2CTi<209RHV080VYZJ0P2GUiL209^KV`80TI6A0P2KVi/00`2LW9`0UIFE09FE
U@0209FEU@80U9BD0P2GUiL209VIV@@0TY:B0P2>SXh208f=S@80PX:20P1aLG4206a/K080JFUY0P1V
IVH2075aL@03079bLP1^KVh0KVi^0080IFEU0P1cLg<207EeM@@0Ng]k0P29RHT208^;R`80QhN70P2C
Ti<20861P@80QHF50P2DU9@208R8R080XJ6Q00<0V9RH09VIV@2IVIT0102`/;020;Vi^@80Zj^[0P2g
]kL20;Rh^1D0oooo000C0?ooo`80][Jf0P2h^;P60;Jf]P80/;2`0P2l_;`20;Bd]0030;bl_02_[jl0
[jn_0080_;bl0P2b/[820;Vi^@80];Bd0P2i^KT20;Bd]080^KVi0P2f][H20;Vi^@80/k>c0P2b/[84
0;Rh^080];Bd00<0^KVi0;Fe]@2e]KD00P2e]KD20;:b/P80^KVi0P2c/k<20;Ng]`80Xj>S0P2b/[82
09jNWP80KFe]0P1aLG4206=SH`80E5AD0P0`<30206YZJP0308B4Q02ATI40TI6A0080S8b<0P2>SXh2
092@T080Ti>C102ATI4209RHV0H0Vi^K102IVIT709^KV`80WIfM0P2IVIT209RHV080UiNG0P2FUYH2
09ZJVP80U9BD0P2HV9P209^KV`80WIfM0P2IVIT209NGU`80Ti>C0P2DU9@00`2GUiL0UIFE09FEU@02
09FEU@@0U9BD0P2EUID409BDU080Ti>C0P2DU9@209>CT`80WIfM0P2EUID209RHV080Ti>C0P2GUiL0
0`2MWId0VIVI09VIV@0209BDU080UIFE102DU9@208b<S080TI6A1026QXH207MgM`80Jf][0P1VIVH2
06MWI`80JFUY0P1_Kfl00`1fMWH0Ng]k07]kN`02079bLP80JFUY0P1iNGT207QhN080OGem0P25QHD2
07moO`80SXj>0P2?Shl208N7Q`80T92@0P29RHT209bLW080TY:B00<0UYJF0::RXP2RXZ800P2e]KD2
0;>c/`80/[:b0P2c/k<20;Bd]080^KVi5@3oool001<0oooo0P2f][H20;Rh^0H0][Jf0P2`/;020;bl
_080];Bd00<0_;bl0:n_[`2_[jl00P2l_;`20;:b/P80^KVi0P2d];@20;Vi^@80];Bd0P2i^KT20;Jf
]P80^KVi0P2c/k<20;:b/P@0^;Rh0P2d];@00`2i^KT0]KFe0;Fe]@020;Fe]@80/[:b0P2i^KT20;>c
/`80]kNg0P2SXj<20;:b/P80WYjN0P1]KFd2075aL@80Hf=S0P1DE5@2030`<080JVYZ00<0Q8B4096A
T@2ATI400P2<S8`208j>SP80T92@0P2CTi<4096AT@80V9RH1P2KVi/409VIV@L0Vi^K0P2MWId209VI
V@80V9RH0P2GUiL209JFUP80VYZJ0P2DU9@209RHV080Vi^K0P2MWId209VIV@80UiNG0P2CTi<209BD
U00309NGU`2EUID0UIFE0080UIFE102DU9@209FEU@@0U9BD0P2CTi<209BDU080Ti>C0P2MWId209FE
U@80V9RH0P2CTi<209NGU`0309fMW@2IVIT0VIVI0080U9BD0P2EUID409BDU080S8b<0P2ATI4408J6
QP80MgMg0P1[Jf/206IVIP80IfMW0P1YJFT206m_K`0307IfMP1kNg/0Ng]k0080LW9b0P1YJFT207Ui
N@80N7Qh0P1mOGd208F5Q@80Ogmo0P2>SXh208n?S`80QhN70P2@T90208V9R@80W9bL0P2BTY800`2F
UYH0XZ:R0::RXP020;Fe]@80/k>c0P2b/[820;>c/`80];Bd0P2i^KTE0?ooo`004`3oool20;Bd]080
/k>c0P2b/[820;Rh^080][Jf0P2_[jl20;Rh^080]KFe00<0^;Rh0;2`/02`/;000P2k^k/20;Rh^080
/k>c0P2i^KT20;>c/`80][Jf0P2i^KT20;Ng]`80/[:b0P2h^;P20;:b/P80^[Zj0P2b/[820;Rh^003
0;Fe]@2d];@0];Bd0080^;Rh102g]kL20;:b/P80^k^k0P2NWYh20;Vi^@80ZJVY0P1kNg/206][J`80
J6QX0P1CDe<203lo?`80:BTY00<0Hf=S08Z:RP2:RXX00P27QhL2096AT@80SHf=0P2FUYH2092@T080
TY:B0P2FUYH609^KV`80WIfM0P2FUYH209NGU`80V9RH00<0Vi^K09ZJVP2JVYX0102GUiL209ZJVP80
Ti>C0P2GUiL209FEU@@0UiNG0P2KVi/209ZJVP80UiNG0P2LW9`209BDU080TI6A1@2CTi<209NGU`80
Ti>C0P2FUYH209BDU0@0T92@0P2EUID2092@T080VYZJ0P2DU9@209ZJVP80UiNG0P2BTY800`2GUiL0
UIFE09FEU@0208f=S@80S8b<0P29RHT208>3P`80QXJ60P22PX8207inOP80HV9R0P1IFET206=SH`80
I6AT0P1eMGD206][J`80I6AT00<0LG5a08>3P`23Ph<00P22PX8207]kN`80Lg=c0P1lO7`2071`L080
PX:20P1nOWh208R8R080PH610P2CTi<209FEU@80UYJF0P2[Zj/208b<S00309BDU02`/;00/;2`0080
[Zj^0P2e]KD20;2`/080];Bd0P2_[jl20;^k^aD0oooo000C0?ooo`80];Bd0P2c/k<20;:b/P80^;Rh
0P2f][H20:n_[`80^;Rh0P2e]KD00`2h^;P0/;2`0;2`/0020;^k^`80^;Rh0P2c/k<20;Vi^@80/k>c
0P2f][H20;Vi^@80]kNg0P2b/[820;Rh^080/[:b0P2j^[X20;:b/P80^;Rh00<0]KFe0;Bd]02d];@0
0P2h^;P40;Ng]`80/[:b0P2k^k/209jNWP80^KVi0P2YZJT207]kN`80Jf][0P1XJ6P205=CD`80?clo
0P0Y:BT00`1SHf<0RXZ:08Z:RP0208N7Q`80TI6A0P2=SHd209JFUP80T92@0P2BTY8209JFUPH0Vi^K
0P2MWId209JFUP80UiNG0P2HV9P00`2KVi/0VYZJ09ZJVP0409NGU`80VYZJ0P2CTi<209NGU`80UIFE
102GUiL209^KV`80VYZJ0P2GUiL209bLW080U9BD0P2ATI4509>CT`80UiNG0P2CTi<209JFUP80U9BD
102@T90209FEU@80T92@0P2JVYX209BDU080VYZJ0P2GUiL209:BTP0309NGU`2EUID0UIFE0080SHf=
0P2<S8`208V9R@80Ph>30P26QXH208:2PP80OWin0P1RHV8205UIF@80Hf=S0P1TI6@207EeM@80Jf][
0P1TI6@00`1aLG40Ph>308>3P`0208:2PP80Ng]k0P1cLg<207alO080L71`0P22PX8207inOP80R8R8
0P21PH4209>CT`80UIFE0P2FUYH20:^[Z`80S8b<00<0U9BD0;2`/02`/;000P2^[Zh20;Fe]@80/;2`
0P2d];@20:n_[`80^k^k5@3oool001<0oooo102c/k<20;Ng]`@0];Bd0P2c/k<20;Vi^@80/[:b00<0
][Jf0;:b/P2b/[80102g]kL20;^k^`80/[:b0P2k^k/20;Fe]@80];Bd0P2l_;`20;:b/P80^k^k0P2f
][H20;6a/@80^KVi0P2f][H00`2b/[80^;Rh0;Rh^0020;2`/080^KVi0P2e]KD20;Jf]P80^;Rh0P2/
[:`20;Bd]080WYjN0P2>SXh206QXJ080IFEU0P1CDe<204I6AP80>3Ph00<09BDU06=SH`1SHf<00P29
RHT2092@T080QXJ6102CTi<208j>SP80V9RH0P2JVYX609NGU`80Vi^K0P2HV9P209BDU00309RHV02L
W9`0W9bL0080UYJF0P2GUiL409RHV0H0TY:B102GUiL209ZJVP80V9RH0P2EUID409>CT`03092@T02C
Ti<0Ti>C0080SHf=0P2BTY8209>CT`80UIFE0P2?Shl209BDU080R8R80P2?Shl208j>SP80U9BD0P2C
Ti<2096AT@80TY:B0P2?Shl309BDU080RHV90P28R8P208F5Q@80O7al0P1eMGD206][J`80Fe]K0P1L
G5`205MGE`80DU9B0P1XJ6P207alO080Ogmo0P1VIVH00`1iNGT0N7Qh07QhN00208B4Q080P8200P28
R8P207UiN@80Lg=c0P1iNGT207inOP80RHV90P23Ph<209BDU080R8R80P2ZZZX209JFUP80VYZJ00<0
YJFU0:j^[P2^[Zh00P2ZZZX20:b/[0@0]KFe0P2`/;020;^k^aD0oooo000C0?ooo`@0/k>c0P2g]kL4
0;Bd]080/k>c0P2i^KT20;:b/P030;Jf]P2b/[80/[:b00@0]kNg0P2k^k/20;:b/P80^k^k0P2e]KD2
0;Bd]080_;bl0P2b/[820;^k^`80][Jf0P2a/K420;Vi^@80][Jf00<0/[:b0;Rh^02h^;P00P2`/;02
0;Vi^@80]KFe0P2f][H20;Rh^080[:b/0P2d];@209jNWP80SXj>0P1XJ6P206EUI@80De=C0P16ATH2
03Ph>00302DU9@1SHf<0Hf=S0080RHV90P2@T90208J6QP@0Ti>C0P2>SXh209RHV080VYZJ1P2GUiL2
09^KV`80V9RH0P2DU9@00`2HV9P0W9bL09bLW00209JFUP80UiNG102HV9P609:BTP@0UiNG0P2JVYX2
09RHV080UIFE102CTi<00`2@T900Ti>C09>CT`0208f=S@80TY:B0P2CTi<209FEU@80Shn?0P2DU9@2
08R8R080Shn?0P2>SXh209BDU080Ti>C0P2ATI4209:BTP80Shn?0`2DU9@208V9R@80R8R80P25QHD2
07alO080MGEe0P1[Jf/205]KF`80G5aL0P1GEeL2059BDP80J6QX0P1lO7`207moO`80IVIV00<0NGUi
07QhN01hN7P00P24Q8@20820P080R8R80P1iNGT207=cL`80NGUi0P1nOWh208V9R@80Ph>30P2DU9@2
08R8R080ZZZZ0P2FUYH209ZJVP030:FUY@2^[Zh0[Zj^0080ZZZZ0P2/[:`40;Fe]@80/;2`0P2k^k/E
0?ooo`004`3oool20;>c/`80[jn_0P2g]kL20;Rh^080];Bd0P2k^k/20;>c/`80][Jf00<0]KFe0;^k
^`2k^k/00P2d];@20;:b/P80^k^k0P2c/k<20;Rh^080/[:b0P2g]kL20;Rh^080/[:b0P2k^k/20;Rh
^080]kNg0P2b/[820;Vi^@030;Rh^02d];@0];Bd0080/K6a0P2e]KD20;Bd]080][Jf0P2_[jl20;Bd
]080Xj>S0P2OWil207moO`80KFe]0P1QHF42051@D080Bd];0P12@T800`0c<c<05aLG01LG5`0205QH
F080SXj>0P24Q8@2092@T080SXj>0P2ATI4209>CT`80VIVI1P2FUYH209BDU080W9bL0P2GUiL00`2F
UYH0VYZJ09ZJVP0209JFUP80U9BD0P2IVIT209FEU@80V9RH0P2CTi<2096AT@80Ti>C0P2EUID2092@
T080VYZJ0P2GUiL209BDU080TI6A00<0TY:B092@T02@T9000P2@T90208b<S080RXZ:0P2ATI42092@
T080Shn?0P2=SHd208j>SP80Rh^;0P2@T90209FEU@80QhN70P2DU9@208R8R00308j>SP2=SHd0SHf=
0080Rh^;0P23Ph<207moO`80Kfm_0P1UIFD205mOG`80GEeM0P1BDU82061PH080Hf=S0P1`L70207Ad
M080N7Qh0P1cLg<00`1lO7`0Lg=c07=cL`0207EeM@@0MWIf0P24Q8@207emO@80Ng]k0P24Q8@208J6
QP80Rh^;0P2DU9@409JFUP80XJ6Q0P2SXj<00`2[Zj/0/k>c0;>c/`020:b/[080[Zj^0P2g]kL20;Rh
^080];Bd0P2i^KTE0?ooo`004`3oool20;>c/`80[jn_0P2g]kL20;Rh^080];Bd0P2k^k/20;>c/`80
][Jf00<0]KFe0;^k^`2k^k/00P2d];@20;:b/P80^k^k0P2c/k<20;Rh^080/[:b0P2g]kL20;Rh^080
/[:b0P2k^k/20;Rh^080]kNg0P2b/[820;Vi^@030;Rh^02d];@0];Bd0080/K6a0P2e]KD20;Bd]080
][Jf0P2_[jl20;Bd]080Xj>S0P2OWil207moO`80KFe]0P1QHF42051@D080Bd];0P12@T800`0c<c<0
5aLG01LG5`0205QHF080SXj>0P24Q8@2092@T080SXj>0P2ATI4209>CT`80VIVI1P2FUYH209BDU080
W9bL0P2GUiL00`2FUYH0VYZJ09ZJVP0209JFUP80U9BD0P2IVIT209FEU@80V9RH0P2CTi<2096AT@80
Ti>C0P2EUID2092@T080VYZJ0P2GUiL209BDU080TI6A00<0TY:B092@T02@T9000P2@T90208b<S080
RXZ:0P2ATI42092@T080Shn?0P2=SHd208j>SP80Rh^;0P2@T90209FEU@80QhN70P2DU9@208R8R003
08j>SP2=SHd0SHf=0080Rh^;0P23Ph<207moO`80Kfm_0P1UIFD205mOG`80GEeM0P1BDU82061PH080
Hf=S0P1`L70207AdM080N7Qh0P1cLg<00`1lO7`0Lg=c07=cL`0207EeM@@0MWIf0P24Q8@207emO@80
Ng]k0P24Q8@208J6QP80Rh^;0P2DU9@409JFUP80XJ6Q0P2SXj<00`2[Zj/0/k>c0;>c/`020:b/[080
[Zj^0P2g]kL20;Rh^080];Bd0P2i^KTE0?ooo`004`3oool20;>c/`80];Bd0P2b/[820;Ng]`80^KVi
0P2m_Kd20;:b/P80][Jf00<0]kNg0;bl_02l_;`00P2g]kL20;:b/P80^;Rh0P2b/[820;Ng]`80];Bd
0P2h^;P20;Ng]`80];Bd0P2g]kL20;Jf]P80^KVi0P2e]KD20;>c/`030;bl_02e]KD0]KFe00@0];Bd
0P2e]KD20;Ng]`80/k>c0P2e]KD209bLW080ZZZZ0P1dM7@206i^KP80I6AT0P1?Cdl204Q8B080A4A4
00<0<30`02`/;00/;2`00P0D51@205IFEP80Rh^;0P2:RXX209:BTP80Shn?0P2EUID209BDU0H0UYJF
0P2DU9@209^KV`80UiNG00<0W9bL09JFUP2FUYH0102FUYH209NGU`80U9BD0P2FUYH209NGU`80Ti>C
0P2BTY8209FEU@80T92@102DU9@209>CT`80TY:B00<0TI6A08n?S`2?Shl00P2BTY8208f=S@80RXZ:
0P29RHT208n?S`80R8R80P25QHD208n?S`80R8R8102@T90208V9R@80QXJ60P2>SXh00`26QXH0Q8B4
08B4Q00208J6QP80N7Qh101SHf<204U9B@80E5AD0P1NGUh205mOG`80Hf=S0P1aLG4207IfMP80M7Ad
0P1bLW8207IfMP0308>3P`20P800P8200080NWYj0P1gMgL208:2PP80N7Qh0P25QHD208N7Q`80RHV9
0P27QhL209>CT`80UIFE102DU9@20:RXZ080[Zj^00<0ZJVY0:f][@2][Jd00P2e]KD20;Bd]080]kNg
0P2i^KT20;Ng]`80][Jf5@3oool001<0oooo0P2c/k<20;Bd]080/[:b0P2g]kL20;Vi^@80_Kfm0P2b
/[820;Jf]P030;Ng]`2l_;`0_;bl0080]kNg0P2b/[820;Rh^080/[:b0P2g]kL20;Bd]080^;Rh0P2g
]kL20;Bd]080]kNg0P2f][H20;Vi^@80]KFe0P2c/k<00`2l_;`0]KFe0;Fe]@040;Bd]080]KFe0P2g
]kL20;>c/`80]KFe0P2LW9`20:ZZZP80M7Ad0P1^KVh206ATI080Cdm?0P18B4P204A4A003030`<00/
;2`0;2`/008051@D0P1FEUH208^;R`80RXZ:0P2BTY8208n?S`80UIFE0P2DU9@609JFUP80U9BD0P2K
Vi/209NGU`0309bLW02FUYH0UYJF00@0UYJF0P2GUiL209BDU080UYJF0P2GUiL209>CT`80TY:B0P2E
UID2092@T0@0U9BD0P2CTi<209:BTP03096AT@2?Shl0Shn?0080TY:B0P2=SHd208Z:RP80RHV90P2?
Shl208R8R080QHF50P2?Shl208R8R0@0T92@0P29RHT208J6QP80SXj>00<0QXJ608B4Q024Q8@00P26
QXH207QhN0@0Hf=S0P19BDT205ADE080GUiN0P1OGel206=SH`80LG5a0P1fMWH207AdM080LW9b0P1f
MWH00`23Ph<0P8200820P00207YjNP80MgMg0P22PX8207QhN080QHF50P27QhL208V9R@80QhN70P2C
Ti<209FEU@@0U9BD0P2XZ:P20:j^[P030:VYZ@2][Jd0[Jf]0080]KFe0P2d];@20;Ng]`80^KVi0P2g
]kL20;Jf]QD0oooo000C0?ooo`80][Jf0P2b/[820;Zj^P80/[:b0P2i^KT20;Ng]`80_;bl0P2f][H0
0`2e]KD0]kNg0;Ng]`020;Rh^0@0]KFe0P2d];@20;:b/P80]KFe102g]kL20;^k^`80^;Rh0P2c/k<2
0;Fe]@80]kNg0P2b/[800`2h^;P0]KFe0;Fe]@020;Ng]`80][Jf102c/k<20;Ng]`80];Bd0P2RXZ82
0:FUY@80MgMg0P1WIfL2065QH@80F5QH0P1;Bd/203dm?@03030`<00S8b<08b<S0080;bl_0P0A4A42
08Z:RP80QhN70P2DU9@2096AT@@0U9BD0P2FUYH209RHV080UiNG0P2HV9P209BDU080UiNG00<0VYZJ
09JFUP2FUYH00P2EUID209BDU080UYJF102EUID209JFUP80Ti>C0P2BTY8209BDU080Shn?0P2ATI42
08j>SP80TY:B0`2@T90408n?S`80Rh^;0P29RHT208N7Q`@0R8R80P24Q8@208Z:RP80T92@0P21PH42
08^;R`80OWin1023Ph<00`21PH40MGEe07EeM@0407EeM@80EUIF0P1=CDd205aLG080BTY:0P1EEED2
05iNGP80IfMW0P1dM7@2071`L080Kfm_0P1iNGT207AdM0<0QHF50P23Ph<207inOP80QhN70P2;Rh/2
08F5Q@80S8b<0P2:RXX209>CT`80U9BD0P2FUYH209NGU`80XJ6Q0P2SXj<20:b/[0030:n_[`2e]KD0
]KFe0080];Bd0P2i^KT20;>c/`80^k^k0P2e]KD20;Bd]1D0oooo000C0?ooo`80][Jf0P2b/[820;Zj
^P80/[:b0P2i^KT20;Ng]`80_;bl0P2f][H00`2e]KD0]kNg0;Ng]`020;Rh^0@0]KFe0P2d];@20;:b
/P80]KFe102g]kL20;^k^`80^;Rh0P2c/k<20;Fe]@80]kNg0P2b/[800`2h^;P0]KFe0;Fe]@020;Ng
]`80][Jf102c/k<20;Ng]`80];Bd0P2RXZ820:FUY@80MgMg0P1WIfL2065QH@80F5QH0P1;Bd/203dm
?@03030`<00S8b<08b<S0080;bl_0P0A4A4208Z:RP80QhN70P2DU9@2096AT@@0U9BD0P2FUYH209RH
V080UiNG0P2HV9P209BDU080UiNG00<0VYZJ09JFUP2FUYH00P2EUID209BDU080UYJF102EUID209JF
UP80Ti>C0P2BTY8209BDU080Shn?0P2ATI4208j>SP80TY:B0`2@T90408n?S`80Rh^;0P29RHT208N7
Q`@0R8R80P24Q8@208Z:RP80T92@0P21PH4208^;R`80OWin1023Ph<00`21PH40MGEe07EeM@0407Ee
M@80EUIF0P1=CDd205aLG080BTY:0P1EEED205iNGP80IfMW0P1dM7@2071`L080Kfm_0P1iNGT207Ad
M0<0QHF50P23Ph<207inOP80QhN70P2;Rh/208F5Q@80S8b<0P2:RXX209>CT`80U9BD0P2FUYH209NG
U`80XJ6Q0P2SXj<20:b/[0030:n_[`2e]KD0]KFe0080];Bd0P2i^KT20;>c/`80^k^k0P2e]KD20;Bd
]1D0oooo000C0?ooo`@0^KVi0P2j^[X20;2`/080^;Rh0P2c/k<20;Jf]P80^KVi00<0^;Rh0;Ng]`2g
]kL00P2f][H20;6a/@80]KFe0P2l_;`20;Fe]@80];Bd102e]KD20;Ng]`80^KVi0P2d];@20;Fe]@80
^KVi0P2d];@00`2f][H0]KFe0;Fe]@020;Vi^@80^;Rh0P2d];@20;Jf]P80];Bd0P2a/K420:2PX080
UiNG0P1gMgL206e]K@80FUYJ0P1IFET2055AD@80BDU900<0=CDe030`<00`<3000P0c<c<202XZ:P80
JVYZ0P2:RXX2092@T080UIFE0P2GUiL209FEU@80TY:B0P2LW9`209BDU080VYZJ1@2FUYH209FEU@80
UiNG0P2BTY8209BDU080Ti>C0P2BTY8209NGU`80TI6A102CTi<2092@T080TI6A0P2<S8`208f=S@D0
TI6A0P2<S8`208^;R`80R8R80P21PH4207inOP80Ph>30P28R8P208V9R@80R8R80P1oOgl607alO080
OGem00<0MgMg06][J`1[Jf/00P1UIFD205YJFP80Kfm_0P1FEUH205mOG`80HF5Q0P1[Jf/206=SH`80
L71`0P1fMWH2075aL@80L71`0P1aLG4207YjNP0307EeM@1mOGd0OGem0080QXJ60P1nOWh207alO080
RHV90P25QHD208^;R`@0Ti>C0P2FUYH209FEU@80XJ6Q0P2ZZZX20:6QX@80]KFe00<0];Bd0;Jf]P2f
][H0102g]kL20;Fe]@80^[Zj0P2b/[820;Vi^AD0oooo000C0?ooo`@0^KVi0P2j^[X20;2`/080^;Rh
0P2c/k<20;Jf]P80^KVi00<0^;Rh0;Ng]`2g]kL00P2f][H20;6a/@80]KFe0P2l_;`20;Fe]@80];Bd
102e]KD20;Ng]`80^KVi0P2d];@20;Fe]@80^KVi0P2d];@00`2f][H0]KFe0;Fe]@020;Vi^@80^;Rh
0P2d];@20;Jf]P80];Bd0P2a/K420:2PX080UiNG0P1gMgL206e]K@80FUYJ0P1IFET2055AD@80BDU9
00<0=CDe030`<00`<3000P0c<c<202XZ:P80JVYZ0P2:RXX2092@T080UIFE0P2GUiL209FEU@80TY:B
0P2LW9`209BDU080VYZJ1@2FUYH209FEU@80UiNG0P2BTY8209BDU080Ti>C0P2BTY8209NGU`80TI6A
102CTi<2092@T080TI6A0P2<S8`208f=S@D0TI6A0P2<S8`208^;R`80R8R80P21PH4207inOP80Ph>3
0P28R8P208V9R@80R8R80P1oOgl607alO080OGem00<0MgMg06][J`1[Jf/00P1UIFD205YJFP80Kfm_
0P1FEUH205mOG`80HF5Q0P1[Jf/206=SH`80L71`0P1fMWH2075aL@80L71`0P1aLG4207YjNP0307Ee
M@1mOGd0OGem0080QXJ60P1nOWh207alO080RHV90P25QHD208^;R`@0Ti>C0P2FUYH209FEU@80XJ6Q
0P2ZZZX20:6QX@80]KFe00<0];Bd0;Jf]P2f][H0102g]kL20;Fe]@80^[Zj0P2b/[820;Vi^AD0oooo
000C0?ooo`80^KVi0P2k^k/20;Rh^080];Bd0P2f][H20;Fe]@80/[:b0P2j^[X00`2d];@0^k^k0;^k
^`040;Bd]080^KVi0P2k^k/20;Fe]@80^;Rh0P2b/[820;^k^`80];Bd0P2e]KD20;6a/@80^KVi0P2f
][H20;6a/@030;Ng]`2k^k/0^k^k0080/k>c0P2i^KT20;>c/`80]KFe0P2a/K420;:b/P80Y:BT0P22
PX8207AdM080JFUY0P1TI6@205QHF080D51@0P15ADD00`0m?Cd0>SXj03Xj>P0203Xj>P80;Bd]0P0Y
:BT208V9R@80U9BD0P2BTY8209bLW080U9BD0P2ATI4209VIV@80Ti>C102EUID209>CT`0309FEU@2G
UiL0UiNG0080U9BD102EUID2096AT@80T92@0P2EUID209BDU0@0T92@0P2EUID208^;R`80Ti>C102:
RXX00`2?Shl0SHf=08f=S@0208V9R@80R8R80P1oOgl208>3P`80NWYj0P1mOGd208^;R`80S8b<0P23
Ph<207MgM`80NWYj0P1lO7`206e]K@80JFUY00<0HF5Q069RHP1RHV800P1WIfL205UIF@80De=C0P1X
J6P2065QH@80Hf=S0P1TI6@206m_K`80MgMg0P1hN7P2071`L080JFUY0P1/K6`208>3P`0307QhN01l
O7`0O7al0080P8200P24Q8@208F5Q@80QXJ60P23Ph<409>CT`80U9BD0P2CTi<209ZJVP80YJFU0P2^
[Zh20:ZZZP80/k>c00<0^k^k0;Bd]02d];@00P2b/[820;Vi^@80^k^k0P2d];@20;Fe]@80^k^k5@3o
ool001<0oooo0P2i^KT20;^k^`80^;Rh0P2d];@20;Jf]P80]KFe0P2b/[820;Zj^P030;Bd]02k^k/0
^k^k00@0];Bd0P2i^KT20;^k^`80]KFe0P2h^;P20;:b/P80^k^k0P2d];@20;Fe]@80/K6a0P2i^KT2
0;Jf]P80/K6a00<0]kNg0;^k^`2k^k/00P2c/k<20;Vi^@80/k>c0P2e]KD20;6a/@80/[:b0P2TY:@2
08:2PP80M7Ad0P1YJFT206ATI080F5QH0P1@D50204E5A@0303dm?@0j>SX0>SXj0080>SXj0P0];Bd2
02TY:@80RHV90P2DU9@209:BTP80W9bL0P2DU9@2096AT@80VIVI0P2CTi<409FEU@80Ti>C00<0UIFE
09NGU`2GUiL00P2DU9@409FEU@80TI6A0P2@T90209FEU@80U9BD102@T90209FEU@80Rh^;0P2CTi<4
08Z:RP0308n?S`2=SHd0SHf=0080RHV90P28R8P207moO`80Ph>30P1jNWX207emO@80Rh^;0P2<S8`2
08>3P`80MgMg0P1jNWX207alO080KFe]0P1YJFT00`1QHF40HV9R069RHP0206MWI`80FEUI0P1CDe<2
06QXJ080HF5Q0P1SHf<206ATI080Kfm_0P1gMgL207QhN080L71`0P1YJFT206a/K080Ph>300<0N7Qh
07alO01lO7`00P20P80208B4Q080QHF50P26QXH208>3P`@0Ti>C0P2DU9@209>CT`80VYZJ0P2UYJD2
0:j^[P80ZZZZ0P2c/k<00`2k^k/0];Bd0;Bd]0020;:b/P80^KVi0P2k^k/20;Bd]080]KFe0P2k^k/E
0?ooo`004`3oool60;Vi^@80/k>c0P2i^KT20;Jf]P80]kNg0P2e]KD00`2i^KT0^k^k0;^k^`020;:b
/PH0^KVi0P2l_;`40;>c/`80_;bl0P2f][H20;Ng]`80/k>c0P2`/;020;bl_080];Bd00<0]KFe0;Rh
^02h^;P00P2c/k<40;Rh^080]KFe102][Jd209RHV080QHF50P1XJ6P206IVIP80EUIF0P1HF5P204];
B`80@T9200<0BDU904A4A014A4@00P0j>SX2028R8P803@d=0P2<S8`409:BTP80VYZJ0P2EUID209BD
U080UiNG0P2ATI4209:BTP80UiNG0`2ATI4209>CT`80U9BD0P2CTi<2096AT@80U9BD0P2BTY8208n?
S`80UIFE0P2ATI42092@T080S8b<0P2ATI4208F5Q@80T92@0P29RHT00`2;Rh/0RXZ:08Z:RP0208R8
R080Ph>30P1nOWh207=cL`@0OGem0P24Q8@208F5Q@80Kfm_0P1`L70207AdM080LW9b0P1ZJVX205MG
E`0305]KF`1HF5P0F5QH0080IFEU0P1NGUh205YJFP80F5QH0P1NGUh2069RHP80GUiN0P1^KVh207Qh
N080MWIf0P1cLg<207MgM`80IFEU0P25QHD00`1dM7@0Q8B408B4Q00206i^KP80S8b<0P20P80207in
OP80SHf=102DU9@209>CT`80X:2P0P2OWil20:j^[P80[jn_0P2][Jd20;Fe]@030;bl_02`/;00/;2`
00H0^KVi0P2b/[820;Jf]P80^KVi5@3oool001<0oooo1P2i^KT20;>c/`80^KVi0P2f][H20;Ng]`80
]KFe00<0^KVi0;^k^`2k^k/00P2b/[860;Vi^@80_;bl102c/k<20;bl_080][Jf0P2g]kL20;>c/`80
/;2`0P2l_;`20;Bd]0030;Fe]@2h^;P0^;Rh0080/k>c102h^;P20;Fe]@@0[Jf]0P2HV9P208F5Q@80
J6QX0P1VIVH205IFEP80F5QH0P1;Bd/20492@P0304U9B@14A4@0A4A40080>SXj0P0R8R8200d=3@80
S8b<102BTY8209ZJVP80UIFE0P2DU9@209NGU`80TI6A0P2BTY8209NGU`<0TI6A0P2CTi<209BDU080
Ti>C0P2ATI4209BDU080TY:B0P2?Shl209FEU@80TI6A0P2@T90208b<S080TI6A0P25QHD2092@T080
RHV900<0Rh^;08Z:RP2:RXX00P28R8P208>3P`80OWin0P1cLg<407emO@80Q8B40P25QHD206m_K`80
L71`0P1dM7@2079bLP80JVYZ0P1GEeL00`1KFe/0F5QH05QHF00206EUI@80GUiN0P1JFUX205QHF080
GUiN0P1RHV8205iNGP80KVi^0P1hN7P207IfMP80Lg=c0P1gMgL206EUI@80QHF500<0M7Ad08B4Q024
Q8@00P1^KVh208b<S080P8200P1nOWh208f=S@@0U9BD0P2CTi<20:2PX080WinO0P2^[Zh20:n_[`80
[Jf]0P2e]KD00`2l_;`0/;2`0;2`/0060;Vi^@80/[:b0P2f][H20;Vi^AD0oooo000C0?ooo`80^KVi
0P2l_;`20;Bd]080^k^k0P2a/K440;Vi^@80]kNg0`2i^KT20;Fe]@80]kNg102i^KT20;^k^`80^;Rh
0P2b/[820;Ng]`80^KVi0P2e]KD20;Ng]`80/[:b0P2k^k/20;>c/`030;bl_02d];@0];Bd0080];Bd
0P2i^KT20;^k^`80]kNg0P2][Jd20:j^[P80QXJ60P24Q8@206m_K`80HV9R0P1NGUh204];B`80ADE5
0P13@d<00`19BDT0ATI604I6AP0203/k>`80=CDe0P061PH209FEU@80T92@0P2HV9P209>CT`@0U9BD
0P2GUiL209BDU080TY:B0P2EUID309:BTP80T92@0P2?Shl209:BTP80Shn?0P2>SXh208n?S`80SXj>
0P2=SHd2096AT@80S8b<0P2?Shl208V9R@80RXZ:1028R8P00`26QXH0Q8B408B4Q00208F5Q@80NWYj
0P1iNGT207EeM@80LG5a0P1nOWh20820P080LW9b0P1^KVh206e]K@80K6a/0P1OGel205]KF`80GemO
00<0De=C061PH01PH6000P1`L70206EUI@80H61P0P1KFe/206ATI080IfMW0P1RHV8206][J`80Lg=c
101iNGT207]kN`80NGUi0P1nOWh00`1eMGD0O7al07alO00207QhN080MWIf0P25QHD208j>SP80RHV9
0P2GUiL209JFUP80UiNG0P2OWil20;Bd]080/;2`0P2/[:`20:n_[`80][Jf00<0]kNg0;Fe]@2e]KD0
0P2i^KT20;Zj^P80][Jf0P2h^;P20;Bd]080^KVi5@3oool001<0oooo0P2i^KT20;bl_080];Bd0P2k
^k/20;6a/@@0^KVi0P2g]kL30;Vi^@80]KFe0P2g]kL40;Vi^@80^k^k0P2h^;P20;:b/P80]kNg0P2i
^KT20;Fe]@80]kNg0P2b/[820;^k^`80/k>c00<0_;bl0;Bd]02d];@00P2d];@20;Vi^@80^k^k0P2g
]kL20:f][@80[Zj^0P26QXH208B4Q080Kfm_0P1RHV8205iNGP80Bd];0P15ADD204=3@`0304U9B@16
ATH0ATI60080>c/k0P0e=CD200H61P80UIFE0P2@T90209RHV080Ti>C102DU9@209NGU`80U9BD0P2B
TY8209FEU@<0TY:B0P2@T90208n?S`80TY:B0P2?Shl208j>SP80Shn?0P2>SXh208f=S@80TI6A0P2<
S8`208n?S`80RHV90P2:RXX408R8R00308J6QP24Q8@0Q8B40080QHF50P1jNWX207UiN@80MGEe0P1a
LG4207inOP80P8200P1bLW8206i^KP80KFe]0P1/K6`205mOG`80Fe]K0P1OGel00`1CDe<0H61P061P
H002071`L080IFEU0P1PH60205]KF`80I6AT0P1WIfL2069RHP80Jf][0P1cLg<407UiN@80Ng]k0P1i
NGT207inOP0307EeM@1lO7`0O7al0080N7Qh0P1fMWH208F5Q@80SXj>0P29RHT209NGU`80UYJF0P2G
UiL209nOW`80];Bd0P2`/;020:b/[080[jn_0P2f][H00`2g]kL0]KFe0;Fe]@020;Vi^@80^[Zj0P2f
][H20;Rh^080];Bd0P2i^KTE0?ooo`004`3oool40;Vi^@80]kNg0P2l_;`20;Bd]0@0^KVi0P2c/k<0
0`2k^k/0]KFe0;Fe]@020;Vi^@80]KFe202i^KT20;Ng]`@0]KFe0P2g]kL20;Fe]@80]kNg0P2k^k/2
0;>c/`030;Zj^P2b/[80/[:b00@0]kNg0P2i^KT20;Jf]P80/[:b0P2WYjL208F5Q@80NWYj0P1[Jf/2
069RHP80G5aL0P1HF5P204Y:BP<0C4a<0P0h>3P203@d=080;2`/0P0C4a<209JFUP80SHf=0P2FUYH2
09:BTP80T92@0P2GUiL209>CT`80SHf=0P2BTY82096AT@<0Shn?0P2@T90208R8R080S8b<0P2@T902
08^;R`@0RXZ:0P27QhL208n?S`@0R8R80P27QhL208F5Q@80RXZ:0P24Q8@00`23Ph<0PX:208:2PP02
07alO080OGem0P1_Kfl207AdM080MWIf0P1aLG4206UYJ@80IVIV0P1WIfL206IVIP80GUiN0P1SHf<2
05YJFP80Fe]K00<0FUYJ05UIF@1IFET00P1cLg<206m_K`80JVYZ0P1TI6@205eMG@80K6a/0P1ZJVX2
06QXJ080Jf][0P1cLg<207AdM080Rh^;0P24Q8@208:2PP0307MgM`1lO7`0O7al0080OGem0P1hN7P2
07UiN@@0Ti>C0P2NWYh209NGU`80Z:RX102/[:`20;Bd]080[:b/0P2b/[820;Fe]@030;:b/P2i^KT0
^KVi0080^k^k0P2c/k<20;Jf]P80]kNg0P2f][H20;Ng]aD0oooo000C0?ooo`80^KVi0P2k^k/20;Fe
]@80^KVi0P2g]kL20;^k^`80]kNg0P2c/k<00`2i^KT0^k^k0;^k^`020;Fe]@80]kNg102i^KT20;^k
^`80]KFe0P2k^k/20;Ng]`80]KFe0P2i^KT20;^k^`80/k>c0P2k^k/30;Fe]@80]kNg0P2d];@20;Fe
]@80]kNg0P2i^KT20:j^[P80W9bL0P27QhL207]kN`80K6a/0P1PH60205]KF`@0Cdm?0`17AdL2038b
<P80<C4a0P0/;2`200h>3P80UYJF0P2ATI4209RHV080S8b<0P2BTY8209>CT`80VYZJ0P2?Shl208Z:
RP80TI6A0P2>SXh00`2:RXX0Rh^;08^;R`0208Z:RP80QXJ61029RHT208R8R080QHF50P2:RXX208B4
Q080SHf=0P27QhL208B4Q080PH611@23Ph<407inOP80MWIf0P1eMGD206i^KP80M7Ad0P1XJ6P206AT
I080Fe]K0P1PH60205=CD`80GEeM0P1CDe<2055AD@80De=C00<0FEUI061PH01PH6000P1]KFd207Ee
M@80N7Qh0P1ZJVX206UYJ@80I6AT0P1QHF42071`L080J6QX101`L70208J6QP@0Q8B400<0Ng]k07em
O@1mOGd00P2;Rh/207alO080OWin102CTi<209^KV`80Xj>S0P2ZZZX20;2`/080[:b/0P2e]KD20:n_
[`80]KFe0P2b/[800`2i^KT0]kNg0;Ng]`020;^k^`80^;Rh102f][H20;Bd]080]KFe5@3oool001<0
oooo0P2i^KT20;^k^`80]KFe0P2i^KT20;Ng]`80^k^k0P2g]kL20;>c/`030;Vi^@2k^k/0^k^k0080
]KFe0P2g]kL40;Vi^@80^k^k0P2e]KD20;^k^`80]kNg0P2e]KD20;Vi^@80^k^k0P2c/k<20;^k^`<0
]KFe0P2g]kL20;Bd]080]KFe0P2g]kL20;Vi^@80[Zj^0P2LW9`208N7Q`80Ng]k0P1/K6`2061PH080
Fe]K101?Cdl304M7A`80<S8b0P0a<C4202`/;0803Ph>0P2FUYH2096AT@80V9RH0P2<S8`209:BTP80
Ti>C0P2JVYX208n?S`80RXZ:0P2ATI4208j>SP0308Z:RP2;Rh/0Rh^;0080RXZ:0P26QXH408V9R@80
R8R80P25QHD208Z:RP80Q8B40P2=SHd208N7Q`80Q8B40P21PH4508>3P`@0OWin0P1fMWH207EeM@80
KVi^0P1dM7@206QXJ080I6AT0P1KFe/2061PH080De=C0P1MGEd205=CD`80DE5A0P1CDe<00`1IFET0
H61P061PH00206e]K@80MGEe0P1hN7P206YZJP80JFUY0P1TI6@2065QH@80L71`0P1XJ6P4071`L080
QXJ61024Q8@00`1kNg/0OGem07emO@0208^;R`80O7al0P1nOWh409>CT`80Vi^K0P2SXj<20:ZZZP80
/;2`0P2/[:`20;Fe]@80[jn_0P2e]KD20;:b/P030;Vi^@2g]kL0]kNg0080^k^k0P2h^;P40;Jf]P80
];Bd0P2e]KDE0?ooo`004`3oool60;Vi^@80^k^k0P2e]KD20;Ng]`80^KVi0P2e]KD00`2g]kL0][Jf
0;Jf]P020;^k^`80]KFe102i^KT20;Ng]``0^KVi0P2e]KD20;^k^`80]KFe00<0/[:b0;Vi^@2i^KT0
0P2c/k<20;Bd]080]kNg0P2l_;`20;2`/080TI6A0P1jNWX207QhN080Hf=S0P1JFUX2059BDP80DE5A
0P19BDT204i>CP030451@@0i>CT0>CTi0080=CDe0P0c<c<2014A4@80TY:B0P2@T90209>CT`80TY:B
0P2EUID208b<S080TY:B0P2EUID208V9R@80T92@0P2<S8`00`27QhL0R8R808R8R00208R8R080PX:2
0P24Q8@208:2PP80QXJ60P22PX8408>3P`80QXJ60P25QHD208:2PP80P8200P1lO7`208:2PP0307in
OP1kNg/0Ng]k0080NGUi0P1fMWH206i^KP80MGEe0P1]KFd2065QH@80FEUI0P1KFe/205EEE@80GEeM
0P1DE5@2055AD@80DU9B0P1=CDd00`1EEED0FUYJ05YJFP0206m_K`80LG5a0P1`L70207QhN080KFe]
0P1ZJVX2065QH@80Fe]K0P1WIfL207UiN@80LG5a0P1oOgl208N7Q`80RHV900<0Ng]k0861P@21PH40
0P24Q8@207emO@80QXJ60P2EUID2092@T080Y:BT0P2WYjL20;:b/P80Zj^[102^[Zh20;Fe]@80]kNg
0P2c/k<00`2k^k/0]KFe0;Fe]@040;Vi^@80^k^k102e]KD20;^k^aD0oooo000C0?ooo`H0^KVi0P2k
^k/20;Fe]@80]kNg0P2i^KT20;Fe]@030;Ng]`2f][H0][Jf0080^k^k0P2e]KD40;Vi^@80]kNg302i
^KT20;Fe]@80^k^k0P2e]KD00`2b/[80^KVi0;Vi^@020;>c/`80];Bd0P2g]kL20;bl_080/;2`0P2A
TI4207YjNP80N7Qh0P1SHf<205YJFP80DU9B0P1ADE4204U9B@80CTi>00<0@D5103Ti>@0i>CT00P0e
=CD203<c<`804A4A0P2BTY82092@T080Ti>C0P2BTY8209FEU@80S8b<0P2BTY8209FEU@80RHV90P2@
T90208b<S00308N7Q`28R8P0R8R80080R8R80P22PX8208B4Q080PX:20P26QXH208:2PP@0Ph>30P26
QXH208F5Q@80PX:20P20P80207alO080PX:200<0OWin07]kN`1kNg/00P1iNGT207IfMP80KVi^0P1e
MGD206e]K@80HF5Q0P1IFET205]KF`80EEEE0P1MGEd205ADE080DE5A0P1BDU8204e=C@0305EEE@1J
FUX0FUYJ0080Kfm_0P1aLG42071`L080N7Qh0P1]KFd206YZJP80HF5Q0P1KFe/206MWI`80NGUi0P1a
LG4207moO`80QhN70P29RHT00`1kNg/0PH610861P@0208B4Q080OGem0P26QXH209FEU@80T92@0P2T
Y:@20:NWY`80/[:b0P2[Zj/40:j^[P80]KFe0P2g]kL20;>c/`030;^k^`2e]KD0]KFe00@0^KVi0P2k
^k/40;Fe]@80^k^k5@3oool001<0oooo102i^KT40;Ng]`80^k^k0P2e]KD20;>c/`80^k^k00<0^;Rh
0;Bd]02d];@00P2g]kL20;Jf]P80^KVi0P2k^k/20;>c/`@0^KVi102g]kL20;Rh^080/[:b102i^KT2
0;Ng]`030;Bd]02i^KT0^KVi0080/;2`0P2j^[X20;Bd]080/[:b0P2d];@208R8R080O7al0P1]KFd2
06YZJP80Fe]K0P1CDe<2055AD@80CTi>0P1BDU800`0e=CD0;2`/02`/;00202h^;P80=SHf0P0H61P2
09JFUP80R8R80P2BTY8208^;R`80Ti>C0P2ATI4208R8R080TI6A0P2:RXX208R8R080RXZ:00<0QXJ6
08>3P`23Ph<01024Q8@20820P080O7al0P1mOGd407]kN`@0PH610P24Q8@207inOP80OGem101jNWX0
0`1hN7P0NWYj07YjNP02079bLP80Lg=c0P1UIFD206IVIP80HV9R0P1IFET205QHF080FUYJ0P1LG5`2
05=CD`80EEEE0P1GEeL205ADE080EEEE00<0F5QH05iNGP1NGUh00P1XJ6P407YjNP80P8200P1hN7P2
06YZJP80G5aL0P1PH602065QH@80JVYZ0P1hN7P20861P@80P8200P27QhL00`22PX80PH610861P@02
07IfMP80Ng]k0P2<S8`209FEU@80U9BD0P2YZJT40:RXZ080];Bd0P2b/[820;2`/080/k>c0P2k^k/2
0;Fe]@<0^KVi0P2g]kL20;Vi^@80^k^k0P2e]KD20;Jf]P80^k^k5@3oool001<0oooo102i^KT40;Ng
]`80^k^k0P2e]KD20;>c/`80^k^k00<0^;Rh0;Bd]02d];@00P2g]kL20;Jf]P80^KVi0P2k^k/20;>c
/`@0^KVi102g]kL20;Rh^080/[:b102i^KT20;Ng]`030;Bd]02i^KT0^KVi0080/;2`0P2j^[X20;Bd
]080/[:b0P2d];@208R8R080O7al0P1]KFd206YZJP80Fe]K0P1CDe<2055AD@80CTi>0P1BDU800`0e
=CD0;2`/02`/;00202h^;P80=SHf0P0H61P209JFUP80R8R80P2BTY8208^;R`80Ti>C0P2ATI4208R8
R080TI6A0P2:RXX208R8R080RXZ:00<0QXJ608>3P`23Ph<01024Q8@20820P080O7al0P1mOGd407]k
N`@0PH610P24Q8@207inOP80OGem101jNWX00`1hN7P0NWYj07YjNP02079bLP80Lg=c0P1UIFD206IV
IP80HV9R0P1IFET205QHF080FUYJ0P1LG5`205=CD`80EEEE0P1GEeL205ADE080EEEE00<0F5QH05iN
GP1NGUh00P1XJ6P407YjNP80P8200P1hN7P206YZJP80G5aL0P1PH602065QH@80JVYZ0P1hN7P20861
P@80P8200P27QhL00`22PX80PH610861P@0207IfMP80Ng]k0P2<S8`209FEU@80U9BD0P2YZJT40:RX
Z080];Bd0P2b/[820;2`/080/k>c0P2k^k/20;Fe]@<0^KVi0P2g]kL20;Vi^@80^k^k0P2e]KD20;Jf
]P80^k^k5@3oool001<0oooo0P2g]kL20;Vi^@80]kNg0P2e]KD20;Vi^@80]KFe0P2b/[830;Jf]P80
^KVi0P2h^;P20;Bd]080^KVi0P2h^;P20;Fe]@80]kNg0P2k^k/20;Fe]@80^;Rh102d];@20;^k^`80
]kNg0P2e]KD30;Vi^@80/[:b0P2j^[X20;:b/P80][Jf0P2PX:0208F5Q@80O7al0P1[Jf/205eMG@80
EUIF0P1IFET2051@D080BTY:0P13@d<00`0`<3009bLW02LW9`0202`/;080;bl_0P0I6AT209JFUP80
RHV90P2CTi<208b<S0@0Shn?0P2:RXX208N7Q`80RHV90P23Ph<208R8R00308F5Q@1nOWh0OWin0080
PX:20P1oOgl20820P080PX:20P1jNWX207QhN080MWIf0P1jNWX207]kN`80P820101lO7`207QhN080
M7Ad00<0LW9b071`L01`L7000P1]KFd206][J`80JVYZ0P1JFUX2055AD@80FEUI0P1DE5@205MGE`80
Fe]K0P17AdL203hn?P80A4A40P1ADE4205eMG@0306EUI@1RHV80HV9R0080IfMW0P1]KFd20820P080
N7Qh0P2;Rh/20861P@80I6AT0P1RHV8206EUI@80M7Ad0P1/K6`207IfMP80R8R80`22PX8407QhN080
LG5a0P2BTY8209ZJVP80WinO0P2TY:@20;6a/@80YjNW0P2c/k<20:^[Z`80^[Zj0P2b/[820;Jf]PD0
^KVi0P2e]KD40;Vi^@80^[Zj0P2d];@20;^k^aD0oooo000C0?ooo`80]kNg0P2i^KT20;Ng]`80]KFe
0P2i^KT20;Fe]@80/[:b0`2f][H20;Vi^@80^;Rh0P2d];@20;Vi^@80^;Rh0P2e]KD20;Ng]`80^k^k
0P2e]KD20;Rh^0@0];Bd0P2k^k/20;Ng]`80]KFe0`2i^KT20;:b/P80^[Zj0P2b/[820;Jf]P80X:2P
0P25QHD207alO080Jf][0P1MGEd205IFEP80FEUI0P1@D50204Y:BP80@d=300<0<30`02LW9`0W9bL0
0P0/;2`202l_;`806ATI0P2FUYH208V9R@80Ti>C0P2<S8`408n?S`80RXZ:0P27QhL208V9R@80Ph>3
0P28R8P00`25QHD0OWin07inOP0208:2PP80Ogmo0P20P80208:2PP80NWYj0P1hN7P207IfMP80NWYj
0P1kNg/20820P0@0O7al0P1hN7P207AdM003079bLP1`L700L71`0080KFe]0P1[Jf/206YZJP80FUYJ
0P1ADE4205UIF@80E5AD0P1GEeL205]KF`80AdM70P0n?Sh204A4A080DE5A0P1MGEd00`1UIFD0HV9R
069RHP0206MWI`80KFe]0P20P80207QhN080Rh^;0P21PH4206ATI080HV9R0P1UIFD207AdM080K6a/
0P1fMWH208R8R0<0PX:2101hN7P2075aL@80TY:B0P2JVYX209nOW`80Y:BT0P2a/K420:NWY`80/k>c
0P2[Zj/20;Zj^P80/[:b0P2f][H50;Vi^@80]KFe102i^KT20;Zj^P80];Bd0P2k^k/E0?ooo`004`3o
ool20;Ng]`80]KFe0P2i^KT20;^k^`80]kNg0P2f][H40;Ng]`030;Jf]P2e]KD0]KFe00@0^KVi0P2l
_;`20;>c/`80^;Rh0P2c/k<20;^k^`80/k>c0P2k^k/20;:b/P80^KVi0P2g]kL20;Vi^@80]kNg00<0
^;Rh0;Jf]P2f][H00P2e]KD20;Bd]0@0/k>c0P2DU9@208B4Q080Kfm_0P1WIfL205mOG`80Cdm?0P1A
DE4204e=C@80Cdm?0P0k>c/00`0e=CD0<C4a034a<@02030`<080=CDe0P0O7al2096AT@80R8R80P2;
Rh/208f=S@80SXj>0P29RHT208^;R`80QhN70P25QHD208>3P`80PH6100<0Ph>307inOP1nOWh00P1j
NWX207UiN@80MgMg0P1eMGD207UiN@80Lg=c0P1eMGD207QhN080Lg=c0P1gMgL207alO080N7Qh101d
M7@00`1^KVh0Kfm_06m_K`0206YZJP80IfMW0P1[Jf/204i>CP80De=C0P1BDU8205QHF080CDe=0P14
A4@204I6AP80;Bd]0P13@d<205=CD`80F5QH00<0Hf=S069RHP1RHV800P1SHf<206a/K080N7Qh0P23
Ph<207UiN@80QhN70P1eMGD206YZJP80LW9b0P1_Kfl207]kN`80KVi^1022PX800`1dM7@0LW9b079b
LP0207]kN`80NGUi0P2EUID209JFUP80[Zj^0P2UYJD20:^[Z`80/;2`0P2_[jl20;6a/@80_;bl0P2c
/k<20;:b/P80^KVi00<0^k^k0;Fe]@2e]KD00P2f][H40;Vi^@80]KFe0P2g]kL20;Vi^AD0oooo000C
0?ooo`80]kNg0P2e]KD20;Vi^@80^k^k0P2g]kL20;Jf]P@0]kNg00<0][Jf0;Fe]@2e]KD0102i^KT2
0;bl_080/k>c0P2h^;P20;>c/`80^k^k0P2c/k<20;^k^`80/[:b0P2i^KT20;Ng]`80^KVi0P2g]kL0
0`2h^;P0][Jf0;Jf]P020;Fe]@80];Bd102c/k<209BDU080Q8B40P1_Kfl206MWI`80GemO0P1?Cdl2
055AD@80CDe=0P1?Cdl203/k>`0303De=@0a<C40<C4a0080<30`0P0e=CD201lO7`80TI6A0P28R8P2
08^;R`80SHf=0P2>SXh208V9R@80Rh^;0P27QhL208F5Q@80Ph>30P21PH400`23Ph<0OWin07inOP02
07YjNP80NGUi0P1gMgL207EeM@80NGUi0P1cLg<207EeM@80N7Qh0P1cLg<207MgM`80O7al0P1hN7P4
07AdM00306i^KP1_Kfl0Kfm_0080JVYZ0P1WIfL206][J`80CTi>0P1CDe<2059BDP80F5QH0P1=CDd2
04A4A080ATI60P0];Bd204=3@`80De=C0P1HF5P00`1SHf<0HV9R069RHP0206=SH`80K6a/0P1hN7P2
08>3P`80NGUi0P27QhL207EeM@80JVYZ0P1bLW8206m_K`80Ng]k0P1^KVh408:2PP0307AdM01bLW80
LW9b0080Ng]k0P1iNGT209FEU@80UYJF0P2^[Zh20:FUY@80Zj^[0P2`/;020:n_[`80/K6a0P2l_;`2
0;>c/`80/[:b0P2i^KT00`2k^k/0]KFe0;Fe]@020;Jf]P@0^KVi0P2e]KD20;Ng]`80^KVi5@3oool0
01<0oooo1P2i^KT20;Ng]`80^k^k0P2c/k<20;Ng]`80][Jf0`2g]kL20;Vi^@80]kNg0P2i^KT20;bl
_080][Jf0P2e]KD20;^k^`80/K6a0P2h^;P20;>c/`80^;Rh0P2e]KD20;^k^`<0][Jf0P2e]KD20;Vi
^@80/[:b0P2f][H20:BTY080R8R80P1lO7`206a/K080HV9R0P1IFET205QHF080CTi>0P1;Bd/203hn
?P80=cLg0`0b<S8203@d=080<c<c0P0W9bL408Z:RP80S8b<0P2>SXh208f=S@80S8b<0P27QhL208b<
S080R8R80P2;Rh/208F5Q@0308B4Q025QHD0QHF50080NGUi0P1cLg<207IfMP80KFe]0P1^KVh2075a
L@80Jf][0P1`L70207IfMP80L71`0P1cLg<2071`L080M7Ad0P1[Jf/00`1XJ6P0I6AT06ATI00206MW
I`80H61P0P1VIVH204a<C080ATI60P1HF5P204a<C080@D510P0m?Cd203hn?P80B4Q80P0m?Cd205MG
E`80KFe]00<0G5aL06UYJ@1YJFT00P1LG5`206=SH`80MGEe0P25QHD207alO080QHF50P1aLG4206i^
KP80MWIf0P1^KVh207YjNP80Ng]k0P27QhL207YjNP0307inOP1gMgL0MgMg0080N7Qh0P23Ph<209BD
U080ZZZZ0P2VYZH20:VYZ@80Z:RX0P2_[jl20;Ng]`80];Bd0P2k^k/20;Ng]`80/k>c0`2i^KT20;bl
_080];Bd0P2k^k/20;Fe]@80^k^k0P2c/k<20;Vi^AD0oooo000C0?ooo`H0^KVi0P2g]kL20;^k^`80
/k>c0P2g]kL20;Jf]P<0]kNg0P2i^KT20;Ng]`80^KVi0P2l_;`20;Jf]P80]KFe0P2k^k/20;6a/@80
^;Rh0P2c/k<20;Rh^080]KFe0P2k^k/30;Jf]P80]KFe0P2i^KT20;:b/P80][Jf0P2TY:@208R8R080
O7al0P1/K6`2069RHP80FEUI0P1HF5P204i>CP80Bd];0P0n?Sh203Lg=`<0<S8b0P0d=3@203<c<`80
9bLW102:RXX208b<S080SXj>0P2=SHd208b<S080QhN70P2<S8`208R8R080Rh^;0P25QHD00`24Q8@0
QHF508F5Q@0207UiN@80Lg=c0P1fMWH206e]K@80KVi^0P1aLG4206][J`80L71`0P1fMWH2071`L080
Lg=c0P1`L70207AdM080Jf][00<0J6QX06ATI01TI6@00P1WIfL2061PH080IVIV0P1<C4`204I6AP80
F5QH0P1<C4`20451@@80?Cdm0P0n?Sh204Q8B080?Cdm0P1GEeL206e]K@0305aLG01YJFT0JFUY0080
G5aL0P1SHf<207EeM@80QHF50P1lO7`208F5Q@80LG5a0P1^KVh207IfMP80KVi^0P1jNWX207]kN`80
QhN70P1jNWX00`1nOWh0MgMg07MgM`0207QhN080Ph>30P2DU9@20:ZZZP80YZJV0P2YZJT20:RXZ080
[jn_0P2g]kL20;Bd]080^k^k0P2g]kL20;>c/`<0^KVi0P2l_;`20;Bd]080^k^k0P2e]KD20;^k^`80
/k>c0P2i^KTE0?ooo`004`3oool40;Ng]`80^k^k0P2e]KD20;Ng]`80];Bd0P2h^;P20;Bd]0030;Ng
]`2e]KD0]KFe0080^KVi0P2c/k<40;Vi^@80][Jf0P2i^KT20;Zj^P80][Jf0P2c/k<20;Jf]P80/K6a
0P2i^KT20;^k^`80/k>c00<0]kNg0;Vi^@2i^KT00P2b/[820;Fe]@80]kNg0P2LW9`208J6QP80MgMg
0P1TI6@206=SH`80EUIF0P1LG5`2051@D080Bd];0P0/;2`303De=@80<S8b0P0`<30203hn?P80;Bd]
0P2=SHd209BDU080T92@0P2MWId209JFUP80UiNG0P2ATI4209:BTP80Shn?102>SXh00`2:RXX0S8b<
08b<S00208Z:RP80PH61101`L70206QXJ080JVYZ0P1[Jf/206UYJ@80IVIV0P1YJFT206m_K`80K6a/
0P1YJFT206a/K00306EUI@1QHF40HF5Q0080Fe]K0P1NGUh205MGE`80BTY:0P16ATH204e=C@80BDU9
0P0e=CD203@d=080A4A40P10@40204U9B@80EEEE0P1XJ6P00`1WIfL0G5aL05aLG00206EUI@80G5aL
0P1fMWH207inOP80Shn?0P24Q8@20820P080Lg=c0P1^KVh406EUI@@0QhN70P1eMGD00`21PH40O7al
07alO00208Z:RP80QhN70P2IVIT20;Vi^@80Z:RX0P2VYZH20;Bd]080[:b/0P2g]kL20;Vi^@80]kNg
0P2k^k/20;Fe]@<0^KVi0P2g]kL60;Vi^@80^k^k0P2e]KD20;Vi^AD0oooo000C0?ooo`@0]kNg0P2k
^k/20;Fe]@80]kNg0P2d];@20;Rh^080];Bd00<0]kNg0;Fe]@2e]KD00P2i^KT20;>c/`@0^KVi0P2f
][H20;Vi^@80^[Zj0P2f][H20;>c/`80][Jf0P2a/K420;Vi^@80^k^k0P2c/k<00`2g]kL0^KVi0;Vi
^@020;:b/P80]KFe0P2g]kL209bLW080QXJ60P1gMgL206ATI080Hf=S0P1FEUH205aLG080D51@0P1;
Bd/202`/;0<0=CDe0P0b<S82030`<080?Shn0P0];Bd208f=S@80U9BD0P2@T90209fMW@80UYJF0P2G
UiL2096AT@80TY:B0P2?Shl408j>SP0308Z:RP2<S8`0S8b<0080RXZ:0P21PH44071`L080J6QX0P1Z
JVX206][J`80JFUY0P1VIVH206UYJ@80Kfm_0P1/K6`206UYJ@80K6a/00<0IFEU065QH@1QHF400P1K
Fe/205iNGP80EeMG0P1:BTX204I6AP80CDe=0P19BDT203De=@80=3@d0P14A4@20410@080BDU90P1E
EED206QXJ00306MWI`1LG5`0G5aL0080IFEU0P1LG5`207IfMP80OWin0P2?Shl208B4Q080P8200P1c
Lg<206i^KP@0IFEU1027QhL207EeM@030861P@1lO7`0O7al0080RXZ:0P27QhL209VIV@80^KVi0P2X
Z:P20:JVYP80];Bd0P2/[:`20;Ng]`80^KVi0P2g]kL20;^k^`80]KFe0`2i^KT20;Ng]`H0^KVi0P2k
^k/20;Fe]@80^KVi5@3oool001<0oooo0P2g]kL20;Fe]@80]kNg0P2k^k/20;Jf]P80/[:b0P2k^k/2
0;>c/`030;Vi^@2k^k/0^k^k0080]kNg0P2e]KD20;Vi^@80_;bl0P2b/[820;^k^`80]KFe0P2j^[X2
0;Jf]P80^;Rh0P2`/;040;Vi^@80]kNg00<0]KFe0;Bd]02d];@00P2e]KD20;Bd]080ZJVY0P2BTY82
08:2PP80Lg=c0P1UIFD205IFEP80EEEE0P1<C4`205]KF`80@T920P0e=CD2030`<00303/k>`0e=CD0
=CDe0080<C4a0P11@D4204E5A@80SXj>0P2KVi/20:6QX@@0WIfM0P2KVi/209nOW`80VIVI0P2HV9P2
09VIV@80TI6A00<0T92@08n?S`2?Shl00P2=SHd408Z:RP80MgMg0P1^KVh406EUI@80JFUY0P1XJ6P2
06UYJ@80HF5Q0P1WIfL206UYJ@80IVIV00<0IfMW061PH01PH6000P1FEUH205MGE`80GemO0P1>CTh2
059BDP80B4Q80P0m?Cd203@d=080>3Ph0P11@D4204e=C@80A4A40P1BDU8206EUI@0306ATI01NGUh0
GUiN0080G5aL0P1PH60206e]K@80N7Qh0P29RHT208Z:RP80Rh^;0P1iNGT2075aL@80K6a/0P1OGel2
0861P@80QhN70P1kNg/00`1jNWX0RHV908V9R@020820P080QHF50P2c/k<20:ZZZP80Z:RX0P2][Jd2
0:n_[`80][Jf0P2c/k<20;^k^`80/[:b0P2g]kL20;Jf]P80]kNg00<0^KVi0;Fe]@2e]KD00P2i^KT2
0;Ng]`@0^KVi0P2k^k/20;Rh^1D0oooo000C0?ooo`80]kNg0P2e]KD20;Ng]`80^k^k0P2f][H20;:b
/P80^k^k0P2c/k<00`2i^KT0^k^k0;^k^`020;Ng]`80]KFe0P2i^KT20;bl_080/[:b0P2k^k/20;Fe
]@80^[Zj0P2f][H20;Rh^080/;2`102i^KT20;Ng]`030;Fe]@2d];@0];Bd0080]KFe0P2d];@20:VY
Z@80TY:B0P22PX8207=cL`80IFEU0P1FEUH205EEE@80C4a<0P1KFe/20492@P80=CDe0P0`<3000`0k
>c/0=CDe03De=@02034a<@80@D510P15ADD208j>SP80Vi^K0P2QXJ4409fMW@80Vi^K0P2OWil209VI
V@80V9RH0P2IVIT2096AT@03092@T02?Shl0Shn?0080SHf=102:RXX207MgM`80KVi^101UIFD206UY
J@80J6QX0P1YJFT2065QH@80IfMW0P1YJFT206IVIP0306MWI`1PH600H61P0080EUIF0P1GEeL205mO
G`80CTi>0P1BDU8204Q8B080?Cdm0P0d=3@203Ph>080@D510P1=CDd204A4A080DU9B0P1UIFD00`1T
I6@0GUiN05iNGP0205aLG080H61P0P1]KFd207QhN080RHV90P2:RXX208^;R`80NGUi0P1aLG4206a/
K080GemO0P21PH4208N7Q`80Ng]k00<0NWYj08V9R@29RHT00P20P80208F5Q@80/k>c0P2ZZZX20:RX
Z080[Jf]0P2_[jl20;Jf]P80/k>c0P2k^k/20;:b/P80]kNg0P2f][H20;Ng]`030;Vi^@2e]KD0]KFe
0080^KVi0P2g]kL40;Vi^@80^k^k0P2h^;PE0?ooo`004`3oool20;Ng]`80^KVi0P2g]kL20;>c/`80
^KVi0P2g]kL20;Rh^080]KFe00<0][Jf0;Vi^@2i^KT0202i^KT20;>c/`@0^KVi0P2c/k<20;Vi^@80
^[Zj0P2`/;020;^k^`80/k>c0P2h^;P00`2d];@0/k>c0;>c/`020;Fe]@80_Kfm0P2OWil208R8R080
NWYj0P1/K6`2065QH@80HV9R0P1BDU82055AD@80Cdm?0P0e=CD503Hf=P80=CDe0P1=CDd204A4A080
Lg=c0P2OWil209fMW@80YjNW0P2QXJ420:2PX080XJ6Q0P2LW9`20:6QX@80W9bL0P2OWil209RHV003
09NGU`2DU9@0U9BD0080T92@0P2=SHd208Z:RP80QhN70P25QHD207UiN@80IfMW0P1RHV8206=SH`80
HV9R0P1ZJVX2061PH080I6AT0P1UIFD00`1NGUh0Fe]K05]KF`0204m?C`80?clo0P1MGEd2051@D080
EeMG0P1;Bd/203<c<`809RHV0P0W9bL203hn?P80IFEU0P17AdL2059BDP80HF5Q00<0J6QX06ATI01T
I6@0101RHV82075aL@80MGEe0P2;Rh/4096AT@80Lg=c0P1bLW8206MWI`80KVi^0P1gMgL207YjNP80
PH6100<0O7al09>CT`2CTi<00P1iNGT209BDU080/;2`0P2XZ:P20::RXP80/k>c0P2][Jd20;^k^`80
]KFe0P2i^KT20;Jf]P80^;Rh0P2f][H20;Ng]`030;>c/`2g]kL0]kNg0080^k^k0P2e]KD40;Vi^@80
]kNg0P2i^KTE0?ooo`004`3oool20;Ng]`80^KVi0P2g]kL20;>c/`80^KVi0P2g]kL20;Rh^080]KFe
00<0][Jf0;Vi^@2i^KT0202i^KT20;>c/`@0^KVi0P2c/k<20;Vi^@80^[Zj0P2`/;020;^k^`80/k>c
0P2h^;P00`2d];@0/k>c0;>c/`020;Fe]@80_Kfm0P2OWil208R8R080NWYj0P1/K6`2065QH@80HV9R
0P1BDU82055AD@80Cdm?0P0e=CD503Hf=P80=CDe0P1=CDd204A4A080Lg=c0P2OWil209fMW@80YjNW
0P2QXJ420:2PX080XJ6Q0P2LW9`20:6QX@80W9bL0P2OWil209RHV00309NGU`2DU9@0U9BD0080T92@
0P2=SHd208Z:RP80QhN70P25QHD207UiN@80IfMW0P1RHV8206=SH`80HV9R0P1ZJVX2061PH080I6AT
0P1UIFD00`1NGUh0Fe]K05]KF`0204m?C`80?clo0P1MGEd2051@D080EeMG0P1;Bd/203<c<`809RHV
0P0W9bL203hn?P80IFEU0P17AdL2059BDP80HF5Q00<0J6QX06ATI01TI6@0101RHV82075aL@80MGEe
0P2;Rh/4096AT@80Lg=c0P1bLW8206MWI`80KVi^0P1gMgL207YjNP80PH6100<0O7al09>CT`2CTi<0
0P1iNGT209BDU080/;2`0P2XZ:P20::RXP80/k>c0P2][Jd20;^k^`80]KFe0P2i^KT20;Jf]P80^;Rh
0P2f][H20;Ng]`030;>c/`2g]kL0]kNg0080^k^k0P2e]KD40;Vi^@80]kNg0P2i^KTE0?ooo`004`3o
ool20;Ng]`80]KFe0P2j^[X20;Bd]080^k^k0P2h^;P20;Bd]080_;bl00<0/K6a0;Ng]`2g]kL00P2f
][H20;Vi^@80^k^k0P2h^;P20;6a/@80^KVi0P2g]kL20;>c/`80^KVi0P2e]KD20;>c/`80^k^k0P2h
^;P20;Ng]`030;Jf]P2c/k<0/k>c0080[jn_0P2b/[8209ZJVP80Ph>30P1aLG4206EUI@80E5AD0P1C
De<205MGE`80DE5A0P14A4@403Hf=P80>c/k00<0>CTi04I6AP16ATH00P1HF5P207UiN@80Vi^K0P2P
X:020:RXZ080XZ:R0P2YZJT209jNWP80YjNW0P2LW9`20:6QX@80WinO0P2NWYh209^KV`0309nOW`2H
V9P0V9RH0080VIVI0P2?Shl208f=S@80RHV90P2:RXX208B4Q080Ph>30P1WIfL205eMG@80G5aL0P1M
GEd2069RHP80GEeM0P1PH6000`1MGEd0EEEE05EEE@0204Q8B080?clo0P14A4@204m?C`80BTY:0P1_
Kfl203Xj>P80?Cdm0P0T92@202`/;080EUIF0P1?Cdl204Y:BP80Fe]K00<0K6a/05aLG01LG5`00P1d
M7@206IVIP80Jf][0P1gMgL208:2PP80Ti>C0P2FUYH208j>SP80HV9R0P1]KFd2071`L080NGUi0P1e
MGD20861P@0308R8R02;Rh/0Rh^;0080NWYj0P2][Jd20:ZZZP80WIfM0P2][Jd20;:b/P80]KFe0P2f
][H20;^k^`80/[:b102i^KT20;Ng]`80^KVi00<0]kNg0;>c/`2c/k<00P2g]kL40;Vi^@80^k^k0P2e
]KD20;Vi^AD0oooo000C0?ooo`80]kNg0P2e]KD20;Zj^P80];Bd0P2k^k/20;Rh^080];Bd0P2l_;`0
0`2a/K40]kNg0;Ng]`020;Jf]P80^KVi0P2k^k/20;Rh^080/K6a0P2i^KT20;Ng]`80/k>c0P2i^KT2
0;Fe]@80/k>c0P2k^k/20;Rh^080]kNg00<0][Jf0;>c/`2c/k<00P2_[jl20;:b/P80VYZJ0P23Ph<2
075aL@80IFEU0P1DE5@205=CD`80EeMG0P1ADE4204A4A0@0=SHf0P0k>c/00`0i>CT0ATI604I6AP02
05QHF080NGUi0P2KVi/20:2PX080Z:RX0P2RXZ820:VYZ@80WYjN0P2WYjL209bLW080XJ6Q0P2OWil2
09jNWP80Vi^K00<0WinO09RHV02HV9P00P2IVIT208n?S`80SHf=0P29RHT208Z:RP80Q8B40P23Ph<2
06MWI`80GEeM0P1LG5`205eMG@80HV9R0P1MGEd2061PH00305eMG@1EEED0EEEE0080B4Q80P0o?cl2
04A4A080Cdm?0P1:BTX206m_K`80>SXj0P0m?Cd202@T9080;2`/0P1FEUH204m?C`80BTY:0P1KFe/0
0`1/K6`0G5aL05aLG00207AdM080IVIV0P1[Jf/207MgM`80PX:20P2CTi<209JFUP80SXj>0P1RHV82
06e]K@80L71`0P1iNGT207EeM@80PH6100<0R8R808^;R`2;Rh/00P1jNWX20:f][@80ZZZZ0P2MWId2
0:f][@80/[:b0P2e]KD20;Jf]P80^k^k0P2b/[840;Vi^@80]kNg0P2i^KT00`2g]kL0/k>c0;>c/`02
0;Ng]`@0^KVi0P2k^k/20;Fe]@80^KVi5@3oool001<0oooo0P2i^KT20;^k^`80]KFe102i^KT20;Jf
]P80^KVi0P2l_;`00`2f][H0^;Rh0;Rh^0020;Bd]0@0^KVi0P2h^;P20;Bd]080/k>c0P2k^k/20;Ng
]`80]KFe0P2g]kL20;Fe]@L0^KVi0P2e]KD20;6a/@80X:2P0P2DU9@207MgM`80LW9b0P1UIFD205QH
F080D51@101?Cdl203`l?080=CDe0P0b<S8203Hf=P03055AD@0[:b/0:b/[0080VYZJ0P2QXJ4209bL
W080WinO0P2SXj<20:JVYP80Y:BT0P2VYZH20:RXZ080XZ:R0P2QXJ4209bLW080XJ6Q0P2LW9`00`2K
Vi/0VYZJ09ZJVP0209VIV@80UiNG0P2@T90208b<S080SXj>0P2:RXX208B4Q080P8200P1_Kfl2065Q
H@80EeMG0P1MGEd205UIF@80FUYJ00<0EUIF04e=C@1=CDd00P1:BTX203`l?080?Shn0P1dM7@204U9
B@80LG5a0P0o?cl202@T9080?3`l0P0m?Cd204U9B@80NGUi0P1GEeL2069RHP0306m_K`1LG5`0G5aL
0080JFUY0P1`L70206i^KP80MgMg0P1hN7P208j>SP80VYZJ0P29RHT206e]K@80IFEU0P1[Jf/2075a
L@80MGEe0P2<S8`00`2>SXh0Q8B408B4Q00208F5Q@80Xj>S0P2WYjL20:VYZ@80/k>c0P2`/;020;^k
^`80/[:b0P2k^k/20;>c/`@0^KVi102e]KD00`2k^k/0]kNg0;Ng]`020;Fe]@80]kNg1P2i^KT20;Ng
]aD0oooo000C0?ooo`80^KVi0P2k^k/20;Fe]@@0^KVi0P2f][H20;Vi^@80_;bl00<0][Jf0;Rh^02h
^;P00P2d];@40;Vi^@80^;Rh0P2d];@20;>c/`80^k^k0P2g]kL20;Fe]@80]kNg0P2e]KD70;Vi^@80
]KFe0P2a/K420:2PX080U9BD0P1gMgL2079bLP80IFEU0P1HF5P2051@D0@0Cdm?0P0l?3`203De=@80
<S8b0P0f=SH00`1ADE40:b/[02/[:`0209ZJVP80XJ6Q0P2LW9`209nOW`80Xj>S0P2VYZH20:BTY080
YZJV0P2XZ:P20::RXP80XJ6Q0P2LW9`20:6QX@80W9bL00<0Vi^K09ZJVP2JVYX00P2IVIT209NGU`80
T92@0P2<S8`208j>SP80RXZ:0P24Q8@20820P080Kfm_0P1QHF4205MGE`80GEeM0P1IFET205YJFP03
05IFEP1=CDd0CDe=0080BTY:0P0l?3`203hn?P80M7Ad0P19BDT2075aL@80?clo0P0T92@203`l?080
?Cdm0P19BDT207UiN@80EeMG0P1RHV800`1_Kfl0G5aL05aLG00206UYJ@80L71`0P1^KVh207MgM`80
N7Qh0P2>SXh209ZJVP80RHV90P1]KFd206EUI@80Jf][0P1aLG4207EeM@80S8b<00<0SXj>08B4Q024
Q8@00P25QHD20:>SX`80YjNW0P2YZJT20;>c/`80/;2`0P2k^k/20;:b/P80^k^k0P2c/k<40;Vi^@@0
]KFe00<0^k^k0;Ng]`2g]kL00P2e]KD20;Ng]`H0^KVi0P2g]kLE0?ooo`004`3oool40;Jf]P80^KVi
0P2g]kL20;bl_080];Bd0P2i^KT20;Jf]P030;Vi^@2g]kL0]kNg0080]kNg0P2i^KT20;Zj^P80];Bd
0P2f][H20;6a/@@0^KVi0P2c/k<20;Jf]P80^KVi0P2h^;P20;Fe]@80^k^k00<0][Jf0;>c/`2c/k<0
0P2a/K4209^KV`80SHf=0P1eMGD206a/K080H61P0P1?Cdl204a<C080BDU90P1:BTX2034a<@80<S8b
0P0e=CD204M7A`0303Ph>01^KVh0KVi^0080WIfM0P2TY:@209bLW080XJ6Q0P2PX:020:BTY080XJ6Q
0P2TY:@40:6QX@80Z:RX102NWYh309^KV`80WYjN0P2KVi/209>CT`80U9BD0P2BTY8208j>SP80S8b<
0P2:RXX208R8R080MGEe0P20P80205]KF`80EUIF0P1IFET2059BDP0305ADE01:BTX0BTY:0080@T92
0P0_;bl203Ti>@80KFe]0P1CDe<2065QH@80Jf][0P1CDe<2034a<@80@4100P16ATH205eMG@80Hf=S
0P1RHV800`1WIfL0Lg=c07=cL`02065QH@80LW9b0P1/K6`2075aL@80O7al0P1mOGd409JFUP80KVi^
0P1RHV8207AdM080KVi^0P1bLW8208>3P`0308j>SP2=SHd0SHf=0080R8R80P2GUiL20:^[Z`80/K6a
0P2c/k<20;:b/P80^KVi0P2e]KD20;Vi^@80]KFe0P2k^k/20;Fe]@80/k>c0P2i^KT30;Ng]`80^k^k
0P2c/k<20;Ng]`@0^KVi0P2e]KDE0?ooo`004`3oool40;Jf]P80^KVi0P2g]kL20;bl_080];Bd0P2i
^KT20;Jf]P030;Vi^@2g]kL0]kNg0080]kNg0P2i^KT20;Zj^P80];Bd0P2f][H20;6a/@@0^KVi0P2c
/k<20;Jf]P80^KVi0P2h^;P20;Fe]@80^k^k00<0][Jf0;>c/`2c/k<00P2a/K4209^KV`80SHf=0P1e
MGD206a/K080H61P0P1?Cdl204a<C080BDU90P1:BTX2034a<@80<S8b0P0e=CD204M7A`0303Ph>01^
KVh0KVi^0080WIfM0P2TY:@209bLW080XJ6Q0P2PX:020:BTY080XJ6Q0P2TY:@40:6QX@80Z:RX102N
WYh309^KV`80WYjN0P2KVi/209>CT`80U9BD0P2BTY8208j>SP80S8b<0P2:RXX208R8R080MGEe0P20
P80205]KF`80EUIF0P1IFET2059BDP0305ADE01:BTX0BTY:0080@T920P0_;bl203Ti>@80KFe]0P1C
De<2065QH@80Jf][0P1CDe<2034a<@80@4100P16ATH205eMG@80Hf=S0P1RHV800`1WIfL0Lg=c07=c
L`02065QH@80LW9b0P1/K6`2075aL@80O7al0P1mOGd409JFUP80KVi^0P1RHV8207AdM080KVi^0P1b
LW8208>3P`0308j>SP2=SHd0SHf=0080R8R80P2GUiL20:^[Z`80/K6a0P2c/k<20;:b/P80^KVi0P2e
]KD20;Vi^@80]KFe0P2k^k/20;Fe]@80/k>c0P2i^KT30;Ng]`80^k^k0P2c/k<20;Ng]`@0^KVi0P2e
]KDE0?ooo`004`3oool20;Fe]@80/[:b0P2k^k/20;>c/`@0^KVi0P2k^k/20;:b/P030;Vi^@2g]kL0
]kNg0080]KFe0P2k^k/20;Ng]`80]KFe0P2f][H20;Bd]080^KVi0P2g]kL20;Rh^080];Bd0P2i^KT2
0;fm_@80/[:b0P2i^KT00`2a/K40/k>c0;>c/`020:NWY`80VYZJ0P21PH4206a/K080JFUY0P1KFe/2
05ADE0@0BTY:0P0g=cL203Ti>@80=cLg0P13@d<204U9B@0305YJFP2KVi/0Vi^K0080Vi^K1P2QXJ42
09fMW@80Y:BT0P2HV9P20:>SX`80W9bL0P2HV9P20::RXP80VYZJ0P2GUiL209JFUP0309NGU`2IVIT0
VIVI0080UiNG0P2KVi/2092@T080Shn?0P2>SXh208^;R`80S8b<0P2:RXX208B4Q0@0OWin0P1JFUX2
04e=C@80De=C00<0B4Q804U9B@19BDT0100h>3P203<c<`80CTi>0P22PX8204U9B@80O7al0P1<C4`2
06EUI@80A4A40P1IFET204U9B@80Kfm_0P1IFET00`1TI6@0JFUY06UYJ@04065QH@80MgMg0P1UIFD2
08N7Q`80LW9b0P27QhL20:RXZ080PX:20P1OGel206UYJ@80LG5a0P1iNGT207YjNP0308V9R@2;Rh/0
Rh^;0080TY:B102ZZZX20:j^[P80]KFe0P2`/;020;Fe]@80^KVi0P2c/k<40;Vi^@80]kNg0P2e]KD2
0;Vi^@030;Ng]`2c/k<0/k>c0080^k^k0P2g]kL20;Fe]@80^KVi0P2e]KD20;Vi^AD0oooo000C0?oo
o`80]KFe0P2b/[820;^k^`80/k>c102i^KT20;^k^`80/[:b00<0^KVi0;Ng]`2g]kL00P2e]KD20;^k
^`80]kNg0P2e]KD20;Jf]P80];Bd0P2i^KT20;Ng]`80^;Rh0P2d];@20;Vi^@80_Kfm0P2b/[820;Vi
^@030;6a/@2c/k<0/k>c0080YjNW0P2JVYX20861P@80K6a/0P1YJFT205]KF`80E5AD101:BTX203Lg
=`80>CTi0P0g=cL204=3@`80BDU900<0FUYJ09^KV`2KVi/00P2KVi/60:6QX@80WIfM0P2TY:@209RH
V080Xj>S0P2LW9`209RHV080XZ:R0P2JVYX209NGU`80UYJF00<0UiNG09VIV@2IVIT00P2GUiL209^K
V`80T92@0P2?Shl208j>SP80Rh^;0P2<S8`208Z:RP80Q8B4101nOWh205YJFP80CDe=0P1CDe<00`18
B4P0BDU904U9B@0403Ph>080<c<c0P1>CTh208:2PP80BDU90P1lO7`204a<C080IFEU0P14A4@205UI
F@80BDU90P1_Kfl205UIF@0306ATI01YJFT0JFUY00@0HF5Q0P1gMgL206EUI@80QhN70P1bLW8208N7
Q`80Z:RX0P22PX8205mOG`80JFUY0P1aLG4207UiN@80NWYj00<0RHV908^;R`2;Rh/00P2BTY840:ZZ
ZP80[Zj^0P2e]KD20;2`/080]KFe0P2i^KT20;>c/`@0^KVi0P2g]kL20;Fe]@80^KVi00<0]kNg0;>c
/`2c/k<00P2k^k/20;Ng]`80]KFe0P2i^KT20;Fe]@80^KVi5@3oool001<0oooo0P2g]kL20;Fe]@80
^k^k0P2c/k<40;Vi^@80^k^k0`2e]KD60;Ng]`80^KVi0P2g]kL20;Fe]@80^KVi0P2e]KD20;Ng]`@0
][Jf102g]kL20;^k^`80^[Zj00<0[Jf]0:n_[`2_[jl00P2JVYX209BDU080Lg=c0P1[Jf/205QHF080
EEEE0P1?Cdl204e=C@80=CDe0P0g=cL2034a<@80;Bd]0P13@d<205QHF0L0WIfM0P2NWYh20:2PX080
VYZJ0P2IVIT209>CT`80TI6A0P2@T90408n?S`80TI6A1@2;Rh/209:BTP80SXj>0P2DU9@2092@T080
Ti>C102=SHd408Z:RP80QhN70P22PX8207inOP80Ph>30P1VIVH304e=C@80@d=30P0o?cl203De=@80
=cLg0P10@40206a/K080MGEe0P1IFET208^;R`80FEUI0P1_Kfl204E5A@80D51@0P1OGel206m_K`03
061PH01OGel0GemO0080KVi^0P1IFET2075aL@80Lg=c0P1kNg/207emO@80R8R80P2=SHd209BDU080
NGUi0P1ZJVX207AdM080N7Qh0P1bLW800`24Q8@0S8b<08b<S0020:FUY@80/[:b0P2ZZZX20;6a/@80
]KFe0P2^[Zh20;^k^`80]kNg0P2c/k<20;^k^`80/[:b0P2g]kL20;^k^`80/k>c00<0^KVi0;Fe]@2e
]KD0102i^KT20;^k^`80]KFe102i^KTE0?ooo`004`3oool20;Ng]`80]KFe0P2k^k/20;>c/`@0^KVi
0P2k^k/30;Fe]@H0]kNg0P2i^KT20;Ng]`80]KFe0P2i^KT20;Fe]@80]kNg102f][H40;Ng]`80^k^k
0P2j^[X00`2][Jd0[jn_0:n_[`0209ZJVP80U9BD0P1cLg<206][J`80F5QH0P1EEED204m?C`80CDe=
0P0e=CD203Lg=`80<C4a0P0];Bd204=3@`80F5QH1`2MWId209jNWP80X:2P0P2JVYX209VIV@80Ti>C
0P2ATI42092@T0@0Shn?0P2ATI4508^;R`80TY:B0P2>SXh209BDU080T92@0P2CTi<408f=S@@0RXZ:
0P27QhL208:2PP80OWin0P23Ph<206IVIP<0CDe=0P13@d<203lo?`80=CDe0P0g=cL20410@080K6a/
0P1eMGD205UIF@80Rh^;0P1IFET206m_K`80ADE50P1@D50205mOG`80Kfm_00<0H61P05mOG`1OGel0
0P1^KVh205UIF@80LG5a0P1cLg<207]kN`80OGem0P28R8P208f=S@80U9BD0P1iNGT206YZJP80M7Ad
0P1hN7P2079bLP0308B4Q02<S8`0S8b<0080YJFU0P2b/[820:ZZZP80/K6a0P2e]KD20:j^[P80^k^k
0P2g]kL20;>c/`80^k^k0P2b/[820;Ng]`80^k^k0P2c/k<00`2i^KT0]KFe0;Fe]@040;Vi^@80^k^k
0P2e]KD40;Vi^AD0oooo000C0?ooo`H0^KVi0P2e]KD60;Vi^@80]KFe00<0^k^k0;Ng]`2g]kL00P2g
]kL40;Fe]@80^KVi0P2k^k/20;Fe]@80^k^k0P2f][H20;Fe]@80];Bd0P2g]kL20;Fe]@80]kNg0P2l
_;`00`2c/k<0Y:BT0:BTY00209nOW`80RXZ:0P1aLG4206ATI080H61P101;Bd/204Q8B080>SXj0P0a
<C4203dm?@80Bd];0P0o?cl209jNWP0309bLW02RXZ80XZ:R0080X:2P0P2KVi/209ZJVP80W9bL0P2G
UiL2096AT@80SHf=0P26QXH208>3P`@0P8200P21PH4207emO@80Ph>31@25QHD208Z:RP80Rh^;102@
T902096AT@@0RXZ:0P27QhL208:2PP80OGem0P1nOWh207]kN`80G5aL00<0A4A40451@@11@D400P0h
>3P202XZ:P80<30`0P11@D42055AD@80Kfm_0P1KFe/205QHF080OGem0P1_Kfl207UiN@80C4a<0P1C
De<206][J`0306a/K01YJFT0JFUY0080HF5Q0P1YJFT206ATI080Ogmo0P1hN7P407inOP80SHf=0P2V
YZH207]kN`80N7Qh0P20P80207emO@80MGEe00<0Q8B408F5Q@25QHD00P2g]kL20:BTY080][Jf0P2a
/K420;Jf]P80/[:b0P2g]kL20;^k^`80]KFe0P2i^KT20;Jf]P80]KFe0P2k^k/30;Fe]@80^KVi0P2g
]kL80;Vi^@80^k^k5@3oool001<0oooo1P2i^KT20;Fe]@H0^KVi0P2e]KD00`2k^k/0]kNg0;Ng]`02
0;Ng]`@0]KFe0P2i^KT20;^k^`80]KFe0P2k^k/20;Jf]P80]KFe0P2d];@20;Ng]`80]KFe0P2g]kL2
0;bl_0030;>c/`2TY:@0Y:BT0080WinO0P2:RXX2075aL@80I6AT0P1PH60404];B`80B4Q80P0j>SX2
034a<@80?Cdm0P1;Bd/203lo?`80WYjN00<0W9bL0::RXP2RXZ800P2PX:0209^KV`80VYZJ0P2LW9`2
09NGU`80TI6A0P2=SHd208J6QP80Ph>31020P8020861P@80OGem0P23Ph<508F5Q@80RXZ:0P2;Rh/4
092@T080TI6A102:RXX208N7Q`80PX:20P1mOGd207inOP80Ng]k0P1LG5`00`14A4@0@D510451@@02
03Ph>080:RXZ0P0`<3020451@@80DE5A0P1_Kfl205]KF`80F5QH0P1mOGd206m_K`80NGUi0P1<C4`2
05=CD`80Jf][00<0K6a/06UYJ@1YJFT00P1QHF4206UYJ@80I6AT0P1oOgl207QhN0@0OWin0P2=SHd2
0:JVYP80Ng]k0P1hN7P20820P080OGem0P1eMGD00`24Q8@0QHF508F5Q@020;Ng]`80Y:BT0P2f][H2
0;6a/@80][Jf0P2b/[820;Ng]`80^k^k0P2e]KD20;Vi^@80][Jf0P2e]KD20;^k^`<0]KFe0P2i^KT2
0;Ng]`P0^KVi0P2k^k/E0?ooo`004`3oool20;Vi^@80^k^k0P2c/k<60;Vi^@80]KFe1@2i^KT20;^k
^`80/k>c202i^KT20;^k^`80]kNg0P2e]KD20;>c/`80][Jf0P2k^k/40;Fe]@030:b/[02SXj<0Xj>S
0080VYZJ0P1jNWX206e]K@80FEUI0P1KFe/2055AD@80@D510P0j>SX203Ti>@80=3@d0P0i>CT202DU
9@80VIVI0P2MWId00`2LW9`0WYjN09jNWP0209jNWP80Vi^K0P2IVIT208J6QP80MGEe0P1dM7@607Yj
NPH0MgMg0P1_Kfl206MWI`0306i^KP1ZJVX0JVYZ0080MGEe0P27QhL208B4Q080SHf=0P2@T90209>C
T`80SHf=0P2<S8`208R8R080QHF50P21PH4207]kN`80N7Qh0P1jNWX00`1=CDd0=SHf03Hf=P0203<c
<`809RHV0P0Z:RX203Ph>080BDU90P1jNWX207EeM@80DU9B0P27QhL207AdM080PH610P1lO7`206EU
I@80Fe]K00<0Kfm_071`L01`L7000P1NGUh206IVIP80H61P0P1lO7`2075aL@H0PX:20P2NWYh208b<
S080PH610P1nOWh207YjNP80OWin00<0RXZ:08j>SP2>SXh00P2XZ:P20:^[Z`80];Bd0P2^[Zh20;:b
/P80^;Rh0P2e]KD20;Jf]P80^[Zj0P2d];@20;Ng]`80^KVi0P2k^k/20;Fe]@030;Ng]`2k^k/0^k^k
0080]KFe0P2g]kL40;Vi^@80]kNg0P2i^KTE0?ooo`004`3oool20;Vi^@80^k^k0P2c/k<40;Vi^@80
]KFe0P2g]kL50;Vi^@80^k^k0P2c/k<40;Vi^@80]kNg0P2f][H20;Vi^@80^k^k0P2f][H20;Ng]`80
];Bd102h^;P20;Ng]`030:RXZ02JVYX0VYZJ0080Ti>C0P1eMGD205mOG`80FUYJ0P1>CTh204U9B@80
ATI60P10@40203De=@80>c/k0P16ATH2055AD@@0W9bL0`2KVi/209fMW@80TI6A0P25QHD208^;R`80
MWIf0P1`L70208b<S080Ogmo0P1jNWX207emO@80Q8B40P20P80207]kN`80Kfm_00<0KFe]06YZJP1Z
JVX00P1NGUh2071`L080QHF50P27QhL208f=S@80T92@0P2ATI4208Z:RP80Rh^;0P29RHT20861P@80
Ogmo0P1jNWX2079bLP0307UiN@18B4P0B4Q80080:b/[0P0X:2P2024Q8@80=SHf0P0Z:RX204I6AP80
S8b<0P1TI6@2061PH080OGem0P1aLG4208N7Q`80Ogmo0P1`L7000`1YJFT0Hf=S06=SH`0206i^KP@0
I6AT0P1]KFd207inOP80KVi^1025QHD209FEU@80U9BD0P1_Kfl207emO@80MWIf0P1hN7P00`2:RXX0
Xj>S0:>SX`020:BTY080[jn_0P2d];@20:b/[080]KFe0P2d];@20;Vi^@80];Bd0P2c/k<20;^k^`80
/k>c0P2i^KT20;Ng]`80^KVi00<0]KFe0;Vi^@2i^KT00P2i^KT20;Fe]@@0^KVi0P2c/k<20;Vi^AD0
oooo000C0?ooo`80^KVi0P2k^k/20;>c/`@0^KVi0P2e]KD20;Ng]`D0^KVi0P2k^k/20;>c/`@0^KVi
0P2g]kL20;Jf]P80^KVi0P2k^k/20;Jf]P80]kNg0P2d];@40;Rh^080]kNg00<0Z:RX09ZJVP2JVYX0
0P2CTi<207EeM@80GemO0P1JFUX204i>CP80BDU90P16ATH20410@080=CDe0P0k>c/204I6AP80DE5A
102LW9`309^KV`80WIfM0P2ATI4208F5Q@80Rh^;0P1fMWH2071`L080S8b<0P1oOgl207YjNP80OGem
0P24Q8@20820P080Ng]k0P1_Kfl00`1]KFd0JVYZ06YZJP0205iNGP80L71`0P25QHD208N7Q`80SHf=
0P2@T902096AT@80RXZ:0P2;Rh/208V9R@80PH610P1oOgl207YjNP80LW9b00<0NGUi04Q8B018B4P0
0P0[:b/202PX:0808B4Q0P0f=SH202XZ:P80ATI60P2<S8`206ATI080H61P0P1mOGd2075aL@80QhN7
0P1oOgl2071`L00306UYJ@1SHf<0Hf=S0080KVi^101TI6@206e]K@80OWin0P1^KVh408F5Q@80UIFE
0P2DU9@206m_K`80OGem0P1fMWH207QhN00308Z:RP2SXj<0Xj>S0080Y:BT0P2_[jl20;Bd]080[:b/
0P2e]KD20;Bd]080^KVi0P2d];@20;>c/`80^k^k0P2c/k<20;Vi^@80]kNg0P2i^KT00`2e]KD0^KVi
0;Vi^@020;Vi^@80]KFe102i^KT20;>c/`80^KVi5@3oool001<0oooo0P2g]kL20;Vi^@80]KFe0P2i
^KT20;Fe]@80^KVi0P2e]KD20;Ng]`030;Vi^@2g]kL0]kNg0080^KVi0P2e]KD20;Ng]`80^KVi0P2f
][H20;:b/P80]kNg0P2i^KT20;>c/`80^KVi0P2k^k/20;6a/@80^k^k0P2ZZZX00`2LW9`0TY:B09:B
TP0207]kN`80L71`0P1CDe<204i>CP80BDU90P1>CTh202l_;`80=SHf0P0e=CD204M7A`80<S8b0P2R
XZ8209jNWP80WIfM00<0Vi^K09VIV@2IVIT00P2NWYh209FEU@80N7Qh0P1eMGD207AdM080Hf=S0P1k
Ng/207emO@80M7Ad0P1[Jf/206YZJP80LG5a0P1RHV8206ATI00306i^KP1cLg<0Lg=c0080JVYZ0P1I
FET206e]K@80R8R80P2:RXX2092@T080Ti>C0P2>SXh208b<S080RXZ:0P24Q8@20861P@80O7al0P1j
NWX00`1eMGD0LG5a075aL@020410@080<S8b0P0K6a/202DU9@80C4a<0P0a<C4207AdM080QHF50P1C
De<208b<S080JVYZ0P1kNg/209NGU`80PH6100<0IVIV07MgM`1gMgL00P1PH60206MWI`80GemO0P1]
KFd207IfMP80MgMg0P1kNg/20820P080TY:B0P2LW9`207alO080LG5a0P1eMGD207YjNP0307AdM02^
[Zh0[Zj^0080[:b/0P2c/k<20;:b/P80Z:RX0P2i^KT20;bl_080][Jf0P2g]kL20;Fe]@80^k^k0P2e
]KD20;Vi^@80]kNg0P2e]KD00`2i^KT0^k^k0;^k^`020;Fe]@80^KVi0P2k^k/20;Ng]`80]KFe0P2k
^k/E0?ooo`004`3oool20;Ng]`80^KVi0P2e]KD20;Vi^@80]KFe0P2i^KT20;Fe]@80]kNg00<0^KVi
0;Ng]`2g]kL00P2i^KT20;Fe]@80]kNg0P2i^KT20;Jf]P80/[:b0P2g]kL20;Vi^@80/k>c0P2i^KT2
0;^k^`80/K6a0P2k^k/20:ZZZP0309bLW02BTY80TY:B0080Ng]k0P1`L70205=CD`80CTi>0P19BDT2
04i>CP80;bl_0P0f=SH203De=@80AdM70P0b<S820::RXP80WYjN0P2MWId00`2KVi/0VIVI09VIV@02
09jNWP80UIFE0P1hN7P207EeM@80M7Ad0P1SHf<207]kN`80OGem0P1dM7@206][J`80JVYZ0P1aLG42
069RHP80I6AT00<0KVi^07=cL`1cLg<00P1ZJVX205UIF@80KFe]0P28R8P208Z:RP80T92@0P2CTi<2
08j>SP80S8b<0P2:RXX208B4Q080PH610P1lO7`207YjNP0307EeM@1aLG40LG5a0080@4100P0b<S82
01/K6`809BDU0P1<C4`2034a<@80M7Ad0P25QHD205=CD`80S8b<0P1ZJVX207]kN`80UiNG0P21PH40
0`1VIVH0MgMg07MgM`02061PH080IfMW0P1OGel206e]K@80MWIf0P1gMgL207]kN`80P8200P2BTY82
09bLW080O7al0P1aLG4207EeM@80NWYj00<0M7Ad0:j^[P2^[Zh00P2/[:`20;>c/`80/[:b0P2XZ:P2
0;Vi^@80_;bl0P2f][H20;Ng]`80]KFe0P2k^k/20;Fe]@80^KVi0P2g]kL20;Fe]@030;Vi^@2k^k/0
^k^k0080]KFe0P2i^KT20;^k^`80]kNg0P2e]KD20;^k^aD0oooo000C0?ooo`80]kNg0P2e]KD20;^k
^`80]KFe0P2k^k/20;>c/`80^KVi0P2e]KD00`2i^KT0]KFe0;Fe]@020;>c/`80^k^k1P2e]KD40;Ng
]`80][Jf0P2b/[820;Vi^@80^[Zj0P2b/[820;no_`80Y:BT00<0VIVI08B4Q024Q8@00P1_Kfl205aL
G080DE5A0P18B4P204M7A`80<c<c0P12@T8202l_;`80@D510P0f=SH2071`L080X:2P102OWil00`2K
Vi/0T92@092@T00208:2PP80P8200P1CDe<2059BDP80FEUI0P1QHF4205aLG080F5QH0P1JFUX205iN
GP80CTi>0P15ADD204A4A080CDe=00<0>c/k055AD@1ADE400P1:BTX204Q8B080@T920P1XJ6P20861
P@@0T92@102>SXh208b<S080QXJ60P1oOgl20861P@80OGem00<0NWYj06m_K`1_Kfl00P1PH602024Q
8@8071`L0P0X:2P203@d=080@D510P1NGUh207inOP80G5aL0P1NGUh207moO`80IVIV0P1mOGd20;2`
/00308Z:RP1]KFd0KFe]0080J6QX0P1^KVh206=SH`80I6AT0P1cLg<206][J`80MgMg0P1lO7`209BD
U080WinO0P27QhL207alO080Ph>30P1gMgL00`1iNGT0ZZZZ0:ZZZP020:j^[P80/k>c0P2a/K420:f]
[@80]KFe102i^KT20;Ng]`80^KVi0P2g]kL20;^k^`80]KFe2`2i^KT20;Ng]`80^KVi0P2g]kL20;Vi
^AD0oooo000C0?ooo`80]kNg0P2e]KD20;^k^`80]KFe0P2k^k/20;>c/`80^KVi0P2e]KD00`2i^KT0
]KFe0;Fe]@020;>c/`80^k^k1P2e]KD40;Ng]`80][Jf0P2b/[820;Vi^@80^[Zj0P2b/[820;no_`80
Y:BT00<0VIVI08B4Q024Q8@00P1_Kfl205aLG080DE5A0P18B4P204M7A`80<c<c0P12@T8202l_;`80
@D510P0f=SH2071`L080X:2P102OWil00`2KVi/0T92@092@T00208:2PP80P8200P1CDe<2059BDP80
FEUI0P1QHF4205aLG080F5QH0P1JFUX205iNGP80CTi>0P15ADD204A4A080CDe=00<0>c/k055AD@1A
DE400P1:BTX204Q8B080@T920P1XJ6P20861P@@0T92@102>SXh208b<S080QXJ60P1oOgl20861P@80
OGem00<0NWYj06m_K`1_Kfl00P1PH602024Q8@8071`L0P0X:2P203@d=080@D510P1NGUh207inOP80
G5aL0P1NGUh207moO`80IVIV0P1mOGd20;2`/00308Z:RP1]KFd0KFe]0080J6QX0P1^KVh206=SH`80
I6AT0P1cLg<206][J`80MgMg0P1lO7`209BDU080WinO0P27QhL207alO080Ph>30P1gMgL00`1iNGT0
ZZZZ0:ZZZP020:j^[P80/k>c0P2a/K420:f][@80]KFe102i^KT20;Ng]`80^KVi0P2g]kL20;^k^`80
]KFe2`2i^KT20;Ng]`80^KVi0P2g]kL20;Vi^AD0oooo000C0?ooo`P0]kNg0P2k^k/20;Ng]`80/k>c
0P2i^KT00`2g]kL0]KFe0;Fe]@020;Fe]@80^KVi0P2g]kL40;Fe]@80]kNg0P2i^KT20;Fe]@80/k>c
0P2i^KT40;Fe]@80^KVi0P2UYJD00`2ATI40Lg=c07=cL`0206ATI080CTi>0P1?Cdl204=3@`80A4A4
0P13@d<203/k>`80@4100P0h>3P205UIF@80WinO0P2NWYh20::RXP80WYjN00<0Vi^K0:NWY`2WYjL0
0P2?Shl208j>SP80MGEe0P1NGUh205UIF@80Fe]K0P1TI6@205mOG`80Hf=S0P1UIFD205iNGP80GEeM
0P1DE5@205IFEP03061PH01GEeL0EeMG0080LG5a0P1cLg<206UYJ@80IVIV0P1iNGT2092@T080Shn?
0P2@T90408Z:RP80SXj>0P21PH4207moO`80OWin00<0PX:207EeM@1eMGD00P1[Jf/20451@@806a/K
0P0F5QH202/[:`80@4100P19BDT206EUI@80TI6A0P1?Cdl207alO080IVIV0P1^KVh208n?S`030:f]
[@1hN7P0N7Qh0080MGEe0P1TI6@206e]K@80IfMW0P1_Kfl2071`L080HF5Q0P22PX8208f=S@80UiNG
0P2BTY8207YjNP80RHV90P1iNGT00`2=SHd0YZJV0:JVYP020;:b/P80[:b/0P2^[Zh20;Ng]`80/;2`
0P2g]kL20;Vi^@80]KFe0P2k^k/20;Fe]@80^KVi0P2g]kL40;Vi^@030;Ng]`2i^KT0^KVi00@0^KVi
0P2e]KD20;^k^`80/k>c0P2i^KTE0?ooo`004`3oool80;Ng]`80^k^k0P2g]kL20;>c/`80^KVi00<0
]kNg0;Fe]@2e]KD00P2e]KD20;Vi^@80]kNg102e]KD20;Ng]`80^KVi0P2e]KD20;>c/`80^KVi102e
]KD20;Vi^@80YJFU00<0TI6A07=cL`1cLg<00P1TI6@204i>CP80Cdm?0P13@d<204A4A080@d=30P0k
>c/20410@080>3Ph0P1IFET209nOW`80WYjN0P2RXZ8209jNWP0309^KV`2WYjL0YjNW0080Shn?0P2>
SXh207EeM@80GUiN0P1IFET205]KF`80I6AT0P1OGel206=SH`80IFEU0P1NGUh205eMG@80E5AD0P1F
EUH00`1PH600EeMG05MGE`02075aL@80Lg=c0P1YJFT206IVIP80NGUi0P2@T90208n?S`80T92@102:
RXX208j>SP80PH610P1oOgl207inOP0308:2PP1eMGD0MGEe0080Jf][0P11@D4201/K6`805QHF0P0[
:b/20410@080BDU90P1UIFD2096AT@80Cdm?0P1lO7`206IVIP80KVi^0P2?Shl00`2][Jd0N7Qh07Qh
N00207EeM@80I6AT0P1]KFd206MWI`80Kfm_0P1`L702065QH@80PX:20P2=SHd209NGU`80TY:B0P1j
NWX208V9R@80NGUi00<0SHf=0:JVYP2VYZH00P2b/[820:b/[080[Zj^0P2g]kL20;2`/080]kNg0P2i
^KT20;Fe]@80^k^k0P2e]KD20;Vi^@80]kNg102i^KT00`2g]kL0^KVi0;Vi^@040;Vi^@80]KFe0P2k
^k/20;>c/`80^KVi5@3oool001<0oooo102g]kL20;Fe]@80/k>c102i^KT20;Ng]`80]KFe00<0^k^k
0;>c/`2c/k<00P2k^k/20;>c/`80^k^k0P2e]KD20;^k^`@0]kNg0P2e]KD20;Ng]`80][Jf0P2b/[82
0;Rh^080/K6a0P2QXJ400`27QhL0IfMW06MWI`02061PH080De=C0P13@d<204E5A@80?Cdm100n?Sh2
04=3@`80820P0P2OWil20:2PX080W9bL0P2NWYh20:6QX@0309fMW@2OWil0WinO0080UYJF0P2^[Zh2
09fMW@80TI6A0P2@T90208>3P`80Rh^;0P27QhL208:2PP80UYJF0P29RHT208^;R`80QXJ60P25QHD0
0`22PX80LW9b079bLP0208Z:RP80S8b<0P2:RXX208j>SP80Rh^;0P2@T90209:BTP80SXj>0P2<S8`2
08V9R@80S8b<0P28R8P20861P@80Ogmo00<0OWin07alO01lO7`00P1dM7@205YJFP80;bl_0P0B4Q82
02l_;`80>SXj0P14A4@204e=C@80L71`0P1YJFT2059BDP80Kfm_0P1FEUH208>3P`0308n?S`2YZJT0
ZJVY0080Kfm_0P1bLW8206][J`80GemO0P1[Jf/207MgM`80J6QX0P1nOWh207emO@80Ti>C0P2MWId2
07AdM080OWin0P1YJFT00`2OWil0[Zj^0:j^[P020:n_[`80[Zj^0P2ZZZX60;Ng]`80/k>c1P2i^KT2
0;^k^`80]KFe102i^KT00`2e]KD0]kNg0;Ng]`020;^k^`80]KFe102i^KT20;Fe]@80^KVi5@3oool0
01<0oooo102g]kL20;Fe]@80/k>c102i^KT20;Ng]`80]KFe00<0^k^k0;>c/`2c/k<00P2k^k/20;>c
/`80^k^k0P2e]KD20;^k^`@0]kNg0P2e]KD20;Ng]`80][Jf0P2b/[820;Rh^080/K6a0P2QXJ400`27
QhL0IfMW06MWI`02061PH080De=C0P13@d<204E5A@80?Cdm100n?Sh204=3@`80820P0P2OWil20:2P
X080W9bL0P2NWYh20:6QX@0309fMW@2OWil0WinO0080UYJF0P2^[Zh209fMW@80TI6A0P2@T90208>3
P`80Rh^;0P27QhL208:2PP80UYJF0P29RHT208^;R`80QXJ60P25QHD00`22PX80LW9b079bLP0208Z:
RP80S8b<0P2:RXX208j>SP80Rh^;0P2@T90209:BTP80SXj>0P2<S8`208V9R@80S8b<0P28R8P20861
P@80Ogmo00<0OWin07alO01lO7`00P1dM7@205YJFP80;bl_0P0B4Q8202l_;`80>SXj0P14A4@204e=
C@80L71`0P1YJFT2059BDP80Kfm_0P1FEUH208>3P`0308n?S`2YZJT0ZJVY0080Kfm_0P1bLW8206][
J`80GemO0P1[Jf/207MgM`80J6QX0P1nOWh207emO@80Ti>C0P2MWId207AdM080OWin0P1YJFT00`2O
Wil0[Zj^0:j^[P020:n_[`80[Zj^0P2ZZZX60;Ng]`80/k>c1P2i^KT20;^k^`80]KFe102i^KT00`2e
]KD0]kNg0;Ng]`020;^k^`80]KFe102i^KT20;Fe]@80^KVi5@3oool001<0oooo0P2g]kL20;Vi^@80
]kNg0P2e]KD20;^k^`80]KFe0P2i^KT20;Ng]`030;^k^`2e]KD0]KFe0080^k^k0P2c/k<20;Vi^@@0
]kNg0P2i^KT20;^k^`80/[:b0P2h^;P20;Ng]`80/k>c0P2_[jl20:JVYP80UiNG00<0NWYj05mOG`1O
Gel0101;Bd/204I6AP80=3@d100n?Sh203dm?@80C4a<0P1:BTX20:6QX@80W9bL0P2OWil20:2PX080
W9bL00<0WinO09bLW02LW9`00P2LW9`20:6QX@80X:2P0P2UYJD20:NWY`80XZ:R0P2JVYX20:RXZ080
Vi^K0P2HV9P209^KV`80X:2P0P2DU9@209NGU`0309BDU02?Shl0Shn?0080UIFE0P2BTY8409BDU080
TI6A0P2@T90209:BTP80TI6A0P2=SHd208^;R`80RXZ:0P25QHD208J6QP80O7al00<0Ng]k07QhN01h
N7P00P1fMWH2061PH080;Bd]0P0R8R8202HV9P80AdM70P1?Cdl205MGE`80GemO0P1[Jf/204U9B@80
JVYZ0P1UIFD206IVIP03092@T02PX:00X:2P0080Shn?0P1lO7`207AdM080K6a/0P1RHV8206ATI080
J6QX0P1eMGD2075aL@80Ti>C0P2LW9`20820P080PX:20P1LG5`00`2XZ:P0[Zj^0:j^[P020:ZZZP80
[jn_0P2[Zj/40;Vi^@80^k^k0P2c/k<40;Vi^@H0]kNg0P2k^k/20;Fe]@030;^k^`2e]KD0]KFe00@0
^KVi0P2k^k/20;Fe]@@0^KVi5@3oool001<0oooo0P2g]kL20;Vi^@80]kNg0P2e]KD20;^k^`80]KFe
0P2i^KT20;Ng]`030;^k^`2e]KD0]KFe0080^k^k0P2c/k<20;Vi^@@0]kNg0P2i^KT20;^k^`80/[:b
0P2h^;P20;Ng]`80/k>c0P2_[jl20:JVYP80UiNG00<0NWYj05mOG`1OGel0101;Bd/204I6AP80=3@d
100n?Sh203dm?@80C4a<0P1:BTX20:6QX@80W9bL0P2OWil20:2PX080W9bL00<0WinO09bLW02LW9`0
0P2LW9`20:6QX@80X:2P0P2UYJD20:NWY`80XZ:R0P2JVYX20:RXZ080Vi^K0P2HV9P209^KV`80X:2P
0P2DU9@209NGU`0309BDU02?Shl0Shn?0080UIFE0P2BTY8409BDU080TI6A0P2@T90209:BTP80TI6A
0P2=SHd208^;R`80RXZ:0P25QHD208J6QP80O7al00<0Ng]k07QhN01hN7P00P1fMWH2061PH080;Bd]
0P0R8R8202HV9P80AdM70P1?Cdl205MGE`80GemO0P1[Jf/204U9B@80JVYZ0P1UIFD206IVIP03092@
T02PX:00X:2P0080Shn?0P1lO7`207AdM080K6a/0P1RHV8206ATI080J6QX0P1eMGD2075aL@80Ti>C
0P2LW9`20820P080PX:20P1LG5`00`2XZ:P0[Zj^0:j^[P020:ZZZP80[jn_0P2[Zj/40;Vi^@80^k^k
0P2c/k<40;Vi^@H0]kNg0P2k^k/20;Fe]@030;^k^`2e]KD0]KFe00@0^KVi0P2k^k/20;Fe]@@0^KVi
5@3oool001<0oooo0P2e]KD20;>c/`80^KVi1P2g]kL20;Vi^@80]KFe00<0][Jf0;Vi^@2i^KT00P2k
^k/20;Fe]@80^k^k102e]KD20;Ng]`80^k^k0P2f][H20;Bd]080]KFe0P2i^KT20;Zj^P80TY:B0P1o
Ogl00`1WIfL0G5aL05aLG00204];B`80@T920P0i>CT20451@@80>SXj0P0o?cl20410@0808b<S0P2@
T90209nOW`80WYjN0P2QXJ4209jNWP80XZ:R00<0VYZJ0:BTY02TY:@00P2KVi/20:6QX@80WinO0P2U
YJD209nOW`80YJFU0P2OWil20:JVYPH0Vi^K0P2MWId2096AT@<0Ti>C0P2@T90209FEU@80TI6A0P2C
Ti<209^KV`80UIFE0P2>SXh209:BTP80Shn?0P2=SHd208j>SP80RXZ:0P24Q8@208J6QP80QHF500<0
NGUi07QhN01hN7P00P1kNg/206QXJ080BTY:0P0a<C4201PH6080>3Ph0P0n?Sh205IFEP80C4a<0P1^
KVh205QHF080CTi>0P1XJ6P206ATI0030820P02ATI40TI6A0080Ti>C0P28R8P207=cL`80KFe]0P1_
Kfl206IVIP80IfMW0P1UIFD207=cL`80S8b<0P2NWYh207]kN`80QHF50P1TI6@00`2XZ:P0/[:b0;:b
/P020:NWY`80Y:BT0P2d];@20;Ng]`80^KVi0P2k^k/20;>c/`@0^KVi102g]kL20;Fe]@80^KVi0P2g
]kL50;Vi^@@0]kNg102i^KT20;^k^aD0oooo000C0?ooo`80]KFe0P2c/k<20;Vi^@H0]kNg0P2i^KT2
0;Fe]@030;Jf]P2i^KT0^KVi0080^k^k0P2e]KD20;^k^`@0]KFe0P2g]kL20;^k^`80][Jf0P2d];@2
0;Fe]@80^KVi0P2j^[X209:BTP80Ogmo00<0IfMW05aLG01LG5`00P1;Bd/20492@P80>CTi0P11@D42
03Xj>P80?clo0P10@40202<S8`80T92@0P2OWil209jNWP80XJ6Q0P2NWYh20::RXP0309ZJVP2TY:@0
Y:BT0080Vi^K0P2QXJ4209nOW`80YJFU0P2OWil20:FUY@80WinO0P2VYZH609^KV`80WIfM0P2ATI43
09>CT`80T92@0P2EUID2096AT@80Ti>C0P2KVi/209FEU@80SXj>0P2BTY8208n?S`80SHf=0P2>SXh2
08Z:RP80Q8B40P26QXH208F5Q@0307UiN@1hN7P0N7Qh0080Ng]k0P1XJ6P204Y:BP80<C4a0P0H61P2
03Ph>080?Shn0P1FEUH204a<C080KVi^0P1HF5P204i>CP80J6QX0P1TI6@00`20P800TI6A096AT@02
09>CT`80R8R80P1cLg<206e]K@80Kfm_0P1VIVH206MWI`80IFEU0P1cLg<208b<S080WYjN0P1kNg/2
08F5Q@80I6AT00<0Z:RX0;:b/P2b/[800P2WYjL20:BTY080];Bd0P2g]kL20;Vi^@80^k^k0P2c/k<4
0;Vi^@@0]kNg0P2e]KD20;Vi^@80]kNg1@2i^KT40;Ng]`@0^KVi0P2k^k/E0?ooo`004`3oool20;Ng
]`80]KFe0P2i^KT20;Ng]`H0]KFe0P2l_;`00`2d];@0]kNg0;Ng]`040;Vi^@80^k^k0P2e]KD20;^k
^`80]KFe0P2k^k/20;Ng]`80][Jf0P2d];@20;6a/@80[jn_0P2HV9P207AdM00306=SH`18B4P0B4Q8
0080DE5A0P0i>CT20410@080<30`0P0l?3`20451@@80=cLg0P0H61P409nOW`80Vi^K0P2OWil20:>S
X`80X:2P00<0WYjN0:2PX02PX:000P2PX:060:6QX@80X:2P102QXJ4209jNWP80VIVI0P2FUYH209RH
V080UiNG0P2=SHd2096AT@0309JFUP2?Shl0Shn?0080UYJF0P2@T90209fMW@80SHf=0P2LW9`409NG
U`80Shn?0P2=SHd2092@T080Rh^;0P27QhL20820P080Ph>300<0OGem07AdM01dM7@00P1eMGD206m_
K`80CTi>0P0X:2P202TY:@80;2`/0P19BDT204m?C`80F5QH0P1LG5`2069RHP80C4a<0P1EEED205aL
G00306][J`21PH40PH610080VYZJ0P28R8P207emO@80KFe]0P1XJ6P2061PH080N7Qh0P1UIFD207]k
N`80P8200P2GUiL208>3P`80MWIf0P1oOgl00`2NWYh0[Zj^0:j^[P020;Bd]080WIfM0P2i^KT20;Fe
]@80^KVi0P2k^k/20;Fe]@80^k^k0P2e]KD20;Ng]`@0^KVi0P2k^k/20;>c/`030;Vi^@2g]kL0]kNg
0080^k^k0P2g]kL20;Fe]@H0^KVi5@3oool001<0oooo0P2g]kL20;Fe]@80^KVi0P2g]kL60;Fe]@80
_;bl00<0];Bd0;Ng]`2g]kL0102i^KT20;^k^`80]KFe0P2k^k/20;Fe]@80^k^k0P2g]kL20;Jf]P80
];Bd0P2a/K420:n_[`80V9RH0P1dM7@00`1SHf<0B4Q804Q8B002055AD@80>CTi0P10@402030`<080
?3`l0P11@D4203Lg=`8061PH102OWil209^KV`80WinO0P2SXj<20:2PX00309jNWP2PX:00X:2P0080
X:2P1P2QXJ420:2PX0@0XJ6Q0P2NWYh209VIV@80UYJF0P2HV9P209NGU`80SHf=0P2ATI400`2FUYH0
Shn?08n?S`0209JFUP80T92@0P2MWId208f=S@80W9bL102GUiL208n?S`80SHf=0P2@T90208^;R`80
QhN70P20P80208>3P`0307emO@1dM7@0M7Ad0080MGEe0P1_Kfl204i>CP80:2PX0P0Y:BT202`/;080
BDU90P1?Cdl205QHF080G5aL0P1RHV8204a<C080EEEE0P1LG5`00`1[Jf/0PH610861P@0209ZJVP80
R8R80P1mOGd206e]K@80J6QX0P1PH60207QhN080IFEU0P1kNg/20820P080UiNG0P23Ph<207IfMP80
Ogmo00<0WYjN0:j^[P2^[Zh00P2d];@209fMW@80^KVi0P2e]KD20;Vi^@80^k^k0P2e]KD20;^k^`80
]KFe0P2g]kL40;Vi^@80^k^k0P2c/k<00`2i^KT0]kNg0;Ng]`020;^k^`80]kNg0P2e]KD60;Vi^AD0
oooo000C0?ooo`80^KVi0P2k^k/20;Fe]@80^k^k0P2g]kL20;Fe]@@0^KVi00<0^k^k0;Fe]@2e]KD0
0P2g]kL80;Vi^@@0]kNg0P2i^KT60;Ng]`80UIFE0P2>SXh206a/K0<0FEUI0P10@40204I6AP80>c/k
0P12@T8203Xj>P80=SHf0P1CDe<202d];@80WYjN0P2LW9`209^KV`80X:2P102QXJ400`2TY:@0X:2P
0:2PX0020:6QX@80X:2P0P2QXJ420::RXP80WinO0P2MWId209jNWP@0TY:B0P26QXH209FEU@80SHf=
0P27QhL208Z:RP03096AT@2?Shl0Shn?0080TI6A0P2CTi<209bLW080V9RH0P2DU9@409ZJVP@0TI6A
102<S8`208F5Q@80QXJ60P1oOgl00`22PX80O7al07alO002071`L080JFUY0P1LG5`203Xj>P80<30`
0P0_;bl203lo?`80B4Q8101CDe<206ATI080DE5A0P1=CDd204=3@`0306QXJ01kNg/0Ng]k0080Ogmo
0P2ATI4208V9R@80KVi^0P1dM7@205QHF080L71`0P1_Kfl207inOP80N7Qh0P2IVIT208^;R`80Hf=S
0P2KVi/00`2EUID0/[:b0;:b/P020:n_[`80/K6a0P2e]KD80;Vi^@80]kNg0P2k^k/20;Fe]@@0^KVi
0P2k^k/20;Fe]@030;Vi^@2c/k<0/k>c00@0^KVi0P2g]kL60;Vi^AD0oooo000C0?ooo`80^KVi0P2k
^k/20;Fe]@80^k^k0P2g]kL20;Fe]@@0^KVi00<0^k^k0;Fe]@2e]KD00P2g]kL80;Vi^@@0]kNg0P2i
^KT60;Ng]`80UIFE0P2>SXh206a/K0<0FEUI0P10@40204I6AP80>c/k0P12@T8203Xj>P80=SHf0P1C
De<202d];@80WYjN0P2LW9`209^KV`80X:2P102QXJ400`2TY:@0X:2P0:2PX0020:6QX@80X:2P0P2Q
XJ420::RXP80WinO0P2MWId209jNWP@0TY:B0P26QXH209FEU@80SHf=0P27QhL208Z:RP03096AT@2?
Shl0Shn?0080TI6A0P2CTi<209bLW080V9RH0P2DU9@409ZJVP@0TI6A102<S8`208F5Q@80QXJ60P1o
Ogl00`22PX80O7al07alO002071`L080JFUY0P1LG5`203Xj>P80<30`0P0_;bl203lo?`80B4Q8101C
De<206ATI080DE5A0P1=CDd204=3@`0306QXJ01kNg/0Ng]k0080Ogmo0P2ATI4208V9R@80KVi^0P1d
M7@205QHF080L71`0P1_Kfl207inOP80N7Qh0P2IVIT208^;R`80Hf=S0P2KVi/00`2EUID0/[:b0;:b
/P020:n_[`80/K6a0P2e]KD80;Vi^@80]kNg0P2k^k/20;Fe]@@0^KVi0P2k^k/20;Fe]@030;Vi^@2c
/k<0/k>c00@0^KVi0P2g]kL60;Vi^AD0oooo000C0?ooo`@0]kNg2P2i^KT20;Ng]`<0^KVi0P2c/k<4
0;Vi^@80]kNg0P2k^k/40;Ng]`80/k>c0P2i^KT20;bl_080][Jf0P2BTY82075aL@80I6AT00<0Bd];
04I6AP16ATH00P17AdL203Hf=P80=CDe0P0m?Cd203lo?`80=CDe0P0Y:BT207=cL`80VYZJ0P2LW9`2
09^KV`H0XJ6Q00<0WinO0:FUY@2UYJD00P2RXZ8209jNWP@0XJ6Q0P2SXj<209VIV@80V9RH0P2BTY82
08^;R`80PH610P28R8P208N7Q`80P8200P26QXH00`29RHT0SHf=08f=S@0208j>SP80U9BD0P2BTY82
09JFUP80Vi^K0P2OWil209JFUP80UIFE0P2GUiL2092@T080SHf=0P27QhL208J6QP<0Ogmo0P1jNWX2
07IfMP80KFe]0P1KFe/203`l?0804a<C0P0R8R8203@d=080ATI60P19BDT2051@D080DE5A0P1QHF42
04e=C@80BDU900<0>c/k07QhN01hN7P00P26QXH20820P080T92@0P1bLW8207YjNP80J6QX0P1VIVH2
06][J`80M7Ad0P1eMGD209JFUP80Vi^K0P1bLW820:^[Z`0308f=S@2/[:`0[:b/0080X:2P2P2i^KT2
0;^k^`80/k>c2P2i^KT20;^k^`030;Ng]`2e]KD0]KFe0080^KVi0P2k^k/20;>c/`H0^KVi5@3oool0
01<0oooo102g]kL:0;Vi^@80]kNg0`2i^KT20;>c/`@0^KVi0P2g]kL20;^k^`@0]kNg0P2c/k<20;Vi
^@80_;bl0P2f][H209:BTP80LG5a0P1TI6@00`1;Bd/0ATI604I6AP0204M7A`80=SHf0P0e=CD203dm
?@80?clo0P0e=CD202TY:@80Lg=c0P2JVYX209bLW080Vi^K1P2QXJ400`2OWil0YJFU0:FUY@020::R
XP80WYjN102QXJ420:>SX`80VIVI0P2HV9P209:BTP80Rh^;0P21PH4208R8R080QhN70P20P80208J6
QP0308V9R@2=SHd0SHf=0080SXj>0P2DU9@209:BTP80UYJF0P2KVi/209nOW`80UYJF0P2EUID209NG
U`80T92@0P2=SHd208N7Q`80QXJ60`1oOgl207YjNP80MWIf0P1]KFd205]KF`80?3`l0P0C4a<2028R
8P80=3@d0P16ATH204U9B@80D51@0P1ADE42065QH@80CDe=0P19BDT00`0k>c/0N7Qh07QhN00208J6
QP80P8200P2@T902079bLP80NWYj0P1XJ6P206IVIP80Jf][0P1dM7@207EeM@80UYJF0P2KVi/2079b
LP80Zj^[00<0SHf=0:b/[02/[:`00P2PX:0:0;Vi^@80^k^k0P2c/k<:0;Vi^@80^k^k00<0]kNg0;Fe
]@2e]KD00P2i^KT20;^k^`80/k>c1P2i^KTE0?ooo`004`3oool20;Ng]`80]KFe202i^KT20;^k^`80
]KFe00<0^KVi0;Ng]`2g]kL00P2e]KD40;Vi^@80]KFe102i^KT20;bl_080];Bd0P2k^k/20;Ng]`80
];Bd0P28R8P206ATI080Cdm?00<0BDU903Ph>00h>3P00P0o?cl203hn?P80?Cdm0P0j>SX203<c<`80
<C4a0P0<30`209ZJVPH0Vi^K0P2QXJ420:2PX080Y:BT00<0Xj>S0:6QX@2QXJ400P2RXZ8209nOW`80
X:2P0P2HV9P208F5Q@80Rh^;0P2KVi/209>CT`80UIFE0P1]KFd2069RHP80L71`0P1gMgL207=cL`03
07QhN022PX80PX:20080SHf=0P2@T90209^KV`80U9BD102KVi/209nOW`80TY:B0P2IVIT209:BTP80
SHf=0P2;Rh/208R8R080PH6100<0Ogmo08:2PP22PX800P1bLW8206UYJ@80Hf=S0P17AdL201lO7`80
7QhN0P0V9RH203Ti>@80@4100P1@D50204U9B@80GUiN0P1<C4`205MGE`0303dm?@1`L700L71`0080
Kfm_0P1fMWH209bLW080Ng]k0P1`L70206ATI080GEeM0P1YJFT206e]K@80Lg=c102DU9@209JFUP80
SXj>00<0Xj>S09VIV@2IVIT00P2OWil:0;Vi^@80^k^k0P2e]KDA0;Vi^@80^k^k0P2e]KD40;Vi^@80
]kNg5@3oool001<0oooo0P2g]kL20;Fe]@P0^KVi0P2k^k/20;Fe]@030;Vi^@2g]kL0]kNg0080]KFe
102i^KT20;Fe]@@0^KVi0P2l_;`20;Bd]080^k^k0P2g]kL20;Bd]080R8R80P1TI6@204m?C`0304U9
B@0h>3P0>3Ph0080?clo0P0n?Sh203dm?@80>SXj0P0c<c<2034a<@8030`<0P2JVYX609^KV`80XJ6Q
0P2PX:020:BTY0030:>SX`2QXJ40XJ6Q0080XZ:R0P2OWil20:2PX080V9RH0P25QHD208^;R`80Vi^K
0P2CTi<209FEU@80KFe]0P1RHV82071`L080MgMg0P1cLg<00`1hN7P0PX:208:2PP0208f=S@80T92@
0P2KVi/209BDU0@0Vi^K0P2OWil209:BTP80VIVI0P2BTY8208f=S@80Rh^;0P28R8P20861P@0307mo
O`22PX80PX:20080LW9b0P1YJFT206=SH`80AdM70P0O7al201hN7P809RHV0P0i>CT20410@080D51@
0P19BDT205iNGP80C4a<0P1GEeL00`0m?Cd0L71`071`L00206m_K`80MWIf0P2LW9`207]kN`80L71`
0P1TI6@205eMG@80JFUY0P1]KFd207=cL`@0U9BD0P2FUYH208j>SP030:>SX`2IVIT0VIVI0080WinO
2P2i^KT20;^k^`80]KFe4@2i^KT20;^k^`80]KFe102i^KT20;Ng]aD0oooo000C0?ooo`H0]kNg0P2i
^KT40;Ng]`80^KVi0P2k^k/00`2e]KD0^KVi0;Vi^@020;Ng]`80^KVi0P2e]KD20;Ng]`X0^KVi0P2k
^k/20:JVYP80N7Qh0P1QHF4205IFEP0304A4A013@d<0@d=30080=3@d0P0k>c/203dm?@80=cLg0P0a
<C4203hn?P805ADE0P2MWId209ZJVP80WYjN0P2LW9`20:FUY@80W9bL0P2QXJ400`2VYZH0WinO09nO
W`020:6QX@80XZ:R0P2MWId20;Jf]P80W9bL0P1hN7P209fMW@80XJ6Q0P2JVYX20:2PX080Ng]k0P1b
LW8207alO080Ti>C00<0KVi^07IfMP1fMWH00P23Ph<208f=S@P0Vi^K0P2JVYX209^KV`80VIVI0P2G
UiL208n?S`80SXj>0P27QhL208J6QP0307emO@1lO7`0O7al0080N7Qh0P1bLW8206=SH`80FEUI100G
5aL2024Q8@80;Rh^0P0n?Sh204Q8B080ADE50P1EEED2055AD@80ADE500<0<30`03hn?P0n?Sh00P1a
LG4207moO`80Ng]k0P25QHD406][J`80EEEE0P1XJ6P206MWI`80MGEe0P2?Shl208R8R080ZZZZ0P1f
MWH00`2_[jl0SXj>08j>SP020;Vi^@80]kNg2P2i^KT20;Ng]`P0^KVi0P2g]kL90;Vi^@@0]kNg0P2k
^k/20;Fe]AD0oooo000C0?ooo`H0]kNg0P2i^KT40;Ng]`80^KVi0P2k^k/00`2e]KD0^KVi0;Vi^@02
0;Ng]`80^KVi0P2e]KD20;Ng]`X0^KVi0P2k^k/20:JVYP80N7Qh0P1QHF4205IFEP0304A4A013@d<0
@d=30080=3@d0P0k>c/203dm?@80=cLg0P0a<C4203hn?P805ADE0P2MWId209ZJVP80WYjN0P2LW9`2
0:FUY@80W9bL0P2QXJ400`2VYZH0WinO09nOW`020:6QX@80XZ:R0P2MWId20;Jf]P80W9bL0P1hN7P2
09fMW@80XJ6Q0P2JVYX20:2PX080Ng]k0P1bLW8207alO080Ti>C00<0KVi^07IfMP1fMWH00P23Ph<2
08f=S@P0Vi^K0P2JVYX209^KV`80VIVI0P2GUiL208n?S`80SXj>0P27QhL208J6QP0307emO@1lO7`0
O7al0080N7Qh0P1bLW8206=SH`80FEUI100G5aL2024Q8@80;Rh^0P0n?Sh204Q8B080ADE50P1EEED2
055AD@80ADE500<0<30`03hn?P0n?Sh00P1aLG4207moO`80Ng]k0P25QHD406][J`80EEEE0P1XJ6P2
06MWI`80MGEe0P2?Shl208R8R080ZZZZ0P1fMWH00`2_[jl0SXj>08j>SP020;Vi^@80]kNg2P2i^KT2
0;Ng]`P0^KVi0P2g]kL90;Vi^@@0]kNg0P2k^k/20;Fe]AD0oooo000C0?ooo`@0]kNg0P2e]KD20;^k
^`80]kNg0P2e]KD20;Vi^@80]kNg00<0^KVi0;^k^`2k^k/00P2e]KD20;>c/`80^k^k0P2e]KD40;Vi
^@80][Jf0P2i^KT40;^k^`80XJ6Q0P1VIVH205IFEP80>c/k00<0@d=30451@@11@D400P0n?Sh203/k
>`80@4100P0`<30202/[:`80?Cdm0P0j>SX409^KV`80WIfM0P2NWYh20:NWY`80YZJV0P2OWil00`2Y
ZJT0X:2P0:2PX0020::RXP80WinO0P2NWYh20:NWY`@0X:2P1P2RXZ8209NGU`80SHf=0P2;Rh/208Z:
RP80T92@00<0SXj>07alO01lO7`00P1nOWh208j>SP80Vi^K102LW9`209^KV`80WinO0P2CTi<209FE
U@80VIVI0P2DU9@208j>SP80S8b<0P28R8P00`1nOWh0MWIf07IfMP0207MgM`80K6a/0P1UIFD205YJ
FP806ATI0P0L71`201PH6080;bl_0P0o?cl204Y:BP80@T920P16ATH2059BDP80B4Q800<0>CTi028R
8P0R8R800P1oOgl207IfMP80N7Qh0P2>SXh206MWI`80L71`0P1NGUh2065QH@80KVi^0P1dM7@208:2
PP80V9RH0P2OWil208^;R`0307inOP2i^KT0^KVi0080^k^k0P2c/k<80;Vi^@80^k^k0P2e]KD20;Vi
^@80]kNg0P2i^KT20;^k^`80]KFe1`2i^KT20;^k^`80]kNg0P2c/k<40;Vi^AD0oooo000C0?ooo`@0
]kNg0P2e]KD20;^k^`80]kNg0P2e]KD20;Vi^@80]kNg00<0^KVi0;^k^`2k^k/00P2e]KD20;>c/`80
^k^k0P2e]KD40;Vi^@80][Jf0P2i^KT40;^k^`80XJ6Q0P1VIVH205IFEP80>c/k00<0@d=30451@@11
@D400P0n?Sh203/k>`80@4100P0`<30202/[:`80?Cdm0P0j>SX409^KV`80WIfM0P2NWYh20:NWY`80
YZJV0P2OWil00`2YZJT0X:2P0:2PX0020::RXP80WinO0P2NWYh20:NWY`@0X:2P1P2RXZ8209NGU`80
SHf=0P2;Rh/208Z:RP80T92@00<0SXj>07alO01lO7`00P1nOWh208j>SP80Vi^K102LW9`209^KV`80
WinO0P2CTi<209FEU@80VIVI0P2DU9@208j>SP80S8b<0P28R8P00`1nOWh0MWIf07IfMP0207MgM`80
K6a/0P1UIFD205YJFP806ATI0P0L71`201PH6080;bl_0P0o?cl204Y:BP80@T920P16ATH2059BDP80
B4Q800<0>CTi028R8P0R8R800P1oOgl207IfMP80N7Qh0P2>SXh206MWI`80L71`0P1NGUh2065QH@80
KVi^0P1dM7@208:2PP80V9RH0P2OWil208^;R`0307inOP2i^KT0^KVi0080^k^k0P2c/k<80;Vi^@80
^k^k0P2e]KD20;Vi^@80]kNg0P2i^KT20;^k^`80]KFe1`2i^KT20;^k^`80]kNg0P2c/k<40;Vi^AD0
oooo000C0?ooo`P0^KVi0P2g]kL40;Vi^@80]KFe0`2i^KT20;Ng]`80/k>c102i^KT20;Jf]P80^k^k
0P2b/[820;Ng]`80^KVi0P2n_[h2096AT@80GUiN101>CTh00`0m?Cd0?Shn03hn?P0204=3@`80@D51
0P0m?Cd402h^;P809BDU0P1]KFd209ZJVP@0X:2P0P2OWil20:BTY0@0YJFU0`2VYZH20:>SX`80X:2P
0P2IVIT20:ZZZP80WIfM0P2UYJD20:RXZ080YjNW102OWil209:BTP@0S8b<0`2:RXX208N7Q`80QHF5
0P2@T90409^KV`80WinO102LW9`209nOW`80V9RH0P2FUYH209>CT`80TY:B102=SHd00`27QhL0Ng]k
07]kN`0207IfMP80KVi^0P1TI6@205EEE@80=SHf0P0:2PX201dM7@@0:RXZ0P12@T82051@D080ADE5
0P18B4P20492@P03059BDP0i>CT0>CTi0080Kfm_0P1^KVh20820P080VIVI0P1[Jf/2079bLP@0Hf=S
0P1TI6@206a/K080Ph>30P2FUYH209NGU`80U9BD00<0Vi^K0;Vi^@2i^KT00P2k^k/20;Fe]@P0^KVi
102g]kL20;^k^`80]KFe3`2i^KT20;^k^`80]KFe102i^KTE0?ooo`004`3oool80;Vi^@80]kNg102i
^KT20;Fe]@<0^KVi0P2g]kL20;>c/`@0^KVi0P2f][H20;^k^`80/[:b0P2g]kL20;Vi^@80_[jn0P2A
TI4205iNGP@0CTi>00<0?Cdm03hn?P0n?Sh00P13@d<20451@@80?Cdm100^;Rh202DU9@80KFe]0P2J
VYX40:2PX080WinO0P2TY:@40:FUY@<0YZJV0P2SXj<20:2PX080VIVI0P2ZZZX209fMW@80YJFU0P2X
Z:P20:NWY`@0WinO0P2BTY8408b<S0<0RXZ:0P27QhL208F5Q@80T92@102KVi/209nOW`@0W9bL0P2O
Wil209RHV080UYJF0P2CTi<209:BTP@0SHf=00<0QhN707]kN`1kNg/00P1fMWH206i^KP80I6AT0P1E
EED203Hf=P802PX:0P0M7Ad402XZ:P80@T920P1@D50204E5A@80B4Q80P12@T800`1BDU80>CTi03Ti
>@0206m_K`80KVi^0P20P80209VIV@80Jf][0P1bLW8406=SH`80I6AT0P1/K6`208>3P`80UYJF0P2G
UiL209BDU00309^KV`2i^KT0^KVi0080^k^k0P2e]KD80;Vi^@@0]kNg0P2k^k/20;Fe]@l0^KVi0P2k
^k/20;Fe]@@0^KVi5@3oool001<0oooo1P2i^KT20;^k^`80]KFe0P2k^k/20;Fe]@<0^KVi0P2c/k<2
0;^k^`80/k>c0P2g]kL20;bl_080];Bd0P2i^KT20;Ng]`80]KFe0P2k^k/20:JVYP80NWYj0P1JFUX2
03/k>`<0?Cdm0P0n?Sh20451@@80@4100P0V9RH202`/;0807alO0P071`L209ZJVP80Vi^K0P2PX:02
09jNWPH0YJFU0P2TY:@00`2VYZH0Y:BT0:BTY0020:VYZ@80Xj>S0P2JVYX40::RXP80XJ6Q0P2ZZZX2
0:NWY`80X:2P0P2JVYX2092@T080R8R80P27QhL308V9R@80QhN70P2>SXh209BDU080W9bL0P2JVYX2
0:6QX@@0WIfM102KVi/209nOW`80UYJF0P2CTi<208b<S080SXj>00<0RHV908F5Q@25QHD00P1jNWX2
06i^KP80IVIV0P1OGel204e=C@804a<C0P0E5AD202LW9`80ADE50P0h>3P204m?C`80BTY:0P1<C4`2
0410@00303lo?`1;Bd/0Bd];0080GUiN0P1/K6`20861P@80SHf=0P1nOWh2065QH@80J6QX0P1PH602
06a/K080J6QX0P27QhL209BDU080Ogmo0P2ATI400`2e]KD0]kNg0;Ng]`020;Vi^@H0]kNg0P2i^KT2
0;^k^`80]kNg0P2c/k<A0;Vi^@80]kNg202i^KTE0?ooo`004`3oool60;Vi^@80^k^k0P2e]KD20;^k
^`80]KFe0`2i^KT20;>c/`80^k^k0P2c/k<20;Ng]`80_;bl0P2d];@20;Vi^@80]kNg0P2e]KD20;^k
^`80YZJV0P1jNWX205YJFP80>c/k0`0m?Cd203hn?P80@D510P10@40202HV9P80;2`/0P0O7al200L7
1`80VYZJ0P2KVi/20:2PX080WYjN1P2UYJD20:BTY0030:JVYP2TY:@0Y:BT0080ZJVY0P2SXj<209ZJ
VP@0XZ:R0P2QXJ420:ZZZP80YjNW0P2PX:0209ZJVP80T92@0P28R8P208N7Q`<0RHV90P27QhL208j>
SP80U9BD0P2LW9`209ZJVP80XJ6Q102MWId409^KV`80WinO0P2FUYH209>CT`80S8b<0P2>SXh00`29
RHT0QHF508F5Q@0207YjNP80KVi^0P1VIVH205mOG`80CDe=0P0C4a<201DE5@809bLW0P15ADD203Ph
>080Cdm?0P1:BTX204a<C080@41000<0?clo04];B`1;Bd/00P1NGUh206a/K080PH610P2=SHd207in
OP80HF5Q0P1XJ6P2061PH080K6a/0P1XJ6P208N7Q`80U9BD0P1oOgl2096AT@030;Fe]@2g]kL0]kNg
0080^KVi1P2g]kL20;Vi^@80^k^k0P2g]kL20;>c/a40^KVi0P2g]kL80;Vi^AD0oooo000C0?ooo`H0
]kNg1P2i^KT20;Ng]`80^k^k00<0]kNg0;Fe]@2e]KD00P2k^k/20;Ng]`80]KFe0P2g]kL20;^k^`80
/k>c102i^KT20;^k^`80ZZZZ0P1YJFT204M7A`@0?Shn00<0@T920410@010@4000P0o?cl201hN7P80
:RXZ0P0Q8B4202l_;`800@410P2KVi/209nOW`80YJFU0P2NWYh40:FUY@80Y:BT1`2UYJD20:RXZ080
Xj>S0P2QXJ4209bLW080XJ6Q0P2TY:@20:6QX@80WYjN0P2KVi/208n?S`80QHF50P27QhL208b<S003
08N7Q`2=SHd0SHf=0080TY:B0P2KVi/209bLW080VYZJ0P2NWYh20:>SX`80W9bL0P2MWId409^KV`80
WIfM0P2EUID208n?S`80SHf=00<0RXZ:08R8R028R8P00P24Q8@207EeM@80J6QX0P1NGUh2055AD@80
5aLG0P0Q8B42028R8P80<C4a0P0o?cl204=3@`80ADE50P1DE5@204I6AP0304M7A`18B4P0B4Q80080
H61P0P1^KVh207EeM@80QhN70P2CTi<2065QH@80H61P0P1KFe/2069RHP80JVYZ0P2<S8`20:NWY`80
OWin0P2KVi/00`2k^k/0]KFe0;Fe]@020;^k^`@0]kNg0P2e]KD40;Vi^@80^k^k0P2e]KD80;Vi^@80
]kNg1@2i^KT20;^k^`80/k>c0P2g]kL60;Vi^AD0oooo000C0?ooo`@0]kNg0P2e]KD60;Vi^@80]KFe
2`2i^KT20;Fe]@80^KVi0P2e]KD40;Ng]`80^[Zj0P2][Jd205mOG`80B4Q80P12@T8203hn?P030492
@P0o?cl0?clo0080@T920P0`<30201hN7P809RHV0P0j>SX203Lg=`80Vi^K0P2OWil20:JVYPH0Y:BT
0P2UYJD30:RXZ080YjNW0P2TY:@20:FUY@80ZJVY102QXJ4209ZJVP80ZJVY0P2RXZ8209jNWP@0TI6A
0P26QXH208^;R`80SXj>00<0S8b<08n?S`2?Shl00P2LW9`209fMW@@0W9bL0P2MWId20:JVYP80WIfM
0P2OWil209bLW080Vi^K0P2MWId209:BTP80U9BD0P2>SXh00`2=SHd0PX:208:2PP0208J6QP80NWYj
0P1[Jf/205iNGP80FUYJ0P0[:b/200h>3P80:2PX0P0T92@203`l?080AdM70P13@d<204E5A@80EEEE
00<0B4Q804U9B@19BDT00P1SHf<207IfMP80MgMg0P22PX82096AT@80JVYZ0P1KFe/205UIF@80HF5Q
0P1RHV8208R8R080VYZJ0P2>SXh20;Fe]AT0^KVi0P2k^k/20;Fe]@D0^KVi0P2k^k/20;Ng]`80]KFe
102i^KT20;Ng]aD0oooo000C0?ooo`@0]kNg0P2e]KD60;Vi^@80]KFe2`2i^KT20;Fe]@80^KVi0P2e
]KD40;Ng]`80^[Zj0P2][Jd205mOG`80B4Q80P12@T8203hn?P030492@P0o?cl0?clo0080@T920P0`
<30201hN7P809RHV0P0j>SX203Lg=`80Vi^K0P2OWil20:JVYPH0Y:BT0P2UYJD30:RXZ080YjNW0P2T
Y:@20:FUY@80ZJVY102QXJ4209ZJVP80ZJVY0P2RXZ8209jNWP@0TI6A0P26QXH208^;R`80SXj>00<0
S8b<08n?S`2?Shl00P2LW9`209fMW@@0W9bL0P2MWId20:JVYP80WIfM0P2OWil209bLW080Vi^K0P2M
WId209:BTP80U9BD0P2>SXh00`2=SHd0PX:208:2PP0208J6QP80NWYj0P1[Jf/205iNGP80FUYJ0P0[
:b/200h>3P80:2PX0P0T92@203`l?080AdM70P13@d<204E5A@80EEEE00<0B4Q804U9B@19BDT00P1S
Hf<207IfMP80MgMg0P22PX82096AT@80JVYZ0P1KFe/205UIF@80HF5Q0P1RHV8208R8R080VYZJ0P2>
SXh20;Fe]AT0^KVi0P2k^k/20;Fe]@D0^KVi0P2k^k/20;Ng]`80]KFe102i^KT20;Ng]aD0oooo000C
0?ooo`P0]kNg0P2k^k/20;Fe]@/0^KVi0P2c/k<20;Vi^@80]KFe0P2k^k/40;Fe]@80/[:b0P2EUID2
05eMG@@0@T920P13@d<00`15ADD0?clo03lo?`0202/[:`809BDU0P0J6QX2038b<P80?Cdm0P2;Rh/2
09nOW`80X:2P0P2XZ:P20:BTY080YJFU0P2WYjL20:6QX@<0YjNW0P2ZZZX20:BTY0@0YJFU0P2WYjL2
0:JVYP80Vi^K0P2UYJD20:VYZ@80XJ6Q0P2IVIT208f=S@80S8b<0P2;Rh/2092@T00308n?S`2CTi<0
Ti>C0080VYZJ102PX:020:6QX@80Vi^K0P2VYZH20:6QX@80Xj>S0P2OWil209jNWP80X:2P0P2IVIT2
09FEU@80U9BD00<0Shn?08V9R@29RHT00P21PH4208F5Q@80MGEe0P1OGel205MGE`80Bd];0P0];Bd2
02TY:@80>c/k0P0e=CD204U9B@80C4a<0P18B4P204a<C00304];B`1:BTX0BTY:0080Fe]K0P1oOgl2
07alO080P8200P2NWYh2061PH080Fe]K0P1;Bd/206UYJ@80F5QH0P2;Rh/20:>SX`80VIVI4@2i^KT2
0;Ng]`@0^KVi102g]kL40;Vi^@80]kNg00<0^KVi0;Ng]`2g]kL0202i^KT20;^k^`80]KFe5@3oool0
01<0oooo202g]kL20;^k^`80]KFe2`2i^KT20;>c/`80^KVi0P2e]KD20;^k^`@0]KFe0P2b/[8209FE
U@80GEeM1012@T8204=3@`0304E5A@0o?cl0?clo0080:b/[0P0U9BD201XJ6P80<S8b0P0m?Cd208^;
R`80WinO0P2PX:020:RXZ080Y:BT0P2UYJD20:NWY`80XJ6Q0`2WYjL20:ZZZP80Y:BT102UYJD20:NW
Y`80YZJV0P2KVi/20:FUY@80ZJVY0P2QXJ4209VIV@80SHf=0P2<S8`208^;R`80T92@00<0Shn?09>C
T`2CTi<00P2JVYX40:2PX080XJ6Q0P2KVi/20:JVYP80XJ6Q0P2SXj<209nOW`80WYjN0P2PX:0209VI
V@80UIFE0P2DU9@00`2?Shl0RHV908V9R@020861P@80QHF50P1eMGD205mOG`80EeMG0P1;Bd/202d]
;@80:BTY0P0k>c/203De=@80BDU90P1<C4`204Q8B080C4a<00<0Bd];04Y:BP1:BTX00P1KFe/207mo
O`80O7al0P20P80209jNWP80H61P0P1KFe/204];B`80JFUY0P1HF5P208^;R`80Xj>S0P2IVITA0;Vi
^@80]kNg102i^KT40;Ng]`@0^KVi0P2g]kL00`2i^KT0]kNg0;Ng]`080;Vi^@80^k^k0P2e]KDE0?oo
o`004`3oool40;Fe]@80]kNg0P2c/k<=0;Vi^@@0]kNg0P2c/k<20;Vi^@80^k^k0P2g]kL20;Fe]@80
Ti>C0P1/K6`204i>CP80=CDe0P0m?Cd20451@@030410@012@T80@T920080;bl_0P0a<C42030`<080
00000P2BTY820:2PX080WYjN0P2SXj<20:ZZZP@0YJFU0P2][Jd40:BTY0030:FUY@2WYjL0YjNW00P0
Y:BT0P2WYjL209nOW`80YJFU0P2YZJT20:>SX`80WinO0P2BTY8208V9R@80TI6A0P2BTY800`2ATI40
TY:B09:BTP0209^KV`80VYZJ0P2TY:@20:NWY`80WinO0P2XZ:P209jNWP80Xj>S0P2PX:020::RXP80
WYjN0P2LW9`209fMW@80U9BD00<0TI6A08b<S02<S8`00P26QXH207moO`80OGem0P1XJ6P205EEE@80
BDU90P0i>CT2034a<@80<S8b0P11@D420410@080De=C0P1=CDd2051@D00305IFEP1DE5@0E5AD0080
GUiN0P22PX8207]kN`80OWin0P2?Shl206YZJP80DE5A0P19BDT206QXJ080IfMW0P1oOgl209fMW@80
/[:b3`2i^KT20;^k^`80]KFe0P2i^KT20;^k^`80]kNg0P2e]KD20;Vi^@80^k^k0P2e]KD00`2i^KT0
]KFe0;Fe]@040;Vi^@80]kNg1P2i^KTE0?ooo`004`3oool40;Fe]@80]kNg0P2c/k<=0;Vi^@@0]kNg
0P2c/k<20;Vi^@80^k^k0P2g]kL20;Fe]@80Ti>C0P1/K6`204i>CP80=CDe0P0m?Cd20451@@030410
@012@T80@T920080;bl_0P0a<C42030`<08000000P2BTY820:2PX080WYjN0P2SXj<20:ZZZP@0YJFU
0P2][Jd40:BTY0030:FUY@2WYjL0YjNW00P0Y:BT0P2WYjL209nOW`80YJFU0P2YZJT20:>SX`80WinO
0P2BTY8208V9R@80TI6A0P2BTY800`2ATI40TY:B09:BTP0209^KV`80VYZJ0P2TY:@20:NWY`80WinO
0P2XZ:P209jNWP80Xj>S0P2PX:020::RXP80WYjN0P2LW9`209fMW@80U9BD00<0TI6A08b<S02<S8`0
0P26QXH207moO`80OGem0P1XJ6P205EEE@80BDU90P0i>CT2034a<@80<S8b0P11@D420410@080De=C
0P1=CDd2051@D00305IFEP1DE5@0E5AD0080GUiN0P22PX8207]kN`80OWin0P2?Shl206YZJP80DE5A
0P19BDT206QXJ080IfMW0P1oOgl209fMW@80/[:b3`2i^KT20;^k^`80]KFe0P2i^KT20;^k^`80]kNg
0P2e]KD20;Vi^@80^k^k0P2e]KD00`2i^KT0]KFe0;Fe]@040;Vi^@80]kNg1P2i^KTE0?ooo`004`3o
ool20;Fe]@80/k>c0P2k^k/20;Fe]@T0^KVi0P2k^k/20;Fe]@80^KVi0P2k^k/20;>c/`H0^KVi0P2g
]kL20:VYZ@80G5aL0P16ATH203/k>`80>SXj0P1:BTX00`11@D40>c/k03/k>`0203/k>`809RHV0P18
B4P202TY:@80WIfM0P2KVi/20:BTY0H0YJFU102ZZZX20:FUY@80Y:BT00<0Xj>S0:ZZZP2ZZZX00P2U
YJD20:RXZ080YjNW0P2TY:@20:RXZ080XJ6Q0P2UYJD40:BTY080XJ6Q0P2BTY8208R8R080SHf=0P2D
U9@00`2FUYH0UiNG09NGU`0209RHV080WIfM0P2UYJD209jNWP80YJFU0P2SXj<20:BTY080WIfM0P2S
Xj<40:6QX@80W9bL0P2NWYh209ZJVP0309>CT`2:RXX0RXZ:0080S8b<0P21PH4207moO`80JFUY0P1I
FET204];B`80<c<c0P0];Bd2038b<P80=cLg0P12@T8204Q8B080De=C0P1DE5@00`1:BTX0FUYJ05YJ
FP02075aL@80Ogmo0P1nOWh207alO080SXj>0P1cLg<2069RHP80CTi>0P1OGel206m_K`80NGUi0P2T
Y:@I0;Vi^@80]kNg0P2i^KT20;Ng]`80^KVi0P2k^k/00`2e]KD0^KVi0;Vi^@020;Vi^@80^k^k0P2e
]KD60;Vi^AD0oooo000C0?ooo`80]KFe0P2c/k<20;^k^`80]KFe2@2i^KT20;^k^`80]KFe0P2i^KT2
0;^k^`80/k>c1P2i^KT20;Ng]`80ZJVY0P1LG5`204I6AP80>c/k0P0j>SX204Y:BP030451@@0k>c/0
>c/k0080>c/k0P0V9RH204Q8B080:BTY0P2MWId209^KV`80Y:BT1P2UYJD40:ZZZP80YJFU0P2TY:@0
0`2SXj<0ZZZZ0:ZZZP020:FUY@80Z:RX0P2WYjL20:BTY080Z:RX0P2QXJ420:FUY@@0Y:BT0P2QXJ42
09:BTP80R8R80P2=SHd209BDU00309JFUP2GUiL0UiNG0080V9RH0P2MWId20:FUY@80WYjN0P2UYJD2
0:>SX`80Y:BT0P2MWId20:>SX`@0XJ6Q0P2LW9`209jNWP80VYZJ00<0Ti>C08Z:RP2:RXX00P2<S8`2
0861P@80Ogmo0P1YJFT205UIF@80Bd];0P0c<c<202d];@80<S8b0P0g=cL20492@P80B4Q80P1CDe<2
05ADE00304Y:BP1JFUX0FUYJ0080LG5a0P1oOgl207inOP80O7al0P2>SXh207=cL`80HV9R0P1>CTh2
05mOG`80Kfm_0P1iNGT20:BTY1T0^KVi0P2g]kL20;Vi^@80]kNg0P2i^KT20;^k^`030;Fe]@2i^KT0
^KVi0080^KVi0P2k^k/20;Fe]@H0^KVi5@3oool001<0oooo0P2g]kL20;Fe]@80^KVi0P2g]kL20;Vi
^@80]kNg1@2i^KT20;Ng]`@0^KVi0P2k^k/20;Fe]@@0^KVi0P2k^k/20;Fe]@80XZ:R0P1QHF42059B
DP80@T920P0e=CD204I6AP0304E5A@0b<S80<S8b0080>CTi0P13@d<202TY:@80Kfm_0P2OWil209jN
WP@0Y:BT0P2QXJ420:NWY`80ZZZZ0P2TY:@20:FUY@<0Y:BT0P2SXj<20:6QX@80YjNW0P2ZZZX60:BT
Y080XJ6Q0P2XZ:P20::RXP80YJFU0P2DU9@208^;R`80QhN70`2BTY8409RHV080WYjN0P2PX:0209jN
WP80XZ:R0P2WYjL20:2PX080WYjN0P2SXj<409nOW`80W9bL0P2KVi/209bLW00309ZJVP2?Shl0Shn?
0080Rh^;0P24Q8@208:2PP80Lg=c0P1RHV8204i>CP80@T920P0`<302034a<@80<S8b0P10@40204E5
A@80D51@0P1;Bd/00`16ATH0@d=304=3@`0208:2PP@0Ng]k0P1lO7`20820P080L71`0P1IFET205iN
GP80H61P0P1UIFD207=cL`80[jn_5`2i^KT20;^k^`80]KFe0P2k^k/20;Fe]@80^KVi0P2g]kL?0;Vi
^AD0oooo000C0?ooo`80]kNg0P2e]KD20;Vi^@80]kNg0P2i^KT20;Ng]`D0^KVi0P2g]kL40;Vi^@80
^k^k0P2e]KD40;Vi^@80^k^k0P2e]KD20::RXP80HF5Q0P1BDU820492@P80=CDe0P16ATH00`15ADD0
<S8b038b<P0203Ti>@80@d=30P0Y:BT206m_K`80WinO0P2NWYh40:BTY080XJ6Q0P2WYjL20:ZZZP80
Y:BT0P2UYJD30:BTY080Xj>S0P2QXJ420:NWY`80ZZZZ1P2TY:@20:6QX@80Z:RX0P2RXZ820:FUY@80
U9BD0P2;Rh/208N7Q`<0TY:B102HV9P209jNWP80X:2P0P2NWYh20::RXP80YjNW0P2PX:0209jNWP80
Xj>S102OWil209bLW080Vi^K0P2LW9`00`2JVYX0Shn?08n?S`0208^;R`80Q8B40P22PX8207=cL`80
HV9R0P1>CTh20492@P80<30`0P0a<C42038b<P80@4100P15ADD2051@D080Bd];00<0ATI604=3@`13
@d<00P22PX8407]kN`80O7al0P20P802071`L080FEUI0P1NGUh2061PH080IFEU0P1cLg<20:n_[aL0
^KVi0P2k^k/20;Fe]@80^k^k0P2e]KD20;Vi^@80]kNg3`2i^KTE0?ooo`004`3oool40;Ng]`80^k^k
0P2e]KD20;^k^`80/k>c0P2i^KT20;Ng]`030;^k^`2c/k<0/k>c00`0^KVi0P2g]kL20:^[Z`80PH61
0P1BDU82051@D080C4a<0P17AdL20410@00303Ti>@0f=SH0=SHf0080=3@d0P15ADD2051@D080WYjN
0P2PX:020:6QX@H0Y:BT0P2UYJD20:NWY`@0Y:BT0P2UYJD00`2SXj<0Vi^K09^KV`020:2PX0@0XZ:R
102TY:@20:JVYP80Vi^K102TY:@20:b/[080VIVI0P2<S8`208N7Q`80Rh^;0`2@T902096AT@80VIVI
0P2OWil209jNWP80X:2P0P2TY:@209fMW@80Y:BT0P2OWil209^KV`80W9bL0P2KVi/209fMW@80Vi^K
00<0UIFE09NGU`2GUiL00P2=SHd208R8R080Ogmo0P1jNWX206EUI@80EUIF0P14A4@202`/;080<30`
0P0d=3@203Lg=`80C4a<0P1>CTh2051@D00304a<C00n?Sh0?Shn0080PH610P1nOWh207UiN@80Jf][
0P1ZJVX206ATI080BDU90P1TI6@206][J`80JVYZ0P1^KVh20;Bd]1d0^KVi0P2g]kL20;^k^`80]KFe
3`2i^KTE0?ooo`004`3oool40;Ng]`80^k^k0P2e]KD20;^k^`80/k>c0P2i^KT20;Ng]`030;^k^`2c
/k<0/k>c00`0^KVi0P2g]kL20:^[Z`80PH610P1BDU82051@D080C4a<0P17AdL20410@00303Ti>@0f
=SH0=SHf0080=3@d0P15ADD2051@D080WYjN0P2PX:020:6QX@H0Y:BT0P2UYJD20:NWY`@0Y:BT0P2U
YJD00`2SXj<0Vi^K09^KV`020:2PX0@0XZ:R102TY:@20:JVYP80Vi^K102TY:@20:b/[080VIVI0P2<
S8`208N7Q`80Rh^;0`2@T902096AT@80VIVI0P2OWil209jNWP80X:2P0P2TY:@209fMW@80Y:BT0P2O
Wil209^KV`80W9bL0P2KVi/209fMW@80Vi^K00<0UIFE09NGU`2GUiL00P2=SHd208R8R080Ogmo0P1j
NWX206EUI@80EUIF0P14A4@202`/;080<30`0P0d=3@203Lg=`80C4a<0P1>CTh2051@D00304a<C00n
?Sh0?Shn0080PH610P1nOWh207UiN@80Jf][0P1ZJVX206ATI080BDU90P1TI6@206][J`80JVYZ0P1^
KVh20;Bd]1d0^KVi0P2g]kL20;^k^`80]KFe3`2i^KTE0?ooo`004`3oool20;Ng]`80]KFe1P2i^KT2
0;Fe]@80^k^k0P2c/k<00`2k^k/0]KFe0;Fe]@0:0;Vi^@80^k^k0P2c/k<20:6QX@80Q8B40P1KFe/2
04Q8B080Bd];0P16ATH204=3@`0303@d=00j>SX0>SXj0080>c/k0P0P820209BDU080Y:BT0P2GUiL4
0:FUY@80YjNW0P2TY:@20:6QX@80ZZZZ0P2TY:@40:6QX@0309ZJVP2KVi/0Vi^K0080VIVI0P2MWId2
09^KV`80Xj>S0P2XZ:P209fMW@80X:2P0P2UYJD20:BTY080ZJVY0P2MWId208^;R`80R8R80`27QhL2
09BDU080Rh^;0P2HV9P209nOW`80VIVI0P2OWil209^KV`80VYZJ0P2NWYh209^KV`80VIVI1P2KVi/2
09fMW@0309FEU@2FUYH0UYJF0080Shn?0P2:RXX208N7Q`80N7Qh0P1^KVh205IFEP80BDU90P0^;Rh2
024Q8@80<C4a0P0i>CT20410@080EEEE0P1>CTh00`1<C4`0BTY:04Y:BP0207emO@80MGEe0P1lO7`2
05mOG`80@d=30P1mOGd204A4A080E5AD0P1aLG4207]kN`80MGEe1P2i^KT00`2g]kL0^KVi0;Vi^@0D
0;Vi^@80^k^k0P2c/k<C0;Vi^AD0oooo000C0?ooo`80]kNg0P2e]KD60;Vi^@80]KFe0P2k^k/20;>c
/`030;^k^`2e]KD0]KFe00X0^KVi0P2k^k/20;>c/`80XJ6Q0P24Q8@205]KF`80B4Q80P1;Bd/204I6
AP80@d=300<0=3@d03Xj>P0j>SX00P0k>c/2020P8080U9BD0P2TY:@209NGU`@0YJFU0P2WYjL20:BT
Y080XJ6Q0P2ZZZX20:BTY0@0XJ6Q00<0VYZJ09^KV`2KVi/00P2IVIT209fMW@80Vi^K0P2SXj<20:RX
Z080WIfM0P2PX:020:FUY@80Y:BT0P2YZJT209fMW@80Rh^;0P28R8P308N7Q`80U9BD0P2;Rh/209RH
V080WinO0P2IVIT209nOW`80Vi^K0P2JVYX209jNWP80Vi^K0P2IVIT609^KV`80WIfM00<0UIFE09JF
UP2FUYH00P2?Shl208Z:RP80QhN70P1hN7P206i^KP80EUIF0P19BDT202h^;P808B4Q0P0a<C4203Ti
>@80@4100P1EEED204i>CP0304a<C01:BTX0BTY:0080OGem0P1eMGD207alO080GemO0P13@d<207em
O@80A4A40P1DE5@2075aL@80Ng]k0P1eMGD60;Vi^@030;Ng]`2i^KT0^KVi01@0^KVi0P2k^k/20;>c
/a<0^KVi5@3oool001<0oooo1P2i^KT20;^k^`80/k>c0P2i^KT20;^k^`80]KFe00<0]kNg0;Vi^@2i
^KT0102i^KT60;Ng]`80^KVi0P2e]KD207moO`80FUYJ0P1QHF4205]KF`80ADE50P1DE5@20410@003
02h^;P0l?3`0?3`l0080FUYJ0P18B4P209FEU@80UiNG0P2FUYH20:FUY@80XJ6Q0P2ZZZX20:BTY080
Xj>S102RXZ8209fMW@80Y:BT00<0TI6A08n?S`2?Shl00P2BTY8209RHV080VIVI0P2KVi/20:BTY080
Vi^K0P2MWId20:FUY@80Y:BT0P2VYZH209^KV`80QXJ60P28R8P208>3P`0308N7Q`25QHD0QHF50080
T92@0P2IVIT209RHV080W9bL0P2DU9@209>CT`80SHf=0P2?Shl408f=S@80Shn?0P2BTY8209RHV080
UYJF00<0W9bL08n?S`2?Shl00P2FUYH208^;R`80PX:20P1kNg/206][J`80HF5Q0P1=CDd20492@P80
71`L0P0T92@2030`<080@D510P1;Bd/205IFEP0304];B`18B4P0B4Q80080O7al0P1bLW8206e]K@80
H61P0P0c<c<208:2PP80BTY:0P1=CDd206i^KP80OWin0P2=SHd40;Vi^@80^k^k00<0]KFe0;Vi^@2i
^KT01P2i^KT20;Ng]``0^KVi0P2k^k/20;Fe]@D0^KVi0P2g]kL<0;Vi^AD0oooo000C0?ooo`H0^KVi
0P2k^k/20;>c/`80^KVi0P2k^k/20;Fe]@030;Ng]`2i^KT0^KVi00@0^KVi1P2g]kL20;Vi^@80]KFe
0P1oOgl205YJFP80HF5Q0P1KFe/204E5A@80E5AD0P10@4000`0^;Rh0?3`l03`l?00205YJFP80B4Q8
0P2EUID209NGU`80UYJF0P2UYJD20:6QX@80ZZZZ0P2TY:@20:>SX`@0XZ:R0P2MWId20:BTY003096A
T@2?Shl0Shn?0080TY:B0P2HV9P209VIV@80Vi^K0P2TY:@209^KV`80WIfM0P2UYJD20:BTY080YZJV
0P2KVi/208J6QP80R8R80P23Ph<00`27QhL0QHF508F5Q@02092@T080VIVI0P2HV9P209bLW080U9BD
0P2CTi<208f=S@80Shn?102=SHd208n?S`80TY:B0P2HV9P209JFUP0309bLW02?Shl0Shn?0080UYJF
0P2;Rh/208:2PP80Ng]k0P1[Jf/2065QH@80CDe=0P12@T8201`L708092@T0P0`<3020451@@80Bd];
0P1FEUH00`1;Bd/0B4Q804Q8B00207alO080LW9b0P1]KFd2061PH080<c<c0P22PX8204Y:BP80CDe=
0P1^KVh207inOP80SHf=102i^KT20;^k^`030;Fe]@2i^KT0^KVi00H0^KVi0P2g]kL<0;Vi^@80^k^k
0P2e]KD50;Vi^@80]kNg302i^KTE0?ooo`004`3oool60;Vi^@80^k^k0P2e]KD40;Vi^@80^k^k00<0
]KFe0;Vi^@2i^KT00P2g]kL20;^k^`80]KFe102g]kL20;Fe]@80^KVi0P2XZ:P204Y:BP80G5aL0P18
B4P204e=C@80Bd];0P0[:b/00`12@T80=CDe03De=@0203/k>`80QXJ60P2=SHd208B4Q080VYZJ0P2V
YZH60:BTY080Xj>S0P2IVIT208V9R@80OGem0P23Ph<00`2ATI40P8200820P00207emO@80S8b<0P2B
TY8209bLW080Xj>S0P2JVYX209VIV@80YJFU0P2TY:@20:f][@80UiNG0P2:RXX207alO080PX:200<0
Q8B408^;R`2;Rh/00P29RHT209JFUP80Ti>C0P2;Rh/208N7Q`80NGUi0P1gMgL207]kN`80PX:20P1l
O7`208>3P`80QHF50P2DU9@209:BTP<0SXj>0P2BTY8208^;R`80QHF50P1iNGT2075aL@80F5QH0P1?
Cdl204=3@`80>c/k0P0Y:BT202XZ:P80>3Ph0P17AdL204Y:BP0305ADE018B4P0B4Q80080KFe]0P1g
MgL206=SH`80I6AT0P0b<S8207QhN080CDe=0P13@d<207EeM@80N7Qh0P2EUID20;bl_0/0^KVi0P2k
^k/20;Fe]A@0^KVi00<0^k^k0;Fe]@2e]KD0302i^KTE0?ooo`004`3oool60;Vi^@80^k^k0P2e]KD4
0;Vi^@80^k^k00<0]KFe0;Vi^@2i^KT00P2g]kL20;^k^`80]KFe102g]kL20;Fe]@80^KVi0P2XZ:P2
04Y:BP80G5aL0P18B4P204e=C@80Bd];0P0[:b/00`12@T80=CDe03De=@0203/k>`80QXJ60P2=SHd2
08B4Q080VYZJ0P2VYZH60:BTY080Xj>S0P2IVIT208V9R@80OGem0P23Ph<00`2ATI40P8200820P002
07emO@80S8b<0P2BTY8209bLW080Xj>S0P2JVYX209VIV@80YJFU0P2TY:@20:f][@80UiNG0P2:RXX2
07alO080PX:200<0Q8B408^;R`2;Rh/00P29RHT209JFUP80Ti>C0P2;Rh/208N7Q`80NGUi0P1gMgL2
07]kN`80PX:20P1lO7`208>3P`80QHF50P2DU9@209:BTP<0SXj>0P2BTY8208^;R`80QHF50P1iNGT2
075aL@80F5QH0P1?Cdl204=3@`80>c/k0P0Y:BT202XZ:P80>3Ph0P17AdL204Y:BP0305ADE018B4P0
B4Q80080KFe]0P1gMgL206=SH`80I6AT0P0b<S8207QhN080CDe=0P13@d<207EeM@80N7Qh0P2EUID2
0;bl_0/0^KVi0P2k^k/20;Fe]A@0^KVi00<0^k^k0;Fe]@2e]KD0302i^KTE0?ooo`004`3oool40;Ng
]`P0^KVi0P2g]kL20;Vi^@030;Ng]`2k^k/0^k^k0080]KFe0P2k^k/20;Fe]@H0^KVi0P2RXZ8209jN
WP80FUYJ0P1?Cdl404=3@`80AdM70P0j>SX00`0e=CD0Fe]K05]KF`0204i>CP80W9bL0P1hN7P207al
O080WIfM0P2SXj<20:BTY080Xj>S0P2MWId208F5Q@80OWin0P29RHT208F5Q@80GUiN00<0GEeM06e]
K@1]KFd00P1[Jf/207inOP80Lg=c0P2;Rh/209nOW`80Vi^K0P2GUiL40:FUY@80Z:RX0P2PX:0208j>
SP80PH610P1kNg/00`1dM7@0Hf=S06=SH`0205]KF`80MgMg0P1oOgl208n?S`80Ng]k0P1IFET205]K
F`80HV9R0P1XJ6P206UYJ@80JVYZ0P1cLg<208Z:RP80TY:B0`2;Rh/208Z:RP80R8R80P23Ph<207Yj
NP80JVYZ0P1SHf<2055AD@80A4A40P15ADD202`/;0809bLW0P0e=CD204I6AP80AdM700<0EEEE05=C
D`1CDe<00P1]KFd206i^KP80IFEU0P1JFUX203Ti>@80PX:20P1IFET204U9B@80Ph>30P1bLW8209ZJ
VP80_kno6`2i^KT20;Ng]aD0^KVi5@3oool001<0oooo102g]kL80;Vi^@80]kNg0P2i^KT00`2g]kL0
^k^k0;^k^`020;Fe]@80^k^k0P2e]KD60;Vi^@80XZ:R0P2NWYh205YJFP80Cdm?1013@d<204M7A`80
>SXj00<0=CDe05]KF`1KFe/00P1>CTh209bLW080N7Qh0P1lO7`209fMW@80Xj>S0P2TY:@20:>SX`80
WIfM0P25QHD207inOP80RHV90P25QHD205iNGP0305eMG@1]KFd0KFe]0080Jf][0P1nOWh207=cL`80
Rh^;0P2OWil209^KV`80UiNG102UYJD20:RXZ080X:2P0P2>SXh20861P@80Ng]k00<0M7Ad06=SH`1S
Hf<00P1KFe/207MgM`80Ogmo0P2?Shl207]kN`80FEUI0P1KFe/2069RHP80J6QX0P1YJFT206YZJP80
Lg=c0P2:RXX209:BTP<0Rh^;0P2:RXX208R8R080Ph>30P1jNWX206YZJP80Hf=S0P1ADE4204A4A080
ADE50P0/;2`202LW9`80=CDe0P16ATH204M7A`0305EEE@1CDe<0De=C0080KFe]0P1^KVh206EUI@80
FUYJ0P0i>CT208:2PP80FEUI0P19BDT208>3P`80LW9b0P2JVYX20;no_a/0^KVi0P2g]kLE0;Vi^AD0
oooo000C0?ooo`80]kNg0P2e]KD60;Vi^@80^k^k0P2e]KD20;^k^`030;Fe]@2i^KT0^KVi00@0^KVi
0P2g]kL60;Vi^@80[:b/0P1nOWh206QXJ080GEeM0P0b<S820492@P80ATI60P0l?3`00`0T92@09BDU
02DU9@0209FEU@80UYJF0P21PH4207inOP80X:2P0P2QXJ420:2PX080WYjN0P27QhL20861P@80Lg=c
0P1jNWX207QhN080JFUY00<0B4Q804m?C`1?Cdl00P1MGEd207EeM@80N7Qh0P1[Jf/2096AT@80U9BD
0P2EUID40:FUY@80YZJV0P2MWId209FEU@80O7al0P1iNGT00`1[Jf/0T92@092@T00204m?C`80De=C
0P1oOgl207AdM080N7Qh0P1NGUh2051@D080EUIF0P1RHV8206IVIP80F5QH0P1LG5`207QhN080QXJ6
00<0QhN708Z:RP2:RXX00P2;Rh/208>3P`80QHF50P1hN7P206a/K080GEeM0P1?Cdl204A4A080;bl_
0P0F5QH201hN7P80<S8b0P1:BTX203hn?P0304Y:BP1JFUX0FUYJ0080IfMW0P1YJFT205iNGP80IVIV
0P10@40206UYJ@80EUIF0P1QHF4208R8R080LW9b0P2_[jlG0;Vi^@80]kNg0P2i^KT20;^k^`80]KFe
0P2g]kLC0;Vi^AD0oooo000C0?ooo`80]kNg0P2e]KD60;Vi^@80^k^k0P2e]KD20;^k^`030;Fe]@2i
^KT0^KVi00@0^KVi0P2g]kL60;Vi^@80[:b/0P1nOWh206QXJ080GEeM0P0b<S820492@P80ATI60P0l
?3`00`0T92@09BDU02DU9@0209FEU@80UYJF0P21PH4207inOP80X:2P0P2QXJ420:2PX080WYjN0P27
QhL20861P@80Lg=c0P1jNWX207QhN080JFUY00<0B4Q804m?C`1?Cdl00P1MGEd207EeM@80N7Qh0P1[
Jf/2096AT@80U9BD0P2EUID40:FUY@80YZJV0P2MWId209FEU@80O7al0P1iNGT00`1[Jf/0T92@092@
T00204m?C`80De=C0P1oOgl207AdM080N7Qh0P1NGUh2051@D080EUIF0P1RHV8206IVIP80F5QH0P1L
G5`207QhN080QXJ600<0QhN708Z:RP2:RXX00P2;Rh/208>3P`80QHF50P1hN7P206a/K080GEeM0P1?
Cdl204A4A080;bl_0P0F5QH201hN7P80<S8b0P1:BTX203hn?P0304Y:BP1JFUX0FUYJ0080IfMW0P1Y
JFT205iNGP80IVIV0P10@40206UYJ@80EUIF0P1QHF4208R8R080LW9b0P2_[jlG0;Vi^@80]kNg0P2i
^KT20;^k^`80]KFe0P2g]kLC0;Vi^AD0oooo000C0?oooa40^KVi0P2g]kL20;Vi^@80^k^k0P2e]KD6
0;Vi^@80inOW0P1mOGd205aLG080AdM70P0h>3P203Lg=`80A4A40P1>CTh00`19BDT04Q8B018B4P02
09jNWP80QHF51023Ph<209ZJVP80Xj>S0P2KVi/208^;R`80MWIf0P0m?Cd204i>CP80OGem0P2BTY82
06][J`0301hN7P0k>c/0>c/k0080@d=30P1=CDd206a/K080JVYZ0P25QHD208R8R080V9RH0P2UYJD2
0:RXZ080XZ:R0P2OWil209NGU`80RHV90P1gMgL00`1TI6@0IFEU06EUI@0208R8R080AdM70P1aLG42
07QhN080GEeM0P0O7al203dm?@80E5AD0P16ATH203dm?@80@d=30P1?Cdl2069RHP80MgMg00<0Ng]k
08J6QP26QXH00P28R8P20861P@80NGUi0P1lO7`206YZJP80F5QH0P1?Cdl204E5A@809RHV100L71`2
020P8080?Shn0`15ADD205MGE`80Hf=S0P1ZJVX205iNGP80HF5Q0P1@D50206UYJ@80@T920P1_Kfl2
08N7Q`80MWIf5`2i^KT20;^k^`80]KFe102i^KT20;^k^`80]KFe4`2i^KTE0?ooo`004`3ooolA0;Vi
^@80]kNg0P2i^KT20;^k^`80]KFe1P2i^KT20>OWi`80OGem0P1LG5`204M7A`80>3Ph0P0g=cL204A4
A080CTi>00<0BDU9018B4P0B4Q800P2NWYh208F5Q@@0Ph>30P2JVYX20:>SX`80Vi^K0P2;Rh/207If
MP80?Cdm0P1>CTh207emO@80TY:B0P1[Jf/00`0N7Qh0>c/k03/k>`0204=3@`80CDe=0P1/K6`206YZ
JP80QHF50P28R8P209RHV080YJFU0P2XZ:P20::RXP80WinO0P2GUiL208V9R@80MgMg00<0I6AT06EU
I@1UIFD00P28R8P204M7A`80LG5a0P1hN7P205eMG@807alO0P0m?Cd205ADE080ATI60P0m?Cd204=3
@`80Cdm?0P1RHV8207MgM`0307]kN`26QXH0QXJ60080R8R80P21PH4207UiN@80O7al0P1ZJVX205QH
F080Cdm?0P15ADD202HV9P@071`L0P0P820203hn?P<0ADE50P1GEeL206=SH`80JVYZ0P1NGUh2065Q
H@80D51@0P1YJFT20492@P80Kfm_0P27QhL207IfMQL0^KVi0P2k^k/20;Fe]@@0^KVi0P2k^k/20;Fe
]A<0^KVi5@3oool001<0oooo402i^KT00`2k^k/0]KFe0;Fe]@0:0;Vi^@80WIfM0P2IVIT20:JVYP80
K6a/0P1;Bd/204=3@`80>c/k0P16ATH204];B`0305EEE@15ADD0ADE50080UiNG0P23Ph<207YjNP80
QHF50P2IVIT209jNWP80UYJF0P24Q8@205EEE@80F5QH0P0i>CT203hn?P80<S8b0P0^;Rh00`1UIFD0
<S8b038b<P0205YJFP80BTY:0P1RHV8207AdM080NWYj0P2>SXh209fMW@80Xj>S0P2WYjL20:>SX`80
WIfM0P2FUYH209RHV080OWin00<0N7Qh05iNGP1NGUh00P1OGel207=cL`80E5AD0P1ADE42024Q8@80
Bd];0P0S8b<20492@P80<30`0P1NGUh203/k>`80BDU90P1RHV8206YZJP0306i^KP1mOGd0OGem0080
PH610P22PX82075aL@80KVi^0P1MGEd205ADE080CTi>0P13@d<203dm?@808R8R0P0Z:RX202l_;`80
;Bd]0P0o?cl00`13@d<0GemO05mOG`0205UIF@80EeMG0P1NGUh206MWI`80EEEE0P1kNg/204Y:BP80
Kfm_0P1dM7@209:BTRP0^KVi0P2g]kL<0;Vi^AD0oooo000C0?oooa00^KVi00<0^k^k0;Fe]@2e]KD0
2P2i^KT209fMW@80VIVI0P2VYZH206a/K080Bd];0P13@d<203/k>`80ATI60P1;Bd/00`1EEED0ADE5
04E5A@0209NGU`80Ph>30P1jNWX208F5Q@80VIVI0P2NWYh209JFUP80Q8B40P1EEED205QHF080>CTi
0P0n?Sh2038b<P80;Rh^00<0IFEU038b<P0b<S800P1JFUX204Y:BP80HV9R0P1dM7@207YjNP80SXj>
0P2MWId20:>SX`80YjNW0P2SXj<209fMW@80UYJF0P2HV9P207inOP0307QhN01NGUh0GUiN0080GemO
0P1cLg<205ADE080DE5A0P0Q8B4204];B`808b<S0P12@T82030`<080GUiN0P0k>c/204U9B@80HV9R
0P1ZJVX00`1^KVh0OGem07emO@020861P@80PX:20P1aLG4206i^KP80GEeM0P1DE5@204i>CP80@d=3
0P0m?Cd2028R8P80:RXZ0P0_;bl202d];@80?clo00<0@d=305mOG`1OGel00P1IFET205MGE`80GUiN
0P1WIfL205EEE@80Ng]k0P1:BTX206m_K`80M7Ad0P2BTY8X0;Vi^@80]kNg302i^KTE0?ooo`004`3o
ool:0;Vi^@80]kNg1@2i^KT20;Ng]`X0^KVi0P2RXZ82065QH@80TY:B0P1PH60204U9B@80C4a<0P16
ATH40451@@0304m?C`1RHV80HV9R0080TI6A101mOGd208B4Q080VYZJ0P2SXj<209bLW080UIFE0P2=
SHd205UIF@80E5AD0P1?Cdl204I6AP80?Cdm00<0?Shn04e=C@1=CDd0101TI6@207AdM080OWin0P2A
TI4209BDU0@0XZ:R0P2WYjL20:>SX`80WYjN0P2LW9`209ZJVP80T92@00<0PH6107emO@1mOGd00P1^
KVh205ADE080GemO0P1lO7`205aLG080BTY:0P0n?Sh203@d=080?Shn0P17AdL2061PH080Fe]K0P1Z
JVX2075aL@03079bLP1jNWX0NWYj0080Ng]k0P1lO7`207QhN080J6QX0P1LG5`204e=C@80BDU90P1:
BTX203lo?`80;2`/0P0Z:RX402d];@80=CDe00<0ADE505eMG@1MGEd00P1RHV8205QHF080EUIF0P1/
K6`2065QH@80OGem0P1FEUH2071`L080JFUY0P2ZZZXW0;Vi^@030;^k^`2e]KD0]KFe00`0^KVi5@3o
ool001<0oooo2P2i^KT20;Ng]`D0^KVi0P2g]kL:0;Vi^@80XZ:R0P1QHF4209:BTP80H61P0P19BDT2
04a<C080ATI61011@D400`1?Cdl0HV9R069RHP02096AT@@0OGem0P24Q8@209ZJVP80Xj>S0P2LW9`2
09FEU@80SHf=0P1IFET205ADE080Cdm?0P16ATH203dm?@0303hn?P1=CDd0CDe=00@0I6AT0P1dM7@2
07inOP80TI6A0P2DU9@40::RXP80YjNW0P2SXj<209jNWP80W9bL0P2JVYX2092@T0030861P@1mOGd0
OGem0080KVi^0P1DE5@205mOG`80O7al0P1LG5`204Y:BP80?Shn0P0d=3@203hn?P80AdM70P1PH602
05]KF`80JVYZ0P1aLG400`1bLW80NWYj07YjNP0207]kN`80O7al0P1hN7P206QXJ080G5aL0P1=CDd2
04U9B@80BTY:0P0o?cl202`/;080:RXZ100];Bd203De=@0304E5A@1MGEd0GEeM0080HV9R0P1HF5P2
05IFEP80K6a/0P1QHF4207emO@80EUIF0P1`L70206UYJ@80ZZZZ9`2i^KT00`2k^k/0]KFe0;Fe]@0<
0;Vi^AD0oooo000C0?ooo`P0^KVi0P2k^k/20;Fe]@@0^KVi00<0^k^k0;Fe]@2e]KD01P2i^KT20;Ng
]`80^KVi0P3Xj>P207IfMP80IFEU0P1DE5@20410@080>SXj0P13@d<203Ti>@80AdM700<0CTi>06QX
J01XJ6P00P22PX8207YjNP80N7Qh0P21PH4209bLW080WYjN0P2PX:020:BTY080XJ6Q0P2IVIT208b<
S080Ph>30P1hN7P207IfMP0307MgM`1aLG40LG5a00@0M7Ad0P21PH4208^;R`80W9bL0P2NWYh209nO
W`80YJFU0P2WYjL20:JVYP80WinO102MWId208j>SP0308B4Q01oOgl0Ogmo0080OWin0P28R8P206a/
K080M7Ad0P1eMGD207MgM`80M7Ad0P1/K6`206MWI`80Hf=S0P1`L70208:2PP80Ph>30P1mOGd00`1n
OWh0PH610861P@020820P080Lg=c0P1eMGD2075aL@80Fe]K0P1@D50204];B`80>CTi0P0h>3P402`/
;080>SXj0P0i>CT2034a<@0303lo?`1OGel0GemO0080I6AT101HF5P206][J`80L71`0P20P80205aL
G080KVi^0P1mOGd20;Jf]S@0^KVi0P2g]kLE0?ooo`004`3oool80;Vi^@80^k^k0P2e]KD40;Vi^@03
0;^k^`2e]KD0]KFe00H0^KVi0P2g]kL20;Vi^@80j>SX0P1fMWH206EUI@80E5AD0P10@40203Xj>P80
@d=30P0i>CT204M7A`0304i>CP1XJ6P0J6QX0080PX:20P1jNWX207QhN080PH610P2LW9`209jNWP80
X:2P0P2TY:@20:6QX@80VIVI0P2<S8`208>3P`80N7Qh0P1fMWH00`1gMgL0LG5a075aL@0407AdM080
PH610P2;Rh/209bLW080WYjN0P2OWil20:FUY@80YjNW0P2VYZH209nOW`@0WIfM0P2>SXh00`24Q8@0
Ogmo07moO`0207inOP80R8R80P1/K6`207AdM080MGEe0P1gMgL207AdM080K6a/0P1WIfL206=SH`80
L71`0P22PX8208>3P`80OGem00<0OWin0861P@21PH400P20P80207=cL`80MGEe0P1aLG4205]KF`80
D51@0P1;Bd/203Ti>@80>3Ph100/;2`203Xj>P80>CTi0P0a<C400`0o?cl0GemO05mOG`0206ATI0@0
F5QH0P1[Jf/2071`L080P8200P1LG5`206i^KP80OGem0P2f][Hd0;Vi^@80]kNg5@3oool001<0oooo
1P2i^KT20;Ng]`@0^KVi0P2g]kL;0;Vi^@80]KFe0P2i^KT20<?3``80KFe]0P1CDe<203Ph>0@0=3@d
0P17AdL203De=@80=SHf00<0D51@06QXJ01XJ6P00P1fMWH207QhN080LG5a0P1mOGd209VIV@80VYZJ
0P2NWYh20:RXZ080YZJV0P2QXJ420:FUY@80XJ6Q0P2HV9P207inOP03071`L01[Jf/0Jf][0080KVi^
0P1aLG4208^;R`80Shn?0P2LW9`20:RXZ080Xj>S0P2WYjL20:BTY080YjNW0P2TY:@20:>SX`80Y:BT
0P2IVIT00`1lO7`0JFUY06UYJ@0205aLG080IVIV0P1_Kfl208B4Q080Rh^;102=SHd208Z:RP80Rh^;
0P2>SXh208Z:RP80SHf=0P2>SXh208^;R`0307moO`1fMWH0MWIf00@0N7Qh0P1[Jf/206QXJ080I6AT
0P1?Cdl204];B`80BTY:0P0^;Rh202TY:@809BDU0P0];Bd202HV9P80>CTi00<0?3`l055AD@1ADE40
0P1VIVH205IFEP80EEEE0P1`L70207=cL`80R8R80P1PH602065QH@80WinO0P2o_klb0;Vi^@80^k^k
0P2e]KDE0?ooo`004`3oool40;Vi^@80^k^k0P2e]KD20;Vi^@80^k^k0P2e]KD70;Vi^@80^k^k0P2e
]KD20;Vi^@@0]KFe0P1_Kfl203Ti>@80=SHf0P0`<30403/k>`80BTY:0P0o?cl00`1>CTh0FEUI05UI
F@0206e]K@80MGEe0P1/K6`207MgM`80XJ6Q0P2@T90209RHV080XJ6Q0P2VYZH40:BTY080Rh^;0P1m
OGd206i^KP0306EUI@1^KVh0KVi^0080NGUi0P1]KFd209JFUP80VYZJ0P2VYZH20:RXZ080Xj>S0P2]
[Jd20:BTY080YZJV0P2WYjL20:6QX@80Zj^[0P2QXJ400`2OWil0PX:208:2PP0205MGE`@0Bd];0P1B
DU8207QhN080SHf=0P2EUID209bLW0@0VIVI0P2BTY82096AT@80SHf=0P23Ph<307AdM080KFe]0P1c
Lg<206YZJP80GemO0P1LG5`205ADE080>c/k0P0f=SH202h^;P80:b/[0P0W9bL2028R8P80?3`l0P0k
>c/00`1;Bd/0E5AD05ADE002065QH@80E5AD0P1ADE4206m_K`80K6a/0P2FUYH206UYJ@80H61P0P2_
[jlh0;Vi^AD0oooo000C0?ooo`@0^KVi0P2k^k/20;Fe]@80^KVi0P2k^k/20;Fe]@L0^KVi0P2k^k/2
0;Fe]@80^KVi102e]KD206m_K`80>CTi0P0f=SH2030`<0@0>c/k0P1:BTX203lo?`0304i>CP1IFET0
FEUI0080KFe]0P1eMGD206a/K080MgMg0P2QXJ42092@T080V9RH0P2QXJ420:JVYP@0Y:BT0P2;Rh/2
07emO@80KVi^00<0IFEU06i^KP1^KVh00P1iNGT206e]K@80UYJF0P2JVYX20:JVYP80Z:RX0P2SXj<2
0:f][@80Y:BT0P2VYZH20:NWY`80XJ6Q0P2[Zj/20:6QX@0309nOW`22PX80PX:20080EeMG101;Bd/2
059BDP80N7Qh0P2=SHd209FEU@80W9bL102IVIT209:BTP80TI6A0P2=SHd208>3P`<0M7Ad0P1]KFd2
07=cL`80JVYZ0P1OGel205aLG080E5AD0P0k>c/203Hf=P80;Rh^0P0[:b/202LW9`808R8R0P0l?3`2
03/k>`0304];B`1DE5@0E5AD0080HF5Q0P1DE5@2055AD@80Kfm_0P1/K6`209JFUP80JFUY0P1PH602
0:n_[cP0^KVi5@3oool001<0oooo5`2i^KT20;Ng]`80^KVi0P2`/;0208b<S080TI6A0P0i>CT20451
@@80>SXj0P0^;Rh203hn?P80@d=30P12@T8304e=C@80FUYJ0P1ZJVX206e]K@80LW9b0P2MWId2092@
T080OGem0P24Q8@208b<S080QHF50P1fMWH207alO080L71`0P1nOWh00`26QXH0N7Qh07QhN00208f=
S@80XJ6Q0P2WYjL20:FUY@80YZJV0P2][Jd20:FUY@80ZZZZ0P2TY:@40:FUY@80YjNW0P2SXj<20:FU
Y@030:JVYP2WYjL0YjNW0080W9bL0P1lO7`206UYJ@80FUYJ0P1:BTX205iNGP80H61P0P1/K6`207Mg
M`80OWin0P1eMGD207AdM080KFe]0P1dM7@00`1iNGT0JFUY06UYJ@0207UiN@80Lg=c0P1[Jf/205iN
GP80F5QH0P1@D50205QHF0809RHV0P0g=cL203Hf=P80=CDe0P0X:2P2020P8080@41000<0D51@05QH
F01HF5P00P1NGUh205UIF@80D51@0P1eMGD206][J`80KVi^101/K6`Q0;Vi^@80]kNg5`2i^KTE0?oo
o`004`3ooolG0;Vi^@80]kNg0P2i^KT20;2`/080S8b<0P2ATI4203Ti>@80@D510P0j>SX202h^;P80
?Shn0P13@d<20492@P<0CDe=0P1JFUX206YZJP80KFe]0P1bLW8209fMW@80T92@0P1mOGd208B4Q080
S8b<0P25QHD207IfMP80O7al0P1`L70207inOP0308J6QP1hN7P0N7Qh0080SHf=0P2QXJ420:NWY`80
YJFU0P2VYZH20:f][@80YJFU0P2ZZZX20:BTY0@0YJFU0P2WYjL20:>SX`80YJFU00<0YZJV0:NWY`2W
YjL00P2LW9`207alO080JFUY0P1JFUX204Y:BP80GUiN0P1PH60206a/K080MgMg0P1nOWh207EeM@80
M7Ad0P1]KFd207AdM00307UiN@1YJFT0JFUY0080NGUi0P1cLg<206][J`80GUiN0P1HF5P2051@D080
F5QH0P0V9RH203Lg=`80=SHf0P0e=CD202PX:080820P0P10@4000`1@D500F5QH05QHF00205iNGP80
FEUI0P1@D50207EeM@80Jf][0P1^KVh406a/K240^KVi0P2g]kLG0;Vi^AD0oooo000C0?oooaD0^KVi
0P2k^k/20;>c/`80]KFe0P31`L4205mOG`80KVi^0P11@D4204I6AP80AdM70P13@d<203Lg=`80@D51
0P10@4000`1;Bd/0Cdm?04m?C`02051@D080GUiN0P1XJ6P207MgM`80V9RH0P2e]KD208f=S@80R8R8
0P22PX8207emO@80QHF50P1mOGd207YjNP80R8R800<0YJFU0:RXZ02XZ:P00P2VYZH:0:ZZZP80[Jf]
0P2TY:@20:FUY@80Z:RX0P2WYjL20:RXZ080YjNW0P2TY:@00`2SXj<0YJFU0:FUY@020:NWY`80WinO
0P2LW9`209JFUP80S8b<0P1gMgL20820P080I6AT0P1OGel206EUI@80IfMW0P1_Kfl207=cL`<0L71`
0P1iNGT207YjNP80MWIf0P1]KFd2061PH080GEeM0P1CDe<203Hf=P80Bd];0P0^;Rh202l_;`8071`L
0P0K6a/201lO7`80<C4a00<0De=C051@D01@D5000P1NGUh205aLG080EUIF0P1aLG4206m_K`80K6a/
0P19BDT209NGUal0^KVi0P2k^k/20;Fe]@80^KVi0P2g]kLC0;Vi^AD0oooo000C0?oooaD0^KVi0P2k
^k/20;>c/`80]KFe0P31`L4205mOG`80KVi^0P11@D4204I6AP80AdM70P13@d<203Lg=`80@D510P10
@4000`1;Bd/0Cdm?04m?C`02051@D080GUiN0P1XJ6P207MgM`80V9RH0P2e]KD208f=S@80R8R80P22
PX8207emO@80QHF50P1mOGd207YjNP80R8R800<0YJFU0:RXZ02XZ:P00P2VYZH:0:ZZZP80[Jf]0P2T
Y:@20:FUY@80Z:RX0P2WYjL20:RXZ080YjNW0P2TY:@00`2SXj<0YJFU0:FUY@020:NWY`80WinO0P2L
W9`209JFUP80S8b<0P1gMgL20820P080I6AT0P1OGel206EUI@80IfMW0P1_Kfl207=cL`<0L71`0P1i
NGT207YjNP80MWIf0P1]KFd2061PH080GEeM0P1CDe<203Hf=P80Bd];0P0^;Rh202l_;`8071`L0P0K
6a/201lO7`80<C4a00<0De=C051@D01@D5000P1NGUh205aLG080EUIF0P1aLG4206m_K`80K6a/0P19
BDT209NGUal0^KVi0P2k^k/20;Fe]@80^KVi0P2g]kLC0;Vi^AD0oooo000C0?ooo`X0^KVi0P2g]kL5
0;Vi^@80]kNg0P2i^KT20;^k^`80]KFe0P2i^KT20<g=c@80O7al0P1FEUH20410@080BTY:0P1JFUX2
04e=C@80ADE50P10@40204E5A@0304Y:BP1>CTh0CTi>0080EEEE0P1MGEd205iNGP80Ng]k0P2HV9P2
09jNWP80XJ6Q0P2[Zj/209fMW@80V9RH0P28R8P208j>SP80XZ:R3@2ZZZX20:^[Z`80ZZZZ0P2][Jd4
0:FUY@@0ZZZZ0P2YZJT40:FUY@030:BTY02WYjL0YjNW0080YJFU0P2PX:0409jNWP80W9bL0P2KVi/2
0:NWY`80VIVI0P28R8P208>3P`80PH610P1fMWH20820P080Ph>300<0OGem07UiN@1iNGT00P1hN7P2
071`L080JVYZ0P1RHV8205mOG`80Hf=S0P18B4P203@d=0809bLW100K6a/201PH60807AdM0P0^;Rh0
0`1FEUH0De=C05=CD`0205ADE080J6QX0P1EEED2079bLP80MWIf0P1KFe/205ADE080[jn_8`2i^KT2
0;^k^`80]KFe4`2i^KTE0?ooo`004`3oool:0;Vi^@80]kNg1@2i^KT20;Ng]`80^KVi0P2k^k/20;Fe
]@80^KVi0P3=cLd207alO080EUIF0P10@40204Y:BP80FUYJ0P1=CDd204E5A@80@4100P15ADD00`1:
BTX0CTi>04i>CP0205EEE@80GEeM0P1NGUh207]kN`80V9RH0P2NWYh20:6QX@80Zj^[0P2MWId209RH
V080R8R80P2>SXh20::RXPd0ZZZZ0P2[Zj/20:ZZZP80[Jf]102UYJD40:ZZZP80ZJVY102UYJD00`2T
Y:@0YjNW0:NWY`020:FUY@80X:2P102NWYh209bLW080Vi^K0P2WYjL209VIV@80R8R80P23Ph<20861
P@80MWIf0P20P80208>3P`0307emO@1iNGT0NGUi0080N7Qh0P1`L70206YZJP80HV9R0P1OGel206=S
H`80B4Q80P0d=3@202LW9`@06a/K0P0H61P201dM7@80;Rh^00<0EUIF05=CD`1CDe<00P1DE5@206QX
J080EEEE0P1bLW8207IfMP80Fe]K0P1DE5@20:n_[b<0^KVi0P2k^k/20;Fe]A<0^KVi5@3oool001<0
oooo1P2i^KT20;Ng]`80^k^k0P2e]KD50;Vi^@80]KFe202i^KT20;bl_080JVYZ0P19BDT204];B`80
BTY:0P1RHV8204m?C`@0BTY:0P15ADD304];B`80De=C0P1OGel205aLG080MWIf0P2KVi/209bLW080
X:2P0P2MWId20:FUY@80YZJV0P2UYJD20:RXZ080Y:BT0P2WYjL00`2XZ:P0ZZZZ0:ZZZP040:ZZZP80
Z:RX0P2ZZZX20:^[Z`80ZZZZ0P2][Jd20::RXP80YjNW102ZZZX20:FUY@80YjNW0P2TY:@00`2UYJD0
Y:BT0:BTY0020:RXZ080XZ:R0P2NWYh20:>SX`80W9bL0P2KVi/209bLW080U9BD0P2HV9P209NGU`80
TY:B0P29RHT208R8R080Q8B400<0OGem08:2PP22PX800P1hN7P207IfMP80IfMW0P1OGel2065QH@80
EUIF0P1LG5`20492@P80;2`/0P0W9bL201lO7`80:2PX0P0R8R8202<S8`0307EeM@1CDe<0De=C0080
BDU90P1hN7P205IFEP80G5aL0P1kNg/205EEE@80I6AT0P2l_;`j0;Vi^AD0oooo000C0?ooo`H0^KVi
0P2g]kL20;^k^`80]KFe1@2i^KT20;Fe]@P0^KVi0P2l_;`206YZJP80BDU90P1;Bd/204Y:BP80HV9R
0P1?Cdl404Y:BP80ADE50`1;Bd/205=CD`80GemO0P1LG5`207IfMP80Vi^K0P2LW9`20:2PX080WIfM
0P2UYJD20:JVYP80YJFU0P2XZ:P20:BTY080YjNW00<0Z:RX0:ZZZP2ZZZX0102ZZZX20:RXZ080ZZZZ
0P2[Zj/20:ZZZP80[Jf]0P2RXZ820:NWY`@0ZZZZ0P2UYJD20:NWY`80Y:BT00<0YJFU0:BTY02TY:@0
0P2XZ:P20::RXP80WYjN0P2SXj<209bLW080Vi^K0P2LW9`209BDU080V9RH0P2GUiL209:BTP80RHV9
0P28R8P208B4Q00307emO@22PX80PX:20080N7Qh0P1fMWH206MWI`80GemO0P1QHF4205IFEP80G5aL
0P12@T8202`/;0809bLW0P0O7al202PX:0808R8R0P0S8b<00`1eMGD0De=C05=CD`0204U9B@80N7Qh
0P1FEUH205aLG080Ng]k0P1EEED206ATI080_;bl>P2i^KTE0?ooo`004`3oool40;Vi^@80^k^k0P2e
]KD60;Vi^@80^k^k00<0]KFe0;Vi^@2i^KT0202i^KT20<[:bP80M7Ad0P1=CDd204i>CP80C4a<0P1N
GUh205UIF@80Cdm?0P1<C4`204M7A`<0ATI60P1;Bd/205iNGP80F5QH0P1`L70209BDU080WYjN0P2O
Wil209fMW@80Xj>S0P2VYZH20::RXP80YjNW0P2^[Zh20:NWY`030:>SX`2ZZZX0ZZZZ0080ZZZZ0P2]
[Jd20:JVYPH0ZZZZ0P2][Jd20:VYZ@80YJFU0P2^[Zh20:RXZ080Y:BT0P2ZZZX30:BTY0@0Xj>S0P2W
YjL209jNWP80Xj>S0P2LW9`209^KV`80W9bL0P2EUID209bLW080TY:B0P2ATI4208f=S@@0QXJ600<0
PH6108:2PP22PX800P1iNGT2079bLP80Jf][0P1RHV84061PH080@d=30P0g=cL203Hf=P80;Bd]0P0K
6a/201PH6080820P0P0Q8B400`1cLg<0Hf=S06=SH`02055AD@80MGEe0P1JFUX204m?C`80MgMg0P0k
>c/208f=S@80_kno>P2i^KTE0?ooo`004`3oool40;Vi^@80^k^k0P2e]KD60;Vi^@80^k^k00<0]KFe
0;Vi^@2i^KT0202i^KT20<[:bP80M7Ad0P1=CDd204i>CP80C4a<0P1NGUh205UIF@80Cdm?0P1<C4`2
04M7A`<0ATI60P1;Bd/205iNGP80F5QH0P1`L70209BDU080WYjN0P2OWil209fMW@80Xj>S0P2VYZH2
0::RXP80YjNW0P2^[Zh20:NWY`030:>SX`2ZZZX0ZZZZ0080ZZZZ0P2][Jd20:JVYPH0ZZZZ0P2][Jd2
0:VYZ@80YJFU0P2^[Zh20:RXZ080Y:BT0P2ZZZX30:BTY0@0Xj>S0P2WYjL209jNWP80Xj>S0P2LW9`2
09^KV`80W9bL0P2EUID209bLW080TY:B0P2ATI4208f=S@@0QXJ600<0PH6108:2PP22PX800P1iNGT2
079bLP80Jf][0P1RHV84061PH080@d=30P0g=cL203Hf=P80;Bd]0P0K6a/201PH6080820P0P0Q8B40
0`1cLg<0Hf=S06=SH`02055AD@80MGEe0P1JFUX204m?C`80MgMg0P0k>c/208f=S@80_kno>P2i^KTE
0?ooo`004`3oool<0;Vi^@80]kNg3@2i^KT20<S8b080SXj>0P15ADD204Y:BP80ADE50P1BDU8204m?
C`@0C4a<0`19BDT204M7A`80CTi>0P1PH602069RHP80JVYZ0P2?Shl209NGU`80WinO0P2PX:0209nO
W`80YJFU0P2VYZH20:6QX@80YjNW0P2][Jd00`2VYZH0ZZZZ0:ZZZP040:ZZZP80YjNW0P2XZ:P:0:ZZ
ZP@0YjNW0P2ZZZX20:BTY080Xj>S00<0XZ:R0:6QX@2QXJ40102QXJ4209nOW`80X:2P0P2LW9`209ZJ
VP80U9BD0P2JVYX409FEU@80TI6A0P2:RXX208^;R`80QHF500<0P82007UiN@1iNGT0101hN7P206][
J`@0H61P0P1?Cdl204Q8B080=cLg0P0e=CD202@T90806a/K0P0H61P202LW9`80:BTY00<0MWIf07=c
L`1cLg<00P1MGEd207emO@80IFEU0P1;Bd/207QhN080?clo0P2e]KDU0;Vi^@80]kNg5@2i^KTE0?oo
o`004`3oool<0;Vi^@80]kNg3@2i^KT20<S8b080SXj>0P15ADD204Y:BP80ADE50P1BDU8204m?C`@0
C4a<0`19BDT204M7A`80CTi>0P1PH602069RHP80JVYZ0P2?Shl209NGU`80WinO0P2PX:0209nOW`80
YJFU0P2VYZH20:6QX@80YjNW0P2][Jd00`2VYZH0ZZZZ0:ZZZP040:ZZZP80YjNW0P2XZ:P:0:ZZZP@0
YjNW0P2ZZZX20:BTY080Xj>S00<0XZ:R0:6QX@2QXJ40102QXJ4209nOW`80X:2P0P2LW9`209ZJVP80
U9BD0P2JVYX409FEU@80TI6A0P2:RXX208^;R`80QHF500<0P82007UiN@1iNGT0101hN7P206][J`@0
H61P0P1?Cdl204Q8B080=cLg0P0e=CD202@T90806a/K0P0H61P202LW9`80:BTY00<0MWIf07=cL`1c
Lg<00P1MGEd207emO@80IFEU0P1;Bd/207QhN080?clo0P2e]KDU0;Vi^@80]kNg5@2i^KTE0?ooo`00
4`3oool:0;Vi^@80^k^k0P2e]KD=0;Vi^@80^k^k0P26QXH205=CD`80BDU90P1<C4`204m?C`80E5AD
0P1EEED204Y:BP80Bd];00<0ATI604i>CP1>CTh00P1<C4`206EUI@80JVYZ0P1`L70208b<S080TI6A
0P2OWil20:2PX080XZ:R0P2UYJD20:JVYP@0YJFU0P2ZZZX00`2WYjL0Z:RX0:RXZ0020:ZZZP80[:b/
102VYZH20:ZZZP80YjNW102ZZZX20:f][@H0Y:BT0P2UYJD20:RXZ0030:6QX@2SXj<0Xj>S0080XJ6Q
0P2RXZ820:2PX0@0Vi^K0P2MWId2096AT@80TY:B0P2ATI4209BDU080TY:B102:RXX208F5Q@0308R8
R01iNGT0NGUi0080N7Qh0P1]KFd206m_K`80J6QX0P1OGel205EEE@80>c/k0P0o?cl202DU9@8092@T
0P0P820201TI6@807alO0P0d=3@00`1IFET0L71`071`L002069RHP80Ogmo0P1]KFd205aLG080A4A4
0P1iNGTU0;Vi^@80^k^k0P2e]KDE0;Vi^AD0oooo000C0?ooo`X0^KVi0P2k^k/20;Fe]@d0^KVi0P2k
^k/208J6QP80De=C0P19BDT204a<C080Cdm?0P1DE5@205EEE@80BTY:0P1;Bd/00`16ATH0CTi>04i>
CP0204a<C080IFEU0P1ZJVX2071`L080S8b<0P2ATI4209nOW`80X:2P0P2RXZ820:FUY@80YZJV102U
YJD20:ZZZP030:NWY`2XZ:P0Z:RX0080ZZZZ0P2/[:`40:JVYP80ZZZZ0P2WYjL40:ZZZP80[Jf]1P2T
Y:@20:FUY@80Z:RX00<0XJ6Q0:>SX`2SXj<00P2QXJ420::RXP80X:2P102KVi/209fMW@80TI6A0P2B
TY82096AT@80U9BD0P2BTY8408Z:RP80QHF500<0R8R807UiN@1iNGT00P1hN7P206e]K@80Kfm_0P1X
J6P205mOG`80EEEE0P0k>c/203lo?`809BDU0P0T92@2020P80806ATI0P0O7al203@d=00305UIF@1`
L700L71`0080HV9R0P1oOgl206e]K@80G5aL0P14A4@207UiNBD0^KVi0P2k^k/20;Fe]AD0^KVi5@3o
ool001<0oooo6`2i^KT20;Fe]@80^;Rh0P16ATH204m?C`80CTi>0P1EEED204m?C`80DU9B0P1<C4`2
04Q8B003059BDP1>CTh0CTi>0080De=C0P1LG5`206m_K`80LW9b0P24Q8@2096AT@80WIfM0P2NWYh4
0:>SX`80YJFU0P2SXj<20:RXZ080[Jf]00<0Z:RX0::RXP2RXZ800P2XZ:P20:f][@80YJFU0P2WYjL2
0:^[Z`80Y:BT102WYjL20:ZZZP80YJFU102TY:@40:FUY@030:>SX`2WYjL0YjNW00@0XJ6Q0P2OWil2
09jNWP80Vi^K0P2OWil209NGU`@0Ti>C0P2BTY82092@T080S8b<0P2:RXX208B4Q0030820P01lO7`0
O7al0080N7Qh0P1_Kfl206][J`80Hf=S0P1MGEd205ADE080B4Q80P0d=3@202TY:@806QXJ100A4A42
030`<080>3Ph00<0De=C06e]K@1]KFd00P1NGUh207]kN`80OGem0P21PH4203`l?080WinO?P2i^KTE
0?ooo`004`3ooolK0;Vi^@80]KFe0P2h^;P204I6AP80Cdm?0P1>CTh205EEE@80Cdm?0P1BDU8204a<
C080B4Q800<0DU9B04i>CP1>CTh00P1CDe<205aLG080Kfm_0P1bLW8208B4Q080TI6A0P2MWId209jN
WP@0Xj>S0P2UYJD20:>SX`80Z:RX0P2][Jd00`2XZ:P0XZ:R0::RXP020:RXZ080[Jf]0P2UYJD20:NW
Y`80Zj^[0P2TY:@40:NWY`80ZZZZ0P2UYJD40:BTY0@0YJFU00<0Xj>S0:NWY`2WYjL0102QXJ4209nO
W`80WYjN0P2KVi/209nOW`80UiNG102CTi<209:BTP80T92@0P2<S8`208Z:RP80Q8B400<0P82007al
O01lO7`00P1hN7P206m_K`80Jf][0P1SHf<205eMG@80E5AD0P18B4P203@d=080:BTY0P0J6QX4014A
4@80<30`0P0h>3P00`1CDe<0KFe]06e]K@0205iNGP80Ng]k0P1mOGd20861P@80?3`l0P2OWiln0;Vi
^AD0oooo000C0?oooa/0^KVi0P2e]KD208R8R080Hf=S0P1IFET204m?C`80DE5A0P1DE5@204];B`@0
CTi>00<0?Shn04i>CP1>CTh00P1FEUH2065QH@80Jf][0P1bLW820820P080TY:B0P2IVIT20:2PX0@0
XZ:R0P2UYJD40:JVYP<0ZZZZ0P2WYjL20:JVYP80ZZZZ0P2[Zj/20:NWY`80Xj>S0P2ZZZX20:RXZ080
YJFU0P2TY:@20:FUY@80Y:BT102UYJD20:RXZ0030::RXP2XZ:P0Z:RX0080XZ:R0P2QXJ4209ZJVP80
XZ:R0P2LW9`409VIV@80UiNG0P2ATI4209:BTP80SXj>102:RXX308B4Q080MgMg0P1jNWX206m_K`80
I6AT0P1QHF42051@D080ATI60P19BDT203<c<`807AdM0P0B4Q82024Q8@804A4A0P0X:2P204i>CP03
059BDP1GEeL0EeMG0080FEUI0P1jNWX2079bLP80SXj>0P1]KFe00;Vi^AD0oooo000C0?oooa/0^KVi
0P2e]KD208R8R080Hf=S0P1IFET204m?C`80DE5A0P1DE5@204];B`@0CTi>00<0?Shn04i>CP1>CTh0
0P1FEUH2065QH@80Jf][0P1bLW820820P080TY:B0P2IVIT20:2PX0@0XZ:R0P2UYJD40:JVYP<0ZZZZ
0P2WYjL20:JVYP80ZZZZ0P2[Zj/20:NWY`80Xj>S0P2ZZZX20:RXZ080YJFU0P2TY:@20:FUY@80Y:BT
102UYJD20:RXZ0030::RXP2XZ:P0Z:RX0080XZ:R0P2QXJ4209ZJVP80XZ:R0P2LW9`409VIV@80UiNG
0P2ATI4209:BTP80SXj>102:RXX308B4Q080MgMg0P1jNWX206m_K`80I6AT0P1QHF42051@D080ATI6
0P19BDT203<c<`807AdM0P0B4Q82024Q8@804A4A0P0X:2P204i>CP03059BDP1GEeL0EeMG0080FEUI
0P1jNWX2079bLP80SXj>0P1]KFe00;Vi^AD0oooo000C0?ooo`H0^KVi0P2g]kL20;Vi^@80]kNg3`2i
^KT20;Fe]@80n?Sh0P1YJFT205=CD`80DU9B0P17AdL404Q8B080BTY:0P16ATH00`1EEED0AdM704M7
A`0205ADE080I6AT0P1dM7@207=cL`80P8200P2BTY8209ZJVP80WinO0P2RXZ840:FUY@80Xj>S0P2Z
ZZX20:f][@030::RXP2ZZZX0ZZZZ0080Z:RX0P2/[:`20:>SX`80ZJVY0P2VYZH20:BTY080ZZZZ0P2U
YJD40:BTY080YZJV0P2UYJD20:BTY0<0YJFU0P2TY:@20:JVYPH0WYjN0P2KVi/209fMW@80T92@0P2M
WId2092@T080TY:B102:RXX208b<S0<0QXJ60P1hN7P207]kN`80JVYZ0P1VIVH205iNGP80G5aL0P1?
Cdl203Lg=`80<c<c0P0L71`201TI6@807QhN0P0K6a/202LW9`80De=C00<0FEUI05QHF01HF5P00P1B
DU8207QhN080NWYj0P1YJFT20:RXZ400^KVi5@3oool001<0oooo1P2i^KT20;Ng]`80^KVi0P2g]kL?
0;Vi^@80]KFe0P3hn?P206UYJ@80De=C0P1BDU8204M7A`@0B4Q80P1:BTX204I6AP0305EEE@17AdL0
AdM70080E5AD0P1TI6@207AdM080Lg=c0P20P80209:BTP80VYZJ0P2OWil20::RXP@0YJFU0P2SXj<2
0:ZZZP80[Jf]00<0XZ:R0:ZZZP2ZZZX00P2XZ:P20:b/[080Xj>S0P2YZJT20:JVYP80Y:BT0P2ZZZX2
0:FUY@@0Y:BT0P2VYZH20:FUY@80Y:BT0`2UYJD20:BTY080YZJV1P2NWYh209^KV`80WIfM0P2@T902
09fMW@80T92@0P2BTY8408Z:RP80S8b<0`26QXH207QhN080Ng]k0P1ZJVX206IVIP80GUiN0P1LG5`2
04m?C`80=cLg0P0c<c<201`L70806ATI0P0N7Qh201/K6`809bLW0P1CDe<00`1IFET0F5QH05QHF002
059BDP80N7Qh0P1jNWX206UYJ@80Z:RX@02i^KTE0?ooo`004`3oool40;Vi^@80^k^k0P2e]KD20;^k
^`80]KFe4@2i^KT20<?3``80SXj>0P1EEED204M7A`80@T921014A4@203lo?`80AdM700<0BTY:05EE
E@1EEED00P1IFET206IVIP80L71`0P1mOGd208:2PP80TY:B0P2JVYX209fMW@80XJ6Q0P2VYZH20:BT
Y080Xj>S0P2WYjL20:ZZZP030:>SX`2ZZZX0ZZZZ0080YZJV0P2][Jd20:VYZ@80YjNW0P2RXZ820:ZZ
ZP80Z:RX0P2UYJD20:BTY0H0YJFU0P2VYZH30:BTY080YJFU0P2NWYh20:6QX@80Xj>S0P2LW9`209jN
WP80WinO0P2DU9@209jNWP80Ti>C0P2BTY8208Z:RP80R8R80P27QhL208Z:RP0308N7Q`1kNg/0Ng]k
0080NWYj0P1^KVh206QXJ080F5QH0P1ADE4203hn?P80<c<c100R8R82018B4P@06QXJ0P0X:2P205YJ
FP0305=CD`1GEeL0EeMG0080De=C0P1lO7`208F5Q@80MGEe@P2i^KTE0?ooo`004`3oool40;Vi^@80
^k^k0P2e]KD20;^k^`80]KFe4@2i^KT20<?3``80SXj>0P1EEED204M7A`80@T921014A4@203lo?`80
AdM700<0BTY:05EEE@1EEED00P1IFET206IVIP80L71`0P1mOGd208:2PP80TY:B0P2JVYX209fMW@80
XJ6Q0P2VYZH20:BTY080Xj>S0P2WYjL20:ZZZP030:>SX`2ZZZX0ZZZZ0080YZJV0P2][Jd20:VYZ@80
YjNW0P2RXZ820:ZZZP80Z:RX0P2UYJD20:BTY0H0YJFU0P2VYZH30:BTY080YJFU0P2NWYh20:6QX@80
Xj>S0P2LW9`209jNWP80WinO0P2DU9@209jNWP80Ti>C0P2BTY8208Z:RP80R8R80P27QhL208Z:RP03
08N7Q`1kNg/0Ng]k0080NWYj0P1^KVh206QXJ080F5QH0P1ADE4203hn?P80<c<c100R8R82018B4P@0
6QXJ0P0X:2P205YJFP0305=CD`1GEeL0EeMG0080De=C0P1lO7`208F5Q@80MGEe@P2i^KTE0?ooo`00
4`3ooolM0;Vi^@80]KFe0P3Ph>02065QH@80BDU90P18B4P204=3@`80ATI60P17AdL20451@@0304A4
A01@D500D51@0080F5QH0P1XJ6P206i^KP80OGem0P26QXH209:BTP80VIVI0P2SXj<209bLW080YZJV
0P2TY:@20:FUY@80Z:RX0P2UYJD00`2YZJT0YJFU0:FUY@080:ZZZP80Z:RX0P2RXZ820:ZZZP80Z:RX
302UYJD00`2YZJT0WinO09nOW`020:>SX`80XJ6Q0P2RXZ8209ZJVP80X:2P102KVi/209ZJVP80UIFE
0P2BTY8208^;R`80S8b<0P24Q8@208R8R0<0P8200P1hN7P206UYJ@80IfMW0P1UIFD2059BDP80>c/k
0P0_;bl4028R8P806ATI0P0L71`201lO7`809bLW0P1ZJVX00`1FEUH0F5QH05QHF00205EEE@80MgMg
0P27QhL209fMW@80^KVi0P2g]kLn0;Vi^AD0oooo000C0?oooad0^KVi0P2e]KD20>3Ph080HF5Q0P19
BDT204Q8B080@d=30P16ATH204M7A`80@D5100<0A4A4051@D01@D5000P1HF5P206QXJ080KVi^0P1m
OGd208J6QP80TY:B0P2IVIT20:>SX`80W9bL0P2VYZH20:BTY080YJFU0P2XZ:P20:FUY@030:VYZ@2U
YJD0YJFU00P0ZZZZ0P2XZ:P20::RXP80ZZZZ0P2XZ:P<0:FUY@030:VYZ@2OWil0WinO0080Xj>S0P2Q
XJ420::RXP80VYZJ0P2PX:0409^KV`80VYZJ0P2EUID209:BTP80Rh^;0P2<S8`208B4Q080R8R80`20
P80207QhN080JFUY0P1WIfL206EUI@80DU9B0P0k>c/202l_;`@08R8R0P0I6AT201`L70807alO0P0W
9bL206YZJP0305IFEP1HF5P0F5QH0080EEEE0P1gMgL208N7Q`80WIfM0P2i^KT20;Ng]ch0^KVi5@3o
ool001<0oooo102i^KT20;Ng]aT0^KVi0P3AdM4208Z:RP80AdM70P0o?cl404=3@`80ATI60P18B4P0
0`14A4@0BDU904U9B@0205aLG080J6QX0P1cLg<207emO@80RHV90P2FUYH209RHV0@0WYjN0P2TY:@2
0:FUY@80XZ:R0P2ZZZX20::RXP030:RXZ02ZZZX0ZZZZ0080Z:RX102ZZZX20::RXP80ZZZZ0P2UYJD2
0::RXP80ZZZZ0P2TY:@20:JVYP80Y:BT1P2UYJD00`2WYjL0WinO09nOW`020:BTY080XZ:R102OWil2
09^KV`80W9bL0P2JVYX209^KV`80Ti>C0P2DU9@208f=S@@0RXZ:0P22PX800`25QHD0MgMg07MgM`02
07EeM@80KVi^0P1PH60205UIF@80D51@0P0k>c/202h^;P809RHV0P0O7al202HV9P8092@T0P0J6QX2
02TY:@80H61P00<0JVYZ05MGE`1GEeL00P1WIfL207EeM@80QHF50P2i^KT20;^k^`80]KFe?P2i^KTE
0?ooo`004`3oool40;Vi^@80]kNg6@2i^KT20=7Ad@80RXZ:0P17AdL203lo?`@0@d=30P16ATH204Q8
B00304A4A019BDT0BDU90080G5aL0P1XJ6P207=cL`80OGem0P29RHT209JFUP80V9RH102NWYh20:BT
Y080YJFU0P2RXZ820:ZZZP80XZ:R00<0Z:RX0:ZZZP2ZZZX00P2XZ:P40:ZZZP80XZ:R0P2ZZZX20:FU
Y@80XZ:R0P2ZZZX20:BTY080YZJV0P2TY:@60:FUY@030:NWY`2OWil0WinO0080Y:BT0P2RXZ8409nO
W`80Vi^K0P2LW9`209ZJVP80Vi^K0P2CTi<209BDU080SHf=102:RXX208:2PP0308F5Q@1gMgL0MgMg
0080MGEe0P1^KVh2061PH080FEUI0P1@D50203/k>`80;Rh^0P0V9RH201lO7`809RHV0P0T92@201XJ
6P80:BTY0P1PH6000`1ZJVX0EeMG05MGE`0206MWI`80MGEe0P25QHD20;Vi^@80^k^k0P2e]KDn0;Vi
^AD0oooo000C0?ooo`80^KVi0P2k^k/20;Fe]AT0^KVi0P2k^k/20:j^[P80GemO1016ATH204Q8B080
A4A40P16ATH00`1;Bd/0BTY:04Y:BP0205ADE080IVIV0P1eMGD208J6QP80RXZ:0P2HV9P209bLW080
WIfM0P2PX:020::RXPP0YJFU00<0YZJV0:b/[02/[:`00P2RXZ820:ZZZP80Y:BT102UYJD20:BTY0@0
YJFU0P2TY:@40:FUY@80YZJV0P2TY:@30:FUY@80XJ6Q0P2RXZ8209jNWP80XJ6Q0P2MWId409^KV`80
WIfM0P2EUID209BDU080TY:B0P2?Shl208Z:RP80Rh^;0P27QhL00`1oOgl0O7al07alO00206i^KP80
Jf][0P1NGUh205EEE@80ATI60P0h>3P2034a<@80:BTY0P0P820202@T90806QXJ0P0B4Q8202HV9P80
EEEE00<0HV9R05YJFP1JFUX00P1]KFd207]kN`80VYZJA02i^KTE0?ooo`004`3oool20;Vi^@80^k^k
0P2e]KDI0;Vi^@80^k^k0P2^[Zh205mOG`@0ATI60P18B4P204A4A080ATI600<0Bd];04Y:BP1:BTX0
0P1DE5@206IVIP80MGEe0P26QXH208Z:RP80V9RH0P2LW9`209fMW@80X:2P0P2RXZ880:FUY@030:JV
YP2/[:`0[:b/0080XZ:R0P2ZZZX20:BTY0@0YJFU0P2TY:@40:FUY@80Y:BT102UYJD20:JVYP80Y:BT
0`2UYJD20:6QX@80XZ:R0P2NWYh20:6QX@80WIfM102KVi/209fMW@80UIFE0P2DU9@209:BTP80Shn?
0P2:RXX208^;R`80QhN700<0Ogmo07alO01lO7`00P1^KVh206][J`80GUiN0P1EEED204I6AP80>3Ph
0P0a<C4202TY:@80820P0P0T92@201XJ6P804Q8B0P0V9RH205EEE@03069RHP1JFUX0FUYJ0080KFe]
0P1kNg/209ZJVT@0^KVi5@3oool001<0oooo8@2i^KT20>_[j`80W9bL0P1bLW8205ADE080EEEE0P1F
EUH204Y:BP0304Q8B01=CDd0CDe=0080GEeM0P1OGel2071`L080P8200P2DU9@209JFUP80V9RH0P2N
WYh209nOW`80XZ:R0P2SXj<20:FUY@80Y:BT0P2QXJ400`2WYjL0ZZZZ0:ZZZP020:BTY080YJFU0P2X
Z:P20:FUY@80Y:BT0P2UYJD20:BTY0@0YJFU0P2RXZ820:FUY@@0Xj>S0P2UYJD00`2RXZ80Xj>S0:>S
X`020:6QX@80WinO0P2NWYh409^KV`80V9RH0P2IVIT409FEU@80T92@0P2=SHd208Z:RP80QhN70P24
Q8@00`21PH40MGEe07EeM@0206][J`80J6QX0P1JFUX204i>CP80@D510P10@40202l_;`80;Rh^0P0Q
8B4201TI6@804A4A100Z:RX205iNGP03061PH01NGUh0GUiN0080Kfm_0P1aLG420;:b/P80]kNg@P2i
^KTE0?ooo`004`3oool40;Vi^@80]kNg4@2i^KT20;Ng]`P0^KVi0P2e]KD20=cLg080`L710P1hN7P2
05QHF080Cdm?0P1DE5@00`1>CTh0Bd];04];B`0205EEE@80IfMW0P1`L70207UiN@80RXZ:0P2JVYX2
09^KV`80VIVI0P2RXZ820:2PX080XZ:R0P2TY:@20:>SX`<0Y:BT0P2UYJD20:JVYP80XZ:R0P2ZZZX2
0:JVYP80Y:BT1P2UYJD20:RXZ080XZ:R0P2WYjL40:6QX@80XZ:R00<0XJ6Q0:FUY@2UYJD00P2JVYX2
0:6QX@H0Vi^K0P2NWYh409:BTP80U9BD0P2CTi<208Z:RP80SHf=0P22PX8207moO`030861P@1bLW80
LW9b0080K6a/0P1FEUH2051@D080CDe=0P11@D42038b<P80=CDe0P0U9BD202PX:0805QHF0P0@4102
02`/;080ADE50P1OGel00`1LG5`0HF5Q065QH@0207AdM080N7Qh0P2k^k/20;Fe]D80^KVi5@3oool0
01<0oooo102i^KT20;Ng]a40^KVi0P2g]kL80;Vi^@80]KFe0P3Lg=`20<71`@80N7Qh0P1HF5P204m?
C`80E5AD00<0CTi>04];B`1;Bd/00P1EEED206MWI`80L71`0P1iNGT208Z:RP80VYZJ0P2KVi/209VI
V@80XZ:R0P2PX:020::RXP80Y:BT0P2SXj<30:BTY080YJFU0P2VYZH20::RXP80ZZZZ0P2VYZH20:BT
Y0H0YJFU0P2XZ:P20::RXP80YjNW102QXJ420::RXP030:6QX@2UYJD0YJFU0080VYZJ0P2QXJ4609^K
V`80WYjN102BTY8209BDU080Ti>C0P2:RXX208f=S@80PX:20P1oOgl00`21PH40LW9b079bLP0206a/
K080EUIF0P1@D50204e=C@80@D510P0b<S8203De=@809BDU0P0X:2P201HF5P80410@0P0/;2`204E5
A@80GemO00<0G5aL065QH@1QHF400P1dM7@207QhN080^k^k0P2e]KE20;Vi^AD0oooo000C0?ooo`80
^KVi0P2k^k/20;Fe]@l0^KVi0P2k^k/20;Fe]@P0^KVi0P2e]KD20;^k^`80aLG50P33`l<205IFEP80
DE5A0P15ADD00`1>CTh0D51@051@D00205EEE@80H61P0P1dM7@207]kN`80QHF50P2FUYH209NGU`80
V9RH0P2NWYh209nOW`80XJ6Q0P2TY:@20:2PX080Xj>S00<0Y:BT0:FUY@2UYJD00P2UYJD20:>SX`H0
YJFU0P2RXZ820:FUY@80XZ:R0P2SXj<20::RXP80YJFU102QXJ4209fMW@030:6QX@2PX:00X:2P00P0
Vi^K0P2JVYX209^KV`80UIFE102@T90408n?S`80SHf=0P1oOgl208R8R00307QhN01]KFd0KFe]0080
I6AT0P1KFe/2051@D080BDU90P1>CTh203<c<`80;Bd]0P0Y:BT201XJ6P804a<C100i>CT205aLG080
Fe]K00<0EeMG06m_K`1_Kfl00P1]KFd209VIV@80^KVi102g]kM00;Vi^AD0oooo000C0?ooo`80^KVi
0P2k^k/20;Fe]@l0^KVi0P2k^k/20;Fe]@P0^KVi0P2e]KD20;^k^`80aLG50P33`l<205IFEP80DE5A
0P15ADD00`1>CTh0D51@051@D00205EEE@80H61P0P1dM7@207]kN`80QHF50P2FUYH209NGU`80V9RH
0P2NWYh209nOW`80XJ6Q0P2TY:@20:2PX080Xj>S00<0Y:BT0:FUY@2UYJD00P2UYJD20:>SX`H0YJFU
0P2RXZ820:FUY@80XZ:R0P2SXj<20::RXP80YJFU102QXJ4209fMW@030:6QX@2PX:00X:2P00P0Vi^K
0P2JVYX209^KV`80UIFE102@T90408n?S`80SHf=0P1oOgl208R8R00307QhN01]KFd0KFe]0080I6AT
0P1KFe/2051@D080BDU90P1>CTh203<c<`80;Bd]0P0Y:BT201XJ6P804a<C100i>CT205aLG080Fe]K
00<0EeMG06m_K`1_Kfl00P1]KFd209VIV@80^KVi102g]kM00;Vi^AD0oooo000C0?ooobD0^KVi0P2e
]KD20=[JfP80EEEE0P12@T8205]KF`0304Y:BP1GEeL0EeMG0080FEUI0P1SHf<206m_K`80Ng]k0P28
R8P209JFUP80Ti>C0P2KVi/209RHV080WinO102PX:020:>SX`80WinO00<0Xj>S0:FUY@2UYJD00P2U
YJD20::RXP@0YJFU0P2XZ:P20:6QX@80YZJV0P2PX:020:BTY080WinO0P2NWYh20:2PX080WinO0P2Q
XJ4509^KV`80W9bL102KVi/209VIV@80VYZJ0P2DU9@2092@T0@0Shn?0P29RHT208B4Q080Ogmo0P1k
Ng/00`1lO7`0K6a/06a/K00206=SH`80Fe]K0P1@D50404=3@`80EeMG0P0U9BD201XJ6P807QhN0P0i
>CT202XZ:P@0GemO0P1NGUh00`1IFET0KFe]06e]K@020820P080[Jf]0P2k^k/20;Fe]D80^KVi5@3o
ool001<0oooo9@2i^KT20;Fe]@80f][J0P1EEED20492@P80Fe]K00<0BTY:05MGE`1GEeL00P1IFET2
06=SH`80Kfm_0P1kNg/208R8R080UYJF0P2CTi<209^KV`80V9RH0P2OWil40:2PX080Xj>S0P2OWil0
0`2SXj<0YJFU0:FUY@020:FUY@80XZ:R102UYJD20:RXZ080XJ6Q0P2VYZH20:2PX080Y:BT0P2OWil2
09jNWP80X:2P0P2OWil20:6QX@D0Vi^K0P2LW9`409^KV`80VIVI0P2JVYX209BDU080T92@102?Shl2
08V9R@80Q8B40P1oOgl207]kN`0307alO01/K6`0K6a/0080Hf=S0P1KFe/2051@D0@0@d=30P1GEeL2
02DU9@806QXJ0P0N7Qh203Ti>@80:RXZ101OGel205iNGP0305UIF@1]KFd0KFe]0080P8200P2][Jd2
0;^k^`80]KFe@P2i^KTE0?ooo`004`3ooolU0;Vi^@80]KFe0P31`L4209FEU@80@d=30P12@T800`1G
EeL0Cdm?04m?C`0406=SH`80L71`0P1kNg/208J6QP80SXj>0P2GUiL209^KV`80VYZJ0P2IVIT209jN
WP80W9bL0P2VYZH20:6QX@0309jNWP2UYJD0YJFU0080WinO202SXj<20:JVYP80WinO0P2LW9`20:6Q
X@80X:2P0P2GUiL209bLW080V9RH0P2PX:0309^KV`80VYZJ202KVi/2092@T080UIFE0P2?Shl208j>
SP80Rh^;0P29RHT208F5Q@80LW9b0P1fMWH00`1]KFd0Hf=S06=SH`0205YJFP@0D51@0P1;Bd/204A4
A080<c<c0P1:BTX2038b<P80=CDe0P0_;bl2055AD@80DU9B0P1WIfL206EUI@0306QXJ01gMgL0MgMg
0080PH610P2e]KD20;jn_P80/[:b0P2o_km00;Vi^AD0oooo000C0?ooobD0^KVi0P2e]KD20<71`@80
UIFE0P13@d<20492@P0305MGE`1?Cdl0Cdm?00@0Hf=S0P1`L70207]kN`80QXJ60P2>SXh209NGU`80
Vi^K0P2JVYX209VIV@80WYjN0P2LW9`20:JVYP80XJ6Q00<0WYjN0:FUY@2UYJD00P2OWil80:>SX`80
YZJV0P2OWil209bLW080XJ6Q0P2PX:0209NGU`80W9bL0P2HV9P20:2PX0<0Vi^K0P2JVYX809^KV`80
T92@0P2EUID208n?S`80SXj>0P2;Rh/208V9R@80QHF50P1bLW8207IfMP0306e]K@1SHf<0Hf=S0080
FUYJ101@D50204];B`80A4A40P0c<c<204Y:BP80<S8b0P0e=CD202l_;`80DE5A0P1BDU8206MWI`80
IFEU00<0J6QX07MgM`1gMgL00P21PH420;Fe]@80_[jn0P2b/[820;no_d00^KVi5@3oool001<0oooo
9@2i^KT20;Fe]@80`<300P2EUID204i>CP80@d=300<0ADE504M7A`17AdL00P1IFET205mOG`80Jf][
0P1fMWH208F5Q@80RHV90P2@T90409RHV080UYJF0P2OWil209RHV080YJFU0P2MWId309jNWP80WinO
0P2QXJ440::RXP80W9bL0P2UYJD209bLW080WIfM0P2IVIT209FEU@80V9RH0P2=SHd209NGU`80Vi^K
00<0VYZJ09NGU`2GUiL0102FUYH209FEU@80U9BD0P2FUYH208b<S0@0SHf=0P26QXH208F5Q@80PH61
0P1nOWh407=cL`0306UYJ@1RHV80HV9R0080GemO0P1;Bd/204A4A080@T920P0o?cl203dm?@80=CDe
0P0b<S8204=3@`80F5QH0P18B4P205eMG@80H61P0P1dM7@00`1`L700RXZ:08Z:RP0209:BTP80]KFe
0P2o_kl20;Ng]`@0^KVi0P2l_;`Q0;Vi^@80_;bl6@2i^KTE0?ooo`004`3ooolU0;Vi^@80]KFe0P30
`<0209FEU@80CTi>0P13@d<00`15ADD0AdM704M7A`0205UIF@80GemO0P1[Jf/207IfMP80QHF50P29
RHT2092@T0@0V9RH0P2FUYH209nOW`80V9RH0P2UYJD209fMW@<0WYjN0P2OWil20:6QX@@0XZ:R0P2L
W9`20:FUY@80W9bL0P2MWId209VIV@80UIFE0P2HV9P208f=S@80UiNG0P2KVi/00`2JVYX0UiNG09NG
U`0409JFUP80UIFE0P2DU9@209JFUP80S8b<102=SHd208J6QP80QHF50P21PH4207inOP@0Lg=c00<0
JFUY069RHP1RHV800P1OGel204];B`80A4A40P12@T8203lo?`80?Cdm0P0e=CD2038b<P80@d=30P1H
F5P204Q8B080GEeM0P1PH60207AdM003071`L02:RXX0RXZ:0080TY:B0P2e]KD20;no_`80]kNg102i
^KT20;bl_240^KVi0P2l_;`I0;Vi^AD0oooo000C0?ooobD0^KVi0P2e]KD20=WIf@80Vi^K0P1<C4`2
03De=@0304];B`1:BTX0BTY:0080CTi>0P1MGEd206QXJ080MGEe0P1lO7`208Z:RP80S8b<0P2@T902
09VIV@80SXj>0P2LW9`209^KV`80W9bL0P2OWil00`2NWYh0VYZJ09ZJVP0209ZJVP80WIfM0P2LW9`2
0:>SX`80VIVI0P2OWil209ZJVP80UiNG0P2FUYH208n?S`@0SXj>0P2=SHd209>CT`0309:BTP2@T900
T92@0080S8b<0P2?Shl208^;R`80S8b<0P2>SXh208J6QP80RHV90P28R8P40861P@80Ogmo0P1aLG42
071`L080KFe]00<0Jf][05iNGP1NGUh00P1FEUH2059BDP80B4Q80P15ADD404a<C080?Shn0P1=CDd2
0451@@80IfMW0P1LG5`206QXJ080GemO0P29RHT00`1lO7`0Ogmo07moO`020;Ng]`80^KVi0P2k^k/2
0;Fe]@80_;bl0P2e]KD20;no_aD0^KVi0P2g]kL80;Vi^@80]KFe0P2o_klI0;Vi^AD0oooo000C0?oo
obD0^KVi0P2e]KD20=WIf@80Vi^K0P1<C4`203De=@0304];B`1:BTX0BTY:0080CTi>0P1MGEd206QX
J080MGEe0P1lO7`208Z:RP80S8b<0P2@T90209VIV@80SXj>0P2LW9`209^KV`80W9bL0P2OWil00`2N
WYh0VYZJ09ZJVP0209ZJVP80WIfM0P2LW9`20:>SX`80VIVI0P2OWil209ZJVP80UiNG0P2FUYH208n?
S`@0SXj>0P2=SHd209>CT`0309:BTP2@T900T92@0080S8b<0P2?Shl208^;R`80S8b<0P2>SXh208J6
QP80RHV90P28R8P40861P@80Ogmo0P1aLG42071`L080KFe]00<0Jf][05iNGP1NGUh00P1FEUH2059B
DP80B4Q80P15ADD404a<C080?Shn0P1=CDd20451@@80IfMW0P1LG5`206QXJ080GemO0P29RHT00`1l
O7`0Ogmo07moO`020;Ng]`80^KVi0P2k^k/20;Fe]@80_;bl0P2e]KD20;no_aD0^KVi0P2g]kL80;Vi
^@80]KFe0P2o_klI0;Vi^AD0oooo000C0?ooobL0^KVi0P32`/820:VYZ@80VIVI0P16ATH00`10@400
FEUI05UIF@0204];B`80EUIF0P1PH60206IVIP80O7al0P29RHT208b<S080SHf=0P2@T90208f=S@80
UYJF0P2LW9`209ZJVP80VIVI00<0WYjN09VIV@2IVIT01P2GUiL209JFUP80TY:B0P2@T90209:BTP80
T92@0P2<S8`208J6QP80QHF50P21PH4208>3P`80QXJ60`23Ph<208:2PP80Q8B4101kNg/20861P@80
NGUi0P1oOgl407MgM`80M7Ad0P1hN7P207=cL`80JFUY0P1PH6000`1JFUX0G5aL05aLG00205eMG@80
C4a<0P1ADE4205IFEP80@4100P1@D50205IFEP80CDe=0P1CDe<2069RHP80H61P0P1VIVH206a/K080
Ph>300<0UiNG096AT@2ATI400P2e]KD40;Vi^@80]KFe0P2o_klG0;Vi^@80^k^k0P2e]KDU0;Vi^AD0
oooo000C0?ooobL0^KVi0P32`/820:VYZ@80VIVI0P16ATH00`10@400FEUI05UIF@0204];B`80EUIF
0P1PH60206IVIP80O7al0P29RHT208b<S080SHf=0P2@T90208f=S@80UYJF0P2LW9`209ZJVP80VIVI
00<0WYjN09VIV@2IVIT01P2GUiL209JFUP80TY:B0P2@T90209:BTP80T92@0P2<S8`208J6QP80QHF5
0P21PH4208>3P`80QXJ60`23Ph<208:2PP80Q8B4101kNg/20861P@80NGUi0P1oOgl407MgM`80M7Ad
0P1hN7P207=cL`80JFUY0P1PH6000`1JFUX0G5aL05aLG00205eMG@80C4a<0P1ADE4205IFEP80@410
0P1@D50205IFEP80CDe=0P1CDe<2069RHP80H61P0P1VIVH206a/K080Ph>300<0UiNG096AT@2ATI40
0P2e]KD40;Vi^@80]KFe0P2o_klG0;Vi^@80^k^k0P2e]KDU0;Vi^AD0oooo000C0?ooobT0^KVi0P3H
f=P20:JVYP80Kfm_00<0CTi>04];B`1;Bd/00P1GEeL205QHF080HV9R0P1PH60206QXJ080LW9b0P28
R8P208Z:RP80SHf=0P2DU9@209:BTP80VIVI102GUiL00`2HV9P0UIFE09FEU@0208j>SP@0Rh^;0P2B
TY82096AT@80QhN71026QXH208>3P`80O7al0P1jNWX407MgM`80NGUi00<0M7Ad07IfMP1fMWH00P1b
LW82071`L080LG5a0P1YJFT206m_K`80L71`0P1^KVh2075aL@80K6a/0P1WIfL206m_K`80Lg=c0P1_
Kfl206i^KP0306EUI@1LG5`0G5aL0080F5QH0P1FEUH2051@D080GUiN0P1HF5P203De=@80@T920P1I
FET206=SH`80IfMW0P1NGUh207UiN@80LW9b0P29RHT00`21PH40];Bd0;Bd]00<0;Vi^@80]kNg8@2i
^KT20;bl_1T0^KVi5@3oool001<0oooo:@2i^KT20=SHf080YZJV0P1_Kfl00`1>CTh0Bd];04];B`02
05MGE`80F5QH0P1RHV82061PH080J6QX0P1bLW8208R8R080RXZ:0P2=SHd209BDU080TY:B0P2IVIT4
09NGU`0309RHV02EUID0UIFE0080SXj>102;Rh/209:BTP80TI6A0P27QhL408J6QP80Ph>30P1lO7`2
07YjNP@0MgMg0P1iNGT00`1dM7@0MWIf07IfMP02079bLP80L71`0P1aLG4206UYJ@80Kfm_0P1`L702
06i^KP80LG5a0P1/K6`206MWI`80Kfm_0P1cLg<206m_K`80KVi^00<0IFEU05aLG01LG5`00P1HF5P2
05IFEP80D51@0P1NGUh205QHF080=CDe0P12@T8205UIF@80Hf=S0P1WIfL205iNGP80NGUi0P1bLW82
08V9R@030861P@2d];@0];Bd00`0^KVi0P2g]kLQ0;Vi^@80_;bl6@2i^KTE0?ooo`004`3oool[0;Vi
^@80e]KF0P2j^[X00`24Q8@0Fe]K05]KF`0204e=C@80DU9B0P1NGUh205aLG080GUiN0P1bLW8207Ee
M@80Shn?0P2BTY8209FEU@80VYZJ0P2HV9P209>CT`80Shn?00<0S8b<08j>SP2>SXh00P27QhL208V9
R@80PH610P22PX8208n?S`80Ph>30P20P80207YjNP80O7al0P1_Kfl207EeM@80Jf][0P1cLg<206=S
H`0307AdM01VIVH0IVIV0080Jf][0P1IFET206UYJ@80Hf=S0P1RHV8206IVIP80HF5Q0P1TI6@206EU
I@80IfMW0P1FEUH205UIF@80Hf=S0P1OGel00`1SHf<0GEeM05eMG@02069RHP80FUYJ0P1;Bd/204Y:
BP80G5aL0P1KFe/204e=C@80DE5A0P1RHV8206i^KP80LW9b0P1jNWX208>3P`80PX:200<0TY:B0;Vi
^@2i^KT0102i^KT20;Ng]`@0^KVi0P2k^k/20;Fe]AT0^KVi0P2g]kL40;Vi^@80]KFe0P2o_klI0;Vi
^AD0oooo000C0?ooob/0^KVi0P3Fe]H20;Zj^P0308B4Q01KFe/0Fe]K0080CDe=0P1BDU8205iNGP80
G5aL0P1NGUh2079bLP80MGEe0P2?Shl209:BTP80UIFE0P2JVYX209RHV080Ti>C0P2?Shl00`2<S8`0
SXj>08j>SP0208N7Q`80RHV90P21PH4208:2PP80Shn?0P23Ph<20820P080NWYj0P1lO7`206m_K`80
MGEe0P1[Jf/207=cL`80Hf=S00<0M7Ad06IVIP1VIVH00P1[Jf/205UIF@80JFUY0P1SHf<2069RHP80
IVIV0P1QHF4206ATI080IFEU0P1WIfL205IFEP80FEUI0P1SHf<205mOG`0306=SH`1MGEd0GEeM0080
HV9R0P1JFUX204];B`80BTY:0P1LG5`205]KF`80CDe=0P1ADE42069RHP80KVi^0P1bLW8207YjNP80
Ph>30P22PX800`2BTY80^KVi0;Vi^@040;Vi^@80]kNg102i^KT20;^k^`80]KFe6@2i^KT20;Ng]`@0
^KVi0P2e]KD20;no_aT0^KVi5@3oool001<0oooo402i^KT00`2g]kL0^KVi0;Vi^@020;Ng]aP0^KVi
0P2o_kl00`2][Jd0KVi^06i^KP0206MWI`80EEEE0P1QHF4207MgM`80IfMW101fMWH208N7Q`80S8b<
0P2ATI4209NGU`@0TI6A0P2:RXX00`29RHT0Ph>308>3P`020820P080O7al1021PH4407alO080P820
0P1cLg<2075aL@80K6a/0P1VIVH206QXJ080KFe]0P1`L70306QXJ080Kfm_0P1WIfL205IFEP80KVi^
0P1SHf<206e]K@80Hf=S0P1QHF4206EUI@80J6QX0P1NGUh2059BDP80Fe]K0P1OGel00`1LG5`0FEUI
05UIF@02061PH080F5QH0P1MGEd2051@D080DE5A0P1CDe<205MGE`80H61P0P1`L70207AdM080NWYj
0P29RHT209JFUP80KVi^1@2i^KT20;^k^b40^KVi0P2k^k/20;Fe]B40^KVi5@3oool001<0oooo402i
^KT00`2g]kL0^KVi0;Vi^@020;Ng]aP0^KVi0P2o_kl00`2][Jd0KVi^06i^KP0206MWI`80EEEE0P1Q
HF4207MgM`80IfMW101fMWH208N7Q`80S8b<0P2ATI4209NGU`@0TI6A0P2:RXX00`29RHT0Ph>308>3
P`020820P080O7al1021PH4407alO080P8200P1cLg<2075aL@80K6a/0P1VIVH206QXJ080KFe]0P1`
L70306QXJ080Kfm_0P1WIfL205IFEP80KVi^0P1SHf<206e]K@80Hf=S0P1QHF4206EUI@80J6QX0P1N
GUh2059BDP80Fe]K0P1OGel00`1LG5`0FEUI05UIF@02061PH080F5QH0P1MGEd2051@D080DE5A0P1C
De<205MGE`80H61P0P1`L70207AdM080NWYj0P29RHT209JFUP80KVi^1@2i^KT20;^k^b40^KVi0P2k
^k/20;Fe]B40^KVi5@3oool001<0oooo1P2i^KT20;Ng]`H0^KVi0P2k^k/00`2e]KD0^k^k0;^k^`02
0;Fe]AX0^KVi00<0iNGU07emO@1mOGd00P1SHf<206ATI080EUIF0P1MGEd2075aL@80N7Qh0P1`L702
08N7Q`80QXJ60P29RHT208^;R`80S8b<0P28R8P208N7Q`0307moO`1nOWh0OWin0080OWin0P1aLG42
079bLP80NWYj0P1gMgL2079bLP80MGEe0P1dM7@206e]K@80HF5Q0P1XJ6P2059BDP80JVYZ0P1OGel0
0`1`L700IfMW06MWI`0205eMG@80JVYZ0P1VIVH205aLG080IVIV0P1HF5P2069RHP80IFEU0P1TI6@2
05aLG080Hf=S0P1<C4`204U9B@80ATI600<0BDU904e=C@1=CDd00P1:BTX204m?C`80B4Q80P1<C4`2
04i>CP80G5aL0P1QHF4206e]K@80Lg=c0P28R8P208J6QP80Ng]k0P1[Jf/209nOW`D0^KVi0P2e]KD2
0;no_d@0^KVi5@3oool001<0oooo1P2i^KT20;Ng]`H0^KVi0P2k^k/00`2e]KD0^k^k0;^k^`020;Fe
]AX0^KVi00<0iNGU07emO@1mOGd00P1SHf<206ATI080EUIF0P1MGEd2075aL@80N7Qh0P1`L70208N7
Q`80QXJ60P29RHT208^;R`80S8b<0P28R8P208N7Q`0307moO`1nOWh0OWin0080OWin0P1aLG42079b
LP80NWYj0P1gMgL2079bLP80MGEe0P1dM7@206e]K@80HF5Q0P1XJ6P2059BDP80JVYZ0P1OGel00`1`
L700IfMW06MWI`0205eMG@80JVYZ0P1VIVH205aLG080IVIV0P1HF5P2069RHP80IFEU0P1TI6@205aL
G080Hf=S0P1<C4`204U9B@80ATI600<0BDU904e=C@1=CDd00P1:BTX204m?C`80B4Q80P1<C4`204i>
CP80G5aL0P1QHF4206e]K@80Lg=c0P28R8P208J6QP80Ng]k0P1[Jf/209nOW`D0^KVi0P2e]KD20;no
_d@0^KVi5@3oool001<0oooo102i^KT20;^k^`80]KFe9`2i^KT00`2e]KD0m_Kf0?KfmP0208>3P`80
KFe]0P1TI6@2069RHP80Lg=c101jNWX20820P080S8b<0P2?Shl208R8R080P8200P1mOGd208B4Q0<0
NWYj0P1nOWh2079bLP80Lg=c0P1[Jf/207AdM080KVi^0P1/K6`6069RHP80Hf=S0P1OGel20410@080
Fe]K00<0DE5A06QXJ01XJ6P00P1RHV8406=SH`80DE5A0P1UIFD205QHF080ATI60P0o?cl205EEE@80
E5AD0P1=CDd2055AD@80D51@0P1CDe<00`1@D500CDe=04e=C@0205EEE@80BDU90P1=CDd205ADE080
G5aL0P1]KFd206][J`80OGem0P1WIfL207moO`80KVi^0P2:RXX205UIF@80_;bl3@2i^KT20;Ng]ch0
^KVi5@3oool001<0oooo102i^KT20;^k^`80]KFe9`2i^KT00`2e]KD0m_Kf0?KfmP0208>3P`80KFe]
0P1TI6@2069RHP80Lg=c101jNWX20820P080S8b<0P2?Shl208R8R080P8200P1mOGd208B4Q0<0NWYj
0P1nOWh2079bLP80Lg=c0P1[Jf/207AdM080KVi^0P1/K6`6069RHP80Hf=S0P1OGel20410@080Fe]K
00<0DE5A06QXJ01XJ6P00P1RHV8406=SH`80DE5A0P1UIFD205QHF080ATI60P0o?cl205EEE@80E5AD
0P1=CDd2055AD@80D51@0P1CDe<00`1@D500CDe=04e=C@0205EEE@80BDU90P1=CDd205ADE080G5aL
0P1]KFd206][J`80OGem0P1WIfL207moO`80KVi^0P2:RXX205UIF@80_;bl3@2i^KT20;Ng]ch0^KVi
5@3oool001<0oooo<02i^KT20;Fe]@80b<S80P1iNGT205UIF@80E5AD0P1PH60206IVIP80LW9b0P28
R8P408b<S080TI6A0P1lO7`207MgM`80MGEe00<0MgMg07=cL`1cLg<00P1gMgL206i^KP80L71`0P1]
KFd206IVIP80Kfm_0P1^KVh205YJFP80JVYZ0P1NGUh205YJFP80KFe]0P1OGel20451@@0306=SH`1<
C4`0C4a<0080F5QH0P1GEeL2059BDP80EEEE0P16ATH203hn?P80DE5A0P13@d<204I6AP80CDe=0P19
BDT204i>CP80C4a<0P1:BTX00`14A4@0CDe=04e=C@0205IFEP80I6AT0P1NGUh206QXJ080GemO0P29
RHT20861P@80N7Qh0P22PX8205IFEP80N7Qh0P1:BTX209^KV`80_kno1@2i^KT20;Ng]`H0^KVi0P2e
]KDI0;Vi^@80]kNg102i^KT20;bl_1d0^KVi5@3oool001<0oooo<02i^KT20;Fe]@80b<S80P1iNGT2
05UIF@80E5AD0P1PH60206IVIP80LW9b0P28R8P408b<S080TI6A0P1lO7`207MgM`80MGEe00<0MgMg
07=cL`1cLg<00P1gMgL206i^KP80L71`0P1]KFd206IVIP80Kfm_0P1^KVh205YJFP80JVYZ0P1NGUh2
05YJFP80KFe]0P1OGel20451@@0306=SH`1<C4`0C4a<0080F5QH0P1GEeL2059BDP80EEEE0P16ATH2
03hn?P80DE5A0P13@d<204I6AP80CDe=0P19BDT204i>CP80C4a<0P1:BTX00`14A4@0CDe=04e=C@02
05IFEP80I6AT0P1NGUh206QXJ080GemO0P29RHT20861P@80N7Qh0P22PX8205IFEP80N7Qh0P1:BTX2
09^KV`80_kno1@2i^KT20;Ng]`H0^KVi0P2e]KDI0;Vi^@80]kNg102i^KT20;bl_1d0^KVi5@3oool0
01<0oooo<P2i^KT20=WIf@80LG5a0P1SHf<2061PH080Jf][0P1NGUh206=SH`80NGUi0P29RHT208R8
R080Rh^;0P1gMgL206][J`80KVi^00<0KFe]07IfMP1fMWH00P1cLg<206QXJ080IFEU0P1ZJVX206a/
K080IVIV0P1YJFT2075aL@80BTY:101RHV8204Y:BP80KFe]0P1CDe<00`18B4P0FUYJ05YJFP0404e=
C@80DE5A0P15ADD204Q8B080BDU90P12@T820451@@80>SXj0P18B4P204M7A`80ADE50P19BDT204Q8
B00304e=C@1CDe<0De=C0080FEUI0P1MGEd206ATI080IfMW0P23Ph<206UYJ@80KVi^0P1kNg/2079b
LP80K6a/0P26QXH206EUI@@0]kNg1@2i^KT20;Fe]@@0^KVi0P2e]KD20;Vi^@80_;bl202i^KT20;bl
_0/0^KVi0P2k^k/20;Fe]@80^KVi0P2e]KD20;no_ad0^KVi5@3oool001<0oooo<P2i^KT20=WIf@80
LG5a0P1SHf<2061PH080Jf][0P1NGUh206=SH`80NGUi0P29RHT208R8R080Rh^;0P1gMgL206][J`80
KVi^00<0KFe]07IfMP1fMWH00P1cLg<206QXJ080IFEU0P1ZJVX206a/K080IVIV0P1YJFT2075aL@80
BTY:101RHV8204Y:BP80KFe]0P1CDe<00`18B4P0FUYJ05YJFP0404e=C@80DE5A0P15ADD204Q8B080
BDU90P12@T820451@@80>SXj0P18B4P204M7A`80ADE50P19BDT204Q8B00304e=C@1CDe<0De=C0080
FEUI0P1MGEd206ATI080IfMW0P23Ph<206UYJ@80KVi^0P1kNg/2079bLP80K6a/0P26QXH206EUI@@0
]kNg1@2i^KT20;Fe]@@0^KVi0P2e]KD20;Vi^@80_;bl202i^KT20;bl_0/0^KVi0P2k^k/20;Fe]@80
^KVi0P2e]KD20;no_ad0^KVi5@3oool001<0oooo<P2i^KT20;Fe]@80oooo0P1^KVh204E5A@80Jf][
1P1`L70207emO@80T92@0P2:RXX207emO@80IFEU0P1ZJVX00`1PH600Jf][06][J`0206a/K080I6AT
0P1MGEd206UYJ@80I6AT0P1MGEd206EUI@80GUiN0P1MGEd2051@D080G5aL0P1KFe/204I6AP80BDU9
00<0D51@04a<C01<C4`00P1;Bd/204U9B@80Bd];0P19BDT20410@080?clo0P0g=cL203@d=080>SXj
0P0h>3P203/k>`80A4A40P1@D50204e=C@0304Y:BP1EEED0EEEE0080KFe]0P1cLg<207IfMP80N7Qh
0P1lO7`208N7Q`80GemO0P1TI6@205eMG@@0M7Ad0P2d];@20;^k^`80/k>c00<0^KVi0;^k^`2k^k/0
0P2e]KD20;Vi^@80^k^k0P2e]KD20;Vi^@80]KFe0P2o_kl60;Vi^@80]KFe0P2o_klb0;Vi^AD0oooo
000C0?oooc80^KVi0P2e]KD20?ooo`80KVi^0P15ADD206][J`H0L71`0P1mOGd2092@T080RXZ:0P1m
OGd206EUI@80JVYZ00<0H61P06][J`1[Jf/00P1/K6`206ATI080GEeM0P1YJFT206ATI080GEeM0P1U
IFD205iNGP80GEeM0P1@D50205aLG080Fe]K0P16ATH204U9B@03051@D01<C4`0C4a<0080Bd];0P19
BDT204];B`80BDU90P10@40203lo?`80=cLg0P0d=3@203Xj>P80>3Ph0P0k>c/204A4A080D51@0P1=
CDd00`1:BTX0EEEE05EEE@0206e]K@80Lg=c0P1fMWH207QhN080O7al0P27QhL205mOG`80I6AT0P1M
GEd407AdM080];Bd0P2k^k/20;>c/`030;Vi^@2k^k/0^k^k0080]KFe0P2i^KT20;^k^`80]KFe0P2i
^KT20;Fe]@80_kno1P2i^KT20;Fe]@80_kno<P2i^KTE0?ooo`004`3ooold0;Vi^@80]kNg0P3/k>`2
08^;R`80>3Ph0P1FEUH206QXJ080M7Ad0P1_Kfl208j>SP80T92@0P20P80205UIF@80KFe]00<0J6QX
06IVIP1VIVH00P1cLg<206i^KP80FUYJ0P1RHV8206UYJ@80EEEE0P1PH60405mOG`80CTi>0P1TI6@2
05eMG@80G5aL0P0e=CD00`0d=3@0DE5A055AD@02059BDP80C4a<0P17AdL203Ti>@80A4A40P0m?Cd2
03Ph>0P0;Rh^0P0h>3P204=3@`80H61P00<0Hf=S065QH@1QHF400P1WIfL20820P080LW9b0P1WIfL2
06YZJP80L71`0P1aLG42059BDP80OWin0P0o?cl20:^[Z`80^k^k0P31`L420;Fe]@<0^KVi0P2g]kL2
0;Vi^@80_;bl5P2i^KT00`2g]kL0^KVi0;Vi^@0@0;Vi^@80_;bl6@2i^KTE0?ooo`004`3oool<0;Vi
^@80]kNg902i^KT20;^k^`@0]KFe0P3Shn<207=cL`80@D510P1=CDd205iNGP80JVYZ0P20P802096A
T@80QXJ60P1QHF4205ADE003079bLP1OGel0GemO0080GUiN0P1WIfL2069RHP80Cdm?0P1NGUh2069R
HP80DE5A0P1IFET206EUI@80F5QH0P1DE5@205mOG`80H61P0P1RHV800`17AdL0@4100410@00203/k
>`80EEEE0P18B4P204Y:BP80@T920P1:BTX204m?C`80B4Q80P11@D4204M7A`80C4a<0P1=CDd205IF
EP80FEUI00<0KFe]08B4Q024Q8@00P1kNg/206i^KP80NWYj0P1DE5@204a<C080GUiN0P1^KVh207If
MP80DE5A0P23Ph<90;Vi^@80_[jn0P2e]KD20;>c/`80_kno202i^KT20;bl_0X0^KVi0P2k^k/00`2e
]KD0^KVi0;Vi^@020;bl_0`0^KVi0P2e]KD20;no_aT0^KVi5@3oool001<0oooo302i^KT20;Ng]b@0
^KVi0P2k^k/40;Fe]@80hn?S0P1cLg<20451@@80CDe=0P1NGUh206YZJP80P8200P2ATI4208J6QP80
HF5Q0P1DE5@00`1bLW80GemO05mOG`0205iNGP80IfMW0P1RHV8204m?C`80GUiN0P1RHV82055AD@80
FEUI0P1UIFD205QHF080E5AD0P1OGel2061PH080HV9R00<0AdM70410@010@4000P0k>c/205EEE@80
B4Q80P1:BTX20492@P80BTY:0P1?Cdl204Q8B080@D510P17AdL204a<C080CDe=0P1FEUH205UIF@03
06e]K@24Q8@0Q8B40080Ng]k0P1^KVh207YjNP80E5AD0P1<C4`205iNGP80KVi^0P1fMWH2055AD@80
Ph>32@2i^KT20;jn_P80]KFe0P2c/k<20;no_`P0^KVi0P2l_;`:0;Vi^@80^k^k00<0]KFe0;Vi^@2i
^KT00P2l_;`<0;Vi^@80]KFe0P2o_klI0;Vi^AD0oooo000C0?ooo`X0^KVi0P2k^k/20;Fe]BX0^KVi
0P38b<P20<[:bP80Kfm_0P1FEUH204];B`80DE5A0P1QHF4206m_K`80T92@0P1YJFT2055AD@0305YJ
FP1`L700L71`0080H61P0P1GEeL205EEE@80C4a<0P17AdL2059BDP@0E5AD0P1FEUH205UIF@80EEEE
0P1DE5@206MWI`80HV9R00<0Fe]K059BDP1BDU800P1BDU8204M7A`80BDU90P1ADE4405=CD`80Bd];
0P1KFe/205UIF@80GEeM0P1TI6@206][J`80KFe]0P1`L7000`1jNWX0L71`071`L00208N7Q`80K6a/
0P1NGUh206=SH`80DU9B101RHV8206UYJ@80N7Qh0P2i^KT40;bl_080^KVi0P2g]kL00`2i^KT0_Kfm
0;fm_@020;jn_P80]KFe0P2g]kL20;Vi^@80_;bl0P2i^KT20;Fe]@80_kno3@2i^KT20;Fe]@80_kno
202i^KT20;bl_1l0^KVi5@3oool001<0oooo2P2i^KT20;^k^`80]KFe:P2i^KT20<S8b080b/[:0P1_
Kfl205IFEP80Bd];0P1ADE42065QH@80Kfm_0P2@T90206UYJ@80DE5A00<0FUYJ071`L01`L7000P1P
H60205MGE`80EEEE0P1<C4`204M7A`80DU9B101DE5@205IFEP80FEUI0P1EEED205ADE080IfMW0P1R
HV800`1KFe/0DU9B059BDP02059BDP80AdM70P19BDT2055AD@@0De=C0P1;Bd/205]KF`80FEUI0P1M
GEd206ATI080Jf][0P1]KFd2071`L00307YjNP1`L700L71`0080QhN70P1/K6`205iNGP80Hf=S0P1B
DU84069RHP80JFUY0P1hN7P20;Vi^@@0_;bl0P2i^KT20;Ng]`030;Vi^@2m_Kd0_Kfm0080_[jn0P2e
]KD20;Ng]`80^KVi0P2l_;`20;Vi^@80]KFe0P2o_kl=0;Vi^@80]KFe0P2o_kl80;Vi^@80_;bl7`2i
^KTE0?ooo`004`3ooold0;Vi^@80_;bl102i^KT20<o?c`80/k>c0P1ZJVX205iNGP80FUYJ0P1GEeL2
06QXJ080IVIV0P2KVi/205mOG`03059BDP1MGEd0GEeM0080KVi^0P1MGEd2069RHP80Cdm?0P19BDT2
04Q8B080De=C0P1DE5@205QHF080DE5A0P1FEUH205MGE`80I6AT0P1/K6`00`1UIFD0LG5a075aL@02
05EEE@80FEUI0P1;Bd/204e=C@80GEeM0P1SHf<206ATI080IFEU0P1VIVH206i^KP80MGEe0P26QXH2
06e]K@80H61P00<0LG5a05YJFP1JFUX00P18B4P204Y:BP80IfMW0P1HF5P205iNGP80KFe]0P1aLG42
06EUI@80_kno0P2e]KD20;^k^`80`/;20P2n_[h20;:b/P030<71`@2e]KD0]KFe0080_kno0P2k^k/4
0;Fe]@80_kno7@2i^KT20;Fe]@80_kno7`2i^KTE0?ooo`004`3ooold0;Vi^@80_;bl102i^KT20<o?
c`80/k>c0P1ZJVX205iNGP80FUYJ0P1GEeL206QXJ080IVIV0P2KVi/205mOG`03059BDP1MGEd0GEeM
0080KVi^0P1MGEd2069RHP80Cdm?0P19BDT204Q8B080De=C0P1DE5@205QHF080DE5A0P1FEUH205MG
E`80I6AT0P1/K6`00`1UIFD0LG5a075aL@0205EEE@80FEUI0P1;Bd/204e=C@80GEeM0P1SHf<206AT
I080IFEU0P1VIVH206i^KP80MGEe0P26QXH206e]K@80H61P00<0LG5a05YJFP1JFUX00P18B4P204Y:
BP80IfMW0P1HF5P205iNGP80KFe]0P1aLG4206EUI@80_kno0P2e]KD20;^k^`80`/;20P2n_[h20;:b
/P030<71`@2e]KD0]KFe0080_kno0P2k^k/40;Fe]@80_kno7@2i^KT20;Fe]@80_kno7`2i^KTE0?oo
o`004`3ooolb0;Vi^@80]KFe0P2m_Kd40;Vi^@80]kNg0P3Fe]H20;2`/080HF5Q0P1HF5P2061PH080
K6a/0P1^KVh207]kN`80UIFE00<0IVIV05UIF@1IFET00P1KFe/206IVIP80FEUI0P1/K6`205IFEP80
Bd];1013@d<204a<C080De=C0P1:BTX2061PH080GemO0P1fMWH00`1_Kfl0QHF508F5Q@0209NGU`80
O7al0P1aLG42071`L080N7Qh0P1bLW8207moO`80QhN70P29RHT207YjNP80O7al0P1UIFD206i^KP80
GEeM00<0DE5A059BDP1BDU800P1CDe<2059BDP80FUYJ101WIfL205EEE@80MWIf0P2o_kl20;Vi^@80
_;bl0P2e]KD20;^k^`80_kno0P2i^KT00`2e]KD0_kno0;no_`020;Vi^@80]kNg102i^KT40;bl_3h0
^KVi5@3oool001<0oooo<P2i^KT20;Fe]@80_Kfm102i^KT20;Ng]`80e]KF0P2`/;02065QH@80F5QH
0P1PH60206a/K080KVi^0P1kNg/209FEU@0306IVIP1IFET0FEUI0080Fe]K0P1VIVH205UIF@80K6a/
0P1FEUH204];B`@0@d=30P1<C4`205=CD`80BTY:0P1PH60205mOG`80MWIf00<0Kfm_08F5Q@25QHD0
0P2GUiL207alO080LG5a0P1`L70207QhN080LW9b0P1oOgl208N7Q`80RHV90P1jNWX207alO080IFEU
0P1^KVh205eMG@03055AD@1BDU80DU9B0080De=C0P1BDU8205YJFP@0IfMW0P1EEED207IfMP80_kno
0P2i^KT20;bl_080]KFe0P2k^k/20;no_`80^KVi00<0]KFe0;no_`2o_kl00P2i^KT20;Ng]`@0^KVi
102l_;`n0;Vi^AD0oooo000C0?oooc80^KVi0P2k^k/20;Fe]@80^KVi0P2k^k/20;Fe]@80_;bl0P3B
d]820<W9b@80MWIf0P1JFUX205=CD`80HF5Q0P1fMWH208N7Q`0309ZJVP1[Jf/0Jf][0080Lg=c0P1N
GUh206m_K`80HV9R0P1_Kfl207MgM`80IVIV0P1=CDd204M7A`80C4a<0P1;Bd/206IVIP80IfMW0P1n
OWh00`1UIFD0PX:208:2PP0209ZJVP80V9RH0P24Q8@209RHV080UiNG0P2CTi<207inOP80PH610P23
Ph<207AdM080LW9b0P1UIFD205ADE080CTi>00<0Bd];059BDP1BDU800P1GEeL205]KF`80J6QX0P1d
M7@206e]K@80HF5Q0P2o_kl20;Vi^@80/k>c0P2o_kl20;Vi^@@0]kNg1`2i^KT20;Fe]@80^KVi0P2e
]KD20;^k^`80_kno0P2i^KT20;Ng]cX0^KVi5@3oool001<0oooo<P2i^KT20;^k^`80]KFe0P2i^KT2
0;^k^`80]KFe0P2l_;`20=;BdP80bLW90P1fMWH205YJFP80De=C0P1QHF4207IfMP80QhN700<0VYZJ
06][J`1[Jf/00P1cLg<205iNGP80Kfm_0P1RHV8206m_K`80MgMg0P1VIVH204e=C@80AdM70P1<C4`2
04];B`80IVIV0P1WIfL207inOP0306EUI@22PX80PX:20080VYZJ0P2HV9P208B4Q080V9RH0P2GUiL2
09>CT`80OWin0P21PH4208>3P`80M7Ad0P1bLW8206EUI@80E5AD0P1>CTh00`1;Bd/0DU9B059BDP02
05MGE`80Fe]K0P1XJ6P207AdM080KFe]0P1QHF420;no_`80^KVi0P2c/k<20;no_`80^KVi102g]kL7
0;Vi^@80]KFe0P2i^KT20;Fe]@80^k^k0P2o_kl20;Vi^@80]kNg>P2i^KTE0?ooo`004`3ooolj0;Vi
^@80]KFe0P32`/820;Vi^@80_;bl0P3Shn<208>3P`80FUYJ0P1?Cdl2061PH080OGem00<0SXj>09^K
V`2KVi/00P1jNWX208B4Q080P8200P24Q8@207moO`80P8200P2FUYH209RHV080MGEe0P2GUiL207Yj
NP80OGem0P29RHT209FEU@0309:BTP1jNWX0NWYj00@0UYJF0P2DU9@209>CT`80QHF50P27QhL208B4
Q080KFe]0P1VIVH206UYJ@80GEeM0P1FEUH204m?C`<0GUiN0P1KFe/206=SH`80GUiN0P1dM7@208n?
S`80MGEe0P2i^KT20;bl_080^KVi0P2e]KD20;Vi^@80^k^k0P2g]kL20;>c/`<0^KVi0P2k^k/20;Fe
]@80]kNg102i^KT20;bl_080^KVi0P2k^k/20;>c/`@0^KVi0P2g]kL20;Vi^@80_;bl<02i^KTE0?oo
o`004`3ooolj0;Vi^@80]KFe0P32`/820;Vi^@80_;bl0P3Shn<208>3P`80FUYJ0P1?Cdl2061PH080
OGem00<0SXj>09^KV`2KVi/00P1jNWX208B4Q080P8200P24Q8@207moO`80P8200P2FUYH209RHV080
MGEe0P2GUiL207YjNP80OGem0P29RHT209FEU@0309:BTP1jNWX0NWYj00@0UYJF0P2DU9@209>CT`80
QHF50P27QhL208B4Q080KFe]0P1VIVH206UYJ@80GEeM0P1FEUH204m?C`<0GUiN0P1KFe/206=SH`80
GUiN0P1dM7@208n?S`80MGEe0P2i^KT20;bl_080^KVi0P2e]KD20;Vi^@80^k^k0P2g]kL20;>c/`<0
^KVi0P2k^k/20;Fe]@80]kNg102i^KT20;bl_080^KVi0P2k^k/20;>c/`@0^KVi0P2g]kL20;Vi^@80
_;bl<02i^KTE0?ooo`004`3ooolY0;Vi^@80_;bl3`2i^KT20;Fe]@80`/;2102i^KT20;Fe]@80l?3`
0P2OWil2061PH080F5QH0P1PH6000`1eMGD0UIFE09FEU@0208n?S`80SXj>0P2SXj<208V9R@@0XJ6Q
0P25QHD209fMW@80UIFE102WYjL20::RXP80Xj>S0P2ZZZX00`2GUiL0WinO09nOW`0209RHV080RXZ:
0P27QhL209BDU080RXZ:0P1^KVh2075aL@80IFEU0P1HF5P205IFEP80Hf=S0P1OGel206m_K`80HV9R
00<0KVi^06e]K@1]KFd00P1`L70207YjNP80HF5Q0P2o_kl20;Ng]`80]KFe0P2o_kl20;Fe]@H0^KVi
0P2k^k/20;Fe]@80^KVi00<0]kNg0;Vi^@2i^KT00P2k^k/20;Fe]@80^KVi0P2e]KD20;no_`80^KVi
0P2k^k/20;Fe]@80^KVi0P2k^k/40;Fe]@80_kno3`2i^KT20;bl_0@0^KVi0P2l_;`20;Vi^@80]kNg
5@2i^KTE0?ooo`004`3ooolY0;Vi^@80_;bl3`2i^KT20;Fe]@80`/;2102i^KT20;Fe]@80l?3`0P2O
Wil2061PH080F5QH0P1PH6000`1eMGD0UIFE09FEU@0208n?S`80SXj>0P2SXj<208V9R@@0XJ6Q0P25
QHD209fMW@80UIFE102WYjL20::RXP80Xj>S0P2ZZZX00`2GUiL0WinO09nOW`0209RHV080RXZ:0P27
QhL209BDU080RXZ:0P1^KVh2075aL@80IFEU0P1HF5P205IFEP80Hf=S0P1OGel206m_K`80HV9R00<0
KVi^06e]K@1]KFd00P1`L70207YjNP80HF5Q0P2o_kl20;Ng]`80]KFe0P2o_kl20;Fe]@H0^KVi0P2k
^k/20;Fe]@80^KVi00<0]kNg0;Vi^@2i^KT00P2k^k/20;Fe]@80^KVi0P2e]KD20;no_`80^KVi0P2k
^k/20;Fe]@80^KVi0P2k^k/40;Fe]@80_kno3`2i^KT20;bl_0@0^KVi0P2l_;`20;Vi^@80]kNg5@2i
^KTE0?ooo`004`3ooolW0;Vi^@80]KFe0P2o_kl=0;Vi^@80_;bl0P2e]KD20<;2`P80_;bl0P2i^KT2
0;bl_080^KVi0P33`l<20>CTi080MWIf0P1LG5`00`1YJFT0Lg=c07=cL`0208V9R@80Shn?0P2LW9`2
09ZJVP80WIfM0P2QXJ4209fMW@80ZJVY0P2NWYh20:BTY080YZJV0P2KVi/20::RXP80ZZZZ00<0Xj>S
09VIV@2IVIT00P2PX:0208n?S`80KFe]0P25QHD206m_K`80IVIV0P1]KFd405mOG`80Fe]K0P1VIVH2
079bLP80Kfm_0P1dM7@00`1kNg/0P8200820P00207moO`80Ph>30P2i^KT20;^k^`80/k>c0P2k^k/2
0;Fe]@80^KVi0P2l_;`20;Vi^@80_;bl1P2i^KT00`2e]KD0^KVi0;Vi^@0>0;Vi^@80_;bl3@2i^KT2
0;bl_0X0^KVi0P2o_kl20;Vi^@80]KFe0P2o_kl20;jn_P80]KFe5@2i^KTE0?ooo`004`3ooolW0;Vi
^@80]KFe0P2o_kl=0;Vi^@80_;bl0P2e]KD20<;2`P80_;bl0P2i^KT20;bl_080^KVi0P33`l<20>CT
i080MWIf0P1LG5`00`1YJFT0Lg=c07=cL`0208V9R@80Shn?0P2LW9`209ZJVP80WIfM0P2QXJ4209fM
W@80ZJVY0P2NWYh20:BTY080YZJV0P2KVi/20::RXP80ZZZZ00<0Xj>S09VIV@2IVIT00P2PX:0208n?
S`80KFe]0P25QHD206m_K`80IVIV0P1]KFd405mOG`80Fe]K0P1VIVH2079bLP80Kfm_0P1dM7@00`1k
Ng/0P8200820P00207moO`80Ph>30P2i^KT20;^k^`80/k>c0P2k^k/20;Fe]@80^KVi0P2l_;`20;Vi
^@80_;bl1P2i^KT00`2e]KD0^KVi0;Vi^@0>0;Vi^@80_;bl3@2i^KT20;bl_0X0^KVi0P2o_kl20;Vi
^@80]KFe0P2o_kl20;jn_P80]KFe5@2i^KTE0?ooo`004`3ooolf0;Vi^@80]KFe0P2o_kl20;Fe]@80
^k^k0P2o_kl20;Fe]@80_kno0P2i^KT20;>c/`80aLG50P3Ph>0209RHV00308N7Q`1QHF40HF5Q0080
Kfm_0P1jNWX208n?S`80UYJF0P2MWId20:>SX`80XZ:R0P2OWil209VIV@80ZJVY0P2RXZ8209bLW080
TY:B0P2?Shl00`23Ph<0R8R808R8R00208J6QP80T92@0P1hN7P205]KF`80K6a/0P1ZJVX2071`L080
IfMW0P2:RXX206YZJP80Ng]k0P1hN7P207YjNP80RHV900<0SXj>08J6QP26QXH00P2XZ:P40;Vi^@80
^k^k0P2e]KD20;bl_080^KVi0P2e]KD20;no_`80]KFe0P2m_Kd20;Vi^@80^k^k0`2i^KT20;bl_0H0
^KVi0P2g]kL20;Vi^@80_;bl0P2e]KD20;no_`H0^KVi0P2l_;`40;Vi^@030;Fe]@2o_kl0_kno00H0
^KVi0P2e]KD20;no_`@0^KVi0P2l_;`20;Vi^@80`/;20P2g]kL;0;Vi^@80_;bl202i^KTE0?ooo`00
4`3ooolf0;Vi^@80]KFe0P2o_kl20;Fe]@80^k^k0P2o_kl20;Fe]@80_kno0P2i^KT20;>c/`80aLG5
0P3Ph>0209RHV00308N7Q`1QHF40HF5Q0080Kfm_0P1jNWX208n?S`80UYJF0P2MWId20:>SX`80XZ:R
0P2OWil209VIV@80ZJVY0P2RXZ8209bLW080TY:B0P2?Shl00`23Ph<0R8R808R8R00208J6QP80T92@
0P1hN7P205]KF`80K6a/0P1ZJVX2071`L080IfMW0P2:RXX206YZJP80Ng]k0P1hN7P207YjNP80RHV9
00<0SXj>08J6QP26QXH00P2XZ:P40;Vi^@80^k^k0P2e]KD20;bl_080^KVi0P2e]KD20;no_`80]KFe
0P2m_Kd20;Vi^@80^k^k0`2i^KT20;bl_0H0^KVi0P2g]kL20;Vi^@80_;bl0P2e]KD20;no_`H0^KVi
0P2l_;`40;Vi^@030;Fe]@2o_kl0_kno00H0^KVi0P2e]KD20;no_`@0^KVi0P2l_;`20;Vi^@80`/;2
0P2g]kL;0;Vi^@80_;bl202i^KTE0?ooo`004`3ooolW0;Vi^@80_;bl6@2i^KT20;Ng]`80_[jn102e
]KD20<;2`P80^KVi00<0gmoO0:RXZ02XZ:P00P2ATI420820P080NGUi0P22PX8209>CT`80UYJF0P2L
W9`20:FUY@80Vi^K0P2WYjL20:>SX`80Y:BT0P2PX:0209>CT`0308V9R@1hN7P0N7Qh0080Ng]k0P26
QXH208j>SP80SHf=0P1/K6`207YjNP80Ti>C0P1gMgL207]kN`80OWin0P2DU9@20:^[Z`80SXj>0P2:
RXX70;Vi^@80_;bl0P2i^KT20;Fe]@80_kno102i^KT20;bl_080^k^k0P2e]KD20;Vi^@80]KFe0P2o
_kl00`2e]KD0_Kfm0;fm_@040;Vi^@80^k^k102e]KD20;no_`80^KVi0P2l_;`20;Vi^@80_;bl0P2i
^KT20<;2`P@0_;bl2@2i^KT20;bl_0@0^KVi0P2e]KD40;no_`80`L712`2i^KT20;Fe]@80_kno202i
^KTE0?ooo`004`3ooolW0;Vi^@80_;bl6@2i^KT20;Ng]`80_[jn102e]KD20<;2`P80^KVi00<0gmoO
0:RXZ02XZ:P00P2ATI420820P080NGUi0P22PX8209>CT`80UYJF0P2LW9`20:FUY@80Vi^K0P2WYjL2
0:>SX`80Y:BT0P2PX:0209>CT`0308V9R@1hN7P0N7Qh0080Ng]k0P26QXH208j>SP80SHf=0P1/K6`2
07YjNP80Ti>C0P1gMgL207]kN`80OWin0P2DU9@20:^[Z`80SXj>0P2:RXX70;Vi^@80_;bl0P2i^KT2
0;Fe]@80_kno102i^KT20;bl_080^k^k0P2e]KD20;Vi^@80]KFe0P2o_kl00`2e]KD0_Kfm0;fm_@04
0;Vi^@80^k^k102e]KD20;no_`80^KVi0P2l_;`20;Vi^@80_;bl0P2i^KT20<;2`P@0_;bl2@2i^KT2
0;bl_0@0^KVi0P2e]KD40;no_`80`L712`2i^KT20;Fe]@80_kno202i^KTE0?ooo`004`3ooolU0;Vi
^@80/k>c0P2o_klG0;Vi^@80^k^k0P2b/[820;no_`80^KVi0P2e]KD20;no_`<0^KVi0P2l_;`20;Vi
^@80gmoO0P2SXj<208f=S@80Q8B41026QXH2096AT@80VYZJ0P2OWil20:6QX@80YZJV0P2][Jd20:>S
X`030:n_[`2MWId0WIfM0080Vi^K0P24Q8@209:BTP80[Jf]1021PH4208b<S080W9bL0P2DU9@208F5
Q@80V9RH0P2[Zj/40;no_`030;fm_@2i^KT0^KVi0080^KVi0P2e]KD20;no_`H0^KVi0P2g]kL20;Fe
]@80_kno0P2g]kL60;Vi^@80]kNg00<0^k^k0;Fe]@2e]KD02P2i^KT20;Ng]`80]KFe0P2o_kl20;Fe
]@P0^k^k0P2m_Kd00`2i^KT0_;bl0;bl_0020;Ng]`80^KVi0P2e]KD20;no_`@0^KVi0P2c/k<20;^k
^`80_kno0P2e]KD20;no_`80]kNg4`2i^KTE0?ooo`004`3ooolU0;Vi^@80/k>c0P2o_klG0;Vi^@80
^k^k0P2b/[820;no_`80^KVi0P2e]KD20;no_`<0^KVi0P2l_;`20;Vi^@80gmoO0P2SXj<208f=S@80
Q8B41026QXH2096AT@80VYZJ0P2OWil20:6QX@80YZJV0P2][Jd20:>SX`030:n_[`2MWId0WIfM0080
Vi^K0P24Q8@209:BTP80[Jf]1021PH4208b<S080W9bL0P2DU9@208F5Q@80V9RH0P2[Zj/40;no_`03
0;fm_@2i^KT0^KVi0080^KVi0P2e]KD20;no_`H0^KVi0P2g]kL20;Fe]@80_kno0P2g]kL60;Vi^@80
]kNg00<0^k^k0;Fe]@2e]KD02P2i^KT20;Ng]`80]KFe0P2o_kl20;Fe]@P0^k^k0P2m_Kd00`2i^KT0
_;bl0;bl_0020;Ng]`80^KVi0P2e]KD20;no_`@0^KVi0P2c/k<20;^k^`80_kno0P2e]KD20;no_`80
]kNg4`2i^KTE0?ooo`004`3ooolS0;Vi^@80^k^k0P2e]KD20;bl_240^KVi0P2g]kL20;Vi^@030;Fe
]@32`/80`/;20080/k>c0P2m_Kd20;Vi^@80e]KF0P2VYZH209FEU@80/;2`0P2HV9P209fMW@80YjNW
0P2NWYh20;2`/080Xj>S0P2MWId00`2PX:00Xj>S0:>SX`020::RXP80VIVI0P2PX:0209bLW080[:b/
0P2QXJ4209>CT`80W9bL0P2RXZ820:n_[`80^KVi0P2e]KD20;no_`80a<C400<0]KFe0;bl_02l_;`0
102l_;`60;Vi^@80^k^k0P2e]KD20;Ng]`80^KVi0P2e]KD40;Vi^@80^k^k0P2e]KD00`2i^KT0]kNg
0;Ng]`020;Vi^@80_;bl0P2g]kL20;Vi^@80^k^k0P2e]KD20;bl_0X0^KVi0P2k^k/30;Fe]@80`L71
102i^KT20;bl_0@0^KVi0P2k^k/20;Fe]@H0^KVi0P2k^k/?0;Vi^@80_;bl102i^KTE0?ooo`004`3o
oolS0;Vi^@80^k^k0P2e]KD20;bl_240^KVi0P2g]kL20;Vi^@030;Fe]@32`/80`/;20080/k>c0P2m
_Kd20;Vi^@80e]KF0P2VYZH209FEU@80/;2`0P2HV9P209fMW@80YjNW0P2NWYh20;2`/080Xj>S0P2M
WId00`2PX:00Xj>S0:>SX`020::RXP80VIVI0P2PX:0209bLW080[:b/0P2QXJ4209>CT`80W9bL0P2R
XZ820:n_[`80^KVi0P2e]KD20;no_`80a<C400<0]KFe0;bl_02l_;`0102l_;`60;Vi^@80^k^k0P2e
]KD20;Ng]`80^KVi0P2e]KD40;Vi^@80^k^k0P2e]KD00`2i^KT0]kNg0;Ng]`020;Vi^@80_;bl0P2g
]kL20;Vi^@80^k^k0P2e]KD20;bl_0X0^KVi0P2k^k/30;Fe]@80`L71102i^KT20;bl_0@0^KVi0P2k
^k/20;Fe]@H0^KVi0P2k^k/?0;Vi^@80_;bl102i^KTE0?ooo`004`3ooolU0;Vi^@80]KFe0P2o_kl2
0;Ng]aD0^KVi0P2l_;`20;Ng]`@0^KVi0P2k^k/20;Fe]@80]kNg00<0]KFe0<71`@31`L400P2g]kL2
0;Fe]@@0^KVi0P2k^k/40;Ng]`80_kno0P2e]KD20;Rh^080Zj^[0P2j^[X20;jn_P80/K6a00<0YjNW
0:6QX@2QXJ400P2ZZZX20;>c/`80[:b/0P2YZJT20:BTY080/K6a0P2e]KD20;Vi^@@0_;bl0P2i^KT2
0;Fe]@80^k^k0P32`/800`2e]KD0^k^k0;^k^`020;^k^`80_kno0P2g]kL20;Vi^@80_;bl0P2i^KT4
0;^k^`80]KFe102i^KT20;bl_080^KVi0P2l_;`00`2k^k/0^KVi0;Vi^@020;Fe]@80_kno0P2e]KD2
0;Vi^@80]kNg0P2e]KD20;no_`l0^KVi0P2e]KD20;fm_@80]KFe0P2o_kl20;bl_0P0^KVi0P2l_;`2
0;Vi^@80]KFe0P2o_kl;0;Vi^@80]KFe0P2o_kl40;Vi^AD0oooo000C0?ooobD0^KVi0P2e]KD20;no
_`80]kNg5@2i^KT20;bl_080]kNg102i^KT20;^k^`80]KFe0P2g]kL00`2e]KD0`L710<71`@020;Ng
]`80]KFe102i^KT20;^k^`@0]kNg0P2o_kl20;Fe]@80^;Rh0P2[Zj/20;Zj^P80_[jn0P2a/K400`2W
YjL0XJ6Q0:6QX@020:ZZZP80/k>c0P2/[:`20:VYZ@80Y:BT0P2a/K420;Fe]@80^KVi102l_;`20;Vi
^@80]KFe0P2k^k/20<;2`P030;Fe]@2k^k/0^k^k0080^k^k0P2o_kl20;Ng]`80^KVi0P2l_;`20;Vi
^@@0^k^k0P2e]KD40;Vi^@80_;bl0P2i^KT20;bl_0030;^k^`2i^KT0^KVi0080]KFe0P2o_kl20;Fe
]@80^KVi0P2g]kL20;Fe]@80_kno3`2i^KT20;Fe]@80_Kfm0P2e]KD20;no_`80_;bl202i^KT20;bl
_080^KVi0P2e]KD20;no_`/0^KVi0P2e]KD20;no_`@0^KVi5@3oool001<0oooo9`2i^KT20;^k^`80
]KFe4`2i^KT20;Fe]@80`L710P2e]KD80;Vi^@80]KFe00<0^KVi0;Ng]`2g]kL00P2l_;`60;Vi^@80
]kNg0P2i^KT20;>c/`80_kno0P2i^KT20;bl_080]kNg0P2i^KT20;^k^`D0]kNg0P2b/[820<;2`P@0
^KVi0P2g]kL40;Vi^@80]KFe0P2k^k/20;no_`80^KVi0P2l_;`20;Fe]@80`/;22@2i^KT20;Fe]@80
`/;20P2l_;`20;Fe]@80_kno102i^KT20;Fe]@80_kno0P2e]KD20;no_`030;Fe]@32`/80`/;20080
^KVi0P2c/k<40;Vi^@80]KFe3P2i^KT20;bl_0<0^KVi0P2k^k/20;Fe]@80^KVi0P2e]KD20<;2`PH0
^KVi0P2c/k<20;no_`@0_;bl3`2i^KT20;bl_080^KVi0P2g]kLE0?ooo`004`3ooolW0;Vi^@80^k^k
0P2e]KDC0;Vi^@80]KFe0P31`L420;Fe]@P0^KVi0P2e]KD00`2i^KT0]kNg0;Ng]`020;bl_0H0^KVi
0P2g]kL20;Vi^@80/k>c0P2o_kl20;Vi^@80_;bl0P2g]kL20;Vi^@80^k^k1@2g]kL20;:b/P80`/;2
102i^KT20;Ng]`@0^KVi0P2e]KD20;^k^`80_kno0P2i^KT20;bl_080]KFe0P32`/890;Vi^@80]KFe
0P32`/820;bl_080]KFe0P2o_kl40;Vi^@80]KFe0P2o_kl20;Fe]@80_kno00<0]KFe0<;2`P32`/80
0P2i^KT20;>c/`@0^KVi0P2e]KD>0;Vi^@80_;bl0`2i^KT20;^k^`80]KFe0P2i^KT20;Fe]@80`/;2
1P2i^KT20;>c/`80_kno102l_;`?0;Vi^@80_;bl0P2i^KT20;Ng]aD0oooo000C0?ooob/0^KVi0P2l
_;`K0;Vi^@80^k^k0P2e]KD20;Vi^@030;jn_P2e]KD0]KFe0080_kno1P2i^KT20;Fe]@80^k^k102i
^KT20;Fe]@80`L711P2i^KT20;bl_0<0^KVi0P2e]KD20;fm_@80^KVi0P2k^k/20;Fe]@H0^KVi0P2g
]kL40;Vi^@80_kno0P2e]KD20<;2`P030;bl_02i^KT0^KVi0080^k^k0P2b/[820;fm_@80]KFe0P2k
^k/20;fm_@80^KVi0P2l_;`80;Vi^@80_;bl0P2i^KT00`2e]KD0`L710<71`@020;Ng]`80]KFe0P2k
^k/20;Fe]@@0^KVi0P2l_;`20;Ng]`H0^KVi0P2e]KD20<;2`P<0^KVi0P2l_;`40;Vi^@80/k>c0P2o
_kl40;Vi^@80^k^k102e]KD20;Vi^@80`/;23@2i^KT20;Fe]@80_kno0P2k^k/20;Vi^AD0oooo000C
0?ooob/0^KVi0P2l_;`K0;Vi^@80^k^k0P2e]KD20;Vi^@030;jn_P2e]KD0]KFe0080_kno1P2i^KT2
0;Fe]@80^k^k102i^KT20;Fe]@80`L711P2i^KT20;bl_0<0^KVi0P2e]KD20;fm_@80^KVi0P2k^k/2
0;Fe]@H0^KVi0P2g]kL40;Vi^@80_kno0P2e]KD20<;2`P030;bl_02i^KT0^KVi0080^k^k0P2b/[82
0;fm_@80]KFe0P2k^k/20;fm_@80^KVi0P2l_;`80;Vi^@80_;bl0P2i^KT00`2e]KD0`L710<71`@02
0;Ng]`80]KFe0P2k^k/20;Fe]@@0^KVi0P2l_;`20;Ng]`H0^KVi0P2e]KD20<;2`P<0^KVi0P2l_;`4
0;Vi^@80/k>c0P2o_kl40;Vi^@80^k^k102e]KD20;Vi^@80`/;23@2i^KT20;Fe]@80_kno0P2k^k/2
0;Vi^AD0oooo000C0?ooob<0^KVi0P2l_;`40;Vi^@80/k>c0P2o_kl20;Vi^@030;Ng]`2i^KT0^KVi
01@0^KVi0P2g]kL20;bl_080^KVi0P2e]KD00`2k^k/0_Kfm0;fm_@040;Vi^@80^k^k0P2e]KD20;Ng
]`80^KVi0P2m_Kd40;Vi^@80]KFe0P32`/820;Vi^@80]KFe0P2o_kl00`2l_;`0^KVi0;Vi^@020;Vi
^@80]KFe0P2i^KT20;Ng]`H0^KVi0P2k^k/40;Fe]@80_kno0P2i^KT20;Fe]@80^k^k00<0`/;20;Vi
^@2i^KT0102i^KT20;Fe]@80_;bl0P2k^k/40;Fe]@80_Kfm102l_;`20;Vi^@80]KFe0P2m_Kd20;bl
_0L0^KVi0P2l_;`40;Vi^@80]KFe0P34a<@20;Fe]@@0^KVi0P2l_;`20;Fe]@80_kno0P2l_;`00`2e
]KD0_kno0;no_`020;bl_080_[jn0P2e]KD20;Vi^@80_;bl202i^KT20;:b/P80_kno2`2i^KT20;bl
_0@0^KVi0P2e]KD20;no_aD0oooo000C0?ooob40^KVi0P2e]KD20;no_`80^KVi0P2k^k/20;Fe]@80
^KVi0P2n_[h00`2e]KD0^KVi0;Vi^@0B0;Vi^@80^k^k0P2b/[820;no_`@0^KVi00<0^k^k0;Fe]@2e
]KD01P2i^KT20;^k^`80/;2`0P31`L420;Fe]@80^KVi0P2l_;`20;>c/`80_kno0P2l_;`20;Vi^@80
]KFe00<0_kno0;^k^`2k^k/0102i^KT20;jn_P80]KFe2P2i^KT20;Ng]`80^KVi0P2l_;`20;Vi^@80
]KFe00<0_kno0;Vi^@2i^KT00P2k^k/40;Fe]@80_kno102i^KT20;^k^`80/[:b0P2k^k/20;fm_@80
^KVi0P2k^k/20;:b/P80_kno0`2i^KT20;Ng]`80^KVi0P2m_Kd20;bl_080^KVi0P2e]KD20<;2`P@0
^KVi0P2c/k<20;no_`80^KVi0P2e]KD20;no_`030;Vi^@2e]KD0]KFe0080^k^k0P2o_kl20;Vi^@80
]KFe0P2o_kl20;Vi^@80]kNg0P2k^k/20;Fe]@d0^KVi0P2c/k<20<;2`PP0^KVi5@3oool001<0oooo
8@2i^KT20;Fe]@80_kno0P2i^KT20;^k^`80]KFe0P2i^KT20;jn_P030;Fe]@2i^KT0^KVi0180^KVi
0P2k^k/20;:b/P80_kno102i^KT00`2k^k/0]KFe0;Fe]@060;Vi^@80^k^k0P2`/;020<71`@80]KFe
0P2i^KT20;bl_080/k>c0P2o_kl20;bl_080^KVi0P2e]KD00`2o_kl0^k^k0;^k^`040;Vi^@80_[jn
0P2e]KD:0;Vi^@80]kNg0P2i^KT20;bl_080^KVi0P2e]KD00`2o_kl0^KVi0;Vi^@020;^k^`@0]KFe
0P2o_kl40;Vi^@80^k^k0P2b/[820;^k^`80_Kfm0P2i^KT20;^k^`80/[:b0P2o_kl30;Vi^@80]kNg
0P2i^KT20;fm_@80_;bl0P2i^KT20;Fe]@80`/;2102i^KT20;>c/`80_kno0P2i^KT20;Fe]@80_kno
00<0^KVi0;Fe]@2e]KD00P2k^k/20;no_`80^KVi0P2e]KD20;no_`80^KVi0P2g]kL20;^k^`80]KFe
3@2i^KT20;>c/`80`/;2202i^KTE0?ooo`004`3ooolY0;Vi^@80_;bl0P2e]KD20;no_aD0^KVi0P2g
]kLA0;Vi^@80^k^k0P2c/k<20;Ng]`80^KVi0P2e]KD20<71`@80]KFe0P2c/k<20<;2`P80_;bl1@2i
^KT20;fm_@80]KFe0P2o_kl60;Vi^@80_;bl102i^KT20;>c/`80]KFe0P2o_kl20;bl_080]kNg00<0
^KVi0;bl_02l_;`00P2i^KT20;bl_0@0^KVi0P2l_;`20;Vi^@80_;bl0P2i^KT20;^k^`80]KFe102i
^KT20;bl_0<0^KVi0P2k^k/20;:b/P80`<300P2`/;020;no_`80_;bl0P2e]KD20;no_`80^KVi0P2n
_[h20;Fe]@@0^KVi0P2l_;`20;Vi^@030;bl_02i^KT0^KVi0080^KVi0P2l_;`20;Ng]`@0^KVi0P2k
^k/20;Fe]@80^KVi0P2l_;`40;Vi^@80_;bl1@2i^KT20;^k^`80/[:b0P2o_kl60;Vi^@80]kNg5@3o
ool001<0oooo:@2i^KT20;bl_080]KFe0P2o_klE0;Vi^@80]kNg4@2i^KT20;^k^`80/k>c0P2g]kL2
0;Vi^@80]KFe0P31`L420;Fe]@80/k>c0P32`/820;bl_0D0^KVi0P2m_Kd20;Fe]@80_kno1P2i^KT2
0;bl_0@0^KVi0P2c/k<20;Fe]@80_kno0P2l_;`20;Ng]`030;Vi^@2l_;`0_;bl0080^KVi0P2l_;`4
0;Vi^@80_;bl0P2i^KT20;bl_080^KVi0P2k^k/20;Fe]@@0^KVi0P2l_;`30;Vi^@80^k^k0P2b/[82
0<30`080/;2`0P2o_kl20;bl_080]KFe0P2o_kl20;Vi^@80_[jn0P2e]KD40;Vi^@80_;bl0P2i^KT0
0`2l_;`0^KVi0;Vi^@020;Vi^@80_;bl0P2g]kL40;Vi^@80^k^k0P2e]KD20;Vi^@80_;bl102i^KT2
0;bl_0D0^KVi0P2k^k/20;:b/P80_kno1P2i^KT20;Ng]aD0oooo000C0?ooobL0^KVi0P2e]KD20;no
_`80^KVi0P2l_;`C0;Vi^@80^k^k0P2e]KD20;bl_0@0^KVi0P2g]kL00`2i^KT0]kNg0;Ng]`060;Vi
^@80^k^k0P2g]kL20;Fe]@80_;bl102i^KT20;^k^`80/[:b0P2k^k/20;no_`80^KVi00<0/k>c0<C4
a034a<@00P2e]KD80;Vi^@80]KFe0P2o_kl20;^k^`80]kNg0P2e]KD20;Vi^@80/k>c0P31`L420;Vi
^@030;Fe]@32`/80`/;20080]KFe0P2o_kl20;Vi^@80/k>c0P32`/820;>c/`80`/;21P2i^KT20;Ng
]`80]KFe0P2o_kl70;Vi^@80^k^k0P2e]KD20;Vi^@80_Kfm0P2g]kL20;Vi^@80]KFe0P2o_kl20;Ng
]`80^KVi0P2e]KD20;no_`80]KFe00<0`/;20;Vi^@2i^KT00P2e]KD20<71`@80]KFe1P2i^KT20;bl
_080]KFe0P2o_kl20;Vi^@80]KFe0P2o_kl=0;Vi^@80]kNg102k^k/E0?ooo`004`3ooolW0;Vi^@80
]KFe0P2o_kl20;Vi^@80_;bl4`2i^KT20;^k^`80]KFe0P2l_;`40;Vi^@80]kNg00<0^KVi0;Ng]`2g
]kL01P2i^KT20;^k^`80]kNg0P2e]KD20;bl_0@0^KVi0P2k^k/20;:b/P80^k^k0P2o_kl20;Vi^@03
0;>c/`34a<@0a<C40080]KFe202i^KT20;Fe]@80_kno0P2k^k/20;Ng]`80]KFe0P2i^KT20;>c/`80
`L710P2i^KT00`2e]KD0`/;20<;2`P020;Fe]@80_kno0P2i^KT20;>c/`80`/;20P2c/k<20<;2`PH0
^KVi0P2g]kL20;Fe]@80_kno1`2i^KT20;^k^`80]KFe0P2i^KT20;fm_@80]kNg0P2i^KT20;Fe]@80
_kno0P2g]kL20;Vi^@80]KFe0P2o_kl20;Fe]@030<;2`P2i^KT0^KVi0080]KFe0P31`L420;Fe]@H0
^KVi0P2l_;`20;Fe]@80_kno0P2i^KT20;Fe]@80_kno3@2i^KT20;Ng]`@0^k^k5@3oool001<0oooo
:`2i^KT20;Fe]@80_kno00<0]kNg0;Vi^@2i^KT03P2i^KT20;Ng]`80_;bl0P2e]KD20;no_`80]kNg
0P2k^k/20;Fe]@030;Vi^@2c/k<0/k>c00H0^KVi102l_;`20;Fe]@80_kno0P2i^KT20;Ng]`X0^KVi
00<0/[:b0;no_`2o_kl00P2l_;`20;Vi^@80]kNg0P2l_;`:0;Vi^@80_;bl0P2k^k/20;Vi^@80]KFe
0P2m_Kd00`2i^KT0_kno0;no_`020;Ng]`@0^KVi0P2b/[820<71`@80]KFe0P2o_kl20;Vi^@80]kNg
0P2k^k/20;Fe]@80_;bl0P2g]kL20;bl_0030;Vi^@2g]kL0]kNg0080^KVi0P2g]kL20;Vi^@80`L71
0P2k^k/20;Fe]@H0^KVi0P2e]KD60;Vi^@80]KFe00<0_kno0;Vi^@2i^KT02P2i^KT20;Fe]@80_kno
0P2i^KT20;Ng]a40^KVi0P2k^k/40;Fe]@80_kno5@3oool001<0oooo:`2i^KT20;Fe]@80_kno00<0
]kNg0;Vi^@2i^KT03P2i^KT20;Ng]`80_;bl0P2e]KD20;no_`80]kNg0P2k^k/20;Fe]@030;Vi^@2c
/k<0/k>c00H0^KVi102l_;`20;Fe]@80_kno0P2i^KT20;Ng]`X0^KVi00<0/[:b0;no_`2o_kl00P2l
_;`20;Vi^@80]kNg0P2l_;`:0;Vi^@80_;bl0P2k^k/20;Vi^@80]KFe0P2m_Kd00`2i^KT0_kno0;no
_`020;Ng]`@0^KVi0P2b/[820<71`@80]KFe0P2o_kl20;Vi^@80]kNg0P2k^k/20;Fe]@80_;bl0P2g
]kL20;bl_0030;Vi^@2g]kL0]kNg0080^KVi0P2g]kL20;Vi^@80`L710P2k^k/20;Fe]@H0^KVi0P2e
]KD60;Vi^@80]KFe00<0_kno0;Vi^@2i^KT02P2i^KT20;Fe]@80_kno0P2i^KT20;Ng]a40^KVi0P2k
^k/40;Fe]@80_kno5@3oool001<0oooo;@2i^KT20;^k^`030;Fe]@2i^KT0^KVi00`0^KVi0P2k^k/2
0;:b/P80_kno0P2i^KT20;^k^`@0^KVi0P2n_[h00`2g]kL0/k>c0;>c/`040;bl_080]KFe0P2i^KT2
0<;2`P@0^KVi0P2k^k/20;Fe]@H0^KVi0P2k^k/20;Vi^@030;bl_02e]KD0]KFe0080_kno0P2k^k/2
0;:b/P80`/;2202i^KT20;Fe]@80_kno0P2i^KT20;no_`80^k^k0P2b/[800`2o_kl0^k^k0;^k^`02
0;Vi^@80_[jn0P2i^KT20;bl_080]KFe0P2o_kl20;Vi^@80^k^k0P2c/k<40;Vi^@80`L710P2b/[82
0;no_`030;jn_P2i^KT0^KVi0080_[jn0P2e]KD20;no_`80]KFe0P2o_kl40;Vi^@80^k^k0P2i^KT2
0;bl_0P0^KVi00<0]kNg0;Vi^@2i^KT02P2i^KT20;bl_080^KVi0P2k^k/20;Fe]@80^KVi0P2l_;`7
0;Vi^@80_;bl0P2i^KT20;bl_0@0^KVi0P2l_;`20;Vi^AD0oooo000C0?ooobd0^KVi0P2k^k/00`2e
]KD0^KVi0;Vi^@0<0;Vi^@80^k^k0P2b/[820;no_`80^KVi0P2k^k/40;Vi^@80_[jn00<0]kNg0;>c
/`2c/k<0102l_;`20;Fe]@80^KVi0P32`/840;Vi^@80^k^k0P2e]KD60;Vi^@80^k^k0P2i^KT00`2l
_;`0]KFe0;Fe]@020;no_`80^k^k0P2b/[820<;2`PP0^KVi0P2e]KD20;no_`80^KVi0P2o_kl20;^k
^`80/[:b00<0_kno0;^k^`2k^k/00P2i^KT20;jn_P80^KVi0P2l_;`20;Fe]@80_kno0P2i^KT20;^k
^`80/k>c102i^KT20<71`@80/[:b0P2o_kl00`2n_[h0^KVi0;Vi^@020;jn_P80]KFe0P2o_kl20;Fe
]@80_kno102i^KT20;^k^`80^KVi0P2l_;`80;Vi^@030;Ng]`2i^KT0^KVi00X0^KVi0P2l_;`20;Vi
^@80^k^k0P2e]KD20;Vi^@80_;bl1`2i^KT20;bl_080^KVi0P2l_;`40;Vi^@80_;bl0P2i^KTE0?oo
o`004`3ooolU0;Vi^@80_;bl0P2i^KT20;bl_0@0^KVi00<0]kNg0;Vi^@2i^KT00P2g]kL:0;Vi^@80
_;bl1P2i^KT20;Fe]@80_kno0P2e]KD20;fm_@030;^k^`2`/;00/;2`0080^k^k0P2m_Kd20;^k^`80
/[:b0P2o_kl80;Vi^@80]kNg102i^KT20;Fe]@80^k^k00<0_kno0;Vi^@2i^KT00P2l_;`20;Vi^@80
]KFe0P2o_kl20;Vi^@80_;bl0P2g]kL20;Vi^@80_;bl0P2i^KT20;no_`L0^KVi0P2e]KD60;^k^`80
_kno0P2i^KT20;bl_080^KVi0P2k^k/40;Fe]@80_kno0P2g]kL20;Vi^@80]KFe1@2k^k/20;no_`80
_;bl0P2i^KT20;bl_0@0^KVi0P2c/k<20;^k^`80`/;21P2i^KT20;jn_P030;Fe]@2i^KT0^KVi00P0
^KVi0P2e]KD20;no_`80]kNg0P2i^KT20;Ng]`80]KFe0P2o_kl60;Vi^@030;Fe]@2o_kl0_kno0080
]KFe0P2o_kl20;Vi^@80]KFe0P2o_kl20;Vi^AD0oooo000C0?ooobD0^KVi0P2l_;`20;Vi^@80_;bl
102i^KT00`2g]kL0^KVi0;Vi^@020;Ng]`X0^KVi0P2l_;`60;Vi^@80]KFe0P2o_kl20;Fe]@80_Kfm
00<0^k^k0;2`/02`/;000P2k^k/20;fm_@80^k^k0P2b/[820;no_`P0^KVi0P2g]kL40;Vi^@80]KFe
0P2k^k/00`2o_kl0^KVi0;Vi^@020;bl_080^KVi0P2e]KD20;no_`80^KVi0P2l_;`20;Ng]`80^KVi
0P2l_;`20;Vi^@80_kno1`2i^KT20;Fe]@H0^k^k0P2o_kl20;Vi^@80_;bl0P2i^KT20;^k^`@0]KFe
0P2o_kl20;Ng]`80^KVi0P2e]KD50;^k^`80_kno0P2l_;`20;Vi^@80_;bl102i^KT20;>c/`80^k^k
0P32`/860;Vi^@80_[jn00<0]KFe0;Vi^@2i^KT0202i^KT20;Fe]@80_kno0P2g]kL20;Vi^@80]kNg
0P2e]KD20;no_`H0^KVi00<0]KFe0;no_`2o_kl00P2e]KD20;no_`80^KVi0P2e]KD20;no_`80^KVi
5@3oool001<0oooo8`2i^KT20;Fe]@80`/;20P2e]KD20;no_`80_;bl0P2k^k/00`2e]KD0^k^k0;^k
^`020;Fe]@P0^KVi0P2e]KD20;no_`P0^KVi0P2g]kL20;^k^`80]KFe00<0^k^k0;Fe]@2e]KD00P2k
^k/20;Fe]@80_;bl0P2i^KT20;bl_0H0^KVi0P2k^k/20;Fe]@/0^KVi0P32`/860;Vi^@80/k>c0P31
`L420;Fe]@80^KVi102o_klE0;Vi^@80`/;20P2l_;`60;Vi^@80^k^k0P2e]KD90;Vi^@80]KFe0P32
`/820;Vi^@80`/;20P2i^KT20;^k^`@0]KFe0P2o_kl40;Vi^@80]KFe0P2o_kl;0;Vi^@80_;bl0P2k
^k/20;>c/`80^k^k0P2c/k<40;Vi^@80_;bl102i^KT00`2l_;`0]kNg0;Ng]`0<0;Vi^AD0oooo000C
0?ooob<0^KVi0P2e]KD20<;2`P80]KFe0P2o_kl20;bl_080^k^k00<0]KFe0;^k^`2k^k/00P2e]KD8
0;Vi^@80]KFe0P2o_kl80;Vi^@80]kNg0P2k^k/20;Fe]@030;^k^`2e]KD0]KFe0080^k^k0P2e]KD2
0;bl_080^KVi0P2l_;`60;Vi^@80^k^k0P2e]KD;0;Vi^@80`/;21P2i^KT20;>c/`80`L710P2e]KD2
0;Vi^@@0_kno5@2i^KT20<;2`P80_;bl1P2i^KT20;^k^`80]KFe2@2i^KT20;Fe]@80`/;20P2i^KT2
0<;2`P80^KVi0P2k^k/40;Fe]@80_kno102i^KT20;Fe]@80_kno2`2i^KT20;bl_080^k^k0P2c/k<2
0;^k^`80/k>c102i^KT20;bl_0@0^KVi00<0_;bl0;Ng]`2g]kL0302i^KTE0?ooo`00o`3ooolQ0?oo
o`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?oo
o`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00V03oool2@000
08H0oooo002J0?ooo`03@000003oool0oooo08<0oooo001k0?ooo`=000000`3oool3@0000080oooo
00=000000?ooo`3oool01@3oool3@0000080oooo0T0000030?ooo`=000001@3oool00d000000oooo
0?ooo`1m0?ooo`00N`3oool00d000000oooo0?ooo`040?ooo`06@000003oool0oooo@000003ooom0
00001@3oool01T000000oooo0?oood000000oooo@00000@0oooo00A000000?ooo`3ooom00000Q@3o
ool007`0oooo00A000000?ooo`3oool0oooo14000000103ooom000000?oood0000050?ooo`05@000
003oool0oooo@000003oool00d0000020?ooo`04@000003oool0oooo@00008D0oooo001l0?ooo`07
@000003oool0oooo0?oood000000oooo@00000020?ooo`03@000003ooom0000000H0oooo0d000000
103ooom00000@000040000030?ooo`=00000Q@3oool007/0oooo00=000000?oood0000000`3oool2
@0000080oooo00=000000?oood000000203oool00d000000oooo0?ooo`2=0?ooo`00O03oool00d00
0000oooo0?ooo`030?ooo`05@000003oool0oooo0?oood000000203oool2@00008l0oooo003o0?oo
ob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?oo
ob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.0250052, -0.0250052, 
  0.00365857, 0.00365857}, {{6.8125, 280.125}, {280.125, 
  6.8125}} -> {-10.161, -6.11446, 0.516914, 0.516914}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0238095 0.952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0238095 0.97619 0.97619 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00751202 0.0192308 0.00751202 [
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(300) show
81.000000 12.812500 moveto
(deg) show
99.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(.) show
105.000000 12.812500 moveto
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
128 string
128 128 8 [128 0 0 128 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
CBCBCED1CECBCAC9CDCDCABEB4B4B4B7B7B5B5B5B5C0C994
9AB1B0ADAAACAFAAABAFAFAFABA8ACAFB1B3B1AFAFAFAFAF
A9ABAFAFB3B6B6B6B6B6B6B4B5B2AFB1B4B2AFAFAFAFAFAF
AFAFAFAFAEAEAFAFAFAFAFB8C6C59A9BA8ACAFABA8A8ABAD
ADADADADB1B4B1B2B7B8B9BBBBB7B8B7B0AEA8A4A7A8A7A5
B3BEA8A9BCC9CFCE
CBCBCED4D2CAC5C4CDD0C5BCA7B4B4B8BAB5B5B5B5C2D89B
8CB0B1ADAAA9B2AEABB2AFAFACA4A8B2B1B3B3AFAFAEB3B2
AAA6B3B0B3BABAB8B8BABAB4B7B6ABB1B6B6AFAFAEAFAFAF
AFAEAFAFAEADB0B3AFAFAFB8D2CB998EBCA8AFABA8A8ABB0
B0ADACACB0B4B4B0BABCBABEBEBBB5BAB0AEA8A0A2A8A89E
9DB9B6A3C3C9D0D2
CCCDCFCDC9CFD6D2CACFD1C5B6A7B5B5B5B5B6B5B4B6BEAA
82D2B4ACADACABA8A5A9AFAFAFAFABADB8B2ADAFAEACA5AD
B2B0AEB5B2AFB2B5B0AFB3B6AFB4B6AFACABABAFB0ABAFAE
AFAFAFAFAFAEAAA8AFAFAFAFB8D2B8697BC9B2AEA8A4A5A8
ACAFB3B3B2B0B0B1B0B4B4B5B1B5B8B5B2ACAEACAAA5A4B4
CDB49EA7B9CFCDC7
C7C8C8C7C7CAC5C7CBC5CBD5D3BEA4A7B0B5B2B7B4B3BECF
9674B8B0ABA2A3ACB2B2B3AFAFAFABA6ACB6B3AFABA9A5A7
A7A1A1A6B0B3B0B2B3AFB0AFAFAFB0AFB1B6B4B0AFB2ABAD
ABABAFAFAFAEAEAFAFAFAFAFAFB2C5D38F74BCA4A8ADA9A4
A5AAA4A8B2B4B6B4B6B4B4B4BABBBAB1B3AEAEABAAA2B3B7
B7CFABA4B3BFD1D6
CCCBCBD1CFCAD4CFCCD1CDC6C7C9C4BEAAACB1ABAFADAFB7
BEA1A6ACADA8A8A8A8A4ACB3B0AFAAA4A8AFAFB2AFACAAA1
9FA3A1A0A5ACB2AEB4B4B4AFAEAEB1BABFB6BABDB8B3B8B3
B8B2AEB0AEAEB0AFAEADADAFADAFB2C5D39892B9AFADADAF
B3AFB0AEAFB1AFB0B0B4B7BABAB7B5B7ADACB1A9A9BDAFB5
B1ABB1ADB7C3BDC5
CBCCCCCDD0D3CECBCBD6D4D4D2CACDC9BCABAFB3AEB0B0C1
D2AC91B0AFACA5A5ACAFA4A9AEAEB3B2AFB2B2A9A9ADAFAF
AFAEABA29FA8AEAFA3A6A5B3B0AFAFAFB3B6ADB2BDBBB1B5
B3B5AEAFB3B2ADB0B6B4B4B2B4AFADB2C5BA84A3BBB6B3B0
ADAFAFB4B2B2B4B5B4B4BABEBABAB7B5B8B5B9C3C9C1D3CD
CDB9AFA6AAC7D0C9
CBCBC7C5C9CBC9D2CFC8CBCCC8D2D2CCCEBFA9A7B2B0B0B1
BBCCB4ACB6B0AAA7A5A9B1B1B3AFA8ADB4A8A7ADA9AEAFAE
ACACACADA69F9DA7A6A7ADAEB3B3B5B0B0B1B6B8B6B2B7B7
B7B7B9B8B6B4B7B4B2B4B0B0B0B1B4AFB2C7BF8A96B3B7B6
B4B3B3B6B6B6B7B5B5B3B5B5BAB9BDB2B2B4AEB7CDBBB3B5
AEC0BEB0BACDCDC8
CBCFD5D4CFCBCCC8CAD1D1CED6D1CAD3D1D1CEBFAEB5B6B5
B7C3C8A9A3D1B4B2ADADA8A8A7A6AAA29DA2A2A5A7A9B3B2
B6B3B3B5B2AEA7A5ABAAA9A6A7A9ABB4B5B3B5B7AFB3B3B2
B4B0B3B2B7B8B2B1B0B3B3B3B3B2B1B3AEB7CFD1B2AEB0B0
AFB1B5B6B7B5B5B6B4B7B8BDBCB9ABB19CA1B6C7C7D2B4B5
BBAFAEB6CACCD0D1
CBCAC9CDC9CCCFD1D1C9C7C5C9CFD3CDD3D1CFCCC0B7B3B6
B4AEB8BE877BBBB1ABA5A8A8A7A3979EA0A09F9C9CA2AFB2
B2B3B3B5B4ABA79FA29F9CA5A5A0A0A0A6A9ADB0B1AFADAE
B0B1B3B5B2AFB5B6B2ADADAEA8ABA8ACAEAAB4C6D1AAA8AE
C3B9B3B6B8B9B7B8BEBBB2B5AAB7A78F96A2BEB8A39CACAD
A3B5ADABC9CCC8CC
C5CACFCBD4D1CDC7CBCDD2D3CDCACCCFD1D6CECECDCCCFCD
D0D1D1CDCCAE94ABC1A4A7AEA5A3A3A4AAAEB0B2AEA5A6AD
B1B6B2B3B3B6B3A8A5ACACA5A6A9A4A19C9B929592929896
989593969899969796969698A1A6A3A3A1A09FA1A3BAA67E
7979D3ADB9B3B3B8B5B1B9B6AA909097979CA0B1ADA1A2BB
B9A8B8BCCCCBCAC4
D7D4D0CECFD4D7D3CDCAC6CCC8C6CBD0C8CBCDCCCFCFCFCD
CDD2CDC9CFD0B497A6B9A9A3A8A8A39C999EA5A8A9A5A5AC
AFB2B9B7B6B1ADAAA6A9A9A9ABA9AFAFABA9AEACA5A19FA1
A1A1A2A49DA0A8A7A8A8A8AFA8A3AEB2ABABABA4A5AAB6B5
B0734A949DB1BDABA69676787E8BA9A6A6A097A8AFAFB09C
B5B09CC7BDD0D2D2
C3C5CFD0C8CBC4C8CFD1CFC6CFD2D2CACECFD1CDD2CCCDC7
CACDCFD3CDCDB99585A49A9EB8A7A6AAA3A3A3A8ADA5A3AB
AFAFAFB2B6B3B6B1ABA6ACB2AFAFAFAFAFABA4A5B3B1B2AB
A4A4AAACB1B1A9A6A5ADAFAFAFAEAEACABADAEB3AFABA8AF
B4B7BAAA7D6E708B8478807A82909AAF9DADAFB1B09DA8BE
B4B1ABADC7C4C8CC
D6D1C6CBD2CED2CFC4C6CBD2CCCDCDD0C7C9CCCDCED3D1D1
D0CBC9C7CACCB9AA9787A1868AC8ABA3A39FA6A7A4AAA9AB
AFAFAFB0B2B1B1B3AFABA6A9AFAFAFAEAFAFAFA9A5A9ACAE
B1ADA4A9A8A5ACB1ADA9AFAEAFABACA9ABABADAAAFAEB2AE
A8A7B0BBADA592626D7B7D7E89888A889BB3A892A5A3A0AE
B4B1C9C3C7CCC5CA
C5CAD4D1C9CDCECED2D6CECED2D2C9CED1D1D2D2CACCD2D2
C9CACDCCC7CABDA7947F91866B6ACBA6A7A2AAA9A8A2A3AB
AFAFAFAFB1B3AFAFAFAFAEB1B1B1B2AFB2AFAFABA9A9ACAE
A9ADAEA6A5A9A9A8A8ABB2AFB2ACA8AFABA9AAACB1ADABA7
ACA39A8983767074736F7A8D838A8D9A9C9EA59DA1A7A1B7
B0B7C1CBC8C7D4D2
D6D3CBC8CCCFCDCACDCCCDCDD1CBD1CAD2D5D1CBD0D2D2CA
D1C9C5CDD1CCC4C4B9978081695855D0A5A69D9BA6A6A9AC
B2AFAFAFAFB2AFAFAFAFABA6A6A9A9AEACB2AFABA6A6ABAC
A8A6A6A7ABA9AAABA9AAAFAAA7A6ACB3ABA5A7A9AAA9A4A6
9A998476736D7687867D777D8C87A09AA7A69889959CA2B7
B0B7CDC9CECDCEC8
CACCD1D3CCCCD2D7D2CFCEC8CBD0CBD5D1C7CBC9CDD0C9D3
CCCBD2CACBC9C2BFBE956C786854404FC79BA2A6A9A5A2AA
A8AFAFAFABA9B1B2AFAEB1B1AEACB1AAA9A9AFAEB1ACA2A6
ACAAADA7A5A8A7A3ACA6AAAEACAEA8AAB1ADAFACA8A8A59F
927E757E71797185898E77778292919A9595A0A6A3A3B79A
B5CCCFCEC5C9CCCF
CDCBC6CACACBD1C9C8C9D4D3CECDCEC9CACDCCCFCCCED0C7
CED2D0D2CDC9C2BABC9F8A766C58473C49D0A09DA5A7A6A7
B2AEB1B1B1AFA6ACB2ABA9A9A6A7A3AAAEB1B1B0A6A9AAA8
A5A6A6ACADA8A7A4A3ABACACA8B0A7B1A9A1989A918D8C89
72715C67828D786F818F97978F7A858D929B9DA6B6C4A6AC
B9C5C9C8CACACECE
C7CDD3C8CACECBC7CCCFCED0CFD0D2D2D4D3D0CEC8C7CED1
C9CACACDCBCCCEC7C39E8E7864564F42352EDBA49DA9A5AA
ADAFA9A9A9ACABA9A9AEA9ACAEAAA7A3A9ACA9ADAEA6A2A1
A3A3A1A4A8A9A1A29E9AA2A6A6A3A99DA9A39A9591847E73
625A64697D8787878D8F959591957E89969A9BA6A8A4A2B7
C9BFB6C4C9C8CAD1
CDCAC9D3D1CCC9D5D3CDC7CDD2CDCAC5C8C5CAD4D5D1CDCF
CDC9C9CBCDC7C0BAB6977C7864535249322E2AD69DA0A0A5
A8A8A9A9A9ACAFA9ABA9A9A9A8A7A9A6A3A5A4A7AAAAA7A7
A4A3A19C9BA1A39EA5A5A2AB9CA09EA299A0988C7B7D5570
63637280868382908880777C808596949596A7A8ABB6CBC4
BDC7CCCBD3D1D4D5
C3C8CFD1D1D3CDC7CDD4D2CEC7C6D1D6D4D3CEC9CBCCCAD1
D3CCCACCCBCCCBBEB89D7F726A5B4F42332832629CA2A8A3
A7A8AAA6A9A6ACB1AEA9A9ACA9A9ABA7A8A7A9A7A7A8A5A2
A2A2A29D9EA09F9A999D979EA59B9F9E9495908758655B56
657A808482858787968B8993968D979A99A7A7A8A7B5BAB8
C1C4CBD1CFCFCCCA
D1D1CFCCD2D0D5D2D2CACCC9CCCDC7C6CDCDD4D0CACDD2CA
C7CDD1C9CAC9C6BFB6A17F706065514933313855C8A0A3A7
A4A8ABABACAEA9A9A9A9A8A5AAABA9A6A5A7A3A0A39BA7A3
A09F9E9B9A939B9A969B9E9C928D938F868375726E4F6260
6364787D7C7D8A8B97A099939CA7A09BA6A7A8A7B3B1BBC9
CBD6D3C9CDD0CCD1
D1CEC9CBC9CDCDD0CACECACAD1CECDD2CDCFCECDD2D1C7CE
D3CFD0D1CCCECBBEA7898470695F534E3E3D3F348AA3A6AB
AAA7ABAEACABA9ACABA8A7A9A6A2A8AAA4A5A6A49DA69AA8
A8A39E9B969589979C99978589898587787F6A606A766C71
81858784807C948386839487968C90A6A6A7AAB8B8C4C8CF
CECAC8D1CFCDCCCE
D1D2D1CBD0C7C9CCD1CECDD1D1D1CDCBD0CDC8CAC8CFCDCA
CDD2CCC8C6C5C5B6AB85777266694F4D4B453E25799DAAAC
AEA6A8A6A6A9A6A6A9ABAAA6A6A5A3A7A9A0A2A3A5A0A49B
9E9B97958B8B9696A29B868D8F877A646C6B6C66646C7472
7683878280777C91909295A7909EB0A6A6A9A1A7C5C5C5CC
CCCBD1D2D1CDD5D1
D1CDCACECED1D1D3D1D1CDD3D1D1CEC9CED4D1CDCAC8CFCF
CECACAD1CEC8C5B09A8A736863514E4F514D3F3364A4A5A4
A7ACA7A8A3A4A9A4A3A4A8A4A5AAA9A6A7A4A6A09A9B9A9F
9C9C9A8C8E848E9C91827D7F7D6E71645E756C6764687064
71818A867F7A898A8C8D888F9A8D96A3A6A6C1CBC2C8CED5
D3CCD1CFC7C8CAD1
D1D1D3CDCAD1D1CFCECDD1CCD1D1D1D1CACDCCC9CDD3CFCF
D0CDD4D4D1C7BEA59085756D68574A534E3E3D327EA5AAAD
ABA4A8A5ACADA5A6A9A4A1A9A49D9F9FA0A69A9F9D9E9C96
95958E877E8A85887F81797F6D725F63657682736B6A6E7D
7B77888592948B84878A808D9DA7ACABA5B3B9C7C7C6C9C9
C8D1CFD0D5D4D5D3
D1CECCD1D3CECACFD1CECDD3D1D1CECCCEC9CCD1CFCFCFCD
CCCACECCC6C3BCA9947E716967535C5452363A2F77A6A3A1
9DA8ADA399A2A3A19F9D9D9E9E9F9A9E9D9B9B9596989A95
948E8A8284828578716C72666E63606A6B747980766A7571
797F7580969B97908A8A8D8996A7AAACBBC9D1C7C5C2CACD
D1D3CEC8C8CBCACD
D1D1D1CECDD4D1CDD4D5CECCD1D1D3D1D1D1D1D1D1CCCFCD
D2D1CBCAD4CDAD9F8B886B6C60585854463A3B3373A6ADA7
AAA4A5AEA1A1A49C9C9F9A979C9B999899999D9896909395
8F8C8E828482786D696A63655B5D5C5A66778880877F766D
6E728A878398998788969C96A2A6ACBBC5BEB7C4CECCCACF
CECCD1D1CFCCCCCF
D1D1D4D3CFCDCFCEC8CAD4D5D1CFCFD1D1D4D4D3D0D1D1CA
C5C8CBCFCECCB591847C6C63545A575637353A3D77A1A3A6
A8A79FA2A59DA19C9999969591919793989898938F8F9090
8E8C81817A7F75676765615D655F595D62717E82777C726E
6D6F76829791909A95958B9B9BA8B7BEBDCCCCC8C0CFCECC
D1D1D3D1CECDD5CF
D4D1C9CDD1CDD1D6D5D1C8CAD2D2CDD3CFCCC9CACACEC9CC
D1D2D1CFC9BFAC908673676B5D5D5251332D35367EA0A0A0
9CA2A29DA09D999A93939592918D85888B9093918D8D8885
87837E81716661695D68674F535A676A686D7D8E9792976B
606D74837F9E98949487879AAAABA8C1C0C1C8C6CFD2D4D1
D1D1CCD1D1CFCACE
C9CCD1CECACBC6C5C7CCD1D1CDCBD2CFCFD0CECDD1D3D1D4
D2CBC8CECBBCA2897F73665A5D5F53413733343A77A69FA6
A6A29E9D94969498958E91918E938E878C8888948D888584
7D7C747D6B56645D615D5650345A5B647C707D868D888F86
78737883828A9695848B8D8EA5B3C4C1C8C1C4CDCCC8CDD1
CECDD5D1D1CDD3D1
D1D1D1D3CFCFD4D5D4D3D1D3D1CDC7CCCECFD2D0D2CCCFCB
C7CDD0C9C5B19B877B68655D55594441373A3A3B7A9C9C9C
969C97989795928B8E898386877C8682828987818689857A
7D79787A6B505D67544F47484449726F677468898F968E92
7B8484828E888D897F7E86A7B2B2C1BDBCCCC6CACECACFD1
D1CDCACECCCFCFD1
D4D3CECDD4CEC9CAC9CDD1CFD1D2D5D1CFC7CCCCCDD1CFCF
D4D2CCCDBCA28F7D716B606751582D43383937476D9C9298
9E9593929995969793908479767F797D7C7B7F84857B7B7A
706D6B795B53575D503C3F52435F6E75706D73788E958F7F
797C7A7B9A998C8B90899995AAC5B4BFC6C8D3D1D3CECCD1
D1D3D1D1D1CECDD2
C9CDD4CEC3C8CFCFD1CEC9CCD1CDCCCECDD0C7CACFD1D1CA
CDCAC9C6BDA38F7A6F61655F6548353C40393655649BACA9
AEADAEA99E9F9C9C9B9A9791817070747A777374717E7773
716962735C515949463941564A586B7B6D6A6C7A8A9D9B9A
8E8276757C9B93848F90A7B9C7C8CCC6CCC8CFCFD1D4D5D4
D1CCD1D3D1D1CEC8
D4D1CAD0D1D4D2CDD5D1D1D1D1D2D0D1D1CFD1CFCBCFD0D2
CBCBCDBEA69588756E6557585C373E3F3C3D4C3376ABB0B8
ADB0A9AFAEAEAAA09FA09998918B7A6C66747677766B7673
6C6B5855745270433A2B35675E4A6A75676F6378828B9C94
8C798673888E9590969F93A8CABFB6C1C6CECDD0C7C8C7CA
CFD3CECCD1D1D3D1
C9CDD0CACEC8CACECED4D4D1CEC9CFD1CACFD1CDCFCEC8C5
C7CDD2C9A1917D7162686358513740423C3C1A7AB1B9B8B6
B6B2B6B4B6B0ABAFAAA09C999B958E8879636C6D7370716F
68614E48674D7A59343B234B794C6777727678728798A8A7
9F7F6C83848589909998A6C7BCB7C5CDCDD4CECDD1D1D4D1
CACFD3D1D1CECCD1
D1CECCD1D2D5D1CDC7C8CAD1D2D2CBD0CECACCC9CCD1D1D1
D0C9BDB599897B695B5A5A5A413A3F405759AFB4B7B9BEBA
BABAB4ADADB4B4AFAEAEADA396999A908876675B696C6768
625950416A655E73392D44415F654F6D7268867B828D9CB0
A082767E7F8D9296939DBBC3B1BAC7CBCECDCFCFD1D1CCCC
CEC9CDD3D1D1D1D3
D6D5D1D3CDCAD2D4D1D4D3D1D0CACCCED1D1D0D4D1D2D6CF
CCC8BEA79481746A585E545A323C3F4B4D78B8B2AFB6B9BB
C0BBBFBFB6B2B0AFB0ABA19FA69F9A9991847D765866655E
624F4B35687F53874D382A5D598C6E7E79776E857B968DAB
A685727A7C7D91ABA79E9BAFC9CFCCD2D1CDD1CCCFCDCFD1
D4D3CFCFD3D1D1CC
C9CCCFCFD1D1CECED1C9CCCECACDCBCBD1C9C8CAD1CCC9D1
CEC5BC9E8F7B796359534F423D3E454356B0B1B6B6B6BBBA
B9BCB4B9BCB3B7B4B3AFB3AAA3A2A29B999188806D545A63
52533F3C4B86725D864765415F6279637C7C6E8B7F859396
B5A4676C89898C999A98A5BAC9C6CACACDD1CFD1D1C9CDD1
CACFCEC9CDD1CCD1
C9CCCFCFD1D1CFCCCDD4D4D4D1C9CDD1CDD4D5D5D4D3CEC6
C6C2AF9E827765625A573B4336395C54AFAEB5BABAB6B4B5
B4B6B5B7B7B0ABAAB0B2AEA9A39F999A9C98928A836E5150
534B423946678B676D7A4C674870756D6C72786A87809395
9A9B88776D7F8994A1ACB7C9B9CACACDCECACFCFD1D3CFCF
D1CCD1D1CECCD1D1
D1D1D1CCD1D1D1CCCEC9CACCCCD1CECCCFCCCACAC9CDD4CD
BEB6A68F7671635059523A38422B34AEB1B4B1AFB1B2AEAA
A2A09F9F9F9D9CA29CA0A1A4A9A3A39E9B98948E8D8B7555
4B4C3F313F5B7A7A6B907B795A4D7184716D6F6F86898D8F
A5B49479878C8289A0BAC7C0CCCAC8C9D3CECDD1C7CCCFCC
CCD1D3D1D1D1D1CE
D1CFCFD1D1D1CCD1D1D1CFCFD1D1D1D1CECACDD1D4CFCDCB
C5B69E8A7A676B524D45403B4585B0B6B8B8B3AFAFA0A2A8
9F9A918D8D8D85909594A99F9BA6A3A0999993908C84806D
413E3B29365076895A6D91727F625A6E84736B7D849288A1
8FA4A58A908591969AB3CCC8CCCED2D2CDD5CFCAD3D1CECD
D3CECDD3D1D1D3D1
D1CFCFD1D1CDD3D1D1D1CFCFD1D1D4D4D1CFCBC6CBD2C9C2
B2ACA17B6C645C51504039433B45B0B0AFB0ADA7AF99756F
677383847B767C6E706F7BA3A29FA6A29E9C99908D8A837A
653A2C2D284E38A482639F8597887571746E806577878A8B
A0A1A7918E9A8C9CB3A6B7C5C7C6C4CBD1CACFCFCFD1D4D1
CCD1D1CCD1D1CFD1
D4D1CDD1CDD1CDD3D1D4D1CDD4D1CCCED4D2D0D1CECECBC7
BBAC8F7A5B61545534453D536BB2ADADAFB1B4938C858395
B19F918B9F9185818B737575AA9F9FA3A0999897918C8381
745E32321C3A505CA07F779475A588687A7F69707C89868E
94A8AB977D7D8799B0C4C6C8C9CAD1CDC7C9CCCECDD1C9CC
D1CECCD1CEC9CCCE
C9CCCECCCFCFD1CDD1CDCFCFCDCDCCC9CACCCDD1D0CDC6B4
A290776C58564D3F49324A4973B4B4B4AFA7B3936C7A8082
72767E7566596168597B685F76B0AFA2A2A2A2988E8F8C86
7D735121203546638F835FA28292AF9C626F707C687F8884
9D98A9997E87838EACC9C7CCC1C7D6D1D1D3D1D3CECCD1D1
D1D1D1D1D3D1D3D1
D4D4D4D3CECACFD1CACCCDD1CACCCDD4D1CDCFD2CECEC6AF
9785705B594C4D443F403C54B5B7B1ABAF9B796859505766
6561635B594D48514E423B3131558BA2A2A19A9C948C8F8F
867562331A1E3F566B9778619B74ADAEA16E836E767B8078
8BA0AFA6909991959FBFC9C7CECACBD4D1CCCECCD1D3D1D1
D3D1D1D1CCCFCFD1
C9CACDCFD1D1C9CCCFCFCFCFCECCCEC9CACDCACCCECABEAE
8F756A534C4F4549464C80B5B5B0B6B6ADA9A29562474447
43415755373C43474D62868E93989CA29F9B9C9D9A938C8F
8A836E4A281343405E7C976B7F7B90BFAE916B787377867C
8099ABAB948D93ADBBC6C5C4C8C9C9CACFD1D1D1CECCD1D1
CDD3CECCD1D1CCD1
D4D1C9CCCECCD1D3CECCCFCFD1D4D3D1CECED2CAC9CAC6A3
81695A5A4F3C4B45445459B1AFB4B2AEB3ADB7B6B9BAB6A9
B1B4AFB2BDB9B6B1A8A6A5A3A09CA3A3A1A09D9A9897928C
8E88795B2A233D5158587A6163846C94AD997D7A786D6D85
8B969BAB988D809DBCC4CAC4C6D1D1CFCFD1D1D4D4D3CECC
CECCD1D1CECCD1D1
CDCFD1D4D4D4D1CDD4D1CECCCFCCCDD3CFCCCBCEC8B2A195
74684D4D4148404846749FB4B6B3B2B4B1B2B0B6B9BBB9BB
B9B8AFB0B0A8A3A1A0A6A4A6A7AF9DA5A6A39F9A98969687
82887C603D2C1E565A717280576E7F95AEAC9F91757F7475
6D8597B39E8D97A3CDC1BDCFCBD3D1CFCFD1D1C9C9CCD1D3
D1D1D1D4D3D1D1CE
C9CDD1CACDCCCCCDCBD3D1D1CECCCECCCECACCCBCECB997A
67525D3D49374C493E8DB4B4B2B5B4B0B2B7B4B6B6B6B7B6
B5B4AEB5AEADA8ABA7A6A7A6A8A8AD9C9B9C9EA097949195
8986846E482A2C3D56586068605E708794B69F7A7B816D80
757C93A79E899094BFC4BBBCD1CCD1CECCCECDD3D1D1CFCF
D1D3CEC9CCD1D1D1
D1CECCCEC9CCD1D1CECDD3D1D1D1D1D4D4D1C9CABFAB9B6F
665A464B4243403F595EB5B0B2B4B6B6B3AFB6B7B6B5B4BA
B4B2AFAFAFA2A3A8A9A5A9ACADA0A5AEADA2A09E9A97928F
8A7E78725733313956586D6877525E60A18198B0857A6E71
8889909E9F8593ABC8C0C3C0CCD1D1D1D1D3CECCD1D1CECD
D1CFD1D1D3D1D1D1
D4D3D1D1D1D1D1D3D1D1CFD1D1D3CEC9CAD0D1CCB299846F
57584F3E414A47396279AEB0B2B6B6B6B9BBB5B6B6B6B2AF
ADA1949DA09A9CA0A2A7A7ACABB4B0AAA0A49B9A9794928F
8F87826F593A17324D5360596E5D564D8298AA927C817D6C
7B8493A2A38F94B8B4D5D7D1D1D1D1D1CFCFD1D1D1D1D1CE
C9CCD1CFCFD1D1D1
C9CCD1D1D1D1CECDD1C9CCD1D1CCD1D1CDCACECBB7906E5C
53404D4140413B387DAEB2B2B6B6B8B3B3B6B4B3B8AEB3C5
9C99977D92A19B8DACA5A7A7A4A5AEAEA9A5ADA19D97938C
8F85797266401B25344D575B6068545E5D9E889AAC78826D
807E8895A6A198C3AFC1AED1D1D1D1D1CECCD1D1D1D1D1D1
D1D1D1CECCD1D1D3
D4D4D3D1D4D3D1CECCD1D4D1CDD3D1D1D1D1D1CDA6846759
46463A46463E37446AAEADACAFB1B5C0B8B8B6B5B4A1737E
AEA89A7B505B7A7B749AA7AAAEAFAFAFAEAF9F9B9B9A9492
8D8D80746352141D2B3F4E55556C51593989819B9B7D8268
69797FA0ADB3B5B1C397D1D3D1D1D1D1D1D3D1D1D1D1D3D1
D1D1D1D1D4D3CECC
C9C9CCCEC9CCD1D3D1CFCDCFCECCD1D2D4D1CEC2976D6247
534A40424733325575B1B0B6BBB9B0B2B6B0B4B3BBB7B4AB
ADACA698989C9F9F8B8297A9AFAFAEAFA9A5B3AEA09A9890
888882786D5E15211C42485646655555356E908A91827B6E
69758692A3ACA094ADD1CFCFD1D1D1D1CECCD1D3D1CECCD1
D1D1D1CECACFD1D1
D1D1D1D1D3D1D1CCD1D1CACFD1D2D4CECED3D1C588665A4C
404849474430355170AEB0AFB1BABBBCBAB7B3B6B9B4AFB9
B5B5B0A79D9FA09C98979BABAFB1B0AFAEAAA0A0A49E9C95
89807E766A5C2E0B253B34654E574B544E598C8EA1926D7C
69787D9AA5AAAE9CADD1CECCD1D1D1D1D4D3CECCD1D1D1D1
D1D1D1D1CECCD1D1
D1D1D1CECCCECCD1D1CFCFCFD3CDCBD1C9CCCFB18363424E
48494A492B352687AEB2B7BBBBBBBBBABABAB5ABB2BEBFBE
C1B5AEAAA5A09D9B9C99A0A5AFB1B0ADB2AFAFA9A0A19E9A
928A7E766C5E40101A3747425A594D4B4B6B7B8E9E906F7A
737378809CA0B6C2CDD3D1D4D4D3D1CECACFD1D1D1D1D1D1
D1D1D1D3D1D1D1D1
D4D4D3D1D1D1D3CEC9CCCEC9CDD3CFCFD1D1CE966A524348
4346482333263469B1B1AFB2BCBBBABCBCBCBCB8B3B6B5BE
B9BCB5AB96979798969CA3B0B0B2B6B2AFADAFAFA8A29B9C
979482756B664F142729464E53565B474C5F748394A27C6E
6B717E9FB39B82ADCECCCEC9C9CCD1D1CECCD1D1D1D1D3D1
D1D1CFCFD3D1D1D1
C9C9CCD1D1D1CCD1D1D1D1D1D1CDD1CDD4D4D090604D4548
494A4B2B212C3C42B0BABABABABAB9B5B5B5BABBB5AEB2B8
B5ACAAA39F969C999DA7AFADAFB0B4B0AEB0AEAFA9A5A39B
9994927D7066592311352D504E49595B4B647F7F90A98178
59746E939BAABECCD1D1D1D1D1D1D1D1D1D1D1D1D1CECCD1
D1D1CEC9CCD1D1D3
D4D4D4D3CECCD1D1D1D1D1D1CFD1CCCFCDCCCA9262464D4C
4B46322B1E342097B5B3B7BAB9B5BEC5C5C1BABCBCB9B0B2
BBB4A89B999C9CA3A6ACB2B4ABADB7B8B4ACADACA99E9E9E
96908C866C625F3F242D3B3D5B4D54565262818A96AA8C6E
5F6F768CB4ABB0D1D1D1D1D1D1D1D1D1D3D1D1D4D3D1D1D3
D1D3D1D1D1D1CECC
CDCCCACFD1D1D1D1D1D1D1C9CACFD1CEC9CC9A815A3A5249
4B4B2E342B5CA8B6B2BEC1B9B9BDBABAB8B5BABABABAB8B9
BBB5ABA69FA0A2A0A3ADB2B3BAB9B1B5B2BDB5B2ADAEA7A2
9E988E8F7D695A4A38363D4E4E5D55585A5B7C9393A5936E
53687684ACBBC8D1D1D1D1D1D1D1D1CECCD1CEC9CCD1CECD
D1CCD1D1D3D1D1D1
CDCFCECCD1D1D1D1D1CECCD1CFCFD1D1D1D3855D493D4B4C
45443B2B5257AEB2BABBB9B9C1C1B9BABEC0B9B5B5BAB8B4
BBBCBBA99FA0A9A8A8A7B0B8BBB8BBBABBB3B1B4B2B0ABA1
9C9C948C806C5C4D35363C464F5B5E5A597F7E8F8F948F65
5D5A7C98A9BFD1D1D1D1D1D1D1D1D1D1D1D1D1D3D1D3D1CE
CCD1D1CECCD1D1D1
C9CCD1D3D1D3D1D1D1D3D1D1CECCD1D1CECD85674D414256
4B3743404275B1B7BABABEC5C1BABBBABCBEBEC5C1BABABB
C1B5ADA59D9BA3AAACB3B4B8B5B8BDB5B0B2BBB8B4B0AFAC
A1969791856F5F4D3F32383D4F555E565482898C93909C68
6F697490B4CCD1D1D1D1D1D1D1D1D1D1D1D1CECCCECCD1D3
D1D1D1D1D1D1D1D1
D4D3CECCCFCFD1D3CFCFD1D1D1D1D1D1D3C6846757504648
413B3E4B4BADB9B4BABABAB9B5BABABABABABFBDBCBABBBA
B2BABAB09E9DA0A9AEAAB8B4B6B7B5BAB8BBB5B1B0B0AFA9
A8A1988F877E6457452E3C3A465D54574F76968F887BAC55
69756F84B1CAD1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D3CECC
D1D1D1D1D1D1D1D1
C9CCD1D1D1CCCFCFCECCD1D1D1D1D1CFCF9984514A5D484F
3743407DB5B9B8BBB9B5BABEC0BABDB9BBB2B3B8BBBEB6B3
B8B9BAB4A49F9BA0A2A8A1B1B3B3BEB8BCB6B0B0B1AFAFAC
A4A697978C7B6E574C2D293E44576154567A8889925D9967
517A8888A6D1D1D1D3D1D1D1D1D1D1D1D1D1D1D1CFCFD1D1
D1D1D1D1D1D1D1D1
D1D1D1CFCFD1CECDD3D1D1D1D4D4D4D1CC6D8B615E4E5944
304F4451ADBBB2B9BEC1BABABEBBB7AFA3B5B9B4B4BBBAB9
BCBBBAB3A8989D979FA5B0B0B3B7AFB0AEB4B2B8B5B9B3B0
A8A0A0978F8570624C3D1B313F5658604F7C8E7E905A7C69
4E7585A0B8D1D1CECCD1D1D1D1D3D1D1D1D1D1D1CECCD1D1
D1D3D1D1D1D1D1D1
D1D1D1CECCD1D1CECCD1D3CFCCC9C9CCCF7465605C57582F
4C418E97B7ADB4BABABABAB9B5B0B4C4AF9AAEAFB8B0B0AD
B5B9BAAE9A95959C9B95A9ACB1AAA89CA4A69C9BA4A8A8A7
ACABA5988D7F735D5647342A324F545F596F8C81785F7B6B
54748DB0C2CCD1D1D1D1D1D1CECCD1D1D1D1D1D1D1D1D1D1
CECCD1D1D1D1D1D1
D4D3D1D1D1D1D3D1D3CECCCECCD1D1D1C5A36651534D5935
474E589D8FA8B8BEBABAB9A8B0A0786D8F98989EACD0B5B0
B8BBBBB4A5908F88A17BA5B8AD9C786E87838C8C95ABAFA7
9D9D9B9A8E8473665146482B2E4C4F565F6A7F72755A896C
5869899DC0D9D1D1D1D1D1D1D1D1D1D1D1D1D1D1D3D1D1D1
D1D1D1D1D1D1D1D1
C9CCD1D1D1CECCCECCD1D1D1D3D1D1D19A86615836555239
319D9D9B8BA3B4B4BCB89F957C77787855728195819EB6BA
B4BBBBB8A7988C8C8E7E47806679935F656082636E8FA69F
A09D9994917D7265544B3919274B534767737D7374637D62
757998ACC3D1D1D1D1D1D1D1D1D1D1D1D1D3D1CECDD3D1D1
D1D1D1D1D1D1D1D1
D1D1D1D1D1D1D1D1D1D3D1CECCD1D1CF925F66583A4A524D
3C5EA49CA3AABCBBB1A48450AFBF8761197353869295ACA2
B2BBB7B0A89A857E728D7766E371791C7D5D7C4065778A9B
A09E9A8F91846F60564A271E212F5B495C6A7C7169658659
7193A0A9D1D1D1D1D1D1D1D1D1D1D1D1CECCD1D1CECCD1D1
D1D1D1D1D1D1D1D1
D1D1D1D1D1D1D1D1CECCD1D1D1D1D1C0FF9E614640444F54
5C7DA39594A7B0B0A88E5A5C5463495C683E5657727D89A9
B6BEB8B2ABA3927A726A7D817D524253345650673E667882
929A978C828169615547391F2E30394D5F6E676B796B8064
67899CADD1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1
D1D3D1D1D1D1D1D1
D1D1D1D1D1D3D1D1D1D3D1D1D1D1D18FA19C5E5154484A52
748F9A8C97A7B2AE967F5A46564B3D37455F635D6C829BAD
B6B6B8B2ACA296887B70656184643031373B46525356727A
7E898D8E7D70605752503F2A33343643606B655E6D747F6E
728AA6C7D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1
CECCD1D1D1D1D1D1
D1D1D1D1CECCD1D1CECCD1D1D1D3D1925A7D5E494C514159
658D9B8E9BABB0AAA596815D3F31292924335D849CADAFAC
B9BCB9AFABADA7999687826151687061482F273D63737177
878D898386735A594F41432E353F37375F75656270798C72
75838DC3D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1
D1D1D1D1D1D1D1D3
D1D1D1D3D1D1D3D1D1D1D1D1D1CCCFC25E713D413F553254
768C8B8793A4AEBBB7B7AEA9A4999599A09F9AA8949DAEB8
B4B5BAB8B2AFA294847F8A94A099726E6F79868B92999A98
929094817A786655534A2E2E2D3C2F495175705F75809375
7A9EC7D9D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1
D1D1D1D1D1D1CECC
D1D1CECCD1CECCD1D1D1D1CECCD1D6E4524C3939414C484A
5E798B858CACB0AEC1C1BABABCA9AB8A797551619EB1BAB7
BEBDBABAB7B6B39C8565575F6F92C6B9B7AAA4A1A2A0A196
878A7A84766C6959424532312A29433D5363675A78839D8C
78A7C3D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1
D1D1D1D1D1D1D1D1
D1D1D1D1D1D1D1D1D1D1D1D1D3CFBFEF633D433B34534955
5F67808289A1AE9CB5C2C4BFAA9D7F56344F89A6AFB2BABD
BBC1BABCBCB8B4B2A07E513944586E9D9BB5BBB1A8A19A96
8176847A6E6663555523413633282C605E6A695F70828188
9A96D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D3D1D1D1D1
D1D1D1D1D1D1D1D1
D1D1D1D1D1D1D1D1D1D1D1CFCFD5B09B7A484D463F404A50
595A66768C9BB2996E80908A7A494A84B2B7BAC0C0C0C0C0
BCBAB9B5B5B7B7B3B4B2A892795536314E5E757F7C7C6C6C
7D85817F71686551454D323822222651625E725D7385767C
7CB2D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1CECCD1D3D1D1
D1D1D1D1D1D1D1D1
D1D1D1D1D1D3D1D1D1D3D1CECCD1AC6854445C534A484451
535B676B88A6B1B6B19B7567709BBDC0C0C0C0C0C0C0C0C1
BDB9B9C0C1C1BCBBBAB9B1AFACABAEAC9A6D4D505B698085
84848B81756C695F403A2D211F1B2254545D6D5C76956978
97C3D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1CECCD1D1
D1D1D1D1D1D1D1D1
D1D1D1D3CECCD1D1D1CCD1D1D1D1B8655852616153534D4F
56586B6A85A2B1B0B4B7BBBAB9B5BAC5C4C0C0C1C4C1C1C0
BDBDC5C1C1B9B5BAB9BAB7B0B6B2AFAFACABABAC9F9B9B92
928C82776A6E6E5F5E3A2B28202A22616A527A766693707E
9BCCD1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1
D1D1D1D1D1D1D1D1
D1D1CECCD1D1D1CECCD1D1D1D1D1B3585350676A5D525250
5253676E7EABB5B6B4B9BEBABDC5BCB6BEC0C0BDBAC0C0C0
BDB6B9BCB5BAC1BABCBEBEB9B2B3B0AFAAA8ACA19F989192
8D8A827C756E68634D3F3B2D1D1F2768756271706187777E
A4D9D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1
D1D1D1D1D1D1D1D1
D1D1D1D1D1D1D3D1D1D1D1D1D1D1BC62515A5B645D575950
524E62667492AEB7B4B4B7BBBABEC5BDBAC0C0C1C4C4C0C0
C0C0C1C5C5C1BABABCB6B6B6B8B6AFADB3AFA8A49E9C9794
8E928A816C6D6B5B50383C261E1B2D5C8B62767863658B74
CCD1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D3D1D1D1
D1D1D1D1D1D1D1D1
D1D1D1D1D1CECCD1D1D1D1D1D1D1CC665E4B55565C565053
4F5860787B98AAAEB4B5B6BBBAB8B9C1C4C4C0BDBABAC1C5
C0C0BDBABABAB9B4AFB3B6B4B1AFAFA9A7AAA9A89F9A9996
8C82817C7B6E64573E452929221B285E817B8D836B5B7EA2
D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1CECCD1D1D1
D1D1D1D1D1D1D1D1
D1D1D1D1D1D1D1D1D1D1D1D1D1D1D47F495C595E5A615354
5A5365778592A6AFB7B8BEBEBBBEC4BDB7BFC4BDBBC5C0BA
C4C5C1B9BABABBBBBEB8B6B4B3ABAFAA9FA1A1A1A09E9895
8E8F817A796D6B59463A2B1D15153D4879797B807A5F67AE
D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1
D1D1D1D1D1D1D1D1
D1D1D1D1D1D1D1D1D1D1D1D1D1D1D4716E4F52635C565655
496768727E93A1ADB3B7B6B6BBBABAC1C0B5BAC1C0B6BEC1
B7B9BABBBABCBCB8B6B8B3B6B2B4AFAEB0A4A9A6A29C9895
8A887E7A726D5C5252341F15251147586369878B909385D1
D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1
D1D1D1D1D1D1D1D1
D1D1D1D3D1D3D1D1D1D1D1D1D1D1D5893F60615557555754
594E6A7A81869FACB2B5B6BBBCBEC0BDBCC1C4BDBEC1BABA
C1BBBABABAB9BABCBBBBB9ADB0B3AFA9ABA8A39F9C9C9892
8C88817970665C4B3E391D1B251B4A5D655D7887889BB9D1
D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1
D1D1D1D1D1D1D1D1
D1D1CECCCECCD1D1D1D1D1D1D1D1D1C2705D504B514D4C55
585F697688919EACB2B7C0BABABEC4C1BEC1BABDB6B6BFC1
B7B9BABBBBBBBABABBBBB2B6B2AFABAAA5A8A09F9C9A9E97
908884766A6061473B282513221D545E62637A8887A0D1D1
D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1
D1D1D1D1D1D1D1D1
D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D595444E4D4B4E4B4A
556670808998A0ABB3B4B4BABABBB7BBB6B9C0C0C1C0B5BD
C1B7BCBBBCBBBBBBB6B2B3B6B4B1B6AFAFABA99F9B98959A
91907D747666543B3424271A2022566C5466749B9BACD1D3
D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1
D1D1D1D1D1D1D1D1
D1D1D3D1D1D1D1D1D1D1D1D1D1D1D1D1B05E4A4C4F4E5050
4B5F70788592A4A8B3BABABDB9BDC0BDC4C1C4C1C1BDC1BB
BDC1BABABABBBCBBB8B9BBB5B0B2AFAFAEACA19E999B9794
918285746D66593C32282329261C5B7B65657890B5D1CECC
D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1
D1D1D1D1D1D1D1D1
D1CECCD1D1D1D1D1D1D1D1D1D1D1D1D1CE8253434E4D4B52
515A6C888F97A0B3AFAFB4B6BBBBBCBBBABDBFC0BABCBBBA
BBB9BABCBBBABABBBBB6B4B5B5B2B0B0ABA8A8A6A09B9892
8A867D74695D4D3C362B232A1E15556D6E758B9CB2D1D1D1
D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1
D1D1D1D1D1D1D1D1
D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D18B37474D55524B
52606B7594A7ABA8B3BAB9BFBEBBBABEC5C0BABBB7B9BAB9
BABBBABCBBBEBEBBB6B3B7B2B4AFAFAEB0A7A4A09E979B97
8A857774615747443132231D132F445F69738CB3C9D3D1D1
D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1
D1D1D1D1D1D1D1D1
D1D1D3D1D1D1D1D1D1D1D1D1D3D1D1D1D1D4B0584B615B5E
53596F81869DAEAFAFB3B5B4B5B9BCBABABBBABDC1BABABC
BBBBB8B6B8B6B6B6B6B8B6B6AEAEAFA9A4AAA69F9C9C9790
8E7B72655F58433B3B2A2C1711414F69737C95A2CECCD1D1
D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1
D1D1D1D1D1D1D1D1
D1CECCD1D1D1D1D1D1D1D1CECCD1D1D1D1D5DDCF864F5F50
5F5A697B8D95A6B2B5B3BAB9BFBDB8BCBABBBBBEBBBBBABC
BBBFBEBFBBB6B6BABFB6AFAFB0AFAFACA8A3A3A2A1948F90
7D7E726253514F32342C1D1534306B65707985B5D1D4D3D1
D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1
D1D1D1D1D1D1D1D1
D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D4AB435A5E
4A66637A8999A4A7A6AFB4B8B2B3B3B9BEBBBBB6BBBBB8B6
BAB4B2B5BAB6B8AFAFAFB0AFAFAFAEADA2A3A3A29C959990
88766960554D5352202023353E8165656F8FACC6CFCAC7D1
D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1
D1D1D1D1D1D1D1D1
D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D4BD71415A
65656F7A8894A2B0B1AFAFB3B8BDB8B7B8BBB9BEBEBEBEB8
B8BBBFB6B2BCB3B6B0AFAFB0AFAFAAAAA9A1A29C998D898A
7D7467605B4E4A414D293038625970667690BCCAC9D1D9D1
D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1
D1D1D1D1D1D1D1D1
D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D4B0874352
5460757B8A99A5A2AFB3AEB7B0B4BAB4B9BAB8B6B6B3BCBA
B4B2AFB4AFACB5AFAEB1B3B1B4B4ACA6A4A19E9D9891837F
706C604F514D4C4040365342566B79758C8D9CD5D9D3D1CF
CCD1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1CFCCD1D1D1D1D1
D1D1D1D1D1D1D1D1
D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D5B2763A48
5D4D6673818E93A3A9AEAEADB4B5B8B4ADB1B6BABCBBB3B4
AFB1AEA7A5A6ABB2B3ACAAAAAAA79FA09D9B94968981837D
716B61594D4950433F4951686869738888BFD3D1CECACCD5
D9D1D1D1D1D1D1D1D1D1D1D1D3D1D1D1D1D5D9D1D1D1D1D1
D1D1D1D1D1D1D1D1
D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1C4A57337
506157717B90A1A19BA7A8ABB5AEADB2B4B0B3B3B4B2B3B6
B4ABA2A1A0A5A9A7A3A1A19F98A29F9A9D9394918A7F7771
6E70604F5B52486153526B6F7373909CA09DCCD1D1D5D9D1
D1D1D1D1D1D1D1D1D1D1D1CECCD1D1D1D1D1D1D1D1D1D1D1
D1D1D1D1D1D1D1D1
D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1A66254
4E5C62656E7592A3B29FA2A1A4B0B3B3B2ACADABB1AC9C9F
9D9F969A8F958E97879A889588878E8789857E7D897E716E
5D605D5C5C664F4060716664707F7EA1BACAD1D1D1D1D1D1
D3D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1CFCCD1D1D1D1D1
D1D1D1D1D1D1D1D1
D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1A94C
3F51556F766B8384909A9CA8AEADA7ABAAA99D9B98A4A496
93988E89868484808C7D7974836D7E767A7A79766A7F7F79
7370685D5466694E465F757E747E96A79CD1D1D1D3D1D1CE
CCD1D1D1D1D1D1D1D1D1D1D1D1D1D3D1D1D5D9D1D1D1D1D1
D1D1D1D1D1D1D1D1
D1D1D1D1D1D1D1D1D3D1D3D1D1D1D1D1D1D1D1D1D1D1D1C9
8C705F5970675B7D9BAAB9B7AFA9A89E9B96939B9993959A
8E84827F7586757B6C767761677E6676666E72705C616969
656A6B6062515C5F6970706A89A39893D1D1D1CCC7D1D1D1
D1D1D1D1D1D1D1D1D1D1D1D1D1CECCD1D1D1D1D1D1D1D1D1
D1D1D1D1D1D1D1D1
D1D1D1D3D1D1D1CECCCECCD1D1D1D1D1D1D1D1D1D1D1D1D1
935076696C8B999398A2959FA7A4A09797978C8B8F97888C
8687747576698775876D78796B756A7775766E706D57615D
61665F625C5D626764687A8FA48EB7AED1D1D1D5D9D1D1D1
D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1
D1D1D1D1D1D1D1D1
D1D1CECCD1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1
D58D446B676D747B7D8B9D9E959A9A978A8F84807F81877C
7D7E72766B5F558365846870706979644E6179645E5C5750
4D51584C5756585474877EBB899B79CCD1D1D1D1D1D1D1D3
D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1
D1D1D1D1D1D1D1D1
D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1
D1D5A772647F8596A7A6A0A194888D8B8D888882837A7984
7563765E6B794953705A7170656355555E475654555A5758
5762645C525E7199808F87727B8EB1D9D1D1D1D3D1D1D1CC
D1D1D1D1D1D1D1D1D1D1D1D1D1D3D1CFCCD1D1D1D1D1D1D1
D1D1D1D1D1D1D1D1
D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1
D1D1A45576625E6B85A1A19D9C818A8287857F757D7C7678
74705B8367647D506067575F5950534B494A4C5951535752
54565D6E798A8A80A49477717A6FD4D3D1D1D1CCD1D1CCCF
CCD1D1D1CFCCD1D1D1D1D1D1CECCD1D5D9D1D1D1D1D1D1D1
D1D1D1D1D1D1D1D1
D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1
D1D1D581385D9B707788A6988F7778737B897D7075797079
75775E6563625659664E59565550494C434146444A54584C
576C726866668C87657D6FA273BAC5CFD1CECCD1CECCD1D5
D9D1D1D1D5D9D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1
D1D1D1D1D1D1D1D1
D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1
D1D1D1D38A3A4790908E95A1987A6E8569787567647D6E62
746A5E636E61593554615949524252413D343938394B5B69
555F818E89899C8A706A8D70C8DDD6CCD1D1D3CFCCD1D1D1
D1D1D1D1D1D1D1D1D3D1D1D1D1D1D1D1D1CFCCD1D1D1D1D1
D1D1D1D1D1D1D1D1
D1D1D1D1D1D1D3D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1
D1D1CECCD5A0454D6B8895A9A4796373826C7E8369657867
606F6E5E6573624F3E4454674D4A484A4A393C3F3C3E4D64
7D7B6B92895A6C767B6B5A88D1D1D1D1CFC9CDD8D9D1D1D1
CFCCD1D1D1D1D1CECCCFCCD1D1D1D1D1D1D5D9D1D1D1D1D1
D1D1D1D1D1D1D1D1
D1D1D1D1D1CECCD1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1
D1D1D1D1D1BC72455460789CA09C56687A7A6168615A5D69
63636966616A6F615F4E514653595253585F5352585E6C71
789A9A876969556A797D70CFCACCD1D2D1DAC9CDD3CFCCD1
D5D9D1D1D1D1D1D1D1D5D9D1D1D1CFCCD1D1D1D1D1D1D1D1
D1D1D1D1D1D1D1D1
D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1
D1D1CFCCD1D1B3725A625B677A90864E647A725F63485455
615E66576860796B6A5D535D515F65645A5D65727982748E
98776471775B6D80525FD9D5DCD3C9D1D5CCD9CECCD5D9D1
D1D1D1D1D1D1D1D1D1D1D1D1D1D1D5D9D1D1D1D1D1D1D1D1
D1D1D1D1D1D1D1D1
D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1
D1D1D6DBD1D1D3A960506D747982917A516D6978646B4F4E
56576959656D79766F635E4942465961695F6A7E89848A6A
6460544E596B736577D9CFCCD5DDD9D1D5D9D1D3D1CFCACC
D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1
D1D1D1D1D1D1D1D1
D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1
D1D1CECCD1CECACCAF4A3D6A6F9599907C5F6D6171676F51
424456506471707D8AC7AB92898E818697B1AD9A8970635A
5A5D586A75835264D9D1D8D9D1D4D3D1D1D1D1CCD1D5DDD9
D1D3D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1
D1D1D1D1D1D1D1D1
D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1
D1D1D1D1D1D1D4D4D1CD874A5A6C8BAE9F7D6F6F66655D7E
7C2D000410456F7E7275A1A1A4ADADC29584837E67685B66
4D556974732575CFCDD1CCD1CECACFD1D1CECDD3D1CFCCD1
CFCFD1D1D3CFCCD1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1
D1D1D1D1D1D1D1D1
D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1CFCCD1D1
D1D1D1D1D1D1D4D4D1D1D5961F447992AAB08E8E9196AA94
93B4CBD9C8BDAEA3A0AEA6ABC0A792827979656E6D5F5851
6D757A4D63D9D3D6D9CCD1D1D1CECCD1D3D1CECCD1D5D9D1
CECCD1CECCD5D9D1D1D1D1D1D1D1CFCCD1CFCCD1D3D1D1D1
D1D1D1D1D1D1D1D1
D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D5D9D1D1
D1D1D1D1CFCCD4D3CCCFCCD1C26C3E6F8CA7AEBEBEB5B0AB
B0B1A2A2A9AEBDBBB6B1AF8C92A67F89796F5C67646B7A87
8E6B4788D1CFCFCECCCFCCCFCCD1D1D1CCD1D1D1D1D1D1D1
CFCCD1D1D1D1D1D1CFCCD1D1D1CFD1D9D1D5D7C9CCD1D1D1
D1D1D1D1D1D1D1D1
D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1
D1D1D1D1D5D9D5DDD9D5D9D1D8CF81265380A3B6ABABB0B8
B9BBC6C7C1BEC0C0B7BCAE9B7F738873656E60537582946B
3F73BAD1D1CECACCD1D5D9D6DBD1CCC7CFCCD1D1D1D3CFCC
D5D9D1D1CFCCD1D1D5D9D1D1D1D5D9D1CFCACFD5D3D1D1D1
D1D1CFCCD1D1D1D1
D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1CFCCD1D1D1
D1D1D1D1D1D1D1D1D1D1D2C9CCD4D4D19D341F64A7C6C4C4
C0ACADB5AAA193897B85919A745954626F7897A690553A81
C7D1D1CFCCD1D5D9D1CFCCCECCD1D5D9D6DBD1D1CECCD5D9
CFCCCFCACFD3CACCD1D1D1D1CFCCD1D1D4D7D9D5C7D1D1D1
D1D1D5D9D1D1D1D1
D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D8D9D1D1D1
D1D1D1D1D1D1D1D1D1CED1D9D1D5D9D1CFCCCF9D4B6E9FAB
ACCCC5BDBEB6AA8B7D727377999A87ABB99B675E94C6D7D9
DBD1D1D5D9D1D1D1D3D5D9D3D1D1D1D3CECCD1D1D1D1D1D3
D5D9D5DDDDDDDEDBCFCDD3D1D5D9D1D1D8DDD9D5D9D3D1D1
D1D1D1D1D1D1D1D1
D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1CECACCD1D1D1
D1D1D1D1D1D1D1D1D1D1D1D1D1D1D3D1D4D5D9DBD1A9626C
787394A4ADB1B9D1DACFB8B4BAB39A625E7EA3C3D1D4D7D1
CACACACCD1D1D1CECDD4D1CCD1D1CECCD1D3CFCDD3D1CECA
CCD1D1D1D1D1CECCD5D5C7CFCCD1D1CECCD1D1D1CCC7D1D1
D1D1D1D1CFCCD1D1
D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D5D9D3D1D1
D1D1D1D1D1D1D1D1CFCDD3D1D1CECDD3D5D6C9CCD1D1CEC9
C7BFBBB6B7C2AD91848C958F8F92A5C0CCCFCACCD1D5DCD4
D5DDDDD9D3CFCCD1CCC5CCD1CFCCCFCCCCC7D6D9CCD1D3D5
D9D1D1D1D1D1D1D1D1D6DBD5D7CCD1D1D1CFCCD1D5D9D1D1
D1D1D1D1D5D9D1D1
D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1CECCD1D1
D1D1D1D1D1D1D1D1D5D6CCD1D1D1D1CCD1D2CCD1D1D1D3D1
D8D9CFCDD3D1CEC9C9C9CFD4D1D1D3D1D1D5DDD9CFCCD4D4
D1D1D1CFC7D4D3CCD5D9D1D1D5D9D5D9D4D5D1CFD1D1CCD1
D1D1D1D1D1CFCCD1D1CECCD1D4D4D1D1D1D8D7CACCD1D1D1
D1D1D1D1CFCCD1D3
D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1CFCCD1
D1D1D1D1D1D1D1D1D1D1D1D1D1CECCCFC8CCD9D1D1D1CCCC
C7D1D5D5C7D1CFCCD1D1D6DBD1CECCD1D1D1D3CFD1D9D4D3
CCD1CED1DBD5DEDBCFCCD1D1D1CFCCD1D5D6C9CCCECCD1CF
CDD3D1D1D1D4D4D1CFCCD1D1D8D9D1D1CECCD6DFD4D1D1D1
D1D1D1D1D5D9CCC7
D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1CFCCD1D1D8D9D1
D3D1D1D1D1D1D1D1D1D1D1D1D2CCD1D5DEDBD1D1CECDD2D1
DBD1D1D4D4D1D5D7CCD1D1CCD1D3D1D1D1CECCD5D9D1D5DC
D4D1D1D1CACCCECCD6DACACCD1D6DACCD1D1D1CFCCD1D1D4
D1CCD1CFCCD5D7CCD5D7CAC9CCCFCCD1D1D1D1D1D9D1D1D1
D1D1CFCCD1D1D5D9
D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D5D9D1CECCCFC9
CCD1D1D1D1D1D1D1D1D1D1CED1D9D1D1CECCD1D1D1CFD3D6
CCCFCDD8D7CCD1D5D9CCC7CFC9CCD1D1D1D1D1D3CFCCD1D5
D9D1CECCD5D9D1D1CED1DEDBD1CED1D9D1D1D2D1DACCD1D4
D4D1D1D8D9D1D5D9D1D5DDD9D1D5D9D1D3CECCD1D1D1D1D1
D1D1D7D4D1D1D1D1
D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1CFCCD5D9
D1D1D1D1D1D1D1D1D1D1D1D3D1D1D1D1D1D1D1D1D1CFCFD3
D1D5D6CDD7D3CCD1CFD1DBD5D9D1D1CFCCD1D1CFD5D7CDD3
CFCCCFCCD1CFCCCFCCD1CECCD1CFCCD1D1CED1D6D3D7CCD5
D9CFC9CCD1CFCCCFCCD1CFCDD3D1D1CECCCFCCD1CFCCD1D1
D1CED1D9D1D1D1D4
D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D5D9CFCC
D1D1D1D1D1D1D1D1D1D1CECACCD1D1D3D1D3D1D1D1CEC9CA
CCD1D1CED1DDD9D1D7D1CCD1D1D1D1D5D9CEC9CCD1D8D5C7
D4D4D5D9D1D7D5D7D4D1D1D1D3D5D9D1D1D1D1CECAD1DCD3
D1D5D9D3D1D5D9D4D4D1D5D6CCD1D1CFCCD5D9D1D5D9D1D1
D1D1D1D1D1D3CCC5
D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D5D9
D3D1D1D1D1D1D1D1D1D2CCD5D9D3CECDD1CFD1D1CFCACCD5
D9D1D3D1D1D1D1D1D1D7CCD1D2CCD1D1D1D1CFCCCCC7D6DA
D1D9D3D1D1D1D5CCD9D1D3CECACDD2CCD1D3D1D2D1D5C5CC
D1D1D1CCD1D1D1D5D9D1D1D1D1D1D1D5D9D1D3D1D1D1D1D1
D1D1D1D1CECCD5D9
D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1CE
CCD1D1D1D1D1D1D1CED1D9D1CCC7CFC9CACDCACCD6DFD4D1
D1CECCD1D1D1CCC6CCD5D9CECFD4D1D1D1D1D5D7D1D9CED1
D9CCC6C8C6CCD5D9D1CFCFCFD1D6D1D7C8C6C8CCD9D5D9D1
D1CCC6CCD1D1D1D1D3D1D1D1D1D1CFCCD1CECCCFCCD1D1D1
CFCCCFCCD1CFCCD1
D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1CFCCCFCCD1D1
D3D1D3D1D1D1D1CFCCD1D1D1D5D9D6DBCFD3DEDBCED1D9D1
D1D1D1D3D1D1D5DDD9CFCCD1D5D9CFCDD3CFCAD1D9D1D1D1
D1D5DDDDDDD9CFCCD1CECCD5D9D3D1D5DDDDDDD7CCCFCCD1
D1D8DCD4D1D1CFC9CCD1D1D1D1D1D5D9D3D1D3D5D9D1D1D1
D5D9D5D9D1D5D9D1
D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D4D4D5D7CCCE
CCCECCD1D1D1D1D5D9D1D1D1D1D3CECCCECCCECACCCFCCD1
D1D1CECCD1D1D1D1CFCFD4D1D1D1D8D6CACFD9D9D1D1D1D1
D1D1D1D1D1CFCFD3CCD1D1D1CECCD1D1D1D1D1D4D3CFD4D1
CECCD5D9D1D1D5D9D1D1D1D1D1CFCCCFCFCFCFD1CFCCD1CF
CDD3D1D1D1D1D1D1
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[40]:=",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`004`3oool40<_;b`80c/k>0P3AdM420<k>cP80bl_;
0P3:b/X20<W9b@<0cLg=0P3:b/X20;jn_PH0];Bd102g]kL80;Fe]@80`<300P39bLT209BDU00309ZJ
VP2a/K40/K6a0080/;2`0P2][Jd20:ZZZP80[:b/0P2_[jl20:ZZZP80Zj^[1P2_[jl20:^[Z`80Z:RX
0P2/[:`20:n_[`030;6a/@2c/k<0/k>c0080/K6a2P2_[jl20:VYZ@80Zj^[102_[jl20;>c/`/0][Jf
0P2d];@20;Fe]@80/[:b0P2_[jl20;6a/@80];Bd0P2b/[8C0:n_[`@0[Zj^2P2_[jl20;Rh^080a/K6
0P35aLD209ZJVP80Vi^K00<0Z:RX0:b/[02/[:`00P2_[jl20:^[Z`@0Z:RX0P2[Zj/:0:f][@80/K6a
0P2d];@20;6a/@80/[:b00<0]kNg0;Rh^02h^;P00P2i^KT40;^k^`80]kNg0P2h^;P20;Ng]`80/;2`
0P2^[Zh20:RXZ080Y:BT0P2WYjL20:RXZ080YjNW0P2UYJD00`2c/k<0_[jn0;jn_P020:RXZ080ZJVY
0P2l_;`20<W9b@80clo?0P3>c/hE0?ooo`004`3oool40<_;b`80c/k>0P3AdM420<k>cP80bl_;0P3:
b/X20<W9b@<0cLg=0P3:b/X20;jn_PH0];Bd102g]kL80;Fe]@80`<300P39bLT209BDU00309ZJVP2a
/K40/K6a0080/;2`0P2][Jd20:ZZZP80[:b/0P2_[jl20:ZZZP80Zj^[1P2_[jl20:^[Z`80Z:RX0P2/
[:`20:n_[`030;6a/@2c/k<0/k>c0080/K6a2P2_[jl20:VYZ@80Zj^[102_[jl20;>c/`/0][Jf0P2d
];@20;Fe]@80/[:b0P2_[jl20;6a/@80];Bd0P2b/[8C0:n_[`@0[Zj^2P2_[jl20;Rh^080a/K60P35
aLD209ZJVP80Vi^K00<0Z:RX0:b/[02/[:`00P2_[jl20:^[Z`@0Z:RX0P2[Zj/:0:f][@80/K6a0P2d
];@20;6a/@80/[:b00<0]kNg0;Rh^02h^;P00P2i^KT40;^k^`80]kNg0P2h^;P20;Ng]`80/;2`0P2^
[Zh20:RXZ080Y:BT0P2WYjL20:RXZ080YjNW0P2UYJD00`2c/k<0_[jn0;jn_P020:RXZ080ZJVY0P2l
_;`20<W9b@80clo?0P3>c/hE0?ooo`004`3oool40<_;b`80c/k>0P3De=@20=;BdP80b/[:0P35aLD2
0<C4a0030<g=c@3@d=00d=3@0080aLG50P2l_;`20:NWY`@0];Bd0P2h^;P20;Zj^PP0]KFe0P32`/82
0=SHf080Vi^K00<0S8b<0;2`/02`/;000P2a/K420:f][@80ZZZZ0P2YZJT20;:b/P80[Zj^0P2[Zj/2
0;:b/P@0[jn_0P2/[:`20:BTY080Z:RX0P2b/[800`2a/K40/k>c0;>c/`020;>c/`@0[jn_0P2^[Zh2
0;>c/`80/[:b0P2ZZZX20:JVYP80/k>c0P2`/;020;>c/`@0^[Zj0`2h^;P40;Zj^P80];Bd0P2g]kL2
0;Jf]P80Zj^[0P2a/K440;Jf]P@0[jn_0P2^[Zh70:n_[`80[Zj^102_[jl20:j^[P80[Jf]0P2`/;02
0;>c/`H0[jn_0P2h^;P20=;BdP80bl_;0P2IVIT208j>SP030;bl_02XZ:P0Z:RX0080[jn_0P2[Zj/4
0:RXZ080Zj^[102`/;020:f][@@0[:b/0P2`/;040;Bd]080/;2`00<0^[Zj0;bl_02l_;`00P2j^[X4
0;jn_P80^k^k0P2e]KD20;Zj^P80/;2`0P2^[Zh20:RXZ080X:2P0P2RXZ840:RXZ080WYjN00<0WIfM
0;Vi^@2i^KT00P2f][H20:>SX`80`l?30P39bLT20=3@d080d];B5@3oool001<0oooo103;bl/20<k>
cP80e=CD0P3Bd]820<[:bP80aLG50P34a<@00`3=cLd0d=3@0=3@d0020<G5a@80_;bl0P2WYjL40;Bd
]080^;Rh0P2j^[X80;Fe]@80`/;20P3Hf=P209^KV`0308b<S02`/;00/;2`0080/K6a0P2][Jd20:ZZ
ZP80ZJVY0P2b/[820:j^[P80Zj^[0P2b/[840:n_[`80[:b/0P2TY:@20:RXZ080/[:b00<0/K6a0;>c
/`2c/k<00P2c/k<40:n_[`80[Zj^0P2c/k<20;:b/P80ZZZZ0P2VYZH20;>c/`80/;2`0P2c/k<40;Zj
^P<0^;Rh102j^[X20;Bd]080]kNg0P2f][H20:^[Z`80/K6a102f][H40:n_[`80[Zj^1`2_[jl20:j^
[P@0[jn_0P2^[Zh20:f][@80/;2`0P2c/k<60:n_[`80^;Rh0P3Bd]820<_;b`80VIVI0P2>SXh00`2l
_;`0Z:RX0:RXZ0020:n_[`80Zj^[102XZ:P20:^[Z`@0/;2`0P2][Jd40:b/[080/;2`102d];@20;2`
/0030;Zj^P2l_;`0_;bl0080^[Zj102n_[h20;^k^`80]KFe0P2j^[X20;2`/080[Zj^0P2XZ:P20:2P
X080XZ:R102XZ:P209jNWP0309fMW@2i^KT0^KVi0080][Jf0P2SXj<20<?3``80bLW90P3@d=020=;B
dQD0oooo000C0?ooo`80c<c<0P3=cLd20<o?c`80cLg=0P39bLT20<o?c`80e]KF0P3Bd]800`3:b/X0
clo?0<o?c`020=7Ad@80aLG50P2f][H20:NWY`P0]KFe0P2f][H20;Fe]@80];Bd0P2f][H20;jn_P80
ZZZZ00<0PX:20=;BdP3Bd]800P2d];@20:b/[080[Jf]0P2/[:`20:^[Z`80Z:RX0P2UYJD20:VYZ@P0
[jn_0P2[Zj/20:f][@030;Rh^02b/[80/[:b0080[Jf]0P2_[jl20:j^[P80[:b/0P2UYJD20:f][@80
/[:b0P2`/;020:j^[P80]KFe0P2b/[820:n_[`80/[:b0P2e]KD00`2`/;00[jn_0:n_[`020;>c/`80
][Jf0P2_[jl20;Bd]080][Jf0P2_[jl20:b/[0@0Zj^[0P2_[jl20;2`/080Zj^[0P2_[jl20:j^[PT0
[jn_0P2^[Zh20:ZZZP80Z:RX202_[jl20;Rh^080d];B0P2h^;P206UYJ@0307]kN`39bLT0bLW90080
/[:b0P2^[Zh20:RXZ080Y:BT0P2UYJD20:RXZ080[:b/0P2_[jl40;>c/`80/[:b102`/;020;6a/@03
0;2`/02d];@0];Bd0080];Bd0P2e]KD20;6a/@80]KFe0P2h^;P20;Fe]@80/[:b0P2/[:`20:j^[P80
[:b/0P2ZZZX20:FUY@80Y:BT0P2d];@00`3=cLd0];Bd0;Bd]00209jNWP80YjNW0P2i^KT20<o?c`80
cLg=0P37alLE0?ooo`004`3oool20<c<c080cLg=0P3?cll20<g=c@80bLW90P3?cll20=KFeP80d];B
00<0b/[:0<o?c`3?cll00P3AdM420<G5a@80][Jf0P2WYjL80;Fe]@80][Jf0P2e]KD20;Bd]080][Jf
0P2n_[h20:ZZZP0308:2PP3Bd]80d];B0080];Bd0P2/[:`20:f][@80[:b/0P2[Zj/20:RXZ080YJFU
0P2YZJT80:n_[`80Zj^[0P2][Jd00`2h^;P0/[:b0;:b/P020:f][@80[jn_0P2^[Zh20:b/[080YJFU
0P2][Jd20;:b/P80/;2`0P2^[Zh20;Fe]@80/[:b0P2_[jl20;:b/P80]KFe00<0/;2`0:n_[`2_[jl0
0P2c/k<20;Jf]P80[jn_0P2d];@20;Jf]P80[jn_0P2/[:`40:^[Z`80[jn_0P2`/;020:^[Z`80[jn_
0P2^[Zh90:n_[`80[Zj^0P2ZZZX20:RXZ0P0[jn_0P2h^;P20=;BdP80^;Rh0P1YJFT00`1kNg/0bLW9
0<W9b@020;:b/P80[Zj^0P2XZ:P20:BTY080YJFU0P2XZ:P20:b/[080[jn_102c/k<20;:b/P@0/;2`
0P2a/K400`2`/;00];Bd0;Bd]0020;Bd]080]KFe0P2a/K420;Fe]@80^;Rh0P2e]KD20;:b/P80[:b/
0P2^[Zh20:b/[080ZZZZ0P2UYJD20:BTY080];Bd00<0cLg=0;Bd]02d];@00P2NWYh20:NWY`80^KVi
0P3?cll20<g=c@80alO75@3oool001<0oooo0P37alL40<S8b0@0alO70P3:b/X20<G5a@80alO700<0
bl_;0<G5a@35aLD00P3;bl/20=GEe@80dm?C0P2n_[h20:BTY080YjNW0P2`/;020;Fe]@80/[:b0P2g
]kL20;Bd]080/k>c0P2n_[h20<o?c`0309JFUP1dM7@0M7Ad0080^;Rh0P2`/;020:^[Z`80XZ:R0P2S
Xj<20:b/[0@0/[:b0P2c/k<60:n_[`80Zj^[0P2VYZH00`2/[:`0][Jf0;Jf]P020;>c/`80[jn_0P2[
Zj/20:VYZ@80YJFU102WYjL40:6QX@80YZJV0P2`/;020;>c/`80/;2`0P2b/[800`2c/k<0[jn_0:n_
[`020;2`/0H0[jn_0P2`/;020:n_[`80/K6a0P2f][H20;Bd]080/;2`0P2_[jl20;:b/P80Zj^[0P2]
[Jd30:^[Z`H0[jn_102^[Zh<0:n_[`80/[:b0P35aLD20=?Cd`0308n?S`1dM7@0M7Ad0080_;bl0P2T
Y:@20:RXZ080[Jf]0P2YZJT20:BTY080YJFU0P2ZZZX20:BTY080Z:RX0P2b/[820;Bd]080][Jf0P2d
];@00`2f][H0];Bd0;Bd]0040;Bd]080^[Zj0P2k^k/20;Zj^P80/K6a0P2c/k<40:j^[P80Zj^[0P2Z
ZZX20::RXP80/k>c0`2g]kL20<o?c`80Zj^[0P2TY:@20;>c/`80_kno0P3AdM420=KFeQD0oooo000C
0?ooo`80alO71038b<P40<O7a`80b/[:0P35aLD20<O7a`030<_;b`35aLD0aLG50080bl_;0P3EeMD2
0=?Cd`80_[jn0P2TY:@20:NWY`80/;2`0P2e]KD20;:b/P80]kNg0P2d];@20;>c/`80_[jn0P3?cll0
0`2FUYH0M7Ad07AdM0020;Rh^080/;2`0P2[Zj/20::RXP80Xj>S0P2/[:`40;:b/P80/k>c1P2_[jl2
0:^[Z`80YZJV00<0[:b/0;Jf]P2f][H00P2c/k<20:n_[`80Zj^[0P2YZJT20:FUY@@0YjNW102QXJ42
0:JVYP80/;2`0P2c/k<20;2`/080/[:b00<0/k>c0:n_[`2_[jl00P2`/;060:n_[`80/;2`0P2_[jl2
0;6a/@80][Jf0P2d];@20;2`/080[jn_0P2b/[820:^[Z`80[Jf]0`2[Zj/60:n_[`@0[Zj^302_[jl2
0;:b/P80aLG50P3Cdm<00`2?Shl0M7Ad07AdM0020;bl_080Y:BT0P2XZ:P20:f][@80ZJVY0P2TY:@2
0:FUY@80ZZZZ0P2TY:@20:RXZ080/[:b0P2d];@20;Jf]P80];Bd00<0][Jf0;Bd]02d];@0102d];@2
0;Zj^P80^k^k0P2j^[X20;6a/@80/k>c102^[Zh20:^[Z`80ZZZZ0P2RXZ820;>c/`<0]kNg0P3?cll2
0:^[Z`80Y:BT0P2c/k<20;no_`80dM7A0P3Fe]HE0?ooo`004`3oool20<c<c0@0bl_;0P3AdM420<o?
c`80b/[:0P3De=@20<o?c`030<c<c03AdM40dM7A0080cLg=0P36a/H20<O7a`80bLW90P34a<@20;jn
_P80ZZZZ0P2/[:`20;6a/@80Zj^[0P2_[jl20:f][@80[jn_0P2g]kL00`2n_[h0XJ6Q0:6QX@020:JV
YP80[:b/0P2][Jd80:RXZ080Y:BT0P2/[:`20;>c/`80/;2`0P2_[jl20:ZZZP80Y:BT00<0Z:RX0:n_
[`2_[jl00P2_[jl20;:b/P80[jn_0P2/[:`20:ZZZP80XJ6Q0P2OWil20:>SX`80XJ6Q0P2PX:020:FU
Y@80[:b/0P2b/[820:j^[PD0];Bd0P2_[jl40:j^[P80/K6a0P2j^[X20;no_`80][Jf0P2j^[X20;fm
_@80^;Rh0P2c/k<20;Rh^080/k>c00<0^;Rh0;:b/P2b/[800P2^[Zh20;2`/0@0[Zj^0P2`/;020:n_
[`80[Zj^102][Jd20:n_[`80[Jf]0P2_[jl20;:b/P80aLG500<0dm?C09RHV02HV9P00P2BTY820;Vi
^@80[jn_102][Jd20:n_[`80/k>c0P2_[jl20;2`/080[Zj^0P2_[jl20;6a/@80[jn_0`2`/;020;Bd
]080]kNg102j^[X20;Ng]`80]KFe0P2g]kL20:f][@80[:b/0P2a/K440:VYZ@80_Kfm0P2_[jl20;Fe
]@030;6a/@2[Zj/0Zj^[0080/K6a0P2][Jd20;Ng]`80`l?30P2m_Kd20<G5aAD0oooo000C0?ooo`80
c<c<103;bl/20=7Ad@80clo?0P3:b/X20=CDe080clo?00<0c<c<0=7Ad@3AdM400P3=cLd20<K6aP80
alO70P39bLT20<C4a080_[jn0P2ZZZX20:b/[080/K6a0P2[Zj/20:n_[`80[Jf]0P2_[jl20;Ng]`03
0;jn_P2QXJ40XJ6Q0080YZJV0P2/[:`20:f][@P0Z:RX0P2TY:@20:b/[080/k>c0P2`/;020:n_[`80
ZZZZ0P2TY:@00`2XZ:P0[jn_0:n_[`020:n_[`80/[:b0P2_[jl20:b/[080ZZZZ0P2QXJ4209nOW`80
Xj>S0P2QXJ420:2PX080YJFU0P2/[:`20;:b/P80[Zj^1@2d];@20:n_[`@0[Zj^0P2a/K420;Zj^P80
_kno0P2f][H20;Zj^P80_Kfm0P2h^;P20;>c/`80^;Rh0P2c/k<00`2h^;P0/[:b0;:b/P020:j^[P80
/;2`102^[Zh20;2`/080[jn_0P2^[Zh40:f][@80[jn_0P2][Jd20:n_[`80/[:b0P35aLD00`3Cdm<0
V9RH09RHV00209:BTP80^KVi0P2_[jl40:f][@80[jn_0P2c/k<20:n_[`80/;2`0P2^[Zh20:n_[`80
/K6a0P2_[jl30;2`/080];Bd0P2g]kL40;Zj^P80]kNg0P2e]KD20;Ng]`80[Jf]0P2/[:`20;6a/@@0
ZJVY0P2m_Kd20:n_[`80]KFe00<0/K6a0:^[Z`2[Zj/00P2a/K420:f][@80]kNg0P33`l<20;fm_@80
aLG55@3oool001<0oooo0P3;bl/40<c<c080cLg=0P3@d=020=?Cd`80c/k>0`3;bl/20=KFeP@0e=CD
0P3Bd]820<[:bP80cLg=0P39bLT20;bl_080Zj^[0P2_[jl20;>c/`80[Zj^102`/;020<71`@030=;B
dP2/[:`0[:b/0080TI6A0P2`/;020:n_[`80[:b/102UYJD20:b/[080[jn_0P2TY:@20:VYZ@@0[Zj^
0P2c/k<20;:b/P030:n_[`2b/[80/[:b0080/[:b102YZJT20:f][@H0[jn_0P2^[Zh20:^[Z`80XZ:R
0P2OWil20:RXZ080[Zj^0P2_[jl00`2SXj<0YZJV0:JVYP020:FUY@80/k>c0P2`/;060:n_[`80/k>c
0P2f][H20:f][@80/[:b0P2m_Kd20;^k^`80/K6a0P2e]KD00`2c/k<0]KFe0;Fe]@020:j^[P80[jn_
0P2c/k<20;:b/P80[Jf]0P2`/;020;Jf]P@0];Bd0P2b/[820;Bd]080[jn_0P2][Jd20;:b/P030<G5
a@2j^[X0^[Zj0080Q8B40P2SXj<20;^k^`80][Jf0P2c/k<20;2`/080[Jf]102_[jl20;Bd]0@0/[:b
0P2d];@20;Fe]@<0];Bd0P2j^[X20;jn_P@0^[Zj0P2g]kL20;Fe]@80^;Rh0P2e]KD20;Vi^@80`l?3
0P39bLT20<71`@80dm?C0`3=cLd20;Vi^@80[jn_0P2VYZH20:ZZZP80alO70P3@d=020<W9bAD0oooo
000C0?ooo`80bl_;103<c<`20<g=c@80d=3@0P3Cdm<20<k>cP<0bl_;0P3Fe]H40=CDe080d];B0P3:
b/X20<g=c@80bLW90P2l_;`20:^[Z`80[jn_0P2c/k<20:j^[P@0/;2`0P31`L400`3Bd]80[:b/0:b/
[002096AT@80/;2`0P2_[jl20:b/[0@0YJFU0P2/[:`20:n_[`80Y:BT0P2YZJT40:j^[P80/k>c0P2b
/[800`2_[jl0/[:b0;:b/P020;:b/P@0ZJVY0P2][Jd60:n_[`80[Zj^0P2[Zj/20::RXP80WinO0P2X
Z:P20:j^[P80[jn_00<0Xj>S0:JVYP2VYZH00P2UYJD20;>c/`80/;2`1P2_[jl20;>c/`80][Jf0P2]
[Jd20;:b/P80_Kfm0P2k^k/20;6a/@80]KFe00<0/k>c0;Fe]@2e]KD00P2^[Zh20:n_[`80/k>c0P2b
/[820:f][@80/;2`0P2f][H40;Bd]080/[:b0P2d];@20:n_[`80[Jf]0P2b/[800`35aLD0^[Zj0;Zj
^P0208B4Q080Xj>S0P2k^k/20;Jf]P80/k>c0P2`/;020:f][@@0[jn_0P2d];@40;:b/P80];Bd0P2e
]KD30;Bd]080^[Zj0P2n_[h40;Zj^P80]kNg0P2e]KD20;Rh^080]KFe0P2i^KT20<?3``80bLW90P31
`L420=?Cd`<0cLg=0P2i^KT20:n_[`80YZJV0P2ZZZX20<O7a`80d=3@0P39bLTE0?ooo`004`3oool4
0<_;b`80alO70P35aLD20<W9b@80bl_;0P39bLT20=;BdP030<o?c`38b<P0b<S80080bl_;0P3<c<`2
0<S8b0@0d];B0P3<c<`20<k>cP80_kno0P2YZJT20:NWY`80/[:b102`/;020;6a/@030;^k^`3<c<`0
c<c<0080];Bd0P2/[:`20;Jf]P80/;2`0P2ZZZX20:NWY`80YJFU0P2YZJT40;6a/@80/k>c0P2_[jl2
0:RXZ080[Jf]00<0];Bd0:RXZ02XZ:P00P2WYjL20:f][@80ZJVY0P2^[Zh20:n_[`80[Zj^1P2/[:`2
0:f][@80YZJV0P2OWil209fMW@80YjNW00<0YZJV0:NWY`2WYjL00P2][Jd20:j^[P@0/k>c0P2e]KD4
0;2`/080/K6a0P2f][H20;Rh^080][Jf0P2b/[870;Ng]`80^KVi0P2h^;P20;Jf]P80];Bd0P2g]kL2
0;Bd]080/[:b0P2d];@60;2`/080/K6a0P2d];@20:n_[`030;:b/P37alL0alO70080_kno0P2:RXX2
09JFUP80/k>c0P2g]kL20;Jf]P80];Bd102c/k<60;Jf]P80]kNg0`2e]KD20;>c/`@0]KFe0P2j^[X2
0;Vi^@80_Kfm102b/[820;Bd]080[Zj^0P2g]kL20<g=c@80^k^k0P2c/k<20;Fe]@030:j^[P30`<00
`<300080_[jn0P2`/;020;Zj^P@0cLg=0P38b<PE0?ooo`004`3oool40<_;b`80alO70P35aLD20<W9
b@80bl_;0P39bLT20=;BdP030<o?c`38b<P0b<S80080bl_;0P3<c<`20<S8b0@0d];B0P3<c<`20<k>
cP80_kno0P2YZJT20:NWY`80/[:b102`/;020;6a/@030;^k^`3<c<`0c<c<0080];Bd0P2/[:`20;Jf
]P80/;2`0P2ZZZX20:NWY`80YJFU0P2YZJT40;6a/@80/k>c0P2_[jl20:RXZ080[Jf]00<0];Bd0:RX
Z02XZ:P00P2WYjL20:f][@80ZJVY0P2^[Zh20:n_[`80[Zj^1P2/[:`20:f][@80YZJV0P2OWil209fM
W@80YjNW00<0YZJV0:NWY`2WYjL00P2][Jd20:j^[P@0/k>c0P2e]KD40;2`/080/K6a0P2f][H20;Rh
^080][Jf0P2b/[870;Ng]`80^KVi0P2h^;P20;Jf]P80];Bd0P2g]kL20;Bd]080/[:b0P2d];@60;2`
/080/K6a0P2d];@20:n_[`030;:b/P37alL0alO70080_kno0P2:RXX209JFUP80/k>c0P2g]kL20;Jf
]P80];Bd102c/k<60;Jf]P80]kNg0`2e]KD20;>c/`@0]KFe0P2j^[X20;Vi^@80_Kfm102b/[820;Bd
]080[Zj^0P2g]kL20<g=c@80^k^k0P2c/k<20;Fe]@030:j^[P30`<00`<300080_[jn0P2`/;020;Zj
^P@0cLg=0P38b<PE0?ooo`004`3oool20<_;b`80clo?0P3EeMD20=CDe080clo?0P3;bl/20<c<c080
b<S800<0b/[:0=7Ad@3AdM400P3AdM420<k>cP80e]KF0P3AdM420<[:bP80dm?C103AdM420<k>cP80
_kno0P2^[Zh20;Fe]@80][Jf0P2e]KD00`2g]kL0`l?30<?3``020<S8b080ZJVY0P2SXj<20=7Ad@80
];Bd0P2b/[840:f][@@0Z:RX0P2WYjL20:JVYP80ZZZZ0P2RXZ800`2MWId0XZ:R0::RXP020::RXP80
YJFU0P2WYjL20:VYZ@80/k>c0P2b/[820;Jf]P@0/k>c0P2e]KD20;:b/P80[Zj^0P2WYjL20:FUY@03
0:^[Z`2ZZZX0ZZZZ0080ZJVY0P2VYZH20:NWY`80ZJVY0P2[Zj/20;Bd]080]KFe0P2c/k<20;Fe]@80
]kNg0P2_[jl40;>c/`80/[:b00<0];Bd0;2`/02`/;000P2c/k<20;:b/P80]kNg0P2h^;P20;:b/P80
/K6a0P2`/;080;>c/`80/[:b0P2a/K420;>c/`030:j^[P2g]kL0]kNg0080clo?0P3AdM420;:b/P80
[Zj^102`/;020:n_[`80/K6a0P2e]KD20;Jf]P80]kNg102e]KD20;Jf]P030;Bd]02g]kL0]kNg0080
^;Rh0P2m_Kd20;bl_080^KVi0P2[Zj/20;6a/@80W9bL0P2QXJ420;Jf]P@0alO70P3Bd]820;Bd]080
]KFe00<0^k^k0:n_[`2_[jl00P2^[Zh20;Jf]P80b/[:0P3<c<`20=3@d080dM7A5@3oool001<0oooo
0P3;bl/20<o?c`80eMGE0P3De=@20<o?c`80bl_;0P3<c<`20<S8b0030<[:bP3AdM40dM7A0080dM7A
0P3>c/h20=KFeP80dM7A0P3:b/X20=?Cd`@0dM7A0P3>c/h20;no_`80[Zj^0P2e]KD20;Jf]P80]KFe
00<0]kNg0<?3``33`l<00P38b<P20:VYZ@80Xj>S0P3AdM420;Bd]080/[:b102][Jd40:RXZ080YjNW
0P2VYZH20:ZZZP80XZ:R00<0WIfM0::RXP2RXZ800P2RXZ820:FUY@80YjNW0P2YZJT20;>c/`80/[:b
0P2f][H40;>c/`80]KFe0P2b/[820:j^[P80YjNW0P2UYJD00`2[Zj/0ZZZZ0:ZZZP020:VYZ@80YZJV
0P2WYjL20:VYZ@80Zj^[0P2d];@20;Fe]@80/k>c0P2e]KD20;Ng]`80[jn_102c/k<20;:b/P030;Bd
]02`/;00/;2`0080/k>c0P2b/[820;Ng]`80^;Rh0P2b/[820;6a/@80/;2`202c/k<20;:b/P80/K6a
0P2c/k<00`2^[Zh0]kNg0;Ng]`020<o?c`80dM7A0P2b/[820:j^[P@0/;2`0P2_[jl20;6a/@80]KFe
0P2f][H20;Ng]`@0]KFe0P2f][H00`2d];@0]kNg0;Ng]`020;Rh^080_Kfm0P2l_;`20;Vi^@80Zj^[
0P2a/K4209bLW080XJ6Q0P2f][H40<O7a`80d];B0P2d];@20;Fe]@030;^k^`2_[jl0[jn_0080[Zj^
0P2f][H20<[:bP80c<c<0P3@d=020=7AdAD0oooo000C0?ooo`80bl_;0P3:b/X20<W9b@80cLg=0P39
bLT20<c<c080clo?0`3AdM420<W9b@80alO70P35aLD20<W9b@80clo?0P3Cdm<20<g=c@80dm?C0P3A
dM420<o?c`80c<c<0P30`<020;Ng]`80/k>c0P2f][H00`2d];@0[Zj^0:j^[P020;Rh^080_[jn0P27
QhL207]kN`80^k^k0P2a/K420:^[Z`80YJFU102XZ:P20:NWY`80Xj>S0P2GUiL209jNWP<0X:2P0P2O
Wil409bLW080XZ:R0P2_[jl40;:b/P@0/k>c0P2e]KD20;Bd]080Zj^[0P2WYjL209nOW`030::RXP2O
Wil0WinO0080W9bL102UYJD60:2PX080YZJV0P2YZJT20:f][@80/;2`0P2a/K420:n_[`80[Jf]0P2^
[Zh00`2`/;00/K6a0;6a/@020;>c/`80]KFe0P2b/[820:n_[`80]KFe0P2f][H20;:b/P@0[Jf]0P2^
[Zh20:RXZ080Zj^[0P2XZ:P20:b/[0030:j^[P2ZZZX0ZZZZ0080];Bd0P36a/H20=7Ad@80ZZZZ0P2X
Z:P20:j^[P80`l?30P2i^KT20;>c/`80][Jf0P2h^;P20;Vi^@80]kNg0P2h^;P00`2n_[h0^k^k0;^k
^`020;:b/P80]KFe0P2ZZZX20;Ng]`80YjNW0P2?Shl209JFUP80XZ:R0P2n_[h20;Rh^080Xj>S0P2L
W9`20:b/[080[Jf]00<0Xj>S0;Fe]@2e]KD00P2][Jd20:^[Z`80bLW90P3<c<`20<S8b080c<c<5@3o
ool001<0oooo0P35aLD20<[:bP80clo?0P3;bl/20=CDe080dM7A0P3=cLd20<O7a`030<_;b`3=cLd0
cLg=0080d];B0P3Cdm<20<g=c@80b/[:0P3<c<`20<o?c`80dM7A0P3Fe]H40<k>cP80cLg=0P3<c<`2
0<o?c`80cLg=00<0d=3@0=7Ad@3AdM400P3AdM420<g=c@80c<c<0P2^[Zh209BDU080Zj^[0P31`L42
0:BTY080YjNW0P2^[Zh20:FUY@@0Xj>S0P2TY:@00`2ZZZX0[Zj^0:j^[P020;2`/080/[:b0P2^[Zh2
0:FUY@80YZJV0P2][Jd20;6a/@80][Jf0P2b/[840;>c/`80][Jf0P2c/k<20:RXZ0030:FUY@2/[:`0
[:b/0080[:b/0P2UYJD20:JVYP80ZJVY0P2TY:@20:6QX@80W9bL0P2KVi/209:BTP80UIFE102BTY82
09RHV080UYJF00<0V9RH09FEU@2EUID00P2CTi<209JFUP80V9RH0P2IVIT209JFUP80UiNG1P2FUYH2
09RHV080XJ6Q0P2VYZH40:>SX`030:6QX@2PX:00X:2P0080WinO0P2QXJ420:>SX`80^[Zj0P2VYZH2
07inOP@0NGUi0P3Cdm<20:f][@80^KVi102c/k<20;Rh^0030;Fe]@2a/K40/K6a0080^KVi0P2f][H2
0:ZZZP@0T92@102GUiL209bLW080X:2P0P2a/K420:f][@80XJ6Q0P2RXZ820;^k^`030;Vi^@2XZ:P0
Z:RX0080^;Rh0P2l_;`20<c<c080bl_;0P3:b/X20<C4a1D0oooo000C0?ooo`80aLG50P3:b/X20<o?
c`80bl_;0P3De=@20=7Ad@80cLg=0P37alL00`3;bl/0cLg=0<g=c@020=;BdP80dm?C0P3=cLd20<[:
bP80c<c<0P3?cll20=7Ad@80e]KF103>c/h20<g=c@80c<c<0P3?cll20<g=c@030=3@d03AdM40dM7A
0080dM7A0P3=cLd20<c<c080[Zj^0P2DU9@20:^[Z`80`L710P2TY:@20:NWY`80[Zj^0P2UYJD40:>S
X`80Y:BT00<0ZZZZ0:j^[P2^[Zh00P2`/;020;:b/P80[Zj^0P2UYJD20:JVYP80[Jf]0P2a/K420;Jf
]P80/[:b102c/k<20;Jf]P80/k>c0P2XZ:P00`2UYJD0[:b/0:b/[0020:b/[080YJFU0P2VYZH20:VY
Z@80Y:BT0P2QXJ4209bLW080Vi^K0P2BTY8209FEU@@0TY:B0P2HV9P209JFUP0309RHV02EUID0UIFE
0080Ti>C0P2FUYH209RHV080VIVI0P2FUYH209NGU`H0UYJF0P2HV9P20:6QX@80YZJV102SXj<00`2Q
XJ40X:2P0:2PX00209nOW`80XJ6Q0P2SXj<20;Zj^P80YZJV0P1nOWh407UiN@80dm?C0P2][Jd20;Vi
^@@0/k>c0P2h^;P00`2e]KD0/K6a0;6a/@020;Vi^@80][Jf0P2ZZZX4092@T0@0UiNG0P2LW9`20:2P
X080/K6a0P2][Jd20:6QX@80XZ:R0P2k^k/00`2i^KT0Z:RX0:RXZ0020;Rh^080_;bl0P3<c<`20<_;
b`80b/[:0P34a<@E0?ooo`004`3oool20=OGe`80e=CD0P3@d=020<k>cP80clo?0P3De=@20=OGe`80
dm?C00<0cLg=0<[:bP3:b/X00P36a/H20<c<c080b<S80P36a/H20<_;b`80d=3@0P38b<P20<_;b`80
cLg=0P3<c<`60<o?c`<0cLg=0P3Bd]820<g=c@80bLW90P3?cll20=3@d080];Bd0P2GUiL20:JVYP80
^KVi0P2YZJT20:>SX`@0Z:RX0P2SXj<209bLW00309VIV@2NWYh0WYjN0080YJFU0P2XZ:P20:VYZ@@0
YJFU0P2/[:`20:n_[`80/[:b0P2i^KT20;Ng]`80][Jf0P2a/K420:f][@80ZZZZ00<0YZJV0:VYZ@2Y
ZJT0102YZJT20:^[Z`80ZJVY102_[jl20:^[Z`80ZJVY0P2^[Zh20:b/[080YJFU0P2QXJ4209nOW`D0
XJ6Q0P2RXZ820:BTY080WIfM0P2PX:020:RXZ080YjNW1P2XZ:P20:n_[`80Z:RX0P2SXj<20:j^[P80
/[:b1@2[Zj/20:BTY080YJFU0P2ZZZX20;Jf]P80]KFe0P2`/;0207=cL`80BTY:0P2DU9@209fMW@80
/K6a0P2m_Kd20:^[Z`030:JVYP2FUYH0UYJF0080MWIf0P1hN7P207inOP80Rh^;0P2YZJT40:JVYP80
X:2P0P2GUiL20:RXZ0@0[jn_0P2`/;0209bLW0030;Fe]@2`/;00/;2`0080W9bL0P37alL20;fm_@80
d=3@103Bd]8E0?ooo`004`3oool20=OGe`80e=CD0P3@d=020<k>cP80clo?0P3De=@20=OGe`80dm?C
00<0cLg=0<[:bP3:b/X00P36a/H20<c<c080b<S80P36a/H20<_;b`80d=3@0P38b<P20<_;b`80cLg=
0P3<c<`60<o?c`<0cLg=0P3Bd]820<g=c@80bLW90P3?cll20=3@d080];Bd0P2GUiL20:JVYP80^KVi
0P2YZJT20:>SX`@0Z:RX0P2SXj<209bLW00309VIV@2NWYh0WYjN0080YJFU0P2XZ:P20:VYZ@@0YJFU
0P2/[:`20:n_[`80/[:b0P2i^KT20;Ng]`80][Jf0P2a/K420:f][@80ZZZZ00<0YZJV0:VYZ@2YZJT0
102YZJT20:^[Z`80ZJVY102_[jl20:^[Z`80ZJVY0P2^[Zh20:b/[080YJFU0P2QXJ4209nOW`D0XJ6Q
0P2RXZ820:BTY080WIfM0P2PX:020:RXZ080YjNW1P2XZ:P20:n_[`80Z:RX0P2SXj<20:j^[P80/[:b
1@2[Zj/20:BTY080YJFU0P2ZZZX20;Jf]P80]KFe0P2`/;0207=cL`80BTY:0P2DU9@209fMW@80/K6a
0P2m_Kd20:^[Z`030:JVYP2FUYH0UYJF0080MWIf0P1hN7P207inOP80Rh^;0P2YZJT40:JVYP80X:2P
0P2GUiL20:RXZ0@0[jn_0P2`/;0209bLW0030;Fe]@2`/;00/;2`0080W9bL0P37alL20;fm_@80d=3@
103Bd]8E0?ooo`004`3oool20<?3``80aLG50P3?cll20=3@d080b<S80P3;bl/20<C4a080b<S800<0
clo?0=7Ad@3AdM400P3?cll20<K6aP80clo?103Bd]820<[:bP80c/k>0P3?cll20=7Ad@80cLg=0P3B
d]820<c<c080cLg=0P37alL00`3:b/X0cLg=0<g=c@020<o?c`80dm?C103=cLd20;Vi^@80UIFE0P25
QHD20:BTY080VYZJ0P2NWYh20;Rh^080YjNW0P2VYZH20:ZZZPD0Xj>S0P2XZ:P20:f][@80YJFU0P2S
Xj<20:^[Z`H0[jn_0P2b/[820;Jf]P80/k>c0P2f][H20;6a/@030:^[Z`2VYZH0YZJV0080[:b/0P2b
/[8:0:n_[`80Zj^[0P2TY:@20:FUY@80/k>c0P2a/K420;:b/P80Zj^[0`2TY:@20:ZZZP80[:b/102a
/K420:VYZ@80YZJV0P2UYJD20:f][@H0[jn_102^[Zh20:b/[0030:^[Z`2][Jd0[Jf]0080[Zj^0P2c
/k<20:n_[`80Zj^[0P2XZ:P20:n_[`80];Bd0P2g]kL20;Zj^P80ZZZZ0P1mOGd206i^KP80L71`0P2;
Rh/00`24Q8@0N7Qh07QhN0020820P080NWYj0P22PX82092@T080VYZJ0P2_[jl209fMW@80[Jf]0P2_
[jl20;6a/@80/;2`0P2MWId20:RXZ080_[jn00<0];Bd0;6a/@2a/K400P2[Zj/20:f][@80alO70P34
a<@20<S8b080c<c<5@3oool001<0oooo0P33`l<20<G5a@80clo?0P3@d=020<S8b080bl_;0P34a<@2
0<S8b0030<o?c`3AdM40dM7A0080clo?0P36a/H20<o?c`@0d];B0P3:b/X20<k>cP80clo?0P3AdM42
0<g=c@80d];B0P3<c<`20<g=c@80alO700<0b/[:0<g=c@3=cLd00P3?cll20=?Cd`@0cLg=0P2i^KT2
09FEU@80QHF50P2TY:@209ZJVP80WYjN0P2h^;P20:NWY`80YZJV0P2ZZZX50:>SX`80Z:RX0P2][Jd2
0:FUY@80Xj>S0P2[Zj/60:n_[`80/[:b0P2f][H20;>c/`80][Jf0P2a/K400`2[Zj/0YZJV0:JVYP02
0:b/[080/[:b2P2_[jl20:^[Z`80Y:BT0P2UYJD20;>c/`80/K6a0P2b/[820:^[Z`<0Y:BT0P2ZZZX2
0:b/[0@0/K6a0P2YZJT20:JVYP80YJFU0P2][Jd60:n_[`@0[Zj^0P2/[:`00`2[Zj/0[Jf]0:f][@02
0:j^[P80/k>c0P2_[jl20:^[Z`80Z:RX0P2_[jl20;Bd]080]kNg0P2j^[X20:ZZZP80OGem0P1^KVh2
071`L080Rh^;00<0Q8B407QhN01hN7P00P20P80207YjNP80PX:20P2@T90209ZJVP80[jn_0P2MWId2
0:f][@80[jn_0P2a/K420;2`/080WIfM0P2XZ:P20;jn_P030;Bd]02a/K40/K6a0080Zj^[0P2][Jd2
0<O7a`80a<C40P38b<P20<c<c1D0oooo000C0?ooo`80e]KF0P3AdM420<K6aP80bl_;0P3Bd]820<k>
cP80d];B0P3?cll00`34a<@0a/K60<K6aP020<_;b`80d];B0P3<c<`40<g=c@80d=3@0P37alL20<W9
b@80c<c<0P3=cLd20<k>cP80dm?C103AdM400`3@d=00bl_;0<_;b`020<W9b@80alO70P3:b/X20<c<
c080^KVi0P2ZZZX209NGU`80QhN70P2QXJ4208J6QP80RXZ:0P38b<P20:^[Z`<0Xj>S0P2OWil20:JV
YP80YjNW0P2TY:@20:ZZZP80ZJVY0P2[Zj/60:n_[`80/;2`0P2b/[840;6a/@80/k>c00<0[jn_0:^[
Z`2[Zj/00P2VYZH20:VYZ@H0[jn_0P2^[Zh60:n_[`80ZJVY0P2UYJD20:VYZ@80[:b/0P2^[Zh00`2a
/K40[Jf]0:f][@020:BTY080ZJVY0P2XZ:P20:FUY@80[:b/0P2a/K420:f][@80ZJVY0P2_[jl20:j^
[P80[jn_0P2[Zj/20:b/[080ZJVY0`2[Zj/20:f][@80ZZZZ0P2_[jl20:j^[P80/[:b0P2^[Zh20:RX
Z080YjNW0P2`/;020;^k^`80[Jf]0P2UYJD209:BTP80HV9R00<0KFe]07]kN`1kNg/00P1mOGd207in
OP80RHV90P28R8P208Z:RP80R8R80P2KVi/20;>c/`80Z:RX0P2BTY820:FUY@80Xj>S0P2PX:020:j^
[P030;Bd]02a/K40/K6a0080bLW90P33`l<20<O7a`80c<c<0P35aLD20<[:bQD0oooo000C0?ooo`80
e]KF0P3AdM420<K6aP80bl_;0P3Bd]820<k>cP80d];B0P3?cll00`34a<@0a/K60<K6aP020<_;b`80
d];B0P3<c<`40<g=c@80d=3@0P37alL20<W9b@80c<c<0P3=cLd20<k>cP80dm?C103AdM400`3@d=00
bl_;0<_;b`020<W9b@80alO70P3:b/X20<c<c080^KVi0P2ZZZX209NGU`80QhN70P2QXJ4208J6QP80
RXZ:0P38b<P20:^[Z`<0Xj>S0P2OWil20:JVYP80YjNW0P2TY:@20:ZZZP80ZJVY0P2[Zj/60:n_[`80
/;2`0P2b/[840;6a/@80/k>c00<0[jn_0:^[Z`2[Zj/00P2VYZH20:VYZ@H0[jn_0P2^[Zh60:n_[`80
ZJVY0P2UYJD20:VYZ@80[:b/0P2^[Zh00`2a/K40[Jf]0:f][@020:BTY080ZJVY0P2XZ:P20:FUY@80
[:b/0P2a/K420:f][@80ZJVY0P2_[jl20:j^[P80[jn_0P2[Zj/20:b/[080ZJVY0`2[Zj/20:f][@80
ZZZZ0P2_[jl20:j^[P80/[:b0P2^[Zh20:RXZ080YjNW0P2`/;020;^k^`80[Jf]0P2UYJD209:BTP80
HV9R00<0KFe]07]kN`1kNg/00P1mOGd207inOP80RHV90P28R8P208Z:RP80R8R80P2KVi/20;>c/`80
Z:RX0P2BTY820:FUY@80Xj>S0P2PX:020:j^[P030;Bd]02a/K40/K6a0080bLW90P33`l<20<O7a`80
c<c<0P35aLD20<[:bQD0oooo000C0?ooo`80aLG50P3:b/X20=CDe080dM7A0P39bLT20<g=c@@0c/k>
00<0d];B0=KFeP3Fe]H0103>c/h40=;BdP80bLW90P3>c/h40=7Ad@@0d];B0P3:b/X20<c<c0@0d];B
00<0bLW90<[:bP3:b/X00P3=cLd20<c<c080alO70P3:b/X20;fm_@80YjNW0P2DU9@207moO`80TI6A
0P26QXH206][J`80JVYZ0P3;bl/20:JVYP030:NWY`2RXZ80XZ:R0080ZZZZ0P2YZJT20:RXZ080XZ:R
0P2SXj<20:^[Z`P0[jn_0P2a/K420;>c/`L0[jn_0P2^[Zh60;6a/@80/[:b0P2_[jl20;:b/P@0[jn_
0P2[Zj/40:VYZ@80[:b/0P2^[Zh00`2YZJT0[Jf]0:f][@020:j^[P80YZJV0P2UYJD40:VYZ@@0Z:RX
0P2[Zj/20;:b/P80[jn_0P2b/[820:b/[080Z:RX0P2_[jl00`2[Zj/0ZJVY0:VYZ@020:ZZZP80[:b/
0P2a/K420:f][@80Zj^[0P2WYjL20:b/[080Xj>S0P2JVYX208V9R@80Ph>30P1fMWH2071`L080M7Ad
00<0Lg=c06m_K`1_Kfl00P1jNWX208f=S@80Ph>30P2:RXX208f=S@80VYZJ0P2LW9`209jNWP80YJFU
0P2MWId20:6QX@80YjNW0P2QXJ420;Ng]`030;2`/02g]kL0]kNg0080`L710P3;bl/20<S8b080alO7
0P3De=@20=;BdQD0oooo000C0?ooo`80aLG50P3:b/X20=CDe080dM7A0P39bLT20<g=c@@0c/k>00<0
d];B0=KFeP3Fe]H0103>c/h40=;BdP80bLW90P3>c/h40=7Ad@@0d];B0P3:b/X20<c<c0@0d];B00<0
bLW90<[:bP3:b/X00P3=cLd20<c<c080alO70P3:b/X20;fm_@80YjNW0P2DU9@207moO`80TI6A0P26
QXH206][J`80JVYZ0P3;bl/20:JVYP030:NWY`2RXZ80XZ:R0080ZZZZ0P2YZJT20:RXZ080XZ:R0P2S
Xj<20:^[Z`P0[jn_0P2a/K420;>c/`L0[jn_0P2^[Zh60;6a/@80/[:b0P2_[jl20;:b/P@0[jn_0P2[
Zj/40:VYZ@80[:b/0P2^[Zh00`2YZJT0[Jf]0:f][@020:j^[P80YZJV0P2UYJD40:VYZ@@0Z:RX0P2[
Zj/20;:b/P80[jn_0P2b/[820:b/[080Z:RX0P2_[jl00`2[Zj/0ZJVY0:VYZ@020:ZZZP80[:b/0P2a
/K420:f][@80Zj^[0P2WYjL20:b/[080Xj>S0P2JVYX208V9R@80Ph>30P1fMWH2071`L080M7Ad00<0
Lg=c06m_K`1_Kfl00P1jNWX208f=S@80Ph>30P2:RXX208f=S@80VYZJ0P2LW9`209jNWP80YJFU0P2M
WId20:6QX@80YjNW0P2QXJ420;Ng]`030;2`/02g]kL0]kNg0080`L710P3;bl/20<S8b080alO70P3D
e=@20=;BdQD0oooo000C0?ooo`80e]KF0P3Cdm<20<_;b`80b<S80P3<c<`20<o?c`80cLg=0P3:b/X0
0`3=cLd0c<c<0<c<c0040<g=c@80dM7A0P3;bl/20=7Ad@80b/[:0P3Bd]820=GEe@80dM7A0P3;bl/2
0=3@d0@0d];B0P3:b/X00`3AdM40bLW90<W9b@020<G5a@80cLg=0P3AdM420<c<c0@0a<C40P2i^KT2
09NGU`80P8200P21PH4206UYJ@80F5QH0P1EEED20=3@d0030:FUY@2VYZH0YZJV0080WIfM0P2KVi/4
0:JVYP80ZJVY0P2/[:`20;:b/PP0[jn_0P2b/[870:n_[`80Zj^[102VYZH40:VYZ@80[Zj^0P2/[:`2
0;:b/P80[jn_0P2[Zj/40:JVYP80Zj^[0P2/[:`00`2XZ:P0YZJV0:JVYP020:JVYP80YjNW0P2[Zj/2
0:VYZ@80ZZZZ0P2[Zj/20:VYZ@80ZZZZ0P2_[jl20:ZZZP80YjNW0P2VYZH20:b/[080/k>c00<0Zj^[
0:FUY@2UYJD00P2WYjL20:VYZ@80ZZZZ0P2YZJT20:BTY080YZJV0P2JVYX209VIV@80Q8B40P1fMWH2
07=cL`80KFe]0P1fMWH208N7Q`0308J6QP1mOGd0OGem0080MgMg0P1mOGd208b<S080QhN70P2PX:02
09ZJVP80YjNW0P2VYZH209RHV080RHV90P2EUID209bLW080XZ:R0P2g]kL00`2`/;00]kNg0;Ng]`02
0<g=c@80bLW90P3>c/h20<g=c@80c/k>0P38b<PE0?ooo`004`3oool20=KFeP80dm?C0P3;bl/20<S8
b080c<c<0P3?cll20<g=c@80b/[:00<0cLg=0<c<c03<c<`0103=cLd20=7Ad@80bl_;0P3AdM420<[:
bP80d];B0P3EeMD20=7Ad@80bl_;0P3@d=040=;BdP80b/[:00<0dM7A0<W9b@39bLT00P35aLD20<g=
c@80dM7A0P3<c<`40<C4a080^KVi0P2GUiL20820P080PH610P1YJFT205QHF080EEEE0P3@d=000`2U
YJD0YZJV0:JVYP0209fMW@80Vi^K102VYZH20:VYZ@80[:b/0P2b/[880:n_[`80/[:b1`2_[jl20:^[
Z`@0YZJV102YZJT20:j^[P80[:b/0P2b/[820:n_[`80Zj^[102VYZH20:^[Z`80[:b/00<0Z:RX0:JV
YP2VYZH00P2VYZH20:NWY`80Zj^[0P2YZJT20:ZZZP80Zj^[0P2YZJT20:ZZZP80[jn_0P2ZZZX20:NW
Y`80YZJV0P2/[:`20;>c/`030:^[Z`2UYJD0YJFU0080YjNW0P2YZJT20:ZZZP80ZJVY0P2TY:@20:JV
YP80VYZJ0P2IVIT208B4Q080MWIf0P1cLg<206e]K@80MWIf0P27QhL00`26QXH0OGem07emO@0207Mg
M`80OGem0P2<S8`208N7Q`80X:2P0P2JVYX20:NWY`80YZJV0P2HV9P208V9R@80UIFE0P2LW9`20::R
XP80]kNg00<0/;2`0;Ng]`2g]kL00P3=cLd20<W9b@80c/k>0P3=cLd20<k>cP80b<S85@3oool001<0
oooo0P3:b/X20<c<c080dM7A0P3Cdm<40<c<c080d];B0P3GemL00`3Bd]80clo?0<o?c`020<k>cP80
b<S80P3;bl/20=3@d080bl_;0P3EeMD20=7Ad@80alO70P3;bl/20<W9b@80cLg=0P3@d=020<W9b@80
dm?C00<0c<c<0<_;b`3;bl/00P3Bd]820<[:bP80bl_;0P39bLT20<;2`P80_kno0P2n_[h209FEU@80
K6a/0P1hN7P206QXJ080E5AD0P10@40204m?C`030<O7a`2KVi/0Vi^K0080XZ:R0P2VYZH20:VYZ@80
YJFU0P2RXZ820:ZZZP80Z:RX1P2_[jl20:^[Z`80ZJVY0P2a/K420;:b/P030:n_[`2^[Zh0[Zj^00@0
/K6a0P2^[Zh20:b/[080/K6a0P2ZZZX40:VYZ@80[jn_0P2^[Zh20;6a/@80[:b/0P2RXZ820:JVYP03
0:b/[02ZZZX0ZZZZ0080[Jf]0P2WYjL20:FUY@80Z:RX0P2WYjL20:>SX`80[:b/0P2VYZH20:ZZZP80
[Zj^0P2/[:`20:j^[P80Z:RX0P2ZZZX00`2a/K40[Jf]0:f][@020:n_[`80[:b/102XZ:P20:FUY@80
WinO0P2BTY8207inOP80MGEe0P1nOWh2075aL@80NGUi0P1aLG4208F5Q@0308V9R@2>SXh0SXj>00@0
MgMg0P22PX8209:BTP80TI6A0P2JVYX409FEU@80X:2P0P2VYZH40:>SX`80]kNg0P2JVYX00`2e]KD0
c<c<0<c<c0020<o?c`80c/k>0P35aLD20<W9b@80c<c<0P3?cllE0?ooo`004`3oool20<[:bP80c<c<
0P3AdM420=?Cd`@0c<c<0P3Bd]820=OGe`030=;BdP3?cll0clo?0080c/k>0P38b<P20<_;b`80d=3@
0P3;bl/20=GEe@80dM7A0P37alL20<_;b`80bLW90P3=cLd20=3@d080bLW90P3Cdm<00`3<c<`0bl_;
0<_;b`020=;BdP80b/[:0P3;bl/20<W9b@80`/;20P2o_kl20;jn_P80UIFE0P1/K6`207QhN080J6QX
0P1DE5@20410@080Cdm?00<0alO709^KV`2KVi/00P2RXZ820:JVYP80ZJVY0P2UYJD20::RXP80ZZZZ
0P2XZ:P60:n_[`80Zj^[0P2YZJT20;6a/@80/[:b00<0[jn_0:j^[P2^[Zh0102a/K420:j^[P80[:b/
0P2a/K420:ZZZP@0ZJVY0P2_[jl20:j^[P80/K6a0P2/[:`20::RXP80YZJV00<0[:b/0:ZZZP2ZZZX0
0P2][Jd20:NWY`80YJFU0P2XZ:P20:NWY`80Xj>S0P2/[:`20:JVYP80ZZZZ0P2^[Zh20:b/[080[Zj^
0P2XZ:P20:ZZZP030;6a/@2][Jd0[Jf]0080[jn_0P2/[:`40:RXZ080YJFU0P2OWil209:BTP80OWin
0P1eMGD207inOP80LG5a0P1iNGT2075aL@80QHF500<0RHV908j>SP2>SXh0101gMgL208:2PP80TY:B
0P2ATI4209ZJVP@0UIFE0P2PX:020:JVYP@0Xj>S0P2g]kL209ZJVP030;Fe]@3<c<`0c<c<0080clo?
0P3>c/h20<G5a@80bLW90P3<c<`20<o?caD0oooo000C0?ooo`80cLg=0P3;bl/20<K6aP@0b/[:0P3;
bl/20=7Ad@80bLW900<0b<S80<W9b@39bLT00P3De=@20=?Cd`80c/k>0P3=cLd20<k>cP80bLW90P3:
b/X20<g=c@80c<c<0P3?cll20<c<c080c/k>0P3@d=020<O7a`030<k>cP3Bd]80d];B0080d=3@0P3B
d]820<g=c@80bLW90P32`/820;Zj^P80_;bl0P2OWil208Z:RP80MWIf0P1/K6`205QHF080AdM70P0l
?3`00`19BDT0d=3@0=3@d0020:2PX080WIfM0P2UYJD20:NWY`80YZJV0P2WYjL20;:b/P80[Zj^1P2a
/K420:n_[`80YZJV0P2/[:`00`2b/[80Zj^[0:^[Z`040:VYZ@80YZJV0P2WYjL20:>SX`80ZZZZ0P2^
[Zh40;6a/@80/;2`0P2VYZH20:VYZ@80ZZZZ0P2XZ:P00`2UYJD0YZJV0:JVYP020:JVYP80[:b/0P2]
[Jd20:RXZ080YjNW0P2TY:@20:>SX`80Zj^[102/[:`20:RXZ080/;2`0P2WYjL20;6a/@030:VYZ@2Q
XJ40XJ6Q0080V9RH0P2JVYX2096AT@80SHf=0P2<S8`208V9R@80LW9b0P1aLG4205aLG080IfMW0P22
PX8208f=S@80N7Qh0P1_Kfl00`21PH40Shn?08n?S`0409NGU`80Shn?0P1jNWX208F5Q@80SHf=0P2B
TY8209^KV`80WIfM0P2VYZH20;Jf]P80a<C40P2VYZH20:b/[0030;Vi^@35aLD0aLG50080bLW90P38
b<P40<[:bP@0c/k>5@3oool001<0oooo0P3=cLd20<_;b`80a/K6103:b/X20<_;b`80dM7A0P39bLT0
0`38b<P0bLW90<W9b@020=CDe080dm?C0P3>c/h20<g=c@80c/k>0P39bLT20<[:bP80cLg=0P3<c<`2
0<o?c`80c<c<0P3>c/h20=3@d080alO700<0c/k>0=;BdP3Bd]800P3@d=020=;BdP80cLg=0P39bLT2
0<;2`P80^[Zj0P2l_;`209nOW`80RXZ:0P1fMWH206a/K080F5QH0P17AdL203`l?00304U9B@3@d=00
d=3@0080X:2P0P2MWId20:FUY@80YjNW0P2VYZH20:NWY`80/[:b0P2^[Zh60;6a/@80[jn_0P2VYZH2
0:b/[0030;:b/P2[Zj/0Zj^[00@0ZJVY0P2VYZH20:NWY`80Xj>S0P2ZZZX20:j^[P@0/K6a0P2`/;02
0:JVYP80ZJVY0P2ZZZX20:RXZ0030:FUY@2VYZH0YZJV0080YZJV0P2/[:`20:f][@80Z:RX0P2WYjL2
0:BTY080Xj>S0P2[Zj/40:b/[080Z:RX0P2`/;020:NWY`80/K6a00<0ZJVY0:6QX@2QXJ400P2HV9P2
09ZJVP80TI6A0P2=SHd208b<S080RHV90P1bLW82075aL@80G5aL0P1WIfL208:2PP80SHf=0P1hN7P2
06m_K`030861P@2?Shl0Shn?00@0UiNG0P2?Shl207YjNP80QHF50P2=SHd209:BTP80Vi^K0P2MWId2
0:JVYP80][Jf0P34a<@20:JVYP80[:b/00<0^KVi0<G5a@35aLD00P39bLT20<S8b0@0b/[:103>c/hE
0?ooo`004`3oool20<O7a`80cLg=0P3Cdm<20<S8b080b/[:0P3>c/h20<_;b`80alO700<0c<c<0<o?
c`3?cll00P3>c/h20=3@d080clo?0P3@d=040=;BdP80e=CD0P3Cdm<20=3@d080c/k>0P38b<P20<O7
a`80c/k>0P3AdM400`39bLT0b/[:0<[:bP020<[:bP80cLg=0P3;bl/20<c<c080c/k>0P37alL20<?3
``80WYjN0P2>SXh207QhN080I6AT0P1FEUH204m?C`80@T9200<0=CDe02h^;P0^;Rh00P3Kfm/20:BT
Y080WIfM0P2YZJT20:FUY@80ZZZZ0P2][Jd20:n_[`H0ZJVY0P2/[:`20:^[Z`<0ZJVY0P2^[Zh20:VY
Z@80[:b/0P2^[Zh20:ZZZP80YjNW0P2SXj<20:VYZ@80[:b/0P2YZJT20:f][@80[Zj^0P2VYZH20::R
XP80XJ6Q0`2SXj<20:6QX@80Y:BT0P2XZ:P20:VYZ@80XJ6Q0P2RXZ8209jNWP80VYZJ0P2RXZ840:JV
YP80Xj>S0P2YZJT209fMW@030:VYZ@2SXj<0Xj>S0080VYZJ0P2EUID2096AT@80Q8B40P1nOWh207=c
L`80HV9R0P1JFUX206ATI080JFUY0P1mOGd608N7Q`0308f=S@2?Shl0Shn?00@0UIFE0P2ATI4209FE
U@80OWin0P29RHT209JFUP80VYZJ0P2KVi/20:JVYP80Z:RX0P2TY:@20::RXP80]kNg00<0bLW90;no
_`2o_kl00P2f][H20<C4a080bLW90P38b<P20<[:bP80dM7A5@3oool001<0oooo0P37alL20<g=c@80
dm?C0P38b<P20<[:bP80c/k>0P3;bl/20<O7a`030<c<c03?cll0clo?0080c/k>0P3@d=020<o?c`80
d=3@103Bd]820=CDe080dm?C0P3@d=020<k>cP80b<S80P37alL20<k>cP80dM7A00<0bLW90<[:bP3:
b/X00P3:b/X20<g=c@80bl_;0P3<c<`20<k>cP80alO70P33`l<209jNWP80SXj>0P1hN7P206ATI080
EUIF0P1?Cdl20492@P0303De=@0^;Rh0;Rh^0080fm_K0P2TY:@209fMW@80ZJVY0P2UYJD20:ZZZP80
[Jf]0P2_[jl60:VYZ@80[:b/0P2[Zj/30:VYZ@80[Zj^0P2YZJT20:b/[080[Zj^0P2ZZZX20:NWY`80
Xj>S0P2YZJT20:b/[080ZJVY0P2][Jd20:j^[P80YZJV0P2RXZ820:6QX@<0Xj>S0P2QXJ420:BTY080
Z:RX0P2YZJT20:6QX@80XZ:R0P2NWYh209ZJVP80XZ:R102VYZH20:>SX`80ZJVY0P2MWId00`2YZJT0
Xj>S0:>SX`0209ZJVP80UIFE0P2ATI4208B4Q080OWin0P1cLg<2069RHP80FUYJ0P1TI6@206UYJ@80
OGem1P27QhL00`2=SHd0Shn?08n?S`0409FEU@80TI6A0P2EUID207inOP80RHV90P2FUYH209ZJVP80
Vi^K0P2VYZH20:RXZ080Y:BT0P2RXZ820;Ng]`030<W9b@2o_kl0_kno0080][Jf0P34a<@20<W9b@80
b<S80P3:b/X20=7AdAD0oooo000C0?ooo`80cLg=0P3:b/X20<W9b@80dm?C0P3AdM420<c<c080bLW9
0P3EeMD00`3Cdm<0cLg=0<g=c@020<O7a`80cLg=0P3Bd]820<g=c@80b/[:0P35aLD20<S8b080aLG5
0P3:b/X20=CDe080eMGE0P3AdM420<g=c@80clo?00<0cLg=0<W9b@39bLT00P39bLT20<_;b`80cLg=
0P37alL20<30`080^[Zj0P2f][H209NGU`80O7al0P1hN7P206ATI080De=C0P1BDU8204U9B@03038b
<P0^;Rh0;Rh^0080:RXZ0P3Fe]H209fMW@@0X:2P0P2UYJD40:RXZ0H0ZJVY0P2/[:`20:n_[`80ZJVY
00<0Zj^[0:VYZ@2YZJT0102YZJT20:RXZ080YjNW0P2YZJT20:JVYP80Xj>S0P2UYJD20:BTY080YjNW
102ZZZX40:NWY`030:BTY02SXj<0Xj>S0080XJ6Q0P2LW9`209^KV`80XJ6Q0P2SXj<209jNWP@0YJFU
0P2RXZ820:^[Z`80W9bL0P2PX:0209jNWP80XZ:R00<0VIVI0:2PX02PX:000P2HV9P208b<S080Ng]k
0P1mOGd205EEE@80L71`101SHf<2079bLP80P8200P26QXH208>3P`80PX:20P2@T9000`28R8P0P820
0820P00207MgM`80O7al0P20P80208F5Q@80UYJF0P2DU9@209FEU@80UYJF0P2WYjL20:RXZ080Zj^[
0P2f][H20<_;b`80a<C400<0_Kfm0<O7a`37alL00P3<c<`20<_;b`80dm?C0P3AdM420=CDe080eMGE
5@3oool001<0oooo0P3=cLd20<[:bP80bLW90P3Cdm<20=7Ad@80c<c<0P39bLT20=GEe@030=?Cd`3=
cLd0cLg=0080alO70P3=cLd20=;BdP80cLg=0P3:b/X20<G5a@80b<S80P35aLD20<[:bP80e=CD0P3E
eMD20=7Ad@80cLg=0P3?cll00`3=cLd0bLW90<W9b@020<W9b@80bl_;0P3=cLd20<O7a`80`<300P2j
^[X20;Jf]P80UiNG0P1lO7`207QhN080I6AT0P1CDe<2059BDP80BDU900<0<S8b02h^;P0^;Rh00P0Z
:RX20=KFeP80WIfM102PX:020:FUY@@0Z:RX1P2YZJT20:b/[080[jn_0P2YZJT00`2[Zj/0ZJVY0:VY
Z@040:VYZ@80Z:RX0P2WYjL20:VYZ@80YZJV0P2SXj<20:FUY@80Y:BT0P2WYjL40:ZZZP@0YjNW00<0
Y:BT0:>SX`2SXj<00P2QXJ4209bLW080Vi^K0P2QXJ420:>SX`80WYjN102UYJD20::RXP80Zj^[0P2L
W9`20:2PX080WYjN0P2RXZ800`2IVIT0X:2P0:2PX00209RHV080S8b<0P1kNg/207emO@80EEEE0P1`
L70406=SH`80LW9b0P20P80208J6QP80Ph>30P22PX82092@T00308R8R020P800P8200080MgMg0P1l
O7`20820P080QHF50P2FUYH209BDU080UIFE0P2FUYH20:NWY`80Z:RX0P2[Zj/20;Jf]P80bl_;0P34
a<@00`2m_Kd0alO70<O7a`020<c<c080bl_;0P3Cdm<20=7Ad@80e=CD0P3EeMDE0?ooo`004`3oool2
0<?3``80b<S80P3?cll40=7Ad@80dm?C0P3=cLd20<O7a`030<g=c@3De=@0e=CD0080d];B0P3>c/h2
0<O7a`80a/K60P3AdM420=KFeP80e=CD0P3Cdm<20<k>cP80bLW90P3;bl/20<c<c080b/[:0P3AdM40
0`3Cdm<0c<c<0<c<c0020<[:bP80c<c<0P3;bl/20<c<c080bl_;0P2n_[h20;Rh^080WIfM0P1oOgl2
079bLP80JVYZ0P1KFe/204m?C`80@T9200<0<c<c02PX:00X:2P00P0b<S82069RHP80W9bL0P2RXZ82
0:RXZ080Xj>S0P2WYjL20:RXZ080ZZZZ0P2VYZH20:VYZ@80YZJV0P2/[:`20;6a/@030:j^[P2YZJT0
ZJVY0080ZJVY0P2/[:`40:VYZ@80Zj^[0P2WYjL20:RXZ080YjNW0P2YZJT40:NWY`80Z:RX0P2UYJD7
0::RXP80WIfM0P2NWYh20:2PX080WinO0P2JVYX209VIV@80WIfM0P2GUiL209jNWP80YJFU0P2KVi/2
09nOW`80WYjN00<0U9BD09FEU@2EUID00P2@T90208N7Q`80F5QH0P1UIFD205]KF`80EUIF0P1UIFD2
07YjNP80P8200P24Q8@208:2PP80QHF51027QhL00`2FUYH0Rh^;08^;R`0208V9R@80Ti>C0P2FUYH2
08f=S@80UiNG0P2JVYX209VIV@@0YjNW0P2XZ:P20:NWY`80]KFe0P2j^[X20;Rh^0030<71`@34a<@0
a<C40080bl_;0P3AdM440<o?c`80c<c<0P3:b/XE0?ooo`004`3oool20<?3``80b<S80P3?cll40=7A
d@80dm?C0P3=cLd20<O7a`030<g=c@3De=@0e=CD0080d];B0P3>c/h20<O7a`80a/K60P3AdM420=KF
eP80e=CD0P3Cdm<20<k>cP80bLW90P3;bl/20<c<c080b/[:0P3AdM400`3Cdm<0c<c<0<c<c0020<[:
bP80c<c<0P3;bl/20<c<c080bl_;0P2n_[h20;Rh^080WIfM0P1oOgl2079bLP80JVYZ0P1KFe/204m?
C`80@T9200<0<c<c02PX:00X:2P00P0b<S82069RHP80W9bL0P2RXZ820:RXZ080Xj>S0P2WYjL20:RX
Z080ZZZZ0P2VYZH20:VYZ@80YZJV0P2/[:`20;6a/@030:j^[P2YZJT0ZJVY0080ZJVY0P2/[:`40:VY
Z@80Zj^[0P2WYjL20:RXZ080YjNW0P2YZJT40:NWY`80Z:RX0P2UYJD70::RXP80WIfM0P2NWYh20:2P
X080WinO0P2JVYX209VIV@80WIfM0P2GUiL209jNWP80YJFU0P2KVi/209nOW`80WYjN00<0U9BD09FE
U@2EUID00P2@T90208N7Q`80F5QH0P1UIFD205]KF`80EUIF0P1UIFD207YjNP80P8200P24Q8@208:2
PP80QHF51027QhL00`2FUYH0Rh^;08^;R`0208V9R@80Ti>C0P2FUYH208f=S@80UiNG0P2JVYX209VI
V@@0YjNW0P2XZ:P20:NWY`80]KFe0P2j^[X20;Rh^0030<71`@34a<@0a<C40080bl_;0P3AdM440<o?
c`80c<c<0P3:b/XE0?ooo`004`3oool40=7Ad@80clo?0P3<c<`20=;BdP80d=3@0P3EeMD30=;BdP80
b/[:0P3<c<`20<W9b@80c<c<0P3=cLd20<O7a`80a/K6103=cLd20=CDe080d=3@0P3:b/X20<g=c@80
d];B0P3:b/X00`37alL0cLg=0<g=c@020=7Ad@80bLW90P3:b/X20<W9b@80a/K60P2o_kl20;Jf]P80
XJ6Q0P1oOgl2071`L080H61P0P1UIFD2055AD@80BDU900<0<c<c034a<@0a<C400P0h>3P205EEE@80
b<S80P2PX:020:>SX`80YjNW0P2TY:@20:RXZ0@0Zj^[0P2/[:`20:j^[PL0ZJVY0P2XZ:P20:FUY@80
ZZZZ0P2[Zj/20:VYZ@80YZJV0P2UYJD20:NWY`80Xj>S0P2PX:020:>SX`80Vi^K0P2WYjL20:>SX`03
0:2PX02OWil0WinO0080WYjN0P2KVi/209ZJVP80Ti>C0P2KVi/209ZJVP80UYJF0P2KVi/209jNWP80
W9bL0P2BTY8208f=S@80Ti>C0P2?Shl00`26QXH0Ph>308>3P`0207EeM@80LW9b0P1^KVh204m?C`80
HV9R0P1PH60206=SH`80I6AT0P1hN7P207emO@80O7al0P1mOGd208Z:RP80Rh^;00<0UiNG0:2PX02P
X:000P2IVIT209>CT`80W9bL0P2WYjL20:2PX080Vi^K0P2VYZH20:NWY`80Z:RX0P2WYjL20;>c/`80
/K6a0P2k^k/20<W9b@030<_;b`3Fe]H0e]KF0080dm?C0P39bLT20<g=c@80d=3@0P3<c<`20=7AdAD0
oooo000C0?ooo`@0dM7A0P3?cll20<c<c080d];B0P3@d=020=GEe@<0d];B0P3:b/X20<c<c080bLW9
0P3<c<`20<g=c@80alO70P36a/H40<g=c@80e=CD0P3@d=020<[:bP80cLg=0P3Bd]820<[:bP030<O7
a`3=cLd0cLg=0080dM7A0P39bLT20<[:bP80bLW90P36a/H20;no_`80][Jf0P2QXJ4207moO`80L71`
0P1PH60206EUI@80DE5A0P19BDT00`0c<c<0<C4a034a<@0203Ph>080EEEE0P38b<P20:2PX080Xj>S
0P2WYjL20:BTY080Z:RX102[Zj/20:b/[080[Zj^1`2YZJT20:RXZ080YJFU0P2ZZZX20:^[Z`80ZJVY
0P2VYZH20:FUY@80YjNW0P2SXj<20:2PX080Xj>S0P2KVi/20:NWY`80Xj>S00<0X:2P09nOW`2OWil0
0P2NWYh209^KV`80VYZJ0P2CTi<209^KV`80VYZJ0P2FUYH209^KV`80WYjN0P2LW9`209:BTP80SHf=
0P2CTi<208n?S`0308J6QP23Ph<0Ph>30080MGEe0P1bLW8206i^KP80Cdm?0P1RHV82061PH080Hf=S
0P1TI6@207QhN080OGem0P1lO7`207emO@80RXZ:0P2;Rh/00`2GUiL0X:2P0:2PX00209VIV@80Ti>C
0P2LW9`20:NWY`80X:2P0P2KVi/20:JVYP80YjNW0P2XZ:P20:NWY`80/k>c0P2a/K420;^k^`80bLW9
00<0bl_;0=KFeP3Fe]H00P3Cdm<20<W9b@80cLg=0P3@d=020<c<c080dM7A5@3oool001<0oooo0P3A
dM420<k>cP80bLW90P3;bl/20<W9b@@0cLg=0P3@d=000`3:b/X0c/k>0<k>cP040<[:bP80dM7A0P3>
c/h20<g=c@80d];B0P3=cLd20<o?c`80c/k>0P3=cLd20=;BdP80dM7A0P37alL20<k>cP030=?Cd`3?
cll0clo?0080d=3@0P3AdM420<c<c080c/k>0P3;bl/20;jn_P80YjNW0P29RHT208B4Q080L71`0P1Y
JFT205mOG`80De=C0P1>CTh00`0n?Sh0?Cdm03dm?@0203lo?`80=3@d0P2:RXX20:>SX`80YZJV0P2[
Zj/20:ZZZP80YjNW0P2[Zj/20:j^[P80[:b/0P2[Zj/20:VYZ@80[:b/00<0Zj^[0:RXZ02XZ:P00P2W
YjL20:VYZ@80YZJV0P2RXZ820:RXZ080ZZZZ0P2TY:@20:FUY@80YZJV0P2TY:@209fMW@80YZJV0P2J
VYX30:RXZ080Xj>S0P2NWYh209^KV`80UYJF0P2EUID208V9R@80UiNG0P2LW9`209VIV@80UiNG0P25
QHD408V9R@80QHF50P27QhL00`1hN7P0Ogmo07moO`0206YZJP80H61P0P1ZJVX207IfMP80K6a/0P1a
LG420861P@80QHF50P27QhL208B4Q080P8200P1lO7`209BDU080Ph>300<0QXJ608>3P`23Ph<00P2D
U9@208N7Q`80UYJF0P2<S8`2092@T0@0YZJV0P2WYjL20:ZZZP@0^;Rh0P34a<@20<S8b080clo?00<0
c/k>0<[:bP3:b/X00P38b<P20=7Ad@80clo?0P3=cLd20<c<c080c/k>5@3oool001<0oooo0P3AdM42
0<k>cP80bLW90P3;bl/20<W9b@@0cLg=0P3@d=000`3:b/X0c/k>0<k>cP040<[:bP80dM7A0P3>c/h2
0<g=c@80d];B0P3=cLd20<o?c`80c/k>0P3=cLd20=;BdP80dM7A0P37alL20<k>cP030=?Cd`3?cll0
clo?0080d=3@0P3AdM420<c<c080c/k>0P3;bl/20;jn_P80YjNW0P29RHT208B4Q080L71`0P1YJFT2
05mOG`80De=C0P1>CTh00`0n?Sh0?Cdm03dm?@0203lo?`80=3@d0P2:RXX20:>SX`80YZJV0P2[Zj/2
0:ZZZP80YjNW0P2[Zj/20:j^[P80[:b/0P2[Zj/20:VYZ@80[:b/00<0Zj^[0:RXZ02XZ:P00P2WYjL2
0:VYZ@80YZJV0P2RXZ820:RXZ080ZZZZ0P2TY:@20:FUY@80YZJV0P2TY:@209fMW@80YZJV0P2JVYX3
0:RXZ080Xj>S0P2NWYh209^KV`80UYJF0P2EUID208V9R@80UiNG0P2LW9`209VIV@80UiNG0P25QHD4
08V9R@80QHF50P27QhL00`1hN7P0Ogmo07moO`0206YZJP80H61P0P1ZJVX207IfMP80K6a/0P1aLG42
0861P@80QHF50P27QhL208B4Q080P8200P1lO7`209BDU080Ph>300<0QXJ608>3P`23Ph<00P2DU9@2
08N7Q`80UYJF0P2<S8`2092@T0@0YZJV0P2WYjL20:ZZZP@0^;Rh0P34a<@20<S8b080clo?00<0c/k>
0<[:bP3:b/X00P38b<P20=7Ad@80clo?0P3=cLd20<c<c080c/k>5@3oool001<0oooo0P3AdM420=;B
dP80dM7A0P3;bl/20=3@d080alO70P39bLT20<c<c0030=7Ad@3>c/h0c/k>0080cLg=1P3AdM420<g=
c@80bl_;0P3@d=020<g=c@80b<S80P3:b/X20<S8b080clo?0P3=cLd20<[:bP030<g=c@3Bd]80d];B
0080c<c<0P38b<P20<K6aP@0aLG50P2f][H20:^[Z`80QHF50P1gMgL2079bLP80IVIV0P1YJFT204m?
C`80CDe=00<0Bd];04E5A@15ADD00P0n?Sh202DU9@80NGUi0P2MWId20:ZZZP80[:b/0P2^[Zh20:JV
YP80Z:RX102VYZH20:VYZ@@0YZJV00<0ZJVY0:^[Z`2[Zj/00P2ZZZX40:JVYP80YJFU0P2SXj<20:NW
Y`80ZJVY0P2PX:020::RXP80Xj>S0P2UYJD20:2PX080Y:BT0P2KVi/00`2NWYh0Vi^K09^KV`0209NG
U`80UIFE102;Rh/409JFUP80XZ:R0P2KVi/208J6QP80SHf=0P2?Shl208N7Q`80NWYj0P1TI6@00`1/
K6`0Jf][06][J`0206a/K080IVIV0P1TI6@206a/K080M7Ad0P1bLW8207IfMP80Ph>30P27QhL208:2
PP80P8200P1gMgL207alO080TI6A00<0T92@09:BTP2BTY800P2EUID20:NWY`80T92@0P2NWYh20;2`
/0@0YZJV0P2YZJT20:6QX@80YjNW1P35aLD30<c<c080bl_;0P3AdM420=;BdP80dM7A0P3=cLd20=GE
e@80dM7A5@3oool001<0oooo0P3AdM420=;BdP80dM7A0P3;bl/20=3@d080alO70P39bLT20<c<c003
0=7Ad@3>c/h0c/k>0080cLg=1P3AdM420<g=c@80bl_;0P3@d=020<g=c@80b<S80P3:b/X20<S8b080
clo?0P3=cLd20<[:bP030<g=c@3Bd]80d];B0080c<c<0P38b<P20<K6aP@0aLG50P2f][H20:^[Z`80
QHF50P1gMgL2079bLP80IVIV0P1YJFT204m?C`80CDe=00<0Bd];04E5A@15ADD00P0n?Sh202DU9@80
NGUi0P2MWId20:ZZZP80[:b/0P2^[Zh20:JVYP80Z:RX102VYZH20:VYZ@@0YZJV00<0ZJVY0:^[Z`2[
Zj/00P2ZZZX40:JVYP80YJFU0P2SXj<20:NWY`80ZJVY0P2PX:020::RXP80Xj>S0P2UYJD20:2PX080
Y:BT0P2KVi/00`2NWYh0Vi^K09^KV`0209NGU`80UIFE102;Rh/409JFUP80XZ:R0P2KVi/208J6QP80
SHf=0P2?Shl208N7Q`80NWYj0P1TI6@00`1/K6`0Jf][06][J`0206a/K080IVIV0P1TI6@206a/K080
M7Ad0P1bLW8207IfMP80Ph>30P27QhL208:2PP80P8200P1gMgL207alO080TI6A00<0T92@09:BTP2B
TY800P2EUID20:NWY`80T92@0P2NWYh20;2`/0@0YZJV0P2YZJT20:6QX@80YjNW1P35aLD30<c<c080
bl_;0P3AdM420=;BdP80dM7A0P3=cLd20=GEe@80dM7A5@3oool001<0oooo0P3AdM420<g=c@80b/[:
103>c/h40=7Ad@80dm?C0`3AdM420<g=c@80dm?C103AdM420<k>cP80bLW90P3>c/h20=CDe080dM7A
0P3=cLd20<[:bP80b<S8103?cll00`3>c/h0b/[:0<[:bP020<[:bP80dM7A0P3>c/h20<S8b080aLG5
0P2`/;0209ZJVP80RXZ:0P1cLg<206QXJ080Hf=S0P1ADE4204i>CP80Cdm?00<0DE5A04e=C@1=CDd0
0P0o?cl203<c<`80I6AT0P2TY:@20:FUY@80Y:BT0P2WYjL20:b/[080YjNW0P2XZ:P20:>SX`80Y:BT
0P2YZJT20:BTY0030:>SX`2TY:@0Y:BT0080Z:RX0P2TY:@20:FUY@80ZZZZ0P2YZJT20:JVYP80YjNW
0P2TY:@20:JVYP80X:2P0P2JVYX209^KV`80VYZJ0P2OWil309bLW080VYZJ0P2<S8`208j>SP80Q8B4
0P2>SXh209bLW080TI6A0P22PX8207emO@80Ogmo0P1mOGd206i^KP80LG5a0P1TI6@00`1NGUh0MGEe
07EeM@0206a/K080IfMW0P1TI6@206QXJ080L71`0P1TI6@2075aL@80PH610P2:RXX208J6QP80Ogmo
0P1jNWX208V9R@80RXZ:00<0S8b<08f=S@2=SHd00P28R8P208n?S`80VYZJ0P2=SHd209JFUP80Xj>S
102VYZH20<71`@80bl_;0P32`/820<S8b080c/k>0P3EeMD00`3Cdm<0c<c<0<c<c0020=7Ad@80clo?
0P37alL20<S8b080b/[:0P3AdM4E0?ooo`004`3oool20=7Ad@80cLg=0P3:b/X40<k>cP@0dM7A0P3C
dm<30=7Ad@80cLg=0P3Cdm<40=7Ad@80c/k>0P39bLT20<k>cP80e=CD0P3AdM420<g=c@80b/[:0P38
b<P40<o?c`030<k>cP3:b/X0b/[:0080b/[:0P3AdM420<k>cP80b<S80P35aLD20;2`/080VYZJ0P2:
RXX207=cL`80J6QX0P1SHf<2055AD@80CTi>0P1?Cdl00`1ADE40CDe=04e=C@0203lo?`80<c<c0P1T
I6@20:BTY080YJFU0P2TY:@20:NWY`80[:b/0P2WYjL20:RXZ080Xj>S0P2TY:@20:VYZ@80Y:BT00<0
Xj>S0:BTY02TY:@00P2XZ:P20:BTY080YJFU0P2ZZZX20:VYZ@80YZJV0P2WYjL20:BTY080YZJV0P2P
X:0209ZJVP80Vi^K0P2JVYX209nOW`<0W9bL0P2JVYX208b<S080SXj>0P24Q8@208j>SP80W9bL0P2A
TI4208:2PP80OGem0P1oOgl207emO@80KVi^0P1aLG4206ATI00305iNGP1eMGD0MGEe0080K6a/0P1W
IfL206ATI080J6QX0P1`L70206ATI080LG5a0P21PH4208Z:RP80QXJ60P1oOgl207YjNP80RHV90P2:
RXX00`2<S8`0SHf=08f=S@0208R8R080Shn?0P2JVYX208f=S@80UYJF0P2SXj<40:JVYP80`L710P3;
bl/20<;2`P80b<S80P3>c/h20=GEe@030=?Cd`3<c<`0c<c<0080dM7A0P3?cll20<O7a`80b<S80P3:
b/X20=7AdAD0oooo000C0?ooo`@0dM7A0P3Cdm<20<g=c@80b/[:103AdM420<o?c`030<k>cP3=cLd0
cLg=0080dM7A0P3<c<`80=7Ad@80b/[:0P3=cLd20<c<c080bLW90P3=cLd20=?Cd`@0clo?00<0d=3@
0<g=c@3=cLd0103De=@20=7Ad@80alO70P2n_[h20:FUY@80T92@0P25QHD207EeM@80KFe]0P1XJ6P2
05MGE`80BTY:0P1CDe<00`1>CTh0?Shn03hn?P0203dm?@80<S8b0P1nOWh20:FUY@80ZZZZ0P2][Jd2
0:^[Z`80Y:BT0P2XZ:P20:FUY@80[:b/0P2][Jd20:FUY@80YZJV00<0ZJVY0:BTY02TY:@00P2QXJ42
0:VYZ@80Y:BT0P2MWId409nOW`80X:2P0P2VYZH209ZJVP80WinO0P2MWId209jNWP80W9bL0P2FUYH3
09FEU@80SXj>0P27QhL207inOP80RXZ:0P25QHD208R8R080Ogmo0P21PH4207UiN@80Ogmo0P1]KFd2
079bLP80GemO0P1SHf<00`1UIFD0MWIf07IfMP0208:2PP80Lg=c0P1[Jf/206YZJP80KVi^0P1mOGd2
07]kN`80MgMg0P28R8P208F5Q@80TY:B0P2DU9@208^;R`80Q8B400<0QhN708Z:RP2:RXX00P20P802
08f=S@80WIfM0P2WYjL20:b/[080Zj^[0P2UYJD20;>c/`80^KVi1037alL20<K6aP@0bLW900<0b<S8
0=7Ad@3AdM400P3?cll20=3@d080eMGE0P3De=@20=GEe@80dm?C5@3oool001<0oooo0P3AdM420<k>
cP80c<c<0P3AdM420=?Cd`80c/k>0P3:b/X20<o?c`030=7Ad@3>c/h0c/k>0080cLg=0P3Cdm<40=7A
d@80c/k>0P3<c<`20<k>cP80bLW90P3<c<`20=7Ad@H0clo?0P3=cLd00`3<c<`0b/[:0<[:bP020<k>
cP80c<c<0P36a/H20<?3``80_;bl0P2YZJT209BDU080OWin0P1aLG4206UYJ@80IfMW0P1CDe<205aL
G080E5AD00<0DU9B03Hf=P0f=SH00P0j>SX202l_;`80MgMg0P2VYZH20:>SX`80XJ6Q0P2MWId20:RX
Z080[Jf]0P2SXj<209VIV@80XZ:R0P2SXj<20:6QX@0309nOW`2MWId0WIfM0080WIfM102NWYh209nO
W`80VYZJ0P2NWYh209fMW@@0Vi^K0P2EUID209JFUP80V9RH0P2JVYX209FEU@0309BDU02>SXh0SXj>
0080RXZ:0P22PX8208B4Q080PX:20P25QHD207QhN080LG5a0P1/K6`2079bLP80IVIV0P1^KVh206=S
H`80H61P0P1ZJVX00`1[Jf/0M7Ad07AdM00207UiN@80P8200P1fMWH206YZJP80MGEe0P1aLG4207Ui
N@80Ogmo0P1eMGD20820P080UYJF0P2KVi/209NGU`80T92@0`2:RXX208f=S@80RHV90P2FUYH20:NW
Y`80ZZZZ0P2/[:`20;^k^`80bLW90P3AdM420<O7a`80aLG50P32`/820<[:bP80cLg=00<0dM7A0=?C
d`3Cdm<00P3>c/h40<S8b080bl_;0P3:b/X20<g=cAD0oooo000C0?ooo`80dM7A0P3>c/h20<c<c080
dM7A0P3Cdm<20<k>cP80b/[:0P3?cll00`3AdM40c/k>0<k>cP020<g=c@80dm?C103AdM420<k>cP80
c<c<0P3>c/h20<W9b@80c<c<0P3AdM460<o?c`80cLg=00<0c<c<0<[:bP3:b/X00P3>c/h20<c<c080
a/K60P33`l<20;bl_080ZJVY0P2DU9@207inOP80LG5a0P1YJFT206MWI`80De=C0P1LG5`205ADE003
059BDP0f=SH0=SHf0080>SXj0P0_;bl207MgM`80YZJV0P2SXj<20:6QX@80WIfM0P2XZ:P20:f][@80
Xj>S0P2IVIT20::RXP80Xj>S0P2QXJ400`2OWil0WIfM09fMW@0209fMW@@0WYjN0P2OWil209ZJVP80
WYjN0P2MWId409^KV`80UIFE0P2FUYH209RHV080VYZJ0P2EUID00`2DU9@0SXj>08j>SP0208Z:RP80
PX:20P24Q8@208:2PP80QHF50P1hN7P2075aL@80K6a/0P1bLW8206IVIP80KVi^0P1SHf<2061PH080
JVYZ00<0Jf][07AdM01dM7@00P1iNGT20820P080MWIf0P1ZJVX207EeM@80LG5a0P1iNGT207moO`80
MGEe0P20P80209JFUP80Vi^K0P2GUiL2092@T0<0RXZ:0P2=SHd208V9R@80UYJF0P2WYjL20:ZZZP80
[:b/0P2k^k/20<W9b@80dM7A0P37alL20<G5a@80`/;20P3:b/X20<g=c@030=7Ad@3Cdm<0dm?C0080
c/k>1038b<P20<_;b`80b/[:0P3=cLdE0?ooo`004`3oool60=7Ad@80c/k>0P3=cLd20=CDe080dM7A
0P3=cLd00`3De=@0eMGE0=GEe@020<k>cP80c<c<103AdM420=?Cd``0dM7A0P3<c<`20<o?c`80cLg=
00<0d];B0=7Ad@3AdM400P3;bl/20<[:bP80e=CD0P3=cLd20:f][@80WinO0P2;Rh/208R8R080Jf][
0P1/K6`2061PH0@0F5QH0P1DE5@00`16ATH0>SXj03Xj>P0203/k>`80<c<c0P1cLg<20:JVYP80[Jf]
0P2WYjL20:ZZZP80Y:BT0P2UYJD20:j^[P@0XJ6Q0P2TY:@309bLW080WinO0P2JVYX209NGU`80W9bL
0P2KVi/209VIV@80V9RH102IVIT209fMW@80V9RH0P2FUYH2092@T080Ti>C0P2EUID00`2?Shl0S8b<
08b<S00208j>SP80PX:20P24Q8@208:2PP80N7Qh0P1]KFd206UYJ@80JVYZ0P1SHf<206EUI@80Fe]K
0P1MGEd205aLG080FUYJ00<0IVIV07MgM`1gMgL00P28R8P20820P080QhN70P1oOgl207IfMP80KFe]
0P1^KVh2079bLP80RXZ:0P27QhL208>3P`80V9RH0P2IVIT208N7Q`0308R8R02FUYH0UYJF0080W9bL
0P2FUYH20::RXP80YZJV0P2/[:`20;^k^`80aLG50P2n_[h20;Ng]`80a<C40P3>c/h20<c<c080b/[:
0P3?cll00`3>c/h0c<c<0<c<c0040=7Ad@80clo?103<c<`20<o?caD0oooo000C0?ooo`H0dM7A0P3>
c/h20<g=c@80e=CD0P3AdM420<g=c@030=CDe03EeMD0eMGE0080c/k>0P3<c<`40=7Ad@80dm?C303A
dM420<c<c080clo?0P3=cLd00`3Bd]80dM7A0=7Ad@020<_;b`80b/[:0P3De=@20<g=c@80[Jf]0P2O
Wil208^;R`80R8R80P1[Jf/206a/K080H61P101HF5P205ADE00304I6AP0j>SX0>SXj0080>c/k0P0c
<c<207=cL`80YZJV0P2][Jd20:NWY`80ZZZZ0P2TY:@20:FUY@80[Zj^102QXJ420:BTY0<0W9bL0P2O
Wil209ZJVP80UiNG0P2LW9`209^KV`80VIVI0P2HV9P409VIV@80WIfM0P2HV9P209JFUP80T92@0P2C
Ti<209FEU@0308n?S`2<S8`0S8b<0080SXj>0P22PX8208B4Q080PX:20P1hN7P206e]K@80JFUY0P1Z
JVX206=SH`80IFEU0P1KFe/205eMG@80G5aL0P1JFUX00`1VIVH0MgMg07MgM`0208R8R080P8200P27
QhL207moO`80MWIf0P1]KFd206i^KP80LW9b0P2:RXX208N7Q`80Ph>30P2HV9P209VIV@80QhN700<0
R8R809JFUP2FUYH00P2LW9`209JFUP80XZ:R0P2VYZH20:b/[080^k^k0P35aLD20;jn_P80]kNg0P34
a<@20<k>cP80c<c<0P3:b/X20<o?c`030<k>cP3<c<`0c<c<00@0dM7A0P3?cll40<c<c080clo?5@3o
ool001<0oooo103AdM420=CDe080dm?C0P3?cll20<g=c@80clo?0P3>c/h00`38b<P0b/[:0<[:bP02
0=CDe080eMGE0P3AdM440<o?c`@0dM7A103De=@20=?Cd`80d=3@103AdM420<[:bP030<G5a@38b<P0
b<S80080bl_;0P3?cll20<k>cP80c<c<0P2e]KD2096AT@80Q8B40P1lO7`206a/K080Hf=S0P1DE5@2
05YJFP80EeMG0P1FEUH00`0g=cL0=CDe03De=@0203Xj>P80?Cdm0P1gMgL20:6QX@80Xj>S0P2VYZH2
0:RXZ080YjNW0P2OWil20::RXP80YJFU0P2MWId20:6QX@80W9bL0`2IVIT209JFUP80UIFE102ATI42
09NGU`80Ti>C1P2HV9P209>CT`@0Shn?102@T9000`2>SXh0S8b<08b<S0040861P@80NWYj0P1oOgl2
07EeM@@0IfMW0P1UIFD2065QH@80GEeM0P1UIFD205mOG`80FEUI0P1MGEd00`1RHV80LG5a075aL@02
07inOP80PX:20P1gMgL207alO080LW9b0P1^KVh206e]K@80Kfm_0P1fMWH208:2PP80UiNG0P2ATI42
092@T080VYZJ0`2EUID208^;R`@0Vi^K0P2XZ:P20;Ng]`80_[jn0P2m_Kd40<c<c080b<S80P30`<02
0<o?c`80c/k>0P3<c<`30=7Ad@80dm?C0P3AdM420<k>cP80cLg=0P3EeMD20<o?caD0oooo000C0?oo
o`@0dM7A0P3De=@20=?Cd`80clo?0P3=cLd20<o?c`80c/k>00<0b<S80<[:bP3:b/X00P3De=@20=GE
e@80dM7A103?cll40=7Ad@@0e=CD0P3Cdm<20=3@d0@0dM7A0P3:b/X00`35aLD0b<S80<S8b0020<_;
b`80clo?0P3>c/h20<c<c080]KFe0P2ATI4208B4Q080O7al0P1/K6`206=SH`80E5AD0P1JFUX205MG
E`80EUIF00<0=cLg03De=@0e=CD00P0j>SX203dm?@80MgMg0P2QXJ420:>SX`80YZJV0P2XZ:P20:NW
Y`80WinO0P2RXZ820:FUY@80WIfM0P2QXJ4209bLW0<0VIVI0P2FUYH209FEU@@0TI6A0P2GUiL209>C
T`H0V9RH0P2CTi<408n?S`@0T92@00<0SXj>08b<S02<S8`01021PH4207YjNP80Ogmo0P1eMGD406MW
I`80IFEU0P1QHF4205eMG@80IFEU0P1OGel205UIF@80GEeM00<0HV9R075aL@1aLG400P1nOWh208:2
PP80MgMg0P1lO7`2079bLP80KVi^0P1]KFd206m_K`80MWIf0P22PX8209NGU`80TI6A0P2@T90209ZJ
VP<0UIFE0P2;Rh/409^KV`80Z:RX0P2g]kL20;jn_P80_Kfm103<c<`20<S8b080`<300P3?cll20<k>
cP80c<c<0`3AdM420=?Cd`80dM7A0P3>c/h20<g=c@80eMGE0P3?cllE0?ooo`004`3oool20=CDe080
dM7A0P39bLT20<g=c@80dM7A0P3=cLd20=7Ad@80e]KF00<0eMGE0=7Ad@3AdM400P38b<P20<[:bP@0
d];B0P3=cLd20=?Cd`80clo?0P3<c<`20<W9b@@0b/[:0P3>c/h20<W9b@80c<c<00<0dM7A0=;BdP3B
d]800P3AdM420<o?c`80bLW90P2o_kl20:b/[080T92@0P26QXH207=cL`80IfMW0P1[Jf/405eMG@80
DU9B0P1ADE400`0c<c<0;Bd]02d];@0203De=@80=SHf0P1nOWh60:2PX080W9bL102RXZ8209fMW@80
X:2P0P2MWId209VIV@80VYZJ0`2CTi<209FEU@80TY:B0P2ATI4208f=S@80QHF50P28R8P208^;R`80
T92@0P2CTi<2096AT@@0SHf=0P28R8P208F5Q@0308N7Q`23Ph<0Ph>30080OWin0P21PH42075aL@80
IVIV0P1QHF4206UYJ@80GEeM0P1XJ6P206MWI`80Cdm?0P1CDe<205YJFP80IfMW0P1ZJVX00`1XJ6P0
KFe]06e]K@0207emO@80SXj>0P2GUiL209:BTP80UiNG0P1[Jf/2061PH080KFe]0P1dM7@208>3P`80
Ogmo0P2NWYh209RHV0<0U9BD1027QhL209ZJVP80ZZZZ0P2[Zj/20:RXZ080`L710P30`<020<71`@80
b<S80P36a/H20<o?c`80d];B0P3De=@50=7Ad@80c<c<103AdM420<o?c`80b/[:0P3>c/hE0?ooo`00
4`3oool20=CDe080dM7A0P39bLT20<g=c@80dM7A0P3=cLd20=7Ad@80e]KF00<0eMGE0=7Ad@3AdM40
0P38b<P20<[:bP@0d];B0P3=cLd20=?Cd`80clo?0P3<c<`20<W9b@@0b/[:0P3>c/h20<W9b@80c<c<
00<0dM7A0=;BdP3Bd]800P3AdM420<o?c`80bLW90P2o_kl20:b/[080T92@0P26QXH207=cL`80IfMW
0P1[Jf/405eMG@80DU9B0P1ADE400`0c<c<0;Bd]02d];@0203De=@80=SHf0P1nOWh60:2PX080W9bL
102RXZ8209fMW@80X:2P0P2MWId209VIV@80VYZJ0`2CTi<209FEU@80TY:B0P2ATI4208f=S@80QHF5
0P28R8P208^;R`80T92@0P2CTi<2096AT@@0SHf=0P28R8P208F5Q@0308N7Q`23Ph<0Ph>30080OWin
0P21PH42075aL@80IVIV0P1QHF4206UYJ@80GEeM0P1XJ6P206MWI`80Cdm?0P1CDe<205YJFP80IfMW
0P1ZJVX00`1XJ6P0KFe]06e]K@0207emO@80SXj>0P2GUiL209:BTP80UiNG0P1[Jf/2061PH080KFe]
0P1dM7@208>3P`80Ogmo0P2NWYh209RHV0<0U9BD1027QhL209ZJVP80ZZZZ0P2[Zj/20:RXZ080`L71
0P30`<020<71`@80b<S80P36a/H20<o?c`80d];B0P3De=@50=7Ad@80c<c<103AdM420<o?c`80b/[:
0P3>c/hE0?ooo`004`3oool20<W9b@80c<c<0P3AdM420<k>cP80b/[:0P3;bl/20<K6aP80aLG500<0
alO70<c<c03<c<`0103AdM420<g=c@80bl_;0P3Bd]840<o?c`80d=3@0P3>c/h20<g=c@80dM7A0P3C
dm<20=7Ad@80e=CD00<0d];B0<_;b`3;bl/00P38b<P20<k>cP80bl_;0P2l_;`20::RXP80RHV90P1o
Ogl207=cL`80IVIV0P1JFUX205eMG@80GemO0P1CDe<20451@@0303Lg=`0c<c<0<c<c0080=3@d0P0j
>SX207MgM`80YZJV0P2OWil40:JVYP80XZ:R0P2NWYh209fMW@80U9BD0P2FUYH209BDU080V9RH00<0
UIFE08j>SP2>SXh0102ATI4208j>SP80Ti>C0P2>SXh208N7Q`80S8b<1028R8P209BDU080SHf=0P28
R8P208F5Q@80Q8B400<0OGem07alO01lO7`00P1dM7@207emO@80Jf][0P1FEUH206ATI080GEeM0P1Q
HF4205eMG@80EUIF0P1@D50203@d=080FUYJ0P1KFe/206ATI00307alO01`L700L71`0080OGem0P26
QXH208f=S@80R8R80P2?Shl208J6QP80N7Qh0P1cLg<207QhN080Ph>30P22PX8208Z:RP80UYJF0P2E
UID00`24Q8@0Rh^;08^;R`0208f=S@80SXj>0P2UYJD20;>c/`80a<C40P31`L420<S8b080`L710P34
a<@20<g=c@80c<c<0P38b<P20<g=c@80dM7A00<0c/k>0<g=c@3=cLd00P3EeMD40=7Ad@80cLg=0P3C
dm<20=7AdAD0oooo000C0?ooo`80bLW90P3<c<`20=7Ad@80c/k>0P3:b/X20<_;b`80a/K60P35aLD0
0`37alL0c<c<0<c<c0040=7Ad@80cLg=0P3;bl/20=;BdP@0clo?0P3@d=020<k>cP80cLg=0P3AdM42
0=?Cd`80dM7A0P3De=@00`3Bd]80bl_;0<_;b`020<S8b080c/k>0P3;bl/20;bl_080XZ:R0P29RHT2
07moO`80Lg=c0P1VIVH205YJFP80GEeM0P1OGel205=CD`80@D5100<0=cLg03<c<`0c<c<00P0d=3@2
03Xj>P80MgMg0P2VYZH209nOW`@0YZJV0P2RXZ8209jNWP80WIfM0P2DU9@209JFUP80U9BD0P2HV9P0
0`2EUID0SXj>08j>SP04096AT@80SXj>0P2CTi<208j>SP80QhN70P2<S8`408R8R080U9BD0P2=SHd2
08R8R080QHF50P24Q8@00`1mOGd0O7al07alO00207AdM080OGem0P1[Jf/205IFEP80I6AT0P1MGEd2
065QH@80GEeM0P1FEUH2051@D080=3@d0P1JFUX205]KF`80I6AT00<0O7al071`L01`L7000P1mOGd2
08J6QP80SHf=0P28R8P208n?S`80QXJ60P1hN7P207=cL`80N7Qh0P23Ph<208:2PP80RXZ:0P2FUYH2
09FEU@0308B4Q02;Rh/0Rh^;0080SHf=0P2>SXh20:FUY@80/k>c0P34a<@20<71`@80b<S80P31`L42
0<C4a080cLg=0P3<c<`20<S8b080cLg=0P3AdM400`3>c/h0cLg=0<g=c@020=GEe@@0dM7A0P3=cLd2
0=?Cd`80dM7A5@3oool001<0oooo1P3AdM420=?Cd`@0clo?0P3De=@20=GEe@030=CDe03Cdm<0dm?C
0080dM7A0P3Cdm<20=7Ad@80cLg=0P37alL20<c<c080c/k>0P3?cll20=;BdP80d=3@0P3Bd]820<c<
c080clo?0P3;bl/00`37alL0cLg=0<g=c@020=3@d080bLW90P35aLD20;6a/@80Vi^K0P27QhL207]k
N`80J6QX0P1UIFD205eMG@80EEEE0P1IFET204A4A080@D5100<0=cLg03Xj>P0j>SX00P0j>SX203/k
>`80NWYj1P2LW9`209JFUP80W9bL0P2GUiL209RHV080UiNG0P2EUID209:BTP80Rh^;00<0SXj>08V9
R@29RHT00P23Ph<208J6QP80QhN70P1lO7`208J6QP@0PX:20P29RHT208N7Q`80PH610P26QXH208V9
R@80QHF50P1jNWX00`1mOGd0NGUi07UiN@0207QhN080NWYj0P1[Jf/2051@D080GEeM0P1WIfL205AD
E080Cdm?0P17AdL204Q8B080A4A40P19BDT2079bLP80Kfm_00<0IfMW07AdM01dM7@00P1XJ6P208V9
R@80Shn?0P2FUYH208j>SP80TY:B0P1kNg/408B4Q080PX:20P2>SXh208R8R080SHf=0P29RHT00`1o
Ogl0OWin07inOP0208J6QP80YjNW102b/[820<71`@80_Kfm0P2l_;`20<c<c080a/K60P3:b/X20<k>
cP80b/[:0P3?cll30=7Ad@80cLg=0P3:b/X20<k>cP80c<c<103?cll20=7AdAD0oooo000C0?ooo`H0
dM7A0P3Cdm<40<o?c`80e=CD0P3EeMD00`3De=@0dm?C0=?Cd`020=7Ad@80dm?C0P3AdM420<g=c@80
alO70P3<c<`20<k>cP80clo?0P3Bd]820=3@d080d];B0P3<c<`20<o?c`80bl_;00<0alO70<g=c@3=
cLd00P3@d=020<W9b@80aLG50P2a/K4209^KV`80QhN70P1kNg/206QXJ080IFEU0P1MGEd205EEE@80
FEUI0P14A4@20451@@0303Lg=`0j>SX0>SXj0080>SXj0P0k>c/207YjNPH0W9bL0P2FUYH209bLW080
UiNG0P2HV9P209NGU`80UIFE0P2BTY8208^;R`0308j>SP29RHT0RHV90080Ph>30P26QXH208N7Q`80
O7al0P26QXH408:2PP80RHV90P27QhL20861P@80QXJ60P29RHT208F5Q@80NWYj00<0OGem07UiN@1i
NGT00P1hN7P207YjNP80Jf][0P1@D50205eMG@80IfMW0P1DE5@204m?C`80AdM70P18B4P204A4A080
BDU90P1bLW8206m_K`0306MWI`1dM7@0M7Ad0080J6QX0P29RHT208n?S`80UYJF0P2>SXh209:BTP80
Ng]k1024Q8@208:2PP80SXj>0P28R8P208f=S@80RHV900<0Ogmo07inOP1nOWh00P26QXH20:NWY`@0
/[:b0P31`L420;fm_@80_;bl0P3<c<`20<K6aP80b/[:0P3>c/h20<[:bP80clo?0`3AdM420<g=c@80
b/[:0P3>c/h20<c<c0@0clo?0P3AdM4E0?ooo`004`3oool20=CDe080dm?C0P3>c/h20<g=c@80e=CD
0P3>c/h20<W9b@80b/[:00<0bLW90<g=c@3=cLd00P3AdM420<o?c`80dM7A0P3Bd]820=GEe@80dM7A
0P3?cll20<O7a`@0c<c<0P3=cLd20=7Ad@@0clo?00<0e=CD0=;BdP3Bd]800P3<c<`20<g=c@80_;bl
0P2RXZ8208n?S`80OGem0P1aLG4206][J`80H61P0P1WIfL2055AD@80F5QH0P0];Bd204=3@`0303Ph
>00i>CT0>CTi0080=cLg0P17AdL206e]K@80W9bL0P2BTY8209RHV080WYjN0P2EUID209>CT`80TY:B
0P2IVIT209FEU@80UYJF0P2GUiL00`2CTi<0T92@092@T00208B4Q080NGUi0P1fMWH207moO`80NGUi
0P1mOGd207alO080Ng]k0P1oOgl208B4Q080QHF5101kNg/207YjNP03071`L01]KFd0KFe]0080Jf][
0P1iNGT205]KF`80De=C0P1GEeL205eMG@80D51@0P0l?3`203lo?`80DU9B0P13@d<205mOG`80KVi^
0P1eMGD00`1`L700KFe]06e]K@0207=cL`80N7Qh0P2>SXh209FEU@80Shn?0P1oOgl207UiN@80O7al
0P1jNWX207]kN`80VYZJ0P2IVIT208b<S080Rh^;00<0T92@08V9R@29RHT00P2IVIT209FEU@80ZZZZ
0P35aLD20;Bd]080_kno0P36a/H20<S8b080dm?C0P3AdM420=?Cd`80c/k>0P3<c<`30=7Ad@80dm?C
1P3AdM420<k>cP80cLg=0P3Bd]8E0?ooo`004`3oool20=CDe080dm?C0P3>c/h20<g=c@80e=CD0P3>
c/h20<W9b@80b/[:00<0bLW90<g=c@3=cLd00P3AdM420<o?c`80dM7A0P3Bd]820=GEe@80dM7A0P3?
cll20<O7a`@0c<c<0P3=cLd20=7Ad@@0clo?00<0e=CD0=;BdP3Bd]800P3<c<`20<g=c@80_;bl0P2R
XZ8208n?S`80OGem0P1aLG4206][J`80H61P0P1WIfL2055AD@80F5QH0P0];Bd204=3@`0303Ph>00i
>CT0>CTi0080=cLg0P17AdL206e]K@80W9bL0P2BTY8209RHV080WYjN0P2EUID209>CT`80TY:B0P2I
VIT209FEU@80UYJF0P2GUiL00`2CTi<0T92@092@T00208B4Q080NGUi0P1fMWH207moO`80NGUi0P1m
OGd207alO080Ng]k0P1oOgl208B4Q080QHF5101kNg/207YjNP03071`L01]KFd0KFe]0080Jf][0P1i
NGT205]KF`80De=C0P1GEeL205eMG@80D51@0P0l?3`203lo?`80DU9B0P13@d<205mOG`80KVi^0P1e
MGD00`1`L700KFe]06e]K@0207=cL`80N7Qh0P2>SXh209FEU@80Shn?0P1oOgl207UiN@80O7al0P1j
NWX207]kN`80VYZJ0P2IVIT208b<S080Rh^;00<0T92@08V9R@29RHT00P2IVIT209FEU@80ZZZZ0P35
aLD20;Bd]080_kno0P36a/H20<S8b080dm?C0P3AdM420=?Cd`80c/k>0P3<c<`30=7Ad@80dm?C1P3A
dM420<k>cP80cLg=0P3Bd]8E0?ooo`004`3oool20<W9b@80cLg=0P3De=@20<k>cP80`l?30P38b<P4
0<o?c`030=7Ad@3>c/h0c/k>0080bLW90P3<c<`20=7Ad@80cLg=0P3<c<`20<k>cP80cLg=0P3@d=02
0<O7a`80b/[:0P3?cll40=7Ad@80b/[:00<0cLg=0<[:bP3:b/X00P39bLT20<K6aP80_Kfm0P2SXj<2
08n?S`80NWYj0P1_Kfl2065QH@80IFEU0P1OGel206EUI@80B4Q80P0e=CD203`l?0030410@00i>CT0
>CTi0080=SHf0P1EEED206ATI080Vi^K0P2/[:`20:VYZ@80[Zj^0P2][Jd20:j^[P80ZJVY0P2NWYh2
09nOW`@0W9bL00<0Vi^K09ZJVP2JVYX00P2GUiL2096AT@80PH61101`L70207AdM080NWYj0P1gMgL2
07=cL`80M7Ad0P1aLG4207inOP80MgMg0P1cLg<00`1aLG40JFUY06UYJ@02069RHP80Lg=c0P1LG5`2
055AD@80FEUI0P19BDT204I6AP80>CTi0P11@D4205IFEP80BTY:0P1HF5P206][J`80Ng]k00<0KFe]
06YZJP1ZJVX00P1/K6`207YjNP80RXZ:0P2MWId209^KV`80VYZJ0P2>SXh208:2PP80MWIf0P1eMGD2
07alO080Vi^K0P2CTi<208B4Q00308n?S`2@T900T92@0080YjNW0P2i^KT20<O7a`80b<S80P3<c<`2
0<K6aP80c<c<0P38b<P40<o?c`80dM7A0P3De=@20=GEe@80e=CD00<0dM7A0<c<c03<c<`00P3AdM42
0=?Cd`@0dM7A0P3>c/h20<S8b1D0oooo000C0?ooo`80bLW90P3=cLd20=CDe080c/k>0P33`l<20<S8
b0@0clo?00<0dM7A0<k>cP3>c/h00P39bLT20<c<c080dM7A0P3=cLd20<c<c080c/k>0P3=cLd20=3@
d080alO70P3:b/X20<o?c`@0dM7A0P3:b/X00`3=cLd0b/[:0<[:bP020<W9b@80a/K60P2m_Kd20:>S
X`80Shn?0P1jNWX206m_K`80HF5Q0P1UIFD205mOG`80IFEU0P18B4P203De=@80?3`l00<0@41003Ti
>@0i>CT00P0f=SH205EEE@80I6AT0P2KVi/20:b/[080ZJVY0P2^[Zh20:f][@80[Zj^0P2YZJT209jN
WP80WinO102LW9`00`2KVi/0VYZJ09ZJVP0209NGU`80TI6A0P21PH44071`L080M7Ad0P1jNWX207Mg
M`80Lg=c0P1dM7@2075aL@80OWin0P1gMgL207=cL`03075aL@1YJFT0JFUY0080HV9R0P1cLg<205aL
G080DE5A0P1IFET204U9B@80ATI60P0i>CT20451@@80EUIF0P1:BTX205QHF080Jf][0P1kNg/00`1]
KFd0JVYZ06YZJP0206a/K080NWYj0P2:RXX209fMW@80Vi^K0P2JVYX208j>SP80PX:20P1fMWH207Ee
M@80O7al0P2KVi/209>CT`80Q8B400<0Shn?092@T02@T9000P2WYjL20;Vi^@80alO70P38b<P20<c<
c080a/K60P3<c<`20<S8b0@0clo?0P3AdM420=CDe080eMGE0P3De=@00`3AdM40c<c<0<c<c0020=7A
d@80dm?C103AdM420<k>cP80b<S85@3oool001<0oooo0P3De=@20=7Ad@80b/[:0P3@d=020=7Ad@80
e=CD0P3Bd]820<g=c@030=GEe@3AdM40dM7A00H0dM7A0P3Bd]820=3@d0@0dM7A0P3?cll20=7Ad@80
clo?0P3;bl/20<o?c`80d=3@0P3Bd]830<_;b`80cLg=0P2n_[h20:JVYP80UIFE0P28R8P207EeM@80
KVi^0P1UIFD205MGE`80F5QH0P1LG5`203Lg=`80?Shn0P0o?cl00`0l?3`0?Cdm03dm?@0204a<C080
<c<c0P1fMWH20:^[Z`80/;2`0P2h^;P20:f][@80/;2`0P2YZJT20:n_[`@0[Zj^0P2ZZZX20:2PX003
09nOW`2PX:00X:2P0080VIVI0P2HV9P2096AT@80Rh^;0P1jNWX206a/K080IVIV0P1dM7@207IfMP80
MgMg0P1fMWH206][J`80MWIf0P1cLg<00`1/K6`0Jf][06][J`0205QHF080EEEE0P1dM7@2059BDP80
L71`0P13@d<203Xj>P80:b/[0P0e=CD206MWI`80GUiN0P1:BTX206YZJP80MGEe00<0IfMW06m_K`1_
Kfl00P1SHf<207QhN080PX:20P2;Rh/209bLW080U9BD0P2<S8`207UiN@80QXJ60P1cLg<208R8R080
SXj>0P2EUID2092@T00309JFUP2OWil0WinO0080Ti>C0P2XZ:P20<[:bP80_kno0P2f][H20<71`@80
a/K60P3>c/h20<g=c@80d=3@0P37alL20<S8b080alO70P3:b/X00`3?cll0dm?C0=?Cd`020<k>cP80
c<c<103AdM420=?Cd`80dM7A5@3oool001<0oooo0P3De=@20=7Ad@80b/[:0P3@d=020=7Ad@80e=CD
0P3Bd]820<g=c@030=GEe@3AdM40dM7A00H0dM7A0P3Bd]820=3@d0@0dM7A0P3?cll20=7Ad@80clo?
0P3;bl/20<o?c`80d=3@0P3Bd]830<_;b`80cLg=0P2n_[h20:JVYP80UIFE0P28R8P207EeM@80KVi^
0P1UIFD205MGE`80F5QH0P1LG5`203Lg=`80?Shn0P0o?cl00`0l?3`0?Cdm03dm?@0204a<C080<c<c
0P1fMWH20:^[Z`80/;2`0P2h^;P20:f][@80/;2`0P2YZJT20:n_[`@0[Zj^0P2ZZZX20:2PX00309nO
W`2PX:00X:2P0080VIVI0P2HV9P2096AT@80Rh^;0P1jNWX206a/K080IVIV0P1dM7@207IfMP80MgMg
0P1fMWH206][J`80MWIf0P1cLg<00`1/K6`0Jf][06][J`0205QHF080EEEE0P1dM7@2059BDP80L71`
0P13@d<203Xj>P80:b/[0P0e=CD206MWI`80GUiN0P1:BTX206YZJP80MGEe00<0IfMW06m_K`1_Kfl0
0P1SHf<207QhN080PX:20P2;Rh/209bLW080U9BD0P2<S8`207UiN@80QXJ60P1cLg<208R8R080SXj>
0P2EUID2092@T00309JFUP2OWil0WinO0080Ti>C0P2XZ:P20<[:bP80_kno0P2f][H20<71`@80a/K6
0P3>c/h20<g=c@80d=3@0P37alL20<S8b080alO70P3:b/X00`3?cll0dm?C0=?Cd`020<k>cP80c<c<
103AdM420=?Cd`80dM7A5@3oool001<0oooo0P39bLT20<g=c@80d=3@0P3:b/X20<k>cP80b<S80P3:
b/X30<k>cP@0e=CD0P3AdM420<k>cP80bLW90P3?cll20=7Ad@80b/[:0P3?cll20=7Ad@80cLg=0P3?
cll20<k>cP80b<S80P35aLD00`37alL0cLg=0<g=c@020=;BdP80bLW90P2QXJ42096AT@80OGem0P1a
LG42069RHP80J6QX0P1SHf<205QHF080DE5A0P0g=cL20410@080@T920`0l?3`201XJ6P80NWYj0P2a
/K420;Vi^@80^;Rh102f][H20;:b/P80][Jf0P2d];@20;Jf]P80/;2`0P2[Zj/20:n_[`030:ZZZP2P
X:00X:2P0080W9bL0P2IVIT209^KV`80UIFE0P2>SXh208R8R080NGUi0P1SHf<206a/K080KFe]0P1c
Lg<2071`L080LG5a0P1_Kfl00`1XJ6P0HF5Q065QH@0204i>CP80B4Q80P1WIfL204e=C@80NWYj0P1I
FET203@d=080>c/k0P0S8b<204];B`80NGUi0P1<C4`206MWI`80MgMg00<0LW9b07IfMP1fMWH00P1h
N7P2079bLP80QhN70P2HV9P20:RXZ080YjNW0P2OWil207moO`80K6a/0P23Ph<208B4Q080QHF50P29
RHT2092@T00309VIV@2HV9P0V9RH0080YZJV0P37alL20;bl_080]kNg0P35aLD40<g=c@80e=CD0P3>
c/h20<g=c@@0dM7A0P3De=@20=7Ad@030<[:bP3?cll0clo?0080dm?C103AdM420<k>cP80c<c<0P3A
dM4E0?ooo`004`3oool20<W9b@80cLg=0P3@d=020<[:bP80c/k>0P38b<P20<[:bP<0c/k>103De=@2
0=7Ad@80c/k>0P39bLT20<o?c`80dM7A0P3:b/X20<o?c`80dM7A0P3=cLd20<o?c`80c/k>0P38b<P2
0<G5a@030<O7a`3=cLd0cLg=0080d];B0P39bLT20:6QX@80TI6A0P1mOGd2075aL@80HV9R0P1XJ6P2
06=SH`80F5QH0P1ADE4203Lg=`80@4100P12@T8303`l?0806QXJ0P1jNWX20;6a/@80^KVi0P2h^;P4
0;Jf]P80/[:b0P2f][H20;Bd]080][Jf0P2`/;020:^[Z`80[jn_00<0ZZZZ0:2PX02PX:000P2LW9`2
09VIV@80Vi^K0P2EUID208j>SP80R8R80P1iNGT206=SH`80K6a/0P1]KFd207=cL`80L71`0P1aLG42
06m_K`0306QXJ01QHF40HF5Q0080CTi>0P18B4P206MWI`80CDe=0P1jNWX205UIF@80=3@d0P0k>c/2
02<S8`80Bd];0P1iNGT204a<C080IfMW0P1gMgL00`1bLW80MWIf07IfMP0207QhN080LW9b0P27QhL2
09RHV080Z:RX0P2WYjL209nOW`80Ogmo0P1/K6`208>3P`80Q8B40P25QHD208V9R@80T92@00<0VIVI
09RHV02HV9P00P2VYZH20<O7a`80_;bl0P2g]kL20<G5a@@0cLg=0P3De=@20<k>cP80cLg=103AdM42
0=CDe080dM7A00<0b/[:0<o?c`3?cll00P3Cdm<40=7Ad@80c/k>0P3<c<`20=7AdAD0oooo000C0?oo
o`80dM7A0P3>c/h20<c<c080dM7A0P3Bd]820=GEe@80dM7A0P3=cLd00`37alL0b<S80<S8b0020<[:
bP80dM7A103Bd]820<_;b`80d=3@0P3>c/h20<[:bP80c<c<0P39bLT20<c<c0H0dM7A00<0d=3@0<W9
b@39bLT00P2m_Kd20;Fe]@80VIVI0P29RHT207]kN`80JFUY0P1KFe/605YJFP80@D510P0j>SX203lo
?`80@41000<0EeMG05UIF@1IFET00P2_[jl20;Bd]080]kNg0P2i^KT20;jn_PH0^[Zj0P2d];@40:f]
[@@0];Bd0P2_[jl30:j^[P80[Jf]0P2SXj<209JFUP80VIVI0P2JVYX2092@T080R8R80P1fMWH206MW
I`80Fe]K0P1YJFT206a/K080IfMW0P1XJ6P00`1RHV80FEUI05UIF@02051@D080@D510P1ZJVX206EU
I@80GUiN0P1cLg<203Ti>@80;Bd]0P14A4@20451@@80GemO0P1UIFD204m?C`80KFe]00<0LW9b06QX
J01XJ6P00P26QXH207]kN`80PX:20P2=SHd209bLW080/;2`0P2PX:0208:2PP80MWIf0P1nOWh207mo
O`80SHf=0P2BTY8209JFUP0309>CT`2MWId0WIfM0080^k^k0P33`l<20;6a/@80^[Zj0P37alL20<_;
b`80c/k>0P3=cLd40<o?c`@0dM7A103<c<`00`3>c/h0bLW90<W9b@020<g=c@80dm?C1P3AdM420=?C
daD0oooo000C0?ooo`80dM7A0P3>c/h20<c<c080dM7A0P3Bd]820=GEe@80dM7A0P3=cLd00`37alL0
b<S80<S8b0020<[:bP80dM7A103Bd]820<_;b`80d=3@0P3>c/h20<[:bP80c<c<0P39bLT20<c<c0H0
dM7A00<0d=3@0<W9b@39bLT00P2m_Kd20;Fe]@80VIVI0P29RHT207]kN`80JFUY0P1KFe/605YJFP80
@D510P0j>SX203lo?`80@41000<0EeMG05UIF@1IFET00P2_[jl20;Bd]080]kNg0P2i^KT20;jn_PH0
^[Zj0P2d];@40:f][@@0];Bd0P2_[jl30:j^[P80[Jf]0P2SXj<209JFUP80VIVI0P2JVYX2092@T080
R8R80P1fMWH206MWI`80Fe]K0P1YJFT206a/K080IfMW0P1XJ6P00`1RHV80FEUI05UIF@02051@D080
@D510P1ZJVX206EUI@80GUiN0P1cLg<203Ti>@80;Bd]0P14A4@20451@@80GemO0P1UIFD204m?C`80
KFe]00<0LW9b06QXJ01XJ6P00P26QXH207]kN`80PX:20P2=SHd209bLW080/;2`0P2PX:0208:2PP80
MWIf0P1nOWh207moO`80SHf=0P2BTY8209JFUP0309>CT`2MWId0WIfM0080^k^k0P33`l<20;6a/@80
^[Zj0P37alL20<_;b`80c/k>0P3=cLd40<o?c`@0dM7A103<c<`00`3>c/h0bLW90<W9b@020<g=c@80
dm?C1P3AdM420=?CdaD0oooo000C0?ooo`80e]KF0P3EeMD20=7Ad@80dm?C0P3=cLd20<[:bP80d];B
0P3De=@00`3AdM40e=CD0=CDe0020=?Cd`80dM7A0P3@d=020<[:bP80c<c<0P3>c/h40=7Ad@80d=3@
0P3De=@20=7Ad@80d];B0P3Fe]H20<o?c`030<c<c038b<P0b<S80080_[jn0P2WYjL209BDU080PH61
0P1dM7@206YZJP80F5QH0P1NGUh205ADE080FUYJ0P0b<S8203`l?080?clo0P1;Bd/00`1=CDd0N7Qh
07QhN0020;Rh^080/[:b0P2_[jl20;Jf]P80^KVi0P2k^k/20<30`080^k^k102o_kl20;Jf]P80/[:b
0P2`/;020:n_[`030;2`/02[Zj/0Zj^[0080XJ6Q0P2OWil20:JVYP80WinO0P2JVYX209VIV@80TI6A
0P24Q8@207emO@80MWIf0P1HF5P206IVIP80IFEU0P1NGUh00`1RHV80Cdm?04m?C`0204];B`80=CDe
0P1XJ6P207moO`80De=C0P27QhL204e=C@80>3Ph0P0Z:RX205eMG@80FEUI0P2<S8`206i^KP80OWin
00<0NGUi07MgM`1gMgL00P1^KVh208F5Q@80Ng]k0P2FUYH208f=S@80Zj^[0P2VYZH208F5Q@80LW9b
0P1jNWX207alO080OGem0P2ATI420:^[Z`030:NWY`2NWYh0WYjN0080Vi^K0P2_[jl20<W9b@80clo?
0P3<c<`20=;BdP80dM7A0P3=cLd20=7Ad@80c<c<0P3?cll20<g=c@80clo?0P3AdM400`3De=@0dm?C
0=?Cd`040<o?c`80dm?C103AdM420<c<c1D0oooo000C0?ooo`80e]KF0P3EeMD20=7Ad@80dm?C0P3=
cLd20<[:bP80d];B0P3De=@00`3AdM40e=CD0=CDe0020=?Cd`80dM7A0P3@d=020<[:bP80c<c<0P3>
c/h40=7Ad@80d=3@0P3De=@20=7Ad@80d];B0P3Fe]H20<o?c`030<c<c038b<P0b<S80080_[jn0P2W
YjL209BDU080PH610P1dM7@206YZJP80F5QH0P1NGUh205ADE080FUYJ0P0b<S8203`l?080?clo0P1;
Bd/00`1=CDd0N7Qh07QhN0020;Rh^080/[:b0P2_[jl20;Jf]P80^KVi0P2k^k/20<30`080^k^k102o
_kl20;Jf]P80/[:b0P2`/;020:n_[`030;2`/02[Zj/0Zj^[0080XJ6Q0P2OWil20:JVYP80WinO0P2J
VYX209VIV@80TI6A0P24Q8@207emO@80MWIf0P1HF5P206IVIP80IFEU0P1NGUh00`1RHV80Cdm?04m?
C`0204];B`80=CDe0P1XJ6P207moO`80De=C0P27QhL204e=C@80>3Ph0P0Z:RX205eMG@80FEUI0P2<
S8`206i^KP80OWin00<0NGUi07MgM`1gMgL00P1^KVh208F5Q@80Ng]k0P2FUYH208f=S@80Zj^[0P2V
YZH208F5Q@80LW9b0P1jNWX207alO080OGem0P2ATI420:^[Z`030:NWY`2NWYh0WYjN0080Vi^K0P2_
[jl20<W9b@80clo?0P3<c<`20=;BdP80dM7A0P3=cLd20=7Ad@80c<c<0P3?cll20<g=c@80clo?0P3A
dM400`3De=@0dm?C0=?Cd`040<o?c`80dm?C103AdM420<c<c1D0oooo000C0?ooo`80bLW90P3<c<`4
0<o?c`@0dM7A103>c/h00`3AdM40bLW90<W9b@020<c<c080c/k>0P3:b/X20<g=c@@0bl_;0P3AdM42
0<W9b@80b<S80P3:b/X20=7Ad@80c<c<0P39bLT20=7Ad@030<k>cP35aLD0aLG50080_;bl0P2NWYh2
08n?S`80Ng]k0P1iNGT206=SH`80FEUI0P1CDe<204m?C`80@T920P0m?Cd203hn?P80ADE50P13@d<0
0`1FEUH0/;2`0;2`/0020;6a/@H0][Jf0P2k^k/20;Zj^P80^KVi0P2l_;`20;Bd]080^KVi0P2l_;`2
0;>c/`80]kNg0P2d];@00`2c/k<0[jn_0:n_[`020;>c/`80ZZZZ0P2SXj<40::RXP80Vi^K0P2IVIT2
096AT@80R8R80P20P80206e]K@80E5AD0P1JFUX206=SH`03059BDP1CDe<0De=C0080?clo0P0l?3`2
04];B`80QXJ60P1bLW8205eMG@80QXJ60P17AdL206EUI@80@D510P1OGel2069RHP80NGUi0P1SHf<3
07alO080KVi^0P2;Rh/207moO`80QHF50P2CTi<209JFUP80]KFe0P2TY:@206MWI`80K6a/1029RHT2
08b<S080VIVI00<0VYZJ09RHV02HV9P00P2UYJD20;Zj^P80bLW90P36a/H40<[:bP80cLg=0P3AdM42
0<o?c`@0dM7A0P39bLT20<g=c@80dM7A00<0b/[:0<o?c`3?cll00P3>c/h20<W9b@80cLg=0P3AdM42
0<c<c080dM7A5@3oool001<0oooo0P39bLT20<c<c0@0clo?103AdM440<k>cP030=7Ad@39bLT0bLW9
0080c<c<0P3>c/h20<[:bP80cLg=103;bl/20=7Ad@80bLW90P38b<P20<[:bP80dM7A0P3<c<`20<W9
b@80dM7A00<0c/k>0<G5a@35aLD00P2l_;`209jNWP80Shn?0P1kNg/207UiN@80Hf=S0P1IFET205=C
D`80Cdm?0P12@T8203dm?@80?Shn0P15ADD204=3@`0305IFEP2`/;00/;2`0080/K6a1P2f][H20;^k
^`80^[Zj0P2i^KT20;bl_080];Bd0P2i^KT20;bl_080/k>c0P2g]kL20;Bd]0030;>c/`2_[jl0[jn_
0080/k>c0P2ZZZX20:>SX`@0XZ:R0P2KVi/209VIV@80TI6A0P28R8P20820P080KFe]0P1DE5@205YJ
FP80Hf=S00<0DU9B05=CD`1CDe<00P0o?cl203`l?080Bd];0P26QXH2079bLP80GEeM0P26QXH204M7
A`80IFEU0P11@D4205mOG`80HV9R0P1iNGT206=SH`<0O7al0P1^KVh208^;R`80Ogmo0P25QHD209>C
T`80UYJF0P2e]KD20:BTY080IfMW0P1/K6`408V9R@80S8b<0P2IVIT00`2JVYX0V9RH09RHV0020:FU
Y@80^[Zj0P39bLT20<K6aP@0b/[:0P3=cLd20=7Ad@80clo?103AdM420<W9b@80cLg=0P3AdM400`3:
b/X0clo?0<o?c`020<k>cP80bLW90P3=cLd20=7Ad@80c<c<0P3AdM4E0?ooo`004`3oool20<W9b@80
c<c<103?cll40=7Ad@80clo?0P3<c<`00`3=cLd0e=CD0=CDe0040=CDe080dM7A0P39bLT20<g=c@80
dM7A0P3=cLd20=CDe0@0eMGE0P3De=@20=?Cd`80c/k>0`36a/H20<;2`P80[jn_0P2NWYh208:2PP80
MgMg0P1UIFD2069RHP80FUYJ0P1GEeL203/k>`80@d=30P0f=SH203Ti>@80G5aL0P1DE5@00`2_[jl0
[Zj^0:j^[P020;Fe]@@0^[Zj0P2f][H20;Bd]080]KFe0P2d];@20;Jf]P80]KFe102g]kL20;2`/080
Zj^[0P2ZZZX00`2`/;00/[:b0;:b/P020:j^[P80ZJVY0P2SXj<209nOW`80VIVI0P2JVYX209bLW080
V9RH0P2BTY8208Z:RP80Ph>30P1^KVh2055AD@80D51@00<0De=C04];B`1;Bd/00P12@T8203Ti>@80
ATI60P1WIfL208^;R`80IfMW0P1]KFd207YjNP80C4a<0P1WIfL204Q8B080L71`0P1eMGD206e]K@03
06a/K01bLW80LW9b0080N7Qh0P1ZJVX208N7Q`80P8200P2CTi<209FEU@80VYZJ0P2KVi/208R8R080
MgMg0P1]KFd207moO`80RHV90P2DU9@00`2QXJ40[:b/0:b/[0020;Ng]`80bLW90P2i^KT40<[:bP80
cLg=0P3>c/h20<[:bP@0clo?0P3AdM420=?Cd`@0clo?00<0dM7A0<c<c03<c<`0103AdM420<k>cP80
c<c<103AdM4E0?ooo`004`3oool20<W9b@80c<c<103?cll40=7Ad@80clo?0P3<c<`00`3=cLd0e=CD
0=CDe0040=CDe080dM7A0P39bLT20<g=c@80dM7A0P3=cLd20=CDe0@0eMGE0P3De=@20=?Cd`80c/k>
0`36a/H20<;2`P80[jn_0P2NWYh208:2PP80MgMg0P1UIFD2069RHP80FUYJ0P1GEeL203/k>`80@d=3
0P0f=SH203Ti>@80G5aL0P1DE5@00`2_[jl0[Zj^0:j^[P020;Fe]@@0^[Zj0P2f][H20;Bd]080]KFe
0P2d];@20;Jf]P80]KFe102g]kL20;2`/080Zj^[0P2ZZZX00`2`/;00/[:b0;:b/P020:j^[P80ZJVY
0P2SXj<209nOW`80VIVI0P2JVYX209bLW080V9RH0P2BTY8208Z:RP80Ph>30P1^KVh2055AD@80D51@
00<0De=C04];B`1;Bd/00P12@T8203Ti>@80ATI60P1WIfL208^;R`80IfMW0P1]KFd207YjNP80C4a<
0P1WIfL204Q8B080L71`0P1eMGD206e]K@0306a/K01bLW80LW9b0080N7Qh0P1ZJVX208N7Q`80P820
0P2CTi<209FEU@80VYZJ0P2KVi/208R8R080MgMg0P1]KFd207moO`80RHV90P2DU9@00`2QXJ40[:b/
0:b/[0020;Ng]`80bLW90P2i^KT40<[:bP80cLg=0P3>c/h20<[:bP@0clo?0P3AdM420=?Cd`@0clo?
00<0dM7A0<c<c03<c<`0103AdM420<k>cP80c<c<103AdM4E0?ooo`004`3oool60=7Ad@80c<c<1P3A
dM420<c<c0030<k>cP39bLT0bLW90080b/[:103<c<`20=7Ad@80c/k>0P3<c<`20<o?c`80c<c<103:
b/X20<W9b@80cLg=0P3De=@20<g=c@030;jn_P2f][H0][Jf0080YZJV0P2?Shl207IfMP80LG5a0P1S
Hf<2051@D080FEUI0P1BDU8203Xj>P80>3Ph0P12@T8202/[:`80=3@d0P2^[Zh00`2a/K40];Bd0;Bd
]0020;6a/@80[jn_0P2a/K420;:b/P80[Zj^0P2ZZZX20::RXP80X:2P1P2OWil209fMW@80W9bL0P2R
XZ800`2LW9`0X:2P0:2PX0020:6QX@80Y:BT0P2YZJT40:>SX`80WYjN0P2KVi/209RHV080U9BD0P2>
SXh208f=S@80Rh^;0P1eMGD205EEE@0304];B`1<C4`0C4a<0080?clo0P0a<C4203lo?`80Fe]K101j
NWX206][J`80T92@0P1kNg/207UiN@80FUYJ0P1=CDd2075aL@80Q8B400<0LG5a06e]K@1]KFd0101_
Kfl208J6QP80RHV90P2=SHd208n?S`80YJFU0P2d];@209BDU080NGUi0P27QhL208b<S080PX:20P29
RHT00`2PX:00^[Zj0;Zj^P020<O7a`80`<300P3<c<`20<[:bP80b<S80P39bLT20=?Cd`80c/k>0P3=
cLd20=7Ad@80alO70P3<c<`20<o?c`<0c<c<0P3AdM420=?Cd`P0dM7A0P3>c/hE0?ooo`004`3oool6
0=7Ad@80c<c<1P3AdM420<c<c0030<k>cP39bLT0bLW90080b/[:103<c<`20=7Ad@80c/k>0P3<c<`2
0<o?c`80c<c<103:b/X20<W9b@80cLg=0P3De=@20<g=c@030;jn_P2f][H0][Jf0080YZJV0P2?Shl2
07IfMP80LG5a0P1SHf<2051@D080FEUI0P1BDU8203Xj>P80>3Ph0P12@T8202/[:`80=3@d0P2^[Zh0
0`2a/K40];Bd0;Bd]0020;6a/@80[jn_0P2a/K420;:b/P80[Zj^0P2ZZZX20::RXP80X:2P1P2OWil2
09fMW@80W9bL0P2RXZ800`2LW9`0X:2P0:2PX0020:6QX@80Y:BT0P2YZJT40:>SX`80WYjN0P2KVi/2
09RHV080U9BD0P2>SXh208f=S@80Rh^;0P1eMGD205EEE@0304];B`1<C4`0C4a<0080?clo0P0a<C42
03lo?`80Fe]K101jNWX206][J`80T92@0P1kNg/207UiN@80FUYJ0P1=CDd2075aL@80Q8B400<0LG5a
06e]K@1]KFd0101_Kfl208J6QP80RHV90P2=SHd208n?S`80YJFU0P2d];@209BDU080NGUi0P27QhL2
08b<S080PX:20P29RHT00`2PX:00^[Zj0;Zj^P020<O7a`80`<300P3<c<`20<[:bP80b<S80P39bLT2
0=?Cd`80c/k>0P3=cLd20=7Ad@80alO70P3<c<`20<o?c`<0c<c<0P3AdM420=?Cd`P0dM7A0P3>c/hE
0?ooo`004`3oool20=7Ad@@0clo?1P3AdM420<c<c0D0dM7A103?cll80=7Ad@80c/k>0P3:b/X20<g=
c@80dM7A0P3De=@20<o?c`80cLg=0P3;bl/00`35aLD0][Jf0;Jf]P0209jNWP80RXZ:0P1jNWX206MW
I`80Jf][0P1BDU8204e=C@80ADE50P10@40203/k>`80ADE50P25QHD20;2`/080][Jf0`2h^;P20;>c
/`@0[jn_0P2PX:020::RXP80Z:RX0P2OWil209ZJVP80TI6A1P2=SHd208F5Q@80T92@00<0UIFE09BD
U02DU9@00P2YZJT209nOW`80Vi^K0P2VYZH20:>SX`80X:2P102IVIT209>CT`80T92@0P2<S8`208B4
Q080P8200P1]KFd00`11@D40?Shn03hn?P0203/k>`80:BTY0P0f=SH2051@D080MWIf0P29RHT205YJ
FP80KFe]0P2ATI42079bLP80Ogmo0P1RHV8205YJFP80KVi^00<0Q8B407=cL`1cLg<00P1[Jf/207em
O@80Q8B40P2BTY8208R8R080XJ6Q0P2?Shl20:BTY080YJFU0P2:RXX2092@T080QHF50P2ATI4209JF
UP0309ZJVP2c/k<0/k>c0080c<c<0P38b<P20<c<c080c/k>103Bd]820<g=c@80eMGE0P3?cll20<[:
bP80dm?C0P3AdM420<k>cP80cLg=00<0dm?C0<k>cP3>c/h00P3=cLd20=?Cd`@0dM7A0P3Cdm<20=7A
dAD0oooo000C0?ooo`80dM7A103?cll40=7Ad@80cLg=0P3Cdm<50=7Ad@@0clo?103AdM440=CDe080
dM7A0P3?cll20<_;b`80a/K60P3;bl/20=;BdP80bLW90P32`/800`2b/[80[:b/0:b/[0020:6QX@80
Ng]k0P1/K6`206ATI080G5aL0P1ADE42051@D080@4100P0i>CT204=3@`80>c/k0P15ADD40;2`/003
0:n_[`2`/;00/;2`0080[Jf]0P2WYjL20:n_[`80VIVI0P1eMGD206m_K`80IfMW0P1cLg<208>3P`80
Q8B40P1kNg/207IfMP80O7al0P1^KVh00`1`L700Kfm_06m_K`0207]kN`80Xj>S0P2RXZ8209nOW`80
YZJV0P2RXZ8209jNWP80W9bL0P2IVIT2092@T080SHf=0P2:RXX208>3P`80NWYj00<0IFEU03Xj>P0j
>SX00P0/;2`202d];@80:2PX0P1>CTh203Ph>080Y:BT0P22PX8206=SH`80WinO0P25QHD209NGU`80
R8R80P1eMGD2075aL@0307AdM01^KVh0KVi^0080P8200P1UIFD207MgM`80QhN70P2:RXX208^;R`80
X:2P0P2QXJ420:NWY`80TI6A0P2>SXh209ZJVP80S8b<0P2LW9`00`2c/k<0YZJV0:JVYP020;Ng]`80
aLG50P37alL20<K6aP80a<C40P3;bl/20=7Ad@80b/[:1P3?cll20=7Ad@80e=CD0P3AdM400`3<c<`0
dM7A0=7Ad@020=7Ad@80c<c<103AdM420<o?c`80dM7A5@3oool001<0oooo0P3AdM440<o?c`@0dM7A
0P3=cLd20=?Cd`D0dM7A103?cll40=7Ad@@0e=CD0P3AdM420<o?c`80bl_;0P36a/H20<_;b`80d];B
0P39bLT20<;2`P030;:b/P2/[:`0[:b/0080XJ6Q0P1kNg/206a/K080I6AT0P1LG5`2055AD@80D51@
0P10@40203Ti>@80@d=30P0k>c/204E5A@@0/;2`00<0[jn_0;2`/02`/;000P2][Jd20:NWY`80[jn_
0P2IVIT207EeM@80Kfm_0P1WIfL207=cL`80Ph>30P24Q8@207]kN`80MWIf0P1lO7`206i^KP03071`
L01_Kfl0Kfm_0080Ng]k0P2SXj<20::RXP80WinO0P2VYZH20::RXP80WYjN0P2LW9`209VIV@80T92@
0P2=SHd208Z:RP80Ph>30P1jNWX00`1UIFD0>SXj03Xj>P0202`/;080;Bd]0P0X:2P204i>CP80>3Ph
0P2TY:@208:2PP80Hf=S0P2OWil208F5Q@80UiNG0P28R8P207EeM@80LG5a00<0M7Ad06i^KP1^KVh0
0P20P80206EUI@80MgMg0P27QhL208Z:RP80Rh^;0P2PX:020:6QX@80YjNW0P2ATI4208j>SP80VYZJ
0P2<S8`209bLW0030;>c/`2VYZH0YZJV0080]kNg0P35aLD20<O7a`80a/K60P34a<@20<_;b`80dM7A
0P3:b/X60<o?c`80dM7A0P3De=@20=7Ad@030<c<c03AdM40dM7A0080dM7A0P3<c<`40=7Ad@80clo?
0P3AdM4E0?ooo`004`3oool20=CDe080dM7A0P3=cLd20=7Ad@80cLg=0P3AdM420<g=c@80dm?C00<0
dM7A0=CDe03De=@00P3AdM420<g=c@80e=CD0P3AdM420<c<c080c/k>0P3De=@20=;BdP80d=3@0P3A
dM440<k>cP80bl_;0P37alL00`2k^k/0[:b/0:b/[00208n?S`80NWYj0P1KFe/2065QH@80E5AD0P1E
EED203@d=080ADE50P0m?Cd205=CD`80Jf][0P2b/[840:f][@030:n_[`2a/K40/K6a0080];Bd0P2C
Ti<208b<S080QHF50P23Ph<209FEU@80/K6a0P2OWil2096AT@80Rh^;0P2OWil2096AT@80QHF50P21
PH400`2;Rh/0Lg=c07=cL`0407EeM@80ZZZZ102OWil20:>SX`80X:2P0P2IVIT209RHV080UiNG0P2A
TI4208b<S080Ph>30P21PH400`1dM7@0GUiN05iNGP04038b<P8071`L0P0j>SX2051@D080G5aL0P2P
X:0207moO`80MgMg0P2DU9@207EeM@80YJFU0P28R8P206QXJ00307YjNP1oOgl0Ogmo0080JFUY0P1`
L70207alO080RHV90P26QXH208j>SP80U9BD0P2XZ:P20:^[Z`80UiNG101mOGd208N7Q`80VIVI00<0
/;2`0<C4a034a<@00P36a/H20<S8b080bLW90P3:b/X20=7Ad@80cLg=0P37alL20<W9b@80c<c<0P3>
c/h20<g=c@80dM7A0P39bLT20<c<c0030=7Ad@3>c/h0c/k>0080c<c<0P3AdM420<k>cP80bLW90P3<
c<`20<k>cQD0oooo000C0?ooo`80e=CD0P3AdM420<g=c@80dM7A0P3=cLd20=7Ad@80cLg=0P3Cdm<0
0`3AdM40e=CD0=CDe0020=7Ad@80cLg=0P3De=@20=7Ad@80c<c<0P3>c/h20=CDe080d];B0P3@d=02
0=7Ad@@0c/k>0P3;bl/20<O7a`030;^k^`2/[:`0[:b/0080Shn?0P1jNWX205]KF`80HF5Q0P1DE5@2
05EEE@80=3@d0P15ADD203dm?@80De=C0P1[Jf/20;:b/P@0[Jf]00<0[jn_0;6a/@2a/K400P2d];@2
09>CT`80S8b<0P25QHD208>3P`80UIFE0P2a/K4209nOW`80TI6A0P2;Rh/209nOW`80TI6A0P25QHD2
0861P@0308^;R`1cLg<0Lg=c00@0MGEe0P2ZZZX409nOW`80Xj>S0P2PX:0209VIV@80V9RH0P2GUiL2
096AT@80S8b<0P23Ph<20861P@0307AdM01NGUh0GUiN00@0<S8b0P0L71`203Xj>P80D51@0P1LG5`2
0:2PX080Ogmo0P1gMgL209BDU080MGEe0P2UYJD208R8R080J6QX00<0NWYj07moO`1oOgl00P1YJFT2
071`L080O7al0P29RHT208J6QP80SXj>0P2DU9@20:RXZ080Zj^[0P2GUiL407emO@80QhN70P2IVIT0
0`2`/;00a<C40<C4a0020<K6aP80b<S80P39bLT20<[:bP80dM7A0P3=cLd20<O7a`80bLW90P3<c<`2
0<k>cP80cLg=0P3AdM420<W9b@80c<c<00<0dM7A0<k>cP3>c/h00P3<c<`20=7Ad@80c/k>0P39bLT2
0<c<c080c/k>5@3oool001<0oooo0P39bLT20<c<c080c/k>0P3<c<`40<o?c`80dM7A0P3=cLd00`3A
dM40cLg=0<g=c@040<o?c`@0cLg=0P3<c<`20<W9b@80b/[:0P3<c<`20<g=c@80dM7A0P3@d=020<g=
c@80a/K60P2d];@00`2RXZ80T92@092@T00207MgM`80K6a/0P1HF5P205IFEP80CDe=0P0o?cl204U9
B@80<S8b0P1:BTX204U9B@80Lg=c1P2d];@00`2_[jl0YjNW0:NWY`020;>c/`80Ti>C0P1/K6`207Yj
NP80P8200P22PX82079bLP80MWIf0P1nOWh207EeM@80IVIV0P1IFET2065QH@80J6QX00<0FEUI07]k
N`1kNg/00P1XJ6P205mOG`80MWIf0P2`/;020:n_[`P0XZ:R0P2HV9P208j>SP80Shn?0P2<S8`208J6
QP0307emO@1cLg<0Lg=c0080DE5A0P0Q8B42020P8080=CDe0P16ATH206=SH`80Shn?0P23Ph<205mO
G`80XZ:R0P22PX8209:BTP80[jn_0P2LW9`00`1RHV80Kfm_06m_K`02071`L080O7al0P1XJ6P207mo
O`80R8R80P24Q8@209fMW@80V9RH0P2YZJT209VIV@80OWin0P27QhL208>3P`80SXj>00<0[:b/0<W9
b@39bLT00P37alL20<c<c080`L710P37alL20=KFeP@0dM7A0P3Cdm<20=7Ad@80dm?C0P3>c/h20<c<
c0/0dM7A0P3Cdm<20=7Ad@80dm?C0P3AdM4E0?ooo`004`3oool20<W9b@80c<c<0P3>c/h20<c<c0@0
clo?0P3AdM420<g=c@030=7Ad@3=cLd0cLg=00@0clo?103=cLd20<c<c080bLW90P3:b/X20<c<c080
cLg=0P3AdM420=3@d080cLg=0P36a/H20;Bd]0030::RXP2@T900T92@0080MgMg0P1/K6`205QHF080
EUIF0P1=CDd203lo?`80BDU90P0b<S8204Y:BP80BDU90P1cLg<60;Bd]0030:n_[`2WYjL0YjNW0080
/k>c0P2CTi<206a/K080NWYj0P20P80208:2PP80LW9b0P1fMWH207inOP80MGEe0P1VIVH205UIF@80
HF5Q0P1XJ6P00`1IFET0Ng]k07]kN`0206QXJ080GemO0P1fMWH20;2`/080[jn_202RXZ8209RHV080
SXj>0P2?Shl208b<S080QXJ600<0OGem07=cL`1cLg<00P1ADE42024Q8@80820P0P0e=CD204I6AP80
Hf=S0P2?Shl208>3P`80GemO0P2RXZ8208:2PP80TY:B0P2_[jl209bLW003069RHP1_Kfl0Kfm_0080
L71`0P1lO7`206QXJ080Ogmo0P28R8P208B4Q080WIfM0P2HV9P20:VYZ@80VIVI0P1nOWh208N7Q`80
Ph>30P2>SXh00`2/[:`0bLW90<W9b@020<O7a`80c<c<0P31`L420<O7a`80e]KF103AdM420=?Cd`80
dM7A0P3Cdm<20<k>cP80c<c<2`3AdM420=?Cd`80dM7A0P3Cdm<20=7AdAD0oooo000C0?ooo`H0e=CD
0P3Cdm<20<k>cP80b/[:0P3?cll20=7Ad@030<[:bP3<c<`0c<c<0080cLg=0P3AdM420<[:bP80c<c<
0P3=cLd20=CDe080dM7A0P3=cLd20<o?c`80d];B103>c/h20<K6aP80[jn_00<0UiNG08F5Q@25QHD0
0P1`L70205]KF`80FEUI0P1<C4`204e=C@80A4A40P0o?cl20410@080?3`l0P1DE5@20;Fe]@80]kNg
0P2a/K420:^[Z`030:n_[`2KVi/0Vi^K0080NGUi0P1XJ6P205UIF@80D51@0P1GEeL206IVIP80IFEU
0P1QHF4206=SH`80Fe]K0P1IFET204e=C@80B4Q80P1ADE400`1>CTh0@T920492@P0203/k>`@0<C4a
0P1EEED208^;R`@0XZ:R0P2QXJ4209ZJVP80W9bL0P2DU9@208b<S0@0Shn?00<0QXJ607EeM@1eMGD0
0P1RHV8203<c<`806QXJ0P0N7Qh203lo?`80EUIF0P1[Jf/209NGU`80N7Qh0P1QHF4209^KV`80M7Ad
0P2][Jd20:j^[P030:6QX@1^KVh0KVi^0080Ph>30P1^KVh207IfMP80Ng]k0P20P80207QhN080Rh^;
0P2PX:020:n_[`80YZJV0P2@T90209VIV@80TI6A0P2EUID00`2OWil0_kno0;no_`020<W9b@80alO7
0P3>c/h20<[:bP80bl_;0P3De=@20=7Ad@80c<c<0P3>c/h20<c<c080dM7A0P3Cdm<40=7Ad@030=?C
d`3AdM40dM7A00@0dM7A0P3<c<`40<o?c`80dM7A5@3oool001<0oooo1P3De=@20=?Cd`80c/k>0P3:
b/X20<o?c`80dM7A00<0b/[:0<c<c03<c<`00P3=cLd20=7Ad@80b/[:0P3<c<`20<g=c@80e=CD0P3A
dM420<g=c@80clo?0P3Bd]840<k>cP80a/K60P2_[jl00`2GUiL0QHF508F5Q@02071`L080Fe]K0P1I
FET204a<C080CDe=0P14A4@203lo?`80@4100P0l?3`205ADE080]KFe0P2g]kL20;6a/@80Zj^[00<0
[jn_09^KV`2KVi/00P1iNGT206QXJ080FEUI0P1@D50205MGE`80IVIV0P1UIFD2065QH@80Hf=S0P1K
Fe/205UIF@80CDe=0P18B4P2055AD@0304i>CP12@T80@T920080>c/k100a<C4205EEE@80Rh^;102R
XZ820:6QX@80VYZJ0P2LW9`209BDU080S8b<102?Shl00`26QXH0MGEe07EeM@02069RHP80<c<c0P0J
6QX201hN7P80?clo0P1FEUH206][J`80UiNG0P1hN7P2065QH@80Vi^K0P1dM7@20:f][@80[Zj^00<0
XJ6Q06i^KP1^KVh00P23Ph<206i^KP80MWIf0P1kNg/20820P080N7Qh0P2;Rh/20:2PX080[jn_0P2V
YZH2092@T080VIVI0P2ATI4209FEU@0309nOW`2o_kl0_kno0080bLW90P37alL20<k>cP80b/[:0P3;
bl/20=CDe080dM7A0P3<c<`20<k>cP80c<c<0P3AdM420=?Cd`@0dM7A00<0dm?C0=7Ad@3AdM40103A
dM420<c<c0@0clo?0P3AdM4E0?ooo`004`3oool20<W9b@80b/[:0P3=cLd20<o?c`@0dM7A0P39bLT2
0<c<c0L0clo?0P3>c/h20<c<c080c/k>0P39bLT20<[:bP80cLg=0P3:b/X20<c<c080c/k>0P3:b/X2
0;jn_P80[Zj^00<0Shn?07EeM@1eMGD00P1ZJVX205=CD`80C4a<0P1?Cdl204E5A@80BDU90P16ATH2
04a<C080P820102e]KD20;2`/0@0][Jf00<0[Jf]0:VYZ@2YZJT00P2RXZ8209FEU@80HV9R0P17AdL2
04A4A080AdM70P13@d<20451@@80EeMG0P1EEED203Lg=`80?3`l0P13@d<204M7A`0304e=C@1RHV80
HV9R0080QXJ60P2>SXh209>CT`80V9RH0P2LW9`20::RXP80WinO0P2KVi/209bLW080WIfM0P2JVYX2
09>CT`80S8b<0P2?Shl00`2:RXX0Ph>308>3P`0206i^KP80BTY:0P0X:2P201<C4`80@d=30P10@402
05iNGP80O7al0P2GUiL206][J`80Ogmo0P1kNg/2092@T080_kno00<0[Zj^096AT@2ATI400P1[Jf/2
07QhN080Lg=c0P1gMgL208J6QP80O7al0P20P80209VIV@@0Zj^[0P2DU9@208f=S@80Ti>C0P2][Jd0
0`2k^k/0a/K60<K6aP020<G5a@80a<C40P38b<P40<W9b@80b/[:0P3?cll60=7Ad@80c/k>0P3<c<`4
0=7Ad@030<g=c@3Cdm<0dm?C0080c/k>0P3<c<`40=7Ad@80c<c<0P3AdM4E0?ooo`004`3oool20<W9
b@80b/[:0P3=cLd20<o?c`@0dM7A0P39bLT20<c<c0L0clo?0P3>c/h20<c<c080c/k>0P39bLT20<[:
bP80cLg=0P3:b/X20<c<c080c/k>0P3:b/X20;jn_P80[Zj^00<0Shn?07EeM@1eMGD00P1ZJVX205=C
D`80C4a<0P1?Cdl204E5A@80BDU90P16ATH204a<C080P820102e]KD20;2`/0@0][Jf00<0[Jf]0:VY
Z@2YZJT00P2RXZ8209FEU@80HV9R0P17AdL204A4A080AdM70P13@d<20451@@80EeMG0P1EEED203Lg
=`80?3`l0P13@d<204M7A`0304e=C@1RHV80HV9R0080QXJ60P2>SXh209>CT`80V9RH0P2LW9`20::R
XP80WinO0P2KVi/209bLW080WIfM0P2JVYX209>CT`80S8b<0P2?Shl00`2:RXX0Ph>308>3P`0206i^
KP80BTY:0P0X:2P201<C4`80@d=30P10@40205iNGP80O7al0P2GUiL206][J`80Ogmo0P1kNg/2092@
T080_kno00<0[Zj^096AT@2ATI400P1[Jf/207QhN080Lg=c0P1gMgL208J6QP80O7al0P20P80209VI
V@@0Zj^[0P2DU9@208f=S@80Ti>C0P2][Jd00`2k^k/0a/K60<K6aP020<G5a@80a<C40P38b<P40<W9
b@80b/[:0P3?cll60=7Ad@80c/k>0P3<c<`40=7Ad@030<g=c@3Cdm<0dm?C0080c/k>0P3<c<`40=7A
d@80c<c<0P3AdM4E0?ooo`004`3oool20=CDe080dM7A0P39bLT20<c<c080c/k>0P3<c<`20=7Ad@80
dm?C00<0c/k>0<c<c03<c<`0103?cll20=7Ad@80e=CD0P3Cdm<20=7Ad@@0c/k>0P3Bd]820<[:bP80
bLW90P3:b/X20<K6aP80Xj>S00<0PH6106UYJ@1YJFT0101JFUX204m?C`80?3`l0P1;Bd/204E5A@80
A4A40P1DE5@205UIF@80/K6a0P2_[jl20;Bd]080/[:b0P2^[Zh00`2c/k<0[Jf]0:f][@020;Ng]`80
][Jf0P2i^KT20;Zj^P80][Jf0P2YZJT20;6a/@80];Bd0P2_[jl20;:b/P80_Kfm0P2i^KT20;Jf]P80
/K6a00<0Z:RX0:JVYP2VYZH00P2UYJD20:>SX`80X:2P0P2LW9`40:>SX`80XJ6Q0P2PX:0209fMW@80
VYZJ0P2HV9P209NGU`80TY:B0P2<S8`00`2>SXh0R8R808R8R00207UiN@80Fe]K0P0Z:RX202<S8`80
?Cdm0P1ADE4405QHF080NWYj0P1QHF4206=SH`80Q8B40P1/K6`209BDU0030:f][@2IVIT0VIVI0080
OGem0P1jNWX207QhN0@0KFe]0P25QHD208^;R`80UYJF0P2KVi/20:^[Z`80V9RH0P2=SHd20820P080
WIfM00<0_;bl0<C4a034a<@00P3:b/X20<C4a080a/K6103AdM440<o?c`@0dM7A103De=@20=?Cd`80
c/k>0P3<c<`00`3>c/h0c<c<0<c<c0040=7Ad@80c/k>0P3<c<`40=7AdAD0oooo000C0?ooo`80e=CD
0P3AdM420<W9b@80c<c<0P3>c/h20<c<c080dM7A0P3Cdm<00`3>c/h0c<c<0<c<c0040<o?c`80dM7A
0P3De=@20=?Cd`80dM7A103>c/h20=;BdP80b/[:0P39bLT20<[:bP80a/K60P2SXj<00`21PH40JFUY
06UYJ@0405YJFP80Cdm?0P0l?3`204];B`80ADE50P14A4@205ADE080FEUI0P2a/K420:n_[`80];Bd
0P2b/[820:j^[P030;>c/`2][Jd0[Jf]0080]kNg0P2f][H20;Vi^@80^[Zj0P2f][H20:VYZ@80/K6a
0P2d];@20:n_[`80/[:b0P2m_Kd20;Vi^@80][Jf0P2a/K400`2XZ:P0YZJV0:JVYP020:FUY@80Xj>S
0P2PX:0209bLW0@0Xj>S0P2QXJ420:2PX080WIfM0P2JVYX209RHV080UiNG0P2BTY8208b<S00308j>
SP28R8P0R8R80080NGUi0P1KFe/202XZ:P808b<S0P0m?Cd2055AD@@0F5QH0P1jNWX2065QH@80Hf=S
0P24Q8@206a/K080U9BD00<0[Jf]09VIV@2IVIT00P1mOGd207YjNP80N7Qh101]KFd208F5Q@80Rh^;
0P2FUYH209^KV`80Zj^[0P2HV9P208f=S@80P8200P2MWId00`2l_;`0a<C40<C4a0020<[:bP80a<C4
0P36a/H40=7Ad@@0clo?103AdM440=CDe080dm?C0P3>c/h20<c<c0030<k>cP3<c<`0c<c<00@0dM7A
0P3>c/h20<c<c0@0dM7A5@3oool001<0oooo0P3=cLd20<o?c`80dM7A1P3De=@20=7Ad@80cLg=00<0
e=CD0=7Ad@3AdM400P3>c/h20<c<c080clo?0P3<c<`20<g=c@80dm?C0P3?cll20<c<c080bl_;0P3>
c/h20<S8b080/[:b0P2QXJ4209FEU@0307AdM01XJ6P0J6QX00@0CDe=0P11@D4204Q8B080@4100P18
B4P204I6AP80M7Ad0P2OWil20;Bd]080][Jf0P2c/k<20;:b/P80];Bd00<0/K6a0;:b/P2b/[800P2`
/;020;Jf]P80^KVi0P2k^k/20;Vi^@80^k^k0P2i^KT20;Rh^080[jn_102`/;020:RXZ080Xj>S0P2Q
XJ400`2PX:00YZJV0:JVYP020:BTY080YZJV0P2WYjL20:n_[`80WIfM0P2UYJD20:JVYP80Xj>S0P2O
Wil209ZJVP80V9RH102FUYH208N7Q`0308:2PP28R8P0R8R80080O7al0P1PH60203dm?@80;2`/0P0N
7Qh205IFEP80FUYJ0P1aLG42079bLP80P8200P1GEeL206i^KP80Ogmo0P2EUID00`2^[Zh0[:b/0:b/
[00209nOW`80TI6A0P1eMGD207moO`80M7Ad0P1eMGD206e]K@80QHF50P2GUiL20;>c/`80WYjN0P2=
SHd209NGU`80Xj>S00<0cLg=0<71`@31`L400P2m_Kd20<o?c`80bl_;0P3Cdm<20=7Ad@@0clo?103A
dM440<W9b@80c<c<0P3AdM420=?Cd`D0dM7A0P3De=@20=?Cd`@0dM7A0P3>c/hE0?ooo`004`3oool2
0<g=c@80clo?0P3AdM460=CDe080dM7A0P3=cLd00`3De=@0dM7A0=7Ad@020<k>cP80c<c<0P3?cll2
0<c<c080cLg=0P3Cdm<20<o?c`80c<c<0P3;bl/20<k>cP80b<S80P2b/[820:6QX@80UIFE00<0M7Ad
06QXJ01XJ6P0101=CDd20451@@80B4Q80P10@40204Q8B080ATI60P1dM7@209nOW`80];Bd0P2f][H2
0;>c/`80/[:b0P2d];@00`2a/K40/[:b0;:b/P020;2`/080][Jf0P2i^KT20;^k^`80^KVi0P2k^k/2
0;Vi^@80^;Rh0P2_[jl40;2`/080Z:RX0P2SXj<20:6QX@030:2PX02VYZH0YZJV0080Y:BT0P2VYZH2
0:NWY`80[jn_0P2MWId20:FUY@80YZJV0P2SXj<209nOW`80VYZJ0P2HV9P409JFUP80QhN700<0PX:2
08R8R028R8P00P1lO7`2061PH080?Cdm0P0/;2`201hN7P80EUIF0P1JFUX2075aL@80LW9b0P20P802
05MGE`80KVi^0P1oOgl209FEU@030:j^[P2/[:`0[:b/0080WinO0P2ATI4207EeM@80Ogmo0P1dM7@2
07EeM@80KFe]0P25QHD209NGU`80/k>c0P2NWYh208f=S@80UiNG0P2SXj<00`3=cLd0`L710<71`@02
0;fm_@80clo?0P3;bl/20=?Cd`80dM7A103?cll40=7Ad@@0bLW90P3<c<`20=7Ad@80dm?C1@3AdM42
0=CDe080dm?C103AdM420<k>cQD0oooo000C0?ooo`80bLW90P3=cLd20=7Ad@80b/[:0P3=cLd40<c<
c080cLg=00<0bl_;0=?Cd`3Cdm<0103AdM420<k>cP80c<c<0P3>c/h20<c<c080c/k>0P3:b/X20<c<
c080bl_;0P3>c/h20<_;b`80VIVI0P1jNWX00`1WIfL0DU9B059BDP0205eMG@80?Cdm0P19BDT203Lg
=`80C4a<0P19BDT203hn?P80SHf=102d];@20;:b/P80]KFe0P2d];@20;2`/0030;:b/P2g]kL0]kNg
0080];Bd1P2f][H20;Ng]`80][Jf0P2e]KD20;Bd]080[Zj^0P2e]KD20:j^[P80[Jf]0P2XZ:P20:^[
Z`030:NWY`2VYZH0YZJV0080YjNW0P2VYZH40:RXZ080[Jf]0P2LW9`209^KV`80W9bL0P2NWYh20:2P
X080UiNG0P2DU9@2096AT@80UIFE00<0RHV908J6QP26QXH00P24Q8@206i^KP80B4Q80P0Z:RX202`/
;080?Cdm0P1FEUH205QHF080H61P0P1XJ6P2061PH080GUiN0P1`L70208N7Q`0309BDU02f][H0][Jf
0080WinO0P1jNWX207]kN`80PH610P1]KFd20820P080MGEe0P1lO7`209>CT`80YjNW0P2NWYh208V9
R@80T92@0P2DU9@00`2o_kl0a<C40<C4a0020;^k^`80_;bl0P3AdM420<c<c080dM7A0P3>c/h20<c<
c080c/k>0P3=cLd20=?Cd`@0dM7A103?cll00`3AdM40dm?C0=?Cd`020<k>cP80bLW90P3<c<`60=7A
dAD0oooo000C0?ooo`80bLW90P3=cLd20=7Ad@80b/[:0P3=cLd40<c<c080cLg=00<0bl_;0=?Cd`3C
dm<0103AdM420<k>cP80c<c<0P3>c/h20<c<c080c/k>0P3:b/X20<c<c080bl_;0P3>c/h20<_;b`80
VIVI0P1jNWX00`1WIfL0DU9B059BDP0205eMG@80?Cdm0P19BDT203Lg=`80C4a<0P19BDT203hn?P80
SHf=102d];@20;:b/P80]KFe0P2d];@20;2`/0030;:b/P2g]kL0]kNg0080];Bd1P2f][H20;Ng]`80
][Jf0P2e]KD20;Bd]080[Zj^0P2e]KD20:j^[P80[Jf]0P2XZ:P20:^[Z`030:NWY`2VYZH0YZJV0080
YjNW0P2VYZH40:RXZ080[Jf]0P2LW9`209^KV`80W9bL0P2NWYh20:2PX080UiNG0P2DU9@2096AT@80
UIFE00<0RHV908J6QP26QXH00P24Q8@206i^KP80B4Q80P0Z:RX202`/;080?Cdm0P1FEUH205QHF080
H61P0P1XJ6P2061PH080GUiN0P1`L70208N7Q`0309BDU02f][H0][Jf0080WinO0P1jNWX207]kN`80
PH610P1]KFd20820P080MGEe0P1lO7`209>CT`80YjNW0P2NWYh208V9R@80T92@0P2DU9@00`2o_kl0
a<C40<C4a0020;^k^`80_;bl0P3AdM420<c<c080dM7A0P3>c/h20<c<c080c/k>0P3=cLd20=?Cd`@0
dM7A103?cll00`3AdM40dm?C0=?Cd`020<k>cP80bLW90P3<c<`60=7AdAD0oooo000C0?ooo`80dM7A
0P3>c/h20<c<c080c/k>0P39bLT20<c<c0@0dM7A00<0c/k>0<g=c@3=cLd00P3Cdm<80=7Ad@@0e=CD
0P3AdM420<W9b@80b/[:0P2o_kl20:^[Z`80Vi^K0P1_Kfl00`1VIVH0FUYJ05YJFP0204I6AP80Bd];
0P12@T8204=3@`80@4100P0o?cl205UIF@80GUiN0P2e]KD20;2`/080/[:b0P2d];@40;Jf]P030;>c
/`2_[jl0[jn_0080][Jf0P2g]kL20;Jf]P80]KFe0P2d];@20;Zj^P80];Bd0P2b/[860:n_[`80XZ:R
0P2SXj<20:RXZ0030:VYZ@2UYJD0YJFU0080ZJVY0P2/[:`20:f][@80X:2P0P2UYJD20:j^[P80[Jf]
0P2RXZ820:2PX080WYjN0P2JVYX209NGU`80TY:B0P2?Shl00`2:RXX0OWin07inOP0207QhN080LW9b
0P1GEeL203<c<`80<C4a0P0i>CT205IFEP80F5QH0P1]KFd206QXJ080MgMg0P1BDU8205iNGP80H61P
00<0XJ6Q0861P@21PH400P2HV9P20;2`/080QHF50P1jNWX206i^KP80LG5a0P28R8P208V9R@80T92@
0P2NWYh209nOW`80QHF50P2CTi<20:^[Z`030<S8b030`<00`<300080`l?30P30`<020<c<c0P0dM7A
0P3Cdm<20<k>cP80c<c<103AdM420<k>cP80cLg=00<0dM7A0<o?c`3?cll0103AdM420=?Cd`H0dM7A
5@3oool001<0oooo0P3AdM420<k>cP80c<c<0P3>c/h20<W9b@80c<c<103AdM400`3>c/h0cLg=0<g=
c@020=?Cd`P0dM7A103De=@20=7Ad@80bLW90P3:b/X20;no_`80Zj^[0P2KVi/206m_K`0306IVIP1J
FUX0FUYJ0080ATI60P1;Bd/20492@P80@d=30P10@40203lo?`80FEUI0P1NGUh20;Fe]@80/;2`0P2b
/[820;Bd]0@0][Jf00<0/k>c0:n_[`2_[jl00P2f][H20;Ng]`80][Jf0P2e]KD20;Bd]080^[Zj0P2d
];@20;:b/PH0[jn_0P2RXZ820:>SX`80Z:RX00<0ZJVY0:FUY@2UYJD00P2YZJT20:b/[080[Jf]0P2P
X:020:FUY@80[Zj^0P2][Jd20::RXP80X:2P0P2NWYh209ZJVP80UiNG0P2BTY8208n?S`0308Z:RP1n
OWh0OWin0080N7Qh0P1bLW8205MGE`80<c<c0P0a<C4203Ti>@80EUIF0P1HF5P206e]K@80J6QX0P1g
MgL2059BDP80GUiN0P1PH6000`2QXJ40PH610861P@0209RHV080/;2`0P25QHD207YjNP80KVi^0P1a
LG4208R8R080RHV90P2@T90209jNWP80WinO0P25QHD209>CT`80Zj^[00<0b<S80<30`030`<000P33
`l<20<30`080c<c<203AdM420=?Cd`80c/k>0P3<c<`40=7Ad@80c/k>0P3=cLd00`3AdM40clo?0<o?
c`040=7Ad@80dm?C1P3AdM4E0?ooo`004`3oool20=CDe080dm?C2P3AdM420=?Cd`<0dM7A0P3?cll4
0=7Ad@80dm?C0P3>c/h20<W9b@80b/[:0P3@d=020=7Ad@80c<c<0P2b/[8209VIV@80Q8B40P1_Kfl0
0`1GEeL0F5QH05QHF00204m?C`80?Shn0P11@D4204Y:BP80AdM70P0i>CT2069RHP80NGUi0P2^[Zh2
0;2`/080/[:b1P2f][H00`2i^KT0^k^k0;^k^`020;Fe]@H0][Jf0P2b/[820:n_[`80[Jf]0P2QXJ42
09BDU080WIfM0P2PX:0209ZJVP80W9bL0P2PX:000`2RXZ80YjNW0:NWY`020:NWY`80[:b/0P2[Zj/2
0;Bd]080/;2`0P2ZZZX20:2PX080Y:BT0P2KVi/209ZJVP80UiNG0P2DU9@209:BTP<0Shn?0P27QhL2
08:2PP80Kfm_0P1IFET203Xj>P805aLG0P0b<S8204e=C@80De=C0P1PH60205UIF@80KVi^0P1MGEd2
05IFEP80CDe=00<0PX:209RHV02HV9P00P2ZZZX209:BTP80O7al0P21PH4207emO@80K6a/0P1kNg/2
08B4Q080Ti>C0P2RXZ820:>SX`80Shn?0P2DU9@20;Rh^0030;Bd]03EeMD0eMGE0080emOG2P3AdM44
0<o?c`X0dM7A0P3>c/h00`39bLT0c<c<0<c<c0020=7Ad@@0clo?1P3AdM4E0?ooo`004`3oool20=CD
e080dm?C2P3AdM420=?Cd`<0dM7A0P3?cll40=7Ad@80dm?C0P3>c/h20<W9b@80b/[:0P3@d=020=7A
d@80c<c<0P2b/[8209VIV@80Q8B40P1_Kfl00`1GEeL0F5QH05QHF00204m?C`80?Shn0P11@D4204Y:
BP80AdM70P0i>CT2069RHP80NGUi0P2^[Zh20;2`/080/[:b1P2f][H00`2i^KT0^k^k0;^k^`020;Fe
]@H0][Jf0P2b/[820:n_[`80[Jf]0P2QXJ4209BDU080WIfM0P2PX:0209ZJVP80W9bL0P2PX:000`2R
XZ80YjNW0:NWY`020:NWY`80[:b/0P2[Zj/20;Bd]080/;2`0P2ZZZX20:2PX080Y:BT0P2KVi/209ZJ
VP80UiNG0P2DU9@209:BTP<0Shn?0P27QhL208:2PP80Kfm_0P1IFET203Xj>P805aLG0P0b<S8204e=
C@80De=C0P1PH60205UIF@80KVi^0P1MGEd205IFEP80CDe=00<0PX:209RHV02HV9P00P2ZZZX209:B
TP80O7al0P21PH4207emO@80K6a/0P1kNg/208B4Q080Ti>C0P2RXZ820:>SX`80Shn?0P2DU9@20;Rh
^0030;Bd]03EeMD0eMGE0080emOG2P3AdM440<o?c`X0dM7A0P3>c/h00`39bLT0c<c<0<c<c0020=7A
d@@0clo?1P3AdM4E0?ooo`004`3oool20<W9b@80c<c<203AdM420<k>cP80cLg=00<0dM7A0<W9b@39
bLT00P3<c<`40=7Ad@80c<c<103AdM420<g=c@80b/[:0P3>c/h20<_;b`80]kNg0P2@T90206i^KP80
G5aL00<0De=C0410@010@4000P1=CDd20451@@80@4100P11@D4203/k>`80>3Ph0P1mOGd20:j^[P@0
/[:b102f][H20;Rh^0<0/k>c0P2f][H20;Bd]080/k>c0P2h^;P20:j^[P80/k>c0P35aLD209bLW080
VIVI0P2GUiL207emO@80TY:B0P2QXJ4209^KV`80SHf=00<0[:b/0:FUY@2UYJD0102WYjL20:BTY080
YJFU102^[Zh20:VYZ@80YJFU0P2][Jd20:6QX@80WIfM0P2GUiL209>CT`80S8b<00<0Shn?08F5Q@25
QHD00P1iNGT2079bLP80IVIV0P10@40201/K6`809BDU0P0d=3@204e=C@80EeMG0P1KFe/2061PH080
J6QX0P1DE5@205iNGP0305eMG@2NWYh0WYjN0080R8R80P2JVYX20:b/[080N7Qh0P22PX8206e]K@80
P8200P1nOWh208R8R080UIFE0P2VYZH20:6QX@80V9RH0P33`l<00`2_[jl0`L710<71`@020:j^[PX0
dM7A0P3>c/h20<c<c140dM7A0P3>c/h20<c<c0@0dM7A0P3Cdm<E0?ooo`004`3oool20<W9b@80c<c<
203AdM420<k>cP80cLg=00<0dM7A0<W9b@39bLT00P3<c<`40=7Ad@80c<c<103AdM420<g=c@80b/[:
0P3>c/h20<_;b`80]kNg0P2@T90206i^KP80G5aL00<0De=C0410@010@4000P1=CDd20451@@80@410
0P11@D4203/k>`80>3Ph0P1mOGd20:j^[P@0/[:b102f][H20;Rh^0<0/k>c0P2f][H20;Bd]080/k>c
0P2h^;P20:j^[P80/k>c0P35aLD209bLW080VIVI0P2GUiL207emO@80TY:B0P2QXJ4209^KV`80SHf=
00<0[:b/0:FUY@2UYJD0102WYjL20:BTY080YJFU102^[Zh20:VYZ@80YJFU0P2][Jd20:6QX@80WIfM
0P2GUiL209>CT`80S8b<00<0Shn?08F5Q@25QHD00P1iNGT2079bLP80IVIV0P10@40201/K6`809BDU
0P0d=3@204e=C@80EeMG0P1KFe/2061PH080J6QX0P1DE5@205iNGP0305eMG@2NWYh0WYjN0080R8R8
0P2JVYX20:b/[080N7Qh0P22PX8206e]K@80P8200P1nOWh208R8R080UIFE0P2VYZH20:6QX@80V9RH
0P33`l<00`2_[jl0`L710<71`@020:j^[PX0dM7A0P3>c/h20<c<c140dM7A0P3>c/h20<c<c0@0dM7A
0P3Cdm<E0?ooo`004`3oool40=CDe080dm?C0P3AdM420=CDe080dm?C0P3AdM420<k>cP030<c<c03A
dM40dM7A0080e=CD0P3AdM420<g=c@80dm?C2P3AdM420<g=c@80YZJV0P24Q8@206MWI`80FEUI0`16
ATH203Xj>P@0ATI60P0n?Sh203Lg=`80A4A40P1ZJVX20:j^[P80[Jf]0P2/[:`20:n_[`80/K6a0P2e
]KD20<30`0<0^;Rh0P2f][H20;Fe]@80];Bd0P2QXJ4207=cL`80OWin0P2^[Zh20:RXZ080VYZJ0P1k
Ng/2051@D080Fe]K0P1jNWX207]kN`0307AdM02JVYX0VYZJ0080YjNW0P2ZZZX20:j^[PH0[jn_0P2^
[Zh20:n_[`80WinO102KVi/209ZJVP80U9BD0P2BTY8308f=S@80P8200P1dM7@206=SH`80DU9B0P0D
51@201dM7@80:b/[0P0o?cl204i>CP@0EEEE0P1/K6`2055AD@80FEUI00<0>CTi08V9R@29RHT00P21
PH4409^KV`80OGem0P22PX8206QXJ080JFUY0P1iNGT207moO`80X:2P0P2][Jd20;>c/`80]KFe0P2a
/K400`33`l<0UiNG09NGU`020=7Ad@80dm?C2P3AdM420=?Cd`P0dM7A0P3Cdm<90=7Ad@80e=CD0P3C
dm<20<k>cP80c<c<5@3oool001<0oooo103De=@20=?Cd`80dM7A0P3De=@20=?Cd`80dM7A0P3>c/h0
0`3<c<`0dM7A0=7Ad@020=CDe080dM7A0P3=cLd20=?Cd`X0dM7A0P3=cLd20:JVYP80Q8B40P1WIfL2
05UIF@<0ATI60P0j>SX404I6AP80?Shn0P0g=cL204A4A080JVYZ0P2^[Zh20:f][@80[:b/0P2_[jl2
0;6a/@80]KFe0P30`<030;Rh^080][Jf0P2e]KD20;Bd]080XJ6Q0P1cLg<207inOP80[Zj^0P2XZ:P2
09ZJVP80Ng]k0P1@D50205]KF`80NWYj0P1kNg/00`1dM7@0VYZJ09ZJVP020:NWY`80ZZZZ0P2^[Zh6
0:n_[`80[Zj^0P2_[jl209nOW`@0Vi^K0P2JVYX209BDU080TY:B0`2=SHd20820P080M7Ad0P1SHf<2
059BDP8051@D0P0M7Ad202/[:`80?clo0P1>CTh405EEE@80K6a/0P1ADE4205UIF@0303Ti>@29RHT0
RHV90080PH61102KVi/207emO@80PX:20P1XJ6P206UYJ@80NGUi0P1oOgl20:2PX080[Jf]0P2c/k<2
0;Fe]@80/K6a00<0`l?309NGU`2GUiL00P3AdM420=?Cd`X0dM7A0P3Cdm<80=7Ad@80dm?C2@3AdM42
0=CDe080dm?C0P3>c/h20<c<c1D0oooo000C0?ooo`@0bLW90P3<c<`20<k>cP80bLW90P3<c<`20=7A
d@80dm?C00<0dM7A0<o?c`3?cll00P3=cLd20<o?c`80c/k>0P3<c<`20=7Ad@80d];B0P3De=@20=7A
d@80c/k>0P32`/8209NGU`80KFe]0P1RHV8204M7A`0305=CD`1:BTX0BTY:0080@4100P12@T8204M7
A`80<c<c0P0b<S8205EEE@80MGEe0P2a/K420;2`/080][Jf0P2k^k/20;Vi^@80/;2`0P2b/[800`2f
][H0/;2`0;2`/0020;Bd]080/k>c0P2k^k/20;Ng]`80];Bd0P2[Zj/20:f][@80[:b/0P2VYZH409RH
V080W9bL102OWil00`2;Rh/0PX:208:2PP0209NGU`80ZJVY102_[jl20:j^[P80[jn_0P2YZJT20:FU
Y@80/k>c0P2^[Zh20:2PX080VYZJ0P2HV9P2092@T0<0R8R80P22PX8207QhN080KFe]0P1NGUh201DE
5@808B4Q0P0L71`20492@P80B4Q80P1FEUH204I6AP80IFEU101EEED00`0e=CD0KVi^06i^KP02092@
T080RXZ:0P2ATI4208:2PP80Ng]k0P1^KVh206UYJ@80MGEe0P26QXH209:BTP80Xj>S0P2/[:`20:2P
X080U9BD00<0[Jf]0=7Ad@3AdM40103?cll80=7Ad@80c/k>0P3<c<`20=7Ad@80dm?C0P3AdM420<k>
cP80c<c<1`3AdM420<k>cP80b/[:0P3?cll40=7AdAD0oooo000C0?ooo`@0bLW90P3<c<`20<k>cP80
bLW90P3<c<`20=7Ad@80dm?C00<0dM7A0<o?c`3?cll00P3=cLd20<o?c`80c/k>0P3<c<`20=7Ad@80
d];B0P3De=@20=7Ad@80c/k>0P32`/8209NGU`80KFe]0P1RHV8204M7A`0305=CD`1:BTX0BTY:0080
@4100P12@T8204M7A`80<c<c0P0b<S8205EEE@80MGEe0P2a/K420;2`/080][Jf0P2k^k/20;Vi^@80
/;2`0P2b/[800`2f][H0/;2`0;2`/0020;Bd]080/k>c0P2k^k/20;Ng]`80];Bd0P2[Zj/20:f][@80
[:b/0P2VYZH409RHV080W9bL102OWil00`2;Rh/0PX:208:2PP0209NGU`80ZJVY102_[jl20:j^[P80
[jn_0P2YZJT20:FUY@80/k>c0P2^[Zh20:2PX080VYZJ0P2HV9P2092@T0<0R8R80P22PX8207QhN080
KFe]0P1NGUh201DE5@808B4Q0P0L71`20492@P80B4Q80P1FEUH204I6AP80IFEU101EEED00`0e=CD0
KVi^06i^KP02092@T080RXZ:0P2ATI4208:2PP80Ng]k0P1^KVh206UYJ@80MGEe0P26QXH209:BTP80
Xj>S0P2/[:`20:2PX080U9BD00<0[Jf]0=7Ad@3AdM40103?cll80=7Ad@80c/k>0P3<c<`20=7Ad@80
dm?C0P3AdM420<k>cP80c<c<1`3AdM420<k>cP80b/[:0P3?cll40=7AdAD0oooo000C0?ooo`P0dM7A
0P3Cdm<40=7Ad@80c<c<0`3AdM420<[:bP80clo?0P3AdM420=;BdP80e=CD103>c/h20=?Cd`80dM7A
0P35aLD208R8R080IVIV0P1JFUX204a<C0030410@018B4P0B4Q80080BDU90P17AdL204A4A080<30`
0P0e=CD2055AD@80L71`0P2^[Zh20;2`/080[jn_0P2a/K420;Zj^P80^k^k0P2l_;`00`2j^[X0]kNg
0;Ng]`020;>c/`80][Jf0P2i^KT20;Bd]080[jn_0P2i^KT40;Fe]@80/;2`0P2WYjL209fMW@80WinO
0P2PX:0209bLW00309RHV02GUiL0UiNG0080Vi^K0P2[Zj/20:n_[`80/K6a0P2`/;020:n_[`80[Zj^
0P2ZZZX40:2PX080Y:BT0P2NWYh209bLW080UIFE00<0RHV90820P020P8000P1nOWh207IfMP80JVYZ
0P1LG5`202h^;P802`/;0P0U9BD203/k>`80=3@d0P1UIFD204i>CP80EeMG0P1;Bd/205ADE00304i>
CP1IFET0FEUI0080S8b<0P2>SXh20:6QX@80TY:B0P1]KFd207alO080JFUY0P1hN7P207emO@80VYZJ
0P2UYJD20:ZZZP80[Zj^0P2LW9`00`2][Jd0dM7A0=7Ad@020<k>cP80c<c<203AdM420=CDe080dm?C
0P3>c/h20<c<c0l0dM7A0P3>c/h20<c<c0@0dM7A5@3oool001<0oooo203AdM420=?Cd`@0dM7A0P3<
c<`30=7Ad@80b/[:0P3?cll20=7Ad@80d];B0P3De=@40<k>cP80dm?C0P3AdM420<G5a@80R8R80P1V
IVH205YJFP80C4a<00<0@41004Q8B018B4P00P19BDT204M7A`80A4A40P0`<30203De=@80DE5A0P1`
L7020:j^[P80/;2`0P2_[jl20;6a/@80^[Zj0P2k^k/20;bl_0030;Zj^P2g]kL0]kNg0080/k>c0P2f
][H20;Vi^@80];Bd0P2_[jl20;Vi^@@0]KFe0P2`/;020:NWY`80WIfM0P2OWil20:2PX080W9bL00<0
V9RH09NGU`2GUiL00P2KVi/20:^[Z`80[jn_0P2a/K420;2`/080[jn_0P2^[Zh20:ZZZP@0X:2P0P2T
Y:@209jNWP80W9bL0P2EUID00`29RHT0P8200820P00207inOP80MWIf0P1ZJVX205aLG080;Rh^0P0;
2`/202DU9@80>c/k0P0d=3@206EUI@80CTi>0P1GEeL204];B`80E5AD00<0CTi>05UIF@1IFET00P2<
S8`208j>SP80XJ6Q0P2BTY8206e]K@80O7al0P1YJFT207QhN080OGem0P2JVYX20:FUY@80ZZZZ0P2^
[Zh209bLW0030:f][@3AdM40dM7A0080c/k>0P3<c<`80=7Ad@80e=CD0P3Cdm<20<k>cP80c<c<3`3A
dM420<k>cP80c<c<103AdM4E0?ooo`004`3oool60=7Ad@80c/k>0P3<c<`20<k>cP80c<c<0`3AdM46
0<o?c`80dm?C0P3=cLd20<_;b`80dM7A0P39bLT20<c<c080clo?0P2a/K4208>3P`80Hf=S0P12@T82
04i>CP0304Q8B019BDT0BDU90080BTY:0P19BDT202/[:`80=CDe0P0V9RH208N7Q`80[Zj^0P2b/[82
0;Ng]`P0^k^k1@2j^[X20;Fe]@80Zj^[0P2b/[820;jn_P80_kno0P2n_[h20<71`@80]KFe0P2^[Zh2
0:ZZZP80YJFU0P2PX:0209fMW@80Vi^K00<0W9bL09VIV@2IVIT00P2PX:020:FUY@80[jn_0P2a/K42
0;2`/080[Jf]0P2b/[840:n_[`80ZJVY0P2PX:020:6QX@80WYjN0P2JVYX00`2BTY80RXZ:08Z:RP02
07inOP80MWIf0P1/K6`205iNGP80@4100P0@410201XJ6P80=cLg0P17AdL20492@P80FUYJ0P1IFET2
04e=C@<0Bd];0P1[Jf/207]kN`80SXj>0P2NWYh2092@T080Kfm_0P1jNWX407=cL`80N7Qh0P20P802
09bLW080X:2P0P2f][H20<;2`P030<g=c@3Cdm<0dm?C0080dM7A103De=@20=?Cd`80dM7A0P3>c/h2
0<[:bP80clo?4@3AdM420=?Cd`P0dM7A5@3oool001<0oooo1P3AdM420<k>cP80c<c<0P3>c/h20<c<
c0<0dM7A1P3?cll20=?Cd`80cLg=0P3;bl/20=7Ad@80bLW90P3<c<`20<o?c`80/K6a0P23Ph<206=S
H`80@T920P1>CTh00`18B4P0BDU904U9B@0204Y:BP80BDU90P0[:b/203De=@809RHV0P27QhL20:j^
[P80/[:b0P2g]kL80;^k^`D0^[Zj0P2e]KD20:^[Z`80/[:b0P2n_[h20;no_`80_[jn0P31`L420;Fe
]@80[Zj^0P2ZZZX20:FUY@80X:2P0P2MWId209^KV`0309bLW02IVIT0VIVI0080X:2P0P2UYJD20:n_
[`80/K6a0P2`/;020:f][@80/[:b102_[jl20:VYZ@80X:2P0P2QXJ4209jNWP80VYZJ00<0TY:B08Z:
RP2:RXX00P1nOWh207IfMP80K6a/0P1NGUh20410@080410@0P0J6QX203Lg=`80AdM70P12@T8205YJ
FP80FEUI0P1=CDd304];B`80Jf][0P1kNg/208j>SP80WYjN0P2@T90206m_K`80NWYj101cLg<207Qh
N080P8200P2LW9`20:2PX080][Jf0P32`/800`3=cLd0dm?C0=?Cd`020=7Ad@@0e=CD0P3Cdm<20=7A
d@80c/k>0P3:b/X20<o?ca40dM7A0P3Cdm<80=7AdAD0oooo000C0?ooo`@0e=CD0P3Cdm<60=7Ad@80
dm?C0P3>c/h00`39bLT0c<c<0<c<c0020<k>cP80bLW90P3=cLd20=?Cd`@0clo?103AdM420<k>cP80
UYJF0P1ZJVX2059BDP80@d=30P18B4P00`13@d<0ATI604I6AP0204Q8B0808b<S0P0c<c<202HV9P80
=3@d0P1YJFT40;6a/@80[jn_0P2b/[820;bl_080^k^k0P2j^[X70;bl_080^;Rh0P2c/k<20;Jf]P80
]KFe0P2n_[h20;Vi^@80_;bl0P2e]KD20:^[Z`80UYJF102GUiL209RHV00309JFUP2LW9`0W9bL0080
Xj>S102`/;020;:b/P80][Jf0P2b/[820:n_[`80[Jf]102_[jl20:RXZ080XZ:R0P2KVi/209bLW003
09NGU`2DU9@0U9BD0080PX:20P1eMGD206][J`80IVIV0P1?Cdl201@D50809bLW0P0Y:BT204I6AP80
CTi>0P1CDe<205IFEP80Fe]K0P17AdL00`1<C4`0GemO05mOG`0207AdM080Ph>30P2DU9@20::RXP80
O7al0P1^KVh206][J`80LG5a0P1nOWh209nOW`80/k>c0P2KVi/208:2PP80[Jf]00<0c/k>0<c<c03<
c<`00P3>c/h40<W9b@80c<c<103AdM420<k>cP80c<c<203AdM420=?Cd`D0dM7A103?cll20=?Cd`H0
dM7A5@3oool001<0oooo1039bLT20<c<c0H0dM7A0P3<c<`;0=7Ad@80cLg=0P3AdM420<g=c@@0e=CD
0P3@d=02092@T080H61P0P1=CDd204E5A@80B4Q800<0BDU904Y:BP1:BTX00P1;Bd/202/[:`808B4Q
0P0/;2`203`l?080@T920P2`/;0:0;Zj^P80^KVi1@2e]KD20;Zj^P80^k^k0P2e]KD20:j^[P80/[:b
0P2h^;P20;Fe]@80[:b/0P2ZZZX20:>SX`80WinO0P2FUYH209bLW080VIVI00<0WIfM0:NWY`2WYjL0
0P2_[jl20:f][@80[jn_0P2`/;020;Bd]080/;2`0P2^[Zh20;2`/080[Zj^0P2_[jl20:VYZ@80YJFU
0P2SXj<209^KV`0309VIV@2DU9@0U9BD0080TY:B0P1mOGd2071`L080IVIV0P1IFET202<S8`804A4A
0P0e=CD202d];@80D51@0P1>CTh204U9B@80FEUI0P1KFe/00`1;Bd/0I6AT06ATI00407moO`80T92@
0P2YZJT20861P@80N7Qh0P1IFET207AdM080KVi^0P2CTi<209^KV`80ZZZZ0P2n_[h20<c<c1T0dM7A
0P3>c/h20<c<c0D0dM7A0P3>c/h20<W9b@80c<c<103AdM420=?CdaD0oooo000C0?ooo`@0bLW90P3<
c<`60=7Ad@80c<c<2`3AdM420<g=c@80dM7A0P3=cLd40=CDe080d=3@0P2@T902061PH080CDe=0P15
ADD204Q8B00304U9B@1:BTX0BTY:0080Bd];0P0[:b/2024Q8@80;2`/0P0l?3`20492@P80/;2`2P2j
^[X20;Vi^@D0]KFe0P2j^[X20;^k^`80]KFe0P2^[Zh20;:b/P80^;Rh0P2e]KD20:b/[080ZZZZ0P2S
Xj<209nOW`80UYJF0P2LW9`209VIV@0309fMW@2WYjL0YjNW0080[jn_0P2][Jd20:n_[`80/;2`0P2d
];@20;2`/080[Zj^0P2`/;020:j^[P80[jn_0P2YZJT20:FUY@80Xj>S0P2KVi/00`2IVIT0U9BD09BD
U00209:BTP80OGem0P1`L70206IVIP80FEUI0P0S8b<2014A4@80=CDe0P0];Bd2051@D080CTi>0P19
BDT205UIF@80Fe]K00<0Bd];06ATI01TI6@0101oOgl2092@T080ZJVY0P21PH4207QhN080FEUI0P1d
M7@206i^KP80Ti>C0P2KVi/20:ZZZP80_[jn0P3<c<`I0=7Ad@80c/k>0P3<c<`50=7Ad@80c/k>0P39
bLT20<c<c0@0dM7A0P3Cdm<E0?ooo`004`3oool60=CDe080dm?C0P3>c/h20<c<c0/0dM7A0P3?cll2
0=7Ad@80c<c<0P3?cll20<g=c@80c<c<0P3:b/X209:BTP80HV9R0P16ATH204e=C@80C4a<00<0Bd];
04I6AP16ATH00P0b<S8202/[:`807QhN0P0d=3@2020P8080UiNG0P2e]KD20;>c/`80]kNg0P2j^[X2
0;Vi^@80]KFe0P2n_[h30<G5a@80`L710P2j^[X40;bl_080^KVi0P2`/;020;:b/P80^k^k0P2d];@2
0:RXZ080Vi^K0P2IVIT409bLW080Xj>S00<0YZJV0:b/[02/[:`00P2b/[820;Bd]080Zj^[0P2][Jd2
0;Ng]`80^;Rh0P2d];@20:b/[080[Jf]0P2/[:`20:VYZ@H0WYjN00<0UYJF092@T02@T9000P2<S8`2
08J6QP80K6a/0P1RHV8205mOG`80?clo0P0T92@202d];@80>c/k0P0m?Cd205]KF`80CDe=0P1DE5@2
05IFEP03059BDP1RHV80HV9R0080PH610P2:RXX209JFUP80ZZZZ0P2<S8`206i^KP80GemO0P1_Kfl2
07IfMP80S8b<0P2d];@20:^[Z`80/;2`4@3AdM420=?Cd`@0dM7A0P3De=@20=?Cd`@0dM7A0P3Cdm<0
0`3AdM40dm?C0=?Cd`080=7Ad@80c/k>0P3<c<`E0?ooo`004`3oool60=CDe080dm?C0P3>c/h20<c<
c0/0dM7A0P3?cll20=7Ad@80c<c<0P3?cll20<g=c@80c<c<0P3:b/X209:BTP80HV9R0P16ATH204e=
C@80C4a<00<0Bd];04I6AP16ATH00P0b<S8202/[:`807QhN0P0d=3@2020P8080UiNG0P2e]KD20;>c
/`80]kNg0P2j^[X20;Vi^@80]KFe0P2n_[h30<G5a@80`L710P2j^[X40;bl_080^KVi0P2`/;020;:b
/P80^k^k0P2d];@20:RXZ080Vi^K0P2IVIT409bLW080Xj>S00<0YZJV0:b/[02/[:`00P2b/[820;Bd
]080Zj^[0P2][Jd20;Ng]`80^;Rh0P2d];@20:b/[080[Jf]0P2/[:`20:VYZ@H0WYjN00<0UYJF092@
T02@T9000P2<S8`208J6QP80K6a/0P1RHV8205mOG`80?clo0P0T92@202d];@80>c/k0P0m?Cd205]K
F`80CDe=0P1DE5@205IFEP03059BDP1RHV80HV9R0080PH610P2:RXX209JFUP80ZZZZ0P2<S8`206i^
KP80GemO0P1_Kfl207IfMP80S8b<0P2d];@20:^[Z`80/;2`4@3AdM420=?Cd`@0dM7A0P3De=@20=?C
d`@0dM7A0P3Cdm<00`3AdM40dm?C0=?Cd`080=7Ad@80c/k>0P3<c<`E0?ooo`004`3oool20<g=c@80
c<c<0P3:b/X20<o?c`d0dM7A0P39bLT20<[:bP80clo?0P3AdM420<k>cP80bLW90P3<c<`209ZJVP80
PH610P1JFUX203Xj>P80DU9B0P19BDT304];B`80;Rh^0P0d=3@202/[:`80G5aL0P2XZ:P20;Jf]P80
/[:b0P2n_[h20<71`@@0^KVi0P2m_Kd40;Zj^P030;Rh^02e]KD0]KFe00P0^[Zj0P2h^;P20;Vi^@80
^k^k0P2e]KD20:^[Z`80YZJV0P2OWil20:2PX080XZ:R0P2PX:000`2SXj<0[Jf]0:f][@020;:b/P80
/k>c0P2j^[X20;Vi^@80/K6a0P2e]KD20;:b/P80_Kfm0P2e]KD20;:b/P80[Jf]0P2^[Zh20:NWY`80
XZ:R00<0WYjN09RHV02HV9P00P2>SXh208n?S`80OGem0P1YJFT205YJFP80BTY:0P0h>3P203Hf=P80
?Cdm101>CTh205eMG@80EEEE0P1HF5P00`1JFUX0Fe]K05]KF`0207alO0@0Ti>C0P2UYJD209>CT`80
KVi^0P1CDe<206QXJ080MWIf0P24Q8@20:b/[080^k^k0P38b<P?0=7Ad@80c/k>0P3<c<`20=7Ad@80
c/k>0P39bLT20<c<c080dM7A0P3>c/h20<g=c@030=7Ad@3<c<`0c<c<00@0dM7A0P3Cdm<60=7AdAD0
oooo000C0?ooo`80cLg=0P3<c<`20<[:bP80clo?3@3AdM420<W9b@80b/[:0P3?cll20=7Ad@80c/k>
0P39bLT20<c<c080VYZJ0P21PH4205YJFP80>SXj0P1BDU8204U9B@<0Bd];0P0^;Rh203@d=080:b/[
0P1LG5`20:RXZ080][Jf0P2b/[820;jn_P80`L71102i^KT20;fm_@@0^[Zj00<0^;Rh0;Fe]@2e]KD0
202j^[X20;Rh^080^KVi0P2k^k/20;Fe]@80Zj^[0P2VYZH209nOW`80X:2P0P2RXZ820:2PX0030:>S
X`2][Jd0[Jf]0080/[:b0P2c/k<20;Zj^P80^KVi0P2a/K420;Fe]@80/[:b0P2m_Kd20;Fe]@80/[:b
0P2][Jd20:j^[P80YjNW0P2RXZ800`2NWYh0V9RH09RHV00208j>SP80Shn?0P1mOGd206UYJ@80FUYJ
0P1:BTX203Ph>080=SHf0P0m?Cd404i>CP80GEeM0P1EEED205QHF00305YJFP1KFe/0Fe]K0080O7al
102CTi<20:FUY@80Ti>C0P1^KVh205=CD`80J6QX0P1fMWH208B4Q080[:b/0P2k^k/20<S8b0l0dM7A
0P3>c/h20<c<c080dM7A0P3>c/h20<W9b@80c<c<0P3AdM420<k>cP80cLg=00<0dM7A0<c<c03<c<`0
103AdM420=?Cd`H0dM7A5@3oool001<0oooo0P3=cLd20<o?c`80c/k>0P3<c<`90=7Ad@80c/k>0P3<
c<`20=7Ad@@0clo?1P3AdM420=?Cd`80QHF50P1MGEd204U9B@80?Cdm0P1;Bd/204a<C00304E5A@14
A4@0A4A40080>c/k0P0[:b/2059BDP80EeMG0P2^[Zh20;:b/P80^[Zj0P2k^k/40;Vi^@@0`L710P2i
^KT20;Zj^P030;jn_P30`<00`<300080^KVi102e]KD20;Zj^P80^;Rh0P2d];@20;^k^`80_;bl0P2k
^k/20:VYZ@80WinO0P2PX:020:VYZ@<0Z:RX0P2WYjL20;2`/080^;Rh0P2k^k/20;Rh^080^k^k0P2j
^[X20;^k^`80/k>c0P2a/K420;Bd]080/[:b0P2`/;020:^[Z`80XJ6Q0`2LW9`209BDU080S8b<0P20
P80206a/K080G5aL0P1=CDd203De=@80=SHf0P0l?3`204I6AP80Cdm?0P1KFe/205iNGP80FUYJ00<0
FEUI07moO`1oOgl00P1nOWh408n?S`80U9BD0P2?Shl206EUI@80GEeM0P1JFUX207alO080V9RH0P2Y
ZJT20;no_aT0dM7A0P3Cdm<20=7Ad@80dm?C0P3AdM420<k>cP030<c<c03AdM40dM7A0080dM7A0P3>
c/h20<c<c0H0dM7A5@3oool001<0oooo0P3=cLd20<o?c`80c/k>0P3<c<`90=7Ad@80c/k>0P3<c<`2
0=7Ad@@0clo?1P3AdM420=?Cd`80QHF50P1MGEd204U9B@80?Cdm0P1;Bd/204a<C00304E5A@14A4@0
A4A40080>c/k0P0[:b/2059BDP80EeMG0P2^[Zh20;:b/P80^[Zj0P2k^k/40;Vi^@@0`L710P2i^KT2
0;Zj^P030;jn_P30`<00`<300080^KVi102e]KD20;Zj^P80^;Rh0P2d];@20;^k^`80_;bl0P2k^k/2
0:VYZ@80WinO0P2PX:020:VYZ@<0Z:RX0P2WYjL20;2`/080^;Rh0P2k^k/20;Rh^080^k^k0P2j^[X2
0;^k^`80/k>c0P2a/K420;Bd]080/[:b0P2`/;020:^[Z`80XJ6Q0`2LW9`209BDU080S8b<0P20P802
06a/K080G5aL0P1=CDd203De=@80=SHf0P0l?3`204I6AP80Cdm?0P1KFe/205iNGP80FUYJ00<0FEUI
07moO`1oOgl00P1nOWh408n?S`80U9BD0P2?Shl206EUI@80GEeM0P1JFUX207alO080V9RH0P2YZJT2
0;no_aT0dM7A0P3Cdm<20=7Ad@80dm?C0P3AdM420<k>cP030<c<c03AdM40dM7A0080dM7A0P3>c/h2
0<c<c0H0dM7A5@3oool001<0oooo0P39bLT20<c<c080dM7A0P3Cdm<20=7Ad@80dm?C1@3AdM420=?C
d`@0dM7A0P3>c/h20<c<c0@0dM7A0P3>c/h20<g=c@80QHF50P1WIfL204e=C@80@D510P12@T8205IF
EP0304];B`0g=cL0=cLg0080@d=30P10@4020492@P80MGEe0P2a/K420;Ng]`@0^[Zj0P2n_[h20<G5
a@80`L710P2j^[X20;^k^`80^[Zj00<0_;bl0;jn_P2n_[h00P2n_[h20<G5a@80`L71102j^[X20;^k
^`80`L710P2e]KD20:f][@80YJFU0P2MWId209^KV`80Xj>S0P2ZZZX00`2/[:`0/k>c0;>c/`020;Bd
]080^;Rh0P2e]KD20;Rh^080_Kfm0P2e]KD20;2`/080/[:b0P2k^k/20;Rh^080];Bd0P2`/;020:n_
[`80[:b/00<0XJ6Q09JFUP2FUYH00P2GUiL2096AT@80QHF50P1_Kfl205mOG`80CDe=0P0o?cl2038b
<P80>3Ph0P0m?Cd204m?C`80EEEE0P1NGUh205IFEP0305ADE022PX80PX:20080RHV90P2<S8`209>C
T`80T92@0P2LW9`206QXJ080Kfm_0P1YJFT207AdM080T92@0P2d];@20<c<c1L0dM7A0P3>c/h20<c<
c080c/k>0P3<c<`20=7Ad@80dm?C3`3AdM4E0?ooo`004`3oool20<W9b@80c<c<0P3AdM420=?Cd`80
dM7A0P3Cdm<50=7Ad@80dm?C103AdM420<k>cP80c<c<103AdM420<k>cP80cLg=0P25QHD206MWI`80
CDe=0P11@D420492@P80EUIF00<0Bd];03Lg=`0g=cL00P13@d<20410@080@T920P1eMGD20;6a/@80
]kNg102j^[X20;jn_P80aLG50P31`L420;Zj^P80^k^k0P2j^[X00`2l_;`0_[jn0;jn_P020;jn_P80
aLG50P31`L440;Zj^P80^k^k0P31`L420;Fe]@80[Jf]0P2UYJD209fMW@80Vi^K0P2SXj<20:ZZZP03
0:b/[02c/k<0/k>c0080];Bd0P2h^;P20;Fe]@80^;Rh0P2m_Kd20;Fe]@80/;2`0P2b/[820;^k^`80
^;Rh0P2d];@20;2`/080[jn_0P2/[:`00`2QXJ40UYJF09JFUP0209NGU`80TI6A0P25QHD206m_K`80
GemO0P1=CDd203lo?`80<S8b0P0h>3P203dm?@80Cdm?0P1EEED205iNGP80EUIF00<0E5AD08:2PP22
PX800P29RHT208b<S080Ti>C0P2@T90209bLW080J6QX0P1_Kfl206UYJ@80M7Ad0P2@T9020;Bd]080
c<c<5`3AdM420<k>cP80c<c<0P3>c/h20<c<c080dM7A0P3Cdm<?0=7AdAD0oooo000C0?ooo`80e=CD
0P3Cdm<20<k>cP80c<c<103?cll20=7Ad@80dm?C0`3?cll<0=7Ad@80dm?C0P36a/H208B4Q080IfMW
0P1GEeL2051@D080ATI60P18B4P00`11@D40>c/k03/k>`0203hn?P@0Bd];0P2][Jd20;Vi^@80];Bd
1P2j^[X20;Vi^@80]KFe2@2j^[X20;no_`80_Kfm0P2l_;`20;Zj^P80^k^k0P2j^[X20;:b/P@0^[Zj
0P2`/;0209jNWP80WIfM0P2PX:020:VYZ@030:j^[P2ZZZX0ZZZZ0080^;Rh0P2d];@20;Jf]P80]kNg
0P2e]KD20;Zj^P80^;Rh0P2k^k/20;Fe]@80/K6a102`/;020:n_[`80ZJVY00<0Z:RX0:6QX@2QXJ40
0P2HV9P208n?S`80QhN70P1nOWh206ATI080EeMG0P15ADD202h^;P80?3`l0P0j>SX204I6AP80GEeM
0P1DE5@205MGE`0304m?C`1fMWH0MWIf0080UYJF0P2?Shl208R8R080Ng]k0P2/[:`205EEE@80JFUY
0P1eMGD206m_K`80Q8B40P2a/K420<[:bQd0dM7A0P3Cdm<20<k>cP80c<c<3`3AdM4E0?ooo`004`3o
ool20=CDe080dm?C0P3>c/h20<c<c0@0clo?0P3AdM420=?Cd`<0clo?303AdM420=?Cd`80a/K60P24
Q8@206MWI`80EeMG0P1@D50204I6AP80B4Q800<0@D5103/k>`0k>c/00P0n?Sh404];B`80[Jf]0P2i
^KT20;Bd]0H0^[Zj0P2i^KT20;Fe]@T0^[Zj0P2o_kl20;fm_@80_;bl0P2j^[X20;^k^`80^[Zj0P2b
/[840;Zj^P80/;2`0P2NWYh209fMW@80X:2P0P2YZJT00`2^[Zh0ZZZZ0:ZZZP020;Rh^080];Bd0P2f
][H20;Ng]`80]KFe0P2j^[X20;Rh^080^k^k0P2e]KD20;6a/@@0/;2`0P2_[jl20:VYZ@030:RXZ02Q
XJ40XJ6Q0080V9RH0P2?Shl208N7Q`80OWin0P1TI6@205MGE`80ADE50P0^;Rh203`l?080>SXj0P16
ATH205eMG@80E5AD0P1GEeL00`1?Cdl0MWIf07IfMP0209JFUP80Shn?0P28R8P207]kN`80[:b/0P1E
EED206UYJ@80MGEe0P1_Kfl208B4Q080/K6a0P3:b/XM0=7Ad@80dm?C0P3>c/h20<c<c0l0dM7A5@3o
ool001<0oooo0P39bLT20<c<c0H0dM7A0P3<c<`40<o?c`030<k>cP3<c<`0c<c<00X0dM7A103?cll2
09VIV@80Q8B40P1ADE4204Y:BP80GEeM0P18B4P204m?C`0303Lg=`13@d<0@d=30080@4100P1mOGd2
0;Fe]@80^KVi0P2h^;P20;^k^`80^KVi0P2e]KD20;Zj^P80_[jn0P30`<020;Zj^P80_Kfm0P2i^KT0
0`2k^k/0/[:b0;:b/P020;>c/`80^;Rh0P2k^k/20;jn_P80][Jf0P2c/k<20;Rh^080^KVi0P2j^[X2
0;Bd]080Y:BT0P2OWil209^KV`80X:2P00<0XZ:R0:RXZ02XZ:P00P2QXJ420;6a/@@0/k>c0P2n_[h2
0;Rh^080_;bl0P2f][H40;2`/080/K6a102_[jl20:b/[0030:BTY02VYZH0YZJV00@0UiNG0P2<S8`2
07]kN`80KVi^0P1GEeL204a<C080;Bd]0P0Y:BT203hn?P80A4A40P1GEeL2065QH@80E5AD00<0EUIF
07YjNP1jNWX00P28R8P208V9R@80TY:B0P1MGEd209VIV@80IfMW0P1ADE4207YjNP@0R8R80P2VYZH6
0=7Ad@030=?Cd`3AdM40dM7A01@0dM7A103?cllC0=7AdAD0oooo000C0?ooo`80bLW90P3<c<`60=7A
d@80c<c<103?cll00`3>c/h0c<c<0<c<c00:0=7Ad@@0clo?0P2IVIT208B4Q080DE5A0P1:BTX205eM
G@80B4Q80P1?Cdl00`0g=cL0@d=304=3@`020410@080OGem0P2e]KD20;Vi^@80^;Rh0P2k^k/20;Vi
^@80]KFe0P2j^[X20;jn_P80`<300P2j^[X20;fm_@80^KVi00<0^k^k0;:b/P2b/[800P2c/k<20;Rh
^080^k^k0P2n_[h20;Jf]P80/k>c0P2h^;P20;Vi^@80^[Zj0P2d];@20:BTY080WinO0P2KVi/20:2P
X0030::RXP2XZ:P0Z:RX0080XJ6Q0P2a/K440;>c/`80_[jn0P2h^;P20;bl_080][Jf102`/;020;6a
/@@0[jn_0P2/[:`00`2TY:@0YZJV0:JVYP0409NGU`80S8b<0P1kNg/206i^KP80EeMG0P1<C4`202d]
;@80:BTY0P0n?Sh204A4A080EeMG0P1QHF4205ADE00305IFEP1jNWX0NWYj0080R8R80P29RHT209:B
TP80GEeM0P2IVIT206MWI`80DE5A0P1jNWX408R8R080YZJV1P3AdM400`3Cdm<0dM7A0=7Ad@0D0=7A
d@@0clo?4`3AdM4E0?ooo`004`3oool60=7Ad@@0clo?0P3AdM420<k>cP80cLg=00<0dm?C0=7Ad@3A
dM40103AdM460=CDe080dM7A0P3<c<`206e]K@80Rh^;0P1QHF4205iNGP80CTi>0P1IFET204A4A003
030`<01?Cdl0Cdm?0080A4A40P1ADE420:f][@80^k^k0P2b/[820;Vi^@80_[jn0P31`L440;Zj^P80
_[jn0P2k^k/20;Ng]`80[jn_00<0Xj>S0;Fe]@2e]KD00P2i^KT40;Bd]080^k^k0P2j^[X20;Vi^@80
_;bl0P2k^k/20;Zj^P80/k>c0P2XZ:P209RHV080WIfM0P2GUiL00`2OWil0YJFU0:FUY@040;2`/080
/k>c0P2g]kL20:n_[`80/;2`0P2^[Zh20;Bd]080/[:b0P2h^;P20;Fe]@80^KVi0P2c/k<20;2`/003
0:RXZ02PX:00X:2P0080X:2P0P2GUiL208n?S`80QHF50P1`L702069RHP80C4a<0P0m?Cd201/K6`80
<C4a0P0o?cl205IFEP80F5QH0P1PH6000`1?Cdl0O7al07alO00208j>SP80OWin0P2@T90205YJFP80
O7al0P1YJFT204i>CP80MGEe0P25QHD20:2PX080^;Rh103AdM420<k>cP030<c<c03AdM40dM7A00H0
dM7A0P3Cdm<<0=7Ad@80c/k>0P3<c<`50=7Ad@80dm?C303AdM4E0?ooo`004`3oool60=7Ad@@0clo?
0P3AdM420<k>cP80cLg=00<0dm?C0=7Ad@3AdM40103AdM460=CDe080dM7A0P3<c<`206e]K@80Rh^;
0P1QHF4205iNGP80CTi>0P1IFET204A4A003030`<01?Cdl0Cdm?0080A4A40P1ADE420:f][@80^k^k
0P2b/[820;Vi^@80_[jn0P31`L440;Zj^P80_[jn0P2k^k/20;Ng]`80[jn_00<0Xj>S0;Fe]@2e]KD0
0P2i^KT40;Bd]080^k^k0P2j^[X20;Vi^@80_;bl0P2k^k/20;Zj^P80/k>c0P2XZ:P209RHV080WIfM
0P2GUiL00`2OWil0YJFU0:FUY@040;2`/080/k>c0P2g]kL20:n_[`80/;2`0P2^[Zh20;Bd]080/[:b
0P2h^;P20;Fe]@80^KVi0P2c/k<20;2`/0030:RXZ02PX:00X:2P0080X:2P0P2GUiL208n?S`80QHF5
0P1`L702069RHP80C4a<0P0m?Cd201/K6`80<C4a0P0o?cl205IFEP80F5QH0P1PH6000`1?Cdl0O7al
07alO00208j>SP80OWin0P2@T90205YJFP80O7al0P1YJFT204i>CP80MGEe0P25QHD20:2PX080^;Rh
103AdM420<k>cP030<c<c03AdM40dM7A00H0dM7A0P3Cdm<<0=7Ad@80c/k>0P3<c<`50=7Ad@80dm?C
303AdM4E0?ooo`004`3oool60=7Ad@80c/k>0P3<c<`40=7Ad@80c/k>00<0c<c<0=7Ad@3AdM400P3C
dm<20<o?c`80c<c<1039bLT20<c<c080clo?0P1dM7@206EUI@80H61P0P1LG5`205MGE`80F5QH0P0_
;bl00`1<C4`0@D510451@@0208j>SP80UiNG0P2g]kL20:f][@80];Bd202j^[X20;Vi^@80]KFe0P2`
/;020;Bd]080a<C400<0[jn_09ZJVP2JVYX00P2^[Zh20:n_[`80^;Rh102`/;020:f][@80]KFe0P2i
^KT20;Zj^P80[Zj^0P2JVYX409FEU@80W9bL00<0Vi^K09FEU@2EUID00P2YZJT20:b/[080/K6a0P2Z
ZZX20:RXZ080W9bL0P2TY:@20:JVYP80W9bL0P2KVi/20:BTY0@0Z:RX0P2WYjL00`2/[:`0Zj^[0:^[
Z`020:FUY@80V9RH0P2=SHd207moO`80Lg=c0P1MGEd205IFEP80AdM70P0d=3@202XZ:P80<S8b0P1?
Cdl205ADE080GemO00<0FEUI06m_K`1_Kfl00P2<S8`20861P@80N7Qh0P1OGel207]kN`80Jf][0P1D
E5@207AdM080SHf=0P2`/;020<;2`P80c<c<2`3AdM420<k>cP80c<c<503AdM400`3>c/h0c<c<0<c<
c00<0=7AdAD0oooo000C0?ooo`H0dM7A0P3>c/h20<c<c0@0dM7A0P3>c/h00`3<c<`0dM7A0=7Ad@02
0=?Cd`80clo?0P3<c<`40<W9b@80c<c<0P3?cll207AdM080IFEU0P1PH60205aLG080EeMG0P1HF5P2
02l_;`0304a<C011@D40@D510080SXj>0P2GUiL20;Ng]`80[Jf]0P2d];@80;Zj^P80^KVi0P2e]KD2
0;2`/080];Bd0P34a<@00`2_[jl0VYZJ09ZJVP020:j^[P80[jn_0P2h^;P40;2`/080[Jf]0P2e]KD2
0;Vi^@80^[Zj0P2^[Zh209ZJVP@0UIFE0P2LW9`00`2KVi/0UIFE09FEU@020:VYZ@80[:b/0P2a/K42
0:ZZZP80Z:RX0P2LW9`20:BTY080YZJV0P2LW9`209^KV`80Y:BT102XZ:P20:NWY`030:b/[02[Zj/0
Zj^[0080YJFU0P2HV9P208f=S@80Ogmo0P1cLg<205eMG@80EUIF0P17AdL203@d=080:RXZ0P0b<S82
04m?C`80E5AD0P1OGel00`1IFET0Kfm_06m_K`0208b<S080PH610P1hN7P205mOG`80Ng]k0P1[Jf/2
05ADE080M7Ad0P2=SHd20;2`/080`/;20P3<c<`;0=7Ad@80c/k>0P3<c<`D0=7Ad@030<k>cP3<c<`0
c<c<00`0dM7A5@3oool001<0oooo0P3De=@20=?Cd`P0dM7A0P3Cdm<20=7Ad@030=?Cd`3>c/h0c/k>
0080c<c<0P3>c/h20<c<c0H0dM7A0P35aLD20:>SX`80IVIV0P1ADE4205=CD`80CDe=0P1IFET203De
=@0304M7A`1>CTh0CTi>0080F5QH0P2MWId208n?S`80Z:RX0P2h^;P20;jn_P@0^[Zj0P2i^KT20:RX
Z080/;2`0P2PX:0207QhN080KFe]00<0Shn?09RHV02HV9P00P2HV9P209jNWP80[:b/0P3@d=020;Fe
]@80/;2`0P2h^;P40;^k^`80];Bd0P2UYJD2092@T080Shn?0P28R8P00`2QXJ40Ng]k07]kN`020:FU
Y@80^;Rh0P2][Jd209bLW080N7Qh0P1^KVh208N7Q`80Ph>3102<S8`209FEU@80Zj^[0P2_[jl20:NW
Y`<0WIfM0P2KVi/209ZJVP80SXj>0P24Q8@207=cL`80IVIV0P1ADE4204I6AP80B4Q80P0[:b/202h^
;P80C4a<0P1?Cdl205IFEP0305mOG`1ZJVX0JVYZ0080Ogmo0P1bLW8207EeM@80FUYJ0P29RHT206a/
K080F5QH0P1YJFT208V9R@80WIfM0P30`<020=WIfA/0dM7A0P3Cdm<E0=7AdAD0oooo000C0?ooo`80
e=CD0P3Cdm<80=7Ad@80dm?C0P3AdM400`3Cdm<0c/k>0<k>cP020<c<c080c/k>0P3<c<`60=7Ad@80
aLG50P2SXj<206IVIP80DE5A0P1CDe<204e=C@80FEUI0P0e=CD00`17AdL0CTi>04i>CP0205QHF080
WIfM0P2?Shl20:RXZ080^;Rh0P2n_[h40;Zj^P80^KVi0P2XZ:P20;2`/080X:2P0P1hN7P206e]K@03
08n?S`2HV9P0V9RH0080V9RH0P2NWYh20:b/[080d=3@0P2e]KD20;2`/080^;Rh102k^k/20;Bd]080
YJFU0P2@T90208n?S`80R8R800<0XJ6Q07]kN`1kNg/00P2UYJD20;Rh^080[Jf]0P2LW9`207QhN080
KVi^0P27QhL208>3P`@0S8b<0P2EUID20:^[Z`80[jn_0P2WYjL309fMW@80Vi^K0P2JVYX208j>SP80
Q8B40P1cLg<206IVIP80DE5A0P16ATH204Q8B080:b/[0P0^;Rh204a<C080Cdm?0P1FEUH00`1OGel0
JVYZ06YZJP0207moO`80LW9b0P1eMGD205YJFP80RHV90P1/K6`205QHF080JFUY0P29RHT209fMW@80
`<300P3IfMTK0=7Ad@80dm?C5@3AdM4E0?ooo`004`3oool20<W9b@80c<c<1P3AdM420<k>cP80c<c<
0P3>c/h00`3<c<`0dM7A0=7Ad@040=7Ad@80dm?C1P3AdM4209ZJVP80QXJ60P1QHF4205QHF080=SHf
0P1EEED2059BDP80>CTi00<0<C4a09fMW@2MWId00P2MWId209^KV`80Rh^;0P2SXj<40;Bd]080_;bl
0P2h^;P209nOW`80UIFE0P1lO7`207MgM`@0N7Qh00<0EEEE079bLP1bLW800P21PH4209FEU@80PH61
0P2NWYh20;Jf]P80^[Zj0P2d];@40;^k^`80^;Rh0P2WYjL209RHV0@0S8b<00<0SXj>07inOP1nOWh0
0P17AdL20820P080IVIV0P1iNGT209>CT`80GemO0P1UIFD2061PH080PX:20P1SHf<206i^KP80Shn?
0P2VYZH209nOW`030:2PX02MWId0WIfM0080VIVI0P2DU9@2096AT@80OGem0P1bLW8206EUI@80E5AD
0P1;Bd/203Ti>@806ATI0P0W9bL204];B`80De=C0P17AdL00`1WIfL0Lg=c07=cL`0207emO@80Lg=c
0P1dM7@206=SH`80OGem0P1RHV8207EeM@80NGUi0P2HV9P20:b/[080`l?35`3AdM420=?Cd`80dM7A
0P3>c/h20<g=c@80dm?C4`3AdM4E0?ooo`004`3oool20<W9b@80c<c<1P3AdM420<k>cP80c<c<0P3>
c/h00`3<c<`0dM7A0=7Ad@040=7Ad@80dm?C1P3AdM4209ZJVP80QXJ60P1QHF4205QHF080=SHf0P1E
EED2059BDP80>CTi00<0<C4a09fMW@2MWId00P2MWId209^KV`80Rh^;0P2SXj<40;Bd]080_;bl0P2h
^;P209nOW`80UIFE0P1lO7`207MgM`@0N7Qh00<0EEEE079bLP1bLW800P21PH4209FEU@80PH610P2N
WYh20;Jf]P80^[Zj0P2d];@40;^k^`80^;Rh0P2WYjL209RHV0@0S8b<00<0SXj>07inOP1nOWh00P17
AdL20820P080IVIV0P1iNGT209>CT`80GemO0P1UIFD2061PH080PX:20P1SHf<206i^KP80Shn?0P2V
YZH209nOW`030:2PX02MWId0WIfM0080VIVI0P2DU9@2096AT@80OGem0P1bLW8206EUI@80E5AD0P1;
Bd/203Ti>@806ATI0P0W9bL204];B`80De=C0P17AdL00`1WIfL0Lg=c07=cL`0207emO@80Lg=c0P1d
M7@206=SH`80OGem0P1RHV8207EeM@80NGUi0P2HV9P20:b/[080`l?35`3AdM420=?Cd`80dM7A0P3>
c/h20<g=c@80dm?C4`3AdM4E0?ooo`004`3ooolA0=7Ad@80dm?C0P3AdM420<k>cP80c<c<103AdM42
0<o?c`80TY:B0P1OGel206IVIP80F5QH0P0j>SX204Y:BP80DU9B0P1=CDd00`0l?3`0GUiN05iNGP02
0:BTY080W9bL0P2SXj<20:ZZZP80_;bl0P2k^k/20;6a/@80Y:BT0P24Q8@2051@D080[jn_0P2o_kl2
08N7Q`80HF5Q00<06ATI07=cL`1cLg<00P1CDe<208J6QP80TY:B0P2EUID20:b/[080XZ:R0P2b/[82
0;^k^`80]kNg0P2`/;020:RXZ080VYZJ0P25QHD207inOP03079bLP2=SHd0SHf=0080MgMg0P1VIVH2
0>?Sh`80LG5a0P1iNGT201`L7080OGem0P1MGEd207alO080@4100P1UIFD207MgM`80RXZ:0P2KVi/0
0`2PX:00WYjN09jNWP0209ZJVP80Shn?0P2ATI4208B4Q080Kfm_0P1PH60205IFEP80BTY:0P0W9bL2
01hN7P808B4Q0P0_;bl205]KF`80BDU900<0G5aL06YZJP1ZJVX00P1lO7`2075aL@80JFUY0P1UIFD2
08J6QP80FEUI0P1aLG4209>CT`80X:2P0P2YZJTG0=7Ad@80c/k>0P3<c<`40=7Ad@80c/k>0P3<c<`C
0=7AdAD0oooo000C0?oooa40dM7A0P3Cdm<20=7Ad@80c/k>0P3<c<`40=7Ad@80clo?0P2BTY8205mO
G`80IVIV0P1HF5P203Xj>P80BTY:0P1BDU8204e=C@0303`l?01NGUh0GUiN0080Y:BT0P2LW9`20:>S
X`80ZZZZ0P2l_;`20;^k^`80/K6a0P2TY:@208B4Q080D51@0P2_[jl20;no_`80QhN70P1QHF400`0I
6AT0Lg=c07=cL`0205=CD`80QXJ60P2BTY8209FEU@80[:b/0P2RXZ820;:b/P80^k^k0P2g]kL20;2`
/080Z:RX0P2JVYX208F5Q@80OWin00<0LW9b08f=S@2=SHd00P1gMgL206IVIP80hn?S0P1aLG4207Ui
N@8071`L0P1mOGd205eMG@80O7al0P10@40206EUI@80MgMg0P2:RXX209^KV`030:2PX02NWYh0WYjN
0080VYZJ0P2?Shl2096AT@80Q8B40P1_Kfl2061PH080EUIF0P1:BTX202LW9`807QhN0P0Q8B4202l_
;`80Fe]K0P19BDT00`1LG5`0JVYZ06YZJP0207alO080LG5a0P1YJFT206EUI@80QXJ60P1IFET2075a
L@80Ti>C0P2PX:020:VYZAL0dM7A0P3>c/h20<c<c0@0dM7A0P3>c/h20<c<c1<0dM7A5@3oool001<0
oooo403AdM400`3>c/h0c<c<0<c<c00:0=7Ad@80`<300P3oool209jNWP80HF5Q0P16ATH20410@080
A4A40P1?Cdl205ADE00305aLG01mOGd0OGem0080Xj>S0P2EUID209BDU080YjNW102`/;020:RXZ080
SXj>0P1JFUX205aLG080E5AD0P1SHf<204U9B@80G5aL00<0J6QX03hn?P0n?Sh00P1FEUH205MGE`80
LW9b0P1mOGd208V9R@80ZJVY0P2f][H20;jn_P80^;Rh0P2b/[820:^[Z`80Xj>S0P2BTY8207YjNP03
079bLP1ZJVX0JVYZ0080OGem0P21PH4207emO@80DU9B0P12@T8205=CD`80=3@d0P1FEUH2051@D080
IfMW0P0n?Sh206IVIP80N7Qh0P22PX800`2BTY80VYZJ09ZJVP0209NGU`80S8b<0P22PX820861P@80
JFUY0P1QHF4205EEE@80AdM70P0i>CT201lO7`80;Rh^0P0`<30203Ti>@80CDe=00<0GemO06i^KP1^
KVh00P1WIfL206][J`80NGUi0P1[Jf/20820P080I6AT0P1WIfL208V9R@80W9bL0P2][JdX0=7Ad@80
dm?C303AdM4E0?ooo`004`3oool@0=7Ad@030<k>cP3<c<`0c<c<00X0dM7A0P30`<020?ooo`80WYjN
0P1QHF4204I6AP80@4100P14A4@204m?C`80E5AD00<0G5aL07emO@1mOGd00P2SXj<209FEU@80U9BD
0P2WYjL40;2`/080Z:RX0P2>SXh205YJFP80G5aL0P1DE5@206=SH`80BDU90P1LG5`00`1XJ6P0?Shn
03hn?P0205IFEP80EeMG0P1bLW8207emO@80RHV90P2YZJT20;Jf]P80_[jn0P2h^;P20;:b/P80Zj^[
0P2SXj<209:BTP80NWYj00<0LW9b06YZJP1ZJVX00P1mOGd20861P@80OGem0P1BDU820492@P80De=C
0P0d=3@205IFEP80D51@0P1WIfL203hn?P80IVIV0P1hN7P208:2PP0309:BTP2JVYX0VYZJ0080UiNG
0P2<S8`208:2PP80PH610P1YJFT2065QH@80EEEE0P17AdL203Ti>@807alO0P0^;Rh2030`<080>CTi
0P1=CDd00`1OGel0KVi^06i^KP0206MWI`80Jf][0P1iNGT206][J`80P8200P1TI6@206MWI`80RHV9
0P2LW9`20:f][BP0dM7A0P3Cdm<<0=7AdAD0oooo000C0?ooo`X0dM7A0P3Cdm<50=7Ad@80dm?C2P3A
dM4208n?S`80XJ6Q0P2LW9`205iNGP80DE5A0P1DE5@204Q8B080BTY:0P1BDU800`1dM7@0Shn?08n?
S`0209ZJVP80S8b<0P2GUiL20:NWY`80/[:b0P2^[Zh209JFUP80Ogmo0P1JFUX204I6AP80EUIF0P1;
Bd/203dm?@80=cLg00<0ADE505mOG`1OGel00P1SHf<205eMG@80K6a/0P22PX8209^KV`80[Jf]102f
][H20;Rh^080/[:b0P2/[:`20::RXP80UYJF0P28R8P00`1kNg/0L71`071`L00206EUI@80HF5Q0P24
Q8@206ATI080<30`0P0a<C4203Lg=`80>c/k0P16ATH2059BDP80De=C0P1FEUH2079bLP80NWYj00<0
OWin08V9R@29RHT00P2=SHd208j>SP80OGem0P1`L702061PH080EeMG0P1BDU82051@D080?clo0P0Z
:RX203<c<`80=3@d0P0f=SH204=3@`03061PH01[Jf/0Jf][0080IFEU0P1NGUh206e]K@80M7Ad0P1o
Ogl206i^KP80LW9b0P2:RXX20:JVYP80alO79`3AdM400`3>c/h0c<c<0<c<c00<0=7AdAD0oooo000C
0?ooo`X0dM7A0P3Cdm<50=7Ad@80dm?C2P3AdM4208n?S`80XJ6Q0P2LW9`205iNGP80DE5A0P1DE5@2
04Q8B080BTY:0P1BDU800`1dM7@0Shn?08n?S`0209ZJVP80S8b<0P2GUiL20:NWY`80/[:b0P2^[Zh2
09JFUP80Ogmo0P1JFUX204I6AP80EUIF0P1;Bd/203dm?@80=cLg00<0ADE505mOG`1OGel00P1SHf<2
05eMG@80K6a/0P22PX8209^KV`80[Jf]102f][H20;Rh^080/[:b0P2/[:`20::RXP80UYJF0P28R8P0
0`1kNg/0L71`071`L00206EUI@80HF5Q0P24Q8@206ATI080<30`0P0a<C4203Lg=`80>c/k0P16ATH2
059BDP80De=C0P1FEUH2079bLP80NWYj00<0OWin08V9R@29RHT00P2=SHd208j>SP80OGem0P1`L702
061PH080EeMG0P1BDU82051@D080?clo0P0Z:RX203<c<`80=3@d0P0f=SH204=3@`03061PH01[Jf/0
Jf][0080IFEU0P1NGUh206e]K@80M7Ad0P1oOgl206i^KP80LW9b0P2:RXX20:JVYP80alO79`3AdM40
0`3>c/h0c<c<0<c<c00<0=7AdAD0oooo000C0?ooo`P0dM7A0P3>c/h20<c<c0@0dM7A00<0c/k>0<c<
c03<c<`01P3AdM420=?Cd`80dM7A0P2BTY8205YJFP80OGem0P1NGUh204U9B@80C4a<0P1ADE420451
@@80FEUI00<0IFEU08f=S@2=SHd00P2KVi/208j>SP80Vi^K0P2[Zj/20;2`/080ZZZZ0P2UYJD209JF
UP80PH610P1MGEd203lo?`80<C4a100Y:BT00`0T92@0<c<c03<c<`0205eMG@80Q8B40P2LW9`20:f]
[@80[jn_0P2/[:`20;Vi^@80_;bl0P2i^KT20:n_[`80Zj^[0P2][Jd20:NWY`80VIVI00<0UYJF08N7
Q`27QhL00P22PX82065QH@80DE5A0P1XJ6P2071`L080HF5Q0P18B4P202l_;`809bLW0P0m?Cd206=S
H`80Lg=c0P1aLG4207MgM`0308N7Q`2=SHd0SHf=0080RHV90P23Ph<208J6QP80Lg=c0P1JFUX205UI
F@80Cdm?0P11@D4204=3@`80;Rh^0P0e=CD203lo?`@0=cLg00<0GemO07EeM@1eMGD00P1UIFD2069R
HP80L71`0P1iNGT208b<S080LW9b0P1eMGD208>3P`80SHf=0P33`l<d0=7Ad@80dm?C5@3oool001<0
oooo203AdM420<k>cP80c<c<103AdM400`3>c/h0c<c<0<c<c0060=7Ad@80dm?C0P3AdM4209:BTP80
FUYJ0P1mOGd205iNGP80BDU90P1<C4`2055AD@80@D510P1IFET00`1UIFD0SHf=08f=S@0209^KV`80
SXj>0P2KVi/20:^[Z`80/;2`0P2ZZZX20:FUY@80UYJF0P21PH4205eMG@80?clo0P0a<C4402TY:@03
02@T900c<c<0<c<c0080GEeM0P24Q8@209bLW080[Jf]0P2_[jl20:b/[080^KVi0P2l_;`20;Vi^@80
[jn_0P2[Zj/20:f][@80YjNW0P2IVIT00`2FUYH0QhN708N7Q`0208:2PP80HF5Q0P1ADE4206QXJ080
L71`0P1QHF4204Q8B080;bl_0P0W9bL203dm?@80Hf=S0P1cLg<2075aL@80MgMg00<0QhN708f=S@2=
SHd00P29RHT208>3P`80QXJ60P1cLg<205YJFP80FEUI0P1?Cdl20451@@80@d=30P0^;Rh203De=@80
?clo100g=cL00`1OGel0MGEe07EeM@0206EUI@80HV9R0P1`L70207UiN@80S8b<0P1bLW8207EeM@80
Ph>30P2=SHd20<?3`c@0dM7A0P3Cdm<E0?ooo`004`3oool60=7Ad@80dm?C103AdM420=?Cd`/0dM7A
0P3<c<`20<o?c`80`/;20P1NGUh2075aL@80?Cdm0P11@D4203lo?`80EEEE0P0b<S8205ADE00307If
MP2<S8`0S8b<0080Rh^;0P27QhL209>CT`80Y:BT0P2^[Zh20;^k^`@0]kNg0P2^[Zh20:VYZ@80Y:BT
0P2IVIT209FEU@80VIVI00<0X:2P09nOW`2OWil00P2JVYX20:RXZ080U9BD0P2MWId20:j^[P80^;Rh
0P2d];@20;Fe]@80^[Zj0P2h^;P20;:b/P80[jn_0P2RXZ8209BDU00308B4Q01oOgl0Ogmo0080RXZ:
0P2DU9@20:2PX080VIVI0P1bLW8206i^KP80Kfm_0P1iNGT208J6QP80Rh^;0P2BTY8209VIV@80VYZJ
0P2HV9P00`2BTY80T92@092@T00209BDU080PH610P1jNWX207QhN080IVIV0P1EEED205=CD`80BTY:
100^;Rh202d];@80?3`l0P0_;bl204U9B@03055AD@1eMGD0MGEe0080L71`0P1OGel207EeM@80P820
0P2CTi<207EeM@80NWYj0P2NWYh20<O7a`80fMWI<P3AdM420<k>cP80c<c<5@3oool001<0oooo103A
dM420<k>cP80c<c<0P3AdM420<k>cP80c<c<1`3AdM420<k>cP80c<c<0P3AdM420=KFeP80i>CT0P1B
DU8204a<C0@0>CTi0P11@D4204a<C080B4Q80P1:BTX00`1NGUh0NGUi07UiN@0208^;R`80QHF50P2<
S8`20:b/[080/;2`0P2^[Zh40<71`@@0^[Zj0P2l_;`20:VYZ@80Zj^[0P2:RXX00`1iNGT0MGEe07Ee
M@02055AD@80HF5Q0P2NWYh20;6a/@80^[Zj0P2g]kL20;jn_P80_Kfm102j^[X20;Ng]`80][Jf0P2c
/k<209bLW00308F5Q@1UIFD0IFEU0080EeMG0P1OGel206m_K`80TY:B0P36a/H20;Vi^@80]kNg0P2Z
ZZX20:BTY080XJ6Q0P2RXZ820:2PX080XJ6Q0P2FUYH00`27QhL0RXZ:08Z:RP0207YjNP80Q8B40P1f
MWH206a/K080JFUY0P1IFET20492@P80ADE50P0b<S82034a<@80:RXZ0P0Y:BT204=3@`80?Cdm00<0
De=C06=SH`1SHf<00P1WIfL205YJFP80N7Qh0P23Ph<209fMW@80S8b<0P1hN7P20:NWY`80`l?3>03A
dM4E0?ooo`004`3oool40=7Ad@80c/k>0P3<c<`20=7Ad@80c/k>0P3<c<`70=7Ad@80c/k>0P3<c<`2
0=7Ad@80e]KF0P3Ti>@2059BDP80C4a<100i>CT20451@@80C4a<0P18B4P204Y:BP0305iNGP1iNGT0
NGUi0080Rh^;0P25QHD208b<S080[:b/0P2`/;020:j^[P@0`L71102j^[X20;bl_080ZJVY0P2[Zj/2
08Z:RP0307UiN@1eMGD0MGEe0080DE5A0P1QHF4209jNWP80/K6a0P2j^[X20;Ng]`80_[jn0P2m_Kd4
0;Zj^P80]kNg0P2f][H20;>c/`80W9bL00<0QHF506EUI@1UIFD00P1GEeL205mOG`80Kfm_0P2BTY82
0<K6aP80^KVi0P2g]kL20:ZZZP80Y:BT0P2QXJ420::RXP80X:2P0P2QXJ4209JFUP0308N7Q`2:RXX0
RXZ:0080NWYj0P24Q8@207IfMP80K6a/0P1YJFT205UIF@80@T920P15ADD2038b<P80<C4a0P0Z:RX2
02TY:@80@d=30P0m?Cd00`1CDe<0Hf=S06=SH`0206MWI`80FUYJ0P1hN7P208>3P`80WIfM0P2<S8`2
07QhN080YjNW0P33`l<h0=7AdAD0oooo000C0?oooaL0dM7A0P3Cdm<20<o?c`80_kno0P3_knl206=S
H`80?Cdm0P13@d<203/k>`80=3@d0P1CDe<204U9B@80EEEE00<0GemO06MWI`1WIfL00P20P80208:2
PP80RHV90P2QXJ420:j^[P80W9bL0P2e]KD20<;2`P80a<C40P2o_kl20:ZZZP80WIfM0P1oOgl205IF
EP0303@d=01?Cdl0Cdm?0080RHV90P2VYZH20:n_[`80/[:b0P2j^[X20;fm_@80^k^k0P31`L420;Zj
^P@0_;bl0P2h^;P20;Bd]080/[:b00<0X:2P07inOP1nOWh00P1ADE4203Ti>@80A4A40P1HF5P206i^
KP80WIfM0P2KVi/20;Fe]@80^k^k0P2a/K420:RXZ080XJ6Q0P2JVYX209JFUP030861P@1fMWH0MWIf
0080Q8B40P1jNWX206i^KP80IVIV0P1SHf<405EEE@808b<S0P11@D4203Hf=P80<c<c0P0X:2P202`/
;080H61P00<0GUiN06YZJP1ZJVX00P1YJFT205mOG`80L71`0P22PX820861P@80R8R80P2JVYX209JF
UR40dM7A0P3Cdm<G0=7AdAD0oooo000C0?oooaL0dM7A0P3Cdm<20<o?c`80_kno0P3_knl206=SH`80
?Cdm0P13@d<203/k>`80=3@d0P1CDe<204U9B@80EEEE00<0GemO06MWI`1WIfL00P20P80208:2PP80
RHV90P2QXJ420:j^[P80W9bL0P2e]KD20<;2`P80a<C40P2o_kl20:ZZZP80WIfM0P1oOgl205IFEP03
03@d=01?Cdl0Cdm?0080RHV90P2VYZH20:n_[`80/[:b0P2j^[X20;fm_@80^k^k0P31`L420;Zj^P@0
_;bl0P2h^;P20;Bd]080/[:b00<0X:2P07inOP1nOWh00P1ADE4203Ti>@80A4A40P1HF5P206i^KP80
WIfM0P2KVi/20;Fe]@80^k^k0P2a/K420:RXZ080XJ6Q0P2JVYX209JFUP030861P@1fMWH0MWIf0080
Q8B40P1jNWX206i^KP80IVIV0P1SHf<405EEE@808b<S0P11@D4203Hf=P80<c<c0P0X:2P202`/;080
H61P00<0GUiN06YZJP1ZJVX00P1YJFT205mOG`80L71`0P22PX820861P@80R8R80P2JVYX209JFUR40
dM7A0P3Cdm<G0=7AdAD0oooo000C0?oooaD0dM7A103?cll20=GEe@80/;2`0P2KVi/207YjNP80B4Q8
0P1=CDd204I6AP80?clo0P10@40204Y:BP80D51@00<0FEUI05YJFP1JFUX00P1VIVH207IfMP80S8b<
0P2KVi/20;:b/P80VIVI0P1^KVh20820P080T92@0P2:RXX207YjNP80BDU90P1:BTX208B4Q0030;:b
/P2g]kL0]kNg0080^[Zj2P30`<020;bl_080^[Zj0P2i^KT40;Fe]@@0]kNg0P2c/k<00`2d];@0/[:b
0;:b/P020:RXZ080TY:B0P1iNGT205EEE@80=SHf0P0a<C4204i>CP80GUiN0P1eMGD207moO`@0O7al
101/K6`00`1mOGd0QHF508F5Q@020861P@80Ogmo0P1aLG4206QXJ080IFEU0P1ADE4204E5A@80CDe=
0P0b<S8203Ph>0@08R8R0P0V9RH2055AD@03069RHP1NGUh0GUiN0080LW9b0P1MGEd207=cL`80QHF5
0P1fMWH407alO080/[:b7`3AdM420<k>cP80c<c<0P3AdM420=?Cda<0dM7A5@3oool001<0oooo5@3A
dM440<o?c`80eMGE0P2`/;0209^KV`80NWYj0P18B4P204e=C@80ATI60P0o?cl20410@080BTY:0P1@
D5000`1IFET0FUYJ05YJFP0206IVIP80MWIf0P2<S8`209^KV`80/[:b0P2IVIT206i^KP80P8200P2@
T90208Z:RP80NWYj0P19BDT204Y:BP80Q8B400<0/[:b0;Ng]`2g]kL00P2j^[X:0<30`080_;bl0P2j
^[X20;Vi^@@0]KFe102g]kL20;>c/`030;Bd]02b/[80/[:b0080Z:RX0P2BTY8207UiN@80EEEE0P0f
=SH2034a<@80CTi>0P1NGUh207EeM@80Ogmo101lO7`406a/K00307emO@25QHD0QHF50080PH610P1o
Ogl2075aL@80J6QX0P1UIFD2055AD@80ADE50P1=CDd2038b<P80>3Ph100R8R8202HV9P80DE5A00<0
HV9R05iNGP1NGUh00P1bLW8205eMG@80Lg=c0P25QHD207IfMP@0O7al0P2b/[8O0=7Ad@80c/k>0P3<
c<`20=7Ad@80dm?C4`3AdM4E0?ooo`004`3oool:0=7Ad@80dm?C1@3AdM420=?Cd`80dM7A0P3>c/h2
0<c<c080dM7A0P2/[:`206QXJ080E5AD0P14A4@205aLG080De=C0P1:BTX204Q8B080A4A40P1ADE40
0`1CDe<0Fe]K05]KF`0206MWI`80Jf][0P28R8P20:JVYP80/K6a0P2f][H20;6a/@80Vi^K0P1eMGD2
06MWI`80L71`0P2KVi/20;fm_@l0`<300P31`L420;fm_@@0^KVi0P30`<040<71`@80_;bl0P2k^k/0
0`2j^[X0^KVi0;Vi^@020;6a/@80[jn_0P2/[:`20:^[Z`80[Zj^0P2/[:`209ZJVP80KFe]0P1=CDd2
051@D080Fe]K0P1YJFT20820P080QHF50`24Q8@208^;R`80PH610P1eMGD206a/K080JFUY0P1OGel2
0410@080>SXj0P0];Bd2024Q8@807alO0P0K6a/2028R8P<0E5AD0P1MGEd206e]K@80G5aL0P1fMWH2
09FEU@80JFUY0P1hN7P209NGU`80`l?38`3AdM420<k>cP80c<c<4`3AdM4E0?ooo`004`3oool:0=7A
d@80dm?C1@3AdM420=?Cd`80dM7A0P3>c/h20<c<c080dM7A0P2/[:`206QXJ080E5AD0P14A4@205aL
G080De=C0P1:BTX204Q8B080A4A40P1ADE400`1CDe<0Fe]K05]KF`0206MWI`80Jf][0P28R8P20:JV
YP80/K6a0P2f][H20;6a/@80Vi^K0P1eMGD206MWI`80L71`0P2KVi/20;fm_@l0`<300P31`L420;fm
_@@0^KVi0P30`<040<71`@80_;bl0P2k^k/00`2j^[X0^KVi0;Vi^@020;6a/@80[jn_0P2/[:`20:^[
Z`80[Zj^0P2/[:`209ZJVP80KFe]0P1=CDd2051@D080Fe]K0P1YJFT20820P080QHF50`24Q8@208^;
R`80PH610P1eMGD206a/K080JFUY0P1OGel20410@080>SXj0P0];Bd2024Q8@807alO0P0K6a/2028R
8P<0E5AD0P1MGEd206e]K@80G5aL0P1fMWH209FEU@80JFUY0P1hN7P209NGU`80`l?38`3AdM420<k>
cP80c<c<4`3AdM4E0?ooo`004`3oool60=7Ad@80dm?C0P3>c/h20<c<c0D0dM7A0P3<c<`80=7Ad@80
^;Rh0P1UIFD205QHF080DU9B101QHF4405=CD`80CDe=0P1?Cdl00`1FEUH0F5QH05QHF00206][J`80
JVYZ0P25QHD20::RXP80/K6a0P2`/;020;Bd]080]kNg0P2k^k/20;Zj^P80^KVi0P2e]KD20;Zj^P80
aLG500<0a<C40<30`030`<000P30`<020<71`@80a<C41031`L420<30`0@0_Kfm0P35aLD40<71`@80
^KVi0P2e]KD20;Zj^P030;Vi^@2j^[X0^[Zj0080]kNg0P2`/;020;Jf]P80/[:b102_[jl20:b/[0@0
Zj^[0P2/[:`209nOW`@0Vi^K0`2BTY8208b<S080PX:20P1gMgL206YZJP@0KVi^0P1OGel205iNGP80
>SXj0P0[:b/202PX:080820P0P0Z:RX2028R8P80HF5Q00<0JVYZ059BDP1BDU800P1jNWX207IfMP80
IVIV0P2CTi<2071`L080OWin0P2KVi/20<c<c3X0dM7A5@3oool001<0oooo1P3AdM420=?Cd`80c/k>
0P3<c<`50=7Ad@80c<c<203AdM420;Rh^080IFEU0P1HF5P2059BDP@0HF5Q101CDe<204e=C@80Cdm?
00<0EUIF05QHF01HF5P00P1[Jf/206YZJP80QHF50P2RXZ820;6a/@80/;2`0P2d];@20;Ng]`80^k^k
0P2j^[X20;Vi^@80]KFe0P2j^[X20<G5a@030<C4a030`<00`<300080`<300P31`L420<C4a0@0`L71
0P30`<040;fm_@80aLG51031`L420;Vi^@80]KFe0P2j^[X00`2i^KT0^[Zj0;Zj^P020;Ng]`80/;2`
0P2f][H20;:b/P@0[jn_0P2/[:`40:^[Z`80[:b/0P2OWil409^KV`<0TY:B0P2<S8`208:2PP80MgMg
0P1ZJVX406i^KP80GemO0P1NGUh203Xj>P80:b/[0P0X:2P2020P8080:RXZ0P0R8R82065QH@0306YZ
JP1BDU80DU9B0080NWYj0P1fMWH206IVIP80Ti>C0P1`L70207inOP80Vi^K0P3<c<`j0=7AdAD0oooo
000C0?ooo`@0dM7A0P3>c/h20<c<c0H0dM7A0P3>c/h00`3<c<`0dM7A0=7Ad@080=7Ad@80/k>c0P1H
F5P205=CD`80D51@0P1WIfL206YZJP80GEeM101BDU82051@D003059BDP1CDe<0De=C0080IfMW0P1^
KVh207inOP80Zj^[0P2e]KD20;Jf]P80];Bd0P2i^KT20;jn_P80^[Zj0P2m_Kd20<G5a@80_;bl0P2f
][H00`2n_[h0`<300<30`0020<30`080_Kfm0P2j^[X60<30`080_Kfm0P2f][H20;Vi^@80_;bl0P2e
]KD20;Zj^P80`L710P2j^[X00`2l_;`0_[jn0;jn_P020;jn_P80^KVi0P2b/[820;>c/`80/;2`0P2_
[jl20:ZZZP80Z:RX0P2/[:`20:6QX@80WinO0P2HV9P2096AT@80TY:B00<0SHf=08Z:RP2:RXX00P22
PX8207alO080MGEe0P1^KVh206QXJ080Hf=S0P1=CDd203lo?`80>c/k0P0];Bd201dM7@807alO0P0W
9bL206QXJ00307EeM@1RHV80HV9R0080LG5a0P1`L702065QH@80QhN70P1gMgL207inOP80Y:BT0P3I
fMTj0=7AdAD0oooo000C0?ooo`@0dM7A0P3>c/h20<c<c0H0dM7A0P3>c/h00`3<c<`0dM7A0=7Ad@08
0=7Ad@80/k>c0P1HF5P205=CD`80D51@0P1WIfL206YZJP80GEeM101BDU82051@D003059BDP1CDe<0
De=C0080IfMW0P1^KVh207inOP80Zj^[0P2e]KD20;Jf]P80];Bd0P2i^KT20;jn_P80^[Zj0P2m_Kd2
0<G5a@80_;bl0P2f][H00`2n_[h0`<300<30`0020<30`080_Kfm0P2j^[X60<30`080_Kfm0P2f][H2
0;Vi^@80_;bl0P2e]KD20;Zj^P80`L710P2j^[X00`2l_;`0_[jn0;jn_P020;jn_P80^KVi0P2b/[82
0;>c/`80/;2`0P2_[jl20:ZZZP80Z:RX0P2/[:`20:6QX@80WinO0P2HV9P2096AT@80TY:B00<0SHf=
08Z:RP2:RXX00P22PX8207alO080MGEe0P1^KVh206QXJ080Hf=S0P1=CDd203lo?`80>c/k0P0];Bd2
01dM7@807alO0P0W9bL206QXJ00307EeM@1RHV80HV9R0080LG5a0P1`L702065QH@80QhN70P1gMgL2
07inOP80Y:BT0P3IfMTj0=7AdAD0oooo000C0?ooo``0dM7A0P3Cdm<=0=7Ad@80_;bl0P1RHV82055A
D@80FUYJ0P1KFe/206ATI080GEeM0P1GEeL205UIF@80D51@00<0DU9B04i>CP1>CTh00P1RHV8206IV
IP80M7Ad0P2BTY820:j^[P80]kNg102d];@20;Ng]`80^k^k0P2j^[X20;jn_P80aLG50P2m_Kd00`2j
^[X0`<300<30`0020<30`080`L711034a<@80<30`080`L711035aLD20<71`@@0^[Zj00<0_;bl0;Jf
]P2f][H0102f][H20;Rh^080][Jf0P2_[jl20:f][@80/k>c0P2_[jl20:RXZ080Y:BT0P2NWYh209bL
W080UiNG0P2DU9@00`2>SXh0TY:B09:BTP0208Z:RP80PH610P1/K6`206e]K@80Jf][0P1KFe/2051@
D080>3Ph0P0l?3`202HV9P807QhN0P0K6a/202d];@80G5aL00<0Rh^;069RHP1RHV800P1fMWH207Qh
N080Hf=S0P1UIFD208^;R`80M7Ad0P3<c<`U0=7Ad@80dm?C5@3AdM4E0?ooo`004`3oool<0=7Ad@80
dm?C3@3AdM420;bl_080HV9R0P1ADE4205YJFP80Fe]K0P1TI6@205eMG@80EeMG0P1IFET2051@D003
059BDP1>CTh0CTi>0080HV9R0P1VIVH207AdM080TY:B0P2^[Zh20;Ng]`@0];Bd0P2g]kL20;^k^`80
^[Zj0P2n_[h20<G5a@80_Kfm00<0^[Zj0<30`030`<000P30`<020<71`@@0a<C42030`<020<71`@@0
aLG50P31`L440;Zj^P030;bl_02f][H0][Jf00@0][Jf0P2h^;P20;Jf]P80[jn_0P2][Jd20;>c/`80
[jn_0P2XZ:P20:BTY080WYjN0P2LW9`209NGU`80U9BD00<0SXj>09:BTP2BTY800P2:RXX20861P@80
K6a/0P1]KFd206][J`80Fe]K0P1@D50203Ph>080?3`l0P0V9RH201hN7P806a/K0P0];Bd205aLG003
08^;R`1RHV80HV9R0080MWIf0P1hN7P206=SH`80IFEU0P2;Rh/207AdM080c<c<9@3AdM420=?CdaD0
dM7A5@3oool001<0oooo2P3AdM420<k>cP80c<c<3@3AdM420<c<c080IVIV0P1NGUh204];B`80EEEE
0P1FEUH205aLG080EUIF0P1@D50205=CD`0304m?C`1HF5P0F5QH0080H61P0P1hN7P207]kN`80V9RH
0P2ZZZX20:j^[P80];Bd0P2e]KD20;Jf]P80^k^k0P2j^[X20;Rh^080^KVi0P31`L430<C4a080`<30
0P2m_Kd40;Zj^P80`L710P35aLD40<30`080_Kfm1P2j^[X20;Vi^@80];Bd00<0[jn_0;>c/`2c/k<0
0P2f][H20;Bd]080/K6a102_[jl20:VYZ@80YjNW0P2ZZZX20:VYZ@80Z:RX0P2OWil209ZJVP80VIVI
0P2FUYH00`2<S8`0PX:208:2PP020861P@80O7al0P1kNg/206i^KP80I6AT0P1GEeL203hn?P80ADE5
100Y:BT2028R8P806a/K0P0X:2P205iNGP030861P@1kNg/0Ng]k0080SHf=0P23Ph<206][J`80Fe]K
0P1nOWh20::RXRD0dM7A0P3>c/h20<c<c1D0dM7A5@3oool001<0oooo2P3AdM420<k>cP80c<c<3@3A
dM420<c<c080IVIV0P1NGUh204];B`80EEEE0P1FEUH205aLG080EUIF0P1@D50205=CD`0304m?C`1H
F5P0F5QH0080H61P0P1hN7P207]kN`80V9RH0P2ZZZX20:j^[P80];Bd0P2e]KD20;Jf]P80^k^k0P2j
^[X20;Rh^080^KVi0P31`L430<C4a080`<300P2m_Kd40;Zj^P80`L710P35aLD40<30`080_Kfm1P2j
^[X20;Vi^@80];Bd00<0[jn_0;>c/`2c/k<00P2f][H20;Bd]080/K6a102_[jl20:VYZ@80YjNW0P2Z
ZZX20:VYZ@80Z:RX0P2OWil209ZJVP80VIVI0P2FUYH00`2<S8`0PX:208:2PP020861P@80O7al0P1k
Ng/206i^KP80I6AT0P1GEeL203hn?P80ADE5100Y:BT2028R8P806a/K0P0X:2P205iNGP030861P@1k
Ng/0Ng]k0080SHf=0P23Ph<206][J`80Fe]K0P1nOWh20::RXRD0dM7A0P3>c/h20<c<c1D0dM7A5@3o
ool001<0oooo6`3AdM420=CDe080Ogmo0P19BDT205aLG080FEUI0P1NGUh205YJFP80HF5Q0P1CDe<2
05ADE00305YJFP1CDe<0De=C0080IFEU0P1gMgL208F5Q@80TY:B0P2VYZH20:n_[`80]kNg0P2h^;P4
0;jn_P80^k^k0P2n_[h20<C4a080_Kfm00<0]kNg0;no_`2o_kl00P34a<@20;fm_@80^k^k0P35aLD2
0<30`080^[Zj0P34a<@20<G5a@80`L710P2i^KT40;Zj^P@0^k^k00<0_[jn0;Rh^02h^;P00P2f][H2
0;Bd]080/k>c0P2[Zj/20:n_[`80ZZZZ0P2OWil60:6QX@80X:2P0P2NWYh209RHV080UIFE00<0SXj>
08n?S`2?Shl00P21PH4207YjNP80NGUi0P1]KFd206][J`80FEUI0P16ATH203Xj>P80:b/[0P0M7Ad4
01DE5@80?Cdm0P18B4P307UiN@80Ng]k0P20P80207YjNP80GemO0P1WIfL20:j^[Sh0dM7A5@3oool0
01<0oooo6`3AdM420=CDe080Ogmo0P19BDT205aLG080FEUI0P1NGUh205YJFP80HF5Q0P1CDe<205AD
E00305YJFP1CDe<0De=C0080IFEU0P1gMgL208F5Q@80TY:B0P2VYZH20:n_[`80]kNg0P2h^;P40;jn
_P80^k^k0P2n_[h20<C4a080_Kfm00<0]kNg0;no_`2o_kl00P34a<@20;fm_@80^k^k0P35aLD20<30
`080^[Zj0P34a<@20<G5a@80`L710P2i^KT40;Zj^P@0^k^k00<0_[jn0;Rh^02h^;P00P2f][H20;Bd
]080/k>c0P2[Zj/20:n_[`80ZZZZ0P2OWil60:6QX@80X:2P0P2NWYh209RHV080UIFE00<0SXj>08n?
S`2?Shl00P21PH4207YjNP80NGUi0P1]KFd206][J`80FEUI0P16ATH203Xj>P80:b/[0P0M7Ad401DE
5@80?Cdm0P18B4P307UiN@80Ng]k0P20P80207YjNP80GemO0P1WIfL20:j^[Sh0dM7A5@3oool001<0
oooo6`3AdM420=CDe080LG5a0P1^KVh204m?C`80DU9B0P1SHf<205aLG0@0EUIF0P1EEED00`19BDT0
IfMW06MWI`0206QXJ080LW9b0P1nOWh209>CT`80XJ6Q0P2][Jd20;>c/`80]kNg102f][H20;^k^`@0
^[Zj0P31`L400`30`<00]KFe0;Fe]@020;Zj^P80`L710P30`<020;Jf]P80_[jn0P31`L420;Ng]`80
^KVi0P2j^[X20;^k^`80^[Zj102l_;`20;Rh^0030;Jf]P2h^;P0^;Rh0080/k>c0P2f][H20;:b/P80
];Bd0P2_[jl20:j^[P80/;2`0P2TY:@20:VYZ@80YZJV0P2RXZ8209bLW080V9RH0P2EUID00`2:RXX0
R8R808R8R00207inOP80NWYj0P1bLW8206e]K@80G5aL101BDU8203@d=0807alO0P0E5AD202DU9@80
4A4A0P17AdL205QHF00306=SH`1YJFT0JFUY0080QhN70P2;Rh/2092@T080Ti>C0P25QHE00=7AdAD0
oooo000C0?oooa/0dM7A0P3De=@2075aL@80KVi^0P1?Cdl2059BDP80Hf=S0P1LG5`405IFEP80EEEE
00<0BDU906MWI`1WIfL00P1XJ6P2079bLP80OWin0P2CTi<20:6QX@80[Jf]0P2c/k<20;Ng]`@0][Jf
0P2k^k/40;Zj^P80`L7100<0`<300;Fe]@2e]KD00P2j^[X20<71`@80`<300P2f][H20;jn_P80`L71
0P2g]kL20;Vi^@80^[Zj0P2k^k/20;Zj^P@0_;bl0P2h^;P00`2f][H0^;Rh0;Rh^0020;>c/`80][Jf
0P2b/[820;Bd]080[jn_0P2^[Zh20;2`/080Y:BT0P2YZJT20:JVYP80XZ:R0P2LW9`209RHV080UIFE
00<0RXZ:08R8R028R8P00P1nOWh207YjNP80LW9b0P1]KFd205aLG0@0DU9B0P0d=3@201lO7`805ADE
0P0U9BD2014A4@80AdM70P1HF5P00`1SHf<0JFUY06UYJ@0208N7Q`80Rh^;0P2@T90209>CT`80QHF5
@03AdM4E0?ooo`004`3oool60=7Ad@80dm?C0P3AdM420=?Cd`l0dM7A0P3EeMD208V9R@80?clo0P1P
H602065QH@80EEEE0P1GEeL205EEE@80EeMG0P1DE5@00`1IFET0CTi>04i>CP0206YZJP80NWYj0P21
PH4208J6QP80WinO0P2/[:`20;:b/P80]KFe0P2f][H20;^k^`80_;bl0P2n_[h20<30`080_Kfm00<0
_;bl0<71`@31`L400P34a<@20;fm_@80_[jn0P31`L440;Zj^P80`L710P2k^k/60;Zj^P80^KVi0P2j
^[X20;bl_0<0^k^k0P2i^KT20:f][@80/;2`0P2c/k<20:n_[`80ZJVY0P2[Zj/20:RXZ080Xj>S0P2O
Wil409bLW080V9RH0P2BTY800`2<S8`0R8R808R8R0020861P@80NGUi0P1`L70206IVIP80G5aL0P1;
Bd/203hn?P80>CTi0P0M7Ad201/K6`809BDU0P0K6a/204Y:BP80GEeM00<0IFEU05eMG@1MGEd00P1h
N7P208N7Q`80R8R80P2KVi/20;Vi^D00dM7A5@3oool001<0oooo1P3AdM420=?Cd`80dM7A0P3Cdm<?
0=7Ad@80eMGE0P29RHT203lo?`80H61P0P1QHF4205EEE@80EeMG0P1EEED205MGE`80E5AD00<0FEUI
04i>CP1>CTh00P1ZJVX207YjNP80PH610P26QXH209nOW`80[:b/0P2b/[820;Fe]@80][Jf0P2k^k/2
0;bl_080_[jn0P30`<020;fm_@030;bl_031`L40`L710080a<C40P2m_Kd20;jn_P80`L71102j^[X2
0<71`@80^k^k1P2j^[X20;Vi^@80^[Zj0P2l_;`30;^k^`80^KVi0P2][Jd20;2`/080/k>c0P2_[jl2
0:VYZ@80Zj^[0P2XZ:P20:>SX`80WinO102LW9`209RHV080TY:B00<0S8b<08R8R028R8P00P21PH42
07UiN@80L71`0P1VIVH205aLG080Bd];0P0n?Sh203Ti>@807AdM0P0K6a/202DU9@806a/K0P1:BTX2
05eMG@0306EUI@1MGEd0GEeM0080N7Qh0P27QhL208R8R080Vi^K0P2i^KU00=7AdAD0oooo000C0?oo
o`@0dM7A0P3>c/h20<c<c080c/k>0P3<c<`A0=7Ad@80`/;20P1`L70205eMG@80D51@0P1;Bd/2055A
D@80CDe=0P1<C4`205EEE@0305QHF01OGel0GemO0080JFUY0P1fMWH208R8R080TI6A0P2NWYh20:b/
[080/[:b0P2g]kL20<30`0@0^[Zj0P2n_[h20<C4a080`L7100<0_[jn0<71`@31`L400P2j^[X20;fm
_@@0][Jf0P2o_kl20<71`@80]kNg0P2i^KT20;Zj^PH0^k^k102j^[X30;^k^`80/[:b0P2f][H20;:b
/P80[jn_0P2[Zj/20:ZZZP80YJFU0P2XZ:P20:2PX080WinO0P2LW9`209ZJVP80WYjN0P2GUiL00`2@
T900R8R808R8R00208B4Q080MWIf0P1ZJVX2061PH080HF5Q0P17AdL203/k>`80:2PX0P0U9BD201<C
4`808R8R0P0M7Ad205ADE080GUiN00<0HV9R06=SH`1SHf<00P1jNWX208R8R080QhN70P2PX:120=7A
dAD0oooo000C0?ooo`@0dM7A0P3>c/h20<c<c080c/k>0P3<c<`A0=7Ad@80`/;20P1`L70205eMG@80
D51@0P1;Bd/2055AD@80CDe=0P1<C4`205EEE@0305QHF01OGel0GemO0080JFUY0P1fMWH208R8R080
TI6A0P2NWYh20:b/[080/[:b0P2g]kL20<30`0@0^[Zj0P2n_[h20<C4a080`L7100<0_[jn0<71`@31
`L400P2j^[X20;fm_@@0][Jf0P2o_kl20<71`@80]kNg0P2i^KT20;Zj^PH0^k^k102j^[X30;^k^`80
/[:b0P2f][H20;:b/P80[jn_0P2[Zj/20:ZZZP80YJFU0P2XZ:P20:2PX080WinO0P2LW9`209ZJVP80
WYjN0P2GUiL00`2@T900R8R808R8R00208B4Q080MWIf0P1ZJVX2061PH080HF5Q0P17AdL203/k>`80
:2PX0P0U9BD201<C4`808R8R0P0M7Ad205ADE080GUiN00<0HV9R06=SH`1SHf<00P1jNWX208R8R080
QhN70P2PX:120=7AdAD0oooo000C0?oooad0dM7A0P3EeMD209FEU@80A4A40P1>CTh204e=C@80Bd];
0P1>CTh204];B`80BTY:00<0EEEE06IVIP1VIVH00P1`L7020820P080RHV90P2HV9P20:2PX080Zj^[
0P2c/k<40;Bd]0@0^[Zj0P2k^k/20;Ng]`80^k^k00<0][Jf0;Vi^@2i^KT01030`<020<71`@80`<30
0P2e]KD20;fm_@80`L710P2g]kL20;bl_080^k^k0P2l_;`60;^k^`030;Jf]P2b/[80/[:b0080/k>c
0P2f][H20;Bd]080/K6a0P2f][H40:n_[`80Zj^[0P2YZJT209nOW`80Vi^K0P2HV9P209FEU@80VYZJ
00<0TI6A092@T02@T9000P1mOGd207AdM080MWIf0P1VIVH205ADE080>c/k0P0d=3@202@T90809bLW
0P0J6QX2020P80808R8R0P1FEUH206a/K00305ADE01VIVH0IVIV0080M7Ad102KVi/20:b/[080dM7A
0P3Cdm<n0=7AdAD0oooo000C0?oooad0dM7A0P3EeMD209FEU@80A4A40P1>CTh204e=C@80Bd];0P1>
CTh204];B`80BTY:00<0EEEE06IVIP1VIVH00P1`L7020820P080RHV90P2HV9P20:2PX080Zj^[0P2c
/k<40;Bd]0@0^[Zj0P2k^k/20;Ng]`80^k^k00<0][Jf0;Vi^@2i^KT01030`<020<71`@80`<300P2e
]KD20;fm_@80`L710P2g]kL20;bl_080^k^k0P2l_;`60;^k^`030;Jf]P2b/[80/[:b0080/k>c0P2f
][H20;Bd]080/K6a0P2f][H40:n_[`80Zj^[0P2YZJT209nOW`80Vi^K0P2HV9P209FEU@80VYZJ00<0
TI6A092@T02@T9000P1mOGd207AdM080MWIf0P1VIVH205ADE080>c/k0P0d=3@202@T90809bLW0P0J
6QX2020P80808R8R0P1FEUH206a/K00305ADE01VIVH0IVIV0080M7Ad102KVi/20:b/[080dM7A0P3C
dm<n0=7AdAD0oooo000C0?ooo`@0dM7A0P3Cdm<I0=7Ad@80/;2`0P1NGUh204Y:BP80C4a<0P1?Cdl2
04i>CP@0D51@00<0Bd];05mOG`1OGel00P1`L70207QhN080QHF50P2BTY820:BTY080Z:RX0P2c/k<4
0;Zj^P80_Kfm0P2i^KT20;fm_@80`<300P2m_Kd00`34a<@0`L710<71`@020<C4a0@0`L710P2m_Kd2
0<71`@80^k^k0P2m_Kd20<71`@H0^[Zj0P2k^k/20;bl_080^k^k00<0^;Rh0;Vi^@2i^KT00P2k^k/2
0;Fe]@80/;2`0P2b/[840:n_[`80[Zj^0P2/[:`20:6QX@80WYjN0P2IVIT209^KV`80UiNG0P2DU9@0
0`2ATI40PX:208:2PP0208F5Q@80M7Ad0P1]KFd206IVIP80FEUI0P0l?3`2038b<P80:2PX0P0S8b<2
02TY:@809RHV0P0L71`205]KF`80Ng]k0`1UIFD207QhN080T92@0P2e]KD20=7Ad@80c/k>0P3<c<`n
0=7AdAD0oooo000C0?ooo`@0dM7A0P3Cdm<I0=7Ad@80/;2`0P1NGUh204Y:BP80C4a<0P1?Cdl204i>
CP@0D51@00<0Bd];05mOG`1OGel00P1`L70207QhN080QHF50P2BTY820:BTY080Z:RX0P2c/k<40;Zj
^P80_Kfm0P2i^KT20;fm_@80`<300P2m_Kd00`34a<@0`L710<71`@020<C4a0@0`L710P2m_Kd20<71
`@80^k^k0P2m_Kd20<71`@H0^[Zj0P2k^k/20;bl_080^k^k00<0^;Rh0;Vi^@2i^KT00P2k^k/20;Fe
]@80/;2`0P2b/[840:n_[`80[Zj^0P2/[:`20:6QX@80WYjN0P2IVIT209^KV`80UiNG0P2DU9@00`2A
TI40PX:208:2PP0208F5Q@80M7Ad0P1]KFd206IVIP80FEUI0P0l?3`2038b<P80:2PX0P0S8b<202TY
:@809RHV0P0L71`205]KF`80Ng]k0`1UIFD207QhN080T92@0P2e]KD20=7Ad@80c/k>0P3<c<`n0=7A
dAD0oooo000C0?ooo`80dM7A0P3>c/h20<c<c1T0dM7A0P3>c/h208:2PP80De=C0P13@d<204i>CP80
CDe=0P1;Bd/2059BDP03055AD@1JFUX0FUYJ0080K6a/0P28R8P208n?S`80UiNG0P2PX:020;>c/`@0
[jn_0P2d];@20;Jf]P@0^k^k0P2l_;`20;^k^`030;Zj^P2m_Kd0_Kfm0080_kno0P30`<020;Zj^P80
_;bl0P2k^k/20;Zj^P80^k^k0P2i^KT20;Zj^P80_;bl0P2k^k/40;Zj^P<0^k^k0P2f][H20;Bd]0@0
]KFe0P2b/[840;2`/080Zj^[102XZ:P20:JVYP80X:2P0P2KVi/209RHV080TY:B00<0RXZ:08J6QP26
QXH00P1mOGd207AdM080JFUY0P1MGEd204e=C@80?3`l0P0f=SH202/[:`808b<S0P0Z:RX201hN7P80
5ADE0P1EEED206e]K@0306i^KP1eMGD0MGEe0080Rh^;0P2LW9`20;:b/T@0dM7A5@3oool001<0oooo
0P3AdM420<k>cP80c<c<6@3AdM420<k>cP80PX:20P1CDe<204=3@`80CTi>0P1=CDd204];B`80DU9B
00<0DE5A05YJFP1JFUX00P1/K6`208R8R080Shn?0P2GUiL20:2PX080/k>c102_[jl20;Bd]080][Jf
102k^k/20;bl_080^k^k00<0^[Zj0;fm_@2m_Kd00P2o_kl20<30`080^[Zj0P2l_;`20;^k^`80^[Zj
0P2k^k/20;Vi^@80^[Zj0P2l_;`20;^k^`@0^[Zj0`2k^k/20;Jf]P80];Bd102e]KD20;:b/P@0/;2`
0P2[Zj/40:RXZ080YZJV0P2PX:0209^KV`80V9RH0P2BTY800`2:RXX0QXJ608J6QP0207emO@80M7Ad
0P1YJFT205eMG@80CDe=0P0l?3`203Hf=P80:b/[0P0S8b<202XZ:P807QhN0P0E5AD205EEE@80KFe]
00<0KVi^07EeM@1eMGD00P2;Rh/209bLW080/[:bA03AdM4E0?ooo`004`3ooolQ0=7Ad@80Rh^;0P0g
=cL204M7A`80CDe=0P1EEED2059BDP80Bd];00<0DU9B061PH01PH6000P1[Jf/207EeM@80U9BD0P2W
YjL20:^[Z`80Z:RX0P2c/k<20;Zj^P80^KVi0P2o_kl20;jn_P80^k^k0P2j^[X20;jn_P030<G5a@30
`<00`<300080^[Zj0P2k^k/20;Ng]`80^KVi0P2j^[X20;Vi^@80^[Zj0P2k^k/20;Zj^P80_;bl0P2k
^k/40;jn_P80^k^k00<0][Jf0;>c/`2c/k<00P2g]kL20;:b/P80];Bd102_[jl20:j^[P80/;2`0P2W
YjL20:BTY080X:2P0P2NWYh209NGU`80Vi^K0P2GUiL00`2:RXX0QHF508F5Q@0207MgM`80M7Ad0P1Q
HF4205MGE`80AdM70P14A4@2034a<@80<S8b0P0S8b<201dM7@804a<C0P0_;bl204A4A080GemO00<0
JFUY07=cL`1cLg<00P2<S8`20;>c/`80bLW90P3Cdm=20=7AdAD0oooo000C0?ooo`@0dM7A0P3Cdm<A
0=7Ad@80dm?C203AdM420=CDe080/;2`0P1HF5P204];B`80HF5Q0P1KFe/205iNGP0305=CD`1IFET0
FEUI0080Kfm_0P21PH4208J6QP80WIfM0P2^[Zh40:n_[`80/k>c0P2e]KD20;Bd]080]KFe0P2i^KT2
0;bl_0<0^[Zj0P2k^k/20;Zj^P80_Kfm0P31`L440;Zj^P80_;bl102k^k/20;Rh^080][Jf0P2h^;P7
0;Jf]P80^;Rh102f][H40:j^[P80[jn_0P2YZJT20:BTY080ZZZZ0P2VYZH209nOW`@0W9bL0P2GUiL2
092@T00308j>SP1kNg/0Ng]k0080LW9b0P1UIFD205mOG`80F5QH0P13@d<403/k>`80:RXZ0P0/;2`2
01LG5`804A4A0P11@D4204m?C`80JFUY00<0Lg=c07alO01lO7`00P2EUID20::RXP80c/k>0P3<c<a2
0=7AdAD0oooo000C0?ooo`@0dM7A0P3Cdm<A0=7Ad@80dm?C203AdM420=CDe080/;2`0P1HF5P204];
B`80HF5Q0P1KFe/205iNGP0305=CD`1IFET0FEUI0080Kfm_0P21PH4208J6QP80WIfM0P2^[Zh40:n_
[`80/k>c0P2e]KD20;Bd]080]KFe0P2i^KT20;bl_0<0^[Zj0P2k^k/20;Zj^P80_Kfm0P31`L440;Zj
^P80_;bl102k^k/20;Rh^080][Jf0P2h^;P70;Jf]P80^;Rh102f][H40:j^[P80[jn_0P2YZJT20:BT
Y080ZZZZ0P2VYZH209nOW`@0W9bL0P2GUiL2092@T00308j>SP1kNg/0Ng]k0080LW9b0P1UIFD205mO
G`80F5QH0P13@d<403/k>`80:RXZ0P0/;2`201LG5`804A4A0P11@D4204m?C`80JFUY00<0Lg=c07al
O01lO7`00P2EUID20::RXP80c/k>0P3<c<a20=7AdAD0oooo000C0?ooo`80dM7A0P3>c/h20<c<c0l0
dM7A0P3>c/h20<c<c0P0dM7A0P3EeMD20=gMg@80clo?0P26QXH204m?C`80GemO0P1@D5000`1OGel0
FUYJ05YJFP0206UYJ@80Ng]k0P2=SHd209FEU@80YZJV0P2b/[820;Fe]@80/k>c0P2j^[X20;Vi^@80
_kno0P2m_Kd20;Rh^080_;bl00<0^[Zj0;^k^`2k^k/00P2k^k/20;jn_P@0^k^k0P2j^[X20;bl_080
^k^k0P2o_kl20;jn_P80_kno0P2k^k/40;Jf]P80^[Zj00<0_kno0;Jf]P2f][H0102_[jl20;2`/0@0
[jn_0P2/[:`20:RXZ0@0Xj>S0P2RXZ820:6QX@80U9BD0P2?Shl2092@T00307emO@1nOWh0OWin0080
LW9b0P1RHV8205=CD`80DE5A0P1?Cdl2038b<P80=3@d0P0/;2`201dM7@805ADE0P0d=3@2030`<080
Jf][0P1UIFD00`1`L700NGUi07UiN@0208F5Q@80]KFe0P3AdM420=CDe080dm?C@03AdM4E0?ooo`00
4`3oool20=7Ad@80c/k>0P3<c<`?0=7Ad@80c/k>0P3<c<`80=7Ad@80eMGE0P3MgMd20<o?c`80QXJ6
0P1?Cdl205mOG`80D51@00<0GemO05YJFP1JFUX00P1YJFT207]kN`80SHf=0P2EUID20:JVYP80/[:b
0P2e]KD20;>c/`80^[Zj0P2i^KT20;no_`80_Kfm0P2h^;P20;bl_0030;Zj^P2k^k/0^k^k0080^k^k
0P2n_[h40;^k^`80^[Zj0P2l_;`20;^k^`80_kno0P2n_[h20;no_`80^k^k102f][H20;Zj^P030;no
_`2f][H0][Jf00@0[jn_0P2`/;040:n_[`80[:b/0P2XZ:P40:>SX`80XZ:R0P2QXJ4209BDU080Shn?
0P2@T9000`1mOGd0OWin07inOP02079bLP80HV9R0P1CDe<2055AD@80Cdm?0P0b<S8203@d=080;2`/
0P0M7Ad201DE5@80=3@d0P0`<30206][J`80IFEU00<0L71`07UiN@1iNGT00P25QHD20;Fe]@80dM7A
0P3De=@20=?Cdd00dM7A5@3oool001<0oooo9@3AdM420=CDe080Zj^[0P13@d<205YJFP80GUiN00<0
BTY:06IVIP1VIVH00P1SHf<207YjNP80RHV90P2IVIT20:BTY080YjNW0P2VYZH20:n_[`80];Bd0P2h
^;P20;:b/P@0/k>c0P2i^KT00`2n_[h0^k^k0;^k^`020;^k^`80][Jf102k^k/20;Rh^080][Jf0P2j
^[X20;Bd]080/[:b0P2e]KD20;Zj^P80][Jf0P2h^;P50:n_[`80/;2`1P2_[jl20:j^[P80[Jf]0P2R
XZ840:>SX`80XZ:R0P2LW9`209FEU@80VIVI0P2@T9000`28R8P0MWIf07IfMP0206UYJ@80H61P0P1E
EED204e=C@80De=C0P1BDU84020P80808b<S0P0e=CD203hn?P80PH61101UIFD00`1_Kfl0Shn?08n?
S`020:b/[080a/K60P3?cll20<[:bP80alO7@03AdM4E0?ooo`004`3ooolU0=7Ad@80e=CD0P2[Zj/2
04=3@`80FUYJ0P1NGUh00`1:BTX0IVIV06IVIP0206=SH`80NWYj0P29RHT209VIV@80Y:BT0P2WYjL2
0:JVYP80[jn_0P2d];@20;Rh^080/[:b102c/k<20;Vi^@030;jn_P2k^k/0^k^k0080^k^k0P2f][H4
0;^k^`80^;Rh0P2f][H20;Zj^P80];Bd0P2b/[820;Fe]@80^[Zj0P2f][H20;Rh^0D0[jn_0P2`/;06
0:n_[`80[Zj^0P2][Jd20::RXP@0Xj>S0P2RXZ8209bLW080UIFE0P2IVIT2092@T00308R8R01fMWH0
MWIf0080JFUY0P1PH60205EEE@80CDe=0P1CDe<2059BDP@0820P0P0S8b<203De=@80?Shn0P21PH44
06EUI@0306m_K`2?Shl0Shn?0080[:b/0P36a/H20<o?c`80b/[:0P37alM00=7AdAD0oooo000C0?oo
obD0dM7A0P3De=@20;fm_@80LG5a0P11@D4205YJFP<0IFEU0P1_Kfl207YjNP80R8R80P2DU9@20::R
XP80/;2`0P2a/K440:n_[`80/k>c0P2h^;P20;fm_@80^;Rh0P2g]kL00`2h^;P0^k^k0;^k^`020;Vi
^@P0_[jn102h^;P20;^k^`80_kno0P2f][H20;:b/P80_;bl0P2c/k<20;Jf]P030;2`/02_[jl0[jn_
0080[jn_0P2`/;040:n_[`@0ZZZZ0P2YZJT20:6QX@80XZ:R0P2LW9`209VIV@80SHf=0P29RHT208Z:
RP0307emO@1dM7@0M7Ad0080IfMW0P1PH60205]KF`80CTi>0P1:BTX20451@@80CDe=0P0Y:BT2030`
<080>3Ph0P1RHV8205UIF@80L71`0P1VIVH00`1fMWH0T92@092@T0020;bl_080b/[:0P39bLT20=7A
d@80fMWI@03AdM4E0?ooo`004`3ooolU0=7Ad@80e=CD0P2m_Kd2075aL@80@D510P1JFUX306EUI@80
Kfm_0P1jNWX208R8R080U9BD0P2RXZ820;2`/080/K6a102_[jl20;>c/`80^;Rh0P2m_Kd20;Rh^080
]kNg00<0^;Rh0;^k^`2k^k/00P2i^KT80;jn_P@0^;Rh0P2k^k/20;no_`80][Jf0P2b/[820;bl_080
/k>c0P2f][H00`2`/;00[jn_0:n_[`020:n_[`80/;2`102_[jl40:ZZZP80ZJVY0P2QXJ420::RXP80
W9bL0P2IVIT208f=S@80RHV90P2:RXX00`1mOGd0M7Ad07AdM00206MWI`80H61P0P1KFe/204i>CP80
BTY:0P11@D4204e=C@80:BTY0P0`<30203Ph>080HV9R0P1IFET2071`L080IVIV00<0MWIf092@T02@
T9000P2l_;`20<[:bP80bLW90P3AdM420=WIfD00dM7A5@3oool001<0oooo9@3AdM420=CDe080/;2`
0P27QhL204=3@`80DU9B00<0E5AD061PH01PH6000P1eMGD207]kN`80RXZ:0P2IVIT20:FUY@80XZ:R
0P2_[jl20;>c/`80[Zj^0P2g]kL20;2`/080];Bd0P2j^[X20;Bd]0030;Vi^@2j^[X0^[Zj0080^;Rh
102f][H20;>c/`80_;bl0P2j^[X20;Bd]080/[:b0P2_[jl20;Bd]080[jn_0P2/[:`20;Fe]@80[jn_
00<0[Zj^0;6a/@2a/K400P2c/k<20;6a/@@0];Bd0P2/[:`20:JVYP80Y:BT0P2QXJ4209jNWP80WIfM
0P2HV9P2096AT@80Ph>30P1oOgl00`1`L700K6a/06a/K002061PH080Cdm?0P1ADE4204e=C@80C4a<
1010@40203Hf=P80De=C0P12@T8205IFEP80Jf][0P1iNGT207EeM@0308b<S02=SHd0SHf=0080W9bL
0P3EeMD20=WIf@80dm?C0P3AdM420<o?c`80c<c<7`3AdM420<o?c`80c<c<6@3AdM4E0?ooo`004`3o
oolU0=7Ad@80e=CD0P2`/;0208N7Q`80@d=30P1BDU800`1DE5@0H61P061PH00207EeM@80Ng]k0P2:
RXX209VIV@80YJFU0P2RXZ820:n_[`80/k>c0P2^[Zh20;Ng]`80/;2`0P2d];@20;Zj^P80];Bd00<0
^KVi0;Zj^P2j^[X00P2h^;P40;Jf]P80/k>c0P2l_;`20;Zj^P80];Bd0P2b/[820:n_[`80];Bd0P2_
[jl20:b/[080]KFe0P2_[jl00`2^[Zh0/K6a0;6a/@020;>c/`80/K6a102d];@20:b/[080YZJV0P2T
Y:@20:6QX@80WYjN0P2MWId209RHV080TI6A0P23Ph<207moO`03071`L01/K6`0K6a/0080H61P0P1?
Cdl2055AD@80CDe=0P1<C4`40410@080=SHf0P1CDe<20492@P80EUIF0P1[Jf/207UiN@80MGEe00<0
S8b<08f=S@2=SHd00P2LW9`20=GEe@80fMWI0P3Cdm<20=7Ad@80clo?0P3<c<`O0=7Ad@80clo?0P3<
c<`I0=7AdAD0oooo000C0?ooobD0dM7A0P3EeMD20;:b/P80MWIf0P0j>SX204Q8B00305eMG@1=CDd0
CDe=0080IVIV0P1cLg<20861P@80SXj>0P2CTi<20:>SX`80ZJVY102^[Zh20:f][@80];Bd0P2e]KD2
0;Rh^080];Bd00<0[Jf]0;6a/@2a/K400P2f][H20;Zj^P80_;bl0P2k^k/20;>c/`80];Bd0P2_[jl2
0;6a/@80[Zj^0P2WYjL20:FUY@80YZJV0P2[Zj/20;:b/P030;>c/`2/[:`0[:b/00H0ZZZZ0P2WYjL2
09nOW`80X:2P0P2MWId209^KV`80U9BD0P2FUYH208V9R@80PH610P23Ph<207emO@03075aL@1[Jf/0
Jf][0080HF5Q0P1IFET204e=C@80BDU90P1@D50204=3@`80?clo0P19BDT2055AD@@0J6QX0P1YJFT2
07=cL`<0R8R80P2o_kl20=?Cd`80dM7A0P3>c/h20<[:bP80c<c<0P3EeMD20=WIfAD0dM7A0P3Cdm<8
0=7Ad@80eMGE0P3IfMTI0=7AdAD0oooo000C0?ooobD0dM7A0P3EeMD20;:b/P80MWIf0P0j>SX204Q8
B00305eMG@1=CDd0CDe=0080IVIV0P1cLg<20861P@80SXj>0P2CTi<20:>SX`80ZJVY102^[Zh20:f]
[@80];Bd0P2e]KD20;Rh^080];Bd00<0[Jf]0;6a/@2a/K400P2f][H20;Zj^P80_;bl0P2k^k/20;>c
/`80];Bd0P2_[jl20;6a/@80[Zj^0P2WYjL20:FUY@80YZJV0P2[Zj/20;:b/P030;>c/`2/[:`0[:b/
00H0ZZZZ0P2WYjL209nOW`80X:2P0P2MWId209^KV`80U9BD0P2FUYH208V9R@80PH610P23Ph<207em
O@03075aL@1[Jf/0Jf][0080HF5Q0P1IFET204e=C@80BDU90P1@D50204=3@`80?clo0P19BDT2055A
D@@0J6QX0P1YJFT207=cL`<0R8R80P2o_kl20=?Cd`80dM7A0P3>c/h20<[:bP80c<c<0P3EeMD20=WI
fAD0dM7A0P3Cdm<80=7Ad@80eMGE0P3IfMTI0=7AdAD0oooo000C0?ooobL0dM7A0P34a<@20:FUY@80
Lg=c0P0g=cL00`1@D500HF5Q065QH@0205MGE`80LG5a0P1kNg/2092@T0@0XJ6Q0P2KVi/20:NWY`80
Z:RX0P2[Zj/20;Fe]@80[Zj^0P2][Jd20;:b/P030;Bd]02`/;00/;2`00@0/k>c0P2d];@20;:b/P80
/k>c0P2f][H20;Bd]080Zj^[0P2RXZ820:6QX@80X:2P0P2UYJD20:VYZ@80YjNW00<0Xj>S0:6QX@2Q
XJ400P2QXJ4209nOW`80V9RH0P2RXZ8209nOW`80VYZJ0P2MWId209>CT`80U9BD0P2ATI4208Z:RP80
Ogmo0P1gMgL2075aL@0306i^KP1`L700L71`0080H61P0P1?Cdl205]KF`80DU9B0P18B4P2065QH@80
De=C0P1BDU8206][J`80Kfm_101cLg<2092@T080W9bL00<0X:2P09fMW@2MWId00P3<c<`40=7Ad@80
eMGE0P3IfMTG0=7Ad@80c/k>0P3<c<`U0=7AdAD0oooo000C0?ooobL0dM7A0P34a<@20:FUY@80Lg=c
0P0g=cL00`1@D500HF5Q065QH@0205MGE`80LG5a0P1kNg/2092@T0@0XJ6Q0P2KVi/20:NWY`80Z:RX
0P2[Zj/20;Fe]@80[Zj^0P2][Jd20;:b/P030;Bd]02`/;00/;2`00@0/k>c0P2d];@20;:b/P80/k>c
0P2f][H20;Bd]080Zj^[0P2RXZ820:6QX@80X:2P0P2UYJD20:VYZ@80YjNW00<0Xj>S0:6QX@2QXJ40
0P2QXJ4209nOW`80V9RH0P2RXZ8209nOW`80VYZJ0P2MWId209>CT`80U9BD0P2ATI4208Z:RP80Ogmo
0P1gMgL2075aL@0306i^KP1`L700L71`0080H61P0P1?Cdl205]KF`80DU9B0P18B4P2065QH@80De=C
0P1BDU8206][J`80Kfm_101cLg<2092@T080W9bL00<0X:2P09fMW@2MWId00P3<c<`40=7Ad@80eMGE
0P3IfMTG0=7Ad@80c/k>0P3<c<`U0=7AdAD0oooo000C0?ooobT0dM7A0P2VYZH2069RHP80E5AD00<0
CTi>05aLG01LG5`00P1RHV8206EUI@80KVi^0P1eMGD209:BTP80Xj>S0P2b/[8209nOW`80XZ:R0P2Q
XJ420:BTY080/;2`102c/k<00`2b/[80[:b/0:b/[0020:f][@80Zj^[0P2a/K420:b/[080W9bL0P2O
Wil209fMW@80WinO0P2FUYH209ZJVP80Shn?0P2EUID208j>SP80UiNG00<0QhN709ZJVP2JVYX00P28
R8P209FEU@80R8R80P27QhL208j>SP80QhN70P29RHT208F5Q@80OWin0P1mOGd208V9R@80OWin0P1a
LG4206i^KP0305eMG@1PH600H61P0080GEeM101LG5`206IVIP80Cdm?0P10@402061PH080LG5a0P1V
IVH206ATI080L71`0P1oOgl207inOP80XJ6Q00<0^[Zj0<[:bP3:b/X0303AdM420=?Cdal0dM7A0P3?
cll20<c<c1T0dM7A5@3oool001<0oooo:@3AdM420:JVYP80HV9R0P1DE5@00`1>CTh0G5aL05aLG002
069RHP80IFEU0P1^KVh207EeM@80TY:B0P2SXj<20;:b/P80WinO0P2RXZ820:6QX@80Y:BT0P2`/;04
0;>c/`030;:b/P2/[:`0[:b/0080[Jf]0P2[Zj/20;6a/@80[:b/0P2LW9`209nOW`80WIfM0P2OWil2
09JFUP80VYZJ0P2?Shl209FEU@80SXj>0P2GUiL00`27QhL0VYZJ09ZJVP0208R8R080UIFE0P28R8P2
08N7Q`80SXj>0P27QhL208V9R@80QHF50P1nOWh207emO@80RHV90P1nOWh2075aL@80KVi^00<0GEeM
061PH01PH6000P1MGEd405aLG080IVIV0P1?Cdl20410@080H61P0P1aLG4206IVIP80I6AT0P1`L702
07moO`80OWin0P2QXJ400`2j^[X0b/[:0<[:bP0<0=7Ad@80dm?C7`3AdM420<o?c`80c<c<6@3AdM4E
0?ooo`004`3oool[0=7Ad@80ZJVY0P1<C4`00`0o?cl0DE5A055AD@0205EEE@80Kfm_0P1fMWH206][
J`80Ph>30P24Q8@2092@T080VYZJ0P2LW9`20:RXZ080[Zj^0P2][Jd20:NWY`80Zj^[00<0ZZZZ0:VY
Z@2YZJT00P2MWId209^KV`80V9RH102TY:@209JFUP80Ti>C0P2HV9P208j>SP80RHV90P26QXH408B4
Q080P82000<0S8b<07emO@1mOGd00P1iNGT207AdM080Ph>30P1]KFd207inOP80MWIf101jNWX207Ui
N@80MWIf0P1ZJVX407moO`80NGUi00<0Lg=c071`L01`L7000P1XJ6P205eMG@80E5AD0P1VIVH206UY
J@80CTi>0P16ATH205mOG`80MGEe0P1nOWh207AdM080OWin0P2FUYH20:NWY`0309bLW03AdM40dM7A
00@0dM7A0P3Cdm<40=7Ad@80c/k>0P3<c<`I0=7Ad@80dm?C103AdM420=GEe@80fMWI6@3AdM4E0?oo
o`004`3oool[0=7Ad@80ZJVY0P1<C4`00`0o?cl0DE5A055AD@0205EEE@80Kfm_0P1fMWH206][J`80
Ph>30P24Q8@2092@T080VYZJ0P2LW9`20:RXZ080[Zj^0P2][Jd20:NWY`80Zj^[00<0ZZZZ0:VYZ@2Y
ZJT00P2MWId209^KV`80V9RH102TY:@209JFUP80Ti>C0P2HV9P208j>SP80RHV90P26QXH408B4Q080
P82000<0S8b<07emO@1mOGd00P1iNGT207AdM080Ph>30P1]KFd207inOP80MWIf101jNWX207UiN@80
MWIf0P1ZJVX407moO`80NGUi00<0Lg=c071`L01`L7000P1XJ6P205eMG@80E5AD0P1VIVH206UYJ@80
CTi>0P16ATH205mOG`80MGEe0P1nOWh207AdM080OWin0P2FUYH20:NWY`0309bLW03AdM40dM7A00@0
dM7A0P3Cdm<40=7Ad@80c/k>0P3<c<`I0=7Ad@80dm?C103AdM420=GEe@80fMWI6@3AdM4E0?ooo`00
4`3oool@0=7Ad@030=?Cd`3AdM40dM7A0080dm?C603AdM420<W9b@0308b<S01`L700L71`0080GemO
0P1IFET2071`L080IfMW0P1KFe/207emO@80Vi^K0P2ZZZX20;Vi^@80]kNg0P2_[jl20:VYZ@80Z:RX
0P2NWYh00`2KVi/0UYJF09JFUP0209>CT`80Vi^K0P2IVIT209>CT`80UIFE0P2JVYX208j>SP80Q8B4
0P22PX8207moO`80MGEe0P26QXH207EeM@80Ng]k00<0K6a/07IfMP1fMWH00P1gMgL2065QH@80IfMW
0P1nOWh206IVIP80MWIf0P1VIVH206i^KP80LW9b0P1`L70205aLG080HF5Q101YJFT00`1UIFD0JVYZ
06YZJP0206][J`80H61P0P1RHV82055AD@80G5aL0P1OGel206UYJ@@0L71`0P1ZJVX208V9R@80Xj>S
0P2HV9P209>CT`D0dM7A0P3<c<`20<O7aal0dM7A0P3>c/h20<c<c240dM7A5@3oool001<0oooo403A
dM400`3Cdm<0dM7A0=7Ad@020=?CdaP0dM7A0P39bLT00`2<S8`0L71`071`L00205mOG`80FEUI0P1`
L70206MWI`80Fe]K0P1mOGd209^KV`80ZZZZ0P2i^KT20;Ng]`80[jn_0P2YZJT20:RXZ080WYjN00<0
Vi^K09JFUP2FUYH00P2CTi<209^KV`80VIVI0P2CTi<209FEU@80VYZJ0P2>SXh208B4Q080PX:20P1o
Ogl207EeM@80QXJ60P1eMGD207]kN`0306a/K01fMWH0MWIf0080MgMg0P1QHF4206MWI`80OWin0P1V
IVH207IfMP80IVIV0P1^KVh2079bLP80L71`0P1LG5`2065QH@@0JFUY00<0IFEU06YZJP1ZJVX00P1[
Jf/2061PH080HV9R0P1ADE4205aLG080GemO0P1YJFT4071`L080JVYZ0P29RHT20:>SX`80V9RH0P2C
Ti<50=7Ad@80c<c<0P37alLO0=7Ad@80c/k>0P3<c<`Q0=7AdAD0oooo000C0?ooo`H0dM7A0P3Cdm<6
0=7Ad@80c/k>00<0c<c<0<k>cP3>c/h00P3<c<`J0=7Ad@0309>CT`1@D500D51@0080MWIf0P1YJFT2
06a/K080Rh^;0P2IVIT209>CT`80V9RH0P2RXZ8209FEU@80WinO0P2WYjL20:BTY080X:2P1@2GUiL2
08b<S080Rh^;0P2?Shl209NGU`80R8R80P2<S8`208J6QP80QhN70P1dM7@207EeM@80MWIf0P1YJFT2
08N7Q`80MGEe00<0QhN706e]K@1]KFd00P1hN7P207UiN@80Jf][0P1eMGD206YZJP80MgMg0P1eMGD2
07IfMP80KVi^0P1`L70206e]K@80EeMG0P1QHF4205eMG@03065QH@1VIVH0IVIV0080GemO0P1RHV82
05aLG080GEeM0P1RHV8206MWI`80I6AT0P1XJ6P207YjNP80Shn?0P2TY:@208j>SP80]kNg0P2^[Zh5
0=7Ad@80eMGE0P3IfMU40=7AdAD0oooo000C0?ooo`H0dM7A0P3Cdm<60=7Ad@80c/k>00<0c<c<0<k>
cP3>c/h00P3<c<`J0=7Ad@0309>CT`1@D500D51@0080MWIf0P1YJFT206a/K080Rh^;0P2IVIT209>C
T`80V9RH0P2RXZ8209FEU@80WinO0P2WYjL20:BTY080X:2P1@2GUiL208b<S080Rh^;0P2?Shl209NG
U`80R8R80P2<S8`208J6QP80QhN70P1dM7@207EeM@80MWIf0P1YJFT208N7Q`80MGEe00<0QhN706e]
K@1]KFd00P1hN7P207UiN@80Jf][0P1eMGD206YZJP80MgMg0P1eMGD207IfMP80KVi^0P1`L70206e]
K@80EeMG0P1QHF4205eMG@03065QH@1VIVH0IVIV0080GemO0P1RHV8205aLG080GEeM0P1RHV8206MW
I`80I6AT0P1XJ6P207YjNP80Shn?0P2TY:@208j>SP80]kNg0P2^[Zh50=7Ad@80eMGE0P3IfMU40=7A
dAD0oooo000C0?ooo`@0dM7A0P3>c/h20<c<c2L0dM7A00<0eMGE08f=S@2=SHd00P14A4@206][J`80
IfMW0P1]KFd207AdM080Ng]k0P1mOGd208^;R`80WIfM0P2NWYh209FEU@@0VYZJ0P2GUiL00`2:RXX0
Shn?08n?S`0208B4Q080P8200P1oOgl20861P@80QhN70P1lO7`207emO@80OWin0P1bLW8207IfMP80
Jf][0P1OGel205EEE@80Ph>300<0IFEU08B4Q024Q8@00P1XJ6P4071`L080JFUY0P1iNGT206ATI080
CTi>0P1QHF4207UiN@80I6AT0P1NGUh205aLG080EeMG0P1@D5000`1=CDd0DE5A055AD@0205QHF080
C4a<0P1GEeL205IFEP80F5QH0P1DE5@207AdM080QhN70P1nOWh20;^k^`80RHV90P2KVi/207UiN@80
c<c<3@3AdM420=?Cdch0dM7A5@3oool001<0oooo103AdM420<k>cP80c<c<9`3AdM400`3EeMD0SHf=
08f=S@0204A4A080Jf][0P1WIfL206e]K@80M7Ad0P1kNg/207emO@80Rh^;0P2MWId209jNWP80UIFE
102JVYX209NGU`0308Z:RP2?Shl0Shn?0080Q8B40P20P80207moO`80PH610P27QhL207alO080OGem
0P1nOWh2079bLP80MWIf0P1[Jf/205mOG`80EEEE0P23Ph<00`1UIFD0Q8B408B4Q00206QXJ0@0L71`
0P1YJFT207UiN@80I6AT0P1>CTh2065QH@80NGUi0P1TI6@205iNGP80G5aL0P1GEeL2051@D00304e=
C@1ADE40DE5A0080F5QH0P1<C4`205MGE`80EUIF0P1HF5P205ADE080M7Ad0P27QhL207inOP80^k^k
0P29RHT209^KV`80NGUi0P3<c<`=0=7Ad@80dm?C?P3AdM4E0?ooo`004`3oool`0=7Ad@80eMGE0P2W
YjL2079bLP80I6AT0P1oOgl208F5Q@80UYJF0P2WYjL20:JVYP80X:2P0P2QXJ4209BDU080R8R80P2=
SHd208^;R`0308f=S@28R8P0R8R80080R8R80P22PX8208>3P`80NWYj0P1iNGT208B4Q080MGEe0P1S
Hf<207IfMP80GUiN0P1[Jf/207UiN@80BDU90P1CDe<00`1`L700FUYJ05YJFP02075aL@80L71`0P1U
IFD206=SH`@0EEEE0P1NGUh204M7A`80EUIF0P1DE5@205EEE@80FUYJ0P1GEeL205QHF00305MGE`1R
HV80HV9R0080I6AT0P1LG5`2059BDP80GUiN0P1aLG4209VIV@80P8200P2?Shl208N7Q`80LW9b0P1k
Ng/208j>SP80/K6a0P3IfMT50=7Ad@80dm?C1P3AdM420<c<c1T0dM7A0P3Cdm<20=7Ad@80clo?0P3<
c<`M0=7AdAD0oooo000C0?oooc00dM7A0P3EeMD20:NWY`80LW9b0P1TI6@207moO`80QHF50P2FUYH2
0:NWY`80YZJV0P2PX:020:6QX@80U9BD0P28R8P208f=S@80Rh^;00<0SHf=08R8R028R8P00P28R8P2
08:2PP80Ph>30P1jNWX207UiN@80Q8B40P1eMGD206=SH`80MWIf0P1NGUh206][J`80NGUi0P19BDT2
05=CD`03071`L01JFUX0FUYJ0080LG5a0P1`L70206EUI@80Hf=S101EEED205iNGP80AdM70P1FEUH2
05ADE080EEEE0P1JFUX205MGE`80F5QH00<0EeMG069RHP1RHV800P1TI6@205aLG080DU9B0P1NGUh2
075aL@80VIVI0P20P80208n?S`80QhN70P1bLW8207]kN`80SXj>0P2a/K420=WIf@D0dM7A0P3Cdm<6
0=7Ad@80c<c<6@3AdM420=?Cd`80dM7A0P3?cll20<c<c1d0dM7A5@3oool001<0oooo<P3AdM420:BT
Y080EEEE0P1fMWH2069RHP80GUiN0P1[Jf/208F5Q@@0XJ6Q0P2MWId209bLW080PH610P2:RXX208:2
PP0308N7Q`25QHD0QHF50080Ogmo0P1eMGD207emO@80O7al0P1fMWH207QhN080M7Ad0P1`L70205]K
F`80Ph>30P1WIfL206ATI080OGem0P1@D5000`1PH600IfMW06MWI`0205MGE`80GemO0P1IFET2051@
D080De=C0P1;Bd/204U9B@80BTY:0P1<C4`205UIF@80DE5A0P1CDe<205MGE`80DU9B00<0E5AD05IF
EP1FEUH00P1MGEd206i^KP80NGUi102:RXX20820P080Y:BT0P2DU9@207MgM`80LG5a0P1jNWX206m_
K`80e=CD0P3Cdm<50=7Ad@80c<c<103AdM420<c<c080clo?0P3<c<`60=7Ad@80clo?0P3<c<`;0=7A
d@80c/k>0P3<c<`20=7Ad@80eMGE0P3IfMTM0=7AdAD0oooo000C0?oooc80dM7A0P2TY:@205EEE@80
MWIf0P1RHV8205iNGP80Jf][0P25QHD40:6QX@80WIfM0P2LW9`20861P@80RXZ:0P22PX800`27QhL0
QHF508F5Q@0207moO`80MGEe0P1mOGd207alO080MWIf0P1hN7P207AdM080L71`0P1KFe/208>3P`80
IfMW0P1TI6@207emO@80D51@00<0H61P06MWI`1WIfL00P1GEeL205mOG`80FEUI0P1@D50205=CD`80
Bd];0P19BDT204Y:BP80C4a<0P1IFET2055AD@80De=C0P1GEeL2059BDP0305ADE01FEUH0EUIF0080
GEeM0P1^KVh207UiN@@0RXZ:0P20P8020:BTY080U9BD0P1gMgL2075aL@80NWYj0P1_Kfl20=CDe080
dm?C1@3AdM420<c<c0@0dM7A0P3<c<`20<o?c`80c<c<1P3AdM420<o?c`80c<c<2`3AdM420<k>cP80
c<c<0P3AdM420=GEe@80fMWI7@3AdM4E0?ooo`004`3ooolb0=7Ad@80eMGE0P21PH4203Ph>080GEeM
0P2KVi/2071`L080MgMg0P28R8P20:JVYP80V9RH0P2?Shl207MgM`80N7Qh0P1cLg<00`1kNg/0RHV9
08V9R@0207emO@80L71`0P1eMGD207UiN@80L71`0P1iNGT207EeM@80MgMg0P1NGUh206EUI@80Hf=S
0P1RHV8205IFEP80FEUI00<0IVIV04i>CP1>CTh00P1IFET205IFEP80EEEE0P1@D50204U9B@80C4a<
0P13@d<20451@@80ATI60P14A4@204Y:BP80E5AD0P1HF5P204a<C00305MGE`1/K6`0K6a/0080LW9b
0P1XJ6P406IVIP80S8b<0P27QhL206EUI@80OGem0P1_Kfl20::RXP80Lg=c0P2j^[X20<G5a@80clo?
00<0dM7A0<k>cP3>c/h00P3<c<`20=7Ad@80c/k>0P3<c<`20=7Ad@80eMGE0P3IfMT60=7Ad@80eMGE
0P3IfMTb0=7AdAD0oooo000C0?oooc80dM7A0P3EeMD20861P@80>3Ph0P1MGEd209^KV`80L71`0P1g
MgL208R8R080YZJV0P2HV9P208n?S`80MgMg0P1hN7P207=cL`0307]kN`29RHT0RHV90080OGem0P1`
L70207EeM@80NGUi0P1`L70207UiN@80MGEe0P1gMgL205iNGP80IFEU0P1SHf<2069RHP80EUIF0P1I
FET00`1VIVH0CTi>04i>CP0205UIF@80EUIF0P1EEED2051@D080BDU90P1<C4`204=3@`80@D510P16
ATH204A4A080BTY:0P1DE5@205QHF080C4a<00<0EeMG06a/K01/K6`00P1bLW8206QXJ0@0IVIV0P2<
S8`208N7Q`80IFEU0P1mOGd206m_K`80XZ:R0P1cLg<20;Zj^P80aLG50P3?cll00`3AdM40c/k>0<k>
cP020<c<c080dM7A0P3>c/h20<c<c080dM7A0P3EeMD20=WIf@H0dM7A0P3EeMD20=WIfC80dM7A5@3o
ool001<0oooo=03AdM420=?Cd`80RXZ:0P0j>SX204M7A`@0T92@0P2>SXh209FEU@80XJ6Q0P2HV9P2
07YjNP80KVi^0P25QHD00`1YJFT0N7Qh07QhN00207EeM@80IfMW0P1TI6@207emO@80KVi^0P1RHV82
07AdM080JVYZ0P1NGUh206=SH`80KVi^0P1QHF4205UIF@80=CDe00<0E5AD065QH@1QHF400P1IFET2
04U9B@80DU9B0P12@T82059BDP80@D510P0m?Cd203@d=080>CTi0P0h>3P203Ti>@80Bd];0P1KFe/2
06UYJ@0305EEE@1OGel0GemO0080PH610P2>SXh408V9R@80W9bL0P2:RXX2071`L080JVYZ0P2=SHd2
071`L080b<S80P3MgMd20=KFeP80c<c<0`3AdM420=?Cd`80clo?0P3<c<`F0=7Ad@030=?Cd`3AdM40
dM7A00h0dM7A0P3?cll20<c<c1T0dM7A5@3oool001<0oooo303AdM420=?Cdb@0dM7A0P3>c/h20<c<
c080eMGE0P2PX:0204E5A@80CDe=0P1[Jf/208R8R080UIFE0P2YZJT20:BTY080NGUi0P1SHf<207=c
L`0308:2PP1/K6`0K6a/0080OWin0P23Ph<206UYJ@80IFEU0P1hN7P206MWI`80H61P0P1_Kfl206i^
KP80GUiN0P1UIFD207=cL`80HV9R0P1?Cdl00`0n?Sh0A4A404A4A00205ADE080IfMW0P1=CDd204Y:
BP80B4Q8101:BTX203Ti>@80?3`l0P0o?cl203`l?080?Shn0P1=CDd206ATI00307emO@1kNg/0Ng]k
0080Jf][0P2BTY8208V9R@80FUYJ0P1/K6`207IfMP80Ng]k0P1[Jf/205YJFP80R8R8203AdM400`3?
cll0bLW90<W9b@020<g=c@80f=SH0P3IfMT60=7Ad@80clo?0P3<c<`:0=7Ad@80c/k>00<0c<c<0<o?
c`3?cll00P3<c<`<0=7Ad@80eMGE0P3IfMTI0=7AdAD0oooo000C0?ooo``0dM7A0P3Cdm<T0=7Ad@80
c/k>0P3<c<`20=GEe@80X:2P0P15ADD204e=C@80Jf][0P28R8P209FEU@80ZJVY0P2TY:@207UiN@80
Hf=S0P1cLg<00`22PX80K6a/06a/K00207inOP80Ph>30P1YJFT206EUI@80N7Qh0P1WIfL2061PH080
Kfm_0P1^KVh205iNGP80IFEU0P1cLg<2069RHP80Cdm?00<0?Shn04A4A014A4@00P1DE5@206MWI`80
CDe=0P1:BTX204Q8B0@0BTY:0P0i>CT203`l?080?clo0P0l?3`203hn?P80CDe=0P1TI6@00`1mOGd0
Ng]k07]kN`0206][J`80TY:B0P29RHT205YJFP80K6a/0P1fMWH207]kN`80Jf][0P1JFUX208R8R0P0
dM7A00<0clo?0<W9b@39bLT00P3=cLd20=SHf080fMWI1P3AdM420<o?c`80c<c<2P3AdM420<k>cP03
0<c<c03?cll0clo?0080c<c<303AdM420=GEe@80fMWI6@3AdM4E0?ooo`004`3oool:0=7Ad@80c/k>
0P3<c<`Z0=7Ad@80_;bl0P1bLW8204E5A@80E5AD0P1PH60207QhN080W9bL0P2PX:0209bLW080EUIF
0P1XJ6P307YjNP80HF5Q0P1XJ6P2065QH@80FUYJ0P1MGEd206UYJ@@0Hf=S0P1YJFT206IVIP80HF5Q
0P1ZJVX206m_K`80HF5Q00<0GemO04i>CP1>CTh00P1ADE4204I6AP80De=C0P1IFET2059BDP80De=C
0P1HF5P205mOG`80De=C0P1BDU8205QHF080GUiN0P1/K6`2075aL@0307QhN02JVYX0VYZJ0080VYZJ
0P27QhL406UYJ@80EEEE0P1ZJVX207UiN@80OGem0P1`L7020<o?c`80b/[:0P3<c<`20=7Ad@80d];B
00<0dM7A0=[JfP3Jf]X00P39bLT20<g=c@80dm?C0P3?cll20<c<c080dM7A0P3EeMD20=WIf@d0dM7A
0P3EeMD20=WIf@H0dM7A0P3?cll20<c<c1l0dM7A5@3oool001<0oooo2P3AdM420<k>cP80c<c<:P3A
dM420;bl_080LW9b0P15ADD205ADE080H61P0P1hN7P209bLW080X:2P0P2LW9`205IFEP80J6QX0`1j
NWX2065QH@80J6QX0P1QHF4205YJFP80GEeM0P1YJFT406=SH`80JFUY0P1VIVH2065QH@80JVYZ0P1_
Kfl2065QH@0305mOG`1>CTh0CTi>0080DE5A0P16ATH205=CD`80FEUI0P1BDU8205=CD`80F5QH0P1O
Gel205=CD`80DU9B0P1HF5P205iNGP80K6a/0P1aLG400`1hN7P0VYZJ09ZJVP0209ZJVP80QhN7101Y
JFT205EEE@80JVYZ0P1iNGT207emO@80L71`0P3?cll20<[:bP80c<c<0P3AdM420=;BdP030=7Ad@3J
f]X0f][J0080bLW90P3=cLd20=?Cd`80clo?0P3<c<`20=7Ad@80eMGE0P3IfMT=0=7Ad@80eMGE0P3I
fMT60=7Ad@80clo?0P3<c<`O0=7AdAD0oooo000C0?oooc80dM7A0P3?cll20<c<c0@0dM7A0P2c/k<2
079bLP80FUYJ0P1RHV8205]KF`80IfMW0P1jNWX2092@T080QXJ60P1>CTh00`1TI6@0NWYj07YjNP02
079bLP80GemO0P1SHf<204Q8B080E5AD0P1EEED2065QH@80GUiN0P1VIVH205MGE`80J6QX0P1PH602
07UiN@80Jf][00<0JVYZ05eMG@1MGEd00P1CDe<205eMG@80DE5A0P1OGel206EUI@80I6AT0P1JFUX2
05eMG@80IFEU0P1bLW8207UiN@80PX:20P1dM7@208j>SP0309RHV01gMgL0MgMg0080I6AT0P1aLG42
07MgM`80Fe]K0P1]KFd20820P080DU9B0P1OGel20=WIf@80eMGE0P3Lg=`20=?Cd`80bLW90P3AdM40
0`3EeMD0c<c<0<c<c0020=WIf@80c/k>0P3<c<`20=GEe@80fMWI7@3AdM420=GEe@80fMWI7`3AdM4E
0?ooo`004`3ooolb0=7Ad@80clo?0P3<c<`40=7Ad@80/k>c0P1bLW8205YJFP80HV9R0P1KFe/206MW
I`80NWYj0P2@T90208J6QP80CTi>00<0I6AT07YjNP1jNWX00P1bLW8205mOG`80Hf=S0P18B4P205AD
E080EEEE0P1QHF4205iNGP80IVIV0P1GEeL206QXJ080H61P0P1iNGT206][J`0306YZJP1MGEd0GEeM
0080De=C0P1MGEd2055AD@80GemO0P1UIFD206ATI080FUYJ0P1MGEd206EUI@80LW9b0P1iNGT208:2
PP80M7Ad0P2>SXh00`2HV9P0MgMg07MgM`0206ATI080LG5a0P1gMgL205]KF`80KFe]0P20P802059B
DP80GemO0P3IfMT20=GEe@80g=cL0P3Cdm<20<W9b@80dM7A00<0eMGE0<c<c03<c<`00P3IfMT20<k>
cP80c<c<0P3EeMD20=WIfAd0dM7A0P3EeMD20=WIfAl0dM7A5@3oool001<0oooo<P3AdM420=KFeP80
fm_K103AdM420=?Cd`80ZJVY0P1PH602051@D080KFe]0P1dM7@207UiN@80PX:20P2ATI4207YjNP03
055AD@1]KFd0KFe]0080JFUY0P1hN7P206ATI080Jf][0P1?Cdl204i>CP80EUIF0P1GEeL206UYJ@80
FEUI0P1UIFD206e]K@80NGUi0P1fMWH00`1_Kfl0Hf=S06=SH`0205iNGP80BDU90P12@T8204I6AP80
FEUI0P1QHF4206UYJ@80GemO0P1ZJVX207inOP80RHV90P24Q8@208Z:RP80JVYZ00<0I6AT061PH01P
H6000P1DE5@204i>CP80FEUI0P1[Jf/207=cL`80IFEU0P1gMgL20=WIf@80clo?0P3<c<`20=GEe@80
gMgM0P3IfMT20=7Ad@030=GEe@3IfMT0fMWI0080dM7A0P3Cdm<20=7Ad@80clo?0P3:b/X20<c<c3h0
dM7A5@3oool001<0oooo<P3AdM420=KFeP80fm_K103AdM420=?Cd`80ZJVY0P1PH602051@D080KFe]
0P1dM7@207UiN@80PX:20P2ATI4207YjNP03055AD@1]KFd0KFe]0080JFUY0P1hN7P206ATI080Jf][
0P1?Cdl204i>CP80EUIF0P1GEeL206UYJ@80FEUI0P1UIFD206e]K@80NGUi0P1fMWH00`1_Kfl0Hf=S
06=SH`0205iNGP80BDU90P12@T8204I6AP80FEUI0P1QHF4206UYJ@80GemO0P1ZJVX207inOP80RHV9
0P24Q8@208Z:RP80JVYZ00<0I6AT061PH01PH6000P1DE5@204i>CP80FEUI0P1[Jf/207=cL`80IFEU
0P1gMgL20=WIf@80clo?0P3<c<`20=GEe@80gMgM0P3IfMT20=7Ad@030=GEe@3IfMT0fMWI0080dM7A
0P3Cdm<20=7Ad@80clo?0P3:b/X20<c<c3h0dM7A5@3oool001<0oooo<P3AdM420<k>cP80c<c<0P3A
dM420<k>cP80b/[:0P3<c<`20:n_[`80BTY:0P0m?Cd206YZJP80Kfm_0P2EUID209VIV@80T92@00<0
O7al05mOG`1OGel00P1]KFd2065QH@80LG5a0P1WIfL206m_K`80DE5A0P12@T8204A4A080EUIF0P1@
D50206ATI080LG5a0P1`L70207emO@0308Z:RP37alL0alO70080Zj^[0P2BTY8208V9R@80SXj>0P21
PH4208J6QP80UiNG0P2a/K420:f][@80VYZJ0P29RHT2071`L080Hf=S0`1JFUX205eMG@80F5QH0P1Z
JVX207EeM@80Ph>30P1BDU8206ATI080fMWI0P3AdM420=SHf080fMWI0P3AdM420=CDe080dm?C1`3A
dM420<c<c080dM7A0P3EeMD20=gMg@80fMWI0P3AdM420=?CdcX0dM7A5@3oool001<0oooo<P3AdM42
0<k>cP80c<c<0P3AdM420<k>cP80b/[:0P3<c<`20:n_[`80BTY:0P0m?Cd206YZJP80Kfm_0P2EUID2
09VIV@80T92@00<0O7al05mOG`1OGel00P1]KFd2065QH@80LG5a0P1WIfL206m_K`80DE5A0P12@T82
04A4A080EUIF0P1@D50206ATI080LG5a0P1`L70207emO@0308Z:RP37alL0alO70080Zj^[0P2BTY82
08V9R@80SXj>0P21PH4208J6QP80UiNG0P2a/K420:f][@80VYZJ0P29RHT2071`L080Hf=S0`1JFUX2
05eMG@80F5QH0P1ZJVX207EeM@80Ph>30P1BDU8206ATI080fMWI0P3AdM420=SHf080fMWI0P3AdM42
0=CDe080dm?C1`3AdM420<c<c080dM7A0P3EeMD20=gMg@80fMWI0P3AdM420=?CdcX0dM7A5@3oool0
01<0oooo>P3AdM440=CDe080dM7A0P3=cLd208N7Q`80BTY:0P1JFUX206a/K080Rh^;0P2^[Zh00`2O
Wil0OGem07emO@0406m_K`80IVIV0P1UIFD205eMG@80OWin0P1lO7`202d];@8000000P0410@2010@
4080ADE50P1_Kfl207inOP03079bLP1eMGD0MGEe00@0XJ6Q0P2TY:@40:f][@80`/;20P2EUID208B4
Q080Ph>30P1nOWh206MWI`80J6QX0P1KFe/206IVIP0304e=C@1EEED0EEEE0080JFUY0P1dM7@207=c
L`809BDU0P1eMGD20<o?c`80cLg=0P3AdM420<c<c080dM7A0P3>c/h20<[:bP80clo?0`3AdM420<k>
cP80cLg=0P3Cdm<20=7Ad@80clo?0P3<c<`20=7Ad@@0clo?103AdM420=?Cd`80clo?0P3<c<``0=7A
dAD0oooo000C0?ooocX0dM7A103De=@20=7Ad@80cLg=0P27QhL204Y:BP80FUYJ0P1/K6`208^;R`80
[Zj^00<0WinO07emO@1mOGd0101_Kfl206IVIP80IFEU0P1MGEd207inOP80O7al0P0];Bd200000080
10@40P0@410204E5A@80Kfm_0P1nOWh00`1bLW80MGEe07EeM@040:6QX@80Y:BT102][Jd20<;2`P80
UIFE0P24Q8@208>3P`80OWin0P1WIfL206QXJ080Fe]K0P1VIVH00`1=CDd0EEEE05EEE@0206UYJ@80
M7Ad0P1cLg<202DU9@80MGEe0P3?cll20<g=c@80dM7A0P3<c<`20=7Ad@80c/k>0P3:b/X20<o?c`<0
dM7A0P3>c/h20<g=c@80dm?C0P3AdM420<o?c`80c<c<0P3AdM440<o?c`@0dM7A0P3Cdm<20<o?c`80
c<c<<03AdM4E0?ooo`004`3ooolW0=7Ad@80clo?0P3<c<`?0=7Ad@@0e=CD103AdM420=GEe@80UYJF
0P0O7al204A4A080NGUi0P2BTY800`2ZZZX0/;2`0;2`/00408j>SP80TI6A0P2FUYH20:ZZZP80U9BD
0P2CTi<20;Bd]080bl_;0P3IfMT20<S8b080_Kfm0P2^[Zh20:>SX`030:2PX02^[Zh0[Zj^0080YZJV
0P2[Zj/20<30`080YjNW0P2BTY8208:2PP@0NGUi0P1UIFD206i^KP80KFe]0P1OGel205QHF080DE5A
00<0KFe]07EeM@1eMGD00P1jNWX204e=C@80Hf=S0P3IfMT20=?Cd`80e]KF0P3IfMT20<c<c0H0dM7A
0P3>c/h20<c<c080dM7A00<0dm?C0=7Ad@3AdM400P3>c/h20<c<c080dM7A0P3EeMD20=WIf@80dM7A
0P3>c/h20<c<c080dM7A0P3>c/h20<c<c080eMGE0P3IfMT=0=7Ad@80clo?0P3<c<`20=7Ad@80clo?
0P3<c<`20=7Ad@80dm?C5@3AdM4E0?ooo`004`3ooolW0=7Ad@80clo?0P3<c<`?0=7Ad@@0e=CD103A
dM420=GEe@80UYJF0P0O7al204A4A080NGUi0P2BTY800`2ZZZX0/;2`0;2`/00408j>SP80TI6A0P2F
UYH20:ZZZP80U9BD0P2CTi<20;Bd]080bl_;0P3IfMT20<S8b080_Kfm0P2^[Zh20:>SX`030:2PX02^
[Zh0[Zj^0080YZJV0P2[Zj/20<30`080YjNW0P2BTY8208:2PP@0NGUi0P1UIFD206i^KP80KFe]0P1O
Gel205QHF080DE5A00<0KFe]07EeM@1eMGD00P1jNWX204e=C@80Hf=S0P3IfMT20=?Cd`80e]KF0P3I
fMT20<c<c0H0dM7A0P3>c/h20<c<c080dM7A00<0dm?C0=7Ad@3AdM400P3>c/h20<c<c080dM7A0P3E
eMD20=WIf@80dM7A0P3>c/h20<c<c080dM7A0P3>c/h20<c<c080eMGE0P3IfMT=0=7Ad@80clo?0P3<
c<`20=7Ad@80clo?0P3<c<`20=7Ad@80dm?C5@3AdM4E0?ooo`004`3ooolW0=7Ad@80eMGE0P3IfMT;
0=7Ad@80clo?0P3<c<`20=CDe080dm?C0P3<c<`20<o?c`80c<c<0P3AdM420<;2`P80K6a/0P0n?Sh2
06m_K`0308b<S02WYjL0YjNW0080[Zj^102n_[h20;Fe]@80/;2`0P2[Zj/20;2`/080/K6a102RXZ82
0:VYZ@80[Zj^0P2m_Kd20;^k^`030;Jf]P2a/K40/K6a0080[jn_0P2<S8`209:BTP80YZJV0P1oOgl2
08V9R@80NGUi0P1_Kfl205aLG080IfMW0P1TI6@206][J`80NWYj0P27QhL00`2>SXh0Jf][06][J`02
04M7A`80R8R80P3AdM440<o?c`80c/k>0P3<c<`20<o?c`80c<c<0P3?cll20<c<c0H0dM7A00<0c<c<
0=7Ad@3AdM40303AdM420<o?c`80c<c<303AdM400`3?cll0c<c<0<c<c0060=7Ad@80clo?0P3AdM42
0=WIf@80dM7A0P3EeMD20=OGe`80bLW90P3<c<`E0=7AdAD0oooo000C0?ooobL0dM7A0P3EeMD20=WI
f@/0dM7A0P3?cll20<c<c080e=CD0P3Cdm<20<c<c080clo?0P3<c<`20=7Ad@80`/;20P1/K6`203hn
?P80Kfm_00<0S8b<0:NWY`2WYjL00P2^[Zh40;jn_P80]KFe0P2`/;020:^[Z`80/;2`0P2a/K440::R
XP80ZJVY0P2^[Zh20;fm_@80^k^k00<0][Jf0;6a/@2a/K400P2_[jl208b<S080TY:B0P2VYZH207mo
O`80RHV90P1iNGT206m_K`80G5aL0P1WIfL206ATI080Jf][0P1jNWX208N7Q`0308j>SP1[Jf/0Jf][
0080AdM70P28R8P20=7Ad@@0clo?0P3>c/h20<c<c080clo?0P3<c<`20<o?c`80c<c<1P3AdM400`3<
c<`0dM7A0=7Ad@0<0=7Ad@80clo?0P3<c<`<0=7Ad@030<o?c`3<c<`0c<c<00H0dM7A0P3?cll20=7A
d@80fMWI0P3AdM420=GEe@80emOG0P39bLT20<c<c1D0dM7A5@3oool001<0oooo=P3AdM420=GEe@80
fMWI0P3EeMD20=gMg@80fMWI0P3EeMD20=WIf@80dM7A0P3Hf=P20<o?c`80PH610P0V9RH00`1CDe<0
P8200820P0020:>SX`80][Jf102[Zj/20;2`/080^;Rh0P2i^KT20;^k^`80a/K60P37alL20<71`@80
_[jn1030`<000`2g]kL0_;bl0;bl_0020:j^[P80Vi^K0P1oOgl207=cL`80R8R80P1cLg<206EUI@80
KVi^0P1PH60205=CD`80MGEe0P22PX8209BDU080Jf][00<0?clo07=cL`1cLg<00P2j^[X40=7Ad@80
c/k>0P3:b/X20<c<c080dM7A0P3EeMD20=WIf@80e]KF0P3Kfm/20=7Ad@80c<c<0P37alL00`3?cll0
c<c<0<c<c0060=7Ad@80dm?C0P3?cll20<c<c080eMGE0P3IfMT40=7Ad@80clo?0P3<c<`40=7Ad@03
0=GEe@3IfMT0fMWI00H0dM7A0P3EeMD20=WIf@80dM7A0P3?cll20<[:bP80clo?0P3EeMD20=?Cd`T0
dM7A0P3?cll20<c<c0P0dM7A5@3oool001<0oooo=P3AdM420=GEe@80fMWI0P3EeMD20=gMg@80fMWI
0P3EeMD20=WIf@80dM7A0P3Hf=P20<o?c`80PH610P0V9RH00`1CDe<0P8200820P0020:>SX`80][Jf
102[Zj/20;2`/080^;Rh0P2i^KT20;^k^`80a/K60P37alL20<71`@80_[jn1030`<000`2g]kL0_;bl
0;bl_0020:j^[P80Vi^K0P1oOgl207=cL`80R8R80P1cLg<206EUI@80KVi^0P1PH60205=CD`80MGEe
0P22PX8209BDU080Jf][00<0?clo07=cL`1cLg<00P2j^[X40=7Ad@80c/k>0P3:b/X20<c<c080dM7A
0P3EeMD20=WIf@80e]KF0P3Kfm/20=7Ad@80c<c<0P37alL00`3?cll0c<c<0<c<c0060=7Ad@80dm?C
0P3?cll20<c<c080eMGE0P3IfMT40=7Ad@80clo?0P3<c<`40=7Ad@030=GEe@3IfMT0fMWI00H0dM7A
0P3EeMD20=WIf@80dM7A0P3?cll20<[:bP80clo?0P3EeMD20=?Cd`T0dM7A0P3?cll20<c<c0P0dM7A
5@3oool001<0oooo9@3AdM420<o?c`80c<c<6@3AdM420=;BdP80bLW90P3<c<`40=CDe080dM7A00<0
WIfM03@d=00d=3@00P0O7al206ATI080YjNW0P36a/H40<C4a080`<300P2/[:`20:f][@80]KFe0P2Z
ZZX20:6QX@80Ti>C0P29RHT00`1kNg/0QHF508F5Q@02096AT@80VYZJ0P1dM7@205UIF@80E5AD0P1R
HV8206m_K`80N7Qh0P2GUiL20:JVYP80T92@0P1EEED203Xj>P80PH6100<0alO70=7Ad@3AdM400P3A
dM420<o?c`80c<c<0P3AdM420=GEe@80fMWI0P3AdM420<o?c`80c<c<0P3>c/h20<c<c080dM7A0P3E
eMD20=WIf@030=KFeP3Kfm/0fm_K00@0dM7A0P3>c/h20<c<c080eMGE0P3IfMT20<o?c`80c<c<0P3?
cll20<[:bP80clo?0P3Cdm<20<[:bP80c<c<1`3AdM420<o?c`80c<c<103AdM420=CDe080emOG0P3I
fMT20=GEe@80alO72@3AdM420=GEe@80fMWI203AdM4E0?ooo`004`3ooolU0=7Ad@80clo?0P3<c<`I
0=7Ad@80d];B0P39bLT20<c<c0@0e=CD0P3AdM400`2MWId0=3@d03@d=00201lO7`80I6AT0P2WYjL2
0<K6aP@0a<C40P30`<020:b/[080[Jf]0P2e]KD20:ZZZP80XJ6Q0P2CTi<208V9R@0307]kN`25QHD0
QHF50080TI6A0P2JVYX207AdM080FEUI0P1DE5@2069RHP80Kfm_0P1hN7P209NGU`80YZJV0P2@T902
05EEE@80>SXj0P21PH400`37alL0dM7A0=7Ad@020=7Ad@80clo?0P3<c<`20=7Ad@80eMGE0P3IfMT2
0=7Ad@80clo?0P3<c<`20<k>cP80c<c<0P3AdM420=GEe@80fMWI00<0e]KF0=_Kf`3Kfm/0103AdM42
0<k>cP80c<c<0P3EeMD20=WIf@80clo?0P3<c<`20<o?c`80b/[:0P3?cll20=?Cd`80b/[:0P3<c<`7
0=7Ad@80clo?0P3<c<`40=7Ad@80e=CD0P3GemL20=WIf@80eMGE0P37alL90=7Ad@80eMGE0P3IfMT8
0=7AdAD0oooo000C0?ooobD0dM7A0P3Hf=P20=WIfAL0dM7A0P3>c/h20=7Ad@80fMWI0P3AdM420=GE
e@80fMWI0P3AdM400`3?cll0c<c<0<c<c0020<o?c`80WIfM0P1;Bd/206i^KP80WinO0P2[Zj/20:b/
[080c<c<0P35aLD20;fm_@80_[jn0P2f][H20:ZZZP80Rh^;00<0OGem079bLP1bLW800P1cLg<207Mg
M`80VIVI0P2JVYX208N7Q`80Zj^[0P2i^KT209^KV`80IfMW0P1NGUh209BDU080a/K60P3GemL20=WI
f@030=_Kf`3AdM40dM7A0080dM7A0P3EeMD20=WIf@H0dM7A0P3Cdm<20=GEe@80fMWI0P3Cdm<60=7A
d@80dm?C00<0c/k>0<c<c03<c<`02P3AdM420=?Cd`80eMGE0P3IfMT20=GEe@H0gMgM0P3Ng]h20=_K
f`030<o?c`3=cLd0cLg=0080dm?C0P3AdM420=GEe@80fMWI103AdM420=SHf080gMgM0P3IfMT20=GE
e@80fMWI0P3Cdm<C0=7AdAD0oooo000C0?ooobD0dM7A0P3Hf=P20=WIfAL0dM7A0P3>c/h20=7Ad@80
fMWI0P3AdM420=GEe@80fMWI0P3AdM400`3?cll0c<c<0<c<c0020<o?c`80WIfM0P1;Bd/206i^KP80
WinO0P2[Zj/20:b/[080c<c<0P35aLD20;fm_@80_[jn0P2f][H20:ZZZP80Rh^;00<0OGem079bLP1b
LW800P1cLg<207MgM`80VIVI0P2JVYX208N7Q`80Zj^[0P2i^KT209^KV`80IfMW0P1NGUh209BDU080
a/K60P3GemL20=WIf@030=_Kf`3AdM40dM7A0080dM7A0P3EeMD20=WIf@H0dM7A0P3Cdm<20=GEe@80
fMWI0P3Cdm<60=7Ad@80dm?C00<0c/k>0<c<c03<c<`02P3AdM420=?Cd`80eMGE0P3IfMT20=GEe@H0
gMgM0P3Ng]h20=_Kf`030<o?c`3=cLd0cLg=0080dm?C0P3AdM420=GEe@80fMWI103AdM420=SHf080
gMgM0P3IfMT20=GEe@80fMWI0P3Cdm<C0=7AdAD0oooo000C0?ooob<0dM7A0P3>c/h20<[:bP80c<c<
8@3AdM420=?Cd`80dM7A00<0e=CD0=GEe@3EeMD00P3IfMT20=_Kf`80dM7A0P2YZJT2069RHP80K6a/
0P1hN7P207=cL`80U9BD0P2TY:@20:f][@80/K6a0P2i^KT20=7Ad@030=[JfP3?cll0clo?0080^;Rh
0P2d];@20;Zj^P80/k>c0P2JVYX2069RHP80GUiN0P1nOWh20:>SX`80`l?30P3AdM420=CDe080emOG
0P3AdM450<[:bP80c<c<1P3AdM420<k>cP80cLg=0P3De=@20=7Ad@80c<c<103AdM420<k>cP80c<c<
00<0dM7A0=?Cd`3Cdm<00P3?cll20<g=c@80dm?C0P3AdM420<k>cP80b/[:0P3<c<`:0=7Ad@80c/k>
0P3<c<`30=GEe@80alO70P3?cll20<c<c0@0dM7A0P3>c/h20<c<c0H0dM7A0P3<c<`20<O7a`/0dM7A
0P3?cll20<c<c0@0dM7A5@3oool001<0oooo8`3AdM420<k>cP80b/[:0P3<c<`Q0=7Ad@80dm?C0P3A
dM400`3De=@0eMGE0=GEe@020=WIf@80fm_K0P3AdM420:VYZ@80HV9R0P1/K6`207QhN080Lg=c0P2D
U9@20:BTY080[Jf]0P2a/K420;Vi^@80dM7A00<0f][J0<o?c`3?cll00P2h^;P20;Bd]080^[Zj0P2c
/k<209ZJVP80HV9R0P1NGUh207inOP80Xj>S0P33`l<20=7Ad@80e=CD0P3GemL20=7Ad@D0b/[:0P3<
c<`60=7Ad@80c/k>0P3=cLd20=CDe080dM7A0P3<c<`40=7Ad@80c/k>0P3<c<`00`3AdM40dm?C0=?C
d`020<o?c`80cLg=0P3Cdm<20=7Ad@80c/k>0P3:b/X20<c<c0X0dM7A0P3>c/h20<c<c0<0eMGE0P37
alL20<o?c`80c<c<103AdM420<k>cP80c<c<1P3AdM420<c<c080alO72`3AdM420<o?c`80c<c<103A
dM4E0?ooo`004`3ooolU0=7Ad@80eMGE0P3IfMT20=?Cda<0dM7A0P3?cll20<g=c@80dm?C103AdM42
0<k>cP80cLg=0P3Cdm<00`3EeMD0e]KF0=KFeP020<W9b@80c<c<103AdM420<k>cP80bLW90P37alL2
0;no_`80^k^k0P2f][H20;Ng]`80`/;20P2][Jd2096AT@0308B4Q02<S8`0S8b<0080UIFE102?Shl2
09:BTP80YJFU0P30`<020<c<c080clo?0P3:b/X20<c<c080dM7A0P3EeMD20=cLg080e=CD00<0eMGE
0=gMg@3MgMd00P3MgMd20=WIf@80dm?C0P3?cll20<c<c080dM7A0P3<c<`20<G5a@80c<c<0P3AdM42
0<o?c`80c<c<0P3?cll30<c<c080alO70P3Fe]H20=WIf@80c<c<0P3AdM420=?Cd`80eMGE0P3IfMT?
0=7Ad@80e]KF0P3Kfm/20=GEe@80emOG0P3<c<`60=7Ad@80clo?0P3<c<`20=7Ad@80eMGE0P3IfMT;
0=7Ad@80eMGE0P3IfMT40=7AdAD0oooo000C0?ooobD0dM7A0P3EeMD20=WIf@80dm?C4`3AdM420<o?
c`80cLg=0P3Cdm<40=7Ad@80c/k>0P3=cLd20=?Cd`030=GEe@3Fe]H0e]KF0080bLW90P3<c<`40=7A
d@80c/k>0P39bLT20<O7a`80_kno0P2k^k/20;Jf]P80]kNg0P32`/820:f][@80TI6A00<0Q8B408b<
S02<S8`00P2EUID408n?S`80TY:B0P2UYJD20<30`080c<c<0P3?cll20<[:bP80c<c<0P3AdM420=GE
e@80g=cL0P3De=@00`3EeMD0gMgM0=gMg@020=gMg@80fMWI0P3Cdm<20<o?c`80c<c<0P3AdM420<c<
c080aLG50P3<c<`20=7Ad@80clo?0P3<c<`20<o?c`<0c<c<0P37alL20=KFeP80fMWI0P3<c<`20=7A
d@80dm?C0P3EeMD20=WIf@l0dM7A0P3Fe]H20=_Kf`80eMGE0P3GemL20<c<c0H0dM7A0P3?cll20<c<
c080dM7A0P3EeMD20=WIf@/0dM7A0P3EeMD20=WIf@@0dM7A5@3oool001<0oooo9`3AdM420<k>cP80
c<c<4`3AdM420=GEe@80e]KF0P3<c<`80=7Ad@80c<c<00<0dM7A0=;BdP3Bd]800P3<c<`60=7Ad@80
dm?C0P3AdM420=SHf080fMWI0P3?cll20<g=c@80dm?C0P3AdM420<k>cPD0bLW90P3?cll20=CDe0@0
dM7A0P3Cdm<40=7Ad@80eMGE0P3MgMd20=WIf@80clo?0P3<c<`40=CDe0D0dM7A0P3?cll20<O7a`80
e=CD0P3Cdm<20<c<c080eMGE0P3IfMT40=7Ad@80eMGE0P3IfMT20=GEe@80fMWI00<0e=CD0=GEe@3E
eMD00P3AdM420<o?c`@0dM7A0P3<c<`<0=7Ad@80clo?0P3<c<`30=7Ad@80c/k>0P3<c<`20=7Ad@@0
e=CD1P3AdM420=SHf080emOG0P3:b/X20<c<c0d0dM7A0P3?cll20<c<c080dM7A0P3Cdm<E0?ooo`00
4`3ooolW0=7Ad@80c/k>0P3<c<`C0=7Ad@80eMGE0P3Fe]H20<c<c0P0dM7A0P3<c<`00`3AdM40d];B
0=;BdP020<c<c0H0dM7A0P3Cdm<20=7Ad@80f=SH0P3IfMT20<o?c`80cLg=0P3Cdm<20=7Ad@80c/k>
1@39bLT20<o?c`80e=CD103AdM420=?Cd`@0dM7A0P3EeMD20=gMg@80fMWI0P3?cll20<c<c0@0e=CD
1@3AdM420<o?c`80alO70P3De=@20=?Cd`80c<c<0P3EeMD20=WIf@@0dM7A0P3EeMD20=WIf@80eMGE
0P3IfMT00`3De=@0eMGE0=GEe@020=7Ad@80clo?103AdM420<c<c0`0dM7A0P3?cll20<c<c0<0dM7A
0P3>c/h20<c<c080dM7A103De=@60=7Ad@80f=SH0P3GemL20<[:bP80c<c<3@3AdM420<o?c`80c<c<
0P3AdM420=?CdaD0oooo000C0?ooobT0dM7A0P3?cll20<c<c1/0dM7A0P3>c/h20<c<c080clo?00<0
b<S80<c<c03<c<`00P3IfMT60=7Ad@@0c<c<0P37alL20=7Ad@@0eMGE0P37alL20=7Ad@80clo?0P3<
c<`30=7Ad@80e]KF0P3Kfm/20=7Ad@80c/k>0P3<c<`60=7Ad@80dm?C0P3?cll20=7Ad@80fMWI0P3D
e=@20=?Cd`030<c<c03AdM40dM7A0080c/k>0P3AdM420=_Kf`80eMGE0P3Ng]h20=_Kf`80clo?0P3<
c<`60=7Ad@80clo?0P3<c<`20=7Ad@030=GEe@3Fe]H0e]KF0080bLW90P3<c<`20<k>cP80c<c<0P3A
dM420<o?c`80cLg=0P3Cdm<60=7Ad@@0e=CD0P3AdM400`3?cll0c<c<0<c<c0040=7Ad@80f=SH0P3I
fMT40=7Ad@80c/k>0P3<c<`20=KFeP80gmoO0P3De=@=0=7Ad@80eMGE0P3IfMT20<c<c080alO75@3o
ool001<0oooo:@3AdM420<o?c`80c<c<6`3AdM420<k>cP80c<c<0P3?cll00`38b<P0c<c<0<c<c002
0=WIf@H0dM7A103<c<`20<O7a`80dM7A103EeMD20<O7a`80dM7A0P3?cll20<c<c0<0dM7A0P3Fe]H2
0=_Kf`80dM7A0P3>c/h20<c<c0H0dM7A0P3Cdm<20<o?c`80dM7A0P3IfMT20=CDe080dm?C00<0c<c<
0=7Ad@3AdM400P3>c/h20=7Ad@80fm_K0P3EeMD20=kNgP80fm_K0P3?cll20<c<c0H0dM7A0P3?cll2
0<c<c080dM7A00<0eMGE0=KFeP3Fe]H00P39bLT20<c<c080c/k>0P3<c<`20=7Ad@80clo?0P3=cLd2
0=?Cd`H0dM7A103De=@20=7Ad@030<o?c`3<c<`0c<c<00@0dM7A0P3Hf=P20=WIf@@0dM7A0P3>c/h2
0<c<c080e]KF0P3Ogml20=CDe0d0dM7A0P3EeMD20=WIf@80c<c<0P37alLE0?ooo`004`3ooolQ0=7A
d@80clo?0P3<c<`40=7Ad@80f=SH0P3IfMT20=7Ad@030=?Cd`3AdM40dM7A01@0dM7A0P3Bd]820<c<
c080dM7A0P3EeMD00`3Ng]h0fm_K0=_Kf`040=7Ad@80c/k>0P3=cLd20=;BdP80dM7A0P3Kfm/40=7A
d@@0e=CD0P3AdM420=GEe@80emOG00<0c<c<0=7Ad@3AdM400P3AdM420<c<c080dM7A0P3Cdm<60=7A
d@80c/k>0P3<c<`20=GEe@80fMWI0P3AdM420=GEe@80g=cL00<0e=CD0=7Ad@3AdM40103AdM420<[:
bP80c<c<0P3>c/h20<c<c080e]KF0P3Jf]X20<[:bP80c<c<0P3AdM420=KFeP80f][J0P3<c<`50=7A
d@80clo?0P3<c<`40=7Ad@80e=CD0P3AdM420<c<c080dM7A0P3?cll20<c<c080eMGE0P3GemL20<c<
c0030=GEe@3GemL0emOG0080b/[:0P39bLT20<c<c080clo?0P3<c<`:0=7Ad@80fMWI2@3AdM420<o?
c`80c<c<103AdM420=GEe@80fMWI5@3oool001<0oooo8@3AdM420=GEe@80fMWI0P3AdM420<k>cP80
c<c<0P3?cll20<W9b@030<c<c03AdM40dM7A0180dM7A0P3>c/h20=7Ad@80fMWI103AdM400`3>c/h0
c<c<0<c<c0060=7Ad@80clo?0P3Cdm<20=KFeP80c<c<0P3?cll20<g=c@80f=SH0P3GemL20<c<c080
dM7A0P3EeMD00`3IfMT0c<c<0<c<c0020<O7a`80clo?0P39bLT20<c<c0X0dM7A0P3Cdm<20<o?c`80
c<c<0P3AdM420=GEe@030=WIf@3AdM40dM7A0080c/k>0P3<c<`20=GEe@80fMWI103AdM420<k>cP80
dM7A0P3Ng]h20=_Kf`80dM7A0P3>c/h20=7Ad@80fMWI0`3AdM420=;BdP80dM7A0P3Jf]X20<c<c080
dM7A103De=@40=7Ad@80f=SH0P3IfMT20=7Ad@80eMGE0P3IfMT00`3AdM40eMGE0=GEe@020=gMg@80
fMWI0P3AdM420=GEe@80fMWI0P3AdM420=?Cd`80c/k>0P3<c<`=0=7Ad@80emOG0P3De=@80=7AdAD0
oooo000C0?ooob40dM7A0P3EeMD20=WIf@80dM7A0P3>c/h20<c<c080clo?0P39bLT00`3<c<`0dM7A
0=7Ad@0B0=7Ad@80c/k>0P3AdM420=WIf@@0dM7A00<0c/k>0<c<c03<c<`01P3AdM420<o?c`80dm?C
0P3Fe]H20<c<c080clo?0P3=cLd20=SHf080emOG0P3<c<`20=7Ad@80eMGE00<0fMWI0<c<c03<c<`0
0P37alL20<o?c`80bLW90P3<c<`:0=7Ad@80dm?C0P3?cll20<c<c080dM7A0P3EeMD00`3IfMT0dM7A
0=7Ad@020<k>cP80c<c<0P3EeMD20=WIf@@0dM7A0P3>c/h20=7Ad@80g]kN0P3Kfm/20=7Ad@80c/k>
0P3AdM420=WIf@<0dM7A0P3Bd]820=7Ad@80f][J0P3<c<`20=7Ad@@0e=CD103AdM420=SHf080fMWI
0P3AdM420=GEe@80fMWI00<0dM7A0=GEe@3EeMD00P3MgMd20=WIf@80dM7A0P3EeMD20=WIf@80dM7A
0P3Cdm<20<k>cP80c<c<3@3AdM420=OGe`80e=CD203AdM4E0?ooo`004`3ooolW0=7Ad@80clo?0P3<
c<`20=GEe@80fMWI5@3AdM420=?Cda40dM7A103?cll20=?Cd`80dM7A0P3EeMD20=KFeP80cLg=0P3G
emL20=?Cd`80c<c<0P3AdM400`3?cll0dM7A0=7Ad@020=_Kf`80eMGE0P3IfMT40=7Ad@80clo?0P3<
c<`40=7Ad@80clo?0P3EeMD20=OGe`80cLg=0P3Cdm<00`3?cll0c<c<0<c<c0020<o?c`80c<c<0P3A
dM420<o?c`80c<c<0P3?cll20<c<c080dM7A0P3>c/h20<c<c080dM7A0P3?cll20<c<c0<0dM7A0P3>
c/h20=7Ad@80e]KF0P3Cdm<20=OGe`80c<c<0P3EeMD20=WIf@80clo?0P39bLT20<c<c080dM7A0P3?
cll20<c<c080clo?00<0c<c<0=7Ad@3AdM400P3?cll20<g=c@80dm?C103AdM420<k>cP80c<c<0P3?
cll20<c<c080dM7A0P3?cll20<c<c0D0dM7A0P3>c/h20=7Ad@80fMWI1P3AdM420=CDe1D0oooo000C
0?ooobL0dM7A0P3?cll20<c<c080eMGE0P3IfMTE0=7Ad@80dm?C4@3AdM440<o?c`80dm?C0P3AdM42
0=GEe@80e]KF0P3=cLd20=OGe`80dm?C0P3<c<`20=7Ad@030<o?c`3AdM40dM7A0080fm_K0P3EeMD2
0=WIf@@0dM7A0P3?cll20<c<c0@0dM7A0P3?cll20=GEe@80emOG0P3=cLd20=?Cd`030<o?c`3<c<`0
c<c<0080clo?0P3<c<`20=7Ad@80clo?0P3<c<`20<o?c`80c<c<0P3AdM420<k>cP80c<c<0P3AdM42
0<o?c`80c<c<0`3AdM420<k>cP80dM7A0P3Fe]H20=?Cd`80emOG0P3<c<`20=GEe@80fMWI0P3?cll2
0<W9b@80c<c<0P3AdM420<o?c`80c<c<0P3?cll00`3<c<`0dM7A0=7Ad@020<o?c`80cLg=0P3Cdm<4
0=7Ad@80c/k>0P3<c<`20<o?c`80c<c<0P3AdM420<o?c`80c<c<1@3AdM420<k>cP80dM7A0P3IfMT6
0=7Ad@80e=CD5@3oool001<0oooo9`3AdM420=GEe@80fMWI0P3?cll20<c<c1<0dM7A0P3>c/h20<[:
bP80c<c<103AdM420=?Cd`030=7Ad@3Cdm<0dm?C00H0dM7A0P3>c/h20<W9b@80b/[:0P3<c<`40=7A
d@80c/k>0P3AdM420=gMg@80fMWI0P3AdM400`3GemL0dM7A0=7Ad@020<c<c0P0dM7A0P3EeMD20=WI
f@80c/k>0P39bLT20<c<c080dM7A0P3Hf=P20=GEe@80alO70`3De=@20=GEe@80fMWI0P3AdM420=OG
e`80eMGE0P3GemL20=CDe0H0dM7A0P3Cdm<20=GEe@80fMWI1`3AdM420<k>cP80b/[:0P3AdM420=cL
g080dm?C0P3AdM420=GEe@80fMWI0P3Cdm<20=7Ad@80eMGE0P3IfMT30=CDe080dM7A0P3EeMD20=KF
eP80c<c<103AdM420<o?c`80c<c<0P3EeMD20=WIf@80dM7A0P3EeMD20=WIf@d0dM7A0P3Cdm<20<c<
c080aLG55@3oool001<0oooo9`3AdM420=GEe@80fMWI0P3?cll20<c<c1<0dM7A0P3>c/h20<[:bP80
c<c<103AdM420=?Cd`030=7Ad@3Cdm<0dm?C00H0dM7A0P3>c/h20<W9b@80b/[:0P3<c<`40=7Ad@80
c/k>0P3AdM420=gMg@80fMWI0P3AdM400`3GemL0dM7A0=7Ad@020<c<c0P0dM7A0P3EeMD20=WIf@80
c/k>0P39bLT20<c<c080dM7A0P3Hf=P20=GEe@80alO70`3De=@20=GEe@80fMWI0P3AdM420=OGe`80
eMGE0P3GemL20=CDe0H0dM7A0P3Cdm<20=GEe@80fMWI1`3AdM420<k>cP80b/[:0P3AdM420=cLg080
dm?C0P3AdM420=GEe@80fMWI0P3Cdm<20=7Ad@80eMGE0P3IfMT30=CDe080dM7A0P3EeMD20=KFeP80
c<c<103AdM420<o?c`80c<c<0P3EeMD20=WIf@80dM7A0P3EeMD20=WIf@d0dM7A0P3Cdm<20<c<c080
aLG55@3oool001<0oooo:`3AdM420=GEe@80fMWI00<0dm?C0=7Ad@3AdM403P3AdM420=;BdP80c<c<
0P3EeMD20=WIf@80dm?C0P3>c/h20<g=c@030=7Ad@3?cll0clo?00@0dM7A0P3?cll20<[:bP80c<c<
0P3EeMD20=WIf@80dM7A0P3Cdm<;0=7Ad@80emOG0P3<c<`20=7Ad@80d];B0P3<c<`80=7Ad@80clo?
103<c<`20<O7a`80e]KF0P3Jf]X00`3AdM40fMWI0=WIf@020=?Cd`H0dM7A0P3EeMD20<c<c080fMWI
0P3AdM420=?Cd`80c/k>0P3:b/X20<g=c@80d];B0P3<c<`00`3AdM40dm?C0=?Cd`020=7Ad@80d];B
0P3AdM420=GEe@80aLG50P3<c<`60=7Ad@80c<c<1P3AdM420=GEe@030=WIf@3AdM40dM7A00X0dM7A
0P3EeMD20=WIf@80dM7A0P3Cdm<A0=7Ad@80c/k>0P3<c<`20=GEe@80fMWI5@3oool001<0oooo:`3A
dM420=GEe@80fMWI00<0dm?C0=7Ad@3AdM403P3AdM420=;BdP80c<c<0P3EeMD20=WIf@80dm?C0P3>
c/h20<g=c@030=7Ad@3?cll0clo?00@0dM7A0P3?cll20<[:bP80c<c<0P3EeMD20=WIf@80dM7A0P3C
dm<;0=7Ad@80emOG0P3<c<`20=7Ad@80d];B0P3<c<`80=7Ad@80clo?103<c<`20<O7a`80e]KF0P3J
f]X00`3AdM40fMWI0=WIf@020=?Cd`H0dM7A0P3EeMD20<c<c080fMWI0P3AdM420=?Cd`80c/k>0P3:
b/X20<g=c@80d];B0P3<c<`00`3AdM40dm?C0=?Cd`020=7Ad@80d];B0P3AdM420=GEe@80aLG50P3<
c<`60=7Ad@80c<c<1P3AdM420=GEe@030=WIf@3AdM40dM7A00X0dM7A0P3EeMD20=WIf@80dM7A0P3C
dm<A0=7Ad@80c/k>0P3<c<`20=GEe@80fMWI5@3oool001<0oooo;@3AdM420<k>cP030<c<c03AdM40
dM7A00`0dM7A0P3>c/h20=7Ad@80fMWI0P3AdM420<c<c080alO70P3?cll20<W9b@030<[:bP3=cLd0
cLg=0080b/[:0P3<c<`20=KFeP80gmoO0P3De=@40=7Ad@80c/k>0P3<c<`60=7Ad@80c<c<0P36a/H0
0`3<c<`0eMGE0=GEe@020=WIf@80c/k>0P3?cll20=CDe0P0dM7A0P3EeMD20=OGe`80dM7A0P3IfMT2
0<k>cP80dM7A00<0fMWI0<c<c03<c<`00P36a/H20<S8b080a/K60P3<c<`20=GEe@80fMWI0P3AdM46
0<o?c`80dM7A0P3Fe]H20=7Ad@80emOG00<0b<S80<K6aP36a/H00P38b<P20<c<c080fMWI0P3EeMD2
0=WIf@@0dM7A0P3<c<`20<K6aP80c<c<203AdM400`3Cdm<0dM7A0=7Ad@080=7Ad@80clo?0P3<c<`2
0=7Ad@80c/k>0P3<c<`20<o?c`80c<c<1P3AdM400`3?cll0c<c<0<c<c0020<o?c`80c<c<0P3AdM42
0<o?c`80c<c<0P3AdM4E0?ooo`004`3oool]0=7Ad@80c/k>00<0c<c<0=7Ad@3AdM40303AdM420<k>
cP80dM7A0P3IfMT20=7Ad@80c<c<0P37alL20<o?c`80bLW900<0b/[:0<g=c@3=cLd00P3:b/X20<c<
c080e]KF0P3Ogml20=CDe0@0dM7A0P3>c/h20<c<c0H0dM7A0P3<c<`20<K6aP030<c<c03EeMD0eMGE
0080fMWI0P3>c/h20<o?c`80e=CD203AdM420=GEe@80emOG0P3AdM420=WIf@80c/k>0P3AdM400`3I
fMT0c<c<0<c<c0020<K6aP80b<S80P36a/H20<c<c080eMGE0P3IfMT20=7Ad@H0clo?0P3AdM420=KF
eP80dM7A0P3GemL00`38b<P0a/K60<K6aP020<S8b080c<c<0P3IfMT20=GEe@80fMWI103AdM420<c<
c080a/K60P3<c<`80=7Ad@030=?Cd`3AdM40dM7A00P0dM7A0P3?cll20<c<c080dM7A0P3>c/h20<c<
c080clo?0P3<c<`60=7Ad@030<o?c`3<c<`0c<c<0080clo?0P3<c<`20=7Ad@80clo?0P3<c<`20=7A
dAD0oooo000C0?ooob<0dM7A0P3?cll20<c<c080clo?0P3<c<`40=7Ad@030=?Cd`3AdM40dM7A0080
dm?C203AdM420<o?c`80c<c<1P3AdM420=GEe@80fMWI0P3Fe]H20=_Kf`030<o?c`3Cdm<0dm?C0080
g]kN0P3Kfm/20<k>cP80dM7A0P3IfMT80=7Ad@80dm?C103AdM420=GEe@80gMgM00<0fMWI0<o?c`3?
cll00P3<c<`20=7Ad@80eMGE0P3IfMT20<o?c`80cLg=0P3Cdm<20<o?c`80b/[:0P3AdM420=WIf@L0
dM7A0P3EeMD60=gMg@80fMWI0P3?cll20<c<c080dM7A0P3>c/h20<c<c080eMGE0P3IfMT20=?Cd`80
dM7A0P3EeMD50=gMg@80emOG0P3<c<`20<o?c`80c<c<103AdM420=SHf080g=cL0P3De=@40=7Ad@80
clo?0P39bLT00`3<c<`0dM7A0=7Ad@080=7Ad@80eMGE0P3IfMT20=?Cd`80dM7A0P3Cdm<20=GEe@80
fMWI1P3AdM400`3EeMD0fMWI0=WIf@020=GEe@80fMWI0P3AdM420=GEe@80fMWI0P3AdM4E0?ooo`00
4`3ooolS0=7Ad@80clo?0P3<c<`20<o?c`80c<c<103AdM400`3Cdm<0dM7A0=7Ad@020=?Cd`P0dM7A
0P3?cll20<c<c0H0dM7A0P3EeMD20=WIf@80e]KF0P3Kfm/00`3?cll0dm?C0=?Cd`020=kNgP80fm_K
0P3>c/h20=7Ad@80fMWI203AdM420=?Cd`@0dM7A0P3EeMD20=gMg@030=WIf@3?cll0clo?0080c<c<
0P3AdM420=GEe@80fMWI0P3?cll20<g=c@80dm?C0P3?cll20<[:bP80dM7A0P3IfMT70=7Ad@80eMGE
1P3MgMd20=WIf@80clo?0P3<c<`20=7Ad@80c/k>0P3<c<`20=GEe@80fMWI0P3Cdm<20=7Ad@80eMGE
1@3MgMd20=OGe`80c<c<0P3?cll20<c<c0@0dM7A0P3Hf=P20=cLg080e=CD103AdM420<o?c`80bLW9
00<0c<c<0=7Ad@3AdM40203AdM420=GEe@80fMWI0P3Cdm<20=7Ad@80dm?C0P3EeMD20=WIf@H0dM7A
00<0eMGE0=WIf@3IfMT00P3EeMD20=WIf@80dM7A0P3EeMD20=WIf@80dM7A5@3oool001<0oooo8`3A
dM440=CDe080eMGE0P3GemL20<c<c080c/k>00<0c<c<0<k>cP3>c/h00P3<c<`80=7Ad@80eMGE0P3I
fMT80=7Ad@80dm?C0P3>c/h20<c<c0030<k>cP3<c<`0c<c<0080c/k>0P3:b/X20<c<c080clo?0P3<
c<`60=7Ad@80c/k>0P3<c<`80=7Ad@<0clo?0P3De=@60=7Ad@80f=SH0P3Fe]H20<[:bP80clo?103I
fMTA0=7Ad@@0clo?0P3Cdm<20<c<c0H0dM7A0P3>c/h20<c<c0T0dM7A0P3De=@20=?Cd`80clo?0P3D
e=@20=7Ad@80c/k>0P3<c<`20=GEe@80fMWI103AdM420=GEe@80fMWI2@3AdM420<o?c`80c<c<203?
cll20=7Ad@80clo?0P3<c<`20=7Ad@80clo?00<0cLg=0=?Cd`3Cdm<0303AdM4E0?ooo`004`3ooolS
0=7Ad@@0e=CD0P3EeMD20=OGe`80c<c<0P3>c/h00`3<c<`0c/k>0<k>cP020<c<c0P0dM7A0P3EeMD2
0=WIf@P0dM7A0P3Cdm<20<k>cP80c<c<00<0c/k>0<c<c03<c<`00P3>c/h20<[:bP80c<c<0P3?cll2
0<c<c0H0dM7A0P3>c/h20<c<c0P0dM7A0`3?cll20=CDe0H0dM7A0P3Hf=P20=KFeP80b/[:0P3?cll4
0=WIfA40dM7A103?cll20=?Cd`80c<c<1P3AdM420<k>cP80c<c<2@3AdM420=CDe080dm?C0P3?cll2
0=CDe080dM7A0P3>c/h20<c<c080eMGE0P3IfMT40=7Ad@80eMGE0P3IfMT90=7Ad@80clo?0P3<c<`8
0<o?c`80dM7A0P3?cll20<c<c080dM7A0P3?cll00`3=cLd0dm?C0=?Cd`0<0=7AdAD0oooo003o0?oo
ob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?oo
ob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo002H0?oo
o`900000QP3oool009X0oooo00=000000?ooo`3oool0P`3oool007/0oooo0T0000040?ooo`03@000
003oool0oooo0080oooo00=000000?ooo`3oool01@3oool3@0000080oooo0T0000030?ooo`=00000
1@3oool00d000000oooo0?ooo`1m0?ooo`00O@3oool01T000000oooo0?oood000000oooo@0000080
oooo00=000000?oood0000001@3oool01T000000oooo0?oood000000oooo@00000@0oooo00A00000
0?ooo`3ooom00000Q@3oool007`0oooo00M000000?ooo`3oool0oooo@000003ooom000000080oooo
00=000000?oood0000001@3oool01D000000oooo0?oood000000oooo00=000000P3oool014000000
oooo0?oood0000250?ooo`00O@3oool01T000000oooo0?oood000000oooo@0000080oooo00=00000
0?oood0000001P3oool3@00000040?oood0000100000@00000<0oooo0d0000250?ooo`00N`3oool0
0d000000oooo@00000020?ooo`03@000003ooom000000080oooo00=000000?oood000000203oool0
0d000000oooo0?ooo`2=0?ooo`00O03oool00d000000oooo0?ooo`020?ooo`03@000003oool0oooo
0080oooo00=000000?ooo`3oool01P3oool2@00008l0oooo003o0?ooob40oooo003o0?ooob40oooo
003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo
003o0?ooob40oooo003o0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.0250052, -0.0250052, 
  0.00365857, 0.00365857}, {{6.8125, 280.125}, {280.125, 
  6.8125}} -> {-10.161, -6.11446, 0.516914, 0.516914}}]
}, Closed]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["2.7 Monochrome static image governing equation",
  FontFamily->"Times New Roman"]], "Section"],

Cell[TextData[{
  StyleBox["\t",
    FontFamily->"Times New Roman",
    FontSize->10.5],
  StyleBox[
  "As shown above, the vectored imaging makes it possible to process the \
image in various ways. In this section, we establish a monochrome image \
governing equation.",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"],
  StyleBox["\n",
    TextAlignment->Left,
    TextJustification->1],
  StyleBox[
  "Regarding the numerical values representing a monochrome image as one of \
he scalar potentials derives this equation. As is well known in the classical \
field theory, application of the second order partial derivatives to a scalar \
potential yields a field source density. Namely, when we apply the Laplacian \
operator to the monochrome image data shown in Fig. 1, then it is possible to \
obtain a source density distribution of the image. A function \
\[OpenCurlyDoubleQuote]laplace2D\[CloseCurlyDoubleQuote] is given by a \
following ",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"],
  StyleBox["Mathematica",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox[
  " code. This function is based on a 9 points finite difference formula, \
where the potentials along the edges of a target area are assumed to zero. \
Also, a parameter \[OpenCurlyDoubleQuote]data2D\[CloseCurlyDoubleQuote] \
refers to a two-dimensional array including a monochrome image data.",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Mathematica",
    FontFamily->"Century",
    FontSize->10.5,
    FontSlant->"Italic"],
  StyleBox[" function",
    FontFamily->"Century",
    FontSize->10.5],
  StyleBox[" ",
    FontFamily->"Century",
    FontSize->13],
  StyleBox["laplace2D",
    FontFamily->"Century",
    FontSize->9]
}], "Subsubsection"],

Cell[TextData[{
  StyleBox["Laplacian operation",
    FontWeight->"Bold"],
  ":\n\n",
  Cell[BoxData[
      \(TraditionalForm\`\[Sigma]\)]],
  " =  ",
  Cell[BoxData[
      \(TraditionalForm\`\[Del]\^2 U\)]],
  " = ",
  Cell[BoxData[
      \(TraditionalForm\`\(\ \[PartialD]\^2 U\)\/\(\ \[PartialD]x\^2\)\)]],
  StyleBox[" + ",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`\(\ \[PartialD]\^2 U\)\/\(\ \[PartialD]y\^2\)\)]],
  StyleBox[",\t\t\t\t\t\t\t\t\t",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  "(4)",
  StyleBox["\n\n",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  StyleBox["where ",
    FontFamily->"Times New Roman"],
  StyleBox["\[Sigma]",
    FontFamily->"\.82l\.82r \.96\.be\.92\[Copyright]"],
  StyleBox[
  " and U are the field source density to be evaluated and input scalar \
potential, respectively.",
    FontFamily->"Times New Roman"]
}], "NumberedEquation"],

Cell["\<\
laplace2D=Compile[{{data2D,_Real,2}},
\tModule[{e2D={{0.}},out={{0.}},dim={0},
\t\tmax=0.,i=0,j=0,nx=0,ny=0},
\t\t\tdim=Dimensions[data2D];
\t\t\tny=dim[[1]]+1;nx=dim[[2]]+1;
\t\t\te2D=Table[0.,{ny+1},{nx+1}];
\t\t\tDo[e2D[[i,j]]=data2D[[i-1,j-1]],
\t\t\t\t{i,2,ny},{j,2,nx}];
\t\t\tTable[e2D[[i+1,j-1]]+4.*e2D[[i+1,j]]+
\t\t\t\te2D[[i+1,j+1]]+4.*e2D[[i,j-1]]-
\t\t\t\t20.*e2D[[i,j]]+4.*e2D[[i,j+1]]+
\t\t\t\te2D[[i-1,j-1]]+4.*e2D[[i-1,j]]+
\t\t\t\te2D[[i-1,j+1]],
\t\t\t{i,2,ny},{j,2,nx}]/6.]];\
\>", "Input",
  CellLabel->"In[41]:="],

Cell[TextData[{
  StyleBox["\t",
    FontFamily->"Times New Roman",
    FontSize->10.5],
  StyleBox[
  "Using this function, we compute the source density of the monochrome image \
in Fig. 1. Figure 7 shows the source density distribution.",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell[CellGroupData[{

Cell["\<\
source=laplace2D[monoSample];
ListDensityPlot[source,PlotRange->All,
\tMesh->False,Frame->False,
\tPlotLabel->\"Fig.7. Source density\"];\
\>", "Input",
  CellLabel->"In[42]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00751202 0.0192308 0.00751202 [
[.5 1.0125 -65 0 ]
[.5 1.0125 65 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -126 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Fig) show
81.000000 12.812500 moveto
(.7) show
93.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(.) show
105.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Source) show
147.000000 12.812500 moveto
(density) show
189.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
128 string
128 128 8 [128 0 0 128 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
0447403F484649493D4B3F5B504F4F484F4E4E4E53363190
46495350584D4C574D4F514E58574D524D4C5150504E4F4D
5C4C4F52494B4C4C4B4B4C4F4954514E4852505150505150
51515050534F4E51505055423B3E7F41544F4E5553544E4F
515252544C4D524F464F48494853464E524F5A5852535667
443B6B4B43433E05
46929399958E8E96978D958CA19694959494949595A17CB4
7E8B969490979697999394959191999190989594909D968F
8C988F929798939598998E98988C97979997979297959595
9494949493959D92949595A08F76ADC47B8F909796969698
91919195929A919A959696989A8F989198939290989A9A80
86A996A18A909846
479697959698989497998F8D86A29C979397939198968B6E
E5859193989B958E909293959492979E8E90959398949695
9B989A94919496909595969495969894919195988F989697
9695949594959294949494959D9B7275D88596999092999A
919C9C94919393939495979291929694949794979B93909E
848F9C9D95928B46
4495938E998F8E9A90919999949189989E9299979697A484
81A7919591959497999991939493999994959390988E989C
9594989996919492909293959596928A9592938E96909590
8F979595959495959596959595999D7C74C681919595948D
94929297929A929994969094939A8D9A959892A5829A9D85
B28795A188999C44
469296958F9695989092918E998E968B9A9A909991999588
82B590958F9A96968C989A93959190929190989696929290
9190949B94968C9B999D91939494969A8F9A9D8E8C9C9099
91959892929796919290978E9696999D73AEA08D8F939298
959792939594929495949094949196918D989284938A8B7F
9E84A1A58F8A9447
47949A949797948E9B96959C9191978F8D99A094969698A1
89849E9191979399998E91908F98968B959B919297919596
959693909B9B9A909B8A989091919395979390919B909392
938F92919591919890969495968F96999B70A4AD93919291
959295929393939694969993948F9092919F969285AA91A5
977CA4948A959448
478F908F9B8E9B95948D9A8E909B9194928C8A9D96939595
9D839A9B868E909390989698978F95A0959598919B8E9490
9293948E948D9B8F93919A96959A8E9191948F9693939494
949597918F96959493929292919592939A937A879C959695
97919692949693998F9890928D988A9CA39A7F95799C928F
9694A68890968D47
469895979691958E98979897988E98929493938E98989797
9BA18790D98395929A959494919F9B929697999A99959196
9394959099929A98999A989199999A9A9393958A93929194
8A948B8F978E8D8C949393969696988E979E917A9C968D86
8C9295929094968E909896908D89AC969D8B8C9AB19790A7
8996A78D90989446
498E9A909392999793938D93959A90979192998E968B9190
8C8C938A77B0928B92969192998D988D8F908B8C919B9594
919595969090909A928A99949395939B98A29E9FA49B9E9D
9DA39E9E9D9FA0A09E9EA2939A9698989A9D98B08A8AA8C2
997F928E939691928C7A7C79AEA2939497A38F9195979A81
959E8E9093929847
3E97909991918F95949A959697978F989B909A9097919598
909695978B7F9AB376909F9092929A989D97969592999692
988E9491959893979596978F9990918F9689909091989095
93938E96978D928E91948C8E9F8E908F978C97959A918880
81FF879F89858B8091B2AFAEA0898B889D9597988889AF8B
88B6859D8F938D48
4B978F99949B9893948D9A94909097949490979098919A95
94978D9794859DAC929C94889394918D97969392919A9691
949797939492919397968F939394949492989D8D8F8F8F97
9692948C8C959695969094949190999098919090919D9395
867C79A4B8B185A0A7899C99899C8098A76D97938DAD8484
A884AD889A95993F
3E98998E988F8F9B97998E98919A8E999698909A90939290
97959897928C9D80B18C8FA6788B998F9E90929B90939791
9495949791999095919899939494949494928F9D95989290
8E9993959B958F8D9C919494929798909A8E9C9294919099
9797867B6966BFA9899B978D9699A9959A76B39B83A9938B
AA80939293959840
4A8F8F989790999090909A91919698919393909797939297
96949196958B9E959AA57DA4BE768895948E959096999691
949495969096969594929192929393939494929594968F98
978C969892949598969093928F9D90929695969090979591
8D969A92AAB491949D9C8599949E89949F849B968BA6819B
9992938F9E8D9046
3F96999396909B909D90998F9A8E9A929291999491919B8F
9698978D958F968579AA8C9694C95E93899C9C9592939690
949494949394949494939A98979990999194939896939494
97979692949392959397909B979690929797949592998C9A
91998FA5A59489908C96A38D9B8B8E948497A896A28E9299
9B8996929394954A
48948E94999190909790969A8E9B8F91999894988F9D8E96
988E9694988DA57F93AB9F91979AD46591988A95919A9499
939494939B9193949492918F978C9695999394918E9A9891
9292929992949792949A8D978D969A908D908E8E908C948D
947D91A88F8B9C93879BA09E81A0879F969D87919F77B09B
85938E9A93998F45
45979795988E9A969B9092919A8F99998F998F95988D9997
8D988F9494929D8B9A7BA7869095A4CA5B90919C8F919B8D
939392929099989192989797949B95948F92919996919297
929A909191978E9D8E93939493939093939E979A9E999286
8BAAB78F808BB6939B858A87A49B9B998C9E8E9D70A59794
9095989294979147
498D95998F98979690969791969095909096919797988F95
969893969294889782939B909796969ED255829F8C979295
8F989696988F97998F96968D959299959495998D94989994
9695959590979397999B958D9F89A38D9292988F908D9298
B499A291918F968A9188929382A19D8E97999195A19D968C
91A1979395999242
449B9092929C8E919298988F97949B969999919190959790
97959593939A92A47BB0968E9C988D8E99E858899A949893
97949494968F998F97959595979391979795989392939193
9590979A988D96948A988D96959B8C989392918B8A9C9599
9C9A8889979993909AA7A699A88A90959F8C939699818C9B
958D959092919243
4B8F979393919A989290949799948E91919197989595958F
95959396948E919B7BA3958B959D908D9D92EE6D988C9893
9593969596978F909694939494939394948F969195939695
949296929292949B97969C829B8E938D9A898A9BA989BD8A
8B918795958FA2889692918D9396919C8B93959C92989A96
95978F9892969B42
41909B8F98919290979499958F989B9598929097968E9799
969096969494949081A0929D9690929D9CA3B05692969296
94988E978D96969695939A9291969298929697949C929495
93979394979394989A848E9C989796909A919B83BA979995
B098929B9A998B9488869A967D95998D94949C90949E8B94
8E8F979790999042
429795979499909B9097989193978D98909695948E99978F
91978F9691938E8FA0969292A385978A9C9992C27A90968D
97978E9595949393949691939A95919595948F9D899F918D
91948F958CA29A95878DA79B909987889792A3A0799C878C
888A8E958F958DA39F979D90A1A88A9495998F968D94918F
989C919296969248
4290998E999598929299919494919995919A9398978E9897
9097969695988B9092A18A9B87899E90A09187CB7190958D
9796939995929895929195969296978E9895968A9D899B95
979595949C8E9E847CA6918A89909C99AC88969B9C888AA3
9390939396B57A9E80A372A0948392959896A58B93989490
9B90939199909342
429C8F99919292949298929494939698919095939B909790
98989190939683A6899B9D979E8B9F968D8793DF5E999497
919691979890969696949595919092968F93909A96989094
928D968E9AA08688A39B999594948FAB948D9E979598A1A1
918E8F9C9D928F9A9099A18F9BA592969E91819695948E90
9793929A959B9343
4292929B9292989299909993949491969696969690929790
998F92909493909F939491958AA4A3958C8D96BB64998991
9B9195918D969390909A8F90999796988C9B9293948E9995
93998FA294968F929690908E8EA897949C7E968E9BA27F94
929394978298949B9799989B86908DA18F9796909894959C
9193988F91909243
429993929398969292999194949399919797929298919695
95959598949189969A9699988E939A798DA496C8649992A3
9191909E9B929398969398949296958F9D8F9A9694949491
99939693A083949BA28C9A87A8858C919B998C91A18E9994
87AA92978B90889B9E85A09E8C979A918E8797919B929690
9393979A95999741
439393999291989292929993949393949393949298919694
8E96988F8C8F96A08990949486A8889996A78ECA65919290
929A8D8F998E979790939890979095959691909296998E98
938F919E8C919A9A8E9991AB908EA79898849291839B939B
9D8789A88D8E9AA58A879A91909D8D9091A2969291949692
9993939196969147
43939392979791989B91919493989394939391979291959A
959A8F95957BA7949A8BA9939B9F8B95929384C4649F8E97
8F959C8C979492939695919A978E94948F94929A92939492
8D9B929A848E959499969F898F9F9B99979890A2989F8C98
92A59785949E8D8D89A1969794968C9A928C919D93909893
9393949398909246
419898919695909190979B92919892939796979991989791
90958F998D919B8F9A939681A58E8B82A39C97BB659C919D
94929694909A919699909694929E999A9396939591999692
9790968D9E9B919D93918D918C8D92939C95937F937998A9
9E9C8BA38E8D938B9F96A288919F938E9D8F9D8B95919394
92999394919C9147
489292989597999A989292929B8F98919790989093929291
96989494839D94998D94A08D9D81A092A59F94C3629A908F
9196919A989594919694948F908C949296988E8F98948E9B
97949D8C9896A3899B8B7EA89EA697868E93969793A37E91
A18F9A8BAB898A9D9393A68F9C8298909598948F9A989393
9991939299919342
429493919790909092949394919A9791988F969099929799
968D998C8F9D8A999799919E988A9296968E93B57295989B
96969B9197949D98949C9691A094929C8D8EA192918D9993
908AA17F93AA88928F90A194BD8482AA8BA395928999809E
9288998E9E88A094A3A38E8F9293949E8F93989196969394
929C929991989342
429399909596999798919893949192919997949991929790
8F98918B9A9A93A18E9B9295978BA0959A9295C0719B9E8D
9D989D949896909692959FA28C9C939496978C8E9A96909A
949C988296A890829D989D978A988A8D9986AB8B968BA498
9E958F9A858C9D8B9D89A1A17E9F9A8C9C8E929392989394
9392949393989146
4892909B9B8F969192989793929B91998F98949792929795
9795928A9391949A948F9C7AA37EB7879793A3B0828B9092
8F8E8B989492979492908E8CA79B9893939A9B9D8C949A90
9698997FADA18F9295A1A577AB948791949D9890908D8D88
9A8C9CB6818A9F9E8D96967D938E93929496929891919292
9993939494929749
4098979090919891949393949196929198918F9B90988E96
95938B9C979695958FA8929F8693A68C8E99C4977E988998
94989690928E9994939693938D91A0A49590908CA3939092
91919C7DA0927DA394989078B190988E9C9F9994A28D9796
9489A7908D93929C7CACA08296A3919C8E98909A969A9797
9193999394939341
48909A92989A909A91939493979890989690969591979997
94908491979A8E97928993997BB09789A3CC8D748E8E998E
9C8B978F9496928D9A939890968F8F89A698959789988E92
9B8D9BB27BA86DB49BABAC7783A5947AA67EA2968C8F8C89
87BA889691A2968F97A97693A290909491919A9192919097
9792939493999343
419992939192929A969A939490979691979696979393928F
9494998C9F8F999BA395909290A9868ECE4E7A9194919295
91929A98968D9694918C8F9B968F939389A5A29A8F9A9395
928BA1AB67CE6B8F9F74B6AC74C4948FA6889199969D888E
93939E928E998D979A90879D9A90988F9A91979292979891
9798929494939343
419393929C92929291919391999397929196909394929295
948C998DA0949392938E96899D9B8FB9977A919C93979292
9390908D97949694929A9C8E92969193909C7CA999919791
949890A677978A84B7BE8E887E7E8B9386B089979296968F
859EA38DA59A858594A69F8C8C9393909891989297969192
9291989294929942
4A91989393929A91989892989494989098969A93929E8F95
8F939096978C9791A5919F7AB197A3BC6894929394958D9B
8B99998B958F9193928F8B99938F96929292938BAC948C9D
879C8BBA8F61D362A169C580BE76B08C96889585AF7DAC87
73ABA789938F9A969F9A8D90989298969098929297979198
9792979891999243
479197939493969791919291979790989191909293919599
8C9B839E90A08A97958F899F9B8BBF5E9293919291969193
918F8E908C9695938A969196929C95949191939384AAAC89
9F8FA09CA07991B461D272A7889888A89281B88A9C8E9798
A07A98B2998D9F92939284A29192988F9896919791919890
9893939299929442
429298939492989198979698929299919797989798928E94
9A8F979B9B939E979486AE93A5E457928F94989892929497
99959796949992979899919194919097939495928985929A
9390909799A37A85A06E9786C692829590A78FA0839D9792
887DAE918799A5939B7BA28A95949A919298909A98929698
9293949493949348
42989294929992949391979294949393979494909197918E
958E928D9C8C8EA38A8AA098A84F8892909296938E878B88
8F949998979594848F8A8E9E8F949198949793949B8F87A6
A08D94A39D9574A6C66FAC8291AEA67F969F809F839E82A1
9E839595989294989C88959095928E9891909B9093939891
9399929494939442
42979292999194949493979394939394929597999095909E
98819A9F919F889896A297A0D67395969797928783B2B6AC
AD9C9B9FA194ABA7A6AC8B8B97909490969294989093977A
AEA191A197968B749D987895868B96A69081AA9F9887AC85
9991879F7D9E9989969D93929997998E9996909893939199
9391999392989342
4198919990999294939298929297999191969191998C928E
80979298949193A183919EBC4E909694968F89A7A092985E
7292917C6891828A9096A8888D9893919997919394989394
80A1A897A677E4696DCC6FBB8286A7977BB883958F949597
948F80A5AB9793A47E9291919B8D919A9597929891989892
9399929398979248
489199919890999197979197969595979598929199899D92
9E9D9688A7919B78B396B49C7D939095938A75A181818DA0
9A9583A0959B919B658A80A976879194928E94979690978F
8E7FA67FAC9C87878CA39575AC8B68AEB08D88A99C8A958B
A28C8CA19A92A4A182968E999B8E93929292939299929394
9493949392929442
4192929297979097959791979596909095959096948B9790
9A899695A18994AE8BAFBA638E9399958BB4ABABC0B3A894
A8A9A2A5A9B8AB9FCCB4BFCACAA48C949199958F9B94938B
9A8D8BB5A38495A8886ED66CB1928E70A382AF869B9391AF
8A8C91889A87A09D928D9991909B91929992999392949493
9494929992989343
47969792919798919790989198919897959695959193908E
99949FA58A97948F90B7508B9A938E9790967A9CA6A4B0A5
B2A893B1A9A2A3A2A67C7D7E7D8F91939994968F92999491
9090879EA5A9A19099757DB771B177966AC290919A8B91AC
84999082AD86A2838C949599929597979294939399939299
9293999292989343
40979792999292929891979292929391988E94988E899090
999D8790988E9C929ECB719A92949A90988F8D8679758082
6F8082756C78737B8385909295929594929496939690968F
9689898F92BA6DA5A8A487AE7EB0AA858D9C9492A2A48D87
89A78B85A298B6829293939B8F9391979394939292939991
9993939399929442
479192929292999293939892979892929597949193A4888E
9A999F948CAC8E93B869889293978E9A8E9B929690988C95
8C999496949E9A9897929895889A978F929693949691969F
948D948FAFA482976C9C65A6B27A998A8F7C88A29286A39D
A49B8684A481B278909D9292919493979292989798939294
9394939393949348
479198969698919B929493939891999297949691808C9F9D
A382A08EA4889294B9649198949198969195939595949594
939592938D98908F98909B8B9F889B989A978E95959A8B91
958D8B8F9587BE89A69BA98CA1869F997F87B08C9B8D9F87
AD8C988992A3A88D9090A989999393989299919293939893
9393989893949442
419991979792949299929494939492929197948BA0879A98
8EAC82A989AB8F8EDC679796949393929A9394949496928F
948B9B889798938F9695938D9B9D8D8A9691969196919892
9A9C8E889BAC9F90888C927B97A3A57BAD9F7189AA88B17E
978CA18593B4829190949795929494939392999394939891
9893939294949443
4293949393949394919893949393989797918E92969A879E
91839F8D8E908EB490829497929494958D95969494929890
999D9D9394989496929691988D90919D9596989698929793
8E8C98948C99849688A487A281AC8DC17477A7939E87A19C
958C9A878EB873AF7D958B93949494939893939494949298
9793939893949443
489394949493999198979392999393919A92978292989994
9E9392A0A18F88C6598F9494929496969694979393858699
9E8E9E8683949388939098939F92948F9C88929493949994
8F9F9089949AB9A08B9681AB809689BF63AE9D65A4968896
8C9BA3879498908F94AD8C94949494939893949494949493
9394939893949343
4193949393949299929292999194949493938E879797A0A1
91A88B968D8C9FD06498969A929B8E909594929A86B6CB85
8D958BCBC3A78EBF9491958E929394938D9C989892989096
9090929E8B94A3909A9197988C8CA67FAD947FA283A089B1
90A38F869F69B66DC47E9194949494949294949494939494
9494949293939942
4798929898939393939797919993949394939286A397967E
9A8EA2958E96A3AF6E9691928E969E8F9C9397938D898A93
948F94888289848AA89E938F94959492A08C899397939495
9890958B907EB59B9A979690A27FA287DB5AA2A673AE86A4
9A8D9B998D93A9B078909893949494939993939493999394
9494939897939343
4293949292929993929796929393929A929489869BA28FB3
958E9A9386A1B39B8293979B93929193929691998E9F8F93
8F948E969492969191999290959295948F9E9A9493959195
9E949495957ABB86AA828A82B3819C82CA72A18A76B2889F
919593928D8F9C9F89939893949494939293999394939494
9494949298939443
439493999299929298909792939B909798928A78A69F898A
9395928B88A1B355919093909394969495909A9D8E8E958B
9497928F939693929A9498919692989194928E9A92969194
91959494958F9CB29482C37BA07EAA928E95938A978EA382
9D96AD95879E908490949292939493989793939494949494
9494939493949443
4293949394929398979297989291989293927EA9A983AC9B
9C958F80AE8DD96195959C919495939494939095949B9196
918F8E9B9C99929D96988E9395928F989595938F95989492
91919A99928884ACA1927B959088A391AC94959B9076AF90
9D94908086C09E8899929897989394929893949494939494
9493989294949443
47989394929993939394939199919892939178AC989AA687
919189BA8DA4D26E9290939495959797979694919C939A8F
9B949A8E9D929597958D9595969692999295959098909791
988A938F968F8AB6809F8E9B979B829C9F8A949C956EA997
9D96A0989093829193949393939494949394949493999394
9493979893949343
4191939399929494949492989099919796946BA19C99958E
9B947D95A1D56A849993959596968D8F8D96939390959D90
8E96989C9498909394938F9996988D94979796929B999297
969A8E999D947EAAB88CB1878BA49486A39A8696986EBB74
B07FB17D8EA8889494949494949494939494939394939394
9394939394939942
4697979393949494949298969792939797827DA5919E8D90
928DA7A1D0487E99918C97988E9797989895959595909692
91988F94999196979691998E8D9C909D8A949196918F9691
9395958597998890998F869E82A08A97ACA07E99947C9A91
AF8DA693908C909494949494949493999393989893939991
9993949394949343
469098939494949493999291979394939270CBA38FB2869E
9885A786CB67999093979990909795958C97969695929B92
938C9097999191939896938E998F938C9A95959195919795
968E9A8C9891969693929E899B8A929C8B948D969C8C9A99
B78E8C9A908B949494949494949494939494929293949299
9294939993949443
47929294939494949393949398939493996BB3929EA48090
949292C4907E949295968E8F9993959494968D8D96959291
939C9299989A90968D9491969691929B9A8C929295948F91
9B93939096989A90A59C96919B8D918DAB7C9392969179A0
8F979F988291949494949494949494949493999299939393
9494949394949443
419399929893939398939494939494938E61B3839799A48D
89A797C0688C989394959798959593929890949595938FA0
91928A989797929096909592949890978C94989595939496
8D9697948C9590979297929F8D97909EBC6C929F8E9474B7
899DA59C8492949494949494949494949494939492939993
9494949494949443
489393929892989298939494949493987D9BC0969B8C918E
9D9EB657809C8E959695968C96938F929799939690919C93
93958F909896959A8CA692929A8B94919196969395949198
8F9A91909A8C9A9290A68A989C7E9B93A6809D8E84C252CE
938698A87E94949394949494949494949494949398939394
9494949494949443
429493989293989293949493939392986EBC7A8EB17AA688
A794D1748E9C90968C969593919690A38F8E9396958D9593
91958F8E9D909B91998D91948C9891988F8E8C8F8E8F938D
9F8B96948C93909B8FA5A18E93938C99A87C969374D463AD
A49591958694939993949494939494949494949398939494
9394949494949443
4394939893949299939393979797989366EC6CA8819A898B
B98D6C79A2938F95969491948E8884829B98909097929C99
92958D9E959C8C979C998F8F958D928A91939D939C939692
8F8C959398929A899389B5989C889883B38280A87FD0539F
B484948F8C95949394949493999394949494949493949493
9993949494949443
429494939493949293999298929393914EBE85A4909A80C1
86D65DB49E8B8F94948F8C8391B1B58482A28A987D8E9598
90948F8F989A9C9A79856F9094A1929C9B8B8E9292878C9B
9897929390948BA197929294A08B9C8FA78D949A8BBB57B6
BA81AA948396949494949494939494949494949394949494
9394949494949443
4893949493999299939394929494947DB4A58FAC8BA27FAC
916087A69F8A99918D8E8BB8B38671B9A79688A2B3828E9A
8F948E94909E869E7BDDB1B0A25EA5BC9099A5A19D8A9293
9391988E98919B8F8F9A759BA1879892938F829D85C753AD
A17EA2879295949494949494949494949394939992949494
9494949494949443
4294949494939493939493999394957BD479907FB48B82A9
E45A988E998A8C92908AA48B725DC3A3A08B94799B87A395
9092979295959CA0956AD55A4DC59E8F71B96890A0998794
8F9194948998958D9B9296B1A17C85B092888DA88DAC61CE
7D88AD7D9494949494949494949494939993949299939494
9494949494949443
4394949494949493999394939494916E54AAB19AAF8B9693
AE629AA39692928E959692DF80609528F874C69F9EAA9290
909293949489A193B08B76CF59CC1AF572AD49DAA391979A
8D938E9D908C8D9A9887AA9E9DAD82A3809D908E8AB264CD
8A9C9A869494949494949494949494949394949493949494
9394949494949443
43949494939494949294949494947AD277A087959A909495
9378A398978D8C9C9D99CB919ABFCDBB8B8BA49D9C8E948F
989194959694929B93A7AA8284CFD3A0A893B691AF9297A2
999490959B8FA3968C978DA3878C9A9B90909BA48BAA6CB6
8DA4808E9494949494949494949494949494949494949493
9993949494949443
439494939993949399939494939475E58F759FA17C909BAD
8D829695958B9892918D91AAB0B3A8ADBBA6918587899793
91929599938C8F8E8C8D93C69D838196AFBBB7988999A095
91919C8D8F999C9497878B9E8F9FA29E878C92A1929876B4
96AA88929494949494949494949494949494949494949494
9394949494949343
43949394939394949394949299948D699A979E989799A982
8895919F9A8E8E93898C897C7F7B75665C638A959E978C99
95959194949496A2889073717A9D9A948A7F7D8A8A898890
8B8C929A8C8AA18C93A7909E918087A98C779CA28B9979B5
9E7D80969494949494949494949494949494949494949494
9494949494939942
43939993939993949494939992958A57E282AB96A670B89D
99888EA29581A18D8E91918E866E879FABBDCB8B928C9595
8D97939397889790A8B6A0A09468797D848F8D92928E918D
95A88A9197929096907C9F999C8EB8949F8F97A4859B6CB7
9F8492959494949494949494949494949494949494949494
9494949494949343
43949394949394949494949294909950DE8CA7988C8D9C87
93908D999F8794938B81847D71B5B1BEC08F7F8C97968F99
8E97939392978E8D8D9DBFBFB6AF7D8575797B887C888595
B1869A95999B8F91AE94A4949BA6778F908A8EAD88A47B93
B27994949494949494949494949494949494939494949494
9494949494949443
4394949494949494949493989578CA2AB69C938EB1869C90
99A792979C8A82C3AFA0A2A6C8C19C7279888B9091929491
98959798959396928B7D7F8399B5D6BDC6AC9D9EA3AFB09E
8D96928E989A90A162C183858293AF86938998A68E829AC5
848794949494949494949494949494949493999393949494
9494949494949443
4394949493949494939493989380ABB6AD9C8A9697999A97
949795A28D8C8E8483A6AAB08F737F8E9293949494949591
989890918E9592949094908C8379767093B2B5ACAE928A97
978A8E8D999886A0AD818F8EA69EAC8B89AB8CA58386B5A3
7A8F94949494949494949494949494949494939399939494
9494949494949443
43949393999394929993949394837CA092AA7D8F9491A08C
95978DA294889793938481838C9790929494949394939592
998E939099979595959097938F97948E8E7C768186878F94
879A999D98908F859F99A2A49A9EB55EA6AC64AB9D6EB9A2
799494949494949494949494949494949494949493949494
9494949494949443
439399939394939992949494948392C29F9E7493A2939492
949B84A58C898F94969094978E909B989394939C93949492
989B919B998C969392928E9A919694949B8C9C92959B9498
939B8F899D968DA573909E8F967DB9648FB47E9AAD66C292
7B9694949494949494949494949494949494949494949494
9494949494949443
43949394949394939494949494897DC18193889A8A8D9498
98A195A1A48A9192959892949990909A9394949192949494
9292918F8E98949297969592909694938D97929496919691
928C8C9F9B8A94849EA68C899F9FBC619EAD759CB077D467
929594949494949494949494949494949494949394949494
9494949494949443
439494949399939494949494949264B6A19CA39794A29299
8FA48598968A999194969394969B9291929493999A929394
949299979795939D959593959895919B9494909398929590
A1939B8C9596949F919E7D9F9A9C9C9172997C9C97B98F7C
949494949494949494949494949494949494939993949494
9494949494949443
43949494949394949494949494965CDA809F90908A8F9592
A093988A9A91948F968F9294958F929A989192998F909C91
9290979495949390909693939795919A9998979394939791
8E9296988F8E938EA87FA4948A9BB3877BB08B9597CC8189
949494949494949494949494949494949494949394949494
9494949494949443
439494949494949494949494949765A3B19C8B8DA18D9D9B
7F99999594969095919699939599928F999992909B978E99
989793959394939A9297919A8D96948D95928E929792968F
9F929795899D8B8E94919596A2AE7D9A8E9C819979B87192
949494949494949494949494949494949494949494949494
9494949494949443
439493949394949494949494949664F8847B9E908F939682
B7958F8EA3959193949691949691929B909192998D969A8D
9595959395959393938D9D959296919E8B9A93999493988F
A089968E9D969FA480989EA480B97C9196AD889AA9818A94
949494949494949494949494949494949494949494949494
9494949494949443
439399929993949494949494949589679EA6969797988E9D
8B9D969490989193958E9396969090988F9B919899968D98
96959494949496938F9C92909896919E8D9A929794929093
99889B9A998C84889A8C9D9587B279968AA78A9AAC799394
949494949494949494949494949494949494949494949494
9494949494949443
4394939493949494949494949494955FD69F94A09296A192
9095899790959294909C9195949797969B9194928E99998D
97949494949494929D949491998C959291919397939C8E95
8A989A8C8EA192A3969E8FA591B86F9D99AB869299889394
949494949494949494949494949494949494949494949494
9494949494949443
4393949494949494949494949494958187A9958F9391919A
9E939A989992949490949095978C998F919294909A8D9599
8C97949694949492968E9498929795948F9B94989591988F
9E8F919B8F898C9F919D8C9F92AE747DAF989D977C919993
949494949494949494949494949494949494949494949494
9494949494949443
4299939494949494949494949494949062B6A99D97999390
A2948A92919B8B94999698939495959991998F9994959693
979694949496949196959790949594929892909096929599
8B9C8D9693978F9C9397998C87B58280A18F949789949394
949494949494949494949494949494949494949494949494
9494949494949443
4393949494949494949494949494949473CCA4AA9498A094
9692A58F8D8A99948E948F929395978E9098959596959595
9493959393929197969396939695948F969396969791948C
959691979293969E8F969A879AC48297A59798818F949494
949494949494949494949494949494949494949494949494
9494949494949443
43939494949494949494949394949494906193AD998D849B
9D938B9A98908E9499929998949495979694978D95959394
94939A91989696978D988E989594929C9291949B8A999489
A090998695979B839C8B9997ACA36C98998EAA7D99939494
949494949494949494949494949494949494949494949494
9494949494949443
42999394949494949494939993949494968C7864BA8F9F8B
939C9A8B99978C919690948F909892959494939595939593
929291919694948C92989694949591929896938F949E8DA1
8F8B93A1A08C9D9C8E9D86A0D36789A896AC8D8892939494
949494949494949494949494949494949494949494949494
9494949494949443
43939494949494949494949394949494959698709AAE8CAB
90A094969293919E929890989995979194929A9394939A90
9A9798949492969A9795949594948F99959490988F8F9783
979A9B95938F83AD918D9FC9468D9AA9928F868E989A9494
949494949494949494949494949494949494949494949494
9494949494949443
439494949494949494949494949494949494977F6BDA956E
AA85999497928F8F92969890938F95999098909292929196
948C919A8C9A8D96949594949592988E969197948FA38C90
94918F8A95A3995FB4AAAB73AF87A19D9A9386939A899694
949494949494949494949494949494949494949494949494
9494949494949443
439494949494949494949494949494949494977C979D9D9F
968397928E8B9B938F9493939C8C98919393969697968D98
9498938E9E8F969593919290908C98958F96928E8D9A9299
9D979C9A90908AAD7F9690B3789C90998FAD878B94969596
959494949494949494949494949494949596959494949494
9494949494949443
4394949494949494949494949494949494949679BB7DB58F
9CA1979495A08E94958D9F8F93939298989591938A9A9297
938E989795998D8D92978F9596939992939892969C909591
9A8A8BA1989D9CA193C0699594AF7FAA927792959A95968C
96949494949494949494949394949494968C969494949494
9494949494949443
439494949494949494949494949494949494958D8B5FDCA6
7AAA8D8F9687919A9494978F9499978F9593949395928F8B
92959692928E8D97949291998F89978A938B958D929B948A
8E92A19396A07A91A6897B9C958F8F86AE8B9394958B9696
959494949494949494949399939494949596959494949494
9494949494949443
43949494949494949494949494949494949494937DB498A1
9B88A19AA0928D7D9897979F909192929295929192989B9A
96919692979797999095918E9A949696919E9A8D979896A6
AA928CA48B89AE8482989BA787AD8C9B7F8F949495969493
949494949494949494949493949494949596959494949494
9494949494949443
4394949494949494949494949494949494949494906F9EB6
AE9A918D879D9AA7939B948E929894928D9A95A097849C94
938B9F8CA18E9F7EA987A38C9F9D8F97959390A0877C9382
8E87A099897997BDA985889CA1888FAE8594949394949399
93949494949494949494949494939494968C969494949494
9494949494949443
439494949494949394939494949494949494949494917B60
9A94B29595C0969787848B8E968F97959E9392919795918D
9E949994969495AD9292A4A983AA8BA69B979A92AAA09E95
99959487ACA38E868D97AB987F8AC2729194949B94949493
949494949494949494949494939993949596959494949494
9494949494949443
439493949494939992999394949494949494949494949476
C8978B9989717E9989A59B928F979296928CA09588959B8F
9398968CA978A27D949B7E93AC799A8293988F7DA4918182
958F7E9984918DA3A1A18384959791889494968B96949494
949494949494949494949494949394949494949494949494
9494949494949443
439399939494949394939494949494949494949494949491
54E0949BACA2A0A6A38F919796968B9B9692A1939E909D8D
9B8098A18DAC7F9C7DA496959670AF9591778D9A8B9EA0B1
A893A79E9EA6AA9C8F8964A37FD772939494959695949394
949494949494949494949494949494949494949494949494
9494949494949443
439493949494949494949494949494949494949494949495
9153A798927682858391938DA096958F9A8D928B9A9C8698
9E92B48884A4BF7BBB7A8F8D85AC8C72B6B0919A9A978A8A
809291AB99A866A18A6AD983BC867E969494939494929993
949494949494949494949494939495969594949494949494
9494949494949443
439494949494949494949494949494949494949494949494
9581AD8FB3A3B2A48E8F968B9195909B9294959B938CA293
88B66792B0619EA679A29C90A1919BAF8E93819B9789949B
A8A1917E8D80A76C75ACA886D26D93949492999392999396
9594949596959494949494939993968C9694949494949494
9494949494949443
439494949494949494949494949494949494949494949494
949255F992649C9F9D8D8F9C8CAC959D888B91A28E919A84
997CB69290A8769D9A8F9A91949B908C8995A28D8E999D9C
92889BA2B49675B9A7A075BB74919893939992939992968C
969494968C96949494949494939495969594949494949494
9494949494949443
439494949494949494949494949494949494949494949494
94948D54C5DA6D7E87A5898F87A7829FA0959FA38C90A28E
A08AAB839B90A9A468A89D95928E9B939E9D8E9399937FA5
A893809D65748C8FB16CDC6C828A9A939492949694949596
959494959695949394949494949494949596959494949494
9494949494949443
439494949493949494949494949494949494949494949494
9493998F4EAED093929686878CA3AB79A0877F87A5848CAA
8788A492879386C3A4966AA090AF8A9EA2A79FAAB3A5A688
82A79B7693BB9B8F92C1A17B96969494959A948B96949495
96959494949493999496959494949494968C969494949494
9494949494949443
439494949399939494949494949494949494949494949494
94949394887ABEADAA89888976A3A29481A8A18A979E888C
9A9B8490A489928B8AA7B1899798909D779899958F8C9799
9561A08691C097948BBA6A92969494978B959A9495969596
8C96949494949493968C9694949596959596959494949494
9494949494949443
439494949493949494949494949494949494949494949494
94959695927A87A995A8B69AA762BDA094859D98A69CA094
9B95919BA18E8B9991AF72A2A083929EA1998F937F988C68
8F878B7FB98D839ED85A938E8F979C8AA08B9499958C9695
96959494949494949596959494968C969494949494949494
9494949494949443
439494949494949494949494949494949494949494949494
94968B969490739EB49092939D9275B4A68C84A375AC989A
858D84AC7EA087A19D89B2AEB19FA8929E99A0868475A4A0
91A7BFB68B8BA7B75A9297998F8D95978B97939395989795
949494949494949494949494949596959494949494949494
9494949494949443
439494949494949494949494949494949494949494949494
94949B94939A91728FD6A188848E9277B48CB785A3879AB2
A7AD8FA18DA88AA266767E947A908F946E6E84769BB28B92
9FA09A827FA6D05993958B969595949596939993968D8D96
939494949494949494949494949494949494949494949494
9494949494949443
439494949494949494949494949494949494949494949494
9494939494958D937E5CC2A2B8977A8A83AA91A598B19173
A1CBAFD1B59C939DC79094938F7873839D9F949D9C8F8FB0
AC8E9582C5BC6291939A9594989793949399919495989793
989394939496959494949494949494949494949494949494
9494949494949443
439494949494949494949494949494949494949596959494
9494949494978F97948F53CCC48F9E8C749597829E748AAA
736C57617284869880928C8A8294BF899A9F958DA79BBB8C
83919FD74F7B91899B9294949298939394929993968C9693
98939399958C969494949494949596959596949394949494
9494949494949443
43949494949494949494949494949494949494968C969494
9494949596978F999596906F64DFAE929889847F8B929291
8BA4A69DA2908B8C96869DAD7D9E8B7EAC8EA6A497967B7F
9BB9A8668F99929B93969596949392999394939495969594
95949493949695959695949495988C96968C979A93949494
9494949494949443
439494949494949494949494949494949494949596959494
949494968C988F8E988C96947C68C7BBAB7D909699978F91
9190818C8D8E808883947F9DA77BA8A2A88ABF93898899BF
B27A7A9093999594968C988B96949B939695949493949696
8C969495969594968C969494968C9895979A8E9494949494
9495969594949443
439494949494949494949494949494949494959695949494
94949495969596969595959A9685785DBED2CB8C84828A8E
96A3929D9DA1AAAFB3998F9EA4C5AA8DA87B7E859ACBAE6D
7B8B949694958B969598959B94968B978B96949399958C97
989696998E99969596959495969695968F928F9D94949494
94968C9694949443
439494949494949494949494949494949494958B96949494
9494949494949494939B8A95968D96907C7163C6C6999B9C
8088908F9089A093A7A1B69471A376747FAAC0A1826F7C88
9694968C96959694968B9593949495949B94949493949596
8C988D8F918F8C96969494968C9694958F909A8B95949494
9495969594949443
4394949494949494949494949494949494939A9795949494
949494949494949494949695949594968D97867F6ABAB99A
C1A89BA1939A817375828A829184B3C1AA947F809191919E
969797969594939992949A93949399939294969494939A95
9695969797969C958B9D94969695939A959695959C949494
9494949596959443
439494949494949494949494949494949494958B95949494
949494949494949596949494939992968C9B9A9491808184
828E8E9D8B92A9B4B2A1A1A7A5A1847D808A919496909198
8D8F8D95949694939A999294969595949B95899B9393958B
9694949494949394978A978C98959493949695968B969494
949494968C969443
43949494949494949494949494949494949495959A939494
94949494949494968B9B9394949199939595939494939293
8993918E918E8C87878D808987888F93968D8D9696998F97
9697959B968E98968A9594968C988C988C949A9292999496
9594949495969594949B94988E969494958C989796959494
9494949598959343
439494949494949494949494949494949494949494969594
949494949494949596949494939993959D8B96949299939C
95968B9D9494959393958C9693999394949597988C998F99
95939B88988F8D9798959495969796978C9A979299929496
94949494968D9695969494958D9694939A978D8F96949494
949494968C959B43
4394949494949494949494949494949495969594958B9693
9494949494949494949494949694968D8C9795939992978A
9695988D96968C9894939B93939394949399958C98978F8F
9694929B96969C958B989695968B9895969393969494968C
9C939596978E98968C98959A9596959493929D8D96949494
9495969596968B45
43949494949494949494949494949494968C96939A95959A
93949494949494949494939B8B9695959C949494929A8A9D
9496968D9895988C959B93959A939494949393969695988E
969399948B9693939D8C8C96949D8B969494978B9895978F
9694958B96988C96988E8D95968C96939399939695949494
94958D9694959644
439494949494949494949494949494949596959495968B95
949494949494949494949393969594949394949493989393
968B9B968E989596988A978B95949596949298958C989496
969595959696959694959C9494959695939B8A9E8B98978D
97959A959596979695979894949694999395949596959494
939C8C9694949342
43949494949494949494949494949494949494968C979895
949494949494949494939A95959493949394949493979995
9596939B8E8E96958C9D94969594968C95989793978B9D96
8D988C96958D988D96949393968C96949494959A988B9596
968B9494968C988D96968B9B93949495968C96968C969494
9494969493939A48
439494949494949494949494949494949494949596968B95
94949494949494949496958B95939991989394959695958B
969394949696939B8C97949496959596949395949C978A99
8D9696939B8CA08D9693939A95969694939493978C9E9993
94949A939596978D969596949494968C9695949596959494
9494949399958A44
43949494949494949494949494949494949494949495959A
93949494949494939B8B96959C949498979596968D8F9796
9499939494949B95988C959C8C96949494968C998B959D8B
979C959C95988B98939893978B9D8B979C959D8B998B9594
949B94949494949594949494949596969499949695949495
9695969494969644
439494949494949494949494949494949495969596959492
9493949494949596949695968B978A93998B8C959D8D9694
9493939494968C8D979895958D97969494979A8D98949496
968C8F8E8D9798959398958C9794988D8E8F8D9996989594
958C8F969495959A9394949494968B959492968C96949496
8C988C96968C9643
4394949494949494949494949494949494968D988C989499
929993949494968C9694949495949B9299949C9595989594
9493999394959697998E969596958A9C978F8E9895949494
9596979797998E98949394959A9395969797998E9A8E9693
9A978E9694968B9594949494959695999298939696959596
9595969595969543
0043434343434343434343434343434343453C46473B4542
434243434343444544434342484242434243443A473A4543
43434243434343453D3E4543424944443C3E474443434343
43434343453D403D45434343424343434343453E3F3E4543
424345444344454443434343453A4447414742453A454539
4A42434343434300
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[42]:=",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`003@3oool200@41080AdM70P10@40203lo?`80B4Q80P16ATH404U9B@80
?Cdm0P1;Bd/203lo?`80Fe]K0P1@D50404m?C`<0B4Q80P1?Cdl604i>CP80De=C0P0f=SH2034a<@80
T92@0P16ATH204U9B@80De=C0P1@D50205QHF080CDe=0P1<C4`205MGE`80CDe=0P1?Cdl2055AD@80
CTi>0P1HF5P205MGE`80CDe=0P1BDU8204e=C@80C4a<0P1ADE44051@D080CTi>0P1?Cdl304e=C@80
G5aL0P1<C4`204m?C`80DU9B0P19BDT204];B`@0C4a<101;Bd/204a<C080Cdm?0P19BDT205ADE080
DE5A0P1>CTh204Q8B080DU9B0P1@D502055AD@@0D51@0P1ADE42051@D0@0DE5A101@D50205=CD`80
Cdm?0P1>CTh3055AD@@0D51@0P1EEED20492@P80>c/k0P0n?Sh207moO`80@D510P1DE5@204m?C`80
CTi>0P1EEED205=CD`80E5AD0P1>CTh204m?C`80DE5A101BDU8205ADE080C4a<0P1=CDd2059BDP80
Cdm?0P16ATH204m?C`80B4Q80P19BDT204Q8B080De=C0P16ATH304i>CP80DU9B0P1?Cdl205YJFP80
F5QH0P1BDU8205=CD`80EUIF0P1WIfL204A4A080>c/k0P1[Jf/204];B`@0@d=30P0n?Sh200D51@l0
oooo000=0?ooo`8010@40P17AdL20410@080?clo0P18B4P204I6AP@0BDU90P0m?Cd204];B`80?clo
0P1KFe/2051@D0@0Cdm?0`18B4P204m?C`H0CTi>0P1CDe<203Hf=P80<C4a0P2@T90204I6AP80BDU9
0P1CDe<2051@D080F5QH0P1=CDd204a<C080EeMG0P1=CDd204m?C`80DE5A0P1>CTh205QHF080EeMG
0P1=CDd2059BDP80CDe=0P1<C4`2055AD@@0D51@0P1>CTh204m?C`<0CDe=0P1LG5`204a<C080Cdm?
0P1BDU8204U9B@80Bd];101<C4`404];B`80C4a<0P1?Cdl204U9B@80E5AD0P1ADE4204i>CP80B4Q8
0P1BDU82051@D080DE5A101@D502055AD@80D51@101ADE44051@D080De=C0P1?Cdl204i>CP<0DE5A
101@D50205EEE@80@T920P0k>c/203hn?P80Ogmo0P11@D4205ADE080Cdm?0P1>CTh205EEE@80De=C
0P1DE5@204i>CP80Cdm?0P1ADE44059BDP80E5AD0P1<C4`204e=C@80DU9B0P1?Cdl204I6AP80Cdm?
0P18B4P204U9B@80B4Q80P1CDe<204I6AP<0CTi>0P1BDU8204m?C`80FUYJ0P1HF5P2059BDP80De=C
0P1FEUH206MWI`80A4A40P0k>c/206][J`80Bd];1013@d<203hn?P801@D53`3oool000d0oooo0P16
ATH209:BTP80Ti>C0P2IVIT209FEU@@0SXj>0P2FUYH209NGU`80SHf=0P2EUID208b<S080XJ6Q0P2F
UYH209BDU0<0UIFE1P2DU9@409FEU@80XJ6Q0P1lO7`20;Bd]080OWin0P2;Rh/209JFUP80U9BD0P2@
T90209NGU`80UYJF0P2GUiL209VIV@80Ti>C0P2DU9@209FEU@@0TI6A0P2IVIT2096AT@80T92@0P2H
V9P209FEU@80U9BD0P2@T90209fMW@80UYJF0`2?Shl208b<S080V9RH0P2?Shl209:BTP80UiNG0P2H
V9P209>CT`80UIFE0P2HV9P209VIV@80SXj>102HV9P208b<S0@0UiNG0P2IVIT409NGU`80TY:B0P2G
UiL609FEU@P0U9BD0P2CTi<209FEU@80WIfM0`2BTY8209BDU0@0UIFE0P2PX:0208n?S`80MWIf0P2]
[Jd20<C4a080Ng]k0P2?Shl2092@T080UiNG1P2FUYH209RHV0H0TI6A0P2EUID209:BTP80VYZJ0P2A
TI4209ZJVP80UIFE102FUYH209RHV080VYZJ0P2?Shl209RHV0<0TI6A0P2HV9P209>CT`80TY:B0P2@
T90209RHV0@0VYZJ0P20P80208J6QP80ZJVY0P2FUYH20:6QX@80RXZ:0P2@T90209RHV080ATI63`3o
ool000d0oooo0P16ATH209:BTP80Ti>C0P2IVIT209FEU@@0SXj>0P2FUYH209NGU`80SHf=0P2EUID2
08b<S080XJ6Q0P2FUYH209BDU0<0UIFE1P2DU9@409FEU@80XJ6Q0P1lO7`20;Bd]080OWin0P2;Rh/2
09JFUP80U9BD0P2@T90209NGU`80UYJF0P2GUiL209VIV@80Ti>C0P2DU9@209FEU@@0TI6A0P2IVIT2
096AT@80T92@0P2HV9P209FEU@80U9BD0P2@T90209fMW@80UYJF0`2?Shl208b<S080V9RH0P2?Shl2
09:BTP80UiNG0P2HV9P209>CT`80UIFE0P2HV9P209VIV@80SXj>102HV9P208b<S0@0UiNG0P2IVIT4
09NGU`80TY:B0P2GUiL609FEU@P0U9BD0P2CTi<209FEU@80WIfM0`2BTY8209BDU0@0UIFE0P2PX:02
08n?S`80MWIf0P2][Jd20<C4a080Ng]k0P2?Shl2092@T080UiNG1P2FUYH209RHV0H0TI6A0P2EUID2
09:BTP80VYZJ0P2ATI4209ZJVP80UIFE102FUYH209RHV080VYZJ0P2?Shl209RHV0<0TI6A0P2HV9P2
09>CT`80TY:B0P2@T90209RHV0@0VYZJ0P20P80208J6QP80ZJVY0P2FUYH20:6QX@80RXZ:0P2@T902
09RHV080ATI63`3oool000d0oooo0P17AdL209JFUP80UiNG0P2EUID209JFUP@0V9RH0P2DU9@209NG
U`80VIVI0P2?Shl208f=S@80QXJ60P2RXZ8209bLW0<0UiNG0P2CTi<209NGU`80Ti>C0P2ATI4209RH
V080UYJF0P2;Rh/206i^KP80iNGU0P25QHD2096AT@80Ti>C0P2HV9P209^KV`80UIFE0P2>SXh2092@
T080TY:B0P2CTi<209FEU@80U9BD0P2BTY8209NGU`80WYjN0P2>SXh2092@T080UIFE0P2CTi<209RH
V080U9BD0P2FUYH309FEU@80Vi^K0P2HV9P209ZJVP80U9BD0P2ATI4209BDU080UYJF0P2@T90409FE
U@80UYJF0P2DU9@209FEU@80UYJF0P2HV9P209BDU0@0TI6A0P2EUID209RHV080Shn?0P2HV9P209JF
UP80UiNG0P2FUYH209FEU@80U9BD0P2EUID209BDU080UIFE0P2BTY8909BDU080UIFE0P2MWId209^K
V`80LW9b0P1eMGD20=SHf080QHF50P2FUYH209VIV@80T92@0P2BTY8209VIV@80VYZJ0P2ATI4409bL
W080U9BD0P2ATI4609>CT`80U9BD0P2EUID209NGU`80TY:B0P2ATI4209:BTP80UYJF1@2DU9@209NG
U`80U9BD0P2GUiL209^KV`80Ti>C0P2@T90209jNWP80Q8B40P2?Shl209bLW080WIfM0P2EUID209:B
TP80Rh^;0P16ATH?0?ooo`003@3oool204M7A`80UYJF0P2GUiL209FEU@80UYJF102HV9P209BDU080
UiNG0P2IVIT208n?S`80SHf=0P26QXH20::RXP80W9bL0`2GUiL209>CT`80UiNG0P2CTi<2096AT@80
V9RH0P2FUYH208^;R`80KVi^0P3UiND208F5Q@80TI6A0P2CTi<209RHV080Vi^K0P2EUID208j>SP80
T92@0P2BTY8209>CT`80UIFE0P2DU9@209:BTP80UiNG0P2NWYh208j>SP80T92@0P2EUID209>CT`80
V9RH0P2DU9@209JFUP<0UIFE0P2KVi/209RHV080VYZJ0P2DU9@2096AT@80U9BD0P2FUYH2092@T0@0
UIFE0P2FUYH209BDU080UIFE0P2FUYH209RHV080U9BD102ATI4209FEU@80V9RH0P2?Shl209RHV080
UYJF0P2GUiL209JFUP80UIFE0P2DU9@209FEU@80U9BD0P2EUID209:BTPT0U9BD0P2EUID209fMW@80
Vi^K0P1bLW8207EeM@80f=SH0P25QHD209JFUP80VIVI0P2@T90209:BTP80VIVI0P2JVYX2096AT@@0
W9bL0P2DU9@2096AT@H0Ti>C0P2DU9@209FEU@80UiNG0P2BTY82096AT@80TY:B0P2FUYH509BDU080
UiNG0P2DU9@209NGU`80Vi^K0P2CTi<2092@T080WYjN0P24Q8@208n?S`80W9bL0P2MWId209FEU@80
TY:B0P2;Rh/204I6APl0oooo000=0?ooo`80A4A40P2EUID209>CT`80SXj>0P2IVIT208n?S`80SXj>
0P2JVYX2092@T080TI6A102IVIT209BDU080TI6A0P29RHT309RHV080WYjN0P2BTY8209VIV@80UiNG
0P2FUYH209NGU`80Y:BT0P24Q8@20861P@80YjNW0P2ATI4209FEU@80TI6A0P2EUID209BDU080UiNG
102IVIT2096AT@80Ti>C0P2DU9@209>CT`@0VIVI0P2DU9@209FEU@80Ti>C0P2@T90209RHV080SXj>
0P2HV9P309bLW080UIFE0P2DU9@209RHV080VIVI0P2FUYH2096AT@80U9BD0P2BTY82092@T080TY:B
0P2CTi<409FEU@80UYJF0P2BTY8208Z:RP80UIFE0P2BTY8209>CT`80SXj>0P2FUYH2092@T080UIFE
0P2@T90208n?S`80UiNG1P2EUID209BDU0L0UIFE0P2FUYH609FEU@80VIVI0P2MWId207alO080M7Ad
0P36a/H20861P@80TI6A102EUID209BDU080SHf=0P2DU9@409:BTP80UiNG0P2BTY8209ZJVP80TY:B
0P2IVIT209BDU080UYJF0P2@T90209BDU080Ti>C0P2JVYX208f=S@<0VYZJ0P2EUID209RHV080TY:B
0P2UYJD208:2PP80VYZJ0P2MWId208F5Q@80/[:b0P27QhL209FEU@80XJ6Q0P28R8P209VIV@80W9bL
0P14A4@?0?ooo`003@3oool204A4A080UIFE0P2CTi<208j>SP80VIVI0P2?Shl208j>SP80VYZJ0P2@
T902096AT@@0VIVI0P2DU9@2096AT@80RHV90`2HV9P209jNWP80TY:B0P2IVIT209NGU`80UYJF0P2G
UiL20:BTY080Q8B40P21PH420:NWY`80TI6A0P2EUID2096AT@80UIFE0P2DU9@209NGU`@0VIVI0P2A
TI4209>CT`80U9BD0P2CTi<409VIV@80U9BD0P2EUID209>CT`80T92@0P2HV9P208j>SP80V9RH0`2L
W9`209FEU@80U9BD0P2HV9P209VIV@80UYJF0P2ATI4209BDU080TY:B0P2@T90209:BTP80Ti>C102E
UID209JFUP80TY:B0P2:RXX209FEU@80TY:B0P2CTi<208j>SP80UYJF0P2@T90209FEU@80T92@0P2?
Shl209NGU`H0UIFE0P2DU9@709FEU@80UYJF1P2EUID209VIV@80WIfM0P1lO7`207AdM080a/K60P21
PH42096AT@@0UIFE0P2DU9@208f=S@80U9BD102BTY8209NGU`80TY:B0P2JVYX209:BTP80VIVI0P2D
U9@209JFUP80T92@0P2DU9@209>CT`80VYZJ0P2=SHd309ZJVP80UIFE0P2HV9P209:BTP80YJFU0P22
PX8209ZJVP80WIfM0P25QHD20;:b/P80QhN70P2EUID20:6QX@80R8R80P2IVIT209bLW080A4A43`3o
ool000d0oooo0P16ATH209:BTP80UYJF0P2EUID208n?S`80UYJF0P2EUID209RHV080T92@0P2BTY82
096AT@80SXj>0P2IVIT208j>SP80UYJF0`2;Rh/409ZJVP80T92@0P2IVIT2096AT@80VIVI0P2EUID2
08R8R080PX:20P2e]KD2092@T080UIFE0P2?Shl209ZJVP@0UYJF0P2<S8`209RHV080VYZJ0P2CTi<2
09FEU@80TI6A0P2@T90209:BTP80TI6A0P2@T90209RHV0@0UYJF102BTY83092@T080TI6A0P2@T902
09BDU080Vi^K0P2DU9@209JFUP80S8b<0P2KVi/209VIV@80WIfM0P2ATI4209>CT`@0U9BD0P2FUYH2
09ZJVP80Shn?0P2JVYX209fMW@80SXj>0P2<S8`209bLW080T92@0P2IVIT2096AT@80UIFE0P2HV9P4
09:BTP80UiNG0P2FUYH3096AT@80TY:B0P2@T90209NGU`80SXj>102FUYH209VIV@80WIfM0P1cLg<2
0:j^[P80X:2P0P2=SHd208n?S`80Ti>C0P2BTY8209RHV080UIFE0P2GUiL209:BTP80Ti>C0P2EUID2
09BDU080TY:B0P2DU9@209FEU@80U9BD0P2@T90409BDU080TI6A0P2FUYH3096AT@80SHf=0P2HV9P2
09:BTP80Q8B40P2CTi<208Z:RP80Rh^;0P1oOgl209jNWP80Q8B40P2QXJ420:FUY@80Shn?0P2:RXX2
09BDU080AdM73`3oool000d0oooo0P16ATH209:BTP80UYJF0P2EUID208n?S`80UYJF0P2EUID209RH
V080T92@0P2BTY82096AT@80SXj>0P2IVIT208j>SP80UYJF0`2;Rh/409ZJVP80T92@0P2IVIT2096A
T@80VIVI0P2EUID208R8R080PX:20P2e]KD2092@T080UIFE0P2?Shl209ZJVP@0UYJF0P2<S8`209RH
V080VYZJ0P2CTi<209FEU@80TI6A0P2@T90209:BTP80TI6A0P2@T90209RHV0@0UYJF102BTY83092@
T080TI6A0P2@T90209BDU080Vi^K0P2DU9@209JFUP80S8b<0P2KVi/209VIV@80WIfM0P2ATI4209>C
T`@0U9BD0P2FUYH209ZJVP80Shn?0P2JVYX209fMW@80SXj>0P2<S8`209bLW080T92@0P2IVIT2096A
T@80UIFE0P2HV9P409:BTP80UiNG0P2FUYH3096AT@80TY:B0P2@T90209NGU`80SXj>102FUYH209VI
V@80WIfM0P1cLg<20:j^[P80X:2P0P2=SHd208n?S`80Ti>C0P2BTY8209RHV080UIFE0P2GUiL209:B
TP80Ti>C0P2EUID209BDU080TY:B0P2DU9@209FEU@80U9BD0P2@T90409BDU080TI6A0P2FUYH3096A
T@80SHf=0P2HV9P209:BTP80Q8B40P2CTi<208Z:RP80Rh^;0P1oOgl209jNWP80Q8B40P2QXJ420:FU
Y@80Shn?0P2:RXX209BDU080AdM73`3oool000d0oooo0P17AdL209BDU080VYZJ0P2DU9@409NGU`80
U9BD0P2>SXh209^KV`80UYJF0P2EUID209bLW0@0TI6A0P2GUiL308n?S`80SHf=0P2IVIT20:2PX080
U9BD102FUYH209RHV080XJ6Q0P29RHT208B4Q080WYjN102ATI4209NGU`80Ti>C102IVIT208j>SP80
TI6A0P2@T90208n?S`80V9RH0P2FUYH208^;R`80UIFE0P2KVi/2096AT@80TY:B0P2GUiL2096AT@80
UIFE0`2FUYH209FEU@80UYJF0P2CTi<2092@T0@0Vi^K0P2JVYX2092@T080Vi^K0P2:RXX209RHV080
T92@102ATI4209>CT`80UIFE0P2GUiL209>CT`80T92@0P2ATI4209^KV`80T92@0P2CTi<209:BTP80
Ti>C0P2?Shl209:BTP80TI6A0P2EUID4096AT@<0V9RH0P2@T90209JFUP80U9BD0P2EUID209JFUP80
Shn?0P2FUYH209VIV@80Vi^K0P1`L7020:BTY080[Jf]0P2CTi<2096AT@80TY:B0P2ATI4209FEU@80
TY:B0P2EUID209:BTPH0Ti>C0P2FUYH209BDU080UYJF0P2IVIT209>CT`80U9BD0P2?Shl2092@T0<0
TY:B0P2ATI4209nOW`80UYJF0P2BTY8208F5Q@80ZZZZ0P2ATI420:FUY@80UiNG0P1lO7`20:BTY080
U9BD0P2:RXX209FEU@80U9BD0P18B4P?0?ooo`003@3oool204M7A`80U9BD0P2JVYX209BDU0@0UiNG
0P2DU9@208j>SP80Vi^K0P2FUYH209FEU@80W9bL102ATI4209NGU`<0Shn?0P2=SHd209VIV@80X:2P
0P2DU9@409JFUP80V9RH0P2QXJ4208V9R@80Q8B40P2NWYh4096AT@80UiNG0P2CTi<409VIV@80SXj>
0P2ATI42092@T080Shn?0P2HV9P209JFUP80Rh^;0P2EUID209^KV`80TI6A0P2BTY8209NGU`80TI6A
0P2EUID309JFUP80UIFE0P2FUYH209>CT`80T92@102KVi/209ZJVP80T92@0P2KVi/208Z:RP80V9RH
0P2@T904096AT@80Ti>C0P2EUID209NGU`80Ti>C0P2@T902096AT@80Vi^K0P2@T90209>CT`80TY:B
0P2CTi<208n?S`80TY:B0P2ATI4209FEU@@0TI6A0`2HV9P2092@T080UYJF0P2DU9@209FEU@80UYJF
0P2?Shl209JFUP80VIVI0P2KVi/2071`L080Y:BT0P2][Jd209>CT`80TI6A0P2BTY82096AT@80UIFE
0P2BTY8209FEU@80TY:B1P2CTi<209JFUP80U9BD0P2FUYH209VIV@80Ti>C0P2DU9@208n?S`80T92@
0`2BTY82096AT@80WinO0P2FUYH209:BTP80QHF50P2ZZZX2096AT@80YJFU0P2GUiL207alO080Y:BT
0P2DU9@208Z:RP80UIFE0P2DU9@204Q8B0l0oooo000=0?ooo`80AdM70P2?Shl2092@T080Shn?0P2K
Vi/208j>SP80Vi^K0P2EUID209BDU080SHf=0P2JVYX208j>SP80T92@0P2KVi/2096AT@<0U9BD0P2B
TY8208b<S080RXZ:0P2MWId209JFUP80Ti>C102EUID209fMW@80Ph>30P2JVYX209^KV`80QXJ60P2>
SXh2092@T080Ti>C0P2@T90209RHV080UYJF0P2HV9P209NGU`80Shn?0P2EUID20:2PX0@0UIFE0P2H
V9P2096AT@80Vi^K0P2>SXh209BDU0<0T92@0P2BTY8209>CT`80U9BD0P2>SXh209BDU080SHf=0P2K
Vi/208n?S`80Ti>C0P2ATI4209ZJVP80UYJF0P2EUID209ZJVP80SXj>102ATI4209BDU080Shn?0P2F
UYH409>CT`H0U9BD0P2EUID209NGU`80TI6A0P2?Shl209JFUP80UIFE0`2DU9@209>CT`H0TY:B0P2A
TI4209FEU@80TY:B0P2CTi<209ZJVP80Ti>C0P1jNWX208N7Q`80W9bL0P2EUID209JFUP80UIFE0P2G
UiL2096AT@80UYJF0P2BTY8209BDU080UYJF0P2CTi<209VIV@80Shn?0P2HV9P2092@T080TY:B0P2=
SHd209RHV080RXZ:0`2LW9`20:>SX`80VYZJ0P1oOgl209FEU@80NGUi0P2LW9`209:BTP80Shn?0P2F
UYH209BDU080YZJV0P28R8P2092@T080UYJF0P2=SHd204M7A`l0oooo000=0?ooo`80AdM70P2?Shl2
092@T080Shn?0P2KVi/208j>SP80Vi^K0P2EUID209BDU080SHf=0P2JVYX208j>SP80T92@0P2KVi/2
096AT@<0U9BD0P2BTY8208b<S080RXZ:0P2MWId209JFUP80Ti>C102EUID209fMW@80Ph>30P2JVYX2
09^KV`80QXJ60P2>SXh2092@T080Ti>C0P2@T90209RHV080UYJF0P2HV9P209NGU`80Shn?0P2EUID2
0:2PX0@0UIFE0P2HV9P2096AT@80Vi^K0P2>SXh209BDU0<0T92@0P2BTY8209>CT`80U9BD0P2>SXh2
09BDU080SHf=0P2KVi/208n?S`80Ti>C0P2ATI4209ZJVP80UYJF0P2EUID209ZJVP80SXj>102ATI42
09BDU080Shn?0P2FUYH409>CT`H0U9BD0P2EUID209NGU`80TI6A0P2?Shl209JFUP80UIFE0`2DU9@2
09>CT`H0TY:B0P2ATI4209FEU@80TY:B0P2CTi<209ZJVP80Ti>C0P1jNWX208N7Q`80W9bL0P2EUID2
09JFUP80UIFE0P2GUiL2096AT@80UYJF0P2BTY8209BDU080UYJF0P2CTi<209VIV@80Shn?0P2HV9P2
092@T080TY:B0P2=SHd209RHV080RXZ:0`2LW9`20:>SX`80VYZJ0P1oOgl209FEU@80NGUi0P2LW9`2
09:BTP80Shn?0P2FUYH209BDU080YZJV0P28R8P2092@T080UYJF0P2=SHd204M7A`l0oooo000=0?oo
o`80ATI60P2HV9P209FEU@80UiNG0P2FUYH2096AT@80UIFE0P2>SXh209RHV080UiNG0P2HV9P209NG
U`80V9RH0P2>SXh209RHV0<0TY:B0P2DU9@409>CT`80SXj>102HV9P409NGU`80Vi^K0P2QXJ4208N7
Q`80T92@0P3IfMT208>3P`80UIFE0P2BTY8209ZJVP80UIFE102DU9@2096AT@80WinO0P2KVi/209:B
TP80UYJF0P2GUiL209VIV@80VYZJ0P2IVIT209FEU@80TI6A0`2FUYH209>CT`80U9BD0P2EUID2092@
T080VIVI0P2BTY8209ZJVP80V9RH0P2IVIT209ZJVP80V9RH0P2ATI4409VIV@@0VYZJ102CTi<209FE
U@80RXZ:0P2CTi<209:BTP80TI6A0P2DU9@208Z:RP80U9BD0P2;Rh/208n?S`80UiNG0P2>SXh208f=
S@<0S8b<0P2DU9@409>CT`H0UYJF0P2HV9P208j>SP80UiNG0P2NWYh2096AT@80NWYj0P2LW9`209JF
UP80SHf=0P26QXH208b<S080TY:B0P2EUID209:BTP80T92@0P2DU9@209JFUP80SXj>0P2@T90209RH
V080UYJF0P2@T90208f=S@80RHV90P2/[:`309JFUP80WIfM0P2;Rh/208b<S080VYZJ0P2a/K4209NG
U`80T92@0P2WYjL208V9R@80UYJF0P2WYjL208f=S@80T92@0P2HV9P209BDU080ATI63`3oool000d0
oooo0P16ATH209RHV080UIFE0P2GUiL209JFUP80TI6A0P2EUID208j>SP80V9RH0P2GUiL209RHV080
UiNG0P2HV9P208j>SP80V9RH0`2BTY8209BDU0@0Ti>C0P2>SXh409RHV0@0UiNG0P2KVi/20:6QX@80
QhN70P2@T9020=WIf@80Ph>30P2EUID209:BTP80VYZJ0P2EUID409BDU080TI6A0P2OWil209^KV`80
TY:B0P2FUYH209NGU`80VIVI0P2JVYX209VIV@80UIFE0P2ATI4309JFUP80Ti>C0P2DU9@209FEU@80
T92@0P2IVIT209:BTP80VYZJ0P2HV9P209VIV@80VYZJ0P2HV9P2096AT@@0VIVI102JVYX409>CT`80
UIFE0P2:RXX209>CT`80TY:B0P2ATI4209BDU080RXZ:0P2DU9@208^;R`80Shn?0P2GUiL208j>SP80
SHf=0`2<S8`209BDU0@0Ti>C1P2FUYH209RHV080SXj>0P2GUiL209jNWP80TI6A0P1jNWX209bLW080
UYJF0P2=SHd208J6QP80S8b<0P2BTY8209FEU@80TY:B0P2@T90209BDU080UYJF0P2>SXh2092@T080
V9RH0P2FUYH2092@T080SHf=0P29RHT20:b/[0<0UYJF0P2MWId208^;R`80S8b<0P2JVYX20;6a/@80
UiNG0P2@T9020:NWY`80RHV90P2FUYH20:NWY`80SHf=0P2@T90209RHV080U9BD0P16ATH?0?ooo`00
3@3oool204U9B@80SXj>0P2JVYX2092@T080Ti>C0P2BTY8209VIV@80UiNG102CTi<208f=S@80Ti>C
0P2EUID209ZJVP80T92@0`2GUiL2096AT@80TY:B0P2IVIT208j>SP80UYJF0P2;Rh/2096AT@80T92@
102<S8`209>CT`80RXZ:0P1gMgL20;2`/080TY:B0P2;Rh/209:BTP80UYJF0P2ATI4209:BTP80VIVI
0P2=SHd209RHV080SHf=0P2?Shl2092@T080Rh^;0P2<S8`2096AT@80Vi^K0P2EUID309BDU080TI6A
102EUID209JFUPH0T92@0P2JVYX209:BTP80RXZ:0P2IVIT209BDU080Ti>C0P2EUID209>CT`80Vi^K
0P2HV9P20::RXP80WYjN0P2OWil20:BTY080Vi^K0P2NWYh409fMW@80Xj>S102NWYh209fMW@80WinO
1@2PX:0409jNWP80XZ:R0P2CTi<209ZJVP80UYJF102HV9P209ZJVP80WIfM0P2HV9P20;2`/0@0RXZ:
0P2XZ:P20<;2`P80VIVI0P1oOgl209:BTP80SXj>0P2CTi<209JFUP80TI6A0P2BTY8208b<S080NWYj
0P1lO7`207UiN@80[Zj^0P2RXZ8209>CT`<0U9BD0P2GUiL20:>SX`80Shn?0P2ATI4209FEU@80UiNG
0P2JVYX20861P@80UIFE0P2NWYh208j>SP80T92@0P2CTi<209:BTP80V9RH0P17AdL?0?ooo`003@3o
ool204U9B@80SXj>0P2JVYX2092@T080Ti>C0P2BTY8209VIV@80UiNG102CTi<208f=S@80Ti>C0P2E
UID209ZJVP80T92@0`2GUiL2096AT@80TY:B0P2IVIT208j>SP80UYJF0P2;Rh/2096AT@80T92@102<
S8`209>CT`80RXZ:0P1gMgL20;2`/080TY:B0P2;Rh/209:BTP80UYJF0P2ATI4209:BTP80VIVI0P2=
SHd209RHV080SHf=0P2?Shl2092@T080Rh^;0P2<S8`2096AT@80Vi^K0P2EUID309BDU080TI6A102E
UID209JFUPH0T92@0P2JVYX209:BTP80RXZ:0P2IVIT209BDU080Ti>C0P2EUID209>CT`80Vi^K0P2H
V9P20::RXP80WYjN0P2OWil20:BTY080Vi^K0P2NWYh409fMW@80Xj>S102NWYh209fMW@80WinO1@2P
X:0409jNWP80XZ:R0P2CTi<209ZJVP80UYJF102HV9P209ZJVP80WIfM0P2HV9P20;2`/0@0RXZ:0P2X
Z:P20<;2`P80VIVI0P1oOgl209:BTP80SXj>0P2CTi<209JFUP80TI6A0P2BTY8208b<S080NWYj0P1l
O7`207UiN@80[Zj^0P2RXZ8209>CT`<0U9BD0P2GUiL20:>SX`80Shn?0P2ATI4209FEU@80UiNG0P2J
VYX20861P@80UIFE0P2NWYh208j>SP80T92@0P2CTi<209:BTP80V9RH0P17AdL?0?ooo`003@3oool2
03hn?P80UiNG0P2@T90209VIV@@0TI6A0P2?Shl209FEU@80U9BD0P2JVYX209FEU@80UYJF102GUiL2
08n?S`<0V9RH0P2KVi/2092@T080VYZJ0P2@T90209NGU`80TI6A0P2EUID209RHV080T92@0P2FUYH2
09FEU@80UiNG0P2;Rh/207moO`80VYZJ0P2c/k<207IfMP80T92@0P2OWil2092@T0@0TY:B0P2JVYX2
09RHV080WIfM0P2GUiL209JFUP80UIFE0P2BTY8209VIV@80UYJF0`2BTY8209RHV080SXj>0P2DU9@2
096AT@80UIFE0P2HV9P209>CT`80UiNG0P2EUID209JFUP80UiNG0P2?Shl209VIV@80T92@0P2ATI42
08n?S`80UYJF0P29RHT4092@T080TI6A0P2HV9P2092@T080UIFE102CTi<208j>SP80UYJF0P2GUiL2
08f=S@80TY:B0`2>SXh2096AT@80U9BD0P2<S8`208j>SP80WinO0P2>SXh2092@T080Shn?0P2GUiL2
08b<S080UiNG0P2EUID209ZJVP80TI6A0P28R8P20820P080PH610P3oool208N7Q`80WinO0P29RHT2
08F5Q@80Rh^;0P20P802096AT@80/[:b0P2_[jl20:j^[P80X:2P0P29RHT208^;R`<0R8R80P2MWId2
09FEU@80UiNG0P2HV9P208R8R080RHV90P2_[jl208^;R`80R8R80P2f][H208F5Q@80WIfM0P2?Shl2
09>CT`80SHf=0P18B4P?0?ooo`003@3oool203hn?P80UiNG0P2@T90209VIV@@0TI6A0P2?Shl209FE
U@80U9BD0P2JVYX209FEU@80UYJF102GUiL208n?S`<0V9RH0P2KVi/2092@T080VYZJ0P2@T90209NG
U`80TI6A0P2EUID209RHV080T92@0P2FUYH209FEU@80UiNG0P2;Rh/207moO`80VYZJ0P2c/k<207If
MP80T92@0P2OWil2092@T0@0TY:B0P2JVYX209RHV080WIfM0P2GUiL209JFUP80UIFE0P2BTY8209VI
V@80UYJF0`2BTY8209RHV080SXj>0P2DU9@2096AT@80UIFE0P2HV9P209>CT`80UiNG0P2EUID209JF
UP80UiNG0P2?Shl209VIV@80T92@0P2ATI4208n?S`80UYJF0P29RHT4092@T080TI6A0P2HV9P2092@
T080UIFE102CTi<208j>SP80UYJF0P2GUiL208f=S@80TY:B0`2>SXh2096AT@80U9BD0P2<S8`208j>
SP80WinO0P2>SXh2092@T080Shn?0P2GUiL208b<S080UiNG0P2EUID209ZJVP80TI6A0P28R8P20820
P080PH610P3oool208N7Q`80WinO0P29RHT208F5Q@80Rh^;0P20P802096AT@80/[:b0P2_[jl20:j^
[P80X:2P0P29RHT208^;R`<0R8R80P2MWId209FEU@80UiNG0P2HV9P208R8R080RHV90P2_[jl208^;
R`80R8R80P2f][H208F5Q@80WIfM0P2?Shl209>CT`80SHf=0P18B4P?0?ooo`003@3oool204];B`80
UiNG0P2?Shl209VIV@80U9BD0P2KVi/209RHV080Ti>C0P2DU9@208f=S@80VYZJ0P2DU9@4092@T080
UiNG1@2DU9@2092@T080UiNG0P2@T90209RHV080TI6A0P2JVYX209FEU@80U9BD0P2GUiL208f=S@80
UiNG0P2DU9@208F5Q@80WIfM0P2/[:`209:BTP80W9bL0P2DU9@208R8R080Ti>C0P2DU9@2096AT@80
SHf=0P2GUiL209JFUP80Ti>C0P2BTY82096AT@80VYZJ0P2FUYH3096AT@80U9BD102GUiL209>CT`80
U9BD0P2BTY82096AT@80Ti>C0P2GUiL209JFUP80Shn?102CTi<609BDU080TY:B0P2HV9P209fMW@80
SHf=1P2?Shl209NGU`80UYJF0P2BTY8209BDU0@0S8b<0P2EUID209JFUP<0UIFE0P2FUYH2092@T0@0
U9BD0P2ATI42092@T080VIVI0P2@T90209RHV080TI6A102@T902096AT@80WIfM0P2CTi<209FEU@80
QXJ60P1lO7`207UiN@80Y:BT0P2h^;P20;6a/@80QHF50P2PX:020:NWY`80RHV90P2LW9`209VIV@80
RHV90P2LW9`20820P0<0V9RH0P2WYjL206e]K@80UiNG0P2CTi<208f=S@80[Jf]1024Q8@20:RXZ080
Q8B40P2][Jd208R8R080VYZJ0P2EUID209VIV@80?clo3`3oool000d0oooo0P1;Bd/209NGU`80Shn?
0P2IVIT209BDU080Vi^K0P2HV9P209>CT`80U9BD0P2=SHd209ZJVP80U9BD102@T90209NGU`D0U9BD
0P2@T90209NGU`80T92@0P2HV9P2096AT@80VYZJ0P2EUID209BDU080UiNG0P2=SHd209NGU`80U9BD
0P25QHD209fMW@80[:b/0P2BTY8209bLW080U9BD0P28R8P209>CT`80U9BD0P2ATI4208f=S@80UiNG
0P2FUYH209>CT`80TY:B0P2ATI4209ZJVP80UYJF0`2ATI4209BDU0@0UiNG0P2CTi<209BDU080TY:B
0P2ATI4209>CT`80UiNG0P2FUYH208n?S`@0Ti>C1P2DU9@209:BTP80V9RH0P2MWId208f=S@H0Shn?
0P2GUiL209JFUP80TY:B0P2DU9@408b<S080UIFE0P2FUYH309FEU@80UYJF0P2@T90409BDU080TI6A
0P2@T90209VIV@80T92@0P2HV9P2096AT@@0T92@0P2ATI4209fMW@80Ti>C0P2EUID208J6QP80O7al
0P1iNGT20:BTY080^;Rh0P2a/K4208F5Q@80X:2P0P2WYjL208V9R@80W9bL0P2IVIT208V9R@80W9bL
0P20P80309RHV080YjNW0P1]KFd209NGU`80Ti>C0P2=SHd20:f][@@0Q8B40P2XZ:P208B4Q080[Jf]
0P28R8P209ZJVP80UIFE0P2IVIT203lo?`l0oooo000=0?ooo`80?Shn0P2HV9P209VIV@80SXj>0P2H
V9P408n?S`80Vi^K0P2GUiL209VIV@80SXj>0P2HV9P2096AT@80VYZJ0P2>SXh309VIV@80UYJF0P2H
V9P2092@T080VYZJ0P2@T90209>CT`80TY:B0P2@T90209NGU`80UIFE0P2HV9P209NGU`80TY:B0P2<
S8`209fMW@80P8200P2a/K4208b<S080Shn?0P2VYZH207QhN080Rh^;0P2IVIT208n?S`80WYjN0P2@
T90209:BTP80Vi^K0P2@T90209>CT`80UiNG0`2ATI4209BDU080UIFE0P2DU9@209NGU`80TI6A0P2I
VIT2092@T080UIFE0P2ATI4209RHV080VIVI0P2CTi<:09BDU080TY:B0P2?Shl209fMW@80UIFE0P2H
V9P209:BTP80T92@0P2>SXh209VIV@80Ti>C0P2EUID209^KV`80UIFE0P2?Shl308f=S@80W9bL0P2A
TI4409BDU080TY:B0P2GUiL209RHV080T92@0P2JVYX208j>SP80W9bL0P2BTY8209BDU080TI6A0P2@
T90209VIV@@0UiNG0P26QXH207]kN`80JFUY0P1VIVH20;no_`80ZJVY0P29RHT209^KV`80UiNG0P2=
SHd209JFUP80VIVI0P2YZJT309FEU@80VYZJ0P1fMWH20;>c/`80Vi^K0P23Ph<20:VYZ@80Ti>C0P2;
Rh/20:ZZZP80P8200P2CTi<209:BTP80Ti>C0P2EUID209RHV080@4103`3oool000d0oooo0P0n?Sh2
09RHV080VIVI0P2>SXh209RHV0@0Shn?0P2KVi/209NGU`80VIVI0P2>SXh209RHV080TI6A0P2JVYX2
08j>SP<0VIVI0P2FUYH209RHV080T92@0P2JVYX2092@T080Ti>C0P2BTY82092@T080UiNG0P2EUID2
09RHV080UiNG0P2BTY8208b<S080WIfM0P20P8020;6a/@80S8b<0P2?Shl20:JVYP80N7Qh0P2;Rh/2
09VIV@80Shn?0P2NWYh2092@T080TY:B0P2KVi/2092@T080Ti>C0P2GUiL3096AT@80U9BD0P2EUID2
09BDU080UiNG0P2ATI4209VIV@80T92@0P2EUID2096AT@80V9RH0P2IVIT209>CT`X0U9BD0P2BTY82
08n?S`80WIfM0P2EUID209RHV080TY:B0P2@T90208j>SP80VIVI0P2CTi<209FEU@80Vi^K0P2EUID2
08n?S`<0SHf=0P2LW9`2096AT@@0U9BD0P2BTY8209NGU`80V9RH0P2@T90209ZJVP80SXj>0P2LW9`2
09:BTP80U9BD0P2ATI42092@T080VIVI102GUiL208J6QP80Ng]k0P1YJFT206IVIP80_kno0P2YZJT2
08V9R@80Vi^K0P2GUiL208f=S@80UYJF0P2IVIT20:VYZ@<0UIFE0P2JVYX207IfMP80/k>c0P2KVi/2
08>3P`80ZJVY0P2CTi<208^;R`80ZZZZ0P20P80209>CT`80TY:B0P2CTi<209FEU@80V9RH0P10@40?
0?ooo`003@3oool204Y:BP@0Shn?0P2HV9P209NGU`80T92@0P2IVIT6092@T080VYZJ102ATI4209JF
UP80V9RH0`2ATI4409>CT`80T92@102GUiL209>CT`80TY:B0P2GUiL209JFUP80U9BD0P2ATI4209JF
UP80UIFE0P2;Rh/209jNWP80UIFE0P2JVYX20:FUY@80OGem0P2TY:@20;jn_P80MWIf0P28R8P209FE
U@80U9BD0P2>SXh209FEU@80T92@0P2FUYH209VIV@80UYJF0`2ATI4409BDU080UIFE0P2FUYH2092@
T0@0UYJF0P2EUID209BDU080TY:B0P2ATI4409:BTPH0Ti>C102DU9@209:BTP80UIFE0P2DU9@209JF
UP80Shn?0P2HV9P209NGU`80S8b<0P2FUYH209RHV080TY:B0P2DU9@209FEU@<0V9RH0P2FUYH2092@
T080Ti>C0P2BTY8208n?S`80WIfM0P2@T90209:BTP80UYJF0P2EUID209JFUP@0T92@0P2GUiL209FE
U@80TI6A0P2=SHd209JFUP80VYZJ0P2BTY820:ZZZP80];Bd0P2ATI4209BDU080WIfM0P2LW9`208F5
Q@80VIVI0P2DU9@209jNWP80RHV90`2DU9@209nOW`80Q8B40P2KVi/209JFUP80Rh^;0P2VYZH20861
P@80Vi^K0P2IVIT209:BTP80Ti>C0P2?Shl209jNWP80SHf=0P2@T90204I6APl0oooo000=0?ooo`80
BTY:102?Shl209RHV080UiNG0P2@T90209VIV@H0T92@0P2JVYX4096AT@80UYJF0P2HV9P3096AT@@0
Ti>C0P2@T90409NGU`80Ti>C0P2BTY8209NGU`80UYJF0P2DU9@2096AT@80UYJF0P2EUID208^;R`80
WYjN0P2EUID209ZJVP80YJFU0P1mOGd20:BTY080_[jn0P1fMWH208R8R080UIFE0P2DU9@208j>SP80
UIFE0P2@T90209JFUP80VIVI0P2FUYH3096AT@@0U9BD0P2EUID209JFUP80T92@102FUYH209FEU@80
U9BD0P2BTY82096AT@@0TY:B1P2CTi<409BDU080TY:B0P2EUID209BDU080UYJF0P2?Shl209RHV080
UiNG0P2<S8`209JFUP80V9RH0P2BTY8209BDU080UIFE0`2HV9P209JFUP80T92@0P2CTi<209:BTP80
Shn?0P2MWId2092@T080TY:B0P2FUYH209FEU@80UYJF102@T90209NGU`80UIFE0P2ATI4208f=S@80
UYJF0P2JVYX209:BTP80ZZZZ0P2d];@2096AT@80U9BD0P2MWId209bLW080QHF50P2IVIT209BDU080
WYjN0P29RHT309BDU080WinO0P24Q8@209^KV`80UYJF0P2;Rh/20:JVYP80PH610P2KVi/209VIV@80
TY:B0P2CTi<208n?S`80WYjN0P2=SHd2092@T080ATI63`3oool000d0oooo0P0o?cl209JFUP80VIVI
0P2CTi<209JFUP80T92@0P2KVi/2092@T080WIfM0P2@T90209VIV@80Shn?0P2JVYX208j>SP80VYZJ
1@2BTY82096AT@80VIVI0P2DU9@4096AT@80Vi^K0P2?Shl209JFUP80V9RH0P2GUiL208f=S@80UIFE
0P2?Shl209JFUP80QHF50P1iNGT20:ZZZP80S8b<0P2FUYH209BDU080bLW90P1NGUh209>CT`80RHV9
102LW9`209FEU@80TY:B0P2CTi<209JFUP<0T92@202DU9@209>CT`P0U9BD0P2CTi<209ZJVP80V9RH
0P2GUiL209VIV@80T92@0P2IVIT2096AT@80U9BD0P2CTi<209RHV080UYJF0P2CTi<409BDU0@0UiNG
0P2FUYH209:BTP80U9BD0P2CTi<209:BTP<0UIFE0P2CTi<209NGU`80T92@0P2KVi/209NGU`80UYJF
0P2@T90209:BTP@0UiNG0P2DU9@209FEU@80TY:B0P2IVIT208b<S080VYZJ0P2ATI4209VIV@80Shn?
102UYJD209BDU080RHV90P2@T90208b<S080UYJF0P2SXj<208f=S@80Vi^K0P2;Rh/208j>SP<0U9BD
0P24Q8@209NGU`80Z:RX0P2FUYH20::RXP80SXj>0P2BTY8209VIV@80Vi^K0P29RHT209JFUP80TY:B
0P2CTi<209BDU080UIFE0P1:BTX?0?ooo`003@3oool203lo?`80UYJF0P2IVIT209>CT`80UYJF0P2@
T90209^KV`80T92@0P2MWId2092@T080VIVI0P2?Shl209ZJVP80SXj>0P2JVYX509:BTP80TI6A0P2I
VIT209BDU0@0TI6A0P2KVi/208n?S`80UYJF0P2HV9P209NGU`80SHf=0P2EUID208n?S`80UYJF0P25
QHD207UiN@80ZZZZ0P2<S8`209JFUP80U9BD0P39bLT205iNGP80Ti>C0P29RHT409bLW080UIFE0P2B
TY8209>CT`80UYJF0`2@T90809BDU080Ti>C202DU9@209>CT`80VYZJ0P2HV9P209NGU`80VIVI0P2@
T90209VIV@80TI6A0P2DU9@209>CT`80V9RH0P2FUYH209>CT`@0U9BD102GUiL209JFUP80TY:B0P2D
U9@209>CT`80TY:B0`2EUID209>CT`80UiNG0P2@T90209^KV`80UiNG0P2FUYH2092@T080TY:B102G
UiL209BDU080UIFE0P2BTY8209VIV@80S8b<0P2JVYX2096AT@80VIVI0P2?Shl40:FUY@80U9BD0P29
RHT2092@T080S8b<0P2FUYH20:>SX`80SHf=0P2KVi/208^;R`80SXj>0`2DU9@208B4Q080UiNG0P2X
Z:P209JFUP80XZ:R0P2>SXh209:BTP80VIVI0P2KVi/208V9R@80UYJF0P2BTY8209>CT`80U9BD0P2E
UID204Y:BPl0oooo000=0?ooo`80B4Q80P2DU9@208j>SP80U9BD0P2IVIT2096AT@@0T92@0P2GUiL2
092@T080UYJF0P2JVYX208j>SP80Vi^K0P2?Shl3096AT@80VIVI0P2HV9P209BDU080V9RH0P2?Shl2
09fMW@80SXj>0P2FUYH209RHV080SXj>0P2FUYH209BDU080V9RH0P2=SHd20:FUY@80Ogmo0P2CTi<2
0:^[Z`80WinO0P2ATI4209NGU`80VYZJ0P3De=@206EUI@80TI6A0P2HV9P208Z:RP80UIFE0P2ATI42
09ZJVP80U9BD0`2IVIT209>CT`@0U9BD0P2CTi<209^KV`80TI6A0P2CTi<409BDU080TY:B0P2ATI42
08n?S`80UiNG0P2<S8`209JFUP80UIFE0P2IVIT209>CT`80U9BD0P2ATI4208j>SP80VYZJ0P2HV9P2
096AT@H0TY:B0P2IVIT209:BTP80U9BD0P2GUiL309:BTP80U9BD0P2JVYX208f=S@80UiNG0P2=SHd2
09JFUP80VYZJ0P2@T90208f=S@80T92@102>SXh2092@T080S8b<0P2DU9@208f=S@80U9BD0P1mOGd2
096AT@80Z:RX0P2?Shl208^;R`80W9bL0P2CTi<208N7Q`80Vi^K0P2PX:0209jNWP80PH610P2PX:02
08N7Q`<0WinO0P2FUYH209fMW@80QhN70P2ATI4209nOW`80MgMg0P2`/;0209^KV`80QHF50P2CTi<2
08j>SP80VYZJ0P2CTi<209VIV@80Shn?0P15ADD?0?ooo`003@3oool204Q8B080U9BD0P2>SXh209BD
U080VIVI0P2ATI44092@T080UiNG0P2@T90209JFUP80VYZJ0P2>SXh209^KV`80Shn?0`2ATI4209VI
V@80V9RH0P2DU9@209RHV080Shn?0P2MWId208j>SP80UYJF0P2HV9P208j>SP80UYJF0P2DU9@209RH
V080SHf=0P2UYJD207moO`80Ti>C0P2[Zj/209nOW`80TI6A0P2GUiL209ZJVP80e=CD0P1UIFD2096A
T@80V9RH0P2:RXX209FEU@80TI6A0P2JVYX209BDU0<0VIVI0P2CTi<409BDU080Ti>C0P2KVi/2096A
T@80Ti>C102DU9@209:BTP80TI6A0P2?Shl209NGU`80S8b<0P2FUYH209FEU@80VIVI0P2CTi<209BD
U080TI6A0P2>SXh209ZJVP80V9RH0P2ATI4609:BTP80VIVI0P2BTY8209BDU080UiNG0`2BTY8209BD
U080VYZJ0P2=SHd209NGU`80SHf=0P2FUYH209ZJVP80T92@0P2=SHd2092@T0@0SXj>0P2@T90208b<
S080U9BD0P2=SHd209BDU080OGem0P2ATI420:RXZ080Shn?0P2;Rh/209bLW080Ti>C0P27QhL209^K
V`80X:2P0P2NWYh20861P@80X:2P0P27QhL309nOW`80UYJF0P2MWId208N7Q`80TI6A0P2OWil207Mg
M`80/;2`0P2KVi/208F5Q@80Ti>C0P2>SXh209ZJVP80Ti>C0P2IVIT208n?S`80ADE53`3oool000d0
oooo0P15ADD409NGU`80UIFE0P2HV9P208j>SP80VYZJ0P2FUYH209^KV`80T92@0P2BTY82096AT@80
VYZJ0P2?Shl509VIV@80Shn?0P2IVIT208n?S`80UIFE0P2HV9P208f=S@80VIVI0P2GUiL208f=S@80
V9RH0P2?Shl409BDU080TY:B0P2MWId208^;R`80VYZJ0P1kNg/20:NWY`80QXJ60P2@T90209FEU@80
Y:BT0P3:b/X205]KF`80T92@0P2ATI4209bLW080Shn?0P2ATI4209^KV`<0SHf=102CTi<409:BTP80
T92@0P2IVIT209RHV080TI6A0P2BTY8209RHV0@0UiNG0P2DU9@209^KV`80UIFE0P2DU9@208n?S`80
TY:B0P2ATI4209VIV@80UYJF0P2ATI4209:BTP80UiNG0P2BTY8209ZJVP80T92@102ATI4209NGU`80
SXj>0`2MWId208j>SP@0Ti>C0P2DU9@409>CT`80T92@102CTi<209jNWP80UiNG0P2JVYX209jNWP80
VIVI0P2BTY8208J6QP80Rh^;0P2ZZZX20;Ng]`80Shn?0P20P80208^;R`80][Jf0P2CTi<209^KV`80
QHF50P2:RXX208N7Q`80Y:BT102KVi/309VIV@80S8b<0P2NWYh208j>SP80WIfM0P1`L7020:FUY@80
UiNG0P2DU9@2092@T080UIFE0P2HV9P209:BTP80U9BD0P2GUiL2096AT@80AdM73`3oool000d0oooo
0P15ADD409NGU`80UIFE0P2HV9P208j>SP80VYZJ0P2FUYH209^KV`80T92@0P2BTY82096AT@80VYZJ
0P2?Shl509VIV@80Shn?0P2IVIT208n?S`80UIFE0P2HV9P208f=S@80VIVI0P2GUiL208f=S@80V9RH
0P2?Shl409BDU080TY:B0P2MWId208^;R`80VYZJ0P1kNg/20:NWY`80QXJ60P2@T90209FEU@80Y:BT
0P3:b/X205]KF`80T92@0P2ATI4209bLW080Shn?0P2ATI4209^KV`<0SHf=102CTi<409:BTP80T92@
0P2IVIT209RHV080TI6A0P2BTY8209RHV0@0UiNG0P2DU9@209^KV`80UIFE0P2DU9@208n?S`80TY:B
0P2ATI4209VIV@80UYJF0P2ATI4209:BTP80UiNG0P2BTY8209ZJVP80T92@102ATI4209NGU`80SXj>
0`2MWId208j>SP@0Ti>C0P2DU9@409>CT`80T92@102CTi<209jNWP80UiNG0P2JVYX209jNWP80VIVI
0P2BTY8208J6QP80Rh^;0P2ZZZX20;Ng]`80Shn?0P20P80208^;R`80][Jf0P2CTi<209^KV`80QHF5
0P2:RXX208N7Q`80Y:BT102KVi/309VIV@80S8b<0P2NWYh208j>SP80WIfM0P1`L7020:FUY@80UiNG
0P2DU9@2092@T080UIFE0P2HV9P209:BTP80U9BD0P2GUiL2096AT@80AdM73`3oool000d0oooo0P15
ADD409NGU`80UIFE0P2HV9P208j>SP80VYZJ0P2FUYH209^KV`80T92@0P2BTY82096AT@80VYZJ0P2?
Shl509VIV@80Shn?0P2IVIT208n?S`80UIFE0P2HV9P208f=S@80VIVI0P2GUiL208f=S@80V9RH0P2?
Shl409BDU080TY:B0P2MWId208^;R`80VYZJ0P1kNg/20:NWY`80QXJ60P2@T90209FEU@80Y:BT0P3:
b/X205]KF`80T92@0P2ATI4209bLW080Shn?0P2ATI4209^KV`<0SHf=102CTi<409:BTP80T92@0P2I
VIT209RHV080TI6A0P2BTY8209RHV0@0UiNG0P2DU9@209^KV`80UIFE0P2DU9@208n?S`80TY:B0P2A
TI4209VIV@80UYJF0P2ATI4209:BTP80UiNG0P2BTY8209ZJVP80T92@102ATI4209NGU`80SXj>0`2M
WId208j>SP@0Ti>C0P2DU9@409>CT`80T92@102CTi<209jNWP80UiNG0P2JVYX209jNWP80VIVI0P2B
TY8208J6QP80Rh^;0P2ZZZX20;Ng]`80Shn?0P20P80208^;R`80][Jf0P2CTi<209^KV`80QHF50P2:
RXX208N7Q`80Y:BT102KVi/309VIV@80S8b<0P2NWYh208j>SP80WIfM0P1`L7020:FUY@80UiNG0P2D
U9@2092@T080UIFE0P2HV9P209:BTP80U9BD0P2GUiL2096AT@80AdM73`3oool000d0oooo0P19BDT2
08f=S@80UIFE0P2IVIT208n?S`80V9RH0P2GUiL209JFUP80T92@0P2FUYH209NGU`80TI6A0P2FUYH2
092@T080UIFE1@2@T90209JFUP80TI6A102GUiL209RHV080Shn?0P2EUID209JFUP80V9RH0P2CTi<2
09JFUP80TY:B0P2DU9@208R8R080UiNG0P22PX8209>CT`80Vi^K0P2@T90209NGU`@0UYJF0P2NWYh2
0=;BdP80EEEE0P22PX8209nOW`80S8b<0P2GUiL209:BTP<0UIFE0P2?Shl209RHV0@0UYJF0P2HV9P2
08n?S`80UiNG0P2IVIT208n?S`@0UYJF0P2=SHd209FEU@80TY:B0P2IVIT209FEU@80U9BD0P2EUID2
09VIV@80SHf=0P2DU9@209RHV080VIVI0P2DU9@209JFUPH0UIFE0P2@T90209NGU`80Ti>C0`2GUiL2
09VIV@80Vi^K0P2EUID208f=S@80WinO0P29RHT20:>SX`80SHf=102BTY8209RHV080Shn?0P2@T902
08f=S@80TY:B0P2HV9P20;Bd]080VIVI0P2RXZ84096AT@80Shn?0P2FUYH208Z:RP80TI6A0P28R8P2
09:BTP80Ti>C0P22PX820:6QX@80WIfM0`2>SXh209NGU`80VIVI0P2ATI4209FEU@80XJ6Q0P2MWId2
09JFUP80S8b<0P2ATI420:6QX@80UiNG0P2CTi<209FEU@80VIVI0P2BTY820492@Pl0oooo000=0?oo
o`80BDU90P2=SHd209FEU@80VIVI0P2?Shl209RHV080UiNG0P2FUYH2092@T080UYJF0P2GUiL2096A
T@80UYJF0P2@T90209FEU@D0T92@0P2FUYH2096AT@@0UiNG0P2HV9P208n?S`80UIFE0P2FUYH209RH
V080Ti>C0P2FUYH209:BTP80U9BD0P28R8P209NGU`80PX:20P2CTi<209^KV`80T92@0P2GUiL409JF
UP80WYjN0P3Bd]8205EEE@80PX:20P2OWil208b<S080UiNG0P2BTY8309FEU@80Shn?0P2HV9P409JF
UP80V9RH0P2?Shl209NGU`80VIVI0P2?Shl409JFUP80SHf=0P2EUID209:BTP80VIVI0P2EUID209BD
U080UIFE0P2IVIT208f=S@80U9BD0P2HV9P209VIV@80U9BD0P2FUYH609FEU@80T92@0P2GUiL209>C
T`<0UiNG0P2IVIT209^KV`80UIFE0P2=SHd209nOW`80RHV90P2SXj<208f=S@@0TY:B0P2HV9P208n?
S`80T92@0P2=SHd209:BTP80V9RH0P2d];@209VIV@80XZ:R102ATI4208n?S`80UYJF0P2:RXX2096A
T@80R8R80P2BTY8209>CT`80PX:20P2QXJ4209fMW@<0SXj>0P2GUiL209VIV@80TI6A0P2EUID20:6Q
X@80WIfM0P2FUYH208b<S080TI6A0P2QXJ4209NGU`80Ti>C0P2EUID209VIV@80TY:B0P12@T8?0?oo
o`003@3oool204A4A080Vi^K0P2@T90409:BTP80W9bL0P2>SXh2096AT@80TY:B102HV9P208n?S`80
UiNG0P2DU9@209^KV`<0UYJF102IVIT4096AT@80T92@0P2EUID209NGU`80T92@0P2GUiL409FEU@@0
Ti>C0P2JVYX209:BTP80Y:BT0P1kNg/20;2`/080UYJF0P2>SXh209bLW080V9RH0P2=SHd208j>SP80
VIVI0P3Xj>P205QHF080RHV90P2JVYX209BDU080V9RH0`2CTi<209NGU`H0U9BD0P2FUYH208n?S`80
VIVI0P2?Shl209NGU`H0UIFE0P2GUiL209>CT`80TI6A102GUiL209FEU@80V9RH0P2CTi<209:BTP80
Ti>C0P2ATI4209>CT`80UIFE0P2@T90209NGU`80VYZJ0P2HV9P208f=S@80UYJF0`2DU9@208Z:RP80
V9RH0P2=SHd209JFUP80UIFE0P2KVi/208b<S080V9RH0P2CTi<209:BTP80TI6A0P2;Rh/208Z:RP80
W9bL0P2EUID209VIV@80W9bL0P2JVYX208R8R080RHV90P2GUiL209VIV@80Ti>C0P2@T90209ZJVP80
YjNW0P2VYZH209VIV@80Z:RX0P2:RXX2092@T0<0UIFE0P2OWil208b<S080Ti>C0P2FUYH209VIV@80
PH610P2<S8`209^KV`80UIFE0P2=SHd209FEU@80T92@0P2BTY82096AT@80TY:B0P13@d<?0?ooo`00
3@3oool204A4A080Vi^K0P2@T90409:BTP80W9bL0P2>SXh2096AT@80TY:B102HV9P208n?S`80UiNG
0P2DU9@209^KV`<0UYJF102IVIT4096AT@80T92@0P2EUID209NGU`80T92@0P2GUiL409FEU@@0Ti>C
0P2JVYX209:BTP80Y:BT0P1kNg/20;2`/080UYJF0P2>SXh209bLW080V9RH0P2=SHd208j>SP80VIVI
0P3Xj>P205QHF080RHV90P2JVYX209BDU080V9RH0`2CTi<209NGU`H0U9BD0P2FUYH208n?S`80VIVI
0P2?Shl209NGU`H0UIFE0P2GUiL209>CT`80TI6A102GUiL209FEU@80V9RH0P2CTi<209:BTP80Ti>C
0P2ATI4209>CT`80UIFE0P2@T90209NGU`80VYZJ0P2HV9P208f=S@80UYJF0`2DU9@208Z:RP80V9RH
0P2=SHd209JFUP80UIFE0P2KVi/208b<S080V9RH0P2CTi<209:BTP80TI6A0P2;Rh/208Z:RP80W9bL
0P2EUID209VIV@80W9bL0P2JVYX208R8R080RHV90P2GUiL209VIV@80Ti>C0P2@T90209ZJVP80YjNW
0P2VYZH209VIV@80Z:RX0P2:RXX2092@T0<0UIFE0P2OWil208b<S080Ti>C0P2FUYH209VIV@80PH61
0P2<S8`209^KV`80UIFE0P2=SHd209FEU@80T92@0P2BTY82096AT@80TY:B0P13@d<?0?ooo`003@3o
ool204];B`80Shn?0P2GUiL409>CT`80TI6A0P2JVYX209RHV080TY:B0P2@T90209BDU080UiNG0P2I
VIT209BDU080SXj>1`2ATI4209NGU`80V9RH1P2EUID208n?S`@0UIFE0P2CTi<209JFUP80U9BD0P2>
SXh2096AT@80Vi^K0P1kNg/20:>SX`80UIFE0P2;Rh/209FEU@80WIfM0P2@T90208f=S@80WIfM0P2B
TY820>k^kP80KFe]0P2HV9P208b<S080V9RH0`2CTi<209FEU@80Ti>C0P2FUYH209FEU@80UYJF0P2G
UiL208n?S`80T92@0P2FUYH209BDU080Ti>C102DU9@409>CT`@0U9BD0P2?Shl209JFUP80TI6A0P2E
UID209>CT`80UYJF0P2EUID209BDU080TY:B0P2FUYH609:BTP80U9BD0`2KVi/209NGU`80UYJF0P2L
W9`208:2PP80Vi^K0P2>SXh209>CT`80SHf=0P2JVYX208V9R@80RXZ:0P2KVi/20:VYZ@80RHV90P2m
_Kd208Z:RP80Rh^;0P2ATI4208N7Q`@0UIFE0P2?Shl20::RXP80R8R80P2FUYH209:BTP80TI6A0P2=
SHd209>CT`80UYJF0P2ATI4309bLW080Rh^;0P2CTi<209FEU@80W9bL0P2BTY8209RHV080VYZJ0P2F
UYH209FEU@80UiNG0P2?Shl209RHV080TY:B0P2FUYH209^KV`80@T923`3oool000d0oooo0P1;Bd/2
08n?S`80UiNG102CTi<2096AT@80VYZJ0P2HV9P209:BTP80T92@0P2DU9@209NGU`80VIVI0P2DU9@2
08j>SPL0TI6A0P2GUiL209RHV0H0UIFE0P2?Shl409FEU@80Ti>C0P2FUYH209BDU080SXj>0P2ATI42
09^KV`80Ng]k0P2SXj<209FEU@80Rh^;0P2EUID209fMW@80T92@0P2=SHd209fMW@80TY:B0P3^k^h2
06e]K@80V9RH0P2<S8`209RHV0<0Ti>C0P2EUID209>CT`80UYJF0P2EUID209JFUP80UiNG0P2?Shl2
092@T080UYJF0P2DU9@209>CT`@0U9BD102CTi<409BDU080Shn?0P2FUYH2096AT@80UIFE0P2CTi<2
09JFUP80UIFE0P2DU9@209:BTP80UYJF1P2BTY8209BDU0<0Vi^K0P2GUiL209JFUP80W9bL0P22PX82
09^KV`80SXj>0P2CTi<208f=S@80VYZJ0P29RHT208Z:RP80Vi^K0P2YZJT208V9R@80_Kfm0P2:RXX2
08^;R`80TI6A0P27QhL409FEU@80Shn?0P2RXZ8208R8R080UYJF0P2BTY82096AT@80SHf=0P2CTi<2
09JFUP80TI6A0`2LW9`208^;R`80Ti>C0P2EUID209bLW080TY:B0P2HV9P209ZJVP80UYJF0P2EUID2
09NGU`80Shn?0P2HV9P209:BTP80UYJF0P2KVi/20492@Pl0oooo000=0?ooo`80@D510P2@T90209^K
V`80Shn?0P2HV9P2096AT@80TY:B0P2@T90209NGU`80U9BD0P2IVIT209FEU@80Shn?0P2HV9P209^K
V`<0UIFE0P2HV9P209:BTP80T92@0P2GUiL209JFUP80SXj>0P2GUiL209VIV@80UYJF0P2@T90409JF
UPH0U9BD0P2@T9020861P@80X:2P0P2BTY8209fMW@80UYJF0P2@T90209:BTP80WIfM0P2LW9`20:>S
X`80/;2`0P1FEUH209:BTP80UYJF0P2BTY8309JFUP80U9BD0P2HV9P208j>SP80UiNG0P2=SHd609JF
UP80UIFE0P2CTi<209ZJVP80TY:B0P2ATI4209JFUP80TY:B0P2HV9P209:BTP80UYJF0P2GUiL209BD
U080W9bL0P2BTY8209BDU080UIFE0P2CTi<209NGU`80Ti>C0P2DU9@209NGU`80Ti>C0P2DU9@309RH
V080VYZJ0P24Q8@208j>SP80W9bL0P2HV9P209NGU`80UYJF0P2@T90209ZJVP80TI6A0P2KVi/208>3
P`80^[Zj0P2GUiL209VIV@80UIFE0P2`/;0209RHV080TY:B0P2KVi/209ZJVP80VIVI0P2;Rh/209BD
U080R8R80P26QXH209ZJVP80UYJF0P1mOGd209FEU@80VIVI0`2=SHd409BDU080W9bL0P2@T90209BD
U080WYjN0P2;Rh/209BDU080SXj>0P2?Shl409NGU`80T92@0P2IVIT2092@T080@T923`3oool000d0
oooo0P11@D42092@T080Vi^K0P2?Shl209RHV080TI6A0P2BTY82092@T080UiNG0P2DU9@209VIV@80
UIFE0P2?Shl209RHV080Vi^K0`2EUID209RHV080TY:B0P2@T90209NGU`80UYJF0P2>SXh209NGU`80
VIVI0P2FUYH2092@T0@0UYJF1P2DU9@2092@T080PH610P2PX:0209:BTP80WIfM0P2FUYH2092@T080
TY:B0P2MWId209bLW080Xj>S0P2`/;0205IFEP80TY:B0P2FUYH209:BTP<0UYJF0P2DU9@209RHV080
SXj>0P2GUiL208f=S@H0UYJF0P2EUID209>CT`80VYZJ0P2BTY82096AT@80UYJF0P2BTY8209RHV080
TY:B0P2FUYH209NGU`80U9BD0P2LW9`209:BTP80U9BD0P2EUID209>CT`80UiNG0P2CTi<209BDU080
UiNG0P2CTi<209BDU0<0V9RH0P2JVYX208B4Q080SXj>0P2LW9`209RHV080UiNG0P2FUYH2092@T080
VYZJ0P2ATI4209^KV`80Ph>30P2j^[X209NGU`80VIVI0P2EUID20;2`/080V9RH0P2BTY8209^KV`80
VYZJ0P2IVIT208^;R`80U9BD0P28R8P208J6QP80VYZJ0P2FUYH207emO@80UIFE0P2IVIT308f=S@@0
U9BD0P2LW9`2092@T080U9BD0P2NWYh208^;R`80U9BD0P2>SXh208n?S`@0UiNG0P2@T90209VIV@80
T92@0P12@T8?0?ooo`003@3oool20492@P80UiNG0P2EUID209NGU`80U9BD0P2IVIT2092@T080Vi^K
0P2@T90209NGU`80V9RH0P2ATI4209>CT`80UiNG0P2=SHd309RHV080T92@0P2FUYH209FEU@80U9BD
0P2>SXh209VIV@80UiNG0P2?Shl2096AT@80UiNG0P2?Shl209JFUP80TI6A0P2CTi<208j>SP80Shn?
0P2PX:0209JFUP@0TY:B0P2SXj<208F5Q@80UiNG0P2:RXX209bLW080VIVI0P2BTY820<;2`P80NWYj
0P2@T90209JFUP<0SHf=102GUiL208j>SP@0UIFE0P2DU9@409>CT`80U9BD0P2FUYH2096AT@80Ti>C
0P2JVYX209FEU@80TI6A102EUID209BDU080Shn?0P2MWId208V9R@80WinO0P2ATI4208f=S@80TI6A
0P2DU9@208n?S`80UIFE0P2<S8`20::RXP80VYZJ0`2EUID208N7Q`80SHf=0P2WYjL209^KV`80T92@
0P2IVIT208N7Q`80R8R80P2GUiL209:BTP80Xj>S0P2PX:0207UiN@80W9bL0P27QhL208b<S080R8R8
0P2:RXX208j>SP80UIFE0P2?Shl209FEU@80SHf=0P2SXj<209nOW`80UiNG0P2MWId2092@T080XJ6Q
0P2XZ:P208Z:RP<0U9BD0P2EUID209VIV@80Shn?0P2FUYH208f=S@80U9BD0P2ATI4208n?S`80V9RH
0P2LW9`2096AT@80TY:B102FUYH209:BTP80B4Q83`3oool000d0oooo0P12@T8209NGU`80UIFE0P2G
UiL209BDU080VIVI0P2@T90209^KV`80T92@0P2GUiL209RHV080TI6A0P2CTi<209NGU`80SHf=0`2H
V9P2092@T080UYJF0P2EUID209BDU080SXj>0P2IVIT209NGU`80Shn?0P2ATI4209NGU`80Shn?0P2F
UYH2096AT@80Ti>C0P2>SXh208n?S`80X:2P0P2FUYH409:BTP80Xj>S0P25QHD209NGU`80RXZ:0P2L
W9`209VIV@80TY:B0P32`/8207YjNP80T92@0P2FUYH308f=S@@0UiNG0P2>SXh409FEU@80U9BD102C
Ti<209BDU080UYJF0P2ATI4209>CT`80VYZJ0P2EUID2096AT@@0UIFE0P2DU9@208n?S`80WIfM0P29
RHT209nOW`80TI6A0P2=SHd2096AT@80U9BD0P2?Shl209FEU@80S8b<0P2RXZ8209ZJVP<0UIFE0P27
QhL208f=S@80YjNW0P2KVi/2092@T080VIVI0P27QhL208R8R080UiNG0P2BTY820:>SX`80X:2P0P1i
NGT209bLW080QhN70P2<S8`208R8R080RXZ:0P2>SXh209FEU@80Shn?0P2EUID208f=S@80Xj>S0P2O
Wil209NGU`80WIfM0P2@T9020:6QX@80Z:RX0P2:RXX309BDU080UIFE0P2IVIT208n?S`80UYJF0P2=
SHd209BDU080TI6A0P2?Shl209RHV080W9bL0P2ATI4209:BTP@0UYJF0P2BTY8204Q8B0l0oooo000=
0?ooo`80@T920P2@T90209VIV@80SXj>0P2IVIT209FEU@80V9RH102BTY8209VIV@80TI6A102DU9@2
096AT@80VIVI0`2EUID2096AT@80VYZJ0P2CTi<209RHV080UiNG0P2>SXh209RHV080UiNG0P2@T902
09NGU`@0UYJF0P2EUID209RHV080Rh^;0P2@T90209:BTP80XJ6Q0P2:RXX209^KV`80QhN70P29RHT2
09jNWP80T92@0P2PX:02096AT@80QhN70P3;bl/2075aL@80T92@0P2EUID308f=S@80UiNG0P2FUYH2
09>CT`80VIVI0P2EUID209:BTP80V9RH0P2EUID209:BTP80TI6A0P2EUID209JFUP80TY:B0P2FUYH2
09NGU`80SXj>0P2HV9P209FEU@80UYJF0P2:RXX209fMW@80RHV90P2KVi/209FEU@80UiNG102EUID2
09BDU080W9bL0P2>SXh209jNWP<0Q8B40P1lO7`20:JVYP80TI6A0P2:RXX208V9R@80T92@0P2LW9`2
09VIV@80[:b/0P28R8P209JFUP80Vi^K0P2LW9`208R8R080RXZ:0P2SXj<209>CT`80T92@102CTi<2
09JFUP80]KFe0P1jNWX209jNWP80P8200P2SXj<2079bLP80X:2P0P2DU9@208>3P`80TY:B0`2EUID2
09RHV080UYJF0P2UYJD208^;R`80Ti>C0P2HV9P209BDU080T92@0P2KVi/2092@T080Ti>C0P2ATI42
09VIV@80T92@0P2CTi<20492@Pl0oooo000=0?ooo`80@T920P2@T90209VIV@80SXj>0P2IVIT209FE
U@80V9RH102BTY8209VIV@80TI6A102DU9@2096AT@80VIVI0`2EUID2096AT@80VYZJ0P2CTi<209RH
V080UiNG0P2>SXh209RHV080UiNG0P2@T90209NGU`@0UYJF0P2EUID209RHV080Rh^;0P2@T90209:B
TP80XJ6Q0P2:RXX209^KV`80QhN70P29RHT209jNWP80T92@0P2PX:02096AT@80QhN70P3;bl/2075a
L@80T92@0P2EUID308f=S@80UiNG0P2FUYH209>CT`80VIVI0P2EUID209:BTP80V9RH0P2EUID209:B
TP80TI6A0P2EUID209JFUP80TY:B0P2FUYH209NGU`80SXj>0P2HV9P209FEU@80UYJF0P2:RXX209fM
W@80RHV90P2KVi/209FEU@80UiNG102EUID209BDU080W9bL0P2>SXh209jNWP<0Q8B40P1lO7`20:JV
YP80TI6A0P2:RXX208V9R@80T92@0P2LW9`209VIV@80[:b/0P28R8P209JFUP80Vi^K0P2LW9`208R8
R080RXZ:0P2SXj<209>CT`80T92@102CTi<209JFUP80]KFe0P1jNWX209jNWP80P8200P2SXj<2079b
LP80X:2P0P2DU9@208>3P`80TY:B0`2EUID209RHV080UYJF0P2UYJD208^;R`80Ti>C0P2HV9P209BD
U080T92@0P2KVi/2092@T080Ti>C0P2ATI4209VIV@80T92@0P2CTi<20492@Pl0oooo000=0?ooo`80
@T920P2LW9`208n?S`80VIVI0P2ATI4409:BTP80U9BD0P2BTY8209RHV080TY:B102DU9@209>CT`80
UYJF0`2HV9P2096AT@80T92@0P2EUID209>CT`80Vi^K0P2@T90209NGU`80T92@102HV9P2096AT@80
T92@0P2CTi<209JFUP80Ph>30P2VYZH208V9R@80Vi^K0P2MWId209NGU`80WYjN0P2;Rh/209nOW`80
UYJF0P2=SHd208N7Q`80Ti>C0P3Ogml205iNGP80VIVI0P2DU9@309NGU`80TI6A0P2FUYH2096AT@80
UiNG0P2HV9P2092@T0H0UYJF0P2DU9@409FEU@80TI6A0P2@T90209:BTP80UYJF0P2?Shl209>CT`80
T92@0P2JVYX209JFUP80V9RH0P2@T90209BDU080TY:B0P2=SHd209JFUP80SXj>0P2JVYX20:2PX080
QXJ60`28R8P20:>SX`80Vi^K0P2IVIT209FEU@@0U9BD0P2?Shl20:^[Z`80U9BD0P2=SHd209jNWP80
UiNG0P2EUID209RHV0@0XJ6Q0P2ATI4208j>SP80Shn?0P2LW9`209fMW@80TY:B0P2?Shl209ZJVP80
T92@0P2IVIT20:6QX@80Shn?0P2KVi/20:FUY@80TY:B0`2FUYH209jNWP80TI6A0P21PH4209JFUP80
UIFE0P2DU9@208j>SP80T92@0P2GUiL209>CT`80TY:B0P2JVYX209FEU@80Vi^K0P2CTi<204=3@`l0
oooo000=0?ooo`80@T920P2LW9`208n?S`80VIVI0P2ATI4409:BTP80U9BD0P2BTY8209RHV080TY:B
102DU9@209>CT`80UYJF0`2HV9P2096AT@80T92@0P2EUID209>CT`80Vi^K0P2@T90209NGU`80T92@
102HV9P2096AT@80T92@0P2CTi<209JFUP80Ph>30P2VYZH208V9R@80Vi^K0P2MWId209NGU`80WYjN
0P2;Rh/209nOW`80UYJF0P2=SHd208N7Q`80Ti>C0P3Ogml205iNGP80VIVI0P2DU9@309NGU`80TI6A
0P2FUYH2096AT@80UiNG0P2HV9P2092@T0H0UYJF0P2DU9@409FEU@80TI6A0P2@T90209:BTP80UYJF
0P2?Shl209>CT`80T92@0P2JVYX209JFUP80V9RH0P2@T90209BDU080TY:B0P2=SHd209JFUP80SXj>
0P2JVYX20:2PX080QXJ60`28R8P20:>SX`80Vi^K0P2IVIT209FEU@@0U9BD0P2?Shl20:^[Z`80U9BD
0P2=SHd209jNWP80UiNG0P2EUID209RHV0@0XJ6Q0P2ATI4208j>SP80Shn?0P2LW9`209fMW@80TY:B
0P2?Shl209ZJVP80T92@0P2IVIT20:6QX@80Shn?0P2KVi/20:FUY@80TY:B0`2FUYH209jNWP80TI6A
0P21PH4209JFUP80UIFE0P2DU9@208j>SP80T92@0P2GUiL209>CT`80TY:B0P2JVYX209FEU@80Vi^K
0P2CTi<204=3@`l0oooo000=0?ooo`80@T92102BTY8209^KV`@0TY:B0P2HV9P209:BTP80VIVI0P2@
T90209VIV@80Ti>C102DU9@2096AT@/0UYJF0P2@T90209:BTP80UiNG0P2@T90209VIV@80Shn?0P2B
TY82092@T080U9BD0P2CTi<2092@T080WinO0P2CTi<209BDU080TI6A0P2EUID208Z:RP80Y:BT0P2S
Xj<209FEU@80S8b<0P2=SHd209JFUP80^k^k0P1TI6@209VIV@80RHV90`2ATI4209^KV`80TI6A0P2E
UID2096AT@80SHf=0P2FUYH209>CT`@0T92@0P2JVYX208n?S`80T92@0P2IVIT209NGU`80UYJF0P2H
V9P208b<S080Vi^K0P2BTY8209>CT`80U9BD0P2>SXh209VIV@80UIFE0P2CTi<209VIV@80Shn?0P2R
XZ8209BDU080UYJF0P2?Shl309:BTP80UYJF102@T90408j>SP80Z:RX0P2GUiL209BDU080W9bL0P1n
OWh209JFUP80SXj>0P2KVi/20::RXP80Ogmo0P2DU9@209:BTP80Ti>C0P2DU9@209NGU`80PX:20P2H
V9P209BDU080Vi^K0P2GUiL209VIV@80V9RH0P2KVi/208J6QP80T92@0P2=SHd30:6QX@80Shn?0P2G
UiL209JFUP80T92@0P2HV9P209BDU080UIFE0P2LW9`2096AT@80Ti>C0P2HV9P208n?S`80TI6A0P2@
T90209:BTP80@d=33`3oool000d0oooo0P12@T8409:BTP80Vi^K102BTY8209RHV080TY:B0P2IVIT2
092@T080VIVI0P2CTi<409BDU080TI6A2`2FUYH2092@T080TY:B0P2GUiL2092@T080VIVI0P2?Shl2
09:BTP80T92@0P2DU9@209>CT`80T92@0P2OWil209>CT`80U9BD0P2ATI4209FEU@80RXZ:0P2TY:@2
0:>SX`80UIFE0P2<S8`208f=S@80UYJF0P2k^k/206ATI080VIVI0P29RHT3096AT@80Vi^K0P2ATI42
09FEU@80TI6A0P2=SHd209JFUP80Ti>C102@T90209ZJVP80Shn?0P2@T90209VIV@80UiNG0P2FUYH2
09RHV080S8b<0P2KVi/209:BTP80Ti>C0P2DU9@208j>SP80VIVI0P2EUID209>CT`80VIVI0P2?Shl2
0::RXP80U9BD0P2FUYH208n?S`<0TY:B0P2FUYH4092@T0@0SXj>0P2XZ:P209NGU`80U9BD0P2LW9`2
07inOP80UYJF0P2>SXh209^KV`80XZ:R0P1oOgl209BDU080TY:B0P2CTi<209BDU080UiNG0P22PX82
09RHV080U9BD0P2KVi/209NGU`80VIVI0P2HV9P209^KV`80QXJ60P2@T90208f=S@<0XJ6Q0P2?Shl2
09NGU`80UYJF0P2@T90209RHV080U9BD0P2EUID209bLW080TI6A0P2CTi<209RHV080Shn?0P2ATI42
092@T080TY:B0P13@d<?0?ooo`003@3oool20492@P80VIVI0P2CTi<209:BTP80Ti>C0P2HV9P209JF
UP@0TY:B0P2IVIT2096AT@@0U9BD0P2CTi<209VIV@<0TI6A102GUiL409:BTP80V9RH0P2ATI4209JF
UPP0UIFE0P2HV9P209BDU080TI6A0P29RHT209JFUP80VYZJ0P2FUYH209VIV@80V9RH0P2>SXh209>C
T`80VYZJ0P1iNGT208f=S@80Y:BT0P2FUYH20<S8b080I6AT0P2IVIT209:BTP<0Xj>S102ATI42092@
T080WYjN0P2KVi/209:BTP80Ti>C0P2HV9P209JFUP80Ti>C0P2HV9P209BDU080TY:B0P2FUYH209FE
U@80Shn?0P2MWId208n?S`80VYZJ0P2FUYH609BDU080TI6A0P2IVIT209>CT`80UYJF0P2CTi<20:2P
X080Ph>30P2DU9@309^KV`80XZ:R0P2<S8`209ZJVP80QhN70P2XZ:P208F5Q@80S8b<0P2ATI4209^K
V`80VIVI0P2<S8`2096AT@80XJ6Q0P2>SXh209VIV@80U9BD0P27QhL20:ZZZP80TY:B0P2GUiL208^;
R`80T92@0P28R8P209^KV`80WYjN0P25QHD20:2PX080WYjN0P2<S8`209NGU`80VYZJ0`2ATI4208j>
SP80QhN70P2GUiL2096AT@80Vi^K0P2BTY8209JFUP80T92@102CTi<209NGU`80VYZJ0P2EUID209VI
V@80UiNG0P11@D4?0?ooo`003@3oool20492@P80VIVI0P2CTi<209:BTP80Ti>C0P2HV9P209JFUP@0
TY:B0P2IVIT2096AT@@0U9BD0P2CTi<209VIV@<0TI6A102GUiL409:BTP80V9RH0P2ATI4209JFUPP0
UIFE0P2HV9P209BDU080TI6A0P29RHT209JFUP80VYZJ0P2FUYH209VIV@80V9RH0P2>SXh209>CT`80
VYZJ0P1iNGT208f=S@80Y:BT0P2FUYH20<S8b080I6AT0P2IVIT209:BTP<0Xj>S102ATI42092@T080
WYjN0P2KVi/209:BTP80Ti>C0P2HV9P209JFUP80Ti>C0P2HV9P209BDU080TY:B0P2FUYH209FEU@80
Shn?0P2MWId208n?S`80VYZJ0P2FUYH609BDU080TI6A0P2IVIT209>CT`80UYJF0P2CTi<20:2PX080
Ph>30P2DU9@309^KV`80XZ:R0P2<S8`209ZJVP80QhN70P2XZ:P208F5Q@80S8b<0P2ATI4209^KV`80
VIVI0P2<S8`2096AT@80XJ6Q0P2>SXh209VIV@80U9BD0P27QhL20:ZZZP80TY:B0P2GUiL208^;R`80
T92@0P28R8P209^KV`80WYjN0P25QHD20:2PX080WYjN0P2<S8`209NGU`80VYZJ0`2ATI4208j>SP80
QhN70P2GUiL2096AT@80Vi^K0P2BTY8209JFUP80T92@102CTi<209NGU`80VYZJ0P2EUID209VIV@80
UiNG0P11@D4?0?ooo`003@3oool204=3@`@0Ti>C0P2IVIT209:BTP80TI6A0P2HV9P609:BTP80VIVI
0P2CTi<209BDU0@0Ti>C0`2DU9@409>CT`80U9BD0P2BTY8209RHV080TI6A0P2FUYH209BDU080SXj>
0P2FUYH209RHV080Shn?0P2<S8`208n?S`80UYJF0P2PX:0208V9R@80T92@102DU9@208J6QP80Z:RX
0P28R8P209VIV@80UYJF0P2WYjL208j>SP80b/[:0P1UIFD2096AT@80TY:B0`2@T90209:BTP80VYZJ
0P2=SHd208n?S`80VIVI0P2>SXh409NGU`80T92@0P2CTi<209RHV080T92@0P2GUiL2092@T0@0UIFE
0P2FUYH2096AT@80T92@0P2BTY8209JFUP80VIVI0P2>SXh209RHV080Ti>C0P2?Shl2096AT@80WYjN
0P2<S8`2096AT@D0VYZJ0P2>SXh209VIV@80TI6A0P2[Zj/2092@T080SXj>0P2WYjL409RHV080Q8B4
0P2BTY82096AT@80Ph>30P2KVi/209>CT`80Vi^K0P2MWId208N7Q`80RHV90P2XZ:P208f=S@80SXj>
0P2JVYX20:FUY@80RXZ:0P27QhL209ZJVP80TI6A0P2@T90209fMW@80SHf=0`2@T902096AT@80XZ:R
0P2FUYH209:BTP80TI6A0P2DU9@209JFUP80TY:B0P2IVIT409>CT`80TI6A102FUYH2096AT@80AdM7
3`3oool000d0oooo0P13@d<409>CT`80VIVI0P2BTY82096AT@80V9RH1P2BTY8209VIV@80Ti>C0P2D
U9@409>CT`<0U9BD102CTi<209BDU080TY:B0P2HV9P2096AT@80UYJF0P2DU9@208j>SP80UYJF0P2H
V9P208n?S`80S8b<0P2?Shl209JFUP80X:2P0P29RHT2092@T0@0U9BD0P26QXH20:RXZ080R8R80P2I
VIT209JFUP80YjNW0P2>SXh20<[:bP80IFEU0P2ATI4209:BTP<0T92@0P2BTY8209ZJVP80SHf=0P2?
Shl209VIV@80SXj>102GUiL2092@T080Ti>C0P2HV9P2092@T080UiNG0P2@T90409FEU@80UYJF0P2A
TI42092@T080TY:B0P2FUYH209VIV@80SXj>0P2HV9P209>CT`80Shn?0P2ATI4209jNWP80S8b<0P2A
TI4509ZJVP80SXj>0P2IVIT2096AT@80Zj^[0P2@T90208j>SP80YjNW102HV9P208B4Q080TY:B0P2A
TI4208>3P`80Vi^K0P2CTi<209^KV`80WIfM0P27QhL208V9R@80Z:RX0P2=SHd208j>SP80VYZJ0P2U
YJD208Z:RP80QhN70P2JVYX2096AT@80T92@0P2MWId208f=S@<0T92@0P2ATI420::RXP80UYJF0P2B
TY82096AT@80U9BD0P2FUYH209:BTP80VIVI102CTi<2096AT@@0UYJF0P2ATI4204M7A`l0oooo000=
0?ooo`80@d=3102CTi<209:BTP@0UiNG0P2ATI4209RHV080Vi^K102ATI4209BDU080Ti>C0P2HV9P2
09>CT`<0U9BD102CTi<2096AT@80UiNG0P2BTY82096AT@80UIFE0P2JVYX209FEU@80VYZJ0P2?Shl4
09FEU@80Ng]k0P2WYjL209BDU080VYZJ0P2;Rh/20:VYZ@80Ti>C0P2KVi/209nOW`80Rh^;0P2EUID2
09:BTP80Ti>C0P24Q8@20<C4a080I6AT0P2OWil208j>SP<0UiNG0P2?Shl209FEU@80W9bL0P2<S8`2
09NGU`80U9BD0P2BTY8209>CT`80UYJF0P2EUID2096AT@80VYZJ0P2GUiL208j>SP@0U9BD0P2?Shl2
09BDU080TY:B0P2JVYX209:BTP80Ti>C0P2DU9@209:BTP80SHf=0P2KVi/209:BTP80VYZJ0P24Q8@2
08j>SP80UIFE0`2DU9@209VIV@80UYJF0P2OWil208V9R@80Shn?0P2OWil209^KV`80VIVI0P2GUiL2
09RHV080T92@0P2RXZ8209RHV080WinO0P2<S8`209RHV080TY:B0P2UYJD209NGU`80QHF50P2DU9@2
09jNWP@0SHf=0P29RHT20:6QX@80UYJF0P2GUiL209BDU080UYJF0P2<S8`309ZJVP80TY:B0P2<S8`2
096AT@80WIfM0P2CTi<2092@T080V9RH1P2CTi<209BDU080Ti>C0P2HV9P2092@T080TY:B0P16ATH?
0?ooo`003@3oool204=3@`@0Ti>C0P2BTY8409NGU`80TI6A0P2HV9P209^KV`@0TI6A0P2DU9@209>C
T`80V9RH0P2CTi<309BDU0@0Ti>C0P2ATI4209NGU`80TY:B0P2ATI4209FEU@80VYZJ0P2EUID209ZJ
VP80Shn?102EUID207]kN`80YjNW0P2DU9@209ZJVP80Rh^;0P2YZJT209>CT`80Vi^K0P2OWil208^;
R`80UIFE0P2BTY8209>CT`80Q8B40P34a<@206ATI080WinO0P2>SXh309NGU`80Shn?0P2EUID209bL
W080S8b<0P2GUiL209BDU080TY:B0P2CTi<209JFUP80UIFE0P2ATI4209ZJVP80UiNG0P2>SXh409BD
U080Shn?0P2DU9@209:BTP80VYZJ0P2BTY8209>CT`80U9BD0P2BTY8208f=S@80Vi^K0P2BTY8209ZJ
VP80Q8B40P2>SXh209FEU@<0U9BD0P2IVIT209JFUP80WinO0P29RHT208n?S`80WinO0P2KVi/209VI
V@80UiNG0P2HV9P2092@T080XZ:R0P2HV9P209nOW`80S8b<0P2HV9P209:BTP80YJFU0P2GUiL208F5
Q@80U9BD0P2NWYh408f=S@80RHV90P2QXJ4209JFUP80UiNG0P2DU9@209JFUP80S8b<0`2JVYX209:B
TP80S8b<0P2ATI4209fMW@80Ti>C0P2@T90209RHV0H0Ti>C0P2DU9@209>CT`80V9RH0P2@T90209:B
TP80ATI63`3oool000d0oooo0P11@D4409RHV080TI6A0P2FUYH209FEU@80T92@0P2ATI42092@T080
UiNG0P2KVi/209:BTP80TI6A0P2HV9P209:BTP<0Ti>C0P2GUiL209JFUP80UiNG0P2IVIT2096AT@80
V9RH0P2GUiL2096AT@80T92@0P2EUID208n?S`80VIVI0P2=SHd2096AT@80Vi^K0P2?Shl209ZJVP80
Ti>C0P2FUYH20861P@80YJFU0P2>SXh208^;R`80PX:20P2SXj<209bLW080UiNG0P2k^k/206EUI@80
W9bL0P2ATI4309fMW@80U9BD0P2BTY8209JFUP80U9BD0P2@T90209ZJVP80TI6A0P2FUYH209VIV@80
T92@0P2FUYH209BDU080TY:B0P2NWYh209VIV@80VYZJ0P2CTi<209JFUP80Ti>C0P2EUID2096AT@80
VIVI0P2FUYH209:BTP80UiNG0P2@T90209JFUP80SHf=0P2NWYh209^KV`80TI6A0`2MWId209>CT`80
TI6A0P2=SHd2096AT@80S8b<0P2=SHd209:BTP80Ti>C0P2LW9`209FEU@80Ti>C0P1oOgl209>CT`80
NGUi0P2HV9P20:VYZ@80WYjN0P2LW9`208^;R`80Xj>S0P2>SXh208f=S@80Ti>C0P2;Rh/209nOW`80
UYJF0P2RXZ8208R8R080TI6A0P2OWil209>CT`<0SXj>0P2MWId208n?S`80WIfM0P2;Rh/209FEU@80
TI6A0P2CTi<209BDU080TY:B0P2IVIT209>CT`80U9BD0P2ATI4209bLW080TI6A0P17AdL?0?ooo`00
3@3oool20451@@@0V9RH0P2ATI4209JFUP80UIFE0P2@T902096AT@80T92@0P2GUiL209^KV`80TY:B
0P2ATI4209RHV080TY:B0`2CTi<209NGU`80UYJF0P2GUiL209VIV@80TI6A0P2HV9P209NGU`80TI6A
0P2@T90209FEU@80Shn?0P2IVIT208f=S@80TI6A0P2KVi/208n?S`80VYZJ0P2CTi<209JFUP80PH61
0P2UYJD208j>SP80Rh^;0P22PX820:>SX`80W9bL0P2GUiL20;^k^`80IFEU0P2LW9`2096AT@<0WIfM
0P2DU9@209:BTP80UYJF0P2DU9@2092@T080VYZJ0P2ATI4209JFUP80VIVI0P2@T90209JFUP80U9BD
0P2BTY8209jNWP80VIVI0P2JVYX209>CT`80UYJF0P2CTi<209FEU@80TI6A0P2IVIT209JFUP80TY:B
0P2GUiL2092@T080UYJF0P2=SHd209jNWP80Vi^K0P2ATI4309fMW@80Ti>C0P2ATI4208f=S@80TI6A
0P2<S8`208f=S@80TY:B0P2CTi<209bLW080UIFE0P2CTi<207moO`80Ti>C0P1iNGT209RHV080ZJVY
0P2NWYh209bLW080Rh^;0P2SXj<208j>SP80SHf=0P2CTi<208^;R`80WinO0P2FUYH20::RXP80R8R8
0P2ATI4209nOW`80Ti>C0`2>SXh209fMW@80Shn?0P2MWId208^;R`80UIFE0P2ATI4209>CT`80U9BD
0P2BTY8209VIV@80Ti>C0P2DU9@2096AT@80W9bL0P2ATI4204M7A`l0oooo000=0?ooo`80B4Q8102B
TY8209RHV080UIFE0P2GUiL209VIV@80VYZJ0P2HV9P609:BTP80Vi^K0P2?Shl209RHV0<0TI6A0P2G
UiL2092@T080V9RH0P2@T90209>CT`@0TY:B0P2ATI4209JFUP80V9RH102DU9@208>3P`80WIfM0P2D
U9@209VIV@80SHf=0P2DU9@20:2PX080SHf=0P2MWId20861P@80X:2P0P2BTY820:FUY@80WinO0P2D
U9@20<?3``80HV9R0P2JVYX2092@T0<0Shn?0P2ATI4209JFUP80TI6A0P2JVYX209RHV080UIFE0P2D
U9@2096AT@80UYJF102DU9@208n?S`80T92@0P2<S8`209BDU080TY:B0P2FUYH209RHV080SXj>0P2?
Shl209RHV080U9BD0P2>SXh209^KV`80UiNG0P2DU9@209fMW@80S8b<0P2HV9P209JFUP80Xj>S0`29
RHT209^KV`80Rh^;0P1nOWh20:RXZ080WYjN0P2VYZH209NGU`80QXJ60P2>SXh209>CT`80UYJF0P2G
UiL209>CT`80Xj>S0P1nOWh2096AT@80XJ6Q0P2?Shl209ZJVP80Rh^;0P2[Zj/208V9R@80RXZ:0P2M
WId409>CT`80YZJV0P2?Shl209bLW080PX:20P2HV9P3092@T080UIFE0P2HV9P209BDU080Shn?0P2J
VYX209RHV0@0Ti>C0P2IVIT2096AT@80Ti>C0P2BTY8209VIV@80TI6A0P2CTi<20492@Pl0oooo000=
0?ooo`80B4Q8102BTY8209RHV080UIFE0P2GUiL209VIV@80VYZJ0P2HV9P609:BTP80Vi^K0P2?Shl2
09RHV0<0TI6A0P2GUiL2092@T080V9RH0P2@T90209>CT`@0TY:B0P2ATI4209JFUP80V9RH102DU9@2
08>3P`80WIfM0P2DU9@209VIV@80SHf=0P2DU9@20:2PX080SHf=0P2MWId20861P@80X:2P0P2BTY82
0:FUY@80WinO0P2DU9@20<?3``80HV9R0P2JVYX2092@T0<0Shn?0P2ATI4209JFUP80TI6A0P2JVYX2
09RHV080UIFE0P2DU9@2096AT@80UYJF102DU9@208n?S`80T92@0P2<S8`209BDU080TY:B0P2FUYH2
09RHV080SXj>0P2?Shl209RHV080U9BD0P2>SXh209^KV`80UiNG0P2DU9@209fMW@80S8b<0P2HV9P2
09JFUP80Xj>S0`29RHT209^KV`80Rh^;0P1nOWh20:RXZ080WYjN0P2VYZH209NGU`80QXJ60P2>SXh2
09>CT`80UYJF0P2GUiL209>CT`80Xj>S0P1nOWh2096AT@80XJ6Q0P2?Shl209ZJVP80Rh^;0P2[Zj/2
08V9R@80RXZ:0P2MWId409>CT`80YZJV0P2?Shl209bLW080PX:20P2HV9P3092@T080UIFE0P2HV9P2
09BDU080Shn?0P2JVYX209RHV0@0Ti>C0P2IVIT2096AT@80Ti>C0P2BTY8209VIV@80TI6A0P2CTi<2
0492@Pl0oooo000=0?ooo`80@T920P2DU9@209>CT`80TI6A0P2GUiL6092@T080TY:B0P2DU9@209>C
T`80U9BD0P2ATI4209ZJVP80UiNG0`2ATI4209RHV080Shn?0P2FUYH2092@T080VIVI0P2BTY8209NG
U`80VIVI0P2FUYH208f=S@80VIVI0P2<S8`208n?S`80WIfM0P2:RXX209VIV@80UiNG0P2IVIT2096A
T@80WYjN0P2HV9P208Z:RP80TY:B102FUYH208j>SP80Ti>C0P2e]KD2079bLP80UIFE0P2HV9P309^K
V`@0UYJF0P2KVi/2096AT@80UiNG0P2DU9@209fMW@80V9RH0P2DU9@209bLW080UYJF0P2ATI420:2P
X080U9BD0P2BTY8209bLW080SHf=0P2>SXh20:6QX@80TY:B0P2ATI4208f=S@80VIVI0P2CTi<2092@
T080RXZ:0P2QXJ4207moO`80Ti>C0P2ZZZX208R8R0<0TY:B0P2?Shl2092@T080XJ6Q0P2DU9@20;fm
_@80Q8B40P22PX820:ZZZP80Rh^;0P2SXj<209FEU@80TY:B0P29RHT209VIV@80P8200P2NWYh209:B
TP80R8R80P2IVIT208j>SP80WYjN0P28R8P20:2PX080U9BD102SXj<208j>SP80Shn?0P2BTY8209>C
T`80U9BD0`2NWYh208n?S`80Ti>C0P2HV9P2096AT@@0UYJF0P2CTi<209BDU080TY:B0P2LW9`209:B
TP80VIVI0P2ATI4209RHV080Ti>C0P12@T8?0?ooo`003@3oool20492@P80U9BD0P2CTi<2096AT@80
UiNG1P2@T90209:BTP80U9BD0P2CTi<209BDU080TI6A0P2JVYX209NGU`<0TI6A0P2HV9P208n?S`80
UYJF0P2@T90209VIV@80TY:B0P2GUiL209VIV@80UYJF0P2=SHd209VIV@80S8b<0P2?Shl209fMW@80
RXZ:0P2IVIT209NGU`80VIVI0P2ATI4209jNWP80V9RH0P2:RXX209:BTP@0UYJF0P2>SXh209>CT`80
]KFe0P1bLW8209FEU@80V9RH0`2KVi/409JFUP80Vi^K0P2ATI4209NGU`80U9BD0P2MWId209RHV080
U9BD0P2LW9`209JFUP80TI6A0P2PX:0209BDU080TY:B0P2LW9`208f=S@80SXj>0P2QXJ4209:BTP80
TI6A0P2=SHd209VIV@80Ti>C0P2@T90208Z:RP80XJ6Q0P1oOgl209>CT`80ZZZZ0P28R8P309:BTP80
Shn?0P2@T9020:6QX@80U9BD0P2m_Kd208B4Q080PX:20P2ZZZX208^;R`80Xj>S0P2EUID209:BTP80
RHV90P2IVIT20820P080WYjN0P2BTY8208R8R080VIVI0P2>SXh209jNWP80R8R80P2PX:0209BDU0@0
Xj>S0P2>SXh208n?S`80TY:B0P2CTi<209BDU0<0WYjN0P2?Shl209>CT`80V9RH0P2ATI4409JFUP80
Ti>C0P2DU9@209:BTP80W9bL0P2BTY8209VIV@80TI6A0P2HV9P209>CT`80@T923`3oool000d0oooo
0P12@T8209>CT`80VIVI0P2@T90209FEU@80UYJF0P2IVIT209NGU`80V9RH0P2ATI4209RHV080Ti>C
0P2DU9@2096AT@80TY:B0`2ATI4209VIV@80UiNG0P2DU9@209VIV@80TI6A0P2BTY8209NGU`80T92@
0P2?Shl209RHV080TI6A0P2;Rh/409ZJVP80Ti>C0P2QXJ4208j>SP80Vi^K0P2BTY8209FEU@80UiNG
0P2;Rh/20:2PX080UIFE0P2JVYX209:BTP80UIFE0P30`<02075aL@80Vi^K0P2NWYh308f=S@80WIfM
0P2HV9P209fMW@80U9BD0P2HV9P209JFUP80T92@0P2FUYH209:BTP80UIFE0P2OWil20::RXP80S8b<
0P2LW9`209>CT`80U9BD0P2FUYH209NGU`80S8b<0P2>SXh209ZJVP80UYJF0P2@T90209ZJVP80U9BD
0P2LW9`209RHV080PX:20P2FUYH20:RXZ080T92@0`22PX8209fMW@80V9RH0P2MWId209NGU`80RXZ:
0P2HV9P208Z:RP80SHf=0P2IVIT208J6QP80Zj^[0P2;Rh/209JFUP80Rh^;0P2TY:@209RHV080WYjN
0P2EUID208n?S`80VYZJ0P25QHD208b<S080WIfM0P2;Rh/209fMW@80RHV9102QXJ4207inOP80WinO
0P2JVYX308b<S080W9bL0P2>SXh209:BTP80Ti>C0P2BTY8209RHV080Ti>C0P2DU9@209>CT`80TY:B
0P2DU9@409>CT`80V9RH0P2ATI4204I6APl0oooo000=0?ooo`80@T920P2CTi<209VIV@80T92@0P2E
UID209JFUP80VIVI0P2GUiL209RHV080TI6A0P2HV9P209>CT`80U9BD0P2ATI4209:BTP<0TI6A0P2I
VIT209NGU`80U9BD0P2IVIT2096AT@80TY:B0P2GUiL2092@T080Shn?0P2HV9P2096AT@80Rh^;102J
VYX209>CT`80XJ6Q0P2>SXh209^KV`80TY:B0P2EUID209NGU`80Rh^;0P2PX:0209FEU@80VYZJ0P2B
TY8209FEU@80`<300P1aLG4209^KV`80WYjN0`2=SHd209fMW@80V9RH0P2MWId209BDU080V9RH0P2F
UYH2092@T080UYJF0P2BTY8209FEU@80WinO0P2RXZ8208b<S080W9bL0P2CTi<209BDU080UYJF0P2G
UiL208b<S080SXj>0P2JVYX209JFUP80T92@0P2JVYX209BDU080W9bL0P2HV9P208:2PP80UYJF0P2X
Z:P2092@T0<0PX:20P2MWId209RHV080WIfM0P2GUiL208Z:RP80V9RH0P2:RXX208f=S@80VIVI0P26
QXH20:^[Z`80Rh^;0P2FUYH208^;R`80Y:BT0P2HV9P209jNWP80UIFE0P2?Shl209ZJVP80QHF50P2<
S8`209fMW@80Rh^;0P2MWId208V9R@@0XJ6Q0P1nOWh209nOW`80VYZJ0`2<S8`209bLW080SXj>0P2B
TY8209>CT`80TY:B0P2HV9P209>CT`80U9BD0P2CTi<209:BTP80U9BD102CTi<209RHV080TI6A0P16
ATH?0?ooo`003@3oool204Q8B080TY:B0P2@T90409^KV`80Shn?0P2FUYH2096AT@80TY:B0P2HV9P2
09NGU`80Ti>C0P2BTY8209^KV`80TI6A0`2IVIT208n?S`80V9RH0P2DU9@209NGU`@0TY:B0P2GUiL2
09FEU@80UiNG0P2EUID209:BTP80RXZ:0P2CTi<2096AT@80U9BD0P2JVYX209BDU080Shn?0P2LW9`2
07YjNP80Xj>S0P1nOWh20;Ng]`80QhN70P2GUiL209>CT`80Xj>S0P2`/;0208:2PP80Rh^;0P2@T903
09:BTP80Shn?0P2>SXh208^;R`80V9RH0P2DU9@209:BTP80UiNG0P2DU9@209:BTP80T92@0P2>SXh2
08b<S080YjNW0P2KVi/209RHV0@0Ti>C0P2JVYX209^KV`80WIfM0P2<S8`209BDU080VYZJ0P2@T902
09JFUP80V9RH0P2IVIT207moO`80[Jf]0P2QXJ4208n?S`<0TY:B0P2EUID20:6QX@80YJFU0P1gMgL2
0:^[Z`80U9BD0P27QhL2096AT@80U9BD0P2MWId209RHV0@0T92@102=SHd208R8R080VYZJ0P2<S8`2
09bLW080][Jf0P21PH4208Z:RP80WinO0P2NWYh208f=S@@0UYJF0P1mOGd209>CT`80SXj>0P2CTi<3
09:BTP80U9BD0P2FUYH209:BTP80V9RH102ATI4409:BTP80VIVI102CTi<409BDU080TY:B0P2GUiL2
04U9B@l0oooo000=0?ooo`80B4Q80P2BTY82092@T0@0Vi^K0P2?Shl209JFUP80TI6A0P2BTY8209RH
V080UiNG0P2CTi<209:BTP80Vi^K0P2ATI4309VIV@80Shn?0P2HV9P209BDU080UiNG102BTY8209NG
U`80UIFE0P2GUiL209FEU@80TY:B0P2:RXX209>CT`80TI6A0P2DU9@209ZJVP80U9BD0P2?Shl209bL
W080NWYj0P2SXj<207inOP80]kNg0P27QhL209NGU`80Ti>C0P2SXj<20;2`/080PX:20P2;Rh/2092@
T0<0TY:B0P2?Shl208j>SP80Rh^;0P2HV9P209BDU080TY:B0P2GUiL209BDU080TY:B0P2@T90208j>
SP80S8b<0P2WYjL209^KV`80V9RH102CTi<209ZJVP80Vi^K0P2MWId208b<S080U9BD0P2JVYX2092@
T080UYJF0P2HV9P209VIV@80Ogmo0P2][Jd20:6QX@80Shn?0`2BTY8209FEU@80XJ6Q0P2UYJD207Mg
M`80Zj^[0P2DU9@208N7Q`80TI6A0P2DU9@209fMW@80V9RH102@T90408f=S@80R8R80P2JVYX208b<
S080W9bL0P2f][H20861P@80RXZ:0P2OWil209jNWP80SHf=102FUYH207emO@80Ti>C0P2>SXh209>C
T`<0TY:B0P2DU9@209JFUP80TY:B0P2HV9P4096AT@@0TY:B0P2IVIT409>CT`@0U9BD0P2BTY8209NG
U`80BDU93`3oool000d0oooo0P10@40209RHV080UiNG102@T902096AT@80V9RH0P2ATI4209BDU0@0
Ti>C0P2DU9@2096AT@80UYJF0P2BTY83096AT@80V9RH0P2ATI4208n?S`80Vi^K0P2@T90209RHV080
SXj>0P2FUYH209FEU@80Ti>C0P2;Rh/209bLW080UiNG0P2FUYH409FEU@80Shn?0P2XZ:P209:BTP80
WinO0P26QXH209>CT`80YZJV0P2<S8`208j>SP80VIVI0P34a<@209NGU`80OWin0P2HV9P208V9R@<0
V9RH0P2DU9@209RHV080UYJF0P2@T90209:BTP80SXj>0P2IVIT209BDU080Ti>C0P2FUYH409>CT`80
SHf=0P2ATI420:2PX080Y:BT0P2EUID4092@T080S8b<0P2SXj<209>CT`80T92@0P2BTY84096AT@80
W9bL0P1mOGd20:2PX080TY:B0P1mOGd30:>SX`80U9BD0P2HV9P2092@T080N7Qh0P2a/K42092@T080
V9RH0P2>SXh209bLW080WinO0P2IVIT209BDU080XZ:R0P2=SHd209NGU`80UYJF0P2DU9@208V9R@80
YjNW0P2@T90208f=S@80Ti>C0P2BTY8209bLW080O7al0P2/[:`20:2PX080PX:20P2FUYH20:>SX`80
TI6A0`2LW9`208j>SP80V9RH0P2@T90209ZJVP80UYJF0P2JVYX409NGU`80TI6A0P2CTi<209VIV@80
Ti>C0P2DU9@409>CT`80@D513`3oool000d0oooo0P10@40209RHV080UiNG102@T902096AT@80V9RH
0P2ATI4209BDU0@0Ti>C0P2DU9@2096AT@80UYJF0P2BTY83096AT@80V9RH0P2ATI4208n?S`80Vi^K
0P2@T90209RHV080SXj>0P2FUYH209FEU@80Ti>C0P2;Rh/209bLW080UiNG0P2FUYH409FEU@80Shn?
0P2XZ:P209:BTP80WinO0P26QXH209>CT`80YZJV0P2<S8`208j>SP80VIVI0P34a<@209NGU`80OWin
0P2HV9P208V9R@<0V9RH0P2DU9@209RHV080UYJF0P2@T90209:BTP80SXj>0P2IVIT209BDU080Ti>C
0P2FUYH409>CT`80SHf=0P2ATI420:2PX080Y:BT0P2EUID4092@T080S8b<0P2SXj<209>CT`80T92@
0P2BTY84096AT@80W9bL0P1mOGd20:2PX080TY:B0P1mOGd30:>SX`80U9BD0P2HV9P2092@T080N7Qh
0P2a/K42092@T080V9RH0P2>SXh209bLW080WinO0P2IVIT209BDU080XZ:R0P2=SHd209NGU`80UYJF
0P2DU9@208V9R@80YjNW0P2@T90208f=S@80Ti>C0P2BTY8209bLW080O7al0P2/[:`20:2PX080PX:2
0P2FUYH20:>SX`80TI6A0`2LW9`208j>SP80V9RH0P2@T90209ZJVP80UYJF0P2JVYX409NGU`80TI6A
0P2CTi<209VIV@80Ti>C0P2DU9@409>CT`80@D513`3oool000d0oooo0P18B4P2092@T080VYZJ0P2B
TY8209RHV080VYZJ0P2@T90209ZJVP80TI6A0P2CTi<209BDU080Ti>C0P2GUiL209RHV080T92@0`2H
V9P209JFUP80T92@0P2FUYH209FEU@80TI6A0P2GUiL209VIV@80UiNG0P2DU9@2092@T080Q8B40P2A
TI4209NGU`80VYZJ0P2>SXh209NGU`80TY:B0P29RHT209>CT`80VIVI0P1kNg/20;2`/080UiNG0P29
RHT20:>SX`80c<c<0P2=SHd207AdM0@0SXj>0P2IVIT308j>SP80W9bL0P2;Rh/209NGU`80Shn?0P2D
U9@209JFUP80TY:B0P2=SHd209ZJVP80Ti>C0P2HV9P2092@T080UYJF102?Shl208V9R@80YZJV0P2H
V9P209FEU@80UiNG0P29RHT209RHV080SXj>0P2BTY8209^KV`80SHf=0P2KVi/20;:b/P80Ng]k0P2X
Z:P206e]K@<0];Bd0P2KVi/20:^[Z`80[:b/0P1gMgL208>3P`80YJFU0P2DU9@207YjNP80YZJV0P1n
OWh20::RXP80UYJF0P2<S8`208n?S`80S8b<0P29RHT208N7Q`80^[Zj0P28R8P209JFUP80TI6A0P2R
XZ8209JFUP80Shn?0P2GUiL20:VYZ@80MWIf0P2CTi<20::RXP@0T92@0`2DU9@4096AT@80VYZJ0P2A
TI4209:BTP80TI6A0P2@T90409NGU`80TY:B0P2CTi<209BDU080Ti>C0P2IVIT209>CT`80@d=33`3o
ool000d0oooo0P18B4P2092@T080VYZJ0P2BTY8209RHV080VYZJ0P2@T90209ZJVP80TI6A0P2CTi<2
09BDU080Ti>C0P2GUiL209RHV080T92@0`2HV9P209JFUP80T92@0P2FUYH209FEU@80TI6A0P2GUiL2
09VIV@80UiNG0P2DU9@2092@T080Q8B40P2ATI4209NGU`80VYZJ0P2>SXh209NGU`80TY:B0P29RHT2
09>CT`80VIVI0P1kNg/20;2`/080UiNG0P29RHT20:>SX`80c<c<0P2=SHd207AdM0@0SXj>0P2IVIT3
08j>SP80W9bL0P2;Rh/209NGU`80Shn?0P2DU9@209JFUP80TY:B0P2=SHd209ZJVP80Ti>C0P2HV9P2
092@T080UYJF102?Shl208V9R@80YZJV0P2HV9P209FEU@80UiNG0P29RHT209RHV080SXj>0P2BTY82
09^KV`80SHf=0P2KVi/20;:b/P80Ng]k0P2XZ:P206e]K@<0];Bd0P2KVi/20:^[Z`80[:b/0P1gMgL2
08>3P`80YJFU0P2DU9@207YjNP80YZJV0P1nOWh20::RXP80UYJF0P2<S8`208n?S`80S8b<0P29RHT2
08N7Q`80^[Zj0P28R8P209JFUP80TI6A0P2RXZ8209JFUP80Shn?0P2GUiL20:VYZ@80MWIf0P2CTi<2
0::RXP@0T92@0`2DU9@4096AT@80VYZJ0P2ATI4209:BTP80TI6A0P2@T90409NGU`80TY:B0P2CTi<2
09BDU080Ti>C0P2IVIT209>CT`80@d=33`3oool000d0oooo0P11@D4209VIV@80TY:B0P2CTi<2096A
T@@0TY:B0P2JVYX209JFUP80VYZJ0P2CTi<209BDU080T92@0P2GUiL209JFUP<0TI6A0P2GUiL409JF
UP80UiNG102CTi<209:BTP80Shn?102DU9@209VIV@80S8b<0P2OWil208n?S`80VIVI0P2KVi/20:>S
X`80UIFE0P2@T90209:BTP80T92@0P2YZJT208J6QP80SXj>0P3>c/h204i>CP80NWYj0P2ATI4209BD
U080TI6A0P2BTY8309FEU@80TI6A0P2BTY8209ZJVP80V9RH0P2FUYH208f=S@80UYJF0P2DU9@2096A
T@80S8b<0P2?Shl209^KV`80UYJF0P2?Shl409>CT`80RHV90P2UYJD20::RXP80VYZJ0P2?Shl209ZJ
VP80Ti>C0P2EUID209:BTP80Rh^;0P2QXJ420:^[Z`80IfMW0P3>c/h206][J`<0Shn?0P2OWil207Ad
M080][Jf0P2/[:`207AdM080a<C40P2DU9@208n?S`80YZJV0P28R8P2096AT@80VIVI0P2FUYH209fM
W@80R8R80P2>SXh409>CT`80WYjN0P2BTY8208j>SP80VIVI0P2=SHd209NGU`80VYZJ0P2@T90208N7
Q`80WIfM0P2JVYX2092@T080V9RH0`2?Shl209ZJVP80TI6A0P2GUiL409:BTP80UiNG0P2HV9P2096A
T@80UiNG0P2HV9P209:BTP@0U9BD102CTi<204=3@`l0oooo000=0?ooo`80@D510P2IVIT209:BTP80
Ti>C0P2ATI4409:BTP80VYZJ0P2FUYH209ZJVP80Ti>C0P2DU9@2092@T080UiNG0P2FUYH3096AT@80
UiNG102FUYH209NGU`@0Ti>C0P2BTY8208n?S`@0U9BD0P2IVIT208b<S080WinO0P2?Shl209VIV@80
Vi^K0P2SXj<209FEU@80T92@0P2BTY82092@T080ZJVY0P26QXH208j>SP80c/k>0P1>CTh207YjNP80
TI6A0P2DU9@2096AT@80TY:B0`2EUID2096AT@80TY:B0P2JVYX209RHV080UYJF0P2=SHd209JFUP80
U9BD0P2ATI4208b<S080Shn?0P2KVi/209JFUP80Shn?102CTi<208V9R@80YJFU0P2RXZ8209ZJVP80
Shn?0P2JVYX209>CT`80UIFE0P2BTY8208^;R`80XJ6Q0P2[Zj/206MWI`80c/k>0P1[Jf/308n?S`80
WinO0P1dM7@20;Jf]P80[:b/0P1dM7@20<C4a080U9BD0P2?Shl20:JVYP80R8R80P2ATI4209VIV@80
UYJF0P2MWId208R8R080SXj>102CTi<209jNWP80TY:B0P2>SXh209VIV@80SHf=0P2GUiL209ZJVP80
T92@0P27QhL209fMW@80VYZJ0P2@T90209RHV0<0Shn?0P2JVYX2096AT@80UiNG102BTY8209NGU`80
V9RH0P2ATI4209NGU`80V9RH0P2BTY8409BDU0@0Ti>C0P13@d<?0?ooo`003@3oool20451@@@0Ti>C
0P2BTY8209bLW0H0TY:B102ATI4209>CT`80TI6A0P2IVIT209>CT`80UiNG0`2BTY82096AT@80UYJF
0P2@T90209>CT`80U9BD102BTY8209FEU@80U9BD0P2<S8`209VIV@80SHf=0P2PX:0209BDU080Ti>C
0P2BTY8209>CT`80SXj>0P2FUYH208V9R@80WIfM0P2KVi/208n?S`80^KVi0P2GUiL207YjNP80TI6A
0P2LW9`209>CT`80UiNG1@2BTY8209>CT`@0T92@0P2=SHd209NGU`80U9BD0P2FUYH209BDU080TY:B
0P2JVYX209bLW080SXj>0P2BTY8209JFUP80TI6A0P2CTi<2092@T080W9bL0P1lO7`20:VYZ@80VIVI
0P2ATI4209NGU`80TI6A0P2DU9@209RHV080T92@0P2VYZH207MgM`80UiNG0P2:RXX308B4Q080]kNg
0P2n_[h208j>SP80R8R8101nOWh208^;R`80Ti>C0P26QXH20;2`/080RHV90P2GUiL209:BTP@0UYJF
0P2?Shl208F5Q@80WYjN0P2SXj<208f=S@80YJFU0P2JVYX408F5Q@80U9BD0P2VYZH209nOW`@0S8b<
102CTi<3092@T080V9RH0P2ATI4209RHV080TY:B0P2GUiL209JFUP80TI6A102BTY82096AT@80V9RH
0P2BTY8209BDU080TY:B0P2IVIT20492@Pl0oooo000=0?ooo`80@D51102CTi<209:BTP80W9bL1P2B
TY84096AT@80Ti>C0P2ATI4209VIV@80Ti>C0P2GUiL309:BTP80TI6A0P2FUYH2092@T080Ti>C0P2D
U9@409:BTP80UIFE0P2DU9@208b<S080VIVI0P2=SHd20:2PX080U9BD0P2CTi<209:BTP80Ti>C0P2>
SXh209JFUP80RHV90P2MWId209^KV`80Shn?0P2i^KT209NGU`80NWYj0P2ATI4209bLW080Ti>C0P2G
UiL509:BTP80Ti>C102@T90208f=S@80UiNG0P2DU9@209JFUP80U9BD0P2BTY8209ZJVP80W9bL0P2>
SXh209:BTP80UYJF0P2ATI4209>CT`80T92@0P2LW9`207alO080ZJVY0P2IVIT2096AT@80UiNG0P2A
TI4209BDU080V9RH0P2@T9020:JVYP80MgMg0P2GUiL208Z:RP<0Q8B40P2g]kL20;jn_P80SXj>0P28
R8P407inOP80Rh^;0P2CTi<208J6QP80/;2`0P29RHT209NGU`80TY:B102FUYH208n?S`80QHF50P2N
WYh20:>SX`80SHf=0P2UYJD209ZJVP@0QHF50P2DU9@20:JVYP80WinO102<S8`409>CT`<0T92@0P2H
V9P2096AT@80V9RH0P2BTY8209NGU`80UYJF0P2ATI4409:BTP80TI6A0P2HV9P209:BTP80U9BD0P2B
TY8209VIV@80@T923`3oool000d0oooo0P1:BTX2096AT@80V9RH102CTi<209:BTP80VYZJ0P2ATI44
09RHV080TY:B0P2HV9P409BDU080V9RH0`2@T90209RHV080UYJF0P2JVYX209>CT`80TY:B0P2NWYh2
08n?S`80UIFE0P2?Shl209>CT`80T92@0P2FUYH209NGU`80S8b<0P2GUiL2096AT@80YJFU0P2ATI42
09nOW`80NWYj0P2a/K4209NGU`80Xj>S0P2l_;`206QXJ080U9BD0P2BTY8209>CT`80U9BD0P2EUID2
08f=S@<0Vi^K0P2;Rh/409VIV@80Rh^;0P2EUID208n?S`80TI6A0P2CTi<209:BTP80Shn?0P2;Rh/2
09VIV@80Ti>C0P2?Shl209JFUPH0TY:B0P2CTi<208^;R`80[:b/0P2DU9@208b<S080WIfM0P27QhL2
09bLW080Rh^;0P2j^[X208n?S`80HF5Q0P3Cdm<3069RHP80XJ6Q0P1YJFT20<G5a@80P8200P2n_[h2
07IfMP80/;2`0P2<S8`209JFUP80R8R80P2EUID208F5Q@80[jn_0P1mOGd20:b/[080QhN70P1cLg<2
0:^[Z`80YjNW0P29RHT209>CT`80Shn?0P2JVYX209JFUP80WinO0P2JVYX208f=S@80T92@0P2HV9P2
09:BTP80V9RH0`2FUYH2092@T080V9RH102BTY8409NGU`80TI6A0P2HV9P209NGU`80TY:B0P2GUiL2
09RHV080TI6A0P2IVIT209:BTP80@d=33`3oool000d0oooo0P1:BTX2096AT@80V9RH102CTi<209:B
TP80VYZJ0P2ATI4409RHV080TY:B0P2HV9P409BDU080V9RH0`2@T90209RHV080UYJF0P2JVYX209>C
T`80TY:B0P2NWYh208n?S`80UIFE0P2?Shl209>CT`80T92@0P2FUYH209NGU`80S8b<0P2GUiL2096A
T@80YJFU0P2ATI4209nOW`80NWYj0P2a/K4209NGU`80Xj>S0P2l_;`206QXJ080U9BD0P2BTY8209>C
T`80U9BD0P2EUID208f=S@<0Vi^K0P2;Rh/409VIV@80Rh^;0P2EUID208n?S`80TI6A0P2CTi<209:B
TP80Shn?0P2;Rh/209VIV@80Ti>C0P2?Shl209JFUPH0TY:B0P2CTi<208^;R`80[:b/0P2DU9@208b<
S080WIfM0P27QhL209bLW080Rh^;0P2j^[X208n?S`80HF5Q0P3Cdm<3069RHP80XJ6Q0P1YJFT20<G5
a@80P8200P2n_[h207IfMP80/;2`0P2<S8`209JFUP80R8R80P2EUID208F5Q@80[jn_0P1mOGd20:b/
[080QhN70P1cLg<20:^[Z`80YjNW0P29RHT209>CT`80Shn?0P2JVYX209JFUP80WinO0P2JVYX208f=
S@80T92@0P2HV9P209:BTP80V9RH0`2FUYH2092@T080V9RH102BTY8409NGU`80TI6A0P2HV9P209NG
U`80TY:B0P2GUiL209RHV080TI6A0P2IVIT209:BTP80@d=33`3oool000d0oooo0P17AdL2096AT@80
UiNG0P2CTi<209BDU080Ti>C0P2FUYH209NGU`@0TI6A0P2BTY82096AT@@0UiNG0P2@T90309RHV0@0
TI6A0P2@T90209:BTP80Ti>C0P2ATI4209FEU@80VIVI0P2<S8`209^KV`80Ph>30P2NWYh2092@T080
X:2P0P2:RXX209NGU`80UIFE0P2?Shl208V9R@80WinO0P2KVi/208^;R`80_kno0P1NGUh209:BTP80
Ti>C0P2ATI4209:BTP80TI6A0P2FUYH2096AT@<0Ti>C0P2ATI4208n?S`80SXj>0P2@T90208b<S080
UYJF0P2EUID209>CT`80RXZ:0P2FUYH2096AT@80UYJF0P2BTY8209bLW080UIFE0P2DU9@4096AT@@0
Ti>C0P24Q8@20:ZZZP80[:b/0P29RHT209nOW`80Shn?0P2PX:0209bLW080X:2P0P1iNGT2096AT@<0
];Bd0P1QHF420=;BdP80LW9b0P2WYjL208R8R080V9RH0P28R8P20:RXZ080TY:B0P21PH420;Rh^080
RXZ:0P2LW9`208j>SP80UiNG0P2HV9P20:2PX080NWYj0P2HV9P20;:b/P80VIVI0P2=SHd209nOW`80
TY:B0P2CTi<209:BTP80Q8B40P2RXZ82096AT@80TY:B0P2HV9P308n?S`80V9RH0P2FUYH2096AT@80
UiNG102ATI4209RHV080T92@0P2HV9P409>CT`80TY:B0P2IVIT209:BTP80U9BD0P12@T8?0?ooo`00
3@3oool204M7A`80TI6A0P2GUiL209>CT`80U9BD0P2CTi<209JFUP80UiNG102ATI4209:BTP80TI6A
102GUiL2092@T0<0V9RH102ATI42092@T080TY:B0P2CTi<2096AT@80UIFE0P2IVIT208b<S080Vi^K
0P23Ph<209jNWP80T92@0P2PX:0208Z:RP80UiNG0P2EUID208n?S`80RHV90P2OWil209^KV`80Rh^;
0P2o_kl205iNGP80TY:B0P2CTi<2096AT@80TY:B0P2ATI4209JFUP80TI6A0`2CTi<2096AT@80Shn?
0P2>SXh2092@T080S8b<0P2FUYH209FEU@80Ti>C0P2:RXX209JFUP80TI6A0P2FUYH209:BTP80W9bL
0P2EUID209BDU0@0TI6A102CTi<208B4Q080ZZZZ0P2/[:`208V9R@80WinO0P2?Shl20:2PX080W9bL
0P2PX:0207UiN@80TI6A0`2d];@2065QH@80d];B0P1bLW820:NWY`80R8R80P2HV9P208R8R080Z:RX
0P2BTY820861P@80^;Rh0P2:RXX209bLW080SXj>0P2GUiL209RHV080X:2P0P1jNWX209RHV080/[:b
0P2IVIT208f=S@80WinO0P2BTY8209>CT`80TY:B0P24Q8@20::RXP80TI6A0P2BTY8209RHV0<0Shn?
0P2HV9P209JFUP80TI6A0P2GUiL4096AT@80V9RH0P2@T90209RHV0@0Ti>C0P2BTY8209VIV@80TY:B
0P2DU9@20492@Pl0oooo000=0?ooo`80@T920P2BTY8209RHV080Ti>C0P2DU9@209:BTP80V9RH0P2A
TI4209RHV080UiNG0P2FUYH209RHV0@0TY:B0P2IVIT3096AT@@0UiNG0P2HV9P209NGU`80V9RH0P2B
TY8208j>SP80U9BD0P2JVYX208n?S`80UiNG102KVi/209>CT`80WYjN0P2GUiL209BDU080QXJ60P2^
[Zh209>CT`80YJFU0P3Ti>@205MGE`80TY:B0P2?Shl209BDU0@0V9RH102BTY8209BDU0<0UiNG0P2I
VIT209FEU@80UiNG0P2FUYH209BDU080VIVI0P2BTY8209NGU`80V9RH0P2IVIT4096AT@80U9BD0P2A
TI42092@T080UiNG0P2CTi<209BDU080UIFE0P2BTY8208V9R@80QHF50P2BTY8209ZJVP80Ti>C102@
T90209NGU`80VIVI0P2SXj<207YjNP<0QHF50P2PX:0206i^KP80UiNG0P26QXH20<K6aP80TY:B0P22
PX8209FEU@80T92@0P2WYjL208n?S`80X:2P0P23Ph<209fMW@80UiNG0P2BTY8208R8R080OGem0P2^
[Zh2096AT@80QhN70P2IVIT20:FUY@80Ti>C0P2KVi/207]kN`80XZ:R0P2:RXX209FEU@80U9BD0P2J
VYX3096AT@80TY:B0P2HV9P2092@T080VYZJ0P2HV9P209:BTP80UYJF0P2HV9P209:BTP80Ti>C102D
U9@209>CT`80U9BD0P2CTi<204Q8B0l0oooo000=0?ooo`80@T920P2BTY8209RHV080Ti>C0P2DU9@2
09:BTP80V9RH0P2ATI4209RHV080UiNG0P2FUYH209RHV0@0TY:B0P2IVIT3096AT@@0UiNG0P2HV9P2
09NGU`80V9RH0P2BTY8208j>SP80U9BD0P2JVYX208n?S`80UiNG102KVi/209>CT`80WYjN0P2GUiL2
09BDU080QXJ60P2^[Zh209>CT`80YJFU0P3Ti>@205MGE`80TY:B0P2?Shl209BDU0@0V9RH102BTY82
09BDU0<0UiNG0P2IVIT209FEU@80UiNG0P2FUYH209BDU080VIVI0P2BTY8209NGU`80V9RH0P2IVIT4
096AT@80U9BD0P2ATI42092@T080UiNG0P2CTi<209BDU080UIFE0P2BTY8208V9R@80QHF50P2BTY82
09ZJVP80Ti>C102@T90209NGU`80VIVI0P2SXj<207YjNP<0QHF50P2PX:0206i^KP80UiNG0P26QXH2
0<K6aP80TY:B0P22PX8209FEU@80T92@0P2WYjL208n?S`80X:2P0P23Ph<209fMW@80UiNG0P2BTY82
08R8R080OGem0P2^[Zh2096AT@80QhN70P2IVIT20:FUY@80Ti>C0P2KVi/207]kN`80XZ:R0P2:RXX2
09FEU@80U9BD0P2JVYX3096AT@80TY:B0P2HV9P2092@T080VYZJ0P2HV9P209:BTP80UYJF0P2HV9P2
09:BTP80Ti>C102DU9@209>CT`80U9BD0P2CTi<204Q8B0l0oooo000=0?ooo`80@T920P2HV9P209:B
TP80U9BD0P2BTY8209VIV@80TY:B0P2DU9@209>CT`80TI6A0P2GUiL209:BTP@0U9BD1@2CTi<209NG
U`@0U9BD0P2@T902096AT@80UiNG0P2ATI4208j>SP80UIFE0P2>SXh209:BTP80SHf=0P2LW9`208b<
S080SXj>0P2SXj<408Z:RP80X:2P0P2HV9P20:RXZ080Cdm?0P28R8P209:BTP80T92@0P2BTY8209JF
UP80Ti>C0P2>SXh208N7Q`80Rh^;0`28R8P208n?S`80U9BD0P2IVIT209RHV080UiNG0P2EUID209BD
U080Q8B40P2?Shl208Z:RP80SXj>0P2NWYh208n?S`80U9BD0P2ATI4209RHV080U9BD0P2GUiL209>C
T`80U9BD0P2KVi/208n?S`80QhN70P2VYZH20:2PX080SHf=0P2DU9@20:>SX`80WIfM0P2EUID207Ad
M0<0YZJV0P36a/H206m_K`80[:b/0P22PX82096AT@80[Zj^0P2VYZH207moO`80UYJF0P2OWil20820
P080WinO0P23Ph<209jNWP80PX:20P2QXJ4209jNWP80Ph>3102EUID209RHV080TY:B0P2DU9@209RH
V080W9bL0P28R8P209FEU@80T92@0P2EUID209:BTP80SXj>0`2HV9P2096AT@80T92@0P2KVi/2092@
T0@0Ti>C0P2HV9P2096AT@80Ti>C0P2IVIT209:BTP@0U9BD0P2CTi<209BDU080@T923`3oool000d0
oooo0P12@T8209RHV080TY:B0P2DU9@209:BTP80VIVI0P2BTY8209BDU080Ti>C0P2ATI4209NGU`80
TY:B102DU9@509>CT`80UiNG102DU9@2092@T080TI6A0P2GUiL2096AT@80SXj>0P2EUID208j>SP80
TY:B0P2=SHd209bLW080S8b<0P2>SXh20:>SX`@0RXZ:0P2PX:0209RHV080Z:RX0P1?Cdl208R8R080
TY:B0P2@T90209:BTP80UYJF0P2CTi<208j>SP80QhN70P2;Rh/308R8R080Shn?0P2DU9@209VIV@80
V9RH0P2GUiL209FEU@80U9BD0P24Q8@208n?S`80RXZ:0P2>SXh209jNWP80Shn?0P2DU9@2096AT@80
V9RH0P2DU9@209NGU`80Ti>C0P2DU9@209^KV`80Shn?0P27QhL20:JVYP80X:2P0P2=SHd209BDU080
Xj>S0P2MWId209FEU@80M7Ad0`2VYZH20<K6aP80Kfm_0P2/[:`208:2PP80TI6A0P2^[Zh20:JVYP80
Ogmo0P2FUYH209nOW`80P8200P2OWil208>3P`80WYjN0P22PX820:6QX@80WYjN0P23Ph<409FEU@80
V9RH0P2BTY8209BDU080V9RH0P2LW9`208R8R080UIFE0P2@T90209FEU@80TY:B0P2>SXh309RHV080
TI6A0P2@T90209^KV`80T92@102CTi<209RHV080TI6A0P2CTi<209VIV@80TY:B102DU9@209>CT`80
U9BD0P12@T8?0?ooo`003@3oool20492@P80UiNG102BTY8209VIV@80TI6A1P2DU9@209>CT`80UiNG
0P2CTi<209BDU0@0Ti>C0`2DU9@209:BTP80UIFE0P2GUiL209VIV@80T92@0P2EUID2092@T080WYjN
0P2HV9P20861P@80VYZJ0P2OWil2096AT@80WinO0P28R8P209RHV080UYJF0P2RXZ8209NGU`80X:2P
0P3Fe]H207=cL`80UIFE0P2FUYH409NGU`80TY:B0P27QhL208>3P`80/[:b0P2f][H30:b/[080[Jf]
0P2LW9`209^KV`80WinO0P2QXJ4209BDU080Zj^[0P2WYjL20:JVYP80[:b/102;Rh/209NGU`80T92@
0P2DU9@2092@T080UYJF0P2BTY8209BDU080V9RH0P2@T90209>CT`80UiNG0P1jNWX20:j^[P80XJ6Q
0P2ATI420:6QX@80UiNG0P2FUYH208^;R`<0M7Ad0P2MWId209RHV080N7Qh0P2EUID208J6QP80Rh^;
0P2FUYH20:JVYP80T92@0P21PH420:ZZZP80WinO0P2HV9P208N7Q`80[:b/0P25QHD209VIV@80TI6A
0P27QhL209nOW`80OGem0P2NWYh209VIV@80RHV90P2FUYH209fMW@80Ti>C0P2BTY8209VIV@80UiNG
0P2IVIT308j>SP80VIVI0P2FUYH2092@T080V9RH102CTi<2096AT@80VIVI0P2CTi<2096AT@80VIVI
0P2CTi<209:BTP80V9RH0P2CTi<20492@Pl0oooo000=0?ooo`80@T920P2GUiL409:BTP80VIVI0P2A
TI4609BDU080Ti>C0P2GUiL209>CT`80U9BD102CTi<309BDU080TY:B0P2EUID209NGU`80VIVI0P2@
T90209FEU@80T92@0P2NWYh209RHV080PH610P2JVYX209nOW`80TI6A0P2OWil208R8R080V9RH0P2F
UYH20::RXP80UiNG0P2PX:020=KFeP80Lg=c0P2EUID209JFUP@0UiNG0P2BTY8208N7Q`80Ph>30P2b
/[820;Jf]P<0[:b/0P2][Jd209bLW080Vi^K0P2OWil20:6QX@80U9BD0P2[Zj/20:NWY`80YZJV0P2/
[:`408^;R`80UiNG0P2@T90209BDU080T92@0P2FUYH209:BTP80U9BD0P2HV9P2092@T080Ti>C0P2G
UiL207YjNP80[Zj^0P2QXJ42096AT@80XJ6Q0P2GUiL209JFUP80Rh^;0`1dM7@209fMW@80V9RH0P1h
N7P209FEU@80QXJ60P2;Rh/209JFUP80YZJV0P2@T9020861P@80ZZZZ0P2OWil209RHV080QhN70P2/
[:`208F5Q@80VIVI0P2ATI4208N7Q`80WinO0P1mOGd209jNWP80VIVI0P29RHT209JFUP80WIfM0P2C
Ti<209:BTP80VIVI0P2GUiL209VIV@<0SXj>0P2IVIT209JFUP80T92@0P2HV9P409>CT`80TI6A0P2I
VIT209>CT`80TI6A0P2IVIT209>CT`80TY:B0P2HV9P209>CT`80@T923`3oool000d0oooo0P11@D42
09RHV080TI6A0P2IVIT2092@T080VIVI0P2BTY8209BDU080Ti>C0P2BTY8209RHV0@0TY:B0P2GUiL2
09VIV@D0TI6A0P2FUYH4096AT@80VIVI0P2<S8`209:BTP80SXj>0P20P80209NGU`80TY:B0P2HV9P2
09BDU080TI6A0P2CTi<20:6QX@80Ph>30P2ATI4209jNWP80_;bl0P1>CTh2092@T080UYJF0P2DU9@2
09JFUP80Shn?0P29RHT20:NWY`80X:2P0P2BTY8209RHV0<0GUiN0P1bLW8209:BTP80TI6A0P1lO7`2
06QXJ080TI6A0P22PX8208Z:RP80T92@0P2FUYH20:RXZ080R8R80P2=SHd209RHV080Ti>C0P2ATI42
09VIV@80UiNG0P2ATI4209>CT`80U9BD0P2HV9P209>CT`80U9BD0P20P8020:6QX@80Z:RX0P2GUiL2
0:JVYP80MgMg0P3Ti>@306UYJ@80KFe]0P3<c<`206m_K`80^k^k0P22PX8208J6QP80YjNW0P2GUiL2
07]kN`80^;Rh0P23Ph<209FEU@80Shn?0P2DU9@209FEU@80UiNG0P2DU9@208n?S`80P8200P2UYJD2
0:^[Z`80UiNG0P2CTi<20:BTY080OWin0P2BTY84096AT@80Vi^K0P2=SHd2096AT@<0VYZJ0P2EUID2
09NGU`80TY:B0P2HV9P2096AT@@0V9RH0P2BTY8209>CT`80VIVI0P2BTY8209>CT`80V9RH0P2GUiL2
09:BTP80B4Q83`3oool000d0oooo0P11@D4209RHV080TI6A0P2IVIT2092@T080VIVI0P2BTY8209BD
U080Ti>C0P2BTY8209RHV0@0TY:B0P2GUiL209VIV@D0TI6A0P2FUYH4096AT@80VIVI0P2<S8`209:B
TP80SXj>0P20P80209NGU`80TY:B0P2HV9P209BDU080TI6A0P2CTi<20:6QX@80Ph>30P2ATI4209jN
WP80_;bl0P1>CTh2092@T080UYJF0P2DU9@209JFUP80Shn?0P29RHT20:NWY`80X:2P0P2BTY8209RH
V0<0GUiN0P1bLW8209:BTP80TI6A0P1lO7`206QXJ080TI6A0P22PX8208Z:RP80T92@0P2FUYH20:RX
Z080R8R80P2=SHd209RHV080Ti>C0P2ATI4209VIV@80UiNG0P2ATI4209>CT`80U9BD0P2HV9P209>C
T`80U9BD0P20P8020:6QX@80Z:RX0P2GUiL20:JVYP80MgMg0P3Ti>@306UYJ@80KFe]0P3<c<`206m_
K`80^k^k0P22PX8208J6QP80YjNW0P2GUiL207]kN`80^;Rh0P23Ph<209FEU@80Shn?0P2DU9@209FE
U@80UiNG0P2DU9@208n?S`80P8200P2UYJD20:^[Z`80UiNG0P2CTi<20:BTY080OWin0P2BTY84096A
T@80Vi^K0P2=SHd2096AT@<0VYZJ0P2EUID209NGU`80TY:B0P2HV9P2096AT@@0V9RH0P2BTY8209>C
T`80VIVI0P2BTY8209>CT`80V9RH0P2GUiL209:BTP80B4Q83`3oool000d0oooo0P18B4P2096AT@80
VIVI0P2ATI4209RHV080T92@0P2IVIT2096AT@@0UiNG0P2ATI4209NGU`80UYJF102EUID309NGU`80
UIFE0P2HV9P209:BTP80TI6A0P2IVIT208V9R@80WIfM0P2BTY8209jNWP80WIfM0P2FUYH208R8R080
YjNW0P2ATI4209^KV`80N7Qh0P2c/k<209JFUP80];Bd0P2LW9`207emO@80Ti>C0P2@T90209FEU@80
Ti>C0P2:RXX207EeM@80XJ6Q1021PH4208f=S@<0X:2P0P2JVYX209FEU@80Ph>30P2PX:0209FEU@80
Vi^K0P2ATI4209^KV`80IFEU0P2:RXX20820P080ZJVY0P1fMWH208N7Q`80TI6A0P2DU9@209:BTP80
SXj>0P2DU9@209NGU`80UYJF0P2@T90209NGU`80Shn?0P2>SXh207moO`80YZJV0P1oOgl20:b/[080
W9bL1@27QhL208b<S080Xj>S0P2EUID207EeM@80[:b/0P2;Rh/206QXJ080[Zj^0P2`/;0208f=S@80
R8R80P2YZJT209bLW080RXZ:0P2EUID208^;R`80XZ:R102<S8`20:6QX@80VYZJ0P2BTY820:BTY080
XJ6Q0P22PX8209JFUP80SXj>0P2IVIT209^KV`80SXj>0P2CTi<709:BTP80Ti>C0P2BTY8209VIV@80
TY:B0P2CTi<409BDU080Ti>C0P2DU9@209>CT`@0TY:B0P2DU9@20492@Pl0oooo000=0?ooo`80B4Q8
0P2ATI4209VIV@80TI6A0P2HV9P2092@T080VIVI0P2ATI4409NGU`80TI6A0P2GUiL209JFUP@0UIFE
0`2GUiL209FEU@80V9RH0P2BTY82096AT@80VIVI0P29RHT209fMW@80TY:B0P2NWYh209fMW@80UYJF
0P28R8P20:NWY`80TI6A0P2KVi/207QhN080/k>c0P2FUYH20;Bd]080W9bL0P1mOGd209>CT`80T92@
0P2EUID209>CT`80RXZ:0P1eMGD20:6QX@@0PH610P2=SHd30:2PX080VYZJ0P2EUID208>3P`80X:2P
0P2EUID209^KV`80TI6A0P2KVi/206EUI@80RXZ:0P20P8020:VYZ@80MWIf0P27QhL2096AT@80U9BD
0P2BTY8208j>SP80U9BD0P2GUiL209JFUP80T92@0P2GUiL208n?S`80SXj>0P1oOgl20:JVYP80Ogmo
0P2/[:`209bLW0D0QhN70P2<S8`20:>SX`80UIFE0P1eMGD20:b/[080Rh^;0P1XJ6P20:j^[P80/;2`
0P2=SHd208R8R080ZJVY0P2LW9`208Z:RP80UIFE0P2;Rh/20::RXP@0S8b<0P2QXJ4209ZJVP80TY:B
0P2TY:@20:6QX@80PX:20P2FUYH208j>SP80VIVI0P2KVi/208j>SP80Ti>C1`2BTY8209>CT`80TY:B
0P2IVIT209:BTP80Ti>C102DU9@209>CT`80U9BD0P2CTi<409:BTP80U9BD0P12@T8?0?ooo`003@3o
ool20451@@H0TY:B102GUiL2092@T080UiNG0P2EUID209NGU`80TI6A0P2GUiL209FEU@80UYJF1@2@
T90409FEU@80T92@0P2FUYH209BDU080Rh^;0P2GUiL2092@T080VYZJ0P29RHT209JFUP80UIFE0P2Q
XJ4208V9R@80U9BD0P2^[Zh208^;R`80[jn_0P2j^[X206=SH`80SXj>0P2CTi<209VIV@80UIFE0P2;
Rh/20;Bd]0@0Zj^[0P30`<020;>c/`80Z:RX0`2DU9@20:RXZ080ZJVY0P2RXZ820:FUY@80ZJVY0P2h
^;P20:^[Z`80WinO0P3<c<`20;Bd]080_kno103:b/X20:BTY080S8b<0P2DU9@2096AT@80VIVI0P2E
UID208n?S`80Vi^K0P2DU9@209>CT`80Rh^;0P2JVYX208f=S@80Rh^;0P2e]KD20:>SX`80Q8B40P2E
UID30:RXZ080R8R80P1^KVh20=KFeP80K6a/0P2a/K4209:BTP80SXj>0P1`L7020:>SX`80PX:20P2_
[jl208J6QP80Vi^K0P2CTi<2096AT@80[jn_0P2:RXX208b<S080TI6A0P28R8P209ZJVP80QhN70P2P
X:0209fMW@80TY:B0P2=SHd209VIV@80TI6A0P2@T90209^KV`80TI6A0`2BTY8209VIV@80TY:B0P2I
VIT209>CT`80TY:B102DU9@209>CT`@0U9BD0P2BTY8209VIV@80TY:B0P2HV9P209>CT`80@d=33`3o
ool000d0oooo0P11@D4609:BTP@0UiNG0P2@T90209NGU`80UIFE0P2GUiL2096AT@80UiNG0P2EUID2
09JFUPD0T92@102EUID2092@T080UYJF0P2DU9@208^;R`80UiNG0P2@T90209ZJVP80RHV90P2FUYH2
09FEU@80XJ6Q0P29RHT209BDU080[Zj^0P2;Rh/20:n_[`80^[Zj0P1SHf<208j>SP80Ti>C0P2IVIT2
09FEU@80Rh^;0P2d];@40:^[Z`80`<300P2c/k<20:RXZ0<0U9BD0P2XZ:P20:VYZ@80XZ:R0P2UYJD2
0:VYZ@80^;Rh0P2[Zj/209nOW`80c<c<0P2d];@20;no_`@0b/[:0P2TY:@208b<S080U9BD0P2ATI42
09VIV@80UIFE0P2?Shl209^KV`80U9BD0P2CTi<208^;R`80VYZJ0P2=SHd208^;R`80]KFe0P2SXj<2
08B4Q080UIFE0`2XZ:P208R8R080KVi^0P3Fe]H206a/K080/K6a0P2BTY8208j>SP80L71`0P2SXj<2
08:2PP80[jn_0P26QXH209^KV`80Ti>C0P2ATI420:n_[`80RXZ:0P2<S8`2096AT@80R8R80P2JVYX2
08N7Q`80X:2P0P2MWId209:BTP80SHf=0P2IVIT2096AT@80T92@0P2KVi/2096AT@<0TY:B0P2IVIT2
09:BTP80VIVI0P2CTi<209:BTP@0U9BD0P2CTi<409BDU080TY:B0P2IVIT209:BTP80V9RH0P2CTi<2
04=3@`l0oooo000=0?ooo`80AdM70P2FUYH209NGU`80TY:B0P2ATI4209NGU`80V9RH0P2ATI4209NG
U`80T92@0P2HV9P2096AT@80V9RH0P2ATI4209RHV0<0UiNG0P2EUID209JFUP@0UIFE0P2ATI4209>C
T`80T92@0P2>SXh209VIV@80U9BD0P2OWil20:FUY@80RXZ:0P2GUiL209BDU080Shn?0P2@T9020;Ng
]`80D51@0P2;Rh/209ZJVP80Ti>C0P2>SXh209NGU`80T92@0P2FUYH207YjNP80W9bL0P2VYZH20:BT
Y080/;2`0`2UYJD20;:b/P80Z:RX0P2CTi<20;6a/@80ZJVY0P2RXZ820:>SX`80XZ:R0P2VYZH207al
O080OGem0P1nOWh207emO@80Shn?0P2ATI4209>CT`80VIVI0P2DU9@209JFUP80Shn?0P2BTY8209VI
V@80U9BD0P2ATI44092@T080QhN70P2NWYh20:FUY@80ZJVY0P2QXJ43092@T080VIVI0P1eMGD207em
O@80]kNg0P1aLG420;6a/@80MgMg0P2FUYH206YZJP80`/;20P2@T902096AT@80VYZJ0P2;Rh/2096A
T@80[:b/0P24Q8@209VIV@80T92@0P22PX820:f][@80QXJ60P2RXZ8208>3P`80S8b<0P2DU9@209FE
U@80VIVI0P2BTY8209FEU@D0UiNG0P2BTY8209BDU0@0Ti>C0P2IVIT209>CT`80TY:B0P2IVIT209:B
TP80Ti>C0P2IVIT409:BTP80V9RH0P2CTi<204=3@`l0oooo000=0?ooo`80AdM70P2FUYH209NGU`80
TY:B0P2ATI4209NGU`80V9RH0P2ATI4209NGU`80T92@0P2HV9P2096AT@80V9RH0P2ATI4209RHV0<0
UiNG0P2EUID209JFUP@0UIFE0P2ATI4209>CT`80T92@0P2>SXh209VIV@80U9BD0P2OWil20:FUY@80
RXZ:0P2GUiL209BDU080Shn?0P2@T9020;Ng]`80D51@0P2;Rh/209ZJVP80Ti>C0P2>SXh209NGU`80
T92@0P2FUYH207YjNP80W9bL0P2VYZH20:BTY080/;2`0`2UYJD20;:b/P80Z:RX0P2CTi<20;6a/@80
ZJVY0P2RXZ820:>SX`80XZ:R0P2VYZH207alO080OGem0P1nOWh207emO@80Shn?0P2ATI4209>CT`80
VIVI0P2DU9@209JFUP80Shn?0P2BTY8209VIV@80U9BD0P2ATI44092@T080QhN70P2NWYh20:FUY@80
ZJVY0P2QXJ43092@T080VIVI0P1eMGD207emO@80]kNg0P1aLG420;6a/@80MgMg0P2FUYH206YZJP80
`/;20P2@T902096AT@80VYZJ0P2;Rh/2096AT@80[:b/0P24Q8@209VIV@80T92@0P22PX820:f][@80
QXJ60P2RXZ8208>3P`80S8b<0P2DU9@209FEU@80VIVI0P2BTY8209FEU@D0UiNG0P2BTY8209BDU0@0
Ti>C0P2IVIT209>CT`80TY:B0P2IVIT209:BTP80Ti>C0P2IVIT409:BTP80V9RH0P2CTi<204=3@`l0
oooo000=0?ooo`80@410102GUiL209:BTP80VIVI1P2BTY8209RHV080TI6A0P2GUiL609:BTP80Ti>C
0`2ATI4209RHV080SXj>0P2DU9@209RHV080SXj>0P29RHT4092@T080VIVI0P2MWId208N7Q`80T92@
0P2HV9P208j>SP80W9bL0P2BTY8209jNWP80bl_;0P1aLG4209ZJVP80TY:B0P2DU9@209ZJVP80T92@
0P2HV9P208n?S`80SHf=0P26QXH207UiN@80MGEe0P20P80308:2PP80Kfm_0P20P80208:2PP80MGEe
0P1/K6`207QhN080Lg=c0P1kNg/208>3P`80QHF50P2@T90209:BTP80UIFE0P2BTY8209FEU@80U9BD
0P2BTY8209BDU080UYJF0P2CTi<209JFUP80T92@0P2FUYH208n?S`80UYJF1029RHT208n?S`80TY:B
0P2j^[X206e]K@<0YJFU0P2XZ:P20:BTY080QhN70P2^[Zh207inOP80/;2`0P2ZZZX208F5Q@80SHf=
0P2LW9`209BDU080TY:B0P2RXZ820:BTY080SHf=0P27QhL208V9R@80YjNW0P2;Rh/208F5Q@80XZ:R
0P2HV9P20;Jf]P80PX:20P2BTY8409>CT`80Vi^K0P2?Shl209>CT`80TI6A0`2GUiL209>CT`80U9BD
0P2CTi<409:BTP80Ti>C0P2IVIT2096AT@80VIVI1P2CTi<209VIV@80TY:B0P2DU9@20492@Pl0oooo
000=0?ooo`80@410102GUiL209:BTP80VIVI1P2BTY8209RHV080TI6A0P2GUiL609:BTP80Ti>C0`2A
TI4209RHV080SXj>0P2DU9@209RHV080SXj>0P29RHT4092@T080VIVI0P2MWId208N7Q`80T92@0P2H
V9P208j>SP80W9bL0P2BTY8209jNWP80bl_;0P1aLG4209ZJVP80TY:B0P2DU9@209ZJVP80T92@0P2H
V9P208n?S`80SHf=0P26QXH207UiN@80MGEe0P20P80308:2PP80Kfm_0P20P80208:2PP80MGEe0P1/
K6`207QhN080Lg=c0P1kNg/208>3P`80QHF50P2@T90209:BTP80UIFE0P2BTY8209FEU@80U9BD0P2B
TY8209BDU080UYJF0P2CTi<209JFUP80T92@0P2FUYH208n?S`80UYJF1029RHT208n?S`80TY:B0P2j
^[X206e]K@<0YJFU0P2XZ:P20:BTY080QhN70P2^[Zh207inOP80/;2`0P2ZZZX208F5Q@80SHf=0P2L
W9`209BDU080TY:B0P2RXZ820:BTY080SHf=0P27QhL208V9R@80YjNW0P2;Rh/208F5Q@80XZ:R0P2H
V9P20;Jf]P80PX:20P2BTY8409>CT`80Vi^K0P2?Shl209>CT`80TI6A0`2GUiL209>CT`80U9BD0P2C
Ti<409:BTP80Ti>C0P2IVIT2096AT@80VIVI1P2CTi<209VIV@80TY:B0P2DU9@20492@Pl0oooo000=
0?ooo`80AdM70P2ATI4809:BTP80VIVI0P2BTY8409>CT`80V9RH0P2BTY8209NGU`80V9RH1@2BTY82
09FEU@80UiNG0P2DU9@2096AT@80Ti>C0P2TY:@208R8R080SXj>0P2JVYX209VIV@80WinO0P2DU9@2
08b<S080[:b/0P2>SXh209>CT`80^;Rh0P1YJFT208R8R080TY:B0P2CTi<209NGU`80SXj>0P2JVYX2
08j>SP80Vi^K0P2BTY8209JFUP80T92@0P2HV9P208b<S0<0UIFE0P2<S8`209VIV@80U9BD0P2FUYH2
09BDU080WYjN0P2JVYX209RHV080UiNG0P2BTY8209RHV080UIFE0P28R8P209ZJVP80UiNG0P2?Shl2
09:BTP80UYJF0P2CTi<209BDU080UYJF0P2ATI4209JFUP80WinO0P2DU9@208f=S@80U9BD0P2?Shl2
0:n_[`80Y:BT0P22PX8309NGU`80K6a/0P2LW9`206EUI@80YZJV0P2b/[8207YjNP80VIVI0P2:RXX2
08n?S`80O7al0P28R8P20::RXP80TY:B0P26QXH20:>SX`80WIfM0P2TY:@209^KV`80QXJ60P24Q8@2
0:BTY080PH610P2b/[8207QhN080T92@0P2MWId409:BTP80TI6A0P2DU9@209>CT`<0UiNG102BTY82
09RHV080UiNG0P2HV9P209>CT`80TY:B0P2DU9@209>CT`80U9BD1P2CTi<209BDU080Ti>C0P18B4P?
0?ooo`003@3oool204M7A`80TI6A202BTY8209VIV@80TY:B102CTi<209RHV080TY:B0P2GUiL209RH
V0D0TY:B0P2EUID209NGU`80U9BD0P2ATI4209>CT`80Y:BT0P28R8P208j>SP80VYZJ0P2IVIT209nO
W`80U9BD0P2<S8`20:b/[080SXj>0P2CTi<20;Rh^080JFUY0P28R8P209:BTP80Ti>C0P2GUiL208j>
SP80VYZJ0P2>SXh209^KV`80TY:B0P2FUYH2092@T080V9RH0P2<S8`309FEU@80S8b<0P2IVIT209BD
U080UYJF0P2DU9@209jNWP80VYZJ0P2HV9P209NGU`80TY:B0P2HV9P209FEU@80R8R80P2JVYX209NG
U`80Shn?0P2BTY8209JFUP80Ti>C0P2DU9@209JFUP80TI6A0P2FUYH209nOW`80U9BD0P2=SHd209BD
U080Shn?0P2_[jl20:BTY080PX:20`2GUiL206a/K080W9bL0P1UIFD20:JVYP80/[:b0P1jNWX209VI
V@80RXZ:0P2?Shl207alO080R8R80P2RXZ8209:BTP80QXJ60P2SXj<209fMW@80Y:BT0P2KVi/208J6
QP80Q8B40P2TY:@20861P@80/[:b0P1hN7P2092@T080WIfM102BTY82096AT@80U9BD0P2CTi<309NG
U`@0TY:B0P2HV9P209NGU`80V9RH0P2CTi<209:BTP80U9BD0P2CTi<209BDU0H0Ti>C0P2DU9@209>C
T`80B4Q83`3oool000d0oooo0P17AdL2096AT@80V9RH102FUYH209RHV080TI6A0P2KVi/209:BTP80
U9BD102CTi<209RHV080TI6A0P2IVIT309:BTP80UiNG0P2DU9@209JFUP80TI6A0P20P80208b<S080
WinO0P2MWId20:>SX`80PX:20P2PX:0208j>SP80Y:BT0P28R8P209:BTP80U9BD0P2i^KT206ATI080
TI6A0P2HV9P209BDU080TI6A0P2HV9P209JFUP80TI6A0P2EUID209>CT`@0UIFE0P2DU9@209FEU@<0
U9BD0P2CTi<209FEU@80TY:B0P2CTi<208f=S@80V9RH0P2@T90208n?S`80V9RH0P2@T90209^KV`80
Rh^;0P2OWil208R8R080Vi^K0P2HV9P209ZJVP80UiNG0P2>SXh409FEU@80VYZJ0P2;Rh/2096AT@80
UIFE0P2=SHd208^;R`80Shn?0P2EUID208N7Q`80_[jn0`29RHT20:JVYP80Vi^K0P2YZJT208b<S080
XJ6Q0P26QXH209nOW`80VIVI0P1oOgl208N7Q`80/;2`0P2<S8`209^KV`80SHf=0P2OWil208N7Q`80
[Jf]0P2<S8`209RHV080RHV90P2BTY820:>SX`80Z:RX0P2=SHd4092@T080ZJVY0P29RHT209VIV@@0
Ti>C0`2HV9P209:BTP80VIVI0P2ATI4209:BTP@0Ti>C0P2HV9P609>CT`@0V9RH0P2CTi<409BDU080
@T923`3oool000d0oooo0P17AdL2096AT@80V9RH102FUYH209RHV080TI6A0P2KVi/209:BTP80U9BD
102CTi<209RHV080TI6A0P2IVIT309:BTP80UiNG0P2DU9@209JFUP80TI6A0P20P80208b<S080WinO
0P2MWId20:>SX`80PX:20P2PX:0208j>SP80Y:BT0P28R8P209:BTP80U9BD0P2i^KT206ATI080TI6A
0P2HV9P209BDU080TI6A0P2HV9P209JFUP80TI6A0P2EUID209>CT`@0UIFE0P2DU9@209FEU@<0U9BD
0P2CTi<209FEU@80TY:B0P2CTi<208f=S@80V9RH0P2@T90208n?S`80V9RH0P2@T90209^KV`80Rh^;
0P2OWil208R8R080Vi^K0P2HV9P209ZJVP80UiNG0P2>SXh409FEU@80VYZJ0P2;Rh/2096AT@80UIFE
0P2=SHd208^;R`80Shn?0P2EUID208N7Q`80_[jn0`29RHT20:JVYP80Vi^K0P2YZJT208b<S080XJ6Q
0P26QXH209nOW`80VIVI0P1oOgl208N7Q`80/;2`0P2<S8`209^KV`80SHf=0P2OWil208N7Q`80[Jf]
0P2<S8`209RHV080RHV90P2BTY820:>SX`80Z:RX0P2=SHd4092@T080ZJVY0P29RHT209VIV@@0Ti>C
0`2HV9P209:BTP80VIVI0P2ATI4209:BTP@0Ti>C0P2HV9P609>CT`@0V9RH0P2CTi<409BDU080@T92
3`3oool000d0oooo0P17AdL2096AT@80V9RH102FUYH209RHV080TI6A0P2KVi/209:BTP80U9BD102C
Ti<209RHV080TI6A0P2IVIT309:BTP80UiNG0P2DU9@209JFUP80TI6A0P20P80208b<S080WinO0P2M
WId20:>SX`80PX:20P2PX:0208j>SP80Y:BT0P28R8P209:BTP80U9BD0P2i^KT206ATI080TI6A0P2H
V9P209BDU080TI6A0P2HV9P209JFUP80TI6A0P2EUID209>CT`@0UIFE0P2DU9@209FEU@<0U9BD0P2C
Ti<209FEU@80TY:B0P2CTi<208f=S@80V9RH0P2@T90208n?S`80V9RH0P2@T90209^KV`80Rh^;0P2O
Wil208R8R080Vi^K0P2HV9P209ZJVP80UiNG0P2>SXh409FEU@80VYZJ0P2;Rh/2096AT@80UIFE0P2=
SHd208^;R`80Shn?0P2EUID208N7Q`80_[jn0`29RHT20:JVYP80Vi^K0P2YZJT208b<S080XJ6Q0P26
QXH209nOW`80VIVI0P1oOgl208N7Q`80/;2`0P2<S8`209^KV`80SHf=0P2OWil208N7Q`80[Jf]0P2<
S8`209RHV080RHV90P2BTY820:>SX`80Z:RX0P2=SHd4092@T080ZJVY0P29RHT209VIV@@0Ti>C0`2H
V9P209:BTP80VIVI0P2ATI4209:BTP@0Ti>C0P2HV9P609>CT`@0V9RH0P2CTi<409BDU080@T923`3o
ool000d0oooo0P11@D4209VIV@80TI6A102GUiL209:BTP80U9BD0P2BTY8209VIV@80TY:B102DU9@2
09>CT`80U9BD1@2BTY82096AT@80UiNG0P2DU9@208^;R`80X:2P0P27QhL209ZJVP80V9RH0P2>SXh2
0:b/[080PX:20P2YZJT208V9R@80Zj^[0P2?Shl208j>SP80g=cL0P1WIfL209NGU`80UYJF0P2DU9@4
09>CT`80TY:B0P2JVYX209>CT`H0U9BD0P2FUYH209:BTP<0Shn?0P2DU9@208^;R`80Vi^K0P28R8P2
09NGU`80V9RH0P2CTi<208n?S`80UYJF0P2EUID209>CT`80SHf=0P2KVi/209fMW@80SHf=0P2:RXX2
09JFUP80TI6A0P2FUYH2096AT@80UYJF0P2ATI4209RHV080TY:B0P2JVYX209bLW080SXj>0P28R8P2
09^KV`80[:b/0P2OWil3092@T080R8R80P2<S8`209:BTP80Ng]k0P2GUiL20:>SX`80YJFU0P1kNg/2
0:f][@80WinO0P1aLG4208V9R@80ZZZZ0P28R8P20;6a/@80OWin0P2GUiL208b<S080XJ6Q0P25QHD2
09>CT`80];Bd0P22PX82096AT@80T92@0P2DU9@209NGU`80UIFE0P2BTY8409BDU0D0Ti>C0P2BTY82
09VIV@80Ti>C0P2DU9@209>CT`80V9RH0P2ATI4209RHV0@0Ti>C0P2BTY8609BDU080@d=33`3oool0
00d0oooo0P11@D4209VIV@80TI6A102GUiL209:BTP80U9BD0P2BTY8209VIV@80TY:B102DU9@209>C
T`80U9BD1@2BTY82096AT@80UiNG0P2DU9@208^;R`80X:2P0P27QhL209ZJVP80V9RH0P2>SXh20:b/
[080PX:20P2YZJT208V9R@80Zj^[0P2?Shl208j>SP80g=cL0P1WIfL209NGU`80UYJF0P2DU9@409>C
T`80TY:B0P2JVYX209>CT`H0U9BD0P2FUYH209:BTP<0Shn?0P2DU9@208^;R`80Vi^K0P28R8P209NG
U`80V9RH0P2CTi<208n?S`80UYJF0P2EUID209>CT`80SHf=0P2KVi/209fMW@80SHf=0P2:RXX209JF
UP80TI6A0P2FUYH2096AT@80UYJF0P2ATI4209RHV080TY:B0P2JVYX209bLW080SXj>0P28R8P209^K
V`80[:b/0P2OWil3092@T080R8R80P2<S8`209:BTP80Ng]k0P2GUiL20:>SX`80YJFU0P1kNg/20:f]
[@80WinO0P1aLG4208V9R@80ZZZZ0P28R8P20;6a/@80OWin0P2GUiL208b<S080XJ6Q0P25QHD209>C
T`80];Bd0P22PX82096AT@80T92@0P2DU9@209NGU`80UIFE0P2BTY8409BDU0D0Ti>C0P2BTY8209VI
V@80Ti>C0P2DU9@209>CT`80V9RH0P2ATI4209RHV0@0Ti>C0P2BTY8609BDU080@d=33`3oool000d0
oooo0P12@T8209>CT`80U9BD102CTi<209BDU080Ti>C0P2DU9@2096AT@80V9RH0P2CTi<209BDU0@0
Ti>C0P2HV9P509NGU`80TI6A0P2>SXh209:BTP80UYJF0P2JVYX208N7Q`80WYjN0P2ATI4208>3P`80
WinO0P2=SHd208j>SP80T92@0P2>SXh20;Bd]080T92@0P22PX8209BDU080UiNG0P2BTY8409BDU080
UIFE0P2=SHd209FEU@80UYJF102DU9@209:BTP80V9RH0`2@T90209VIV@@0WIfM0P2CTi<209BDU080
V9RH0P2DU9@209JFUP80TY:B0P2FUYH2096AT@80V9RH0P2=SHd2092@T080TI6A0P2MWId209FEU@80
UYJF0P2HV9P209JFUP80V9RH0P2BTY8209NGU`80Ti>C0P2>SXh208b<S080V9RH0P2DU9@208b<S080
VIVI0P24Q8@309JFUP80R8R80P2TY:@208N7Q`80XZ:R0P21PH420:b/[080SHf=0P31`L4207AdM080
MgMg0P2WYjL209>CT`80WYjN0P27QhL20:6QX@80W9bL0P2EUID208b<S080VYZJ0P27QhL208j>SP80
^;Rh0P1cLg<20:n_[`80OGem0P2EUID208^;R`80Ti>C1P2DU9@309>CT`80V9RH102CTi<609BDU080
TY:B0P2HV9P209NGU`@0Ti>C0P2HV9P209>CT`@0U9BD0P13@d<?0?ooo`003@3oool20492@P80Ti>C
0P2DU9@409>CT`80U9BD0P2CTi<209BDU080TI6A0P2HV9P209>CT`80U9BD102CTi<209RHV0D0UiNG
0P2ATI4208j>SP80TY:B0P2FUYH209ZJVP80QhN70P2NWYh2096AT@80Ph>30P2OWil208f=S@80SXj>
0P2@T90208j>SP80];Bd0P2@T90208:2PP80U9BD0P2GUiL209:BTP@0U9BD0P2EUID208f=S@80UIFE
0P2FUYH409BDU080TY:B0P2HV9P3092@T080VIVI102MWId209>CT`80U9BD0P2HV9P209BDU080UYJF
0P2BTY8209JFUP80TI6A0P2HV9P208f=S@80T92@0P2ATI4209fMW@80UIFE0P2FUYH209RHV080UYJF
0P2HV9P209:BTP80UiNG0P2CTi<208j>SP80S8b<0P2HV9P209BDU080S8b<0P2IVIT208B4Q0<0UYJF
0P28R8P20:BTY080QhN70P2RXZ820861P@80[:b/0P2=SHd20<71`@80M7Ad0P1gMgL20:NWY`80Ti>C
0P2NWYh208N7Q`80XJ6Q0P2LW9`209FEU@80S8b<0P2JVYX208N7Q`80SXj>0P2h^;P207=cL`80[jn_
0P1mOGd209FEU@80Rh^;0P2CTi<609BDU0<0Ti>C0P2HV9P409>CT`H0U9BD0P2BTY8209RHV080UiNG
102CTi<209RHV080Ti>C102DU9@204=3@`l0oooo000=0?ooo`80B4Q80P2CTi<609BDU080Ti>C0P2I
VIT2096AT@80V9RH0P2GUiL209>CT`80TY:B0P2IVIT409>CT`<0TI6A0P2JVYX209:BTP80UiNG0P22
PX8209:BTP80V9RH0P2IVIT209BDU080WYjN0P2CTi<209:BTP80X:2P0P2QXJ4208n?S`80R8R80P36
a/H205UIF@80Shn?102DU9@209:BTP80U9BD1P2FUYH209BDU080UiNG102CTi<208F5Q@80QXJ60`2I
VIT209jNWP80SXj>0P2NWYh208J6QP80Ph>30P2DU9@209>CT`80R8R80P2CTi<2092@T080V9RH0P2C
Ti<209nOW`80TY:B0P2DU9@208n?S`80W9bL0P28R8P209:BTP80U9BD0P2CTi<209BDU080VIVI0P2D
U9@208n?S`80WinO0P2@T90208V9R@80U9BD0P2JVYX20;Vi^@<0X:2P0P2;Rh/209JFUP80PH610P2[
Zj/20820P080UYJF0P29RHT20;no_`80Hf=S0P2^[Zh209fMW@80IFEU0P2TY:@209JFUP80R8R80P2F
UYH208b<S080Vi^K0P2SXj<208N7Q`80U9BD0P2HV9P2092@T080Shn?0P2DU9@20:f][@80S8b<202D
U9@309>CT`80V9RH0P2CTi<:09BDU0@0Ti>C0P2DU9@209>CT`80V9RH0P2CTi<209BDU080Ti>C0P13
@d<?0?ooo`003@3oool204Q8B080Ti>C1P2DU9@209>CT`80VIVI0P2ATI4209RHV080UiNG0P2CTi<2
09:BTP80VIVI102CTi<3096AT@80VYZJ0P2BTY8209NGU`80PX:20P2BTY8209RHV080VIVI0P2DU9@2
09jNWP80Ti>C0P2BTY820:2PX080XJ6Q0P2?Shl208R8R080a/K60P1IFET208n?S`@0U9BD0P2BTY82
09BDU0H0UYJF0P2DU9@209NGU`@0Ti>C0P25QHD208J6QP<0VIVI0P2NWYh208j>SP80WYjN0P26QXH2
08>3P`80U9BD0P2CTi<208R8R080Ti>C0P2@T90209RHV080Ti>C0P2OWil209:BTP80U9BD0P2?Shl2
09bLW080R8R80P2BTY8209BDU080Ti>C0P2DU9@209VIV@80U9BD0P2?Shl209nOW`80T92@0P29RHT2
09BDU080VYZJ0P2i^KT30:2PX080Rh^;0P2FUYH20861P@80Zj^[0P20P80209JFUP80RHV90P2o_kl2
06=SH`80[Zj^0P2MWId206EUI@80Y:BT0P2FUYH208R8R080UYJF0P2<S8`209^KV`80Xj>S0P27QhL2
09BDU080V9RH0P2@T90208n?S`80U9BD0P2][Jd208b<S0P0U9BD0`2CTi<209RHV080Ti>C2P2DU9@4
09>CT`80U9BD0P2CTi<209RHV080Ti>C0P2DU9@209>CT`80@d=33`3oool000d0oooo0P11@D4209>C
T`80U9BD102CTi<209BDU080TY:B0P2IVIT609:BTP80VIVI0P2ATI4709BDU0@0Ti>C0P2>SXh208N7
Q`@0UiNG0P2PX:020:6QX@80TI6A0P2XZ:P208^;R`80UYJF0P2=SHd208b<S080WinO0P3@d=0206AT
I080V9RH0P2FUYH209ZJVP80TY:B0P2KVi/208j>SP80T92@0P2EUID209BDU080TY:B0P2JVYX208J6
QP80][Jf0P3;bl/308F5Q@80SHf=0P2EUID208^;R`80bl_;0P33`l<20:NWY`80SXj>0P2o_kl209BD
U080TI6A0P2EUID208j>SP80TY:B0P2CTi<209BDU080Ti>C0P2=SHd209bLW0@0V9RH0P2BTY8209RH
V080T92@0P2FUYH4092@T080TY:B0P2NWYh208^;R`80U9BD0P2SXj<3092@T080VYZJ0P2ATI4209NG
U`80V9RH102<S8`20:JVYP80Ogmo0P2][Jd209BDU080Ogmo0P2RXZ8208>3P`80X:2P0P29RHT20;6a
/@80T92@0P2SXj<208n?S`80QXJ60P2OWil206UYJ@80][Jf0P1]KFd20<C4a080OWin0P2ATI4;09BD
U080TY:B202DU9@209>CT`X0U9BD0P2BTY8409>CT`80VIVI0P12@T8?0?ooo`003@3oool20451@@80
Ti>C0P2DU9@409>CT`80U9BD0P2BTY8209VIV@H0TY:B0P2IVIT2096AT@L0U9BD102CTi<208j>SP80
QhN7102GUiL20:2PX080XJ6Q0P2ATI420:RXZ080Rh^;0P2FUYH208f=S@80S8b<0P2OWil20=3@d080
I6AT0P2HV9P209JFUP80VYZJ0P2BTY8209^KV`80SXj>0P2@T90209FEU@80U9BD0P2BTY8209ZJVP80
QXJ60P2f][H20<_;b`<0QHF50P2=SHd209FEU@80Rh^;0P3;bl/20<?3``80YjNW0P2>SXh20;no_`80
U9BD0P2ATI4209FEU@80SXj>0P2BTY8209>CT`80U9BD0P2CTi<208f=S@80W9bL102HV9P209:BTP80
V9RH0P2@T90209JFUP@0T92@0P2BTY8209jNWP80Rh^;0P2DU9@20:>SX`<0T92@0P2JVYX2096AT@80
UiNG0P2HV9P408b<S080YZJV0P1oOgl20:f][@80U9BD0P1oOgl20::RXP80Ph>30P2PX:0208V9R@80
/K6a0P2@T9020:>SX`80Shn?0P26QXH209nOW`80JFUY0P2f][H206e]K@80a<C40P1nOWh2096AT@/0
U9BD0P2BTY8809BDU080Ti>C2P2DU9@209:BTP@0Ti>C0P2IVIT20492@Pl0oooo000=0?ooo`80AdM7
0P2HV9P209:BTP@0V9RH202CTi<409NGU`80TI6A0P2IVIT209>CT`80U9BD0`2CTi<209BDU080Ti>C
0P2BTY8208J6QP80Xj>S0P2GUiL209JFUP80OWin0P2JVYX208j>SP80XZ:R0P2EUID208j>SP80UYJF
0P2SXj<20:n_[`80KVi^0P2FUYH2096AT@80TY:B0P2>SXh209JFUP80WYjN0P2?Shl209bLW080Ti>C
0P2GUiL209>CT`80SHf=0P29RHT208Z:RP<0Ti>C0P2DU9@208n?S`80U9BD0P28R8P208:2PP80RHV9
0P24Q8@208Z:RP80Z:RX0P2NWYh209>CT`80Shn?0P2DU9@209FEU@80U9BD0P2BTY820:2PX080S8b<
0P29RHT209>CT`80UiNG0P2CTi<209BDU080UIFE0P2HV9P2092@T080UIFE0P2;Rh/2092@T080OWin
0P2e]KD309^KV`80VYZJ0P2GUiL209JFUP80T92@0P2RXZ8207moO`80XZ:R0P27QhL20=_Kf`80FUYJ
0P2RXZ820:JVYP80Lg=c0P2^[Zh208J6QP80Y:BT0P2JVYX208f=S@80Vi^K0P2IVIT208f=S@80Ti>C
0P2YZJT20;2`/080N7Qh0P2@T90209RHV080Ti>C1P2DU9@309>CT`80VIVI102CTi<209BDU080Ti>C
0P2IVIT209>CT`H0U9BD0P2CTi<209RHV080UiNG102CTi<204=3@`l0oooo000=0?ooo`80AdM70P2H
V9P209:BTP@0V9RH202CTi<409NGU`80TI6A0P2IVIT209>CT`80U9BD0`2CTi<209BDU080Ti>C0P2B
TY8208J6QP80Xj>S0P2GUiL209JFUP80OWin0P2JVYX208j>SP80XZ:R0P2EUID208j>SP80UYJF0P2S
Xj<20:n_[`80KVi^0P2FUYH2096AT@80TY:B0P2>SXh209JFUP80WYjN0P2?Shl209bLW080Ti>C0P2G
UiL209>CT`80SHf=0P29RHT208Z:RP<0Ti>C0P2DU9@208n?S`80U9BD0P28R8P208:2PP80RHV90P24
Q8@208Z:RP80Z:RX0P2NWYh209>CT`80Shn?0P2DU9@209FEU@80U9BD0P2BTY820:2PX080S8b<0P29
RHT209>CT`80UiNG0P2CTi<209BDU080UIFE0P2HV9P2092@T080UIFE0P2;Rh/2092@T080OWin0P2e
]KD309^KV`80VYZJ0P2GUiL209JFUP80T92@0P2RXZ8207moO`80XZ:R0P27QhL20=_Kf`80FUYJ0P2R
XZ820:JVYP80Lg=c0P2^[Zh208J6QP80Y:BT0P2JVYX208f=S@80Vi^K0P2IVIT208f=S@80Ti>C0P2Y
ZJT20;2`/080N7Qh0P2@T90209RHV080Ti>C1P2DU9@309>CT`80VIVI102CTi<209BDU080Ti>C0P2I
VIT209>CT`H0U9BD0P2CTi<209RHV080UiNG102CTi<204=3@`l0oooo000=0?ooo`80@T920P2CTi<2
09BDU0H0TY:B0P2IVIT209>CT`80TY:B0P2GUiL209JFUP80TY:B102CTi<209:BTP<0VYZJ0P2BTY82
09BDU080RHV90P26QXH209^KV`80XZ:R0P2?Shl20;>c/`80UIFE0P2>SXh209ZJVP80Ti>C0P26QXH2
0:6QX@80/k>c0P2KVi/208:2PP80Ti>C0P2GUiL209^KV`80Ti>C0P2BTY82096AT@80Ti>C0P2BTY82
09JFUP80TI6A0P2IVIT208j>SP80WinO0P2?Shl309>CT`80Shn?0P2DU9@208j>SP80UYJF0P2DU9@2
09:BTP80UYJF102ATI4209VIV@80TY:B0P2@T90209FEU@80TY:B0P2EUID209BDU080Shn?0P2NWYh2
09ZJVP80U9BD0P2CTi<209FEU@80TI6A0P2EUID209jNWP@0U9BD102EUID207YjNP80^k^k0`26QXH2
0:ZZZP80PX:20P2:RXX208:2PP80/k>c0P21PH4209bLW080PX:20P3:b/X2079bLP80XJ6Q0P2:RXX2
07IfMP80/[:b0P28R8P209nOW`80TI6A0P2EUID209>CT`80TY:B0P2=SHd208n?S`80W9bL0P2OWil2
08V9R@80Ti>C0P2HV9P209>CT`H0U9BD0`2CTi<209:BTP80Ti>C0P2IVIT209>CT`80U9BD0P2CTi<:
09BDU080TY:B0P2HV9P209>CT`80U9BD0P13@d<?0?ooo`003@3oool20492@P80Ti>C0P2DU9@609:B
TP80VIVI0P2CTi<209:BTP80UiNG0P2FUYH209:BTP@0Ti>C0P2BTY8309ZJVP80TY:B0P2DU9@208V9
R@80QXJ60P2KVi/20::RXP80Shn?0P2c/k<209FEU@80SXj>0P2JVYX209>CT`80QXJ60P2QXJ420;>c
/`80Vi^K0P22PX8209>CT`80UiNG0P2KVi/209>CT`80TY:B0P2ATI4209>CT`80TY:B0P2FUYH2096A
T@80VIVI0P2>SXh209nOW`80Shn?0`2CTi<208n?S`80U9BD0P2>SXh209JFUP80U9BD0P2BTY8209JF
UP@0TI6A0P2IVIT209:BTP80T92@0P2EUID209:BTP80UIFE0P2DU9@208n?S`80WYjN0P2JVYX209BD
U080Ti>C0P2EUID2096AT@80UIFE0P2NWYh409BDU0@0UIFE0P1jNWX20;^k^`<0QXJ60P2ZZZX208:2
PP80RXZ:0P22PX820;>c/`80PH610P2LW9`208:2PP80b/[:0P1bLW820:6QX@80RXZ:0P1fMWH20;:b
/P80R8R80P2OWil2096AT@80UIFE0P2CTi<209:BTP80SHf=0P2?Shl209bLW080WinO0P29RHT209>C
T`80V9RH0P2CTi<609BDU0<0Ti>C0P2BTY8209>CT`80VIVI0P2CTi<209BDU080Ti>C2P2DU9@209:B
TP80V9RH0P2CTi<209BDU080@d=33`3oool000d0oooo0P13@d<209BDU080Ti>C0P2IVIT209:BTP80
VIVI102BTY8209RHV080T92@0P2GUiL209:BTP80Ti>C0P2KVi/2092@T0<0UiNG0P2HV9P209:BTP80
RXZ:0P1hN7P20:JVYP80WinO0P29RHT208Z:RP80Ti>C0P2EUID209:BTP80Rh^;0P28R8P20:6QX@80
/k>c0P1EEED2096AT@80T92@0P2CTi<2092@T080Ti>C0P2DU9@209JFUP80U9BD0P2EUID2092@T080
VYZJ0P2MWId408j>SP80UIFE0`2;Rh/209BDU080UiNG0P2BTY8208n?S`80Ti>C0P2FUYH209>CT`80
TY:B0P2JVYX209BDU080V9RH0P2ATI4209JFUP80TY:B0P2HV9P2096AT@80U9BD0P2BTY8208j>SP80
VYZJ0P2BTY8209JFUP80TI6A0P2DU9@2096AT@80UIFE102DU9@209FEU@80Shn?0P2LW9`30;:b/P80
U9BD0P22PX820<?3``80Ng]k0P2PX:0207inOP80ZZZZ0P2BTY8208j>SP80UIFE0P2CTi<208Z:RP80
UiNG0P2>SXh20:>SX`80PX:20P2MWId209JFUP80[Jf]0P2EUID208N7Q`80WYjN0P2@T90208B4Q080
T92@0P2DU9@409:BTP80Ti>C0P2DU9@209>CT`<0V9RH0P2GUiL409>CT`h0U9BD0P2CTi<209BDU080
Ti>C102DU9@204=3@`l0oooo000=0?ooo`80@d=30P2DU9@209>CT`80VIVI0P2BTY8209VIV@@0TY:B
0P2HV9P2092@T080UiNG0P2BTY8209>CT`80Vi^K0P2@T90309NGU`80V9RH0P2BTY8208Z:RP80N7Qh
0P2VYZH209nOW`80RHV90P2:RXX209>CT`80UIFE0P2BTY8208^;R`80R8R80P2QXJ420;>c/`80EEEE
0P2ATI42092@T080Ti>C0P2@T90209>CT`80U9BD0P2FUYH209BDU080UIFE0P2@T90209ZJVP80WIfM
102>SXh209FEU@<0Rh^;0P2DU9@209NGU`80TY:B0P2?Shl209>CT`80UYJF0P2CTi<209:BTP80VYZJ
0P2DU9@209RHV080TI6A0P2FUYH209:BTP80V9RH0P2ATI4209BDU080TY:B0P2>SXh209ZJVP80TY:B
0P2FUYH2096AT@80U9BD0P2ATI4209FEU@@0U9BD0P2EUID208n?S`80W9bL0`2b/[8209BDU080PX:2
0P33`l<207]kN`80X:2P0P1nOWh20:ZZZP80TY:B0P2>SXh209FEU@80Ti>C0P2:RXX209NGU`80SXj>
0P2SXj<208:2PP80WIfM0P2FUYH20:f][@80UIFE0P27QhL209jNWP80T92@0P24Q8@2092@T080U9BD
102BTY8209>CT`80U9BD0P2CTi<309RHV080UiNG102CTi<>09BDU080Ti>C0P2DU9@209>CT`@0U9BD
0P13@d<?0?ooo`003@3oool20492@P80Ti>C0P2DU9@209>CT`80U9BD0P2BTY8209>CT`80V9RH0P2G
UiL209:BTP80UiNG0P2HV9P209:BTP80TI6A0P2HV9P309:BTP80Ti>C0P2BTY8207inOP@0ZJVY0P23
Ph<20:b/[080Vi^K0P2LW9`209FEU@80Shn?0P20P8020:j^[P80SHf=0P3IfMT2065QH@@0UIFE0P2L
W9`2096AT@80U9BD0P2EUID209>CT`@0U9BD0P2CTi<2092@T080UIFE0P2DU9@209^KV`80TI6A0`2F
UYH2096AT@80Shn?0P2>SXh209^KV`80W9bL0P2IVIT209:BTP80WIfM0P2FUYH209RHV080SXj>0P2C
Ti<209FEU@80TY:B0P2?Shl209RHV0@0UIFE0P2CTi<208n?S`80UIFE0P2HV9P209BDU080TY:B102A
TI4209ZJVP80VIVI0P2BTY8208R8R080Q8B40`2/[:`20:6QX@80TY:B0P1kNg/209FEU@80T92@0P28
R8P20:>SX`80TI6A0P2/[:`209BDU080UIFE0P2KVi/2092@T080MWIf0P2_[jl2092@T080WIfM0P2D
U9@2092@T080P8200P26QXH20<30`080WYjN0P28R8P209VIV@80TY:B0P2HV9P209NGU`80V9RH0P2C
Ti<209BDU0<0TY:B0P2HV9P209>CT`H0U9BD0P2CTi<609BDU080Ti>C0P2HV9P209:BTPH0U9BD0P13
@d<?0?ooo`003@3oool20492@P80Ti>C0P2DU9@209>CT`80U9BD0P2BTY8209>CT`80V9RH0P2GUiL2
09:BTP80UiNG0P2HV9P209:BTP80TI6A0P2HV9P309:BTP80Ti>C0P2BTY8207inOP@0ZJVY0P23Ph<2
0:b/[080Vi^K0P2LW9`209FEU@80Shn?0P20P8020:j^[P80SHf=0P3IfMT2065QH@@0UIFE0P2LW9`2
096AT@80U9BD0P2EUID209>CT`@0U9BD0P2CTi<2092@T080UIFE0P2DU9@209^KV`80TI6A0`2FUYH2
096AT@80Shn?0P2>SXh209^KV`80W9bL0P2IVIT209:BTP80WIfM0P2FUYH209RHV080SXj>0P2CTi<2
09FEU@80TY:B0P2?Shl209RHV0@0UIFE0P2CTi<208n?S`80UIFE0P2HV9P209BDU080TY:B102ATI42
09ZJVP80VIVI0P2BTY8208R8R080Q8B40`2/[:`20:6QX@80TY:B0P1kNg/209FEU@80T92@0P28R8P2
0:>SX`80TI6A0P2/[:`209BDU080UIFE0P2KVi/2092@T080MWIf0P2_[jl2092@T080WIfM0P2DU9@2
092@T080P8200P26QXH20<30`080WYjN0P28R8P209VIV@80TY:B0P2HV9P209NGU`80V9RH0P2CTi<2
09BDU0<0TY:B0P2HV9P209>CT`H0U9BD0P2CTi<609BDU080Ti>C0P2HV9P209:BTPH0U9BD0P13@d<?
0?ooo`003@3oool204M7A`80V9RH0P2CTi<209BDU080TY:B0P2IVIT609>CT`80U9BD0P2CTi<2096A
T@80VIVI0P2ATI4209RHV0<0TY:B0P2CTi<2096AT@80N7Qh0P2/[:`209RHV080VYZJ0P2VYZH208N7
Q`@0TI6A0P29RHT20;Zj^P80SHf=0P2TY:@20=;BdP80KVi^0P2BTY82092@T080Ti>C0P2DU9@409FE
U@H0UiNG0P2FUYH209BDU080TI6A0P2LW9`209>CT`80VYZJ0`2?Shl209^KV`80U9BD0P2JVYX208j>
SP80WIfM0P2BTY8209FEU@80UiNG0P2EUID208f=S@@0UIFE102FUYH209:BTP80VIVI0P2BTY8409FE
U@80T92@0P2HV9P2092@T080UiNG0P2ATI4209RHV080RXZ:0P2CTi<208n?S`80UYJF0P2?Shl208Z:
RP<0][Jf0P20P80209nOW`80SXj>0P2KVi/209NGU`80Vi^K0P22PX8209bLW080WinO0P2:RXX209BD
U080W9bL0P2EUID206i^KP80ZJVY0P2GUiL209fMW@80UYJF0P2PX:0209RHV080T92@0P2CTi<208:2
PP80TI6A0P2CTi<209BDU0H0Ti>C1`2DU9@209>CT`H0U9BD0P2CTi<209VIV@80Ti>C102DU9@209>C
T`80UiNG0P2HV9P209>CT`80U9BD0P2CTi<204=3@`l0oooo000=0?ooo`80AdM70P2HV9P209>CT`80
U9BD0P2BTY8209VIV@H0Ti>C0P2DU9@209>CT`80TI6A0P2IVIT2096AT@80V9RH0`2BTY8209>CT`80
TI6A0P1hN7P20:b/[080V9RH0P2JVYX20:JVYP80QhN7102ATI4208V9R@80^[Zj0P2=SHd20:BTY080
d];B0P1^KVh209:BTP80T92@0P2CTi<209BDU0@0UIFE1P2GUiL209JFUP80U9BD0P2ATI4209bLW080
Ti>C0P2JVYX308n?S`80Vi^K0P2DU9@209ZJVP80SXj>0P2MWId209:BTP80UIFE0P2GUiL209FEU@80
SHf=102EUID409JFUP80TY:B0P2IVIT209:BTP@0UIFE0P2@T90209RHV080T92@0P2GUiL2096AT@80
V9RH0P2:RXX209>CT`80Shn?0P2FUYH208n?S`80RXZ:0`2f][H20820P080WinO0P2>SXh209^KV`80
UiNG0P2KVi/208:2PP80W9bL0P2OWil208Z:RP80U9BD0P2LW9`209FEU@80KVi^0P2YZJT209NGU`80
WIfM0P2FUYH20:2PX080V9RH0P2@T90209>CT`80PX:20P2ATI4209>CT`80U9BD1P2CTi<709BDU080
Ti>C1P2DU9@209>CT`80VIVI0P2CTi<409BDU080Ti>C0P2GUiL209RHV080Ti>C0P2DU9@209>CT`80
@d=33`3oool000d0oooo0P11@D42096AT@@0Ti>C0P2IVIT209:BTPP0U9BD0P2BTY8209RHV080T92@
0P2IVIT2096AT@<0UiNG0P2FUYH209BDU080Jf][0P2QXJ4209bLW080VIVI0P2EUID208j>SP80Vi^K
0P2DU9@207emO@80UIFE0P2QXJ420=GEe@80JVYZ0P24Q8@209VIV@80Ti>C102EUID409JFUP80SHf=
0P2?Shl208f=S@80UYJF102CTi<2092@T080UIFE0P2MWId3092@T080SXj>0P2FUYH209RHV080W9bL
0P2DU9@209RHV080T92@0P2CTi<209BDU080Ti>C0P2?Shl209VIV@80UYJF0P2HV9P208f=S@80U9BD
102GUiL209JFUP80TY:B0P2KVi/209VIV@80TY:B0P2GUiL209JFUP80VYZJ0P2>SXh209VIV@80WIfM
0P2DU9@207inOP<0ZZZZ0P2h^;P208b<S080/K6a0P27QhL208^;R`80Y:BT0P2DU9@208J6QP80Xj>S
0P2JVYX208J6QP80UYJF0P2HV9P206i^KP80^k^k0P1dM7@20;2`/080Ogmo0P2a/K4207emO@80SXj>
0P2XZ:P208R8R100U9BD0`2CTi<409BDU0@0Ti>C0P2DU9@409>CT`80U9BD0P2CTi<209BDU0@0Ti>C
0P2DU9@209>CT`80VIVI0P12@T8?0?ooo`003@3oool20451@@80TI6A102CTi<209VIV@80TY:B202D
U9@209:BTP80V9RH0P2@T90209VIV@80TI6A0`2GUiL209JFUP80U9BD0P1[Jf/20:6QX@80W9bL0P2I
VIT209FEU@80SXj>0P2KVi/209BDU080OGem0P2EUID20:6QX@80eMGE0P1ZJVX208B4Q080VIVI0P2C
Ti<409FEU@@0UYJF0P2=SHd208n?S`80SHf=0P2FUYH409>CT`80T92@0P2EUID209fMW@<0T92@0P2>
SXh209JFUP80V9RH0P2LW9`209BDU080V9RH0P2@T90209>CT`80U9BD0P2CTi<208n?S`80VIVI0P2F
UYH209RHV080SHf=0P2DU9@409NGU`80UYJF0P2BTY8209^KV`80VIVI0P2BTY8209NGU`80UYJF0P2J
VYX208j>SP80VIVI0P2MWId209BDU080OWin0`2ZZZX20;Rh^080S8b<0P2a/K4208N7Q`80Rh^;0P2T
Y:@209BDU080QXJ60P2SXj<209ZJVP80QXJ60P2FUYH209RHV080KVi^0P2k^k/207AdM080/;2`0P1o
Ogl20;6a/@80OGem0P2>SXh20:RXZ080R8R8402DU9@309>CT`@0U9BD102CTi<209BDU0@0Ti>C0P2D
U9@209>CT`80U9BD102CTi<209BDU080Ti>C0P2IVIT20492@Pl0oooo000=0?ooo`80ATI6102GUiL4
09>CT`P0U9BD0P2BTY8209RHV080UYJF0P2GUiL209:BTP80Ti>C1@2GUiL208:2PP80OGem0P2UYJD2
096AT@80WYjN0P2=SHd2092@T080TY:B0P2=SHd20:NWY`80XJ6Q0P3@d=0204Q8B080OWin0P2IVIT2
096AT@80S8b<0P2GUiL209RHV080SXj>102GUiL409RHV0P0UIFE0P2@T90209JFUP<0TY:B0P2ATI42
09RHV080Shn?0P2DU9@209VIV@80TI6A0P2FUYH209NGU`80UYJF0P2ATI4209VIV@80SXj>0P2=SHd2
09bLW080T92@0P2MWId208Z:RP80U9BD0P2ATI4209JFUP80TI6A0P2?Shl209JFUP80TI6A0P2CTi<4
09FEU@80QHF50P2GUiL209VIV@80R8R80`2@T90209VIV@80Shn?0P26QXH209jNWP80PX:20P2PX:02
08Z:RP80UiNG0P2/[:`20:2PX080OWin0P2IVIT209BDU080O7al0P2JVYX2096AT@80[jn_0P2=SHd2
0:JVYP80Ti>C0P2@T90208b<S080T92@3P2DU9@209>CT`<0VIVI102CTi<409RHV0@0Ti>C0P2IVIT2
096AT@80VIVI0P2CTi<209BDU080Ti>C102DU9@209>CT`80@d=33`3oool000d0oooo0P16ATH409NG
U`@0Ti>C202DU9@209:BTP80V9RH0P2FUYH209NGU`80TY:B0P2CTi<509NGU`80PX:20P1mOGd20:FU
Y@80TI6A0P2NWYh208f=S@80T92@0P2BTY8208f=S@80YjNW0P2QXJ420=3@d080B4Q80P1nOWh209VI
V@80TI6A0P2<S8`209NGU`80V9RH0P2>SXh409NGU`@0V9RH202EUID2092@T080UYJF0`2BTY82096A
T@80V9RH0P2?Shl209BDU080VIVI0P2ATI4209JFUP80UiNG0P2FUYH2096AT@80VIVI0P2>SXh208f=
S@80W9bL0P2@T90209fMW@80RXZ:0P2DU9@2096AT@80UYJF0P2ATI4208n?S`80UYJF0P2ATI4209>C
T`@0UIFE0P25QHD209NGU`80VIVI0P28R8P3092@T080VIVI0P2?Shl208J6QP80WYjN0P22PX820:2P
X080RXZ:0P2GUiL20:b/[080X:2P0P1nOWh209VIV@80U9BD0P1lO7`209ZJVP80TI6A0P2_[jl208f=
S@80YZJV0P2CTi<2092@T080S8b<0P2@T90>09BDU080Ti>C0`2IVIT409>CT`@0V9RH102CTi<209VI
V@80TI6A0P2IVIT209>CT`80U9BD0P2CTi<409BDU080Ti>C0P13@d<?0?ooo`003@3oool204I6AP80
T92@0P2HV9P209>CT`P0U9BD0P2CTi<209VIV@80TY:B0P2ATI4209NGU`80Ti>C0P2DU9@309>CT`80
TY:B0P1`L7020<_;b`80Xj>S0P2?Shl20;:b/P80QXJ60P2NWYh209RHV080QHF50P2WYjL208J6QP80
bl_;0P1WIfL209VIV@80T92@0P2CTi<209NGU`80VIVI102@T90209NGU`@0UIFE0P2<S8`209NGU`@0
UYJF0P2EUID209:BTP80Vi^K0`2BTY8209>CT`80S8b<0P2@T90209NGU`80VIVI102ATI4209>CT`80
V9RH0P2FUYH209>CT`80SXj>0P2IVIT208n?S`80Ti>C0P2<S8`209ZJVP@0UIFE0P2ATI4209FEU@80
TI6A0P2GUiL209FEU@80UYJF0P2>SXh209ZJVP80S8b<0P2HV9P2096AT@D0UYJF0P2CTi<209:BTP80
WYjN0P29RHT209^KV`80RXZ:0P2BTY8209bLW080Rh^;0P2DU9@208f=S@80UYJF0P2LW9`208b<S080
VYZJ0P2IVIT20;Ng]`80SXj>0P2<S8`209ZJVP80T92@0P2;Rh/B09BDU0<0Ti>C102DU9@409:BTP80
Ti>C0P2DU9@209:BTP80VIVI0P2BTY8209BDU080Ti>C0P2IVIT209>CT`@0U9BD0P13@d<?0?ooo`00
3@3oool204I6AP80T92@0P2HV9P209>CT`P0U9BD0P2CTi<209VIV@80TY:B0P2ATI4209NGU`80Ti>C
0P2DU9@309>CT`80TY:B0P1`L7020<_;b`80Xj>S0P2?Shl20;:b/P80QXJ60P2NWYh209RHV080QHF5
0P2WYjL208J6QP80bl_;0P1WIfL209VIV@80T92@0P2CTi<209NGU`80VIVI102@T90209NGU`@0UIFE
0P2<S8`209NGU`@0UYJF0P2EUID209:BTP80Vi^K0`2BTY8209>CT`80S8b<0P2@T90209NGU`80VIVI
102ATI4209>CT`80V9RH0P2FUYH209>CT`80SXj>0P2IVIT208n?S`80Ti>C0P2<S8`209ZJVP@0UIFE
0P2ATI4209FEU@80TI6A0P2GUiL209FEU@80UYJF0P2>SXh209ZJVP80S8b<0P2HV9P2096AT@D0UYJF
0P2CTi<209:BTP80WYjN0P29RHT209^KV`80RXZ:0P2BTY8209bLW080Rh^;0P2DU9@208f=S@80UYJF
0P2LW9`208b<S080VYZJ0P2IVIT20;Ng]`80SXj>0P2<S8`209ZJVP80T92@0P2;Rh/B09BDU0<0Ti>C
102DU9@409:BTP80Ti>C0P2DU9@209:BTP80VIVI0P2BTY8209BDU080Ti>C0P2IVIT209>CT`@0U9BD
0P13@d<?0?ooo`003@3oool204M7A`@0TY:B0P2DU9@209>CT`H0U9BD102CTi<209BDU080Ti>C0P2H
V9P209>CT`80U9BD0`2CTi<209VIV@80Jf][0P2c/k<209:BTP80WYjN0P2TY:@20820P080T92@0P2D
U9@409:BTP80a<C40P2@T90207inOP80U9BD0P2BTY8209FEU@80UYJF0P2>SXh208n?S`80VIVI0P2C
Ti<209FEU@@0U9BD0P2FUYH408f=S@80UYJF0P2EUID209:BTP<0TI6A0P2CTi<209bLW080TY:B0P2I
VIT209RHV080VYZJ0P2@T90209JFUP80SHf=0P2DU9@2096AT@@0UYJF0P2ATI4209:BTP80Vi^K0P2J
VYX208b<S0@0TY:B0P2EUID209BDU080Shn?0P2ATI4209^KV`@0Ti>C0P2@T90209JFUP80V9RH0P2J
VYX3092@T080YJFU0P2LW9`209JFUP80TI6A0P2KVi/208f=S@80TI6A0P2=SHd20:^[Z`80O7al0P2C
Ti<209:BTP80UYJF0P2ATI4207UiN@80X:2P0P2?Shl209NGU`80WinO0P2HV9P208:2PP80TI6A5`2D
U9@209>CT`80VIVI0P2BTY8209VIV@H0Ti>C1P2DU9@209>CT`H0U9BD0P13@d<?0?ooo`003@3oool2
04M7A`@0TY:B0P2DU9@209>CT`H0U9BD102CTi<209BDU080Ti>C0P2HV9P209>CT`80U9BD0`2CTi<2
09VIV@80Jf][0P2c/k<209:BTP80WYjN0P2TY:@20820P080T92@0P2DU9@409:BTP80a<C40P2@T902
07inOP80U9BD0P2BTY8209FEU@80UYJF0P2>SXh208n?S`80VIVI0P2CTi<209FEU@@0U9BD0P2FUYH4
08f=S@80UYJF0P2EUID209:BTP<0TI6A0P2CTi<209bLW080TY:B0P2IVIT209RHV080VYZJ0P2@T902
09JFUP80SHf=0P2DU9@2096AT@@0UYJF0P2ATI4209:BTP80Vi^K0P2JVYX208b<S0@0TY:B0P2EUID2
09BDU080Shn?0P2ATI4209^KV`@0Ti>C0P2@T90209JFUP80V9RH0P2JVYX3092@T080YJFU0P2LW9`2
09JFUP80TI6A0P2KVi/208f=S@80TI6A0P2=SHd20:^[Z`80O7al0P2CTi<209:BTP80UYJF0P2ATI42
07UiN@80X:2P0P2?Shl209NGU`80WinO0P2HV9P208:2PP80TI6A5`2DU9@209>CT`80VIVI0P2BTY82
09VIV@H0Ti>C1P2DU9@209>CT`H0U9BD0P13@d<?0?ooo`003@3oool20451@@80Ti>C0P2IVIT209:B
TP80V9RH1P2CTi<209RHV080Ti>C102DU9@209>CT`@0U9BD0`2CTi<208j>SP80HF5Q0P2c/k<208>3
P`80UiNG0P2IVIT20:BTY080SHf=0P29RHT20:NWY`80UiNG0P30`<0206QXJ080S8b<0P2HV9P209>C
T`80U9BD0P2EUID209NGU`80V9RH102EUID209>CT`80TY:B0P2HV9P2092@T080U9BD102EUID209>C
T`80Shn?0`2PX:02096AT@80TY:B0P2:RXX209RHV0@0UiNG0P2BTY82092@T080UYJF0P2@T90209FE
U@80TY:B0P2DU9@209RHV080T92@0P2GUiL208b<S080U9BD0P2HV9P409FEU@80Ti>C0P2DU9@209JF
UP80SHf=0P2FUYH209NGU`80U9BD0P2<S8`209FEU@80T92@0`2GUiL209:BTP80UiNG0P2BTY8209nO
W`80SHf=0P2GUiL2092@T080WYjN0P2l_;`206a/K080TY:B0P2OWil208j>SP80U9BD0P1dM7@20;Ng
]`80RHV90P2MWId20:FUY@80W9bL0P24Q8@209:BTQT0U9BD0P2CTi<209BDU080TY:B0P2CTi<209VI
V@80Ti>C3P2DU9@204=3@`l0oooo000=0?ooo`80@D510P2CTi<209VIV@80TY:B0P2HV9P609>CT`80
V9RH0P2CTi<409BDU080Ti>C102DU9@309>CT`80SXj>0P1QHF420;>c/`80Ph>30P2GUiL209VIV@80
Y:BT0P2=SHd208V9R@80YjNW0P2GUiL20<30`080J6QX0P2<S8`209RHV080Ti>C0P2DU9@209FEU@80
UiNG0P2HV9P409FEU@80Ti>C0P2BTY8209RHV080T92@0P2DU9@409FEU@80Ti>C0P2?Shl30:2PX080
TI6A0P2BTY8208Z:RP80V9RH102GUiL209:BTP80T92@0P2FUYH2092@T080UIFE0P2BTY8209BDU080
V9RH0P2@T90209NGU`80S8b<0P2DU9@209RHV0@0UIFE0P2CTi<209BDU080UYJF0P2=SHd209JFUP80
UiNG0P2DU9@208b<S080UIFE0P2@T90309NGU`80TY:B0P2GUiL209:BTP80WinO0P2=SHd209NGU`80
T92@0P2NWYh20;bl_080K6a/0P2BTY8209nOW`80SXj>0P2DU9@207AdM080]kNg0P29RHT209fMW@80
YJFU0P2LW9`208B4Q080TY:B6@2DU9@209>CT`80U9BD0P2BTY8209>CT`80VIVI0P2CTi<>09BDU080
@d=33`3oool000d0oooo0P18B4P409>CT`80TY:B0P2HV9P209:BTP80V9RH0P2BTY8209RHV080Ti>C
202DU9@209>CT`<0V9RH0P1mOGd209^KV`80`<300P2FUYH209^KV`80S8b<0P2ATI4208j>SP80WIfM
0P2NWYh20;Jf]P80EeMG0P20P80209bLW080SXj>0P2EUID209JFUP80UIFE0P2FUYH208b<S080UYJF
0P2CTi<208n?S`80TY:B0P2GUiL209VIV@80Ti>C0P2FUYH2092@T080TI6A0P2LW9`509>CT`80UIFE
0P2?Shl2092@T080V9RH0P2FUYH209FEU@80VYZJ0P2<S8`20:JVYP@0TY:B0P2JVYX208^;R`80U9BD
102ATI4409JFUP80Ti>C0P2EUID209BDU080TI6A0P2HV9P208n?S`80VYZJ0P2ATI42092@T080VYZJ
0P2<S8`209ZJVP<0TY:B0P2@T9020:JVYP80RXZ:0P2HV9P209bLW080OWin0P2KVi/209>CT`80YZJV
0P20P80209fMW@80SXj>0P24Q8@20<;2`P80DU9B0P3>c/h209>CT`80QXJ60P2HV9P20:RXZ080OWin
102DU9@209>CTaL0U9BD0P2CTi<209RHV0@0Ti>C402DU9@204=3@`l0oooo000=0?ooo`80B4Q8102C
Ti<209:BTP80V9RH0P2BTY8209RHV080TY:B0P2HV9P209>CT`P0U9BD0P2CTi<309RHV080OGem0P2K
Vi/20<30`080UYJF0P2KVi/208b<S080TI6A0P2>SXh209fMW@80WYjN0P2f][H205MGE`80P8200P2L
W9`208j>SP80UIFE0P2FUYH209FEU@80UYJF0P2<S8`209JFUP80Ti>C0P2?Shl209:BTP80UiNG0P2I
VIT209>CT`80UYJF0P2@T902096AT@80W9bL1@2CTi<209FEU@80Shn?0P2@T90209RHV080UYJF0P2E
UID209ZJVP80S8b<0P2VYZH409:BTP80VYZJ0P2;Rh/209BDU0@0TI6A102FUYH209>CT`80UIFE0P2D
U9@2096AT@80V9RH0P2?Shl209ZJVP80TI6A0P2@T90209ZJVP80S8b<0P2JVYX309:BTP80T92@0P2V
YZH208Z:RP80V9RH0P2LW9`207inOP80Vi^K0P2CTi<20:JVYP80P8200P2MWId208j>SP80Q8B40P32
`/82059BDP80c/k>0P2CTi<208J6QP80V9RH0P2XZ:P207inOP@0U9BD0P2CTi<G09BDU080Ti>C0P2H
V9P409>CTa00U9BD0P13@d<?0?ooo`003@3oool20492@P80U9BD0P2CTi<209RHV080TY:B0P2CTi<2
09RHV080TY:B0P2CTi<409BDU0H0Ti>C0P2BTY8309RHV080KVi^0P2l_;`207YjNP80SXj>0P2a/K42
07YjNP80YZJV0P28R8P20:NWY`80U9BD0P3AdM4207AdM080SXj>0P2LW9`2092@T080UYJF0P2<S8`2
09JFUP80UIFE0P2CTi<2096AT@80UYJF0P2@T9020:>SX`80Shn?0P2>SXh209>CT`80UYJF0P2EUID2
08f=S@80UIFE0`2CTi<2096AT@80UIFE0P2?Shl208j>SP80WIfM0P2@T90209^KV`80TI6A0P2IVIT2
08f=S@80TI6A0P2DU9@208b<S080V9RH0P2ATI4209RHV080Shn?0P2>SXh208b<S080Shn?0P2>SXh2
08n?S`80Ti>C0P2=SHd209nOW`80Rh^;0P2FUYH209BDU080S8b<0P2CTi<2092@T0<0Vi^K0P2?Shl2
0:FUY@80XJ6Q0P2>SXh409>CT`80S8b<0P2IVIT20:RXZ080O7al0P2FUYH209>CT`80M7Ad0P3De=@2
06=SH`80[Jf]0P2TY:@209FEU@80TI6A0P2EUID208J6QP80U9BD0P2CTi<209VIV@80Ti>C1P2DU9@2
09>CT`d0U9BD0P2CTi<209RHV080Ti>C102DU9@209>CT``0U9BD0P13@d<?0?ooo`003@3oool20492
@P80U9BD0P2CTi<209RHV080TY:B0P2CTi<209RHV080TY:B0P2CTi<409BDU0H0Ti>C0P2BTY8309RH
V080KVi^0P2l_;`207YjNP80SXj>0P2a/K4207YjNP80YZJV0P28R8P20:NWY`80U9BD0P3AdM4207Ad
M080SXj>0P2LW9`2092@T080UYJF0P2<S8`209JFUP80UIFE0P2CTi<2096AT@80UYJF0P2@T9020:>S
X`80Shn?0P2>SXh209>CT`80UYJF0P2EUID208f=S@80UIFE0`2CTi<2096AT@80UIFE0P2?Shl208j>
SP80WIfM0P2@T90209^KV`80TI6A0P2IVIT208f=S@80TI6A0P2DU9@208b<S080V9RH0P2ATI4209RH
V080Shn?0P2>SXh208b<S080Shn?0P2>SXh208n?S`80Ti>C0P2=SHd209nOW`80Rh^;0P2FUYH209BD
U080S8b<0P2CTi<2092@T0<0Vi^K0P2?Shl20:FUY@80XJ6Q0P2>SXh409>CT`80S8b<0P2IVIT20:RX
Z080O7al0P2FUYH209>CT`80M7Ad0P3De=@206=SH`80[Jf]0P2TY:@209FEU@80TI6A0P2EUID208J6
QP80U9BD0P2CTi<209VIV@80Ti>C1P2DU9@209>CT`d0U9BD0P2CTi<209RHV080Ti>C102DU9@209>C
T``0U9BD0P13@d<?0?ooo`003@3oool204=3@`80U9BD0P2CTi<209RHV080Ti>C0P2DU9@209:BTP80
VIVI1P2CTi<609NGU`80V9RH0`2CTi<206IVIP80k>c/0P1/K6`20:RXZ080PH610P2JVYX208V9R@80
Rh^;0P2i^KT208f=S@80K6a/0P1iNGT20::RXP80Ti>C0P2?Shl209FEU@80UYJF0P2DU9@2096AT@80
U9BD0P2>SXh208R8R080Q8B40P22PX8209^KV`80V9RH102@T90209NGU`80TY:B0P2LW9`309VIV@80
TY:B0P2EUID208f=S@80WYjN0P2EUID209bLW080S8b<0P2GUiL209bLW080VIVI102?Shl209FEU@80
SHf=0P2BTY8208Z:RP80TI6A0P2CTi<209fMW@80Ti>C0P2LW9`209>CT`80UYJF0P2BTY8208n?S`80
S8b<0P2EUID209>CT`80V9RH0P2BTY8209ZJVP<0RHV90P2CTi<208V9R@80]KFe0P2HV9P209bLW080
R8R80P2HV9P208>3P`80/k>c0P22PX820820P080Z:RX0P1oOgl20=3@d080De=C0P2OWil20;Bd]080
Q8B40P2DU9@208n?S`80S8b<0P2EUID209BDU080Ti>C1P2DU9@209>CT`80VIVI0P2CTi<=09BDU080
Ti>C102DU9@209>CT`80VIVI0P2CTi<:09BDU080@d=33`3oool000d0oooo0P13@d<209BDU080Ti>C
0P2HV9P209>CT`80U9BD0P2BTY8209VIV@H0Ti>C1P2GUiL209RHV0<0Ti>C0P1VIVH20>c/k080K6a/
0P2XZ:P20861P@80VYZJ0P29RHT208^;R`80^KVi0P2=SHd206a/K080NGUi0P2RXZ8209>CT`80Shn?
0P2EUID209JFUP80U9BD0P2ATI4209BDU080SXj>0P28R8P208B4Q080PX:20P2KVi/209RHV0@0T92@
0P2GUiL209:BTP80W9bL0`2IVIT209:BTP80UIFE0P2=SHd209jNWP80UIFE0P2LW9`208b<S080UiNG
0P2LW9`209VIV@@0Shn?0P2EUID208f=S@80TY:B0P2:RXX2096AT@80Ti>C0P2MWId209>CT`80W9bL
0P2CTi<209JFUP80TY:B0P2?Shl208b<S080UIFE0P2CTi<209RHV080TY:B0P2JVYX308V9R@80Ti>C
0P29RHT20;Fe]@80V9RH0P2LW9`208R8R080V9RH0P23Ph<20;>c/`80PX:20P20P8020:RXZ080Ogmo
0P3@d=0205=CD`80WinO0P2d];@208B4Q080U9BD0P2?Shl208b<S080UIFE0P2DU9@209>CT`H0U9BD
0P2CTi<209VIV@80Ti>C3@2DU9@209>CT`@0U9BD0P2CTi<209VIV@80Ti>C2P2DU9@204=3@`l0oooo
000=0?ooo`80@T92102DU9@209>CT`80U9BD0P2CTi<209BDU080TY:B0P2CTi<209VIV@80TY:B0P2H
V9P209:BTP@0Ti>C0`2ATI4204i>CP80_[jn0P25QHD20:BTY080T92@0P2JVYX20820P080`L710P26
QXH20=KFeP80GEeM0P2d];@209jNWP80Rh^;0P2?Shl409BDU080Shn?0P2<S8`208>3P`80TI6A0P2a
/K420;Fe]@80Q8B40P22PX820::RXP80RXZ:0P2HV9P207emO@80SXj>0P2EUID309RHV080T92@0P2D
U9@408n?S`80V9RH0P2JVYX209bLW080VYZJ0P1iNGT208F5Q@80Kfm_0P2@T90209BDU080XJ6Q0P2B
TY8209bLW080Vi^K0P2;Rh/208j>SP@0TY:B0P27QhL208b<S080Vi^K0P2HV9P209NGU`80TY:B0P2C
Ti<2092@T080U9BD0P2;Rh/30:6QX@80UiNG102BTY8209BDU080X:2P0P2;Rh/209bLW080Shn?0P2W
YjL208f=S@80U9BD0P2JVYX208^;R`80^k^k0P1GEeL20;Jf]P80^[Zj0P21PH420:ZZZP80U9BD0P23
Ph<209JFUP`0U9BD0P2CTi<=09BDU080Ti>C202DU9@209>CT``0U9BD0P13@d<?0?ooo`003@3oool2
0492@P@0U9BD0P2CTi<209BDU080Ti>C0P2DU9@209:BTP80Ti>C0P2IVIT209:BTP80V9RH0P2BTY84
09>CT`<0TI6A0P1>CTh20;jn_P80QHF50P2TY:@2092@T080VYZJ0P20P8020<71`@80QXJ60P3Fe]H2
05eMG@80];Bd0P2NWYh208^;R`80Shn?102DU9@208n?S`80S8b<0P23Ph<2096AT@80/K6a0P2e]KD2
08B4Q080PX:20P2RXZ8208Z:RP80V9RH0P1mOGd208j>SP80UIFE0`2HV9P2092@T080U9BD102?Shl2
09RHV080VYZJ0P2LW9`209ZJVP80NGUi0P25QHD206m_K`80T92@0P2DU9@20:6QX@80TY:B0P2LW9`2
09^KV`80Rh^;0P2>SXh409:BTP80QhN70P2<S8`209^KV`80V9RH0P2GUiL209:BTP80Ti>C0P2@T902
09BDU080Rh^;0`2QXJ4209NGU`@0TY:B0P2DU9@20:2PX080Rh^;0P2LW9`208n?S`80YjNW0P2=SHd2
09BDU080VYZJ0P2;Rh/20;^k^`80EeMG0P2f][H20;Zj^P80PH610P2ZZZX209BDU080Ph>30P2FUYH<
09BDU080Ti>C3@2DU9@209>CT`P0U9BD0P2CTi<<09BDU080@d=33`3oool000d0oooo0P18B4P209>C
T`@0U9BD0P2CTi<209VIV@80TY:B0P2IVIT409>CT`80U9BD0P2BTY8609BDU0<0OGem0P2d];@20:FU
Y@80Shn?0P2/[:`208^;R`80XZ:R0P1oOgl20:b/[080TI6A0P1PH60208N7Q`80YZJV0P2OWil208Z:
RP80VIVI0P2ATI4208f=S@80SXj>0P2;Rh/20;Rh^080/k>c0P26QXH2075aL@80^KVi0P2WYjL209JF
UP80R8R80P2RXZ820;>c/`80PX:20P2>SXh309ZJVP80Shn?0P2DU9@208j>SP80U9BD0P2@T90209jN
WP80QXJ60P2NWYh207]kN`80gMgM0P2a/K420;2`/080XZ:R0P1NGUh20:FUY@80_;bl0P2@T90209VI
V@80YJFU0P2QXJ4209fMW@80RXZ:0P2BTY8409>CT`80TI6A0P2HV9P208j>SP80V9RH0P2ATI4209^K
V`D0Shn?0P2JVYX207EeM@80Vi^K0P2QXJ4208N7Q`80V9RH0P2BTY8209>CT`80Shn?0P22PX8209fM
W@80QHF50P37alL205=CD`80[Jf]0P2QXJ4207inOP80XZ:R0P27QhL209:BTP80UIFE5@2DU9@209>C
T`80U9BD0P2CTi<209VIV@80TY:B502DU9@204=3@`l0oooo000=0?ooo`80B4Q80P2CTi<409BDU080
Ti>C0P2IVIT209:BTP80VIVI102CTi<209BDU080TY:B1P2DU9@307emO@80];Bd0P2UYJD208n?S`80
[:b/0P2;Rh/20::RXP80Ogmo0P2/[:`2096AT@80H61P0P27QhL20:JVYP80WinO0P2:RXX209VIV@80
TI6A0P2=SHd208j>SP80Rh^;0P2h^;P20;>c/`80QXJ60P1aLG420;Vi^@80YjNW0P2FUYH208R8R080
XZ:R0P2c/k<208:2PP80SXj>0`2JVYX208n?S`80U9BD0P2>SXh209BDU080T92@0P2NWYh208J6QP80
WYjN0P1kNg/20=gMg@80/K6a0P2`/;020::RXP80GUiN0P2UYJD20;bl_080T92@0P2IVIT20:FUY@80
XJ6Q0P2MWId208Z:RP80TY:B102CTi<2096AT@80V9RH0P2>SXh209RHV080TI6A0P2KVi/508n?S`80
VYZJ0P1eMGD209^KV`80XJ6Q0P27QhL209RHV080TY:B0P2CTi<208n?S`80PX:20P2MWId208F5Q@80
alO70P1CDe<20:f][@80XJ6Q0P1nOWh20::RXP80QhN70P2BTY8209FEUAD0U9BD0P2CTi<209BDU080
Ti>C0P2IVIT209:BTQ@0U9BD0P13@d<?0?ooo`003@3oool20492@PP0U9BD0P2CTi<209BDU0@0Ti>C
0P2DU9@209>CT`80VIVI0P2CTi<209BDU080UIFE0`1kNg/20=CDe080NGUi0P2@T90207moO`80];Bd
0P2;Rh/208:2PP80ZJVY0P3Ti>@205YJFP80V9RH0P2>SXh209VIV@80RXZ:0P2<S8`209:BTP80T92@
0P2:RXX20:BTY080Rh^;0P1bLW8205eMG@80`l?30P2SXj<20:2PX080Rh^;0P2DU9@207UiN@80Vi^K
0P27QhL20:>SX`<0UIFE0P2@T90209:BTP80UiNG0P2BTY8409FEU@80W9bL0P2PX:0209FEU@80JVYZ
0P3EeMD205YJFP80CDe=0P35aLD209jNWP80Shn?0P1aLG420;Vi^@80J6QX0P2@T9020:2PX080VIVI
0P27QhL209BDU080Shn?0P2ATI4409BDU080RHV90P2HV9P209FEU@<0SHf=0P2KVi/209:BTP80UYJF
0P2a/K420:6QX@80O7al0P25QHD20;2`/080TY:B0P28R8P208f=S@80Z:RX0P2=SHd20:b/[080HF5Q
0P3>c/h207emO@80R8R80P2][Jd207emOAH0U9BD0`2CTi<209VIV@80Ti>C0P2DU9@209:BTP80VIVI
0P2CTi<B09BDU080@d=33`3oool000d0oooo0P12@T8809BDU080Ti>C0P2DU9@409>CT`80U9BD0P2C
Ti<209VIV@80Ti>C0P2DU9@209FEU@<0Ng]k0P3De=@207UiN@80T92@0P1oOgl20;Bd]080Rh^;0P22
PX820:VYZ@80i>CT0P1JFUX209RHV080SXj>0P2IVIT208Z:RP80S8b<0P2BTY82092@T080RXZ:0P2T
Y:@208^;R`80LW9b0P1MGEd20<?3``80Xj>S0P2PX:0208^;R`80U9BD0P1iNGT209^KV`80QhN70P2S
Xj<309FEU@80T92@0P2BTY8209NGU`80TY:B102EUID209bLW080X:2P0P2EUID206YZJP80eMGE0P1J
FUX204e=C@80aLG50P2NWYh208n?S`80LG5a0P2i^KT206QXJ080T92@0P2PX:0209VIV@80QhN70P2D
U9@208n?S`80TI6A102DU9@208V9R@80V9RH0P2EUID308f=S@80Vi^K0P2BTY8209JFUP80/K6a0P2Q
XJ4207alO080QHF50P2`/;0209:BTP80R8R80P2=SHd20:RXZ080SHf=0P2/[:`2065QH@80c/k>0P1m
OGd208R8R080[Jf]0P1mOGdF09BDU0<0Ti>C0P2IVIT209>CT`80U9BD0P2BTY8209VIV@80Ti>C4P2D
U9@204=3@`l0oooo000=0?ooo`80@d=3302DU9@209>CT`80VIVI0P2CTi<209BDU080Ti>C102DU9@2
096AT@<0KVi^0P1DE5@20:ZZZP80/K6a0P2JVYX20:n_[`80Rh^;0P2FUYH209>CT`80[Zj^0P1RHV82
09ZJVP80Xj>S0P2FUYH409:BTP80SXj>0P2EUID209JFUP80TY:B0P3Ogml20820P080H61P0P2EUID2
02PX:080n?Sh0P1dM7@20<K6aP80WinO0P2NWYh20:ZZZP80TY:B1@2@T90209:BTP80Ti>C102DU9@2
08V9R@80XJ6Q0P2CTi<20;2`/080Rh^;0P1fMWH20<o?c`80FEUI0P3<c<`201XJ6P80mOGe0P1bLW82
0:f][@80BDU90P3Jf]X20:>SX`80TI6A0P2GUiL209ZJVP80SHf=0P2CTi<208j>SP80WIfM0P2@T902
08b<S080SHf=0`2JVYX209RHV080QhN70P2ZZZX209jNWP80WIfM0P2][Jd208:2PP80Xj>S0P20P802
09fMW@80T92@0P2>SXh208Z:RP80/[:b0P1TI6@20<g=c@80RXZ:0P2LW9`209ZJVP80QXJ66@2DU9@2
09>CT`H0U9BD0P2CTi<609BDU080Ti>C302DU9@204=3@`l0oooo000=0?ooo`80@d=3302DU9@209>C
T`80VIVI0P2CTi<209BDU080Ti>C102DU9@2096AT@<0KVi^0P1DE5@20:ZZZP80/K6a0P2JVYX20:n_
[`80Rh^;0P2FUYH209>CT`80[Zj^0P1RHV8209ZJVP80Xj>S0P2FUYH409:BTP80SXj>0P2EUID209JF
UP80TY:B0P3Ogml20820P080H61P0P2EUID202PX:080n?Sh0P1dM7@20<K6aP80WinO0P2NWYh20:ZZ
ZP80TY:B1@2@T90209:BTP80Ti>C102DU9@208V9R@80XJ6Q0P2CTi<20;2`/080Rh^;0P1fMWH20<o?
c`80FEUI0P3<c<`201XJ6P80mOGe0P1bLW820:f][@80BDU90P3Jf]X20:>SX`80TI6A0P2GUiL209ZJ
VP80SHf=0P2CTi<208j>SP80WIfM0P2@T90208b<S080SHf=0`2JVYX209RHV080QhN70P2ZZZX209jN
WP80WIfM0P2][Jd208:2PP80Xj>S0P20P80209fMW@80T92@0P2>SXh208Z:RP80/[:b0P1TI6@20<g=
c@80RXZ:0P2LW9`209ZJVP80QXJ66@2DU9@209>CT`H0U9BD0P2CTi<609BDU080Ti>C302DU9@204=3
@`l0oooo000=0?ooo`80@d=31P2DU9@209>CT`H0U9BD0P2BTY8:09BDU080NWYj0`3Bd]8207MgM`80
X:2P0P27QhL209FEU@80VYZJ0P2@T90209BDU080UIFE0P2CTi<207QhN080Xj>S0P2HV9P209NGU`80
SHf=0P2<S8`209bLW080WIfM0P2IVIT20<_;b`80TI6A0P2JVYX20;no_`80cLg=0P2k^k/408^;R`80
Y:BT0P2MWId209bLW080SXj>0P2DU9@308n?S`80V9RH0P2ATI4209BDU080UIFE0P2FUYH209BDU080
TY:B0P2KVi/209>CT`80YjNW0P2ZZZX208:2PP80Q8B40P3?cll20=?Cd`80X:2P0P2XZ:P209>CT`80
][Jf0P2ATI420:n_[`80TY:B0P2GUiL20::RXP80VIVI0P2DU9@2092@T080UIFE0P2KVi/208n?S`80
Xj>S0`2FUYH208b<S080UiNG0P2=SHd20:>SX`80QhN70P2<S8`209ZJVP80Vi^K102@T90209^KV`80
Y:BT0P2;Rh/20:ZZZP80K6a/0P2f][H208f=S@80Y:BT0P20P80208j>SRL0U9BD0P2CTi<209VIV@80
Ti>C2P2DU9@204=3@`l0oooo000=0?ooo`80@d=31P2DU9@209>CT`H0U9BD0P2BTY8:09BDU080NWYj
0`3Bd]8207MgM`80X:2P0P27QhL209FEU@80VYZJ0P2@T90209BDU080UIFE0P2CTi<207QhN080Xj>S
0P2HV9P209NGU`80SHf=0P2<S8`209bLW080WIfM0P2IVIT20<_;b`80TI6A0P2JVYX20;no_`80cLg=
0P2k^k/408^;R`80Y:BT0P2MWId209bLW080SXj>0P2DU9@308n?S`80V9RH0P2ATI4209BDU080UIFE
0P2FUYH209BDU080TY:B0P2KVi/209>CT`80YjNW0P2ZZZX208:2PP80Q8B40P3?cll20=?Cd`80X:2P
0P2XZ:P209>CT`80][Jf0P2ATI420:n_[`80TY:B0P2GUiL20::RXP80VIVI0P2DU9@2092@T080UIFE
0P2KVi/208n?S`80Xj>S0`2FUYH208b<S080UiNG0P2=SHd20:>SX`80QhN70P2<S8`209ZJVP80Vi^K
102@T90209^KV`80Y:BT0P2;Rh/20:ZZZP80K6a/0P2f][H208f=S@80Y:BT0P20P80208j>SRL0U9BD
0P2CTi<209VIV@80Ti>C2P2DU9@204=3@`l0oooo000=0?ooo`80@d=3102DU9@209>CT`80VIVI0P2C
Ti<209BDU080Ti>C0P2IVIT209>CT`@0U9BD0P2CTi<209BDU080MGEe0`3UiND208n?S`80MGEe0P2O
Wil20:6QX@80O7al0P2@T90209^KV`80[Jf]0P2=SHd208:2PP80UYJF102EUID208^;R`80V9RH0P2B
TY82096AT@80SHf=0P2ATI420:ZZZP80/;2`0P2c/k<20:RXZ080[Jf]0P2k^k/20:JVYP80TI6A0P25
QHD208N7Q`80RHV90P2GUiL309>CT`80TI6A0P2BTY8209FEU@80VIVI0P2CTi<208b<S080Shn?0P2>
SXh208b<S080SHf=0P2CTi<20<K6aP80WIfM0P23Ph<20861P@80UYJF0P2_[jl20;^k^`80]kNg0P2H
V9P208V9R@80VIVI0P2PX:0209FEU@@0TI6A0P2LW9`208f=S@80Shn?0P2IVIT209bLW0<0U9BD0P2G
UiL208N7Q`80Rh^;0P2NWYh208n?S`80WinO0P2RXZ8209jNWP80QhN70P2<S8`209:BTP80XJ6Q0P2B
TY8209RHV080MWIf0P2d];@209JFUP80ZZZZ0P28R8P209:BTRT0U9BD0P2CTi<:09BDU080Ti>C0P13
@d<?0?ooo`003@3oool204=3@`@0U9BD0P2CTi<209VIV@80Ti>C0P2DU9@209>CT`80VIVI0P2CTi<4
09BDU080Ti>C0P2DU9@207EeM@<0iNGU0P2?Shl207EeM@80WinO0P2QXJ4207alO080T92@0P2KVi/2
0:f][@80SHf=0P22PX8209JFUP@0UIFE0P2;Rh/209RHV080TY:B0P2ATI4208f=S@80TI6A0P2ZZZX2
0;2`/080/k>c0P2XZ:P20:f][@80^k^k0P2VYZH2096AT@80QHF50P27QhL208V9R@80UiNG0`2CTi<2
096AT@80TY:B0P2EUID209VIV@80Ti>C0P2<S8`208n?S`80SXj>0P2<S8`208f=S@80Ti>C0P36a/H2
09fMW@80Ph>30P21PH4209JFUP80[jn_0P2k^k/20;Ng]`80V9RH0P29RHT209VIV@80X:2P0P2EUID4
096AT@80W9bL0P2=SHd208n?S`80VIVI0P2LW9`309BDU080UiNG0P27QhL208^;R`80WYjN0P2?Shl2
09nOW`80XZ:R0P2NWYh208N7Q`80S8b<0P2BTY820:6QX@80TY:B0P2HV9P207IfMP80];Bd0P2FUYH2
0:ZZZP80R8R80P2BTY8Y09BDU080Ti>C2P2DU9@209>CT`80@d=33`3oool000d0oooo0P13@d<209BD
U080Ti>C0P2DU9@409>CT`@0U9BD0P2CTi<409BDU080TY:B0P2IVIT209BDU080SHf=0`1YJFT209ZJ
VP80UiNG0P2NWYh209RHV080UiNG0P2IVIT20:VYZ@80PX:20P28R8P209FEU@80TI6A0P2OWil209ZJ
VP@0SXj>0P2CTi<208V9R@80S8b<0P29RHT207alO080Ogmo0P1kNg/207EeM@80IVIV0P1LG5`206=S
H`80RXZ:0P2EUID209jNWP80UiNG0P2<S8`309VIV@@0UIFE0P2ATI4609BDU080UYJF0P2RXZ8208R8
R080T92@0P1cLg<2075aL@80NWYj0P2MWId209ZJVP80U9BD0P2:RXX207moO`80OGem102:RXX208V9
R@80R8R80P2@T90208^;R`80S8b<0P2BTY8209ZJVP80S8b<0P2:RXX20:6QX@<0S8b<0P2CTi<20:NW
Y`80T92@0P2NWYh2096AT@80P8200P27QhL20:VYZ@80S8b<0P1gMgL209bLW080XZ:R0P2;Rh/209VI
V@80NGUi0P2e]KD209jNWP80OGem0P20P80209JFUS<0U9BD0P2CTi<209VIV@80@T923`3oool000d0
oooo0P13@d<209BDU080Ti>C0P2DU9@409>CT`@0U9BD0P2CTi<409BDU080TY:B0P2IVIT209BDU080
SHf=0`1YJFT209ZJVP80UiNG0P2NWYh209RHV080UiNG0P2IVIT20:VYZ@80PX:20P28R8P209FEU@80
TI6A0P2OWil209ZJVP@0SXj>0P2CTi<208V9R@80S8b<0P29RHT207alO080Ogmo0P1kNg/207EeM@80
IVIV0P1LG5`206=SH`80RXZ:0P2EUID209jNWP80UiNG0P2<S8`309VIV@@0UIFE0P2ATI4609BDU080
UYJF0P2RXZ8208R8R080T92@0P1cLg<2075aL@80NWYj0P2MWId209ZJVP80U9BD0P2:RXX207moO`80
OGem102:RXX208V9R@80R8R80P2@T90208^;R`80S8b<0P2BTY8209ZJVP80S8b<0P2:RXX20:6QX@<0
S8b<0P2CTi<20:NWY`80T92@0P2NWYh2096AT@80P8200P27QhL20:VYZ@80S8b<0P1gMgL209bLW080
XZ:R0P2;Rh/209VIV@80NGUi0P2e]KD209jNWP80OGem0P20P80209JFUS<0U9BD0P2CTi<209VIV@80
@T923`3oool000d0oooo0P13@d<209>CT`80VIVI102CTi<209VIV@80Ti>C1P2DU9@209>CT`80VIVI
0P2BTY8209FEU@80RXZ:0`1GEeL20>;RhP80PX:20P2[Zj/209JFUP80YZJV0P1`L7020;Rh^080WIfM
0P2IVIT208R8R080SXj>0P2RXZ8209FEU@80PH610P2QXJ4208f=S@80SXj>102ATI4208j>SP80QXJ6
0P1^KVh208N7Q`80WinO0P2[Zj/20;fm_@80bl_;0P2;Rh/209:BTP80S8b<1@2EUID208f=S@80UiNG
102CTi<209NGU`80R8R80P2GUiL2092@T080Z:RX0P2f][H40:2PX080U9BD0P1XJ6P207UiN@80OGem
0P24Q8@208n?S`80SHf=102BTY8208j>SP80TI6A0P2=SHd209FEU@80Z:RX0P2:RXX2096AT@80UiNG
0P2BTY82092@T0<0UYJF0P2@T90207alO080WinO0P2IVIT209bLW080SXj>0P2h^;P209BDU080WinO
0P2?Shl209NGU`80Y:BT0P25QHD209^KV`80K6a/0P2g]kL209nOW`80Q8B40P2BTY8209FEUCD0U9BD
0P2CTi<204=3@`l0oooo000=0?ooo`80@d=30P2CTi<209VIV@@0Ti>C0P2IVIT209>CT`H0U9BD0P2C
Ti<209VIV@80TY:B0P2EUID208Z:RP<0EeMG0P3Rh^8208:2PP80Zj^[0P2FUYH20:JVYP80L71`0P2h
^;P209fMW@80VIVI0P28R8P208j>SP80XZ:R0P2EUID20861P@80XJ6Q0P2=SHd208j>SP@0TI6A0P2>
SXh208J6QP80KVi^0P27QhL209nOW`80Zj^[0P2m_Kd20<_;b`80Rh^;0P2BTY8208b<S0D0UIFE0P2=
SHd209NGU`@0Ti>C0P2GUiL208R8R080UiNG0P2@T9020:RXZ080][Jf102PX:0209BDU080J6QX0P1i
NGT207emO@80Q8B40P2?Shl208f=S@@0TY:B0P2>SXh2096AT@80SHf=0P2EUID20:RXZ080RXZ:0P2A
TI4209NGU`80TY:B0P2@T90309JFUP80T92@0P1lO7`209nOW`80VIVI0P2LW9`208j>SP80^;Rh0P2D
U9@209nOW`80Shn?0P2GUiL20:BTY080QHF50P2KVi/206a/K080]kNg0P2OWil208B4Q080TY:B0P2E
UIDe09BDU080Ti>C0P13@d<?0?ooo`003@3oool204=3@`80U9BD0P2CTi<409BDU080Ti>C2P2DU9@2
09:BTP80U9BD0P2@T90209VIV@<0D51@0P3Ng]h208b<S080YjNW0P2HV9P208b<S080SHf=0P2LW9`2
08N7Q`80Ti>C0P2@T90208f=S@80VIVI0P2OWil208N7Q`80U9BD0P2CTi<208^;R`80PH610P24Q8@2
07emO@80LG5a0P2e]KD20;6a/@80_[jn0P30`<0208n?S`80Ogmo0P2<S8`209NGU`80UYJF0P2?Shl3
09VIV@80SXj>0P2GUiL409>CT`80TY:B0P2GUiL208j>SP@0SHf=0P2MWId40;no_`80][Jf0P2_[jl2
07emO@80QHF50P1eMGD207UiN@80Ng]k0P28R8P207alO080R8R80P25QHD209FEU@80/K6a0P26QXH2
09ZJVP80UIFE0P2IVIT209^KV`80Shn?0`2ATI420:j^[P80U9BD0P2TY:@209BDU080Vi^K0P2VYZH2
07MgM`80Shn?0P2@T90208Z:RP80SXj>0P2][Jd208R8R080Y:BT0P1kNg/209>CT`80/[:b0P1iNGTQ
09BDU080Ti>C602DU9@204=3@`l0oooo000=0?ooo`80@d=30P2DU9@209>CT`@0U9BD0P2CTi<:09BD
U080TY:B0P2DU9@2092@T080VIVI0`1@D5020=kNgP80S8b<0P2WYjL209RHV080S8b<0P2=SHd209bL
W080QhN70P2CTi<2092@T080SHf=0P2IVIT209nOW`80QhN70P2DU9@209>CT`80Rh^;0P21PH4208B4
Q080OGem0P1aLG420;Fe]@80/K6a0P2n_[h20<30`080Shn?0P1oOgl208b<S080UiNG0P2FUYH208n?
S`<0VIVI0P2>SXh209NGU`@0Ti>C0P2BTY8209NGU`80SXj>102=SHd209fMW@@0_kno0P2f][H20:n_
[`80OGem0P25QHD207EeM@80NGUi0P1kNg/208R8R080O7al0P28R8P208F5Q@80UIFE0P2a/K4208J6
QP80VYZJ0P2EUID209VIV@80Vi^K0P2?Shl3096AT@80[Zj^0P2DU9@20:BTY080U9BD0P2KVi/20:JV
YP80MgMg0P2?Shl2092@T080RXZ:0P2>SXh20:f][@80R8R80P2TY:@207]kN`80Ti>C0P2b/[8207Ui
NB40U9BD0P2CTi<H09BDU080@d=33`3oool000d0oooo0P13@d<B09BDU080Ti>C0P2HV9P209FEU@80
N7Qh0P3:b/X302XZ:P80][Jf0P2LW9`209>CT`80SXj>0P2a/K4208J6QP80W9bL0P2@T90209VIV@80
YjNW0P2BTY8209NGU`80W9bL0P2:RXX208:2PP80`l?30P2_[jl20:2PX080XZ:R0P2VYZH20<S8b080
`L710P2LW9`2079bLP80NGUi0P28R8P208^;R`80T92@0P2ATI4209:BTP80U9BD0`2ATI4209RHV080
UIFE0P2GUiL209RHV080UIFE0P2CTi<209JFUP80TY:B0P2;Rh/207emO@80Ogmo0P23Ph<209VIV@80
]KFe0P3Fe]H20;fm_@80a/K60P2/[:`209fMW@80WYjN0P2SXj<20:n_[`80/;2`0P2NWYh208f=S@80
UYJF0P2BTY8208j>SP80V9RH0P2JVYX2092@T0<0XJ6Q0P1RHV820<71`@80Ph>30P25QHD208:2PP80
Ti>C0P2_[jl208J6QP80Ti>C0P29RHT209RHV080YZJV0P2>SXh208:2PP80VYZJ0P35aLD208B4Q080
QhN77`2DU9@209>CT`80VIVI102CTi<D09BDU080@d=33`3oool000d0oooo0P13@d<B09BDU080Ti>C
0P2HV9P209FEU@80N7Qh0P3:b/X302XZ:P80][Jf0P2LW9`209>CT`80SXj>0P2a/K4208J6QP80W9bL
0P2@T90209VIV@80YjNW0P2BTY8209NGU`80W9bL0P2:RXX208:2PP80`l?30P2_[jl20:2PX080XZ:R
0P2VYZH20<S8b080`L710P2LW9`2079bLP80NGUi0P28R8P208^;R`80T92@0P2ATI4209:BTP80U9BD
0`2ATI4209RHV080UIFE0P2GUiL209RHV080UIFE0P2CTi<209JFUP80TY:B0P2;Rh/207emO@80Ogmo
0P23Ph<209VIV@80]KFe0P3Fe]H20;fm_@80a/K60P2/[:`209fMW@80WYjN0P2SXj<20:n_[`80/;2`
0P2NWYh208f=S@80UYJF0P2BTY8208j>SP80V9RH0P2JVYX2092@T0<0XJ6Q0P1RHV820<71`@80Ph>3
0P25QHD208:2PP80Ti>C0P2_[jl208J6QP80Ti>C0P29RHT209RHV080YZJV0P2>SXh208:2PP80VYZJ
0P35aLD208B4Q080QhN77`2DU9@209>CT`80VIVI102CTi<D09BDU080@d=33`3oool000d0oooo0P13
@d<609BDU080Ti>C1P2DU9@209>CT`80U9BD0P2CTi<209RHV080Ti>C0P20P8020:^[Z`<0][Jf0P2]
[Jd209bLW080RXZ:0P2FUYH209NGU`80VIVI0P2JVYX209NGU`80U9BD0P2GUiL209FEU@80XZ:R0P2=
SHd208b<S080SXj>0P24Q8@208>3P`80YZJV0P2ZZZX20;2`/080Shn?0P1cLg<207moO`80SXj>0P2B
TY8209>CT`P0U9BD0P2EUID3096AT@@0V9RH0P2@T902096AT@80SXj>0P2EUID209:BTP80U9BD0P2@
T90209BDU080T92@0P2<S8`208>3P`80NGUi0P1fMWH2071`L080Ti>C0P2b/[820;Fe]@80[:b/0P2^
[Zh209:BTP80RXZ:102GUiL208Z:RP80SXj>0P2=SHd209VIV@80V9RH0P26QXH30:2PX080[Jf]0P21
PH4208n?S`80SXj>0P2VYZH209jNWP80[:b/0P2;Rh/208V9R@80Zj^[0P2<S8`20:FUY@80Ph>30P26
QXH20;Fe]@80Xj>S0P1jNWX208n?Sb40U9BD102CTi<209VIV@80Ti>C4P2DU9@204=3@`l0oooo000=
0?ooo`80@d=31P2DU9@209>CT`H0U9BD0P2CTi<209BDU080Ti>C0P2HV9P209>CT`80P8200P2[Zj/3
0;Jf]P80[Jf]0P2LW9`208Z:RP80UYJF0P2GUiL209VIV@80VYZJ0P2GUiL209BDU080UiNG0P2EUID2
0::RXP80SHf=0P2<S8`208j>SP80Q8B40P23Ph<20:JVYP80ZZZZ0P2`/;0208n?S`80Lg=c0P1oOgl2
08j>SP80TY:B0P2CTi<809BDU080UIFE0`2ATI4409RHV080T92@0P2ATI4208j>SP80UIFE0P2BTY82
09BDU080T92@0P2DU9@2092@T080S8b<0P23Ph<207UiN@80MWIf0P1`L70209>CT`80/[:b0P2e]KD2
0:b/[080[Zj^0P2BTY8208Z:RP@0UiNG0P2:RXX208j>SP80SHf=0P2IVIT209RHV080QXJ60`2PX:02
0:f][@80PH610P2?Shl208j>SP80YZJV0P2NWYh20:b/[080Rh^;0P29RHT20:^[Z`80S8b<0P2UYJD2
08>3P`80QXJ60P2e]KD20:>SX`80NWYj0P2?ShlQ09BDU0@0Ti>C0P2IVIT209>CTa80U9BD0P13@d<?
0?ooo`003@3oool204=3@`80U9BD102CTi<209VIV@80Ti>C0P2DU9@209:BTP80VIVI0P2CTi<209BD
U080Ti>C0P2DU9@208>3P`80O7al0`2PX:0209:BTP80ZZZZ0P1mOGd208n?S`80U9BD0P2ATI420:2P
X080S8b<0P2EUID209NGU`80SHf=0P2RXZ8209BDU080R8R80P2GUiL409>CT`80Q8B40P21PH4208>3
P`80S8b<0P2GUiL2092@T080TY:B1P2DU9@209>CT`80U9BD0P2CTi<209FEU@<0TY:B0P2IVIT208j>
SP80Ti>C0P2@T90209VIV@80UiNG1P2EUID2092@T080UiNG0P2CTi<208n?S`80UiNG0P2DU9@408j>
SP80O7al0P1fMWH20861P@80QXJ60P27QhL208n?S`80U9BD0P27QhL209ZJVP80VIVI0P2MWId209RH
V080T92@0P2?Shl308F5Q@80WinO0P2IVIT20::RXP80Y:BT0P2JVYX209jNWP80]KFe0P1NGUh20:JV
YP80[:b/0P1TI6@20:^[Z`80WIfM0P1^KVh20;Vi^@80XZ:R0P1iNGTW09BDU080Ti>C502DU9@204=3
@`l0oooo000=0?ooo`80@d=30P2DU9@409>CT`80VIVI0P2CTi<209BDU080TY:B0P2IVIT209>CT`80
U9BD0P2CTi<209BDU080Ph>30P1lO7`30:2PX080TY:B0P2ZZZX207emO@80Shn?0P2DU9@2096AT@80
X:2P0P2<S8`209FEU@80UiNG0P2=SHd20::RXP80U9BD0P28R8P209NGU`@0Ti>C0P24Q8@20861P@80
Ph>30P2<S8`209NGU`80T92@0P2BTY8609BDU080Ti>C0P2DU9@209>CT`80UIFE0`2BTY8209VIV@80
SXj>0P2CTi<2092@T080VIVI0P2GUiL609FEU@80T92@0P2GUiL209>CT`80Shn?0P2GUiL209BDU0@0
SXj>0P1lO7`207IfMP80PH610P26QXH208N7Q`80Shn?0P2DU9@208N7Q`80VYZJ0P2IVIT209fMW@80
V9RH0P2@T90208n?S`<0QHF50P2OWil209VIV@80XZ:R0P2TY:@209ZJVP80WYjN0P2e]KD205iNGP80
YZJV0P2/[:`206ATI080Zj^[0P2MWId206i^KP80^KVi0P2RXZ8207UiNBL0U9BD0P2CTi<D09BDU080
@d=33`3oool000d0oooo0P13@d<209>CT`80VIVI102CTi<209BDU080Ti>C0P2IVIT209:BTPP0U9BD
0P23Ph<209:BTP<0`/;20P2OWil209jNWP80M7Ad0P2CTi<20::RXP80Ti>C0P2DU9@209:BTP80U9BD
0P2KVi/208B4Q080YJFU0P2<S8`208V9R@80Shn?0P2DU9@209JFUP80T92@0P2DU9@209NGU`80SXj>
0P2@T90209^KV`80V9RH0P2CTi<209BDU080Ti>C0P2LW9`209>CT`@0U9BD0`2BTY8209RHV080Vi^K
0P2ATI4209^KV`80VIVI0P2<S8`209JFUP80Ti>C102BTY8208j>SP80VYZJ0P2ATI4209JFUP@0U9BD
0P2KVi/208b<S080W9bL0P2BTY8209FEU@80Vi^K0P2DU9@209RHV080Ti>C0P2KVi/208n?S`80RHV9
0P2MWId209JFUP80SHf=0`2UYJD207=cL`80T92@0P2NWYh208n?S`80UYJF0P1mOGd20;Vi^@80I6AT
0P2?Shl20;Bd]080OWin0P2JVYX20:f][@80IVIV0P32`/8209:BTP80Ng]k0P2FUYHk09BDU080@d=3
3`3oool000d0oooo0P13@d<209>CT`80VIVI102CTi<209BDU080Ti>C0P2IVIT209:BTPP0U9BD0P23
Ph<209:BTP<0`/;20P2OWil209jNWP80M7Ad0P2CTi<20::RXP80Ti>C0P2DU9@209:BTP80U9BD0P2K
Vi/208B4Q080YJFU0P2<S8`208V9R@80Shn?0P2DU9@209JFUP80T92@0P2DU9@209NGU`80SXj>0P2@
T90209^KV`80V9RH0P2CTi<209BDU080Ti>C0P2LW9`209>CT`@0U9BD0`2BTY8209RHV080Vi^K0P2A
TI4209^KV`80VIVI0P2<S8`209JFUP80Ti>C102BTY8208j>SP80VYZJ0P2ATI4209JFUP@0U9BD0P2K
Vi/208b<S080W9bL0P2BTY8209FEU@80Vi^K0P2DU9@209RHV080Ti>C0P2KVi/208n?S`80RHV90P2M
WId209JFUP80SHf=0`2UYJD207=cL`80T92@0P2NWYh208n?S`80UYJF0P1mOGd20;Vi^@80I6AT0P2?
Shl20;Bd]080OWin0P2JVYX20:f][@80IVIV0P32`/8209:BTP80Ng]k0P2FUYHk09BDU080@d=33`3o
ool000d0oooo0P13@d<209BDU080Ti>C102DU9@209>CT`80U9BD0P2CTi<:09BDU080RHV90P1mOGd3
0<71`@80PH610P2CTi<208R8R080VYZJ0P2:RXX208f=S@80U9BD102HV9P20:6QX@80UIFE0P2QXJ42
0:BTY080RXZ:0P2ATI4209:BTP80UIFE0P2HV9P209:BTP80U9BD0P2IVIT4092@T080VYZJ0P2CTi<4
09BDU080TI6A0P2BTY8709BDU0@0TY:B0P2ATI4208n?S`80SXj>0P2HV9P209BDU080TY:B0P2GUiL2
09JFUP80UIFE0P2BTY82092@T080UYJF0P2DU9@209>CT`80SHf=0P2GUiL209:BTP80U9BD0P2FUYH2
096AT@80UYJF0P2ATI4209:BTP@0S8b<0P2OWil209^KV`80RXZ:0P2DU9@308B4Q080WYjN0P2VYZH2
08b<S080RHV9102OWil20;bl_080HF5Q0P2NWYh20:f][@80MGEe0P2LW9`20;2`/080MgMg0P3De=@2
06MWI`80TY:B0P2EUIDS09BDU080Ti>C5P2DU9@204=3@`l0oooo000=0?ooo`80@d=30P2DU9@209>C
T`@0U9BD0P2CTi<209BDU080Ti>C2P2DU9@208V9R@80OGem0`31`L420861P@80Ti>C0P28R8P209ZJ
VP80RXZ:0P2=SHd209BDU0@0V9RH0P2QXJ4209FEU@80XJ6Q0P2TY:@208Z:RP80TI6A0P2BTY8209FE
U@80V9RH0P2BTY8209BDU080VIVI102@T90209ZJVP80Ti>C102DU9@2096AT@80TY:B1`2DU9@409:B
TP80TI6A0P2?Shl208j>SP80V9RH0P2DU9@209:BTP80UiNG0P2FUYH209FEU@80TY:B0P2@T90209JF
UP80U9BD0P2CTi<208f=S@80UiNG0P2BTY8209BDU080UYJF0P2ATI4209JFUP80TI6A0P2BTY8408b<
S080WinO0P2KVi/208Z:RP80U9BD0`24Q8@209jNWP80YZJV0P2<S8`208V9R@@0WinO0P2l_;`2065Q
H@80WYjN0P2][Jd207EeM@80W9bL0P2`/;0207MgM`80e=CD0P1WIfL209:BTP80UIFE8`2DU9@209>C
TaH0U9BD0P13@d<?0?ooo`003@3oool204=3@`H0U9BD0P2CTi<209VIV@80Ti>C302DU9@209:BTP80
I6AT0`2f][H20:6QX@80W9bL0P2SXj<209NGU`80U9BD0P2RXZ8209:BTP80VIVI0P2?Shl20:BTY080
QHF50P2HV9P209JFUP80RXZ:0P2IVIT2096AT@80U9BD0P2FUYH209>CT`80U9BD0P2FUYH209^KV`80
TY:B0P2ATI4209:BTP80U9BD0P2CTi<209VIV@80VYZJ0P2BTY8209>CT`D0U9BD0P2BTY8209VIV@@0
UiNG0P2EUID209>CT`80WIfM102EUID209>CT`80UIFE0P2HV9P209FEU@80TI6A0P2KVi/409BDU080
T92@0P2CTi<209RHV080TY:B0P2EUID2092@T080XJ6Q0P2CTi<209^KV`80S8b<0P2EUID209JFUP80
U9BD0`2OWil2096AT@80WYjN0P1mOGd209nOW`80VYZJ102LW9`2096AT@80LW9b0P2IVIT207alO080
W9bL0P2GUiL20;Vi^@80Shn?0P1lO7`U09BDU080Ti>C0P2IVIT209>CTa@0U9BD0P13@d<?0?ooo`00
3@3oool204=3@`H0U9BD0P2CTi<209VIV@80Ti>C302DU9@209:BTP80I6AT0`2f][H20:6QX@80W9bL
0P2SXj<209NGU`80U9BD0P2RXZ8209:BTP80VIVI0P2?Shl20:BTY080QHF50P2HV9P209JFUP80RXZ:
0P2IVIT2096AT@80U9BD0P2FUYH209>CT`80U9BD0P2FUYH209^KV`80TY:B0P2ATI4209:BTP80U9BD
0P2CTi<209VIV@80VYZJ0P2BTY8209>CT`D0U9BD0P2BTY8209VIV@@0UiNG0P2EUID209>CT`80WIfM
102EUID209>CT`80UIFE0P2HV9P209FEU@80TI6A0P2KVi/409BDU080T92@0P2CTi<209RHV080TY:B
0P2EUID2092@T080XJ6Q0P2CTi<209^KV`80S8b<0P2EUID209JFUP80U9BD0`2OWil2096AT@80WYjN
0P1mOGd209nOW`80VYZJ102LW9`2096AT@80LW9b0P2IVIT207alO080W9bL0P2GUiL20;Vi^@80Shn?
0P1lO7`U09BDU080Ti>C0P2IVIT209>CTa@0U9BD0P13@d<?0?ooo`003@3oool204=3@`H0U9BD0P2C
Ti<209VIV@80Ti>C302DU9@209:BTP80I6AT0`2f][H20:6QX@80W9bL0P2SXj<209NGU`80U9BD0P2R
XZ8209:BTP80VIVI0P2?Shl20:BTY080QHF50P2HV9P209JFUP80RXZ:0P2IVIT2096AT@80U9BD0P2F
UYH209>CT`80U9BD0P2FUYH209^KV`80TY:B0P2ATI4209:BTP80U9BD0P2CTi<209VIV@80VYZJ0P2B
TY8209>CT`D0U9BD0P2BTY8209VIV@@0UiNG0P2EUID209>CT`80WIfM102EUID209>CT`80UIFE0P2H
V9P209FEU@80TI6A0P2KVi/409BDU080T92@0P2CTi<209RHV080TY:B0P2EUID2092@T080XJ6Q0P2C
Ti<209^KV`80S8b<0P2EUID209JFUP80U9BD0`2OWil2096AT@80WYjN0P1mOGd209nOW`80VYZJ102L
W9`2096AT@80LW9b0P2IVIT207alO080W9bL0P2GUiL20;Vi^@80Shn?0P1lO7`U09BDU080Ti>C0P2I
VIT209>CTa@0U9BD0P13@d<?0?ooo`003@3oool204=3@`P0U9BD0P2CTi<>09BDU080UYJF0P1LG5`3
0=[JfP80P8200P2OWil4092@T080RXZ:0P2?Shl209FEU@80TY:B0P2PX:0209>CT`80V9RH0P2:RXX2
09ZJVP80TI6A0P2DU9@208n?S`80UYJF0P2?Shl209:BTP80U9BD0P2EUID208n?S`80TY:B0P2JVYX2
09RHV080TI6A0P2BTY8209VIV@80Shn?0P2@T90209bLW0<0TI6A0P2BTY82092@T080UiNG0P2DU9@2
09FEU@80U9BD0P2CTi<4092@T080UYJF102CTi<209NGU`80UIFE0P2ATI4209ZJVP80VIVI0P2HV9P2
09NGU`80Ti>C0P2DU9@209>CT`80UiNG0P2ATI4208j>SP80TY:B0P2FUYH209RHV080Shn?0P2>SXh2
09>CT`<0SXj>0P2XZ:P207moO`80Y:BT0P2DU9@208Z:RP80Vi^K0P2c/k<208N7Q`80Ng]k0P2`/;02
08^;R`80UIFE0P2GUiL20<c<c080PH610P29RHTW09BDU080Ti>C5P2DU9@204=3@`l0oooo000=0?oo
o`80@d=3202DU9@209>CT`h0U9BD0P2FUYH205aLG0<0f][J0P20P80209nOW`@0T92@0P2:RXX208n?
S`80UIFE0P2BTY820:2PX080Ti>C0P2HV9P208Z:RP80VYZJ0P2ATI4209BDU080Shn?0P2FUYH208n?
S`80TY:B0P2DU9@209FEU@80Shn?0P2BTY8209ZJVP80V9RH0P2ATI4209:BTP80VIVI0P2?Shl2092@
T080W9bL0`2ATI4209:BTP80T92@0P2GUiL209BDU080UIFE0P2DU9@209>CT`@0T92@0P2FUYH409>C
T`80UiNG0P2EUID2096AT@80VYZJ0P2IVIT209RHV080UiNG0P2CTi<209BDU080Ti>C0P2GUiL2096A
T@80SXj>0P2BTY8209JFUP80V9RH0P2?Shl208j>SP80Ti>C0`2>SXh20:RXZ080Ogmo0P2TY:@209BD
U080RXZ:0P2KVi/20;>c/`80QhN70P1kNg/20;2`/080Rh^;0P2EUID209NGU`80c<c<0P21PH4208V9
RBL0U9BD0P2CTi<F09BDU080@d=33`3oool000d0oooo0P13@d<H09BDU080UiNG0P1UIFD30:>SX`80
/K6a0P2LW9`208^;R`80SHf=0P2QXJ4208f=S@80WIfM0P2KVi/207moO`@0VIVI0P2EUID209BDU080
UYJF0P2@T90209FEU@80TI6A0P2FUYH209VIV@80Ti>C0P2EUID209VIV@80TY:B0P2?Shl409VIV@80
TY:B0P2@T90209^KV`80UiNG0P2>SXh309VIV@80V9RH0P2GUiL209>CT`80UIFE0P2CTi<209BDU080
Ti>C0P2JVYX209:BTP80UiNG0P2ATI4209ZJVP80SHf=0P2FUYH209BDU080SHf=0P2EUID209:BTP80
SXj>0P2BTY8209NGU`80TY:B0P2FUYH208n?S`80WinO0P2BTY8209NGU`80UIFE0P29RHT209fMW@80
Rh^;0`2>SXh209BDU080TI6A0P2EUID209JFUP80XZ:R0P2^[Zh207emO@80VYZJ0P2>SXh209bLW080
PH610P2IVIT207UiN@80^;Rh0P1aLG4209:BTSl0U9BD0P13@d<?0?ooo`003@3oool204=3@aP0U9BD
0P2GUiL206EUI@<0Xj>S0P2a/K4209bLW080Rh^;0P2=SHd20:6QX@80SHf=0P2MWId209^KV`80Ogmo
102IVIT209FEU@80U9BD0P2FUYH2092@T080UIFE0P2ATI4209JFUP80VIVI0P2CTi<209FEU@80VIVI
0P2BTY8208n?S`@0VIVI0P2BTY82092@T080Vi^K0P2GUiL208j>SP<0VIVI0P2HV9P209NGU`80Ti>C
0P2EUID209>CT`80U9BD0P2CTi<209ZJVP80TY:B0P2GUiL2096AT@80VYZJ0P2=SHd209JFUP80U9BD
0P2=SHd209FEU@80TY:B0P2>SXh209:BTP80UiNG0P2BTY8209JFUP80Shn?0P2OWil209:BTP80UiNG
0P2EUID208V9R@80WIfM0P2;Rh/308j>SP80U9BD0P2ATI4209FEU@80UYJF0P2RXZ820:j^[P80OGem
0P2JVYX208j>SP80W9bL0P21PH4209VIV@80NGUi0P2h^;P2075aL@80TY:B?`2DU9@204=3@`l0oooo
000=0?ooo`80@d=30P2DU9@209>CT`80U9BD0P2CTi<@09BDU080UYJF0P1TI6@30?Shn080Q8B40P1k
Ng/209jNWP80T92@0P2?Shl209>CT`80UYJF0P22PX820;Ng]`80UIFE0P2?Shl208j>SP80Xj>S0P2E
UID2096AT@80Ti>C0P2DU9@209JFUP80TI6A0P2DU9@209JFUP80TI6A0P2BTY8209^KV`80T92@0P2A
TI4209:BTP80VIVI0P2=SHd209JFUP80VYZJ0`2=SHd609FEU@80Ti>C102EUID609>CT`80SHf=0P2M
WId209FEU@80TY:B0P2FUYH2096AT@80WYjN0P2;Rh/209ZJVP80Ti>C0P2IVIT209BDU080Ti>C0P2H
V9P208n?S`80X:2P0P29RHT209JFUP80SXj>0P2MWId209JFUP80WinO0`2TY:@20820P080V9RH0P2N
WYh20:BTY080P8200P2i^KT207alO080TI6A0P2FUYH20:f][@80R8R80P2JVYX20:VYZ@80PH610P2:
RXY109BDU080@d=33`3oool000d0oooo0P13@d<209BDU080Ti>C0P2DU9@209>CTa00U9BD0P2FUYH2
06ATI0<0n?Sh0P24Q8@207]kN`80WYjN0P2@T90208n?S`80Ti>C0P2FUYH208:2PP80]kNg0P2EUID2
08n?S`80SXj>0P2SXj<209FEU@80TI6A0P2CTi<209BDU080UYJF0P2ATI4209BDU080UYJF0P2ATI42
09:BTP80Vi^K0P2@T902096AT@80TY:B0P2IVIT208f=S@80UYJF0P2JVYX308f=S@H0UIFE0P2CTi<4
09FEU@H0Ti>C0P2=SHd209fMW@80UIFE0P2BTY8209JFUP80TI6A0P2NWYh208^;R`80VYZJ0P2CTi<2
09VIV@80U9BD0P2CTi<209RHV080Shn?0P2PX:0208V9R@80UYJF0P2>SXh209fMW@80UYJF0P2OWil3
0:BTY080P8200P2HV9P209jNWP80Y:BT0P20P8020;Vi^@80O7al0P2ATI4209JFUP80[Jf]0P28R8P2
09ZJVP80ZJVY0P21PH4208Z:RT40U9BD0P13@d<?0?ooo`003@3oool204=3@`80Ti>C0P2IVIT209:B
TP80VIVI0P2CTi<>09BDU080UIFE0P29RHT306MWI`80WYjN0P2VYZH209JFUP@0UiNG0P2HV9P208j>
SP80WIfM0P2;Rh/209fMW@80UYJF0P2DU9@2092@T080V9RH0P2ATI4209>CT`80UIFE0P2>SXh209>C
T`@0UYJF102@T90209RHV080Shn?0P2KVi/2096AT@80V9RH0P2IVIT209JFUP80SHf=0`2HV9P209JF
UP80UIFE202DU9@209JFUP80Ti>C0P2?Shl209bLW080TY:B0P2@T90209RHV080UYJF0P2ATI4209jN
WP80SHf=0P2JVYX209:BTP80UiNG0P2DU9@209:BTP80T92@0P2CTi<209VIV@80R8R80P2KVi/209ZJ
VP80VIVI0P2<S8`208B4Q0<0R8R80P2JVYX208b<S080WIfM0P2EUID208N7Q`80/[:b0P1iNGT209JF
UP80RXZ:0P2WYjL208Z:RP80VYZJ0P2/[:`207UiN@80Ti>C@@2DU9@204=3@`l0oooo000=0?ooo`80
@d=30P2CTi<209VIV@80TY:B0P2IVIT209>CT`h0U9BD0P2EUID208V9R@<0IfMW0P2NWYh20:JVYP80
UYJF102GUiL209RHV080SXj>0P2MWId208^;R`80WIfM0P2FUYH209BDU080T92@0P2HV9P2096AT@80
Ti>C0P2EUID208j>SP80Ti>C102FUYH4092@T080V9RH0P2?Shl209^KV`80TI6A0P2HV9P209VIV@80
UYJF0P2=SHd309RHV080UYJF0P2EUID809BDU080UYJF0P2CTi<208n?S`80W9bL0P2BTY82092@T080
V9RH0P2FUYH2096AT@80WYjN0P2=SHd209ZJVP80TY:B0P2GUiL209BDU080TY:B0P2@T90209>CT`80
VIVI0P28R8P209^KV`80VYZJ0P2IVIT208b<S080Q8B40`28R8P209ZJVP80S8b<0P2MWId209FEU@80
QhN70P2b/[8207UiN@80UYJF0P2:RXX20:NWY`80RXZ:0P2JVYX20:b/[080NGUi0P2CTi=109BDU080
@d=33`3oool000d0oooo0P13@d<209BDU080Ti>C0P2DU9@209>CTa80U9BD0P2EUID305mOG`80e]KF
0P2OWil209BDU080X:2P0P2BTY8209JFUP80XJ6Q0P2BTY82092@T080UIFE0P29RHT209NGU`80T92@
0P2EUID209:BTP80U9BD0P2@T90209bLW080TI6A0P2EUID209BDU0@0UiNG0P2FUYH209^KV`80TI6A
0P2DU9@209:BTP80SXj>102IVIT308f=S@80UiNG302DU9@209:BTP80WIfM102DU9@2096AT@80VIVI
0P2<S8`209FEU@80TY:B102ATI4209>CT`80UiNG0P2CTi<209bLW080SXj>0P2EUID208Z:RP80V9RH
0P2JVYX208b<S080SXj>0P2QXJ4209:BTP<0Xj>S0P2FUYH209jNWP80Shn?0P2UYJD2096AT@80^;Rh
0P1_Kfl209fMW@80VIVI0P2[Zj/208J6QP80TY:B0P2IVIT208R8R080Ti>C@@2DU9@204=3@`l0oooo
000=0?ooo`80@d=30P2DU9@209>CT`80U9BD0P2CTi<B09BDU080UIFE0`1OGel20=KFeP80WinO0P2D
U9@20:2PX080TY:B0P2FUYH20:6QX@80TY:B0P2@T90209FEU@80RHV90P2GUiL2092@T080UIFE0P2B
TY8209BDU080T92@0P2LW9`2096AT@80UIFE0P2DU9@409NGU`80UYJF0P2KVi/2096AT@80U9BD0P2B
TY8208j>SP@0VIVI0`2=SHd209NGU``0U9BD0P2BTY8209fMW@@0U9BD0P2ATI4209VIV@80S8b<0P2E
UID209:BTP@0TI6A0P2CTi<209NGU`80Ti>C0P2LW9`208j>SP80UIFE0P2:RXX209RHV080VYZJ0P2<
S8`208j>SP80XJ6Q0P2BTY830:>SX`80UYJF0P2NWYh208n?S`80YJFU0P2ATI420;Rh^080Kfm_0P2M
WId209VIV@80Zj^[0P26QXH209:BTP80VIVI0P28R8P209>CTd40U9BD0P13@d<?0?ooo`003@3oool2
04=3@`80Ti>C602DU9@209FEU@<0PH610P27QhL20:VYZ@80UIFE0P2?Shl209>CT`@0TI6A0P2JVYX2
09jNWP80Ti>C0P2JVYX209RHV080VIVI0P2BTY8409BDU080T92@0P2DU9@2092@T080UIFE0P2GUiL2
08b<S080VIVI0P2?Shl2096AT@80TY:B0P2DU9@2092@T080VYZJ0P2=SHd209FEU@<0VIVI0P2<S8`2
09NGU`80U9BD0P2FUYH609BDU080TY:B0P2FUYH208j>SP80U9BD0P2HV9P209:BTP80UiNG0P2EUID2
09BDU080Shn?0P2KVi/209BDU080V9RH0P2EUID2096AT@80V9RH0P2?Shl209jNWP80Shn?0P2ATI42
09^KV`80Shn?0P29RHT208b<S0<0WinO0P2ATI4209fMW@80S8b<0P2OWil209:BTP80[Zj^0P1dM7@2
07emO@80[jn_0P2HV9P209fMW@80UiNG0P1lO7`2096AT@80VIVI0P2CTi<o09BDU080@d=33`3oool0
00d0oooo0P13@d<209>CTaP0U9BD0P2EUID30861P@80QhN70P2YZJT209FEU@80Shn?0P2CTi<4096A
T@80VYZJ0P2NWYh209>CT`80VYZJ0P2HV9P209VIV@80TY:B102DU9@2092@T080U9BD0P2@T90209FE
U@80UiNG0P2<S8`209VIV@80Shn?0P2ATI4209:BTP80U9BD0P2@T90209ZJVP80SHf=0P2EUID309VI
V@80S8b<0P2GUiL209BDU080UYJF1P2DU9@209:BTP80UYJF0P2>SXh209BDU080V9RH0P2BTY8209NG
U`80UIFE0P2DU9@208n?S`80Vi^K0P2DU9@209RHV080UIFE0P2ATI4209RHV080Shn?0P2NWYh208n?
S`80TI6A0P2KVi/208n?S`80RHV90P2<S8`309nOW`80TI6A0P2MWId208b<S080WinO0P2BTY820:j^
[P80M7Ad0P1mOGd20:n_[`80V9RH0P2MWId209NGU`80O7al0P2ATI4209VIV@80Ti>C?`2DU9@204=3
@`l0oooo000=0?ooo`80@T920P2IVIT209>CTaP0U9BD0`2@T902069RHP80][Jf0P2YZJT209fMW@80
UiNG0P2IVIT209>CT`80T92@0P2RXZ8209BDU080RXZ:0P2BTY82096AT@80Vi^K0P2;Rh/209BDU080
VIVI0P2FUYH209RHV080Ti>C0P2DU9@409FEU@80VIVI0P2ATI4209VIV@80Shn?0P2IVIT209BDU080
UIFE0P2FUYH309>CT`80UiNG0P2FUYH609BDU080UYJF0P2DU9@2096AT@80UYJF0P2EUID209NGU`80
T92@0P2DU9@209FEU@80U9BD0P2BTY8209RHV080TY:B102@T90209JFUP80TY:B0P2EUID209VIV@80
Rh^;0P2LW9`208f=S@80UYJF0P2CTi<209NGU`80Shn?0`2LW9`209>CT`80UiNG0P2IVIT208b<S080
QhN70P2e]KD208:2PP80P8200P2QXJ4208n?S`80U9BD0P2GUiL208V9R@80U9BD0P2CTi=109BDU080
@d=33`3oool000d0oooo0P12@T8209VIV@80Ti>C602DU9@3092@T080HV9R0P2f][H20:VYZ@80WIfM
0P2GUiL209VIV@80Ti>C0P2@T9020::RXP80U9BD0P2:RXX209:BTP80TI6A0P2KVi/208^;R`80U9BD
0P2IVIT209JFUP80V9RH0P2CTi<209BDU0@0UIFE0P2IVIT2096AT@80VIVI0P2?Shl209VIV@80U9BD
0P2EUID209JFUP<0Ti>C0P2GUiL209JFUPH0U9BD0P2FUYH209BDU080TI6A0P2FUYH209FEU@80UiNG
0P2@T90209BDU080UIFE0P2DU9@209:BTP80V9RH0P2BTY84092@T080UYJF0P2BTY8209FEU@80VIVI
0P2;Rh/209bLW080SHf=0P2FUYH209>CT`80UiNG0P2?Shl309bLW080Ti>C0P2GUiL209VIV@80S8b<
0P27QhL20;Fe]@80PX:20P20P8020:6QX@80Shn?0P2DU9@209NGU`80RHV90P2DU9@209>CTd40U9BD
0P13@d<?0?ooo`003@3oool204=3@`80Ti>C7@2DU9@207=cL`80c<c<0P2TY:@20:ZZZP80U9BD0P2H
V9P20:2PX080U9BD0P2FUYH209:BTP80YJFU0P2?Shl208f=S@80RXZ:0P2IVIT209BDU080SXj>0P2D
U9@208n?S`80TY:B0P2CTi<209FEU@80UiNG0P2>SXh2092@T080V9RH102EUID209JFUPL0UIFE0P2D
U9@209>CT`80UIFE102CTi<209:BTP80TI6A0P2GUiL209JFUP80Ti>C0P2FUYH209>CT`80UYJF0P2E
UID209BDU080Shn?0P2FUYH209>CT`@0UYJF0P2GUiL2096AT@80U9BD0P2<S8`209FEU@80UYJF0P2A
TI4209NGU`80TY:B0P2CTi<209JFUP<0WYjN0P2?Shl209JFUP80VYZJ0P27QhL209ZJVP80a<C40P22
PX8209NGU`80YJFU0P2GUiL209RHV080PH610P2?Shm509BDU080@d=33`3oool000d0oooo0P13@d<2
09>CTad0U9BD0P1cLg<20<c<c080Y:BT0P2ZZZX209BDU080V9RH0P2PX:0209BDU080UYJF0P2BTY82
0:FUY@80Shn?0P2=SHd208Z:RP80VIVI0P2DU9@208j>SP80U9BD0P2?Shl209:BTP80Ti>C0P2EUID2
09NGU`80SXj>0P2@T90209RHV0@0UIFE0P2FUYH709FEU@80U9BD0P2CTi<209FEU@@0Ti>C0P2BTY82
096AT@80UiNG0P2FUYH209>CT`80UYJF0P2CTi<209JFUP80UIFE0P2DU9@208n?S`80UYJF0P2CTi<4
09JFUP80UiNG0P2ATI4209BDU080S8b<0P2EUID209JFUP80TI6A0P2GUiL209:BTP80Ti>C0P2FUYH3
09jNWP80Shn?0P2FUYH209ZJVP80QhN70P2JVYX20<C4a080PX:20P2GUiL20:FUY@80UiNG0P2HV9P2
0861P@80Shn?A@2DU9@204=3@`l0oooo000=0?ooo`80@d=30P2CTi<B09BDU080Ti>C2@2DU9@2092@
T080HF5Q0P2CTi<20:f][@80VIVI0P2=SHd208B4Q080Vi^K0P2MWId209>CT`80Rh^;0P2JVYX209RH
V080T92@0P2>SXh209BDU080VIVI0P2BTY8209VIV@80V9RH102DU9@209FEU@80UiNG0P2FUYH209BD
U080UiNG0P2=SHd409FEU@80Ti>C1@2DU9@209>CT`80VYZJ0P2ATI4209RHV0@0UYJF0P2GUiL208f=
S@80V9RH0P2>SXh209RHV080UIFE0P2DU9@209:BTP80W9bL0P2BTY82096AT@80U9BD0P2KVi/208Z:
RP80VIVI0P2DU9@208V9R@80X:2P0P2@T90209VIV@80QXJ60P2EUID209NGU`80Vi^K0`23Ph<209bL
W080Rh^;0P2IVIT209NGU`80[:b/0P2SXj<206a/K080V9RH0P2IVIT208j>SP80ZZZZ0P1mOGd209VI
V@80Ti>C@`2DU9@204=3@`l0oooo000=0?ooo`80@d=30P2CTi<B09BDU080Ti>C2@2DU9@2092@T080
HF5Q0P2CTi<20:f][@80VIVI0P2=SHd208B4Q080Vi^K0P2MWId209>CT`80Rh^;0P2JVYX209RHV080
T92@0P2>SXh209BDU080VIVI0P2BTY8209VIV@80V9RH102DU9@209FEU@80UiNG0P2FUYH209BDU080
UiNG0P2=SHd409FEU@80Ti>C1@2DU9@209>CT`80VYZJ0P2ATI4209RHV0@0UYJF0P2GUiL208f=S@80
V9RH0P2>SXh209RHV080UIFE0P2DU9@209:BTP80W9bL0P2BTY82096AT@80U9BD0P2KVi/208Z:RP80
VIVI0P2DU9@208V9R@80X:2P0P2@T90209VIV@80QXJ60P2EUID209NGU`80Vi^K0`23Ph<209bLW080
Rh^;0P2IVIT209NGU`80[:b/0P2SXj<206a/K080V9RH0P2IVIT208j>SP80ZZZZ0P1mOGd209VIV@80
Ti>C@`2DU9@204=3@`l0oooo000=0?ooo`80@T920P2IVIT209>CT`h0U9BD0P2CTi<209VIV@80Ti>C
1`2DU9@209JFUP80S8b<0P1hN7P206ATI080^[Zj0P2?Shl209nOW`80Rh^;0P2CTi<209bLW080VYZJ
0P2;Rh/209VIV@80UiNG0P2<S8`2096AT@80UYJF0P2@T90209BDU080Shn?0P2@T90209RHV080TY:B
0P2EUID409BDU080Ti>C102EUID209>CT`80UIFE0`2CTi<409:BTP@0TI6A0P2FUYH409BDU080S8b<
0P2BTY8209RHV080UYJF102DU9@209FEU@80TI6A0P2BTY8209RHV080UYJF0P2CTi<208n?S`80U9BD
0P2NWYh208f=S@80XJ6Q0P2?Shl208^;R`80Ti>C0P2QXJ420:2PX080S8b<0P2MWId309bLW080SXj>
0P2MWId208J6QP80X:2P0P3Cdm<206MWI`80RHV90P2XZ:P209JFUP80[:b/0P2=SHd208R8R080TY:B
0P2CTi=309BDU080@d=33`3oool000d0oooo0P12@T8209VIV@80Ti>C3P2DU9@209>CT`80VIVI0P2C
Ti<709BDU080UYJF0P2<S8`207QhN080I6AT0P2j^[X208n?S`80WinO0P2;Rh/209>CT`80W9bL0P2J
VYX208^;R`80VIVI0P2GUiL208b<S080TI6A0P2FUYH2092@T080U9BD0P2?Shl2092@T080V9RH0P2B
TY8209FEU@@0U9BD0P2CTi<409FEU@80Ti>C0P2EUID309>CT`@0TY:B102ATI4209JFUP@0U9BD0P2<
S8`209:BTP80V9RH0P2FUYH409BDU080UIFE0P2ATI4209:BTP80V9RH0P2FUYH209>CT`80Shn?0P2D
U9@209jNWP80SHf=0P2QXJ4208n?S`80Rh^;0P2CTi<20:6QX@80X:2P0P2<S8`209fMW@<0W9bL0P2>
SXh209fMW@80QXJ60P2PX:020=?Cd`80IfMW0P29RHT20:RXZ080UYJF0P2/[:`208f=S@80R8R80P2B
TY8209>CTd<0U9BD0P13@d<?0?ooo`003@3oool204=3@`80Ti>C4P2DU9@209>CT`T0U9BD0P2EUID2
09JFUP80V9RH0P1`L70209ZJVP80[Zj^0P2<S8`20:^[Z`80T92@0P2PX:0209BDU080UYJF0P2BTY82
09>CT`80TI6A0P2NWYh209:BTP80V9RH0P2@T90209RHV080VIVI0P2EUID209NGU`80TI6A0P2DU9@2
09:BTP80VYZJ0P2CTi<209BDU080Ti>C0P2JVYX3092@T080VYZJ0P2GUiL209RHV0@0U9BD0P2BTY82
09JFUP80VYZJ0P2GUiL209FEU@80U9BD0P2EUID409BDU080Shn?0P2IVIT209FEU@80U9BD0P2@T902
09RHV0@0Shn?0P2GUiL208>3P`80UiNG0P2JVYX209^KV`80UIFE0P2CTi<208n?S`80Ph>30`2][Jd2
096AT@80SHf=0P2OWil20<W9b@80ATI60P2=SHd209ZJVP80ZJVY0P2BTY8208n?S`80QXJ60P2>SXh2
09RHV080VYZJ@`2DU9@204=3@`l0oooo000=0?ooo`80@d=30P2CTi<B09BDU080Ti>C2@2DU9@209FE
U@80UYJF0P2HV9P2071`L080VYZJ0P2^[Zh208b<S080Zj^[0P2@T9020:2PX080U9BD0P2FUYH209:B
TP80Ti>C0P2ATI4209jNWP80TY:B0P2HV9P2092@T080V9RH0P2IVIT209FEU@80UiNG0P2ATI4209BD
U080TY:B0P2JVYX209>CT`80U9BD0P2CTi<209ZJVP<0T92@0P2JVYX209NGU`80V9RH102DU9@209:B
TP80UYJF0P2JVYX209NGU`80UIFE0P2DU9@209FEU@@0U9BD0P2?Shl209VIV@80UIFE0P2DU9@2092@
T080V9RH102?Shl209NGU`80Ph>30P2GUiL209ZJVP80Vi^K0P2EUID209>CT`80Shn?0P23Ph<30:f]
[@80TI6A0P2=SHd209nOW`80bLW90P16ATH208f=S@80VYZJ0P2YZJT209:BTP80Shn?0P26QXH208j>
SP80V9RH0P2JVYY309BDU080@d=33`3oool000d0oooo0P13@d<S09BDU080UiNG0P1oOgl206][J`80
f][J0P2EUID206i^KP80ZZZZ0P25QHD209VIV@80U9BD0P2GUiL209:BTP@0Shn?0P2BTY8209JFUP80
V9RH0P2@T90209>CT`80Shn?0P2EUID209VIV@80T92@0P2HV9P2092@T0H0TY:B0P2ATI4309JFUP80
U9BD0P2<S8`2096AT@80VYZJ0P2<S8`209ZJVP80SHf=0P2FUYH209BDU080UIFE102DU9@209FEU@80
TY:B0P2HV9P208j>SP80UYJF0P2ATI4209NGU`80U9BD0P2?Shl20:>SX`80S8b<0P2@T90209BDU080
TI6A0P2?Shl208Z:RP80UIFE0P2SXj<209VIV@<0GemO0P2d];@20:ZZZP80Zj^[0P1cLg<20:n_[`80
QhN70P2QXJ4209fMW@80VYZJ0P2CTi<208J6QP80Ti>C0P2JVYX208V9R@80UYJF@@2DU9@204=3@`l0
oooo000=0?ooo`80@d=38`2DU9@209NGU`80Ogmo0P1[Jf/20=[JfP80UIFE0P1^KVh20:ZZZP80QHF5
0P2IVIT209BDU080UiNG0P2BTY8408n?S`80TY:B0P2FUYH209RHV080T92@0P2CTi<208n?S`80UIFE
0P2IVIT2092@T080V9RH0P2@T90609:BTP80TI6A0`2FUYH209BDU080S8b<0P2ATI4209ZJVP80S8b<
0P2JVYX208f=S@80UYJF0P2DU9@209FEU@@0U9BD0P2EUID209:BTP80V9RH0P2>SXh209JFUP80TI6A
0P2GUiL209BDU080Shn?0P2SXj<208b<S080T92@0P2DU9@2096AT@80Shn?0P2:RXX209FEU@80Xj>S
0P2IVIT305mOG`80];Bd0P2ZZZX20:^[Z`80Lg=c0P2_[jl208N7Q`80XJ6Q0P2MWId209ZJVP80Ti>C
0P26QXH209>CT`80VYZJ0P29RHT209JFUT40U9BD0P13@d<?0?ooo`003@3oool204=3@b<0U9BD0P2G
UiL207alO080UiNG102MWId209nOW`80UYJF0P23Ph<209NGU`80TY:B0P2>SXh208^;R`80Vi^K0P2C
Ti<208n?S`80U9BD102CTi<209bLW080S8b<0P2HV9P2096AT@@0Ti>C102FUYH209NGU`80UYJF0P2=
SHd309RHV080U9BD0P2HV9P209>CT`80SXj>0P2NWYh208n?S`80UYJF0P2EUID209>CT`80TI6A0P2B
TY84092@T080S8b<0P2HV9P209FEU@80Shn?0P2FUYH209:BTP80SXj>0P2=SHd209ZJVP80TY:B0P2I
VIT209fMW@80UiNG0P2LW9`209ZJVP@0T92@0P2:RXX30:f][@80Ogmo0P2FUYH2092@T080/k>c0P1h
N7P209bLW080T92@0P2IVIT208n?S`80[Jf]0P27QhL208^;R`80U9BD0P2FUYH209FEU@80UYJF0P2E
UIDO09BDU080UIFE0P2FUYH209FEUAP0U9BD0P13@d<?0?ooo`003@3oool204=3@b<0U9BD0P2GUiL2
07alO080UiNG102MWId209nOW`80UYJF0P23Ph<209NGU`80TY:B0P2>SXh208^;R`80Vi^K0P2CTi<2
08n?S`80U9BD102CTi<209bLW080S8b<0P2HV9P2096AT@@0Ti>C102FUYH209NGU`80UYJF0P2=SHd3
09RHV080U9BD0P2HV9P209>CT`80SXj>0P2NWYh208n?S`80UYJF0P2EUID209>CT`80TI6A0P2BTY84
092@T080S8b<0P2HV9P209FEU@80Shn?0P2FUYH209:BTP80SXj>0P2=SHd209ZJVP80TY:B0P2IVIT2
09fMW@80UiNG0P2LW9`209ZJVP@0T92@0P2:RXX30:f][@80Ogmo0P2FUYH2092@T080/k>c0P1hN7P2
09bLW080T92@0P2IVIT208n?S`80[Jf]0P27QhL208^;R`80U9BD0P2FUYH209FEU@80UYJF0P2EUIDO
09BDU080UIFE0P2FUYH209FEUAP0U9BD0P13@d<?0?ooo`003@3oool204=3@b<0U9BD0P2FUYH207Ui
N@80^k^k0P1mOGd20;Fe]@80Shn?0P2LW9`20:6QX@80UiNG0P2DU9@209FEU@80X:2P0P2>SXh209BD
U080UIFE0P2=SHd209nOW`80Shn?102CTi<209:BTP@0V9RH0P2EUID2096AT@80Ti>C0P2:RXX209ZJ
VP80TY:B0`2GUiL209>CT`80SXj>0P2HV9P209NGU`80UIFE0P2IVIT408f=S@80TY:B0P2GUiL208n?
S`80UIFE0P2FUYH209>CT`80VIVI0P2BTY8209>CT`80V9RH0P2BTY8209JFUP80W9bL0P2@T90209FE
U@80TI6A0P2JVYX208Z:RP80Rh^;0P2QXJ4209RHV080WIfM0P2LW9`30:6QX@80Ti>C0P30`<0206UY
J@80UIFE0P2DU9@20:n_[`80Ogmo0P2ZZZX209:BTP80MgMg0P2BTY8209FEU@80VYZJ0P2EUID209JF
UP80S8b<0P2FUYHD09BDU080Ti>C2@2DU9@209JFUP80S8b<0P2FUYHH09BDU080@d=33`3oool000d0
oooo0P13@d<S09BDU080UYJF0P1iNGT20;^k^`80OGem0P2e]KD208n?S`80W9bL0P2QXJ4209NGU`80
U9BD0P2EUID20:2PX080SXj>0P2DU9@209FEU@80SHf=0P2OWil208n?S`@0Ti>C0P2BTY8409RHV080
UIFE0P2ATI4209>CT`80RXZ:0P2JVYX209:BTP<0UiNG0P2CTi<208j>SP80V9RH0P2GUiL209FEU@80
VIVI102=SHd209:BTP80UiNG0P2?Shl209FEU@80UYJF0P2CTi<209VIV@80TY:B0P2CTi<209RHV080
TY:B0P2FUYH209bLW080T92@0P2EUID2096AT@80VYZJ0P2:RXX208^;R`80XJ6Q0P2HV9P209fMW@80
W9bL0`2QXJ4209>CT`80`<300P1YJFT209FEU@80U9BD0P2_[jl207moO`80ZZZZ0P2BTY8207MgM`80
TY:B0P2EUID209ZJVP80UIFE0P2FUYH208b<S080UYJF502DU9@209>CT`T0U9BD0P2FUYH208b<S080
UYJF602DU9@204=3@`l0oooo000=0?ooo`80@d=38`2DU9@209FEU@80SHf=0P2;Rh/205mOG`80g=cL
0P2VYZH207YjNP80ZZZZ0P2=SHd208n?S`80UYJF0P27QhL2096AT@80VYZJ102DU9@209NGU`80Shn?
0P2DU9@209VIV@80UiNG0P2?Shl209FEU@80Ti>C0P2DU9@209>CT`80UIFE0P2BTY8208n?S`<0Rh^;
0P2BTY8209FEU@80UYJF102BTY8208j>SP80SHf=0P2GUiL209BDU080TY:B0P2ATI4209VIV@80Shn?
0P29RHT209NGU`80RXZ:0P2CTi<208^;R`80UIFE0P2=SHd209:BTP80Vi^K0P2DU9@208Z:RP80SXj>
0P2BTY820:6QX@80Ti>C0P2FUYH20:2PX080NWYj0`2ATI420:JVYP80RHV90P1kNg/209bLW080UIFE
102?Shl208J6QP80[Zj^0P2;Rh/209>CT`80U9BD0P2EUID208^;R`@0UYJF0P2EUIDB09BDU080Ti>C
0P2IVIT209>CT`L0U9BD0P2EUID209JFUP80UIFE602DU9@204=3@`l0oooo000=0?ooo`80@d=38`2D
U9@209FEU@80SHf=0P2;Rh/205mOG`80g=cL0P2VYZH207YjNP80ZZZZ0P2=SHd208n?S`80UYJF0P27
QhL2096AT@80VYZJ102DU9@209NGU`80Shn?0P2DU9@209VIV@80UiNG0P2?Shl209FEU@80Ti>C0P2D
U9@209>CT`80UIFE0P2BTY8208n?S`<0Rh^;0P2BTY8209FEU@80UYJF102BTY8208j>SP80SHf=0P2G
UiL209BDU080TY:B0P2ATI4209VIV@80Shn?0P29RHT209NGU`80RXZ:0P2CTi<208^;R`80UIFE0P2=
SHd209:BTP80Vi^K0P2DU9@208Z:RP80SXj>0P2BTY820:6QX@80Ti>C0P2FUYH20:2PX080NWYj0`2A
TI420:JVYP80RHV90P1kNg/209bLW080UIFE102?Shl208J6QP80[Zj^0P2;Rh/209>CT`80U9BD0P2E
UID208^;R`@0UYJF0P2EUIDB09BDU080Ti>C0P2IVIT209>CT`L0U9BD0P2EUID209JFUP80UIFE602D
U9@204=3@`l0oooo000=0?ooo`80@d=39@2DU9@209>CT`80OGem0P2d];@209RHV080XJ6Q0P2KVi/2
08R8R080XJ6Q0P2JVYX20:2PX080TY:B0P2=SHd207emO@80V9RH102GUiL209nOW`80T92@0P2ATI46
09:BTP80UIFE0P2BTY82096AT@80TY:B0P2HV9P209^KV`<0VYZJ0P2FUYH2096AT@80UYJF0P2BTY86
09NGU`80VIVI0P2@T90209FEU@80TI6A0P2>SXh209ZJVP80U9BD102FUYH2096AT@80WYjN0P2JVYX2
08f=S@80UiNG0P2HV9P209JFUP80YZJV0P2ZZZX209:BTP80S8b<0P2TY:@208^;R`80RHV90P2^[Zh3
08B4Q080PX:20P2HV9P209^KV`80YjNW0P27QhL20:f][@80S8b<0P2KVi/207moO`80Shn?102DU9@2
09FEU@80UYJF0P2DU9@209>CTaH0U9BD0P2CTi<909BDU080UIFE0P2FUYH209FEUAP0U9BD0P13@d<?
0?ooo`003@3oool204=3@bD0U9BD0P2CTi<207emO@80];Bd0P2HV9P20:6QX@80Vi^K0P28R8P20:6Q
X@80VYZJ0P2PX:0209:BTP80SHf=0P1mOGd209RHV0@0UiNG0P2OWil2092@T080TI6A1P2BTY8209FE
U@80TY:B0P2ATI4209:BTP80V9RH0P2KVi/309ZJVP80UYJF0P2ATI4209JFUP80TY:B1P2GUiL209VI
V@80T92@0P2EUID2096AT@80SXj>0P2JVYX209BDU0@0UYJF0P2ATI4209jNWP80VYZJ0P2=SHd209NG
U`80V9RH0P2FUYH20:JVYP80ZZZZ0P2BTY8208b<S080Y:BT0P2;Rh/208V9R@80[Zj^0`24Q8@208:2
PP80V9RH0P2KVi/20:NWY`80QhN70P2][Jd208b<S080Vi^K0P1oOgl208n?S`@0U9BD0P2EUID209JF
UP80U9BD0P2CTi<F09BDU080Ti>C2@2DU9@209FEU@80UYJF0P2EUIDH09BDU080@d=33`3oool000d0
oooo0P13@d<W09BDU080T92@0P1_Kfl209jNWP80][Jf0P2^[Zh209ZJVP80TI6A0P2=SHd208N7Q`80
WIfM0P2JVYX20:NWY`80Ti>C0P2KVi/209BDU080SXj>0P2BTY8209RHV080U9BD0P2BTY8208f=S@80
VYZJ0P2EUID20:2PX080UiNG0P24Q8@209bLW0<0U9BD0P2CTi<208^;R`80WinO0P2<S8`20:6QX@80
SXj>0P2OWil207inOP80ZJVY0P27QhL20:>SX`80S8b<0P2OWil209fMW@80Shn?0P2GUiL209FEU@80
Ti>C0P2@T9020:2PX080QhN70P1lO7`209>CT`80PX:20P2>SXh208N7Q`80X:2P0P2IVIT208V9R@80
NGUi0P2GUiL30;fm_@80ZJVY0P25QHD208R8R080W9bL0P2QXJ4208R8R080Shn?0P2^[Zh208F5Q@@0
U9BD0P2CTi<409BDU080Ti>C0P2IVIT209>CTaP0U9BD0P2CTi<509BDU080UYJF0P2<S8`209JFUQP0
U9BD0P13@d<?0?ooo`003@3oool204=3@bL0U9BD0P2@T90206m_K`80WYjN0P2f][H20:j^[P80VYZJ
0P2ATI4208f=S@80QhN70P2MWId209ZJVP80YjNW0P2CTi<209^KV`80U9BD0P2>SXh209:BTP80V9RH
0P2DU9@209:BTP80SHf=0P2JVYX209FEU@80X:2P0P2GUiL208B4Q080W9bL0`2DU9@209>CT`80Rh^;
0P2OWil208b<S080XJ6Q0P2>SXh209nOW`80OWin0P2YZJT208N7Q`80Xj>S0P2<S8`209nOW`80WIfM
0P2?Shl209NGU`80UIFE0P2CTi<2092@T080X:2P0P27QhL207alO080Ti>C0P22PX8208j>SP80QhN7
0P2PX:0209VIV@80RHV90P1iNGT209NGU`<0_Kfm0P2YZJT208F5Q@80R8R80P2LW9`20:6QX@80R8R8
0P2?Shl20:j^[P80QHF5102DU9@209>CT`@0U9BD0P2CTi<209VIV@80Ti>C602DU9@209>CT`D0U9BD
0P2FUYH208b<S080UYJF602DU9@204=3@`l0oooo000=0?ooo`80@d=3302DU9@209>CT`80U9BD0P2C
Ti<G09BDU080TI6A0P1kNg/2061PH080VYZJ0P2DU9@20;:b/P@0UIFE0P30`<0209JFUP80UiNG0P27
QhL208B4Q080Rh^;0P2>SXh209JFUP80Shn?0P2GUiL209FEU@80WYjN0P2CTi<209:BTP80TI6A0P2G
UiL209FEU@80TI6A0`2=SHd209jNWP80U9BD0P2IVIT209BDU080UYJF0P2DU9@209FEU@80[Jf]102B
TY820:BTY080ZJVY0P23Ph<20:ZZZP80Rh^;0P2VYZH209^KV`80UiNG0P2JVYX209:BTP80ZZZZ0P2P
X:0209jNWP80UIFE0P2IVIT209FEU@80U9BD0P27QhL20:b/[080Xj>S0P2>SXh308J6QP80SHf=0P2G
UiL20:^[Z`80V9RH0P1oOgl208Z:RP80`/;20P1bLW82096AT@@0U9BD0P2KVi/609BDU080Ti>C602D
U9@209>CT`80VIVI0P2CTi<309BDU080UIFE0P2FUYH209FEUAP0U9BD0P13@d<?0?ooo`003@3oool2
04=3@``0U9BD0P2CTi<209BDU080Ti>C5`2DU9@2096AT@80Ng]k0P1PH60209ZJVP80U9BD0P2b/[84
09FEU@80`<300P2FUYH209NGU`80QhN70P24Q8@208^;R`80SXj>0P2FUYH208n?S`80UiNG0P2EUID2
09jNWP80Ti>C0P2BTY82096AT@80UiNG0P2EUID2096AT@<0SHf=0P2NWYh209BDU080VIVI0P2DU9@2
09JFUP80U9BD0P2EUID20:f][@@0TY:B0P2TY:@20:VYZ@80Ph>30P2ZZZX208^;R`80YZJV0P2KVi/2
09NGU`80VYZJ0P2BTY820:ZZZP80X:2P0P2NWYh209FEU@80VIVI0P2EUID209BDU080QhN70P2/[:`2
0:>SX`80SXj>0`26QXH208f=S@80UiNG0P2[Zj/209RHV080Ogmo0P2:RXX20<;2`P80LW9b0P2ATI44
09BDU080Vi^K1P2DU9@209>CTaP0U9BD0P2CTi<209VIV@80Ti>C0`2DU9@209FEU@80UYJF0P2EUIDH
09BDU080@d=33`3oool000d0oooo0P13@d<209BDU080Ti>C1P2DU9@209>CT`80VIVI0P2BTY8209VI
V@80Ti>C6@2DU9@207IfMP80b<S80P2GUiL208^;R`80VIVI0P29RHT2075aL@80OWin0P2IVIT208V9
R@80YJFU0P2KVi/209:BTP80Shn?0P2GUiL209:BTP80UYJF0P2BTY8208b<S080X:2P0P2EUID208R8
R080UIFE0P2KVi/308n?S`80Ti>C0P2HV9P209JFUP80S8b<0P2YZJT207QhN080XZ:R0P1mOGd209BD
U080Vi^K0P1nOWh209>CT`80[:b/0P1iNGT209ZJVP80PX:20P2CTi<209RHV080Shn?0P1mOGd20:BT
Y080TI6A0P21PH4208:2PP80UIFE0P2?Shl207inOP80VIVI0P24Q8@2096AT@80SHf=0`2SXj<40:6Q
X@80Ph>30P24Q8@209FEU@80UiNG0P2ATI4208R8R0@0U9BD0P2FUYH208^;R`80UYJF802DU9@209>C
Tb<0U9BD0P13@d<?0?ooo`003@3oool204=3@`80U9BD0P2CTi<609BDU080Ti>C0P2IVIT209:BTP80
VIVI0P2CTi<I09BDU080MWIf0P38b<P209NGU`80Rh^;0P2IVIT208V9R@80LG5a0P1nOWh209VIV@80
RHV90P2UYJD209^KV`80TY:B0P2?Shl209NGU`80TY:B0P2FUYH209:BTP80S8b<0P2PX:0209FEU@80
R8R80P2EUID209^KV`<0Shn?0P2CTi<209RHV080UYJF0P2<S8`20:VYZ@80N7Qh0P2RXZ8207emO@80
U9BD0P2KVi/207inOP80Ti>C0P2/[:`207UiN@80VYZJ0P22PX8209>CT`80V9RH0P2?Shl207emO@80
Y:BT0P2ATI420861P@80PX:20P2EUID208n?S`80OWin0P2IVIT208B4Q080TI6A0P2=SHd30:>SX`@0
XJ6Q0P23Ph<208B4Q080UIFE0P2GUiL2096AT@80R8R8102DU9@209JFUP80Rh^;0P2FUYHP09BDU080
Ti>C8`2DU9@204=3@`l0oooo000=0?ooo`80@d=30P2CTi<209VIV@80Ti>C1P2DU9@209>CT`80U9BD
0P2CTi<K09BDU080TI6A0P1DE5@20>3Ph080U9BD0P2KVi/20:b/[080XZ:R0P2PX:020:JVYP80Xj>S
0P2?Shl2096AT@80UiNG102FUYH208^;R`80Vi^K0P2FUYH209:BTP80XJ6Q0P2CTi<209jNWP80T92@
0P2MWId308f=S@80Vi^K0P20P80209RHV080XJ6Q0P2=SHd20:b/[080Ogmo0P2LW9`207emO@80Y:BT
0P2FUYH209FEU@80UYJF0P1`L7020:n_[`80UIFE0P2ATI4207MgM`80SHf=0P2JVYX208^;R`80WYjN
0P2PX:020;6a/@80Z:RX0P2CTi<20:NWY`@0WYjN0P2VYZH20:ZZZP<0W9bL0P2?Shl208V9R@80I6AT
0P2SXj<207moO`80emOG0P1bLW8209>CT`@0U9BD0P2EUID209JFUP80UIFE0P2DU9@209>CTd40U9BD
0P13@d<?0?ooo`003@3oool204=3@`80Ti>C0P2IVIT209>CT`H0U9BD0P2CTi<209BDU080Ti>C6`2D
U9@2096AT@80E5AD0P3Ph>0209BDU080Vi^K0P2/[:`20::RXP80X:2P0P2VYZH20:>SX`80Shn?0P2A
TI4209NGU`@0UYJF0P2;Rh/209^KV`80UYJF0P2BTY820:6QX@80Ti>C0P2NWYh2092@T080WIfM0`2=
SHd209^KV`80P8200P2HV9P20:6QX@80SHf=0P2/[:`207moO`80W9bL0P1mOGd20:BTY080UYJF0P2E
UID209JFUP80L71`0P2_[jl209FEU@80TI6A0P1gMgL208f=S@80VYZJ0P2;Rh/209jNWP80X:2P0P2a
/K420:RXZ080Ti>C0P2WYjL409jNWP80YZJV0P2ZZZX309bLW080Shn?0P29RHT206ATI080Xj>S0P1o
Ogl20=OGe`80LW9b0P2CTi<409BDU080UIFE0P2FUYH209FEU@80U9BD0P2CTi=109BDU080@d=33`3o
ool000d0oooo0P13@d<209BDU080Ti>C:@2DU9@209FEU@80TI6A0P1CDe<20:NWY`80V9RH0P2BTY82
07IfMP80PX:20P25QHD208>3P`80TI6A0P2CTi<208f=S@80X:2P0P2FUYH209FEU@80Shn?0P2JVYX2
08f=S@80TY:B0P2;Rh/209ZJVP80W9bL0P26QXH309RHV080WYjN0P2BTY820;Bd]080R8R80P24Q8@2
0:BTY080_kno0P1kNg/20;^k^`80NWYj0P2?Shl208f=S@80QHF50P2/[:`208b<S080LW9b0P2f][H2
0;2`/080TI6A102JVYX209NGU`@0RXZ:0P20P80209:BTP80TI6A0P2[Zj/209VIV@80Z:RX0P1VIVH3
0:6QX@80RXZ:0P1ZJVX20=WIf@80Ph>30P2l_;`208J6QP80OWin0P2FUYH409BDU080Ti>C102DU9@2
09:BTP80VIVI0P2CTi<H09BDU080Ti>C0P2DU9@209FEU@<0UYJF0P2EUIDL09BDU080@d=33`3oool0
00d0oooo0P13@d<209BDU080Ti>C:@2DU9@209FEU@80TI6A0P1CDe<20:NWY`80V9RH0P2BTY8207If
MP80PX:20P25QHD208>3P`80TI6A0P2CTi<208f=S@80X:2P0P2FUYH209FEU@80Shn?0P2JVYX208f=
S@80TY:B0P2;Rh/209ZJVP80W9bL0P26QXH309RHV080WYjN0P2BTY820;Bd]080R8R80P24Q8@20:BT
Y080_kno0P1kNg/20;^k^`80NWYj0P2?Shl208f=S@80QHF50P2/[:`208b<S080LW9b0P2f][H20;2`
/080TI6A102JVYX209NGU`@0RXZ:0P20P80209:BTP80TI6A0P2[Zj/209VIV@80Z:RX0P1VIVH30:6Q
X@80RXZ:0P1ZJVX20=WIf@80Ph>30P2l_;`208J6QP80OWin0P2FUYH409BDU080Ti>C102DU9@209:B
TP80VIVI0P2CTi<H09BDU080Ti>C0P2DU9@209FEU@<0UYJF0P2EUIDL09BDU080@d=33`3oool000d0
oooo0P13@d<_09BDU080UIFE0P21PH420:f][@80Shn?0P2c/k<20:>SX`80/[:b0P2TY:@208j>SP80
Shn?0P2FUYH208^;R`80TI6A0P2EUID2092@T080Vi^K0P2BTY8209BDU080UIFE0P2KVi/209>CT`80
S8b<0P2RXZ8309>CT`80R8R80P2f][H206MWI`80TY:B0P2`/;02065QH@80WYjN0P2VYZH207UiN@80
XZ:R0P2LW9`2092@T080XJ6Q0P2ATI4209^KV`80[jn_0P2>SXh209>CT`80PH610P2KVi/209NGU`80
RHV90P2DU9@209^KV`80Z:RX0P2QXJ42096AT@80OWin0P2=SHd20820P080YjNW0`1/K6`207EeM@80
[:b/0P2XZ:P208J6QP80d];B0P1]KFd209>CT`@0U9BD0P2BTY8209VIV@80Ti>C0P2BTY8209VIV@80
Ti>C0P2FUYH209FEU@@0U9BD0P2EUID209JFUP80UIFE2P2DU9@209>CT`80VIVI0P2CTi<209JFUP<0
S8b<0P2FUYHL09BDU080@d=33`3oool000d0oooo0P13@d<_09BDU080UIFE0P21PH420:f][@80Shn?
0P2c/k<20:>SX`80/[:b0P2TY:@208j>SP80Shn?0P2FUYH208^;R`80TI6A0P2EUID2092@T080Vi^K
0P2BTY8209BDU080UIFE0P2KVi/209>CT`80S8b<0P2RXZ8309>CT`80R8R80P2f][H206MWI`80TY:B
0P2`/;02065QH@80WYjN0P2VYZH207UiN@80XZ:R0P2LW9`2092@T080XJ6Q0P2ATI4209^KV`80[jn_
0P2>SXh209>CT`80PH610P2KVi/209NGU`80RHV90P2DU9@209^KV`80Z:RX0P2QXJ42096AT@80OWin
0P2=SHd20820P080YjNW0`1/K6`207EeM@80[:b/0P2XZ:P208J6QP80d];B0P1]KFd209>CT`@0U9BD
0P2BTY8209VIV@80Ti>C0P2BTY8209VIV@80Ti>C0P2FUYH209FEU@@0U9BD0P2EUID209JFUP80UIFE
2P2DU9@209>CT`80VIVI0P2CTi<209JFUP<0S8b<0P2FUYHL09BDU080@d=33`3oool000d0oooo0P13
@d<a09BDU080TY:B0P1EEED20?Win@80TY:B0P1TI6@209bLW080WinO0P2MWId208f=S@80Shn?0P2L
W9`208b<S080[:b/0P2EUID209fMW@80R8R80P2;Rh/2096AT@80XZ:R0P2>SXh2096AT@80VYZJ0`24
Q8@209VIV@80O7al0P2f][H209:BTP80T92@0P2XZ:P207IfMP80WIfM0P2JVYX208n?S`80VYZJ0P2A
TI4209BDU080Vi^K0P2@T90208b<S080RHV90P2EUID20::RXP80SHf=0P2>SXh209VIV@80WIfM0P2L
W9`209:BTP80R8R80P2KVi/20::RXP80];Bd0P2FUYH207EeM@<0^KVi0P2WYjL20:2PX080MGEe0P2k
^k/207AdM080TI6A0P2HV9P409>CT`80VIVI0P2BTY8209>CT`80VIVI0P2BTY8209JFUP80S8b<0P2F
UYH409BDU080UYJF0P2<S8`209JFUP`0U9BD0P2CTi<209BDU080UIFE0`2FUYH209FEUA`0U9BD0P13
@d<?0?ooo`003@3oool204=3@c40U9BD0P2BTY8205EEE@80nOWi0P2BTY8206ATI080W9bL0P2OWil2
09fMW@80SHf=0P2?Shl209bLW080S8b<0P2/[:`209FEU@80WIfM0P28R8P208^;R`80TI6A0P2RXZ82
08j>SP80TI6A0P2JVYX308B4Q080VIVI0P1lO7`20;Jf]P80TY:B0P2@T9020:RXZ080MWIf0P2MWId2
09ZJVP80Shn?0P2JVYX2096AT@80U9BD0P2KVi/2092@T080S8b<0P29RHT209FEU@80XZ:R0P2=SHd2
08j>SP80VIVI0P2MWId209bLW080TY:B0P28R8P209^KV`80XZ:R0P2d];@209JFUP80MGEe0`2i^KT2
0:NWY`80X:2P0P1eMGD20;^k^`80M7Ad0P2ATI4209RHV0@0Ti>C0P2IVIT209:BTP80Ti>C0P2IVIT2
09:BTP80UYJF0P2<S8`209JFUP@0U9BD0P2FUYH208b<S080UYJF302DU9@209>CT`80U9BD0P2EUID3
09JFUP80UIFE702DU9@204=3@`l0oooo000=0?ooo`80@d=3<`2DU9@208f=S@80E5AD0P35aLD20=[J
fP80KFe]0P1nOWh208N7Q`80YJFU0P29RHT208n?S`80QhN70P2WYjL208:2PP80WinO0P2PX:0209FE
U@80WinO0P2SXj<208b<S080T92@0P2RXZ8308j>SP80X:2P0P2:RXX20:^[Z`80Ph>30P2KVi/2092@
T080ZJVY0P2TY:@206QXJ080Z:RX0P2MWId209FEU@80TY:B0P2>SXh209^KV`80Ti>C0P2NWYh209fM
W@80SXj>0P2CTi<209VIV@80Ti>C0P1oOgl20:FUY@80Z:RX0P2CTi<20820P080WIfM0P1UIFD207Ad
M080S8b<0`2?Shl20;6a/@80K6a/0P3Lg=`206a/K080PX:20P2:RXX209ZJVP80Ti>C0P2DU9@209:B
TP80U9BD0P2FUYH409BDU080UIFE0P2FUYH209FEU@@0U9BD0P2EUID209JFUP80UIFE0P2DU9@209>C
Ta40U9BD0P2EUID209JFUP80UIFE602DU9@204=3@`l0oooo000=0?ooo`80@d=3<`2DU9@208f=S@80
E5AD0P35aLD20=[JfP80KFe]0P1nOWh208N7Q`80YJFU0P29RHT208n?S`80QhN70P2WYjL208:2PP80
WinO0P2PX:0209FEU@80WinO0P2SXj<208b<S080T92@0P2RXZ8308j>SP80X:2P0P2:RXX20:^[Z`80
Ph>30P2KVi/2092@T080ZJVY0P2TY:@206QXJ080Z:RX0P2MWId209FEU@80TY:B0P2>SXh209^KV`80
Ti>C0P2NWYh209fMW@80SXj>0P2CTi<209VIV@80Ti>C0P1oOgl20:FUY@80Z:RX0P2CTi<20820P080
WIfM0P1UIFD207AdM080S8b<0`2?Shl20;6a/@80K6a/0P3Lg=`206a/K080PX:20P2:RXX209ZJVP80
Ti>C0P2DU9@209:BTP80U9BD0P2FUYH409BDU080UIFE0P2FUYH209FEU@@0U9BD0P2EUID209JFUP80
UIFE0P2DU9@209>CTa40U9BD0P2EUID209JFUP80UIFE602DU9@204=3@`l0oooo000=0?ooo`80@d=3
202DU9@209>CTbL0U9BD0P2CTi<209VIV@80Shn?0P1>CTh20:j^[P80d=3@0P2CTi<209:BTP80UYJF
0P26QXH208N7Q`80S8b<0P2SXj<20:^[Z`80NGUi0P2PX:0208N7Q`80Ogmo0P27QhL20:FUY@80Q8B4
0P2<S8`30:ZZZP80QhN70P28R8P20:BTY080TY:B0P27QhL209>CT`80QXJ60P33`l<20:BTY080UYJF
0P1ZJVX20:2PX080T92@0P2_[jl208Z:RP80WYjN0P2RXZ820:NWY`80WinO0P2ZZZX20;>c/`80YJFU
0P2VYZH208R8R080PX:20P2WYjL209^KV`80MWIf0P2CTi<20;^k^`80Vi^K0`2?Shl209:BTP80`L71
0P2QXJ4207]kN`@0UYJF102DU9@209FEU@80VYZJ0P2DU9@208^;R`80UYJF102DU9@209FEU@80UYJF
0P2EUID809BDU080Ti>C0P2IVIT209BDU080UYJF0P2EUID;09BDU080UYJF0P2<S8`209JFUQP0U9BD
0P13@d<?0?ooo`003@3oool204=3@`P0U9BD0P2CTi<W09BDU080Ti>C0P2IVIT208n?S`80CTi>0P2^
[Zh20=3@d080Ti>C0P2BTY8209JFUP80QXJ60P27QhL208b<S080Xj>S0P2[Zj/207UiN@80X:2P0P27
QhL207moO`80QhN70P2UYJD208B4Q080S8b<0`2ZZZX208N7Q`80R8R80P2TY:@209:BTP80QhN70P2C
Ti<208J6QP80`l?30P2TY:@209JFUP80JVYZ0P2PX:02092@T080[jn_0P2:RXX209jNWP80XZ:R0P2W
YjL209nOW`80ZZZZ0P2c/k<20:FUY@80YZJV0P28R8P208:2PP80YjNW0P2KVi/207IfMP80Ti>C0P2k
^k/209^KV`<0Shn?0P2BTY820<71`@80XJ6Q0P1kNg/409JFUP@0U9BD0P2EUID209ZJVP80U9BD0P2;
Rh/209JFUP@0U9BD0P2EUID209JFUP80UIFE202DU9@209>CT`80VIVI0P2DU9@209JFUP80UIFE2`2D
U9@209JFUP80S8b<0P2FUYHH09BDU080@d=33`3oool000d0oooo0P13@d<609BDU080Ti>C0P2IVIT2
09>CTbL0U9BD0P2CTi<209BDU080R8R80P1jNWX20;jn_P80[Jf]0P2ZZZX208V9R@80R8R80P29RHT2
07IfMP80Xj>S0P2RXZ8209BDU080PH610P2XZ:P20:6QX@80RXZ:0P2GUiL209jNWP80R8R80`2<S8`2
09ZJVP80Vi^K0P24Q8@2092@T080Y:BT0P29RHT209:BTP80Rh^;0P2:RXX20:NWY`80/K6a0P29RHT2
09NGU`80V9RH0P2@T90209fMW@80MgMg0P2HV9P209VIV@80UIFE0P2?Shl208b<S080UiNG0P2IVIT2
09FEU@80HF5Q0P2PX:0208J6QP80TI6A0P30`<0209NGU`<0U9BD0P2;Rh/20;Zj^P80JVYZ0P2BTY82
09JFUP@0U9BD0P2GUiL208^;R`80UIFE0P2JVYX209BDU080UIFE0P2FUYH209FEU@80UYJF0P2<S8`2
09JFUPX0U9BD0P2CTi<209JFUP80S8b<0P2FUYH409BDU080UIFE0P2FUYH509FEU@80UYJF0P2EUIDH
09BDU080@d=33`3oool000d0oooo0P13@d<609BDU080Ti>C0P2IVIT209>CTbL0U9BD0P2CTi<209BD
U080R8R80P1jNWX20;jn_P80[Jf]0P2ZZZX208V9R@80R8R80P29RHT207IfMP80Xj>S0P2RXZ8209BD
U080PH610P2XZ:P20:6QX@80RXZ:0P2GUiL209jNWP80R8R80`2<S8`209ZJVP80Vi^K0P24Q8@2092@
T080Y:BT0P29RHT209:BTP80Rh^;0P2:RXX20:NWY`80/K6a0P29RHT209NGU`80V9RH0P2@T90209fM
W@80MgMg0P2HV9P209VIV@80UIFE0P2?Shl208b<S080UiNG0P2IVIT209FEU@80HF5Q0P2PX:0208J6
QP80TI6A0P30`<0209NGU`<0U9BD0P2;Rh/20;Zj^P80JVYZ0P2BTY8209JFUP@0U9BD0P2GUiL208^;
R`80UIFE0P2JVYX209BDU080UIFE0P2FUYH209FEU@80UYJF0P2<S8`209JFUPX0U9BD0P2CTi<209JF
UP80S8b<0P2FUYH409BDU080UIFE0P2FUYH509FEU@80UYJF0P2EUIDH09BDU080@d=33`3oool000d0
oooo0P13@d<809BDU080Ti>C9`2DU9@209FEU@80UYJF0P2EUID209:BTP80NWYj0P27QhL20:VYZ@80
UIFE0P2XZ:P20;Jf]P80VYZJ0P2WYjL2069RHP80_Kfm0P2PX:0209BDU080QHF50P2MWId209RHV080
YZJV0P2LW9`20:2PX0<0U9BD0P2KVi/209FEU@80TI6A0P2KVi/20:6QX@80SXj>0P2;Rh/209VIV@80
TI6A0P2_[jl2079bLP80XZ:R0P2PX:0208>3P`80TY:B0P2NWYh20:6QX@80VIVI0P2?Shl209>CT`80
Ogmo0P2HV9P208b<S080J6QX0P2?Shl208N7Q`80Rh^;0P1oOgl20;Vi^@80SHf=0P23Ph<309jNWP80
f=SH0P1JFUX209>CT`80SXj>0P2?Shl209NGU`80W9bL0P2:RXX20:2PX080Rh^;0P2DU9@209VIV@80
UIFE0P2<S8`209JFUP80UIFE0P2FUYH209FEU@`0U9BD0P2EUID209JFUP80UIFE102DU9@209JFUP80
S8b<0`2FUYHN09BDU080@d=33`3oool000d0oooo0P13@d<809BDU080Ti>C9`2DU9@209FEU@80UYJF
0P2EUID209:BTP80NWYj0P27QhL20:VYZ@80UIFE0P2XZ:P20;Jf]P80VYZJ0P2WYjL2069RHP80_Kfm
0P2PX:0209BDU080QHF50P2MWId209RHV080YZJV0P2LW9`20:2PX0<0U9BD0P2KVi/209FEU@80TI6A
0P2KVi/20:6QX@80SXj>0P2;Rh/209VIV@80TI6A0P2_[jl2079bLP80XZ:R0P2PX:0208>3P`80TY:B
0P2NWYh20:6QX@80VIVI0P2?Shl209>CT`80Ogmo0P2HV9P208b<S080J6QX0P2?Shl208N7Q`80Rh^;
0P1oOgl20;Vi^@80SHf=0P23Ph<309jNWP80f=SH0P1JFUX209>CT`80SXj>0P2?Shl209NGU`80W9bL
0P2:RXX20:2PX080Rh^;0P2DU9@209VIV@80UIFE0P2<S8`209JFUP80UIFE0P2FUYH209FEU@`0U9BD
0P2EUID209JFUP80UIFE102DU9@209JFUP80S8b<0`2FUYHN09BDU080@d=33`3oool000d0oooo0P13
@d<a09BDU080UYJF0P2;Rh/209JFUP80U9BD0P2@T90207=cL`80WYjN0P2d];@2092@T080TY:B0P2C
Ti<209fMW@80TY:B0P1eMGD20;Bd]080YZJV0P2<S8`208B4Q080Xj>S0P1eMGD20:b/[080V9RH0`2J
VYX208F5Q@80SHf=0P24Q8@20:b/[080OWin0P2PX:0208N7Q`80XJ6Q0P2MWId208V9R@80/[:b0P2^
[Zh20;6a/@80WinO0P2XZ:P209:BTP80WYjN0P2IVIT20:2PX080QXJ60P24Q8@207EeM@80Y:BT0P2P
X:02096AT@80YjNW0P2o_kl20;Jf]P@0Rh^;0P2WYjL30;Ng]`80FUYJ0P2BTY8209NGU`80VIVI0P2?
Shl208f=S@80UIFE0P2GUiL208^;R`80UiNG102CTi<209FEU@80V9RH0P2GUiL209FEUAX0U9BD0P2E
UID209JFUP<0UIFE7P2DU9@204=3@`l0oooo000=0?ooo`80@d=3<@2DU9@209JFUP80Rh^;0P2FUYH2
09BDU080T92@0P1cLg<209jNWP80];Bd0P2@T90209:BTP80Ti>C0P2MWId209:BTP80MGEe0P2d];@2
0:JVYP80S8b<0P24Q8@20:>SX`80MGEe0P2/[:`209RHV0<0VYZJ0P25QHD208f=S@80Q8B40P2/[:`2
07inOP80X:2P0P27QhL20:6QX@80WIfM0P29RHT20;:b/P80[Zj^0P2a/K4209nOW`80Z:RX0P2BTY82
09jNWP80VIVI0P2PX:0208J6QP80Q8B40P1eMGD20:BTY080X:2P0P2ATI420:NWY`80_kno0P2f][H4
08^;R`80YjNW0`2g]kL205YJFP80TY:B0P2GUiL209VIV@80Shn?0P2=SHd209FEU@80UiNG0P2;Rh/2
09NGU`@0Ti>C0P2EUID209RHV080UiNG0P2EUIDJ09BDU080UIFE0P2FUYH309FEUAh0U9BD0P13@d<?
0?ooo`003@3oool204=3@c<0U9BD0P2KVi/209BDU080Ti>C0P2JVYX2096AT@80LW9b0P2?Shl20=KF
eP80XJ6Q0P28R8P208B4Q080SXj>0P2BTY8207MgM`80];Bd0P2<S8`20;Ng]`80QHF50P2SXj<208N7
Q`80VYZJ0`2b/[820:NWY`80[Jf]0P2?Shl20:6QX@80SHf=0P2XZ:P208Z:RP80XZ:R0P1VIVH207If
MP80OWin0P2DU9@207YjNP80T92@0P2?Shl209BDU0@0KVi^0P24Q8@207IfMP80Vi^K0P2b/[8208^;
R`80TY:B0P2OWil20:2PX080VYZJ0P22PX8207moO`80YZJV0P3@d=0305UIF@80Ti>C0P2EUID208^;
R`80UYJF102EUID209BDU080UIFE0P2FUYH209>CT`80VIVI0P2CTi<209JFUP@0SHf=0P2FUYH209>C
Tcd0U9BD0P13@d<?0?ooo`003@3oool204=3@c<0U9BD0P2KVi/209BDU080Ti>C0P2JVYX2096AT@80
LW9b0P2?Shl20=KFeP80XJ6Q0P28R8P208B4Q080SXj>0P2BTY8207MgM`80];Bd0P2<S8`20;Ng]`80
QHF50P2SXj<208N7Q`80VYZJ0`2b/[820:NWY`80[Jf]0P2?Shl20:6QX@80SHf=0P2XZ:P208Z:RP80
XZ:R0P1VIVH207IfMP80OWin0P2DU9@207YjNP80T92@0P2?Shl209BDU0@0KVi^0P24Q8@207IfMP80
Vi^K0P2b/[8208^;R`80TY:B0P2OWil20:2PX080VYZJ0P22PX8207moO`80YZJV0P3@d=0305UIF@80
Ti>C0P2EUID208^;R`80UYJF102EUID209BDU080UIFE0P2FUYH209>CT`80VIVI0P2CTi<209JFUP@0
SHf=0P2FUYH209>CTcd0U9BD0P13@d<?0?ooo`003@3oool204=3@c<0U9BD0P2CTi<409BDU080UIFE
0P2=SHd209>CT`80OWin0P1LG5`20<;2`P80XZ:R0P2h^;P209NGU`80NWYj0P2:RXX208>3P`80ZZZZ
0P2ATI420:FUY@80V9RH0P2a/K42096AT@<0Lg=c0P2QXJ420<_;b`80[jn_0P3AdM420;Fe]@80W9bL
0P2CTi<209fMW@80alO70P2@T90209BDU080Ti>C0P2?Shl207QhN080Lg=c0P23Ph<209fMW@80WinO
0P2DU9@209fMW@80W9bL102?Shl20;2`/080[:b/0P2>SXh209FEU@80PX:20P35aLD20;bl_080HV9R
0`2ATI4209>CT`80VYZJ0P2EUID209BDU080V9RH0P2GUiL209>CT`80U9BD0P2CTi<209VIV@80TI6A
0P2DU9@209FEU@80V9RH0P2GUiL209>CT`80V9RH0P2CTi<209BDU080Ti>C0P2DU9@209JFUP80UIFE
<@2DU9@204=3@`l0oooo000=0?ooo`80@d=3<`2DU9@209>CT`@0U9BD0P2EUID208f=S@80Ti>C0P1n
OWh205aLG080`/;20P2RXZ820;Rh^080UiNG0P1jNWX208Z:RP80Ph>30P2ZZZX2096AT@80YJFU0P2H
V9P20;6a/@80TI6A0`1cLg<20:6QX@80bl_;0P2_[jl20=7Ad@80]KFe0P2LW9`209>CT`80WIfM0P37
alL2092@T080U9BD0P2CTi<208n?S`80N7Qh0P1cLg<208>3P`80WIfM0P2OWil209BDU080WIfM0P2L
W9`408n?S`80/;2`0P2/[:`208j>SP80UIFE0P22PX820<G5a@80_;bl0P1RHV83096AT@80Ti>C0P2J
VYX209FEU@80U9BD0P2HV9P209NGU`80Ti>C0P2DU9@209>CT`80VIVI0P2ATI4209BDU080UIFE0P2H
V9P209NGU`80Ti>C0P2HV9P209>CT`80U9BD0P2CTi<209BDU080UYJF0P2EUIDa09BDU080@d=33`3o
ool000d0oooo0P13@d<U09BDU080UIFE0P2FUYH209FEU@h0U9BD0P2GUiL208n?S`80UiNG0P2DU9@2
08n?S`80De=C0P3<c<`20<C4a080Shn?0P2NWYh208b<S080M7Ad0P2EUID209NGU`80PX:20P2NWYh2
07AdM080RXZ:0`2ZZZX207=cL`80K6a/0P1GEeL2065QH@80LW9b0P24Q8@208J6QP80V9RH0P20P802
09:BTP80S8b<0P2:RXX208:2PP80U9BD0P2o_kl208V9R@80VYZJ0P2OWil209FEU@80SHf=0P2WYjL2
09^KV`80^k^k0P2<S8`208>3P`80TI6A0P2OWil20=OGe`80Cdm?0P1kNg/2096AT@<0RHV90P2KVi/2
09:BTP@0U9BD0P2BTY8209RHV0@0Ti>C0P2DU9@209:BTP80VIVI0P2CTi<209JFUP80S8b<0P2FUYH2
09>CT`80V9RH102CTi<209VIV@80UIFE0P2<S8`209JFUP`0U9BD0P2EUID209JFUPD0UIFE0P2FUYH2
09BDU080Ti>C5P2DU9@204=3@`l0oooo000=0?ooo`80@d=39@2DU9@209FEU@80UYJF0P2EUID>09BD
U080UiNG0P2?Shl209NGU`80U9BD0P2?Shl205=CD`80c<c<0P34a<@208n?S`80WYjN0P2<S8`207Ad
M080UIFE0P2GUiL208:2PP80WYjN0P1dM7@208Z:RP<0ZZZZ0P1cLg<206a/K080EeMG0P1QHF42079b
LP80Q8B40P26QXH209RHV080P8200P2BTY8208b<S080RXZ:0P22PX8209BDU080_kno0P29RHT209ZJ
VP80WinO0P2EUID208f=S@80YjNW0P2KVi/20;^k^`80S8b<0P23Ph<2096AT@80WinO0P3GemL204m?
C`80Ng]k0P2ATI4308V9R@80Vi^K0P2BTY8409BDU080TY:B0P2HV9P409>CT`80U9BD0P2BTY8209VI
V@80Ti>C0P2FUYH208b<S080UYJF0P2CTi<209RHV0@0Ti>C0P2IVIT209FEU@80S8b<0P2FUYH<09BD
U080UIFE0P2FUYH509FEU@80UYJF0P2DU9@209>CTaH0U9BD0P13@d<?0?ooo`003@3oool204=3@bD0
U9BD0P2FUYH208b<S080UYJF2P2DU9@209FEU@80UYJF0P2GUiL208n?S`80VIVI0P2EUID209JFUP80
T92@0P1_Kfl206ATI080gmoO0P2^[Zh209:BTP80V9RH0P29RHT208B4Q080Ogmo0P2;Rh/409:BTP<0
TI6A0P2;Rh/20:BTY080YZJV0P2MWId20::RXP80T92@0P2;Rh/208b<S080UYJF0P26QXH209fMW@80
[Jf]0P1mOGd209jNWP80Rh^;0P1nOWh20:b/[080SXj>0P2VYZH20:BTY080UiNG0P2FUYH207]kN`80
Ogmo0P2KVi/20;Vi^@80Z:RX0P1VIVH208n?S`80VIVI0P2BTY8309^KV`80Ti>C0P2FUYH209FEU@80
UYJF0P2DU9@209>CT`80TY:B0P2IVIT209>CT`80U9BD0P2CTi<209BDU080UIFE0P2FUYH209FEU@80
U9BD0P2EUID409BDU080Ti>C0P2DU9@209JFUP@0UIFE0P2FUYH209FEU@@0U9BD0P2EUID209RHV080
S8b<1@2FUYH208b<S080UiNG0P2JVYX209>CTa@0U9BD0P13@d<?0?ooo`003@3oool204=3@bD0U9BD
0P2FUYH208b<S080UYJF2P2DU9@209FEU@80UYJF0P2GUiL208n?S`80VIVI0P2EUID209JFUP80T92@
0P1_Kfl206ATI080gmoO0P2^[Zh209:BTP80V9RH0P29RHT208B4Q080Ogmo0P2;Rh/409:BTP<0TI6A
0P2;Rh/20:BTY080YZJV0P2MWId20::RXP80T92@0P2;Rh/208b<S080UYJF0P26QXH209fMW@80[Jf]
0P1mOGd209jNWP80Rh^;0P1nOWh20:b/[080SXj>0P2VYZH20:BTY080UiNG0P2FUYH207]kN`80Ogmo
0P2KVi/20;Vi^@80Z:RX0P1VIVH208n?S`80VIVI0P2BTY8309^KV`80Ti>C0P2FUYH209FEU@80UYJF
0P2DU9@209>CT`80TY:B0P2IVIT209>CT`80U9BD0P2CTi<209BDU080UIFE0P2FUYH209FEU@80U9BD
0P2EUID409BDU080Ti>C0P2DU9@209JFUP@0UIFE0P2FUYH209FEU@@0U9BD0P2EUID209RHV080S8b<
1@2FUYH208b<S080UiNG0P2JVYX209>CTa@0U9BD0P13@d<?0?ooo`003@3oool204=3@bD0U9BD0P2F
UYH208b<S080UYJF2P2DU9@209FEU@80UYJF0P2GUiL208n?S`80VIVI0P2EUID209JFUP80T92@0P1_
Kfl206ATI080gmoO0P2^[Zh209:BTP80V9RH0P29RHT208B4Q080Ogmo0P2;Rh/409:BTP<0TI6A0P2;
Rh/20:BTY080YZJV0P2MWId20::RXP80T92@0P2;Rh/208b<S080UYJF0P26QXH209fMW@80[Jf]0P1m
OGd209jNWP80Rh^;0P1nOWh20:b/[080SXj>0P2VYZH20:BTY080UiNG0P2FUYH207]kN`80Ogmo0P2K
Vi/20;Vi^@80Z:RX0P1VIVH208n?S`80VIVI0P2BTY8309^KV`80Ti>C0P2FUYH209FEU@80UYJF0P2D
U9@209>CT`80TY:B0P2IVIT209>CT`80U9BD0P2CTi<209BDU080UIFE0P2FUYH209FEU@80U9BD0P2E
UID409BDU080Ti>C0P2DU9@209JFUP@0UIFE0P2FUYH209FEU@@0U9BD0P2EUID209RHV080S8b<1@2F
UYH208b<S080UiNG0P2JVYX209>CTa@0U9BD0P13@d<?0?ooo`003@3oool204=3@bD0U9BD0P2EUID2
09JFUP80UIFE2P2DU9@209JFUP80S8b<0P2HV9P208n?S`80SXj>0P2HV9P208b<S080UYJF0P2DU9@2
07alO080J6QX0P37alL20;^k^`80Zj^[0P1mOGd2092@T080UYJF0P2IVIT209NGU`80Shn?1@2ATI42
092@T080PH610P2<S8`208f=S@80SXj>0P20P80208R8R080Ph>30P2DU9@207moO`80WIfM0P2WYjL2
07]kN`80Z:RX0P2RXZ820:RXZ080RXZ:0P2o_kl209>CT`80RHV90P28R8P209VIV@80_kno0P2b/[84
07YjNP80T92@0P2CTi<209VIV@80UIFE0`2DU9@209JFUP80S8b<0P2HV9P208^;R`80UYJF0P2DU9@2
09^KV`80Ti>C0P2FUYH209FEU@@0U9BD0P2CTi<209BDU0@0UYJF0P2<S8`209JFUP80U9BD0P2EUID2
09JFUP80UIFE0P2DU9@209JFUP80S8b<0P2FUYH409BDU080UYJF0P2<S8`209RHV0<0UIFE0P2GUiL2
09ZJVP80SXj>302DU9@209FEU@80UYJF0P2EUID609BDU080@d=33`3oool000d0oooo0P13@d<U09BD
U080UIFE0P2FUYH209FEU@X0U9BD0P2FUYH208b<S080V9RH0P2?Shl208j>SP80V9RH0P2<S8`209JF
UP80U9BD0P1lO7`206QXJ080alO70P2k^k/20:^[Z`80OGem0P2@T90209JFUP80VIVI0P2GUiL208n?
S`D0TI6A0P2@T9020861P@80S8b<0P2=SHd208j>SP80P8200P28R8P208>3P`80U9BD0P1oOgl209fM
W@80YjNW0P1kNg/20:RXZ080XZ:R0P2XZ:P208Z:RP80_kno0P2CTi<208V9R@80R8R80P2IVIT20;no
_`80/[:b101jNWX2092@T080Ti>C0P2IVIT209FEU@<0U9BD0P2FUYH208b<S080V9RH0P2;Rh/209JF
UP80U9BD0P2KVi/209>CT`80UYJF0P2EUID409BDU080Ti>C0P2DU9@409JFUP80S8b<0P2FUYH209BD
U080UIFE0P2FUYH209FEU@80U9BD0P2FUYH208b<S080UYJF102DU9@209JFUP80S8b<0P2HV9P309FE
U@80UiNG0P2JVYX208j>SP`0U9BD0P2EUID209JFUP80UIFE1P2DU9@204=3@`l0oooo000=0?ooo`80
@d=38`2DU9@209FEU@80UYJF0P2EUID<09BDU080UIFE0P2FUYH209FEU@@0UYJF1P2EUID209ZJVP80
UYJF0P25QHD207QhN080GEeM0P2n_[h20=;BdP80bl_;0P2<S8`208B4Q080PX:20P2:RXX308j>SP80
UYJF0P2SXj<209:BTP@0WIfM0P2QXJ420:ZZZP80[jn_0P2c/k<209VIV@80Shn?0P2NWYh20:BTY080
aLG50P2ZZZX208f=S@80Z:RX0P1kNg/207inOP80QHF50P2JVYX20<_;b`80[Zj^0P1]KFd207]kN`80
Rh^;0P2DU9@209JFUP80U9BD0P2EUID208^;R`<0UYJF0P2EUID209RHV080UIFE0P2KVi/209BDU080
UYJF0P2;Rh/209NGU`80Rh^;0P2FUYH209BDU080Ti>C0P2IVIT209FEU@80S8b<0P2GUiL209RHV0@0
UYJF0P2IVIT208j>SP80VIVI0P2FUYH209FEU@80UYJF0P2EUID209BDU080UIFE102FUYH209FEU@<0
UYJF0P2?Shl209:BTP80Shn?0P2MWId:09BDU080UYJF0P2<S8`209JFUPH0U9BD0P13@d<?0?ooo`00
3@3oool204=3@b<0U9BD0P2EUID209JFUP80UIFE302DU9@209FEU@80UYJF0P2EUID409JFUPH0UIFE
0P2JVYX209JFUP80QHF50P1hN7P205eMG@80_[jn0P3Bd]820<_;b`80S8b<0P24Q8@208:2PP80RXZ:
0`2>SXh209JFUP80Xj>S0P2BTY8409fMW@80XJ6Q0P2ZZZX20:n_[`80/k>c0P2IVIT208n?S`80WYjN
0P2TY:@20<G5a@80ZZZZ0P2=SHd20:RXZ080Ng]k0P1nOWh208F5Q@80VYZJ0P3;bl/20:j^[P80KFe]
0P1kNg/208^;R`80U9BD0P2FUYH209BDU080UIFE0P2;Rh/309JFUP80UIFE0P2HV9P209FEU@80Vi^K
0P2DU9@209JFUP80Rh^;0P2GUiL208^;R`80UYJF0P2DU9@209>CT`80VIVI0P2EUID208b<S080UiNG
0P2HV9P409JFUP80VIVI0P2>SXh209VIV@80UYJF0P2EUID209JFUP80UIFE0P2DU9@209FEU@@0UYJF
0P2EUID309JFUP80Shn?0P2BTY8208n?S`80WIfM2P2DU9@209JFUP80S8b<0P2FUYH609BDU080@d=3
3`3oool000d0oooo0P13@d<S09BDU080UIFE0P2;Rh/209JFUQH0U9BD0P2CTi<209^KV`80RXZ:0P2E
UID209JFUP80SHf=0P2FUYH2092@T080O7al0P1aLG4206=SH`@0a/K60P2IVIT209^KV`<0W9bL0P20
P80208R8R080T92@0P2?Shl2092@T080RHV90P2PX:0209>CT`80YjNW0P2QXJ420;Jf]P80U9BD0P1a
LG420:>SX`80MWIf0P1dM7@207moO`80ZZZZ0P30`<020:6QX@80PX:20P1_Kfl207alO080R8R80P2F
UYH209BDU080UYJF0P2<S8`209JFUP80UIFE0P2FUYH309BDU080UYJF0P2;Rh/209FEU@80Ti>C102D
U9@209FEU@80U9BD0P2KVi/609BDU080Ti>C0P2DU9@209FEU@80UYJF0P2<S8`209RHV080SHf=0P2?
Shl2096AT@80Shn?0P2<S8`409JFUP@0U9BD0P2FUYH208b<S080UYJF0P2DU9@309FEU@80Shn?0P2@
T90209ZJVP80Rh^;0P2EUID809BDU080UIFE0P2FUYH209FEU@H0U9BD0P13@d<?0?ooo`003@3oool2
04=3@b<0U9BD0P2EUID208^;R`80UYJF5P2DU9@209>CT`80Vi^K0P2:RXX209FEU@80UYJF0P2=SHd2
09JFUP80T92@0P1lO7`2075aL@80Hf=S1036a/H209VIV@80Vi^K0`2LW9`20820P080R8R80P2@T902
08n?S`80T92@0P29RHT20:2PX080Ti>C0P2WYjL20:6QX@80][Jf0P2DU9@2075aL@80Xj>S0P1fMWH2
07AdM080Ogmo0P2ZZZX20<30`080XJ6Q0P22PX8206m_K`80O7al0P28R8P209JFUP80U9BD0P2FUYH2
08b<S080UYJF0P2EUID209JFUP<0U9BD0P2FUYH208^;R`80UIFE0P2CTi<409BDU080UIFE0P2DU9@2
09^KV`H0U9BD0P2CTi<209BDU080UIFE0P2FUYH208b<S080V9RH0P2=SHd208n?S`80TI6A0P2?Shl2
08b<S0@0UYJF102DU9@209JFUP80S8b<0P2FUYH209BDU0<0UIFE0P2?Shl2092@T080VYZJ0P2;Rh/2
09FEU@P0U9BD0P2EUID209JFUP80UIFE1P2DU9@204=3@`l0oooo000=0?ooo`80@d=38@2DU9@209>C
T`80VYZJ0P2GUiL209FEUAX0U9BD0P2FUYH209FEU@80U9BD0P2EUID209BDU080UYJF0P2=SHd209NG
U`80QXJ60P1oOgl206YZJP80^[Zj0P2i^KT309ZJVP80`L710P2XZ:P209^KV`80XJ6Q0P2CTi<209ZJ
VP80PH610P1cLg<207EeM@80PX:20P2:RXX208:2PP80TI6A0P24Q8@20;>c/`80`L710P2ZZZX209BD
U080Ogmo0P20P806096AT@80WYjN0P2FUYH409NGU`80UYJF0P2EUID209BDU080Ti>C0`2IVIT209:B
TP80U9BD0P2JVYX209>CT`80U9BD0P2CTi<209VIV@80Ti>C0P2BTY8209BDU080UYJF102DU9@209>C
T`80VYZJ0P2EUID209JFUP80UIFE0P2FUYH409NGU`80UYJF0P2LW9`209FEU@80Rh^;0P2MWId209BD
U0@0UYJF0P2EUID209>CT`<0VYZJ0P2EUID209JFUP@0UIFE0P2LW9`<09BDU080UIFE0P2FUYH209FE
U@80U9BD0P13@d<?0?ooo`003@3oool204=3@b40U9BD0P2CTi<209ZJVP80UiNG0P2EUIDJ09BDU080
UYJF0P2EUID209BDU080UIFE0P2DU9@209JFUP80SHf=0P2GUiL208J6QP80Ogmo0P1ZJVX20;Zj^P80
^KVi0`2JVYX20<71`@80Z:RX0P2KVi/20:6QX@80Ti>C0P2JVYX20861P@80Lg=c0P1eMGD208:2PP80
RXZ:0P22PX82096AT@80Q8B40P2c/k<20<71`@80ZZZZ0P2DU9@207moO`80P8201P2ATI4209jNWP80
UYJF102GUiL209JFUP80UIFE0P2DU9@209>CT`<0VIVI0P2BTY8209BDU080VYZJ0P2CTi<209BDU080
Ti>C0P2IVIT209>CT`80TY:B0P2DU9@209JFUP@0U9BD0P2CTi<209ZJVP80UIFE0P2FUYH209FEU@80
UYJF102GUiL209JFUP80W9bL0P2EUID208^;R`80WIfM0P2DU9@409JFUP80UIFE0P2CTi<309ZJVP80
UIFE0P2FUYH409FEU@80W9bL302DU9@209FEU@80UYJF0P2EUID209BDU080@d=33`3oool000d0oooo
0P13@d<S09BDU080UIFE0P2;Rh/209FEUA@0U9BD0P2EUID209JFUPH0U9BD0P2CTi<209VIV@80TY:B
0P2FUYH208b<S080Vi^K0P2JVYX209BDU080TI6A0P20P8020861P@<0Q8B40P22PX8408j>SP80WIfM
0P2;Rh/209:BTP80ZJVY0P2d];@20;:b/P@0XJ6Q0P2WYjL20:FUY@80XJ6Q0P24Q8@207emO@80P820
0P2:RXX2096AT@80U9BD0P2FUYH2092@T080TI6A0P2HV9P208f=S@80Shn?0P2=SHd209FEU@80U9BD
0P2FUYH209BDU0<0Ti>C0P2JVYX209VIV@80TY:B0P2DU9@209JFUP@0UIFE0P2DU9@209^KV`80UIFE
0P29RHT209^KV`@0Ti>C0P2EUID208^;R`80UYJF2P2DU9@209>CT`80U9BD0P2GUiL208Z:RP80UiNG
0P2<S8`209RHV080UIFE0P2DU9@309>CT`80U9BD0P2FUYH209FEU@80UYJF0P2;Rh/209JFUPX0U9BD
0P2FUYH208b<S080UYJF0P2DU9@204=3@`l0oooo000=0?ooo`80@d=38`2DU9@209FEU@80Rh^;0P2E
UIDD09BDU080UIFE0P2FUYH609BDU080Ti>C0P2IVIT209:BTP80UYJF0P2<S8`209^KV`80VYZJ0P2D
U9@2096AT@80P8200P21PH4308B4Q080PX:2102>SXh209fMW@80Rh^;0P2BTY820:VYZ@80];Bd0P2b
/[840:6QX@80YjNW0P2UYJD20:6QX@80Q8B40P1mOGd20820P080RXZ:0P2ATI4209BDU080UYJF0P2@
T902096AT@80V9RH0P2=SHd208n?S`80SHf=0P2EUID209BDU080UYJF0P2DU9@309>CT`80VYZJ0P2I
VIT209:BTP80U9BD0P2FUYH409FEU@80U9BD0P2KVi/209FEU@80RHV90P2KVi/409>CT`80UIFE0P2;
Rh/209JFUPX0U9BD0P2CTi<209BDU080UiNG0P2:RXX209NGU`80S8b<0P2HV9P209FEU@80U9BD0`2C
Ti<209BDU080UYJF0P2EUID209JFUP80Rh^;0P2FUYH:09BDU080UYJF0P2<S8`209JFUP80U9BD0P13
@d<?0?ooo`003@3oool204=3@b<0U9BD102EUID209ZJVP80Ti>C4P2DU9@209JFUP80Rh^;0P2KVi/2
09>CT`@0U9BD0P2ATI4209VIV@80Ti>C102EUID209>CT`@0U9BD0P2CTi<209:BTP<0Ti>C0P29RHT2
09>CT`80TI6A0P2>SXh2096AT@80SXj>0P2<S8`408N7Q`80SHf=0P20P80208V9R@80QhN70P28R8P2
08n?S`80Ti>C0P2FUYH408f=S@@0UYJF0P2IVIT208n?S`80UiNG0P2FUYH209NGU`80UIFE0P2KVi/2
09JFUP80SXj>0P2HV9P309JFUP80RXZ:0P2EUID209BDU080UYJF0P2<S8`209RHV080S8b<0P2HV9P2
08b<S080U9BD0P2JVYX409:BTP80VIVI0P2DU9@209JFUP80UIFE1P2DU9@209FEU@80UYJF0P2EUID4
09BDU080Vi^K0P2DU9@209RHV080SXj>0P2FUYH509BDU080UIFE0P2<S8`209RHV080UiNG0P2FUYH2
09FEU@X0U9BD0P2EUID209RHV080UIFE0P2CTi<204=3@`l0oooo000=0?ooo`80@d=38`2DU9@409FE
U@80VYZJ0P2CTi<B09BDU080UYJF0P2;Rh/209^KV`80Ti>C102DU9@2096AT@80VIVI0P2CTi<409FE
U@80Ti>C102DU9@209>CT`80TY:B0`2CTi<208V9R@80Ti>C0P2ATI4208j>SP80TI6A0P2>SXh208b<
S0@0QhN70P2=SHd20820P080RHV90P27QhL208R8R080Shn?0P2CTi<209JFUP@0SHf=102FUYH209VI
V@80Shn?0P2GUiL209JFUP80UiNG0P2EUID209^KV`80UYJF0P2>SXh209RHV0<0UYJF0P2:RXX209FE
U@80U9BD0P2FUYH208b<S080V9RH0P2<S8`209RHV080S8b<0P2DU9@209ZJVP@0TY:B0P2IVIT209BD
U080UYJF0P2EUID609BDU080UIFE0P2FUYH209FEU@@0U9BD0P2KVi/209BDU080V9RH0P2>SXh209JF
UPD0U9BD0P2EUID208b<S080V9RH0P2GUiL209JFUP80UIFE2P2DU9@209FEU@80V9RH0P2EUID209>C
T`80@d=33`3oool000d0oooo0P13@d<Y09BDU080UYJF0P2EUID@09BDU080UIFE0P2FUYH609BDU080
Ti>C0P2IVIT209>CT`80UIFE0P2MWId208^;R`80UYJF0P2DU9@209:BTP80VIVI0P2CTi<309bLW080
UIFE0P2FUYH208^;R`80WIfM102DU9@209FEU@@0Ti>C0P2EUID208b<S080UYJF0P2CTi<209VIV@80
Ti>C102DU9@209FEU@80UiNG0P2HV9P208b<S080VIVI0P2?Shl209VIV@80UIFE0P2CTi<209^KV`80
R8R80P2HV9P208n?S`80SHf=0`2GUiL209RHV080UIFE0P2DU9@209FEU@80UYJF0P2GUiL209JFUP80
UiNG0P2<S8`209ZJVP80UiNG0P2BTY8209VIV@80TY:B0P2DU9@209JFUPP0U9BD0P2FUYH208f=S@80
UYJF0P2EUID209JFUP@0U9BD0P2EUID208f=S@80UYJF0P2DU9@309>CT`80VYZJ0P2GUiL208f=S@80
Shn?0P2FUYH<09BDU080UYJF0P2<S8`209FEU@80Vi^K0P13@d<?0?ooo`003@3oool204=3@bT0U9BD
0P2FUYH209FEUA00U9BD0P2EUID209JFUPH0U9BD0P2CTi<209VIV@80Ti>C0P2EUID209fMW@80Rh^;
0P2FUYH209BDU080TY:B0P2IVIT209>CT`<0W9bL0P2EUID209JFUP80Rh^;0P2MWId409BDU080UIFE
102CTi<209FEU@80S8b<0P2FUYH209>CT`80VIVI0P2CTi<409BDU080UIFE0P2GUiL209RHV080S8b<
0P2IVIT208n?S`80VIVI0P2EUID209>CT`80Vi^K0P28R8P209RHV080Shn?0P2=SHd309NGU`80V9RH
0P2EUID209BDU080UIFE0P2FUYH209NGU`80UYJF0P2GUiL208b<S080VYZJ0P2GUiL209:BTP80VIVI
0P2BTY8209BDU080UYJF202DU9@209JFUP80SHf=0P2FUYH209FEU@80UYJF102DU9@209FEU@80SHf=
0P2FUYH209BDU0<0Ti>C0P2JVYX209NGU`80SHf=0P2?Shl209JFUP`0U9BD0P2FUYH208b<S080UIFE
0P2KVi/204=3@`l0oooo000=0?ooo`80@d=37`2DU9@209FEU@80UYJF0P2EUID209BDU080UIFE0P2;
Rh/209JFUP80Ti>C602DU9@209JFUP80U9BD0P2FUYH208f=S@80S8b<0P2GUiL209FEU@80Ti>C0P2I
VIT209:BTP80UiNG0`2:RXX209JFUP80UIFE0P2HV9P208f=S@@0UYJF0P2<S8`209RHV080U9BD0P2C
Ti<209^KV`H0Ti>C102DU9@209>CT`80VIVI0P2EUID208b<S080V9RH0P2GUiL408n?S`80UYJF0P2D
U9@209:BTP80Vi^K102FUYH209bLW0<0UIFE0P2;Rh/209RHV080UYJF0P2EUID209JFUP80Rh^;0P2H
V9P209FEU@80UYJF102CTi<209JFUP@0U9BD0P2FUYH208b<S080W9bL0P2CTi<209FEU@80UYJF0P2G
UiL208j>SP80V9RH0P2FUYH208b<S080V9RH0P2EUID209ZJVP80UIFE0P2FUYH209FEU@<0U9BD0P2C
Ti<209:BTP80WIfM0P2=SHd209JFUPP0U9BD0P2EUID209JFUP80UIFE102FUYH208^;R`80ADE53`3o
ool000d0oooo0P13@d<O09BDU080UIFE0P2FUYH209FEU@80U9BD0P2EUID208^;R`80UYJF0P2CTi<H
09BDU080UYJF0P2DU9@209JFUP80SHf=0P2<S8`209NGU`80UIFE0P2CTi<209VIV@80TY:B0P2GUiL3
08Z:RP80UYJF0P2EUID209RHV080SHf=102FUYH208b<S080V9RH0P2DU9@209>CT`80Vi^K1P2CTi<4
09BDU080Ti>C0P2IVIT209FEU@80S8b<0P2HV9P209NGU`@0Shn?0P2FUYH209BDU080TY:B0P2KVi/4
09JFUP80W9bL0`2EUID208^;R`80V9RH0P2FUYH209FEU@80UYJF0P2;Rh/209RHV080UIFE0P2FUYH4
09>CT`80UYJF102DU9@209JFUP80S8b<0P2LW9`209>CT`80UIFE0P2FUYH209NGU`80SXj>0P2HV9P2
09JFUP80S8b<0P2HV9P209FEU@80VYZJ0P2EUID209JFUP80UIFE0`2DU9@209>CT`80TY:B0P2MWId2
08f=S@80UYJF202DU9@209FEU@80UYJF0P2EUID409JFUP80Rh^;0P15ADD?0?ooo`003@3oool204=3
@al0U9BD0P2FUYH208b<S080UYJF0P2CTi<209ZJVP@0UIFE0P2JVYX209>CTa80U9BD0P2CTi<209^K
V`80Rh^;0P2FUYH409FEU@80W9bL1P2DU9@209:BTP80VYZJ0P2:RXX309fMW@80U9BD102FUYH208f=
S@80V9RH0P2EUID209RHV080S8b<0P2EUID209^KV`80Ti>C0P2EUID209ZJVP80Ti>C1P2DU9@409>C
T`@0UYJF0P2EUID209RHV080SXj>0P2FUYH209>CT`80VIVI0P2DU9@208^;R`80UYJF1@2CTi<209fM
W@@0S8b<0P2FUYH209BDU080WIfM0P2;Rh/209JFUP@0U9BD0P2GUiL208^;R`80V9RH0P2EUID209NG
U`80Shn?0P2FUYH209BDU080UIFE0P2;Rh/209JFUP80V9RH0P2<S8`209JFUP80V9RH0P2>SXh208f=
S@80UIFE0P2FUYH208b<S080UYJF1@2CTi<209VIV@80Ti>C0P2FUYH209FEU@P0U9BD0P2EUID208f=
S@80UYJF0P2DU9@209FEU@80UYJF0P14A4@?0?ooo`003@3oool204=3@al0U9BD0P2FUYH208b<S080
UYJF0P2CTi<209ZJVP@0UIFE0P2JVYX209>CTa80U9BD0P2CTi<209^KV`80Rh^;0P2FUYH409FEU@80
W9bL1P2DU9@209:BTP80VYZJ0P2:RXX309fMW@80U9BD102FUYH208f=S@80V9RH0P2EUID209RHV080
S8b<0P2EUID209^KV`80Ti>C0P2EUID209ZJVP80Ti>C1P2DU9@409>CT`@0UYJF0P2EUID209RHV080
SXj>0P2FUYH209>CT`80VIVI0P2DU9@208^;R`80UYJF1@2CTi<209fMW@@0S8b<0P2FUYH209BDU080
WIfM0P2;Rh/209JFUP@0U9BD0P2GUiL208^;R`80V9RH0P2EUID209NGU`80Shn?0P2FUYH209BDU080
UIFE0P2;Rh/209JFUP80V9RH0P2<S8`209JFUP80V9RH0P2>SXh208f=S@80UIFE0P2FUYH208b<S080
UYJF1@2CTi<209VIV@80Ti>C0P2FUYH209FEU@P0U9BD0P2EUID208f=S@80UYJF0P2DU9@209FEU@80
UYJF0P14A4@?0?ooo`003@3oool204=3@al0U9BD0P2EUID209JFUP80UIFE0P2DU9@209FEU@80UYJF
0P2;Rh/209FEUA@0U9BD102CTi<209JFUP80UIFE102DU9@209>CT`H0U9BD0P2CTi<209RHV0D0Ti>C
0P2FUYH208^;R`80Vi^K0P2FUYH208j>SP80V9RH0P2EUID209JFUP80V9RH0P2:RXX209NGU`80Rh^;
0P2EUID209BDU080UIFE0P2FUYH209BDU080TY:B0P2HV9P209FEU@80S8b<0P2HV9P209BDU0@0UYJF
1P2EUID409JFUP80UIFE0`2FUYH209BDU080UIFE0P2LW9`409BDU080UIFE0P2FUYH209FEU@80Ti>C
0P2KVi/208Z:RP80WYjN0P2;Rh/209RHV080UiNG0P2=SHd209NGU`80UIFE0P2JVYX409FEU@80UYJF
0P2GUiL209JFUP80UIFE0P2GUiL209RHV0@0U9BD0P2FUYH209BDU0<0VIVI0P2CTi<209FEU@80U9BD
0P2EUID209JFUP80UIFE102DU9@209>CT`80W9bL0P2<S8`209JFUP@0U9BD0P2CTi<20492@Pl0oooo
000=0?ooo`80@d=37`2DU9@209FEU@80UYJF0P2EUID209BDU080UIFE0P2FUYH208^;R`80UIFE502D
U9@409>CT`80UYJF0P2EUID409BDU080Ti>C1P2DU9@209>CT`80V9RH1@2CTi<209JFUP80Rh^;0P2K
Vi/209JFUP80SXj>0P2HV9P209FEU@80UYJF0P2HV9P208Z:RP80UiNG0P2;Rh/209FEU@80U9BD0P2E
UID209JFUP80U9BD0P2BTY8209RHV080UIFE0P2<S8`209RHV080U9BD102FUYH609FEU@@0UYJF0P2E
UID309JFUP80U9BD0P2EUID209bLW0@0U9BD0P2EUID209JFUP80UIFE0P2CTi<209^KV`80RXZ:0P2N
WYh208^;R`80V9RH0P2GUiL208f=S@80UiNG0P2EUID209ZJVP@0UIFE0P2FUYH209NGU`80UYJF0P2E
UID209NGU`80V9RH102DU9@209JFUP80U9BD0`2IVIT209>CT`80UIFE0P2DU9@209FEU@80UYJF0P2E
UID409BDU080Ti>C0P2LW9`208b<S080UYJF102DU9@209>CT`80@T923`3oool000d0oooo0P13@d<U
09BDU080UYJF0P2<S8`209NGU`80V9RH0P2EUIDB09BDU080Ti>C0P2JVYX409FEU@80U9BD0P2CTi<2
09BDU080Ti>C1P2DU9@209>CT`80UiNG0P2IVIT509FEU@80UYJF0P2CTi<209^KV`@0SXj>0P2FUYH2
09FEU@80S8b<0P2MWId209BDU080UYJF0P2EUID209BDU080UYJF0P2<S8`209FEU@80V9RH0P2GUiL2
09>CT`80UiNG0P2;Rh/209fMW@80UYJF0P2=SHd209RHV080S8b<0P2FUYH209FEU@80SHf=0P2HV9P3
08f=S@80UYJF0P2DU9@409>CT`80UYJF0P2<S8`209JFUPH0U9BD0P2EUID209ZJVP80V9RH0P2;Rh/2
09FEU@@0UYJF0P2;Rh/409BDU080UYJF0P2<S8`209RHV080SHf=102FUYH208^;R`80Vi^K0P2CTi<4
09BDU0<0UIFE0P2FUYH208b<S0@0UYJF0P2<S8`209JFUPP0U9BD0P2FUYH209BDU0@0Ti>C0P2JVYX2
04Q8B0l0oooo000=0?ooo`80@d=39@2DU9@209JFUP80S8b<0P2GUiL209RHV080UIFE4P2DU9@209>C
T`80VYZJ102EUID209BDU080Ti>C0P2DU9@209>CT`H0U9BD0P2CTi<209NGU`80VIVI1@2EUID209JF
UP80Ti>C0P2KVi/408j>SP80UYJF0P2EUID208b<S080WIfM0P2DU9@209JFUP80UIFE0P2DU9@209JF
UP80S8b<0P2EUID209RHV080UiNG0P2CTi<209NGU`80Rh^;0P2MWId209JFUP80SHf=0P2HV9P208b<
S080UYJF0P2EUID208f=S@80V9RH0`2=SHd209JFUP80U9BD102CTi<209JFUP80S8b<0P2FUYH609BD
U080UIFE0P2JVYX209RHV080Rh^;0P2EUID409JFUP80Rh^;102DU9@209JFUP80S8b<0P2HV9P208f=
S@@0UYJF0P2;Rh/209^KV`80Ti>C102DU9@309FEU@80UYJF0P2<S8`409JFUP80S8b<0P2FUYH809BD
U080UYJF0P2DU9@409>CT`80VYZJ0P18B4P?0?ooo`003@3oool204=3@bD0U9BD0P2EUID409JFUP80
Rh^;0P2EUIDB09BDU080UYJF0P2EUID208^;R`80UIFE0P2CTi<209VIV@80TI6A0P2HV9P209>CT`80
U9BD0P2EUID209JFUP@0UIFE0`2;Rh/209JFUP80Ti>C102DU9@409JFUP80Ti>C0P2KVi/208b<S080
UiNG102DU9@209JFUP@0UIFE0P2FUYH209BDU080Ti>C0P2EUID209BDU080W9bL0P2GUiL208Z:RP80
VIVI0P2=SHd409JFUP80Ti>C0P2KVi/208b<S080X:2P0`2=SHd209JFUP@0Ti>C0P2JVYX209FEU@@0
UYJF0P2DU9@209>CT`80U9BD0P2CTi<209NGU`80S8b<0P2NWYh209VIV@80Ti>C102DU9@209ZJVP80
Ti>C0P2EUID209JFUP80UiNG0P2=SHd209JFUP80UIFE0P2FUYH609BDU080UYJF0`2<S8`209JFUP80
UIFE0P2DU9@209FEU@80UYJF0P2EUID:09BDU080Ti>C0P2IVIT209FEU@80RXZ:0P14A4@?0?ooo`00
3@3oool204=3@bD0U9BD0P2EUID409JFUP80Rh^;0P2EUIDB09BDU080UYJF0P2EUID208^;R`80UIFE
0P2CTi<209VIV@80TI6A0P2HV9P209>CT`80U9BD0P2EUID209JFUP@0UIFE0`2;Rh/209JFUP80Ti>C
102DU9@409JFUP80Ti>C0P2KVi/208b<S080UiNG102DU9@209JFUP@0UIFE0P2FUYH209BDU080Ti>C
0P2EUID209BDU080W9bL0P2GUiL208Z:RP80VIVI0P2=SHd409JFUP80Ti>C0P2KVi/208b<S080X:2P
0`2=SHd209JFUP@0Ti>C0P2JVYX209FEU@@0UYJF0P2DU9@209>CT`80U9BD0P2CTi<209NGU`80S8b<
0P2NWYh209VIV@80Ti>C102DU9@209ZJVP80Ti>C0P2EUID209JFUP80UiNG0P2=SHd209JFUP80UIFE
0P2FUYH609BDU080UYJF0`2<S8`209JFUP80UIFE0P2DU9@209FEU@80UYJF0P2EUID:09BDU080Ti>C
0P2IVIT209FEU@80RXZ:0P14A4@?0?ooo`003@3oool204=3@bT0U9BD102EUID209ZJVP80Ti>C302D
U9@209>CT`80Vi^K0P2;Rh/209JFUP80UIFE0P2LW9`409BDU080V9RH0P2GUiL209FEU@@0UYJF0P2=
SHd208n?S`80UiNG0`2FUYH209BDU080VIVI0P2CTi<609BDU080Vi^K0P2EUID209RHV080S8b<0P2E
UID209bLW080S8b<0P2FUYH609BDU080UYJF0P2<S8`209VIV@80Rh^;0P2EUID209fMW@80Rh^;0P2G
UiL209bLW080UIFE0P2LW9`209FEU@80V9RH0P2;Rh/309RHV080Ti>C0P2HV9P209>CT`80UiNG0P2;
Rh/209fMW@80Rh^;0P2GUiL209bLW080UIFE0P2MWId208^;R`80VIVI0P2;Rh/209FEU@@0U9BD0P2K
Vi/:09BDU080UIFE2P2DU9@209FEU@D0UYJF0P2DU9@209VIV@80U9BD0P2FUYH209FEU@@0U9BD0P2E
UID209JFUP80UIFE0P2FUYH409BDU0@0UYJF0P14A4@?0?ooo`003@3oool204=3@bT0U9BD102EUID2
09ZJVP80Ti>C302DU9@209>CT`80Vi^K0P2;Rh/209JFUP80UIFE0P2LW9`409BDU080V9RH0P2GUiL2
09FEU@@0UYJF0P2=SHd208n?S`80UiNG0`2FUYH209BDU080VIVI0P2CTi<609BDU080Vi^K0P2EUID2
09RHV080S8b<0P2EUID209bLW080S8b<0P2FUYH609BDU080UYJF0P2<S8`209VIV@80Rh^;0P2EUID2
09fMW@80Rh^;0P2GUiL209bLW080UIFE0P2LW9`209FEU@80V9RH0P2;Rh/309RHV080Ti>C0P2HV9P2
09>CT`80UiNG0P2;Rh/209fMW@80Rh^;0P2GUiL209bLW080UIFE0P2MWId208^;R`80VIVI0P2;Rh/2
09FEU@@0U9BD0P2KVi/:09BDU080UIFE2P2DU9@209FEU@D0UYJF0P2DU9@209VIV@80U9BD0P2FUYH2
09FEU@@0U9BD0P2EUID209JFUP80UIFE0P2FUYH409BDU0@0UYJF0P14A4@?0?ooo`003@3oool204=3
@b40U9BD0P2EUID209JFUP80UIFE0P2FUYH209FEU@80U9BD0P2BTY8209BDU080Ti>C202DU9@209FE
U@80UYJF0P2DU9@209JFUP80UIFE0P2FUYH208^;R`80UiNG0P2:RXX209>CT`80VIVI0P2;Rh/208b<
S080UIFE0P2MWId208f=S@80UYJF1@2DU9@409>CT`@0U9BD0P2FUYH208b<S080SHf=0P2GUiL209RH
V0@0UIFE0P2=SHd209NGU`80UYJF102DU9@209NGU`80VYZJ0P2=SHd209RHV0@0U9BD102FUYH208b<
S080Shn?0P2>SXh208f=S@80UiNG0P2HV9P309FEU@80Ti>C0P2HV9P209FEU@80S8b<0P2GUiL209BD
U080V9RH0P2=SHd208j>SP80Shn?0P2=SHd209VIV@80UYJF0P2HV9P209FEU@80U9BD0P2EUID208b<
S080Shn?0P2FUYH209BDU0@0UIFE0P2JVYX209>CT`P0U9BD0P2FUYH208^;R`<0UIFE0P2DU9@209:B
TP80UYJF0P2<S8`209JFUP@0U9BD0P2FUYH208b<S080V9RH0P2<S8`409JFUP80S8b<0P2FUYH204=3
@`l0oooo000=0?ooo`80@d=38@2DU9@209FEU@80UYJF0P2EUID209JFUP80UIFE0P2DU9@209:BTP80
U9BD0P2CTi<809BDU080UIFE0P2FUYH209BDU080UYJF0P2EUID209JFUP80Rh^;0P2GUiL208Z:RP80
Ti>C0P2IVIT208^;R`80S8b<0P2EUID209fMW@80SHf=0P2FUYH509BDU0@0Ti>C102DU9@209JFUP80
S8b<0P2=SHd209NGU`80V9RH102EUID208f=S@80UiNG0P2FUYH409BDU080UiNG0P2JVYX208f=S@80
V9RH102DU9@409JFUP80S8b<0P2?Shl208j>SP80SHf=0P2GUiL209RHV0<0UIFE0P2CTi<209RHV080
UIFE0P2<S8`209NGU`80U9BD0P2HV9P208f=S@80SXj>0P2?Shl208f=S@80VIVI0P2FUYH209RHV080
UIFE0P2DU9@209FEU@80S8b<0P2?Shl209JFUP80U9BD102EUID209ZJVP80Ti>C202DU9@209JFUP80
Rh^;0`2EUID209BDU080TY:B0P2FUYH208b<S080UYJF102DU9@209JFUP80S8b<0P2HV9P208b<S0@0
UYJF0P2<S8`209JFUP80@d=33`3oool000d0oooo0P13@d<Q09BDU080UYJF0P2=SHd209RHV080S8b<
0P2HV9P209BDU080VIVI0P2BTY8209VIV@80Ti>C1P2DU9@209JFUP80S8b<0P2FUYH609BDU080UIFE
0P2DU9@209^KV`80TY:B0P2IVIT209BDU080W9bL102EUID209RHV080UIFE1@2DU9@209>CT`80VIVI
0P2CTi<209BDU080UIFE0P2FUYH209NGU`80VIVI0P2>SXh209JFUP80UIFE0P2FUYH209FEU@80RXZ:
0P2LW9`209NGU`80Shn?0P2>SXh209RHV080UIFE1P2DU9@209FEU@80UYJF1P2GUiL209VIV@80SXj>
0`2HV9P209BDU080Ti>C0P2DU9@209FEU@80VYZJ0P2CTi<209FEU@80UYJF102GUiL209VIV@80SXj>
0P2JVYX208j>SP80UYJF0P2CTi<209ZJVP80UiNG0P2>SXh209JFUP80U9BD0P2FUYH208^;R`80UIFE
202DU9@209FEU@80UYJF0P2EUID309VIV@80TY:B0P2HV9P209>CT`@0UYJF102EUID209JFUP@0UIFE
0P2FUYH409FEU@80UYJF0P2EUID204=3@`l0oooo000=0?ooo`80@d=38@2DU9@209JFUP80SHf=0P2H
V9P208b<S080V9RH0P2DU9@209VIV@80TY:B0P2IVIT209>CT`H0U9BD0P2FUYH208b<S080UYJF1P2D
U9@209FEU@80U9BD0P2KVi/209:BTP80VIVI0P2DU9@209bLW0@0UIFE0P2HV9P209FEU@D0U9BD0P2C
Ti<209VIV@80Ti>C0P2DU9@209FEU@80UYJF0P2GUiL209VIV@80SXj>0P2FUYH209FEU@80UYJF0P2E
UID208Z:RP80W9bL0P2GUiL208n?S`80SXj>0P2HV9P209FEU@H0U9BD0P2EUID209JFUPH0UiNG0P2I
VIT208j>SP<0V9RH0P2DU9@209>CT`80U9BD0P2EUID209ZJVP80Ti>C0P2EUID209JFUP@0UiNG0P2I
VIT208j>SP80VYZJ0P2>SXh209JFUP80Ti>C0P2JVYX209NGU`80SXj>0P2FUYH209BDU080UYJF0P2;
Rh/209FEU@P0U9BD0P2EUID209JFUP80UIFE0`2IVIT209:BTP80V9RH0P2CTi<409JFUP@0UIFE0P2F
UYH409FEU@80UYJF102EUID209JFUP80UIFE0P13@d<?0?ooo`003@3oool200000240@d=30P15ADD2
03`l?080ATI60P17AdL203/k>`80ADE50P12@T8204=3@`80@T922013@d<204A4A080ADE50P14A4@4
04=3@`80@T920P18B4P40492@P80@d=30P12@T8204=3@`80A4A40P0j>SX204M7A`80>SXj0P15ADD7
04=3@`80@T922013@d<204E5A@80?Cdm0P0n?Sh204E5A@80@d=30P12@T8204U9B@@0A4A40P0l?3`2
03hn?P80AdM70P14A4@@04=3@`80ADE50P0m?Cd20410@0<0?Cdm0P15ADD604=3@`80@T922P13@d<2
04E5A@80?Shn0P0o?cl203hn?P80ADE50P13@d<20492@P80@d=30P15ADD204A4A080@d=30P14A4@2
04E5A@80A4A42013@d<204E5A@80>SXj0P14A4@304M7A`80@D510P17AdL20492@P80ADE50P0j>SX4
04E5A@80>CTi0P1:BTX20492@PX0@d=30P00000?0?ooo`003@3oool200000240@d=30P15ADD203`l
?080ATI60P17AdL203/k>`80ADE50P12@T8204=3@`80@T922013@d<204A4A080ADE50P14A4@404=3
@`80@T920P18B4P40492@P80@d=30P12@T8204=3@`80A4A40P0j>SX204M7A`80>SXj0P15ADD704=3
@`80@T922013@d<204E5A@80?Cdm0P0n?Sh204E5A@80@d=30P12@T8204U9B@@0A4A40P0l?3`203hn
?P80AdM70P14A4@@04=3@`80ADE50P0m?Cd20410@0<0?Cdm0P15ADD604=3@`80@T922P13@d<204E5
A@80?Shn0P0o?cl203hn?P80ADE50P13@d<20492@P80@d=30P15ADD204A4A080@d=30P14A4@204E5
A@80A4A42013@d<204E5A@80>SXj0P14A4@304M7A`80@D510P17AdL20492@P80ADE50P0j>SX404E5
A@80>CTi0P1:BTX20492@PX0@d=30P00000?0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3o
oolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3o
oolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00G03oool2@00006D0oooo
0T00001K0?ooo`00GP3oool00d000000oooo0?ooo`1S0?ooo`03@000003oool0oooo05T0oooo001@
0?ooo`=000000`3oool3@00000<0oooo0d0000050?ooo`03@000003oool0oooo0080oooo00=00000
0?ooo`3oool0103oool00d000000oooo0?ooo`080?ooo`=000000`3oool2@00000<0oooo0d000000
103ooom00000@000040000020?ooo`=000000`3oool2@00000l0oooo0d0000020?ooo`90000000<0
oooo@000040000000P3oool014000000oooo@000040000030?ooo`=000000`3oool2@00000<0oooo
00=000000?ooo`3oool0F@3oool00540oooo00=000000?ooo`3oool00`3oool01D000000oooo0?oo
o`3ooom000000080oooo00=000000?ooo`3oool0203oool00d000000oooo0?ooo`0?0?ooo`03@000
003ooom000000080oooo00I000000?ooo`3ooom000000?oood0000020?ooo`04@000003oool0oooo
@00000<0oooo00=000000?ooo`3oool00P3oool00d000000oooo0?ooo`0>0?ooo`06@000003oool0
oooo@000003ooom00000103oool014000000oooo0?oood0000030?ooo`05@000003oool0oooo0?oo
od0000000`3oool024000000oooo0?oood000000oooo@000003ooom00000FP3oool00540oooo00=0
00000?ooo`3oool00`3oool01D000000oooo0?ooo`3ooom000000080oooo00=000000?ooo`3oool0
203oool00d000000oooo0?ooo`0A0?ooo`04@000003oool0oooo@0000080oooo00=000000?oood00
00000P3oool014000000oooo0?oood0000030?ooo`03@000003oool0oooo0080oooo0d00000>0?oo
o`05@000003oool0oooo@000003oool00d0000020?ooo`04@000003oool0oooo@0000080oooo00=0
00000?ooo`3oool00P3oool01D000000oooo0?ooo`3ooom0000000@0oooo00=000000?oood000000
FP3oool00540oooo0T0000030?ooo`900000103oool3@00000/0oooo00=000000?ooo`3oool03`3o
ool00d000000oooo0?ooo`020?ooo`90000000@0oooo@00004000000oooo0T0000000`3ooom00000
@0000002@00000040?oood0000100000@0000080oooo0d00000?0?ooo`=0000000D0oooo@0000400
001000000?ooo`04@00000<0oooo0T0000020?ooo`9000000P3oool4@00000040?oood0000100000
0?ooo`900000F@3oool00540oooo00A000000?ooo`3ooom000004`3oool00d000000oooo@000000@
0?ooo`03@000003ooom0000002X0oooo00=000000?ooo`3oool04`3oool00d000000oooo0?ooo`1O
0?ooo`00D03oool5@0000080oooo00=000000?ooo`3oool03P3oool3@0000100oooo0d00000Y0?oo
o`9000004@3oool00d000000oooo0?ooo`1S0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-6.47761, -2.56068, 0.491133, 
  0.491133}}]
}, Open  ]],

Cell[TextData[{
  StyleBox["\t",
    FontFamily->"Times New Roman",
    FontSize->10.5],
  StyleBox[
  "According to the classical field theory, when we are given a source \
density distribution, then it is possible to establish a field governing \
equation. A field governing equation having time independent source density \
is one of the Poisson type equations. Obviously, our given image source \
density distribution in Fig. 7 is independent to the time, so that the static \
monochrome image governing equation becomes a Poisson type partial \
differential equation. Further, a solution of this governing equation should \
recover the original monochrome image.\n\tIn order to solve the image \
governing equation, we employ a 9 points finite difference formula assuming \
the zero Dirichlet boundary condition at the image edges. A function \
\[OpenCurlyDoubleQuote]poissonSOR\[CloseCurlyDoubleQuote] gives an iterative \
solution by a simple successive over relaxation method. A parameter \
\[OpenCurlyDoubleQuote]source\[CloseCurlyDoubleQuote] of this function refers \
to the image source density.",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Mathematica",
    FontFamily->"Century",
    FontSize->10.5,
    FontSlant->"Italic"],
  StyleBox[" function poissonSOR",
    FontFamily->"Century",
    FontSize->10.5]
}], "Subsubsection"],

Cell[TextData[{
  StyleBox["Poisson's equation",
    FontWeight->"Bold"],
  ":\n\n ",
  Cell[BoxData[
      \(TraditionalForm\`\[Del]\^2 U = \[Sigma]\)]],
  StyleBox[",\t\t\t\t\t\t\t\t\t\t\t",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  "(5)",
  StyleBox["\n\n",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  StyleBox["where ",
    FontFamily->"Times New Roman"],
  StyleBox["\[Sigma]",
    FontFamily->"\.82l\.82r \.96\.be\.92\[Copyright]"],
  StyleBox[
  " and U are the input field source density and scalar potential to be \
evaluated, respectively.",
    FontFamily->"Times New Roman"]
}], "NumberedEquation"],

Cell["\<\
poissonSOR=Compile[{{source,_Real,2}},
\tModule[{i=0,j=0,omg=1.8,error=1.,solutionI=0.,diff=0.,
\t\tmax=1.*10^-5,dim={0},solution={{0.}},dummy={{0.}}},
\tdim=Dimensions[source];
\tsolution=Table[0.,{dim[[1]]+2},{dim[[2]]+2}];
\tdummy=solution;
\tDo[dummy[[i+1,j+1]]=source[[i,j]],
\t\t{i,dim[[1]]},{j,dim[[2]]}];
\tWhile[error>max,
\t\terror=0.;
\t\tDo[solutionI=0.05*
\t\t\t(solution[[i+1,j+1]]+4.*solution[[i+1,j]]+
\t\t\tsolution[[i+1,j-1]]+4.*solution[[i,j+1]]+
\t\t\t4.*solution[[i,j-1]]+solution[[i-1,j+1]]+
\t\t\t4.*solution[[i-1,j]]+solution[[i-1,j-1]]+
\t\t\t6.*dummy[[i,j]]);
\t\t\tdiff=solutionI-solution[[i,j]];
\t\t\tsolution[[i,j]]=solution[[i,j]]+omg*diff;
\t\t\terror=error+Abs[diff],
\t\t{i,2,dim[[1]]+1},{j,2,dim[[2]]+1}]];
\tTable[solution[[i+1,j+1]],
\t\t{i,dim[[1]]},{j,dim[[2]]}]]]; \
\>", "Input",
  CellLabel->"In[44]:="],

Cell[TextData[{
  StyleBox["\t",
    FontFamily->"Times New Roman",
    FontSize->10.5],
  StyleBox[
  "By means of this solution routine, we can solve an image governing \
equation whose source density has been obtained by the Laplacian operation to \
the monochrome image dada \[OpenCurlyDoubleQuote]monoSample\
\[CloseCurlyDoubleQuote]. This function is useful code to show a practical \
over-relaxation technique using 9 points finite differences, but requires an \
extremely long CPU time. To overcome this difficulty, we employ the MathLink \
utility connecting an externally exploited object file to the ",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"],
  StyleBox["Mathematica",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox[" kernel.",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Mathematica ",
    FontFamily->"Century",
    FontSize->10.5,
    FontSlant->"Italic"],
  StyleBox["function poissonSOR2D",
    FontFamily->"Century",
    FontSize->10.5]
}], "Subsubsection"],

Cell[TextData[{
  StyleBox["\t",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"],
  StyleBox[
  "A function \[OpenCurlyDoubleQuote]poissonSOR2D\[CloseCurlyDoubleQuote] is \
the faster solving routine utilizing the MathLink utility of ",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"],
  StyleBox["Mathematica",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox[
  ". The function \[OpenCurlyDoubleQuote]poissonSOR2D has two parameters. One \
is the source density. Also, the other is a one-dimensional list including \
the desired number of pixels; the first and second integers of this list \
refer to the number of pixels in the directions of x- and y-axes, \
respectively. ",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell["\<\
poissonSOR2D[source2D_,size_]:= 
\tModule[{i,j,relax = 1.8,link,in,out,dim,
\t\tdx,dy,interP}, 
    dim= Dimensions[source2D];
    dx=(1.*(dim[[2]]-1))/(size[[2]]-1); 
    dy=(1.*(dim[[1]]-1))/(size[[1]]-1);
    interP=ListInterpolation[source2D]; 
    in=Table[interP[i,j],
    \t{i,1,dim[[1]],dy},{j,1,dim[[2]],dx}];
    link = Install[\"Sor04.exe\"];Pause[0.01];
    out=Sor[in,relax];
    Uninstall[link];
    out]; \
\>", "Input",
  CellLabel->"In[45]:="],

Cell[TextData[{
  StyleBox["\t",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"],
  StyleBox[
  "Figure 8 shows a recovered monochrome image whose numerical values are \
contained in a list \
\[OpenCurlyDoubleQuote]recoverMono\[CloseCurlyDoubleQuote].  A \
\[OpenCurlyDoubleQuote]Timing\[CloseCurlyDoubleQuote] command of ",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"],
  StyleBox["Mathematica",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox[" gives a CPU time used in the computations.",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell[CellGroupData[{

Cell["\<\
recoverMono=
\tpoissonSOR2D[-source,Dimensions[source]];//Timing\
\>", "Input",
  CellLabel->"In[46]:="],

Cell[BoxData[
    \({27.9400000000000003`\ Second, Null}\)], "Output",
  CellLabel->"Out[46]="]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
ListDensityPlot[recoverMono,PlotRange->All,Mesh->False,
\tFrame->False,PlotLabel->\"Fig.8. Recovered image\"];\
\>", "Input",
  CellLabel->"In[47]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00751202 0.0192308 0.00751202 [
[.5 1.0125 -68 0 ]
[.5 1.0125 68 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -129 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Fig) show
81.000000 12.812500 moveto
(.8) show
93.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(.) show
105.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Recovered) show
165.000000 12.812500 moveto
(image) show
195.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
128 string
128 128 8 [128 0 0 128 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
F0F0F7F7F0F0EEEEF7EEF0D3D3D3D4DAD4D4D4D4D4F0EA90
CBD4CBCBC4CCCCC3CCCDCCCDC4C4CCCCD2D2CDCDCCCCCCCD
C1CDCDCDD6D6D6D6D6D6D6D2D6CDCDD1D6CDCDCDCDCDCCCC
CCCCCDCDCBCDCDCCCDCDCCE3F0E39CC4C4CCCCC4C4C4CBCB
CBCBCBCBD3D2CED2DCD6DCDCDCD4DCD3CCCBC0C0C4C4C3C0
E0DFB5D2E9F2F7F0
F0F2F2EEF0F7F7F0F0F7F0EED4D4D4D4D4D4D4D3D3D3EAAD
CDD3CCCBCBC4C4C4C6CCCDCCCDCCC6CDD3CDCDCCCCC1C6CC
CCC4CCCDCCCDD2D1CDCDD6CDCDD6CDCDCDCDCDD1CDCDCCCC
CDCDCDCDCDCBC4CDCDCCCDCCE3F0B198CCCCCCC4C4C4C4C4
CCCDCDCDD2CDD3CDD3D3D4D4D4DCD4D4CBCCCBCBC4C4CBE8
E9C3C2C4E9F2F0F0
EEEEEEF0F0F0F0F0F0F0F7F7F2D4D3D3D3D1D3D3CED3E4EA
86CBCECCC4BEC4CCCCCCCDCCCDCCC4C1D2D2CDCCC6C6C3C3
BEBEBEC6CCCDCDD2CDCDCDCDCCCDCDD3D6D6D2D1D6CDCDCD
CDCDCDCDCDCCCDCDCDCDCDCDCCD4F0E38FC4C4C4CCCBC4C4
CCC4C4CDD3D2D3D2D3D3D4DADCDAD4D2CECBCDCBCBD2D9D8
E8D8C3C4DFEEF7F0
F0F0F2F7F0F7F7EEF7F7F0F0F0EEEEDCCED3CDCDCDCDCDEA
DAB6CBCCCCC4C4C4C4C4CCCDCDCCC4C4CCCDCDCDC6CCC3BE
C3C3BEBDC4CCCCCDCDCCCDCCCCCCD2DCD6D6D6DCD6D6D2D6
D6CDCDCECECECDCECECDCDCDCDCDD4F0E398CDCDCDCDCDD2
CDCDCECDD2CDD3CED3D4DCDADAD4DACECECCD3CCE9D9D8E8
C3DFCBC3E9E9E9F0
F0F2F0F2F7F2F2F0F7F7F7F7F0F7F0F0DCD3D6CDD2CDD6EA
EAB6CDCED2C4C4C4CCC4C4CCCCCDCCCCCDCCC6C6C6CCCCCC
CCCCC6BEC3C4CCC1C1C1CCCDCDCDCDCDD6CDCDDCDCCED6D1
D6D1CDD3D3CECED3D3D3CDD3CDCDCDD4F0B5B9CDD2D2D2CD
CDCDD2D3D2D3D6D3D3D6DCDADADAD4D4D4CCDAEEE9E8E8EE
D2E4C3C3E9F7F0EE
F0F2EEF2F0F0F2F7EEF2F2EEF7F7F2F7F2E0D3D6D3D3D3D4
EAE8CDD3D3CCCBC4C4CCCBCDCDC4C4CCC4BEC6C6C3CCCCCC
CDCCCDCDC1BEBEC6BECCC4CCCDCDCDCDCDD1D6D6CDD4D3D3
D3D6D3D6D3D4D3CED3CECECECDD2CDCDD4F0C4B9CDD3D3D2
CED2D2D6D6D6D6D3D6D4D4DADADAD4CCC9C3D9E8F0CBD9CB
D4E9C4D9F2F2F2EE
F0F7F7F7EEF7EEF2F2F7EEF7F7F0F7F7F7F7F0DADADCDADC
DCF0DACED4D4D2CCCBC4C4C3C3C4BDB5BDBDBDC3BDCCCDD2
D2D2D2D6CCCCBEC6C3C6BEC3C4C1CCCCCDCDD2CDCDCDCDCD
CECDCDD3D3CECECECDCDCDCDCDCBCDCDCBDAF0E3CBCDCDCD
CCD2D1D6D6D3D6D3DCD4DADADACCCBB6B0C4E9DFEECCD2D3
D2D2C2E9F2F0F7F0
F0F0F2F2F2F7F2F7F0F0EEF0F0F7F2F7F7F7F2F0E4E3E3E3
E0E0F0DA98D4CECDC4C4C4C4C3B5B5BDBDBDBDBDBDC4CCCD
D2D2D2D6CDCDC1BEBDBDBEC4BEBDBDBEC4C4C4CCC4C4C6C4
CCC4CCCBC4CBCCCCC4C4C4C4C4C4C4CCC4C4DAEACCCBCCCD
CDCDCDD3D6D3D3DCDCD4D4D4CBC4A5B1B0CBD9CBB5C4CCC2
D9CCC3E8F2EEF0F0
F0F7F0F7F7F7F0F0F2F2F7F2F0EEF7F2F7F7F0F7F0F7F2F2
F7F7F2F2F0C0CBCDCBC4C4C4BEC3BAC3C3C6CCCCC6BDC6CC
D2D2D2D2D6D2CCC0C6CCC1C6C6C4C4BDBDB5B5B5AFB5B5B5
B5AFB5B5B5B5B5B5B5B5B5C3BEC3C3C3BEBDC3B5D3D3B298
B5C4C4CDCDCDD3D4D4DAD4CC9BA4B5B7B5B5CCCBC4C2C3DF
D2C3DAE8F0F2EEEE
F7F2F7F0F7F7F7F2F2EEF0F0F0F0F7F0EEF7F0F7F2F7F2F0
F7F2F2F0F7F0C3A5D8C4B6C4C4C3BABAB5BDC3C6C6BDC3CC
CCD6D2D6D2CDCDC6C6C6C6CCC6CCCCCCC6CCC6C6C3BEC3BE
BEBEC3BEBEC6C3C6C4C4CCCCBECCCCCCC4CCC4C4C6CED2D3
C45FBEB6C4CBCBCCB28E868695B5C2C4B5C2C3C4D2CBB5DA
D8B5E0DFF0F2F7F0
EEF0F7F0F2EEF0F2F2F7EEF2F7F7F2F2F2F7F2F7F2F7F0F2
F2F0F7F0F2F2C3A4B5B0B6C3C3C3C3C4BABDC3C6C6BDC2CC
CDCCCDD2D2D2D2CCC6C6CCCCCCCCCCCCCCC6C1CCCCCCCCC4
C3C6C6CCCCC6C6C6C4CCCCCCCCCCC6CCC6CCCCCDCCC4CDCC
D2CFDAB29898AC918695868EA4A4C2B5B1E8C2C2C9AED4E0
C3DFCCEEE9EEEEF7
F7F0F0F7F0F7F7EEF0F0F7F2F7F0F7F0F2F2F7F0F7F7F7F7
F0F0EEEEF2EECCCB9BB1B19CC3C4BEC3B6C2C3BDC6C2C2CC
CCCCCDCDD2CCD2CCCCC6C6CCCCCCCCCCCCCCCCC1C6C6CCCC
CCC3C6C4C1C6CCCCC1CCCCCCCCC6C6CCC4CCC3CCCCCCCCC4
C4C4D2D3D3C06C728E868E9B9B9C9BB0BADFA4B4CBAECCD8
C2EEE8EEEEF0F0F7
F0F7F7F0F0F7F0F7F7F7F0F7F7F2F0F7F7F7F7F0F2F7F7F2
F0F0F2F0F0F0D3CCB29BB18572B6C3BEBEC3BEC3C0BDC3CC
CCCCCCCCD2CCCCCCCCCCCCCCCCCCCDCCCCCCCCC6C6C6CCC6
C6CCC3C1C6C6C6C3C4CCCDCCCCC1CCCCC6C6C6CCCCC4C4C4
C3B5ACA58676868583859B959B9CB4B4B5CBAEB4C2B4D8CB
D2E8EEF2E8F7F7F2
F7F2F0F2F0F7F0F7EEF7F0F7F0F7F0F7F7F7F0F2F7F7F0F7
F0EEF0F7F0F0E0E8D8959B857559BEB6C3B5B6BEC3C2C3CC
CCCCCCCCCDCCCCCCCCCCC6C6C6C6CCC6CCCCCCC6C6C6C6C6
C3C3C3C6C6C6C6C3C6C6CCC3C6C6CCCCC6C3C6C6C6BDC3B5
B5A59B7C76869595998E859B9BADB5B4C3B5A4B4B4CBCBCB
D8F2EEF0F0F2F2EE
F0F2F7F2EEF7F7F7F0F7F2F0F7F0F7F7F0F0F2F0F7EEF7F2
F0F7F2F2EEF0D9F0CB9586856F593FAFB5B5C3BEC3BDC2C4
CCCCCCCCC6CCCCCCCCCCCCCCC6CCC6C6C6CCCCCCCCC0C0C6
C6C6C6C1C6C3C0C2C3C1CCC6CCC6C3CCCCC6C6C3BDBDB5B4
A4A486728E958695A5958E95AD9BB1A4B0AEC2C2C2E0B5CC
EEEEF2EAF0EEF7F2
F0F0F0F0F0F7EEF0EEF7F7F7F0F7F0F0F7F0F7F2F0F7F0F0
F7F0F7F2F0EEE0E8CCC0858E75593F3FB5B5BDB5C3C2BDCC
CCCCCCCCCCC6C6CCCCC6C6C6C6C0C3C6CCCCCCC6C6C6C3C0
C2BDC6C6C6C0C3B7C3C2C6C6C6C6C6C6C2B4B4AEA4A4A4A4
8E685986A49B73959CB1ADAD95959BA4B5AEC2C2E8C3CBDA
E9E8E9F0F0F0F7F2
EEF7F2F0F7F0F0F2F7F2F2F7F2F7F2F7F7F2F7F2F0F0F7F2
F0EEF2F0F2EEF0DFDFB18E866C594B3F35B5BEB0C2BDC2C6
CCC6C6C6C6CCC6C6CCC6C6CCC6C6C0C2C6C6C3CCC6C0BDC0
BDBDBDBDC2BDBDB7B7B7C0C6B7C6B4C2BDB7AEAEA49C8E7C
59676C8E9B9B94A4A4ADA4A4AD959BAEAEB4C2C4C3CBD8E8
E9DFE9F2F2F0F7F7
F0EEF7F7F7EEF7F7F7F0F0F7F0F2EEF2F0F0F7F7F7F2F2F7
F0F0F0F2F0E9E8D2E0958E856759594B3519ACB6B5BDBDC4
C3C6C6C6C6CCC6CCC6C6C6C6C3C6C6C0C0C2C0C6C6C3C2C0
BDC0B7B4B7C0B7B7C0B7C2BDB7B4BDB5B5B4AEA5967C726C
6873919C95949BA49B8E8E9B95ADAEAEADC2C4C4CBE8E8E0
E9F2F0F7F7F7F7F7
EEF7F2F7F7F7F0F2F7F7F2F0EEF2F7F7F7F7F2F0F2F2F2F7
F2F2F2F0F0F2E9D8DF9B8E866C59594B2D2D19B5B5C3BEC3
C3C6C6C6C6C6CCCCC6C6C6C6C6C6C6C2C2C6C0C3C0C1BDBD
BDBDB7B7B7B7B4AEB4B7B4C3AEB5B4B4A5AFA48667724973
7C869B95949994ADA4A4A4ADADAEB4B1C2C3C4C4D4DAE0E8
EEF0F7F2F7F2F0F7
F7F7EEF7F2F7F7F7F2F2EEF2F7F0EEF2F2F7F7F0F2F7F0F0
F2F7F2F0F0EEE8DFD39B8E766C68593F2D2235B5B5BDC3C3
C4C3CCC6CCC6C6C6C6C6C0C6C6C2C6C0C3C0BDBDB7BDBDBD
BDB7B7B4AFAEAEAEB4C3B4A5A4A5A7A79696858652676872
6886958E8E94A4A4B1B5A4ADC2B1B4C2C2C4C3D4DADAF0F0
F7F7F2F2F7F0F7F7
F7F2F0F0F2F0F7F0F7F0F0F7F7F2F7F0F7F2F2F2F7F0F0F7
F7F2F7F0F2EEEAD8B19B8E7C677559513535464CB6C2C3CC
C3C3CCC6C6C6C6C6C6C3C6C3BDC1C6C2C0C0C2B7C2B4BDC2
BDB7B7AFAF9CA4B5C3B5969CA49CA49C86856F6C86738686
919B9C949594A4959CA4A4AEA4A4C2C2C2C3D2DAE8E8F2F7
F0EEF7F7F2F2F7F2
F7F7F0F7F0F2F2F7F7F0F7F7F7F7F0F2F7F0F2EEF0F7F0F2
F7F0F2F0EEE8E9CFB18E8E767C7251513F494B2DB5C3C4CC
C3C3C6C0C2C6C0C2C6C6C2C0C2C0C0C6BDBDBDC2B4C0B4B7
B5B4AFA89CA4A4C2C3969CA4A49683786885756C72858676
8E9B9B958E7CB19BB19CC2A4AEC2C2C2C2CBCCE8E9E9F2F7
EEF7F7F7F0F7F7F7
F7F0F7F0F7F7F7F7F7F2F7F7F7F7F2F0F7F7F2F2EEF7F2F7
F0F0F7F7F0E8E8B5B18E7C7368684B5159593F19C3BDC4C3
C6C3C6C0C0C6C0C0C0C0C0C0C2C2C0BDC2BDBDB4B4B4B7B4
B5B5A8A49696B4B5968F8F948F837A5E7385757575767376
8E9B9C91919BA59CA49C9CADADAEC3C3C4DAF0E8E9EEF7F7
F2F7F7F0F2F0F7F7
F7F7F7F0F7F7F2F7F2F7F2F7F7F7F7F2F2F2F2F2F7F7F2F7
F0F7F7F7F0E8D9B1A4918376735149595F513B35C4BECCC4
BDC6C3C3C6C0C1C2C0B7C0C0B7B7B7B7C0B4B7B5B4B7AEAF
AEA5A490969BA49C8E8F8E8E83686F6F7295868575729186
8E919599B1A4A4999C9C9CA4C2C4CCC4DAE0E8EEE8EEF0EE
F7F7F2F7F7F7F7F7
F7F2F7F7F7F2F2F7F7F2F7F7F7F7F2F7F2F2F7F7F2F7F2F2
F2F2F2F0F0E8D8B29C8E7C73725F59725935352DC4BEC3B5
C3C6C6B7B7C0BDB7B7B7B4B7B7B4B4B7AFB7AFAFAFAFAEAE
A4A49C958FA5948378867C83667C75727386958E7C868386
917C9499B1B1B19B9CB19BA4C2C3CBDAE8F0E8EEE8F0F0F7
F7F7F2F0F2F0F2F7
F7F7F7F2F7F7F2F7F7F7F2F7F7F7F7F7F7F7F7F7F2F7F2F2
F7F0F0F7F7E8C4A4A4917C7373516859492D3B2DC3C3C3C3
C3BDC6C2B7C0B7B4B7B4AFB4AFB4AFAFAFB5B4AEA8A5AEA5
A5A49C8E9C9683787C73735F6F6F5968769595959C86867C
7C91998EACB1A599B1B5A4B4C2C2DAE3E8DFE8EEF2F2F2F7
F2F7F7F7F2F2F7F2
F7F7F7F7F2F2F7F2F0F7F7F7F7F2F7F7F7F7F7F2F7F7F2EE
F2EEF7F2F0F0B0A4948E686F5F576857463B4635C4B6C3BD
C3BDB7C2B7B7B7B4AFAFAFA7A8AEA8A8AFAEAEA4A7A4A4A4
A496968E9C8E7C736E6E66736F5F5F687585958E958E917C
7C768EA4A5A4B2B2B19CA4B4C3CCE0DFE8F0EEE8F2F7F2F7
F7F7F7F7F2F7F7F2
F7F2F2F7F2F2F7F7F7F2F0F7F7F2F7F7F2F2F0F0F7F2F2F7
F7F2F7EEF0D8B2A48E83737C5968685F312D353BC3B5BEB5
BDBDB7B7B7AFB4AEA8AEA8A8A79C9C9CA4A4A8A4A49C9C9C
96968F917C7372686E73736868686C75768595ADA4B49472
727C948EA4B1B1B19B9B9BC2CBCCDFE8E0EEE8F7F2F7F7F7
F7F2F7F7F7F0F7F2
F2F7F7F2F2F0F0F0F2F7F7F7F0F7F2F7F2F7F0F7F7F7F7F7
F2F0F2F0F0C4B199917C686F5F72514928283535C3B5BDBE
BDB7B7AFAEAEAEAEA7A5A4A7A4A49C9C9C9CA4A49C9C9C8F
8F8E838E76685F736873734646516F8585858E9BA49CB191
7C8E8E9C8EB2B29C9B9C9BC2CBE8DFE8E8E9F0F7EEF0F7F7
F2F7F7F7F2F7F7F7
F7F7F7F7F2F7F7F7F7F7F7F7F7F0F2F7F0F7F2F7F2F7F2F0
F2F7EEF2DFBAB19183736F5F5F68513F353B3B3FB5B5B5B5
B7B5AFB5AFAFA5A7A79C9C9C909696909C9C909C9C9C8F8E
8F8E7C9573516F6F685F49462D6C856F8576869BADA5B491
919B919C99B19C9C8E95B4CBDAE0E0DFEEF0F0F7F2F2F7F7
F7F0F7F2F7F2F7F7
F7F7F2F7F2F2F0F2F2F7F2F7F7F7F7F7F0F0F2F0F7F7F2F7
F7F0F2EECCB2A183836F6E685F5F3B3B353B3B3BB5B5B5C4
B8B8B3B8B3B3B5AFAFA5968E96888E8E8E8E96968E8E8E83
83787C8E684C687351463F4C596785857C85729BA4B19C99
8E949491B1B19BA49BB1B1C9F0DADFEEE9F7F7F7F7F2F7F7
F7F7F7F7F7F2F7F2
F2F7F7EEEEF7F2F7F7F2F2F7F7F0F7F2F7F0F2F0F7F7F2F2
F0F0F0E8C9B199837C73687C575F22443B3B3555B5CBCDCD
CDCCCCC1C1C1B9B8B8B5AFA588888688888383838E888386
7C7373865152685E49353B6C496886857C727C95A5B4B5B1
99998376B1B1999CB1B1C3EEE8E8E8EEF0F2F7F2F7F7F7F7
F2F7F7F7F7F7F2F0
F7F2F2F7F7F7F2F7F7F7F7F7F7F2F7F7F2F7F7EEF7F2F7F0
F0F2F2D2BAA494837A5F685F68492D46443B3589CDCEDCD1
D1CDCDD1CDCDC1C1BEB8B5AFA89C867C8386868878838683
7C73667C5F687C493F354A754B68768675727C8E95B4B5B1
A4997C91A4A4A4A4C2A4C3EEE0D8EAE9F7F2F7F0F2F0F2F2
F7F7F2F7F7F7F7F7
F2F7F0F7F2F0F7F0F7F7F7F7F2F0F7F2F2F7F2F2F7F2F0F0
F0F2F2D2B099917A7373685F682D3B4C3B3B90CED6DCD6DC
D1DCD1D6D1CDCCCDC1C1B8B7AFAEA49C7C7C7C7C867C837C
6E6F56497C5F8E3F35222D727659769572917C8EA4B4C2C4
B27691919C94A4B2B1AEE9E0D4E8F0F2F7F7F0F7F7F7F7F2
F2F7F7F7F7F2F7F7
F7F2F7F7F7F7F7F0F2F0F7F7F7F0F2F7F2F2F2F2F7F7F7F7
F0E9D8CBA199836F5F68685F4F2D4C4C3BCCD6D2D6DCDCDA
DCDAD1D1D1D6CDCCCCCCC3B5B5B7AFA59C7873737C737873
6E6849468E4996683B4A2249864B7686758E8E8E9BA4C3C4
B19483919999B1B2B1C2DFD9DFEEEEF7F0F7F2F7F7F2F2F7
F2F2F7F7F7F7F7F7
F7F7F7F7F0F7F7F7F7F7F7F7F0F2F0F7F7F2F7F7F7F7F7F2
EEE9CFC09891837366685F5F3B35463B85D3D6CDD6D6DCDC
DCDCDADCD1D1CDCDCDC4BEC3BDB7B5AFA5909C6E6E736F6E
66575044867A837C35224668868E86868E73949199A4B1C3
C2917C918699BAC2B7B2CBE8F0F0F2F7F2F7F2F7F2F2F7F7
F7F7F2F7F7F7F2F7
F0F7F2F7F7F7F0F7F2F2F7F2F2F2F0F7F2F2F0F7F7EEF7F0
EEDFCFB098917C6F565F515F283B445ECDCED6D6D6D6DCD1
DCD1D1DCD1D1CDCCCDCDCCBEBEBDB5B5AFA59C90686E6E61
684F4C2D6FA5519C6673356C52916C858691899983B19BC4
D3917C9194A1A4B1B2C2DFE8E9F0EEF2F7F2F7F7F2F2F7F2
F2F7F2F2F7F2F7F7
F2F7F2F7F7F7F2F2F7F7F7F7F2F2F7F2F7F7F7F7F7F7F2E9
E9D2CFA1947A7C665F5F553B354F5CCECDD2D6D6D6D1D2CD
CDCDCDCDCCC1C1C4CCC3C6BEBEB5B7B5B5AFA49C96685768
52513B3B5691836FA14B835F6E7686728691689191A4A4B0
B5C2917691A199B1C2D9EEDFEEF0EEF7F2F2F7F2F7F7F2F7
F2F7F7F7F2F7F7F7
F7F7F2F7F7F7F2F7F2F2F2F2F7F7F2F7F2F0F0F2F2F7F7E9
D9D2B798837A665F5F5F313B3535CECED6D2CDCDD1CDC6BE
B8B8B5B5B5AFB5B5B5B5BDBDBDBEBDB5B5AFA8A5A496785F
5550443B4A669C917DA4868349728E8586728383A599A4B1
C4CC9199A59994B0C3F0DFF2EEF0EEF7F7F2F7F0F2F7F2F2
F7F7F7F7F7F7F7F2
F7F2F7F7F7F2F7F7F7F7F2F7F7F7F7F7F2F2F2F7F7F2F2E9
D8CFB2997C7C6E525F55353B4FCCD3D3D6D2CDCDCCC4B8B7
AFA8A1A1A1A1A1AFA8AFB5AFBDBDBEB5B5AFACA59C9C8F5E
4A4C3B283B659C7A5FAC869B83687395867C9183A499B1A4
B1CBB1A4A1A1A4B2C4E8E8F0EEF2F7F2F7F7F0F7F7F7F2F7
F7F2F7F7F7F7F7F7
F7F2F7F7F2F7F7F7F7F7F2F7F7F7F7F7F7F2F0F0F7F2EED9
D2D0A1837A686E564F3B3B3F4CCECECDCDCDCDCCC18C8092
92989898989880808080A5B5B5BDBDBDB5B5AFA5A59C908E
4C3B352235567AA58990B19BA499867C8E91727C91A491B4
B2C2C4A1B199A4C2CFD9E9EEE9EEF0F7F0F2F7F2F7F7F7F2
F7F7F2F7F7F2F7F7
F7F2F7F2F7F2F7F7F7F7F2F7F7F2F0F7F7F2F7F7F0F7E9DF
D8B2997D6F685F4C56443B4CD4CECDCDCCD2CDA1989898CE
C1A1A1B3C1989892908780A5B5B5BDBEB5B5B5ACA59C988F
834A2828225628ACB568B283AEB1918E9B6C8E8391999CA5
B2C4CC988999A4B0E8E8EEEEE8F7F7F0F2F2F7F2F7F2F2F7
F7F2F7F7F2F2F7F2
F2F7F2F7F2F7F2F7F2F2F7F2F2F2F2F2F2F0F7F7F0F7DACF
B099897D565F525F2D3B3B85D3D3D3CDCCCCCC929898928C
8C8C988080717777A1878771ADB8BDBDBDBDB5ACA5A59C9C
8E7A3B3B15355E89998391B18EB4D2917C8E8E73839B99A4
A4C4C4A199A198B0E8E9F0E9E9F7F7F7F7F7F7F7F2F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F2F2F7F2F2F2F7F2F2F2F7F7F2F2F7F2F2F2D9C6
A4997A66525F4F3546355FD4D4D3CDCDCCA1987A575D697A
696971655746515D4158514A6198BDBDBDB5B5B5A5A5A4A5
8F835E19153B4A5C91AC5FAC83A5C3D29C9C758E83919483
B1C2C4C0A4B1A1BADFEEE8EEF2EEF7F7F2F7F2F7F7F7F7F7
F7F7F7F2F7F2F7F7
F2F2F2F7F7F2F2F7F2F7F2F7F2F7F2F2F2F2F2F0F2E9D9C0
988366525E514C4C4C4AD4D4CED3D6CDCCC1CCA187807780
778092777777777777A4ACADB5B5BDBDB7B7B5B7AFA5A5A4
9C8F75371515375C75A5996FA483C3C3D37A8E8E83919183
B1B1C4CB99B1A4D8E9E9E8E8F2F2F2F2F7F7F7F7F2F7F7F2
F7F7F2F7F7F2F7F7
F7F2F2F7F2F7F7F7F2F7F2F7F7F7F7F7F0F7F2EEF0E8D0B2
896F6F5E514F444C4955D3CDD3D2CDD2CCD2D6D6DCDACECD
DCCDCCD6DCCECDC4BEC4BEBDBDBEBDBEBDB8B5B5AFAFA5A4
9C9C83552A0A5C4A5C7591688E738EC3C3A49C917C7C919C
A49CC4CBA1A194DFE8E8E9E8F7F7F7F2F7F7F7F7F7F7F2F7
F2F7F7F7F2F7F7F7
F2F7F7F7F7F7F2F7F7F7F2F7F2F2F7F7F2F0F2F2E9C9C3A1
7A66555550354C4C46BAD3D3D3D1D6CDD6CDD6D6DCD6DCD6
DCCCCDCDCDBEBEBEBEC3BEC3CCBEBDC3BEB8B8B5AFAFA598
9C9C8361221E4A558575A1685F9491B5C3CCB18E8E947C83
839CC4CBA4B299E8E9DFE8F0F7F7F7F2F7F7F2F2F2F7F7F7
F7F7F7F7F7F7F7F2
F2F7F2F2F2F2F7F0F7F7F7F7F2F7F2F7F2F2F0F2F2D0A183
686F4F503B4C4C4C4CD3D3CED3D6D1D1D6D3D6D6D6D6D6D6
D3CDCCCCCCBEC3C6BEC4BECCBECCBEBEB8B8BDB5AFA8AFA4
9C9C8F6F443715515666687A68837D9CC2C29CA48E917C91
7CA4B1C4B099A5D9E8E8D8F7F2F7F7F2F7F2F7F7F7F7F2F7
F7F7F2F2F7F7F7F7
F7F2F7F2F2F7F7F7F2F7F7F7F7F7F7F7F7F2F2F0D0C6987C
6F4F5E3B4C354C4F3BD3CECED3D6D6D6D1D6D6D6D6D3D6D6
CCCCBECCBEB7BDC3BEC1C6CCC1C1CDCCBEBEB8B7AFAFA5A4
98908F7C4A22284A656D75896F5E669894ADCCB186946F99
91A5A4C4B091CCD8E9E9E9F2F7F7F7F7F7F7F2F7F7F7F2F7
F2F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F2F7F7F7F7F2F2F2F7F7E9C9A9986F
68664A4C4C4A4C3B89CCCECED6D6D6D6DCD6D3D6D6D6CDCD
BEB5AFB8B5AFB5B8BDBEC6C4CCCDCDC1C1BEB8B5AFAFA5A5
A49C88785E373B3E5C5675667C556856B2C2A4AE94997D83
91A1A4C3BA99DFC4F2E9F7F7F7F7F7F7F2F7F7F7F7F7F7F2
F2F7F7F2F7F7F7F7
F2F7F7F7F7F7F2F7F2F2F7F7F2F7F7F7F0F7F2F2C3987A66
52524C3B3B4C4C35CCCECED1D6D6D6D6D6D6D2D6D6D6CDC1
B9BDA8AFAFA5ACB5B5BDBEC6C1CCCCCCC1CCC0B8B5AFA5A5
A4908F8361370A244A556F567C68684CAC8EA4D299949483
908E99C3C0C0CFD9D9D3F7F7F7F7F7F7F2F7F7F7F7F7F7F7
F7F7F7F2F7F7F7F7
F7F7F7F7F7F7F7F2F7F7F7F2F7F7F7F7F7F7F7E9B2896655
523B4C444C4A3531CECBCDCDD6D1DCDCD6D6D6D1DAA892CD
CDC1B3717190A883A4B5BECCCCCDCDCDCCC1BEB8B7AFAFA5
A49C8F786E441524314A565C6F6F556F5E91B4A4B48E9168
8383A4C2C0E9B0E9BAF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F2F7
F2F2F7F2F2F7F7F7F7F2F2F7F2F7F7F7F7F7F2DF997A6668
4C4C3B464C3B3156CECDD3D6DCD6D1DCD1D6D2D6DCD3CED1
D1CDBDB5B5B7BDAF96A5BECDCDCDCDCDC1CCCCC0B7B5AFA5
9C9C8F88755E0A15243E515E5675555F28B1969BC383916F
7A9199B0C9C9AFBAF7F7F2F7F7F7F7F7F2F7F7F7F7F2F7F7
F7F7F7F2F2F7F7F7
F7F7F7F7F7F7F2F7F7F2F2F7F7F7F7F0F7F7F7D99166613B
4A50444C502D2D7FCBD1D1D1DADCDCDCDAD6D6D1DCCEDADA
DAD1CCBDB9B9B5B5AFAFC1CDCDD1CDCDCDC1C1C1BDB7B5A8
98988F8373660A1E154A5666446F555F319991B1C383917A
838998B2C9C9C0CFF7F7F2F7F7F7F7F7F7F7F2F7F7F7F7F7
F7F7F7F7F2F7F7F7
F7F7F7F2F7F2F7F7F2F7F2F7F7F0F7F2F2F7F2D37A5E5F55
4C4C4F52462837CCCED6D6DCDCDCDADCDADCD1CDDCDCDAE4
DAD1CDC4B8B3B5B5AFB8C1CDCDD2CDD1CDCCCCC1C1B8B7AF
A89C9083735F28001E442868556F46555E7A94AEAEA48391
7A8383B0CBBAD3F2F7F7F7F7F7F7F7F2F2F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F2F2F7F2F2F7F7F2F7F7F7F09966663B44
444C504C1E2D1ECDD1D4D1DCDCDADCDCDCDCDCD6D6D1DADA
DAD6CDB8ADAFB5ADB5BECDCECED3D6CDCDCCCDCCC1B8B7B5
AFA490837A6E4A07153759565E664C554A758E9CB5C47C83
758399C3CBA1CFF7F2F7F2F2F2F7F7F7F2F7F7F7F7F7F7F7
F7F7F2F7F7F7F7F7
F2F2F7F7F7F2F7F7F7F7F7F7F2F7F2F7F7F7F08A664F3B56
50504C15282237CDD6DCDADADADADADADADADCDCD1D4D1DC
D1CEC1BEADB5B5B5BECDCDCDCED1D6CED1CDCCCDC1C1B8B7
ACAF9C8F7A6F520A2A28444A55556855557D919BB5D2837C
6F7D89B0C9CFF2F7F7F7F7F7F7F7F7F7F7F7F7F7F7F2F7F7
F7F7F2F2F7F7F7F7
F7F7F7F7F2F7F7F7F7F7F7F2F7F2F7F2F2F2F28A5F4C4C56
4A4C50281E28B0D3D3DCDADADADAE3E3E3DADCDCDCD6CEDC
DCCDC1B5B5B5BDBEC4CDD3CED1D1DCD4D1CECDCDC1BEBEB5
AFA5A48F786F661E073128565E4C5F685575A1A4B4D27A94
5E897AC2D2CFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F2F7
F2F2F2F7F7F7F7F7F7F7F2F2F2F7F7F2F2F7CB755E445555
504C281E15C1D4D1DCE3DADAE3DADADADADADADADADCD6DC
DCD1CDBEB5BDBDBEC4CECEDADCD1DAD1DCD4D4CECDCBC1BD
B5ACA5A4836F68442D3B4A4A6655685E5275ACA4B1C4917C
557D83B5D8EEF7F7F7F7F7F7F7F7F7F2F7F7F2F2F7F7F2F7
F2F7F7F7F7F7F7F7
F2F7F2F7F7F7F7F7F7F2F7F7F2F7F7F7F7F7755F5531594A
4A50283B37CDCEDADCDADAE3E3DADADCE3DADADADADCD4DC
DCDCD1BEB5BEC3C4C4CBD3DCD4DCDADCD1D4D4D4CECDC4BE
B5B5A5A48878614A3B3B3B565568665E738AA5A4A4B19472
4F7D98B2DFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F2
F7F7F7F2F7F7F7F7
F2F7F7F7F7F7F7F7F7F7F7F7F2F7F7F7F2F77A684A3B5E56
4C443B2886D1D4DADADAE3E3DADCDADCDCDAE3E3DADADCDC
DAD1D1BEB5B5C3C4CDCDD4D4D4DADAD1D1DCD6D3CECDCDC4
B5B5ACA48F78615231313B4A506668665FA4A4A4A4ACB173
737A89B4EEF7F7F7F7F7F7F7F7F7F7F7F7F7F2F7F2F7F7F7
F7F7F7F7F7F7F7F7
F7F7F2F7F2F7F7F7F2F7F7F7F7F7F7F7F7F27575564A4456
50314456CED6D4DADADADADADADADCDAD4DADADADADCDCCE
DADADCC4B8B5BEC4C4CBCED4D4D4DAD4DCD4CECECDCECBC4
C4B5ACA59C836F5644353B3B565F65564FB2A499A5A1B55F
7A7A85B1F0F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F2F7
F7F7F7F7F7F7F7F7
F2F7F7F7F2F7F2F7F2F7F7F7F7F7F7F2F7AE5F65555E5552
3B3744CBDCCEDCDADADADAE3DADADCD4CECED4D4DCDCD1D6
DADADCCDB8B5B5B6C3B6CCD2CEDAD4D4D4CECCCECDCDCDC4
C4B6B5AC988F6F5F4A283B3B4A6F5E5E5EA199A4A46FC249
6F9199B0F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F2F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F2F7F7F2F7F7F7F7F7F7F7F7F2F77F906F4A6F4A52
314A4CCBD1CBDADAE3DADADCDAD4D4C1CBCDCDCED4DCD3D6
DCDADCCDB3B5ADB5B5C4CCCED4CBCBC4CBCBCBCBCDCECBCB
BAC3B5ACA48F7A5F5028223B4A5E685E5EA19C9CA450B461
5E8AACCBF7F7F7F2F7F7F7F7F7F7F7F7F7F7F7F7F2F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F2F7F7F7F2F7F7F7F2F2F2F2F7F751965E6D5C5E4A
2868B7CDB8CEDCDADADADAD4D2CECECDB6B5C4CBCED4CBCE
DADADCC1B5A8B2ADB0BACBCCC4C4BAB9B5B5ADB6B6C4C4C4
C3C3B5AC9C90786F5644152D3B5E5E6F5698A583914FC26F
5299B1D8F7F7F7F7F7F7F7F7F2F7F7F7F7F7F7F7F7F7F7F7
F2F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F2F7F2F7F7F7F7FF6F7F565E566122
5550D19CAFD3DCDADADAD4CCB69890ADAB98B6B6D4D4CECE
DCDCDCCDB5A5A1A5C3B6CCB9B6AA9F8A90A1A1A1ABC3C4B6
B6B6B5ACA1908361564A3B31315655655E8A9183835FC25F
52A1A4D9FFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F2F7F7F7F7F2F7F2F7F7F7F7F7F7F7F7A07D754A564A6131
5FC0C1A1ADD3D4DADACEB98991B6AE656B86A19898CECECB
DCDCDCCCBEA5AC98AC577190ADCB7B577F7F7D7F8AADB5B5
B6B6ADAD9C90786F5E4A56282856565E6F89987C8359C368
75B1B1E9F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F2F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F2F7F7F7F78A9F756531566135
28D1B7B3B5D4DCD4CBB98A90C1D96E6553767FA198B9B5CC
DCDCD3CDBEAF988A90A158CBE9727366885CA0756B8AACAC
B5B5ADA5A48A7A6F554A310A1E565E446F8A896F7D6EB54F
98B2B2F7F7F7F7F7F7F7F7F7F7F7F7F7F2F7F7F7F2F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F2F7F7F7F7F7F7FFF285554C31565656
61D1AFA1B5CCD3CDB698733798B77AB20E7044738A98BED2
DCDCD6CDC3BD98907590986FC553B90E6B53A02A517F9098
ACADAC98998F7A6156501E151E28564A7A757D7D836EB14F
91A5C9F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F796C88B73544A565661
87C1A1A5B5CED3BEAB904A63633E2437566B637F98B8C6D6
D6DCD6CDC6BEAF98907A738D8D372837374A3E57547F898A
9CA5A5988A83615E5E4A3B1E373B3B4A6F7A6F68837AB166
91A4E8F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F2F7F7F7F7F7F7F7
F7F7F7F7F2F7F7F7F2F7F7F7F7F7F77AA09D5E4A65564A52
8FB3A5A5B5CECCCBC4B5987865545454567390ACBECDCDD6
DCDCD6CDCDCCBDAFA5988A627F867D63473E4A759190909C
A5A5989C9178615E5656442837313144758375688391B16F
91ACEEF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F2F7F7E88C6D4A444A4A3B6F
8F9CA198ADCCD3D3DCD4CDCEC4BEB9BEC4BEA5AFB8CCDCD6
DADADCD6D2CDBDA4A898ACADAC9898989CA5ACACB5B7B5AD
ACA59C9091836165563B3B28374A443B6F916F688E98B575
98E0FFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F2F7
F7F7F2F7F7F2F7F7F7F7F7F2F7F7FFFF445E313B3B663157
78989C90ACD3C4D6DCDCDADCDCDAB3907F7578BECCDCDCDC
E3DADCDAD6DCC6B8906E757890C4CBCDCBC4C4BEBEBEB5AC
99899C91837A6F5E55562D282837224A5E7A6F669499C37D
A1E9F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7E9FF3B4C313B4A564A68
71839190A1CDC9C3CEDCDADAD18A7F7378ACCCD6D6DCE3DC
E3DADCDCDCD6D6CCB89161566178AFB9CBCDCDC1C4B5AF98
7D9C908A7A6F6F5E3B3B28312822515C6D7D755F9191B298
A1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F2F7FFAEFF55444A4A31564C5F
61617F8AA1CCD498A1ACA598787AA5D6DCDCE3E3E3E3E3E3
DADADADADCDAD6D6D6D2BEAC90735E756E809090897F7D8A
989898917A6F6F566F1E44443B2824626F7A6F6691A48A73
CFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F2F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F2F7F7A9754A4A62564A4A4A56
5F65757DACCCD3D3CDAC9F98B6DAE3E3E3E3E3E3E3E3E3E4
DADAE3E3E3DCDCDADCD6D1CDCDCDCBCBA17F7A7F7F98A198
9CA49C917A757A563B4A3B3115151E65735E7D6E99A16F91
E9F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F2F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F2F7F7F7F2F7F7F7F7F7C86F594A7D6B59564A5E
5E657A7AA5CDCED3D3DCDCDADADAE3E3E3E3E3E3E3E4E3E3
DAE3E3E3DADADADADADCD3D3D6CDCDCDC4CBCBBEB5B5ADA5
AC9890837A7D7A6F4A3B221515151E90655EA46F83B16FA1
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F2F7F7F7F7F2F7F7F7F7F7F7B74F515C8B6D565C595C
5C5E7D75A5CBD3D3D4DCDCDAE3E3DADCE3E3E3DCE3E3E3E3
DCDAE3DADAE3DADCDCDCDCD1D6CECDCBC4CDBEBEB5ACACA5
A5989991787A7A5E6F4428281E3122987D5E987A6FB26FC0
FFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7D0566B6575656B655C56
55556F7590C3CED3D3D4DCDCDAE3E3DCE3E3E3E3E3E3E3E3
E3E3E3E3E3DADADAD6D6D6D6D6CDCCCBCDC4C3BDB5B5ADAC
A5A49C837A83756F4A313B3115151E997F6FA47C65986FF2
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F2F7F7F7F7F7F7F7F7F2655656566265565C56
5C567D8399BEC4D2D4D6DCDCDADAE3E3E3E3E3DCDCE3E3E3
E3E3DADADADADAD1D6D6D6D2CDCDCDC1C4C3C4BEB5B5AFAC
989C9091837A6F564A37441E15153175A489A5837566B0F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F2F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7FF546B56656B6D655C5C
5665759198B5C4D3D4DCDCDCDCE3E3DCDCE3E3DCE3E3DAE3
E3E3DADADADCDCDCDCD6D6D2CDCDCDC1BEBEBEBEB8B5ADAC
A59C9089897F6F5E3B4A221E1E152473987599918566D3F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7FF7D515E6D6D5C655659
6D65758A99ADC4CDD6D6D6DCDCDCE3E3DADCE3E3DADCE3DC
DADADCDADCDCDCD6DCD6D6CDD6CDCCCCC4C3C4BDB5B5ADAC
989C9089896F6F5E4A3B22150A0A54657D7AA199B299F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7FF567F7D5E65625E5C68
44657F9190ACC3CDD3D6DCDCDCE3E3DAE3E3E3DCE3DCDAE3
DCDADADCDADADCDCDCDCCDD1D2CDCDC1CCBEBEB5B5B5ADAC
98A4908A756D5C4A5631150A240A626D6F669999A1DFF7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F2F7F2F7F7F7F7F7F7F7F7F7F7DF7F59595656555C56
65657D90A1ADC3CDD3DCDCDADCE3E3DCE3DCE3DCDADCE3DC
DADADCDCDCDCDADCDCD1D6D6CDCDCDC1CCBEBEB5B5B5B5AC
A1A58A7F75756F593B31151524156D6D756899A1ADF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FF6559564A55514A59
656F8990A5B2C3CDD6D1DCDADCDCDCDCDAE3E3E3E3DADAE3
DCDCDCDCDCDCDCDCD1D6D6D6CDD6CDCCCCC6BEB5B5ADB5AC
AC988A8A7F655E3B311E1E0A1B157C6D6866A1B7D0F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7B962565655565651
566F7F90A1B6C4CDD6D6DCDADAE3DAE3E3E3E3E3DAE3DCDA
E3DADCDADCDCDCDCD6DCD6D1D2CDCDCCCCBEBEB6B5B5ACAD
9C9C917F7D755E37311E24131E1E7F8A5E7A99C3F7F7F2F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F2F7F7F7F7F7F7F7F7F7F7F7F7F7F7F26B4A4A51515659
516D8998ACB5CCCDCED3D6DCDCDCDCDCE3DCE3DADCDCDADC
DADADCDCDCDADCDCD6D6D2D6D1CDCDCDC4C4C3BDB5B5ADA5
A590917F7565563731241E2828156F896F8EACD1F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F77F6B515C595159
5C6D7599B2C4C4CDD6D6DCDCDCDADAE3E3DADCDCDADADADA
DCDCDADCDCDCDCD6D6D6D2D2CDCCCCCDC4C3BDB8B5B5AFAF
9C908A7A6F5E4A3737281E28150A6D756F91B5EEF7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFB97F6D6D6D59
596D8590A5BECCCDCDD6D3D6DADADADADCDCDAE3DCDADCDC
DCDCD6DCD6D6D6D6DCD1D6CCCCCCCCC1C4C3BDB5BDACACAC
90907F7D6556444A31311E1507378A757C9CB0F7F2F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F2F7F7F7F7F7F7F7F7F7F2F7F7F7F7F7FFFFE9736D5C65
62657A98A1B5CCCDCDD6D6DCDCD6DADADCDCDCDCDCDCDADC
DCDCDCDCD6D6D6DCD6CDCDCDCDCCCDC6BEBEBEBDB5A5AD98
98917A61565C44373724280E077D7F668394D2F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFA0566251
65657D91A5B6C4C1CDCDD6D2D2D6D6DCDCDCD6DCDCDCD6DC
D3D6D4D6D6D6D2CDCDCDCDCCCDCCCCC1BEBEBEB5B5ADA5AC
907F6F665E5C5C313128150A8A7C6F6691BAE9F7F2F2F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFCF3B5C7D
597D7D91A1B5C3CBCDCCCDD6D6DCD6D4DCD6DCDCDCDCDCD6
D6DCD6CDD6CDD6CDCDCCCDCDCCCCC3C6BDBDB6B5B098A59C
8A7F756F5C4A516D1E151B59567D6F7A99C4F2F7F2FFF7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFB7755656
627F7D91A5B5B6C4CDCCCDD1CDDCD2D6D6D6D6D6D6D6DCD1
D1CDCDCDC1CDCCCCCCCCCCCDCCCCBDBDBEB5B5B5AC98988A
7A75665C5C5656374A374A447F758991B2C0F7FFF7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFA9A14455
595E758998A1BABEC4CCC1D1D1D3D3CECDD1D6D6DCCED3CD
CDCCC1BEBEC0CCCCC6C1C6C0BEBEB5B8B5ADADA59898908A
7A7D6F51514A4A3E4431856D756FA599C3F7F7F7F2F7F7FF
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFF7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7DFCB3144
6F56758590ADB5B6BEC1C1CCCDCBCDD3CDCDCDCECDCCCDCD
C6BEB7B8B8BDC0B7B7B7B7AFB5B8ACB5ACACA1A4988A8989
7D755E5C59516B594A6B8A737F91ACC3C0F2F7F7F7FFF7F7
F7F7F7F7F7F7F7F7F7F7F7F2F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7A97D59
5C6D65757F98ADC3B6BABEBECDCDCDCDCBC4C4C4C4BEB6B5
B5B5ACACA5A5A5A4A8A5A4A4989C9C9C9C909098908A836F
65736D576D6D4A656F6F756F9189B5C3F0F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7AE73
5C656D7D8A7F9098B5BAC4CCCBC4C4C4C3B5B5ACB5C3ADAF
ACAD98A1909C91A5879C839083839189898A8A7F9098858B
7D7F6565737F5C3B5683898391B0BAC0F7F7F7F7F7F7F7F2
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFF7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E9
8C7359757D6590A1C0CCCCCCC4C4BAB6ACB0ADADACADACAC
999990908A908A7A8A89756F8A7589757A7F7D7F656D737A
73757375565C6B6F757D7D99BABAA1F7F7F7F7F2F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F2F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F2F7F2F7F7F7F7F7F7F7F7F7F7F7F7F7F7
8C7F7F778BA9AB9FB6ABB6C0C0B6B5ADACAD98A1ACA199A1
9890898A75987F98897F917D6F987D8A7F7D858B626D7D7C
6B737F666F666F667589B1B7B0B2D3F7F7F7F7FFF7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F2F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
FF7386776D8590909FB6BAB5B0ADB2A1A1A1909890989098
8A987D757F66857D90757F7D7F996575758A7D6D6D5C594A
516556565959667C99B1CB9FB289F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7FF967F7FA0A1A9BABABABAA1A1A1A198A198988A8A9889
7D7F668585654A7F5C897D7F7F5E6F7D444A685E5C5E6866
6F666656686FB098B2C0659F85D1FFF7F7F7F7F7F7F7F2F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7AA8662776F85AAB7B6BAA9989890989890858B907F89
8965997D6598655C7F65656D5C5E55445656685659665E56
505E758989A198C3BA857D9F85F7F7F7F7F7F2F7F7F2F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F2F7F7FFF7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7FF577D9F7F8596AFB7ADA97F8A8598988A778A897F90
7F895C7573657D5C65665C625C515656564A445659565555
657D7D7D7DA1B77C7C85A998E9F2F2F7F7F2F7F7F2F7F7FF
F7F7F7F7FFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F77D4A969D9F96BABAAF7D907F7F897D738585737F
737F5C7D6F6D514A7D51595C59554A4A3B37444444556F5C
6585A198C4B79F8B6DA16DE9FFFFF2F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F2F7FF7F44748696B7C0AF7D6D967F9096896D857D65
7F7F65757D736B314A597D56563B56443B313731314A5E85
988A98B796627A89856FAAF7F7F7F7F7F7F2F7FFF7F7F7F7
F7F7F7F7F7F7F7F2F7F7F7F7F7F7F7F7F7FFF7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F2F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7D16659628B9FAFBA856D7D9073737F6B657773
6B6D7F73657D756B654A4A6256565E556F55555F6F7A7F91
A1C9969F7D4A73859696F7F7F7F7F7F7FFF7F2F7F7F7F7F7
FFF7F7F7F7F7F7F7F7FFF7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7C17A716362868DBA656B7C89736D5C595965
656D7365657D857573597D5655736D65666F7D89A19098BA
9F9D8B8B59778B857FFFF7FFFFF7F2FFF2FFF7F2F7FFF7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFF7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7FFF7F7F7F7AE737477858CA1A96B6B85856D85565C5C
6F6D75567F75907F8A966D5E5E757589899191ACACA97F7D
7D5E44567F857C98FFF7F7F7FFFFF7F7FFF7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F2F7F7F2F7F7B963748B969FA9AF73856586737F6D56
544A655977759890C9CCBAA1B6ADADADCBCBB5B78B6B7C6D
5C596589967F7FFFF7F7FFF7F7F7F7F7F7F7F2F7F7FFFFF7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7FFF7F7F084745E8BB7B7B08690868C7F98A9
7D546B547396A99F8CC0C1C0C9D8D3C0A196968674736D51
56737C987F96F7F7F7F2F7F7F2F2F7F7F7F2F7F7F7F7F7F7
F2F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7FFF7F7F7FF7D63838CAFCBAFAFC1AECFC1AA
D3DAF0E8DAD3D2C0CFC9C9C9D2B78BA98B7C7D7D656B577F
8B85857FFFF7F7FFF2F7F7F7F7F2F7F7F7F7F2F7F7FFF7F7
F2F7F7F2F7FFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFF7F7F7
F7F7F7F7F7F7FFF7F7F7F7F7DF637296A7C1CFD9D0CFCFCF
D9C9CCD2CCDAE0D9CFD3B7A0C09F9DA0717D656B7D869FA1
9085AAF7F7F2F7F2F7F7F7F7F7F7F7F2F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFF7F7FFF7F2F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7FFF7FFFFF7FFF7F7FFE986838DB7B7C1C6CFD9D9
D9D9E8DFDAD9E0D3CFC1C59D8DA07C7D738B638C9FA19D8C
A1DFF7F7F7F2F7F7F7FFF7FFF7F7F2F7F7F7F7F7F7F7F7F7
FFF7F7F7F7F7F7F7FFF7F7F7F7FFF7F7F7F7FFF7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F2F7FFF7F7987D86B9CBD9D9D8
D3CBDAD0CBC1AF9F96A9AF9D8C687F9D8CAFAFB7AF8DAFF2
F7F7F7F7F7F7FFF7F7F7F7F2F7F7FFF7FFF7F7F7F2F7FFF7
F7F7F7F7FFF7F7F7F7F7F7F7F7F7F7F7FFFFFFF2F7F7F7F7
F7F7FFF7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFF7F7F7F7
F7F7F7F7F7F7F7F7F7F2FFF7F7FFF7F7F7F7F7A098B7B9C1
DADAD9DADAD9C1C1AAA798B7CFA0C1CBC1A096C0E9FFFFFF
F7F7F7FFF7F7F7F7F7FFF7F7F7F7F7F7F2F7F7F7F7F7F7F7
FFF7FFFFFFFFFFF7F7F7F7F7FFF7F7F7FFFFF7FFF7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F2F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFF7FFF7F7AEA7C1
AAC0D0D0DFDAE8F0E8D9CFD9D0CFAA9FB7CFE9F7F7FFFFF2
F7F7F7F7F7F7F7F2F7F7F2F7F7F7F2F7F7F7F7F7F7F7F2F7
F7F7F7F7F7F7F2F7FFF2F7F7F7F7F7F2F7F7F7F7F2F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFF7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F2F7F7FFF2F2F7F7F7F2F2
F2E9E9DFF0E8CFC1C1CFD0CBCBD1E9F2F7F7F7F7F7FFFFF7
FFFFFFF7F7F7F7F7F2F2F7F7F7F7F7F7F2F7FFF2F7F7F7FF
F7F7F7F7F7F7F7F7F7FFF7FFF7F7F7F7F7F7F7F7FFF7F7F7
F7F7F7F7FFF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F2F7F7F7
F7F7F7F7F7F7F7F7FFF2F7F7F7F7F2F7F7F7F7F7F7F7F7F7
FFF7F7F7F7F7F2F2F2F2FFF7F7F7F7F7F7FFFFF7F7F7FFF7
F7F7F7F2F7FFF7F7FFF7F7F7FFF7FFF7FFF7F2F7F7F2F7F7
F7F7F7F7F7F7F7F7F7F2F7F7FFF7F7F7F7FFF7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F2F7F7F2FFF7F7F7F2F7F2
F7F7FFF2F7F7F7F7F7F7FFF7F7F2F7F7F7F7F7F7FFF7FFF7
F7F7F2FFF7FFFFF7F7F7F7F7F7F7F7F7FFF2F2F7F2F7F7F7
F7F7F7F7F7FFF7F7F7F7F7F7FFF7F7F7F2F7FFFFF7F7F7F7
F7F7F7F7FFF7F2F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFF7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFF7F7F7F2F7F7FF
F7F7F7FFF7F7FFF7F7F7F2F7F7F7F7F7F7F2F7FFF7F7FFFF
F7F7F7F2F7F7F2F7FFF7F7F7F7FFF7F7F7F7F7F7F7F7F7FF
F2F7F7F7F7FFF7F7FFF7F7F2F7F7F7F7F7F7F2FFF7F7F7F7
F7F7F7F7F7F7FFF7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFF7F7F2F7F7F2
F7F7F7F7F7F7F7F7F7F7F7F2FFF7F7F7F2F7F7F7F7F2FFF2
F7F7F7FFF7F7F7FFF7F2F7F7F2F7F7F7F7F7F7F7F7F7F7FF
F7F7F2F7FFF7F7F7F2FFFFF7F7F2FFF7F7F7F7FFF7F7F7FF
F7F7F7FFF7F7FFF7F7FFFFF7F7FFF7F7F7F2F7F7F7F7F7F7
F7F7FFF7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFF7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F2F7F7
F7FFF2F7FFF7F7F7F7FFF7FFF7F7F7F7F7F7F2F7FFF7F7F7
F7F7F7F7F7F7F7F7F7F7F2F7F7F7F7F7F7F2FFF2FFF7F7FF
F7F7F2F7F7F7F7F7F7F7F7F7F7F7F7F2F7F7F7F7F7F7F7F7
F7F2FFF7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFF7F7F7
F7F7F7F7F7F7F7F7F7F7F2F7F7F7F7F7F7F7F7F7F7F2F2F7
F7F7F7F2FFFFF7F7FFF2F7F7F7F7F7FFF7F2F2F7F7FFF2F7
FFF7FFF7F7FFF7FFF7F7F7F7F7FFF7F7F7F7F7F2F7FFF7F7
F7FFF7F7F7FFF7FFF7F7FFF2F7F7F7F7F7FFF7F7FFF7F7F7
F7F7F7F7F7F7F2F2
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFF7
F7F7F7F7F7F7F7F7F7F7F7FFF7F7F2F7F2F7F7F7F7F7F7FF
F7F7F7F7F7F7F7F2FFF7F7F7F7F7F7F7F7F7F7F7F2F7FFF7
FFF7F7F7F2FFF2FFF7F7F7F2F7F7F7F7F7F7F7F7FFF2F2F7
F7F7F2F7F7F7F7FFF7F7F7F7F7F7F7FFF7F7F7F7F7F7F7F7
F7F7F7F7F2F7FFF7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F2
F7F7F7F7F7F7F7F7F2FFF7F7F2F7F7F2F2F7F7F7FFFFF7F7
F7F2F7F7F7F7F2F7F7FFF7F2FFF7F7F7F7F7FFF7FFF7F2FF
F7F2F7F2F7F7FFF7F7F2F7F7FFF2FFF7F2F7F2FFF7FFF7F7
F7F2F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F2F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7FFF7FFF7F2FFFFF7F2FFF7F7
F7F7F7F7F7F7FFFFF7F7F7F7FFF7F7F7F7F7F7FFF7F7F7F7
F7FFFFFFFFF7F7F7F7F2F7FFF7F7F7FFFFFFFFF7F7F7F7F7
F7FFFFF7F7F7F7F2F7F7F7F7F7F7FFF7F7F7F7FFF7F7F7F7
FFF7FFF7F7FFF7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFF7FFF7F7F2
F7F2F7F7F7F7F7FFF7F7F7F7F7F7F2F7F2F7F2F7F7F7F7F7
F7F7F2F7F7F7F7F7F7FFF7F7F7F7FFF2F7FFFFF7F7F7F7F7
F7F7F7F7F7F7FFF7F7F7F7F7F2F7F7F7F7F7F7FFF7FFF7F7
F2F7FFF7F7F7FFF7F7F7F7F7F7F7F7F2F7F2F7F7F7F7F7F7
F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFF7F7FFF7F7
F7F7F7F7F7F7F7F7F7F7F7F7F2F7F7F7F7F7F7FFF7FFF7F7
F7F7F7F7F7F7F7F7FFFFF7F7F7F2F7F7FFFFF7F7F7F7F7F7
F7F7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7FFF7F2F7F2F7F7FFF7F7FF
F2F7F7F7F7F7F7F7
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[47]:=",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`003@3oool40?3`l0@0moOg103`l?040>k^kP80moOg0P3^k^h20?3`l0H0
dm?C0P3De=@30=[JfPX0e=CD0P3`l?020>[ZjP80T92@0P3;bl/20=CDe0@0bl_;0P34a<@40<c<c080
`l?30P3<c<`20<g=c@80c<c<0P3=cLd40<C4a0@0c<c<103Bd]840<g=c@H0c<c<0`3=cLd20<71`@H0
cLg=3P3Fe]H20=;BdP80e]KF103=cLd20=7Ad@80e]KF2P3=cLd80<c<c0@0cLg=0P3;bl/40<g=c@<0
c<c<103=cLd20<c<c080hn?S0P3`l?020>?Sh`80W9bL1034a<@40<c<c0H0a<C4303;bl/20=?Cd`80
d];B0P3>c/h20=;BdP80g=cL0P3Fe]H60=cLg080e=CD0P3Lg=`30=?Cd`80c<c<0P3;bl/40<30`0@0
a<C40P33`l<20<30`080h>3P0P3Ogml20;Fe]@80d];B0P3YjNT20?;blP80moOg0P3`l?0?0?ooo`00
3@3oool40?3`l0@0moOg103`l?040>k^kP80moOg0P3^k^h20?3`l0H0dm?C0P3De=@30=[JfPX0e=CD
0P3`l?020>[ZjP80T92@0P3;bl/20=CDe0@0bl_;0P34a<@40<c<c080`l?30P3<c<`20<g=c@80c<c<
0P3=cLd40<C4a0@0c<c<103Bd]840<g=c@H0c<c<0`3=cLd20<71`@H0cLg=3P3Fe]H20=;BdP80e]KF
103=cLd20=7Ad@80e]KF2P3=cLd80<c<c0@0cLg=0P3;bl/40<g=c@<0c<c<103=cLd20<c<c080hn?S
0P3`l?020>?Sh`80W9bL1034a<@40<c<c0H0a<C4303;bl/20=?Cd`80d];B0P3>c/h20=;BdP80g=cL
0P3Fe]H60=cLg080e=CD0P3Lg=`30=?Cd`80c<c<0P3;bl/40<30`0@0a<C40P33`l<20<30`080h>3P
0P3Ogml20;Fe]@80d];B0P3YjNT20?;blP80moOg0P3`l?0?0?ooo`003@3oool20?3`l0@0l_;b0P3^
k^h20?3`l0@0moOg103`l?020?Ogm`80l?3`0P3^k^h?0=CDe0H0dm?C0P3Zj^X20:f][@80cLg=0P3C
dm<20<c<c0@0bl_;1P34a<@20<K6aP80c<c<0P3=cLd20<c<c080cLg=0P3<c<`20<K6aP80cLg=0P3C
dm<40<g=c@@0c<c<0P31`L420<K6aPD0c<c<0P34a<@20<c<c080cLg=0P3<c<`20<g=c@80d];B0P3A
dM440<g=c@80e]KF103=cLd20=KFePX0cLg=0P3AdM440<g=c@@0c<c<2P3=cLd20<_;b`80a<C41@3=
cLd20<c<c080cLg=0P3<c<`20>?Sh`80l?3`0P2a/K4209RHV0H0c<c<2P34a<@20<c<c0H0cLg=0P3B
d]820<g=c@80dm?C0P3=cLd40=?Cd`H0e=CD0P3Lg=`50=CDe080bl_;0P3<c<`40<_;b`@0a<C40P3;
bl/20>SXj080jNWY0P33`l<20<;2`P80a<C40P3YjNT20?;blP@0l?3`3`3oool000d0oooo0P3`l?04
0?;blP80k^k^0P3`l?040?Ogm`@0l?3`0P3gmoL20?3`l080k^k^3`3De=@60=?Cd`80j^[Z0P2][Jd2
0<g=c@80dm?C0P3<c<`40<_;b`H0a<C40P36a/H20<c<c080cLg=0P3<c<`20<g=c@80c<c<0P36a/H2
0<g=c@80dm?C103=cLd40<c<c080`L710P36a/H50<c<c080a<C40P3<c<`20<g=c@80c<c<0P3=cLd2
0=;BdP80dM7A103=cLd20=KFeP@0cLg=0P3Fe]H:0<g=c@80dM7A103=cLd40<c<c0X0cLg=0P3;bl/2
0<C4a0D0cLg=0P3<c<`20<g=c@80c<c<0P3Shn<20?3`l080/K6a0P2HV9P60<c<c0X0a<C40P3<c<`6
0<g=c@80d];B0P3=cLd20=?Cd`80cLg=103Cdm<60=CDe080g=cL1@3De=@20<_;b`80c<c<103;bl/4
0<C4a080bl_;0P3Xj>P20>WYj@80`l?30P32`/820<C4a080jNWY0P3bl_840?3`l0l0oooo000=0?oo
o`H0k^k^3P3`l?040?Ogm`80l_;b0P3De=@70=?Cd`80dM7A103Cdm<20<k>cP80dm?C0P3Ti>@20>[Z
jP80QXJ60P3;bl/20<k>cP80c<c<0P34a<@20;jn_P80a<C41P3<c<`20<g=c@80c<c<0P3=cLd20<c<
c080a<C40P31`L440=;BdP80cLg=0P3<c<`40<K6aPD0`l?31P2n_[h20<K6aP80c<c<103=cLd20=;B
dPP0cLg=0P3<c<`40<g=c@80dm?C103Fe]H20=;BdP80dM7A0P3Fe]H@0<g=c@80c<c<3@3=cLd20<c<
c080e=CD0P3`l?020>?Sh`80Shn?1P34a<@20<c<c080bl_;1034a<@20<c<c0@0a<C40P3=cLd20=?C
d`80d];B0P3Cdm<20=;BdP@0dm?C0P3De=@20=[JfP80g=cL0P3Jf]X20=CDe0<0d];B0P3>c/h20<_;
b`80cLg=103;bl/20=;BdP80fMWI0P3Hf=P20>SXj080f=SH0P33`l<20<C4a080gmoO0P3^k^h20?Og
m`80l?3`3`3oool000d0oooo1P3^k^h>0?3`l0@0moOg0P3bl_820=CDe0L0dm?C0P3AdM440=?Cd`80
c/k>0P3Cdm<20>CTi080j^[Z0P26QXH20<_;b`80c/k>0P3<c<`20<C4a080_[jn0P34a<@60<c<c080
cLg=0P3<c<`20<g=c@80c<c<0P34a<@20<71`@@0d];B0P3=cLd20<c<c0@0a/K61@33`l<60;jn_P80
a/K60P3<c<`40<g=c@80d];B203=cLd20<c<c0@0cLg=0P3Cdm<40=KFeP80d];B0P3AdM420=KFeQ00
cLg=0P3<c<`=0<g=c@80c<c<0P3De=@20?3`l080hn?S0P2?Shl60<C4a080c<c<0P3;bl/40<C4a080
c<c<1034a<@20<g=c@80dm?C0P3Bd]820=?Cd`80d];B103Cdm<20=CDe080f][J0P3Lg=`20=[JfP80
e=CD0`3Bd]820<k>cP80bl_;0P3=cLd40<_;b`80d];B0P3IfMT20=SHf080j>SX0P3Hf=P20<?3``80
a<C40P3Ogml20>k^kP80moOg0P3`l?0?0?ooo`003@3oool40?3`l080l_;b0P3gmoL20?3`l0@0moOg
0P3^k^h40?Ogm`H0l?3`103^k^h30=cLg080c/k>0P3Cdm<:0<g=c@80j^[Z0P3Jf]X20;Jf]P80bl_;
103<c<`:0<C4a080c<c<103=cLd20<c<c0@0a<C40P3<c<`60<g=c@80a/K60P3<c<`20<?3``<0_[jn
1033`l<20;jn_P80_Kfm0P34a<@40<c<c0@0cLg=0P3<c<`20<g=c@H0c<c<0P3Bd]820=cLg0H0e]KF
0P3Lg=`40=KFeP80d];B103Fe]H40<g=c@H0c/k>0P3=cLd50<k>cPX0cLg=0P3De=@20?3`l080hn?S
0P2HV9P:0<g=c@80d];B103=cLd20<k>cP80cLg=0P3Bd]820<g=c@80dm?C0P3>c/h20=?Cd`80e=CD
0P3Lg=`40=[JfP80e=CD0P3Jf]X50<k>cP80c<c<0P3Cdm<20<c<c080jNWY0P3IfMT20=SHf080j>SX
0P33`l<20=oOg`80bl_;0P33`l<60>WYj@80l?3`3`3oool000d0oooo103`l?020?;blP80moOg0P3`
l?040?Ogm`80k^k^103gmoL60?3`l0@0k^k^0`3Lg=`20<k>cP80dm?C2P3=cLd20>[ZjP80f][J0P2f
][H20<_;b`@0c<c<2P34a<@20<c<c0@0cLg=0P3<c<`40<C4a080c<c<1P3=cLd20<K6aP80c<c<0P33
`l<30;jn_P@0`l?30P2n_[h20;fm_@80a<C4103<c<`40<g=c@80c<c<0P3=cLd60<c<c080d];B0P3L
g=`60=KFeP80g=cL103Fe]H20=;BdP@0e]KF103=cLd60<k>cP80cLg=1@3>c/h:0<g=c@80e=CD0P3`
l?020>?Sh`80V9RH2P3=cLd20=;BdP@0cLg=0P3>c/h20<g=c@80d];B0P3=cLd20=?Cd`80c/k>0P3C
dm<20=CDe080g=cL103Jf]X20=CDe080f][J1@3>c/h20<c<c080dm?C0P3<c<`20>WYj@80fMWI0P3H
f=P20>SXj080`l?30P3Ogml20<_;b`80`l?31P3YjNT20?3`l0l0oooo000=0?ooo`80l?3`0P3bl_82
0?3`l080l_;b0P3gmoL40?;blP80l?3`203gmoL20?3`l080moOg1@3`l?020=cLg080dm?C0P3Fe]H2
0<g=c@80d];B0P3=cLd20=KFeP@0j^[Z0P2f][H20<g=c@80c/k>0P3Bd]860<C4a080c<c<1034a<@4
0<c<c080cLg=103<c<`20<g=c@80c<c<1P36a/H;0<c<c080a/K60P2n_[h20<?3``80a<C40P3<c<`6
0<71`@80c<c<2P3=cLd20=KFeP@0cLg=103Lg=`20<k>cP80e]KF0P3AdM420=KFeP80dM7A0P3=cLd4
0=?Cd`@0c/k>1`3Cdm<20<g=c@80dm?C1P3=cLd20=CDe080l?3`0P2e]KD20;Vi^@80cLg=1P3Bd]86
0<g=c@80d];B0P3Cdm<20=;BdP80dm?C0P3Fe]H40=?Cd`80e]KF0P3Lg=`60=[JfPL0e=CD0P3<c<`2
0=[JfP80k^k^0P3YjNT40>SXj080k^k^0P3Bd]820>CTi0@0`l?30P3YjNT20?Ogm`80l?3`0P3^k^h?
0?ooo`003@3oool20?3`l080l_;b0P3`l?020?;blP80moOg103bl_820?3`l0P0moOg0P3`l?020?Og
m`D0l?3`0P3Lg=`20=?Cd`80e]KF0P3=cLd20=;BdP80cLg=0P3Fe]H40>[ZjP80][Jf0P3=cLd20<k>
cP80d];B1P34a<@20<c<c0@0a<C4103<c<`20<g=c@@0c<c<0P3=cLd20<c<c0H0a/K62`3<c<`20<K6
aP80_[jn0P33`l<20<C4a080c<c<1P31`L420<c<c0X0cLg=0P3Fe]H40<g=c@@0g=cL0P3>c/h20=KF
eP80dM7A0P3Fe]H20=7Ad@80cLg=103Cdm<40<k>cPL0dm?C0P3=cLd20=?Cd`H0cLg=0P3De=@20?3`
l080]KFe0P2i^KT20<g=c@H0d];B1P3=cLd20=;BdP80dm?C0P3Bd]820=?Cd`80e]KF103Cdm<20=KF
eP80g=cL1P3Jf]X70=CDe080c<c<0P3Jf]X20>k^kP80jNWY103Xj>P20>k^kP80d];B0P3Ti>@40<?3
``80jNWY0P3gmoL20?3`l080k^k^3`3oool000d0oooo0P3`l?020?;blP80k^k^0P3bl_840?3`l080
l_;b0P3gmoL20>k^kP@0l_;b0P3^k^h40?Ogm`80l_;b0`3gmoL20?;blP80h>3P0P3Cdm<20=KFePH0
dm?C0P3De=@20>[ZjP80j>SX0P3=cLd40=?Cd`80c<c<0P3;bl/40<C4a080c<c<0P3;bl/40<g=c@@0
a<C40P3<c<`20<C4a080_[jn1036a/H20<?3``L0c<c<0P3=cLd20<c<c0@0cLg=0P31`L440;jn_P80
a/K60P2n_[h20<c<c080a<C40P3<c<`:0<g=c@80dM7A103Fe]H20<g=c@80e=CD1P3Cdm<20=KFeP80
dm?C0P3Fe]H20=?Cd`80e=CD0P3Cdm<30<k>cP80dm?C1P3>c/h20<g=c@80d];B103=cLd20=CDe080
l?3`0P34a<@20;Vi^@80cLg=103Cdm<20=;BdP80c/k>103Bd]880=KFeP80dm?C0P3Fe]H40=CDe0H0
f][J0P3De=@30<c<c080bLW90P33`l<20=WIf@80j>SX0P3`l?020<_;b`80fMWI0P3;bl/20=CDe080
jNWY0P34a<@20=WIf@H0l_;b0P3^k^h?0?ooo`003@3oool20?3`l080l_;b0P3^k^h20?;blP@0l?3`
0P3bl_820?Ogm`80k^k^103bl_820>k^kP@0moOg0P3bl_830?Ogm`80l_;b0P3Ph>020=?Cd`80e]KF
1P3Cdm<20=CDe080j^[Z0P3Xj>P20<g=c@@0dm?C0P3<c<`20<_;b`@0a<C40P3<c<`20<_;b`@0cLg=
1034a<@20<c<c080a<C40P2n_[h40<K6aP80`l?31`3<c<`20<g=c@80c<c<103=cLd20<71`@@0_[jn
0P36a/H20;jn_P80c<c<0P34a<@20<c<c0X0cLg=0P3AdM440=KFeP80cLg=0P3De=@60=?Cd`80e]KF
0P3Cdm<20=KFeP80dm?C0P3De=@20=?Cd`<0c/k>0P3Cdm<60<k>cP80cLg=0P3Bd]840<g=c@80e=CD
0P3`l?020<C4a080^KVi0P3=cLd40=?Cd`80d];B0P3>c/h40=;BdPP0e]KF0P3Cdm<20=KFeP@0e=CD
1P3Jf]X20=CDe0<0c<c<0P39bLT20<?3``80fMWI0P3Xj>P20?3`l080bl_;0P3IfMT20<_;b`80e=CD
0P3YjNT20<C4a080fMWI1P3bl_820>k^kPl0oooo000=0?ooo`80l?3`1P3gmoL20>k^kP80moOg0P3^
k^h40?;blP80moOg0P3^k^h40?Ogm`80l?3`2@3gmoL20?3`l0@0f][J0P3Lg=`20=[JfP@0g=cL0P3`
l?020=[JfP80c/k>103De=@20=;BdP80c<c<0P3;bl/40<C4a0@0`l?30P34a<@20;fm_@80]KFe1P2m
_Kd20<?3``80_Kfm0P3<c<`20<g=c@T0d];B0P3Fe]H40<c<c080_[jn0P36a/H20<?3``80a/K60P2n
_[h20<?3``80a<C40P31`L440<c<c0@0cLg=0P3Bd]8:0<g=c@80c/k>103=cLd40=?Cd`L0c/k>2P3=
cLd20<_;b`@0cLg=0P3;bl/20=[JfP80l?3`0P3Shn<20<_;b`H0cLg=0P3<c<`20=;BdP80dM7A103F
e]H20=?Cd`80e]KF0P3Cdm<20=cLg080e=CD1P3Jf]X20<c<c080bl_;0`2f][H20;2`/080a<C40P3Y
jNT20=oOg`80k^k^0P3<c<`20=;BdP80dm?C103Bd]820<;2`P80jNWY0P3bl_820?3`l080moOg0P3`
l?0?0?ooo`003@3oool20?3`l0H0moOg0P3^k^h20?Ogm`80k^k^103bl_820?Ogm`80k^k^103gmoL2
0?3`l0T0moOg0P3`l?040=[JfP80g=cL0P3Jf]X40=cLg080l?3`0P3Jf]X20<k>cP@0e=CD0P3Bd]82
0<c<c080bl_;1034a<@40<?3``80a<C40P2m_Kd20;Fe]@H0_Kfm0P33`l<20;fm_@80c<c<0P3=cLd9
0=;BdP80e]KF103<c<`20;jn_P80a/K60P33`l<20<K6aP80_[jn0P33`l<20<C4a080`L71103<c<`4
0<g=c@80d];B2P3=cLd20<k>cP@0cLg=103Cdm<70<k>cPX0cLg=0P3;bl/40<g=c@80bl_;0P3Jf]X2
0?3`l080hn?S0P3;bl/60<g=c@80c<c<0P3Bd]820=7Ad@@0e]KF0P3Cdm<20=KFeP80dm?C0P3Lg=`2
0=CDe0H0f][J0P3<c<`20<_;b`<0][Jf0P2`/;020<C4a080jNWY0P3Ogml20>k^kP80c<c<0P3Bd]82
0=?Cd`@0d];B0P32`/820>WYj@80l_;b0P3`l?020?Ogm`80l?3`3`3oool000d0oooo103`l?060?;b
lP80moOg0P3bl_820?Ogm`@0l?3`0P3^k^h40?3`l080moOg0P3bl_870?Ogm`80l_;b0P3`l?020>CT
i0H0hn?S103Ph>020?3`l080f][J0P2HV9P20=CDe080c/k>0P3=cLd80<C4a080`l?3102e]KD<0;fm
_@80a<C40P3<c<`30<g=c@H0d];B0P3Fe]H40<g=c@80`L710P2n_[h40;fm_@80_[jn0P34a<@20;jn
_P@0_Kfm0P2n_[h60<C4a080c<c<1034a<@20<K6aP80a<C40P3<c<`20<C4a080c<c<0P3;bl/20<C4
a080bl_;1@3<c<`>0<C4a080c<c<1034a<@20=[JfP80j^[Z0P3<c<`20<_;b`80c<c<203=cLd20=?C
d`80e]KF103Cdm<40=cLg0H0e=CD0P3;bl/20<C4a080YJFU0`2a/K420;2`/080bl_;0P3IfMT20<_;
b`80]KFe0P34a<@20<c<c080`/;20P3IfMT20<c<c080`l?30P3Xj>P20?;blP80k^k^103`l?0?0?oo
o`003@3oool40?3`l0H0l_;b0P3gmoL20?;blP80moOg103`l?020>k^kP@0l?3`0P3gmoL20?;blPL0
moOg0P3bl_820?3`l080i>CT1P3Shn<40>3Ph080l?3`0P3Jf]X209RHV080e=CD0P3>c/h20<g=c@P0
a<C40P33`l<40;Fe]@`0_Kfm0P34a<@20<c<c0<0cLg=1P3Bd]820=KFeP@0cLg=0P31`L420;jn_P@0
_Kfm0P2n_[h20<C4a080_[jn102m_Kd20;jn_PH0a<C40P3<c<`40<C4a080a/K60P34a<@20<c<c080
a<C40P3<c<`20<_;b`80a<C40P3;bl/50<c<c0h0a<C40P3<c<`40<C4a080f][J0P3Zj^X20<c<c080
bl_;0P3<c<`80<g=c@80dm?C0P3Fe]H40=?Cd`@0g=cL1P3De=@20<_;b`80a<C40P2UYJD30;6a/@80
/;2`0P3;bl/20=WIf@80bl_;0P2e]KD20<C4a080c<c<0P32`/820=WIf@80c<c<0P33`l<20>SXj080
l_;b0P3^k^h40?3`l0l0oooo000=0?ooo`80l?3`0P3gmoL20?3`l0H0moOg103`l?040?;blP80moOg
0P3bl_820?3`l080k^k^0P3gmoL30?;blP@0moOg0P3`l?020?Ogm`80l?3`0P3gmoL40?;blP@0moOg
103bl_820?3`l080`<300P3;bl/20<g=c@80bl_;1P34a<@20;jn_P80`l?30P2j^[X40<?3``80a/K6
103<c<`20<K6aP80_Kfm0P36a/H30<c<c0P0d];B0P3Fe]H20=;BdP80c<c<0P30`<020<K6aP80c<c<
0P31`L440<K6aP@0a<C4102m_Kd60;Fe]@80[jn_202e]KD20:n_[a<0]KFe0P33`l<20;jn_PH0`l?3
0P2n_[h20;fm_@80`l?30P2e]KD40=?Cd`80/[:b0P2HV9P20;Fe]@@0a<C41P3=cLd20=?Cd`@0e=CD
0P3Jf]X20=CDe080c<c<0P2KVi/20:BTY080]KFe0`2g]kL40;Fe]@80c<c<0P3;bl/20<C4a080`/;2
0P33`l<20=oOg`80d];B0P33`l<20=[JfP80j>SX0P3`l?020?;blP@0k^k^3`3oool000d0oooo0P3`
l?020?Ogm`80l?3`1P3gmoL40?3`l0@0l_;b0P3gmoL20?;blP80l?3`0P3^k^h20?Ogm`<0l_;b103g
moL20?3`l080moOg0P3`l?020?Ogm`@0l_;b103gmoL40?;blP80l?3`0P30`<020<_;b`80cLg=0P3;
bl/60<C4a080_[jn0P33`l<20;Zj^P@0`l?30P36a/H40<c<c080a/K60P2m_Kd20<K6aP<0c<c<203B
d]820=KFeP80d];B0P3<c<`20<30`080a/K60P3<c<`20<71`@@0a/K61034a<@40;fm_@H0]KFe0P2_
[jl80;Fe]@80[jn_4`2e]KD20<?3``80_[jn1P33`l<20;jn_P80_Kfm0P33`l<20;Fe]@@0dm?C0P2b
/[8209RHV080]KFe1034a<@60<g=c@80dm?C103De=@20=[JfP80e=CD0P3<c<`209^KV`80Y:BT0P2e
]KD30;Ng]`@0]KFe0P3<c<`20<_;b`80a<C40P32`/820<?3``80gmoO0P3Bd]820<?3``80f][J0P3X
j>P20?3`l080l_;b103^k^h?0?ooo`003@3oool20?Ogm`80l_;b0P3gmoL20?3`l0H0moOg103bl_82
0>k^kPP0l?3`0P3gmoL30?3`l080k^k^0P3gmoL20?3`l080moOg0P3bl_820?Ogm`80l_;b0P3`l?02
0?Ogm`@0l_;b0P3`l?020?Ogm`80l?3`0P33`l<20:FUY@80f=SH0P34a<@20;Jf]P@0a<C40P33`l<4
0;Zj^P80]KFe0P2m_Kd20<?3``@0a/K60P2m_Kd20<?3``D0c<c<0P3Fe]H20=;BdP80e]KF0P3Bd]84
0<g=c@P0a/K60P3<c<`20<K6aPH0c<c<0P36a/H20<c<c0@0a/K60P33`l<20;jn_P80`l?31P2n_[h2
0<?3``@0_[jn0P36a/H20<?3``<0a/K61034a<@40<c<c080_[jn1P3<c<`20<C4a080c<c<1034a<@2
0<K6aP80c/k>0P3Bd]820=?Cd`80a<C40P1OGel20;jn_P80][Jf0P34a<@40<_;b`80c<c<0P2b/[82
08j>SP@0QXJ60P2EUID20;Fe]@80`/;20`34a<@20;Fe]@80`/;20P33`l<20<C4a080d];B0P3;bl/2
0;Fe]@80f][J0P3Hf=P20;Fe]@80h>3P0P3Ogml20?3`l080l_;b0P3gmoL20?3`l0l0oooo000=0?oo
o`80moOg0P3bl_820?Ogm`80l?3`1P3gmoL40?;blP80k^k^203`l?020?Ogm`<0l?3`0P3^k^h20?Og
m`80l?3`0P3gmoL20?;blP80moOg0P3bl_820?3`l080moOg103bl_820?3`l080moOg0P3`l?020<?3
``80YJFU0P3Hf=P20<C4a080][Jf1034a<@20<?3``@0^[Zj0P2e]KD20;fm_@80`l?31036a/H20;fm
_@80`l?31@3<c<`20=KFeP80d];B0P3Fe]H20=;BdP@0cLg=2036a/H20<c<c080a/K61P3<c<`20<K6
aP80c<c<1036a/H20<?3``80_[jn0P33`l<60;jn_P80`l?3102n_[h20<K6aP80`l?30`36a/H40<C4
a0@0c<c<0P2n_[h60<c<c080a<C40P3<c<`40<C4a080a/K60P3>c/h20=;BdP80dm?C0P34a<@205mO
G`80_[jn0P2f][H20<C4a0@0bl_;0P3<c<`20;:b/P80SXj>1026QXH209FEU@80]KFe0P32`/830<C4
a080]KFe0P32`/820<?3``80a<C40P3Bd]820<_;b`80]KFe0P3Jf]X20=SHf080]KFe0P3Ph>020=oO
g`80l?3`0P3bl_820?Ogm`80l?3`3`3oool000d0oooo0P3^k^h20?3`l080moOg0P3`l?020?;blP80
k^k^0P3`l?040?;blP80moOg0P3^k^h20?;blP@0moOg1`3bl_820?Ogm`80l_;b0P3gmoL20?;blP80
moOg0P3`l?040?;blP80l?3`0P3gmoL20?3`l0@0l_;b0P33`l<20:BTY080]KFe0P2`/;020;Jf]PP0
`l?30P34a<@20;Zj^P80_Kfm0P33`l<40<K6aP80_Kfm0P32`/830<c<c080cLg=0P3<c<`20<g=c@P0
d];B0P3<c<`40<K6aPh0c<c<0P36a/H20<71`@P0c<c<0P34a<@20<?3``@0a/K6103<c<`70<K6aP80
a<C42P3<c<`20<K6aP80c<c<0P36a/H40<c<c080cLg=0P3<c<`20<C4a080cLg=0P3<c<`20=;BdP80
clo?0P3Jf]X20;:b/P@0V9RH0P2/[:`2096AT@80QXJ60P2EUID208J6QP80SXj>102TY:@20<;2`P<0
]KFe0P2a/K420>SXj0@0`/;20P39bLT20:j^[P80e=CD0P3Ph>020<?3``80gmoO0P3<c<`20>k^kP80
jNWY103^k^h20?Ogm`l0oooo000=0?ooo`80k^k^0P3`l?020?Ogm`80l?3`0P3bl_820>k^kP80l?3`
103bl_820?Ogm`80k^k^0P3bl_840?Ogm`L0l_;b0P3gmoL20?;blP80moOg0P3bl_820?Ogm`80l?3`
103bl_820?3`l080moOg0P3`l?040?;blP80`l?30P2TY:@20;Fe]@80/;2`0P2f][H80<?3``80a<C4
0P2j^[X20;fm_@80`l?31036a/H20;fm_@80`/;20`3<c<`20<g=c@80c<c<0P3=cLd80=;BdP80c<c<
1036a/H>0<c<c080a/K60P31`L480<c<c080a<C40P33`l<40<K6aP@0c<c<1`36a/H20<C4a0X0c<c<
0P36a/H20<c<c080a/K6103<c<`20<g=c@80c<c<0P34a<@20<g=c@80c<c<0P3Bd]820<o?c`80f][J
0P2b/[8409RHV080[:b/0P2ATI4208J6QP80UIFE0P26QXH208j>SP@0Y:BT0P32`/830;Fe]@80/K6a
0P3Xj>P40<;2`P80bLW90P2^[Zh20=CDe080h>3P0P33`l<20=oOg`80c<c<0P3^k^h20>WYj@@0k^k^
0P3gmoL?0?ooo`003@3oool20?Ogm`@0l?3`0P3gmoL20?3`l0@0moOg0P3^k^h40?3`l080moOg0P3b
l_820?Ogm`80l?3`0P3gmoL30?3`l0@0l_;b0P3gmoL20?3`l0P0moOg103`l?040>k^kP80l_;b0P3^
k^h20<c<c080bl_;0P2KVi/40;6a/@80W9bL0P33`l<20<C4a080_[jn0P33`l<20;Jf]P80`/;20P33
`l<20;fm_@80a/K61032`/870<c<c0@0cLg=0P3Bd]820<c<c080d];B103<c<`40<K6aQ00c<c<0P31
`L440<K6aPH0c<c<0P33`l<20<K6aP80a<C40P31`L420<K6aPD0c<c<0P31`L480<c<c0@0a/K60P3<
c<`20<C4a080c<c<0P33`l<80<c<c0H0a<C40P3Bd]840=?Cd`80`<300P1/K6`2079bLP80SXj>0P26
QXH208j>SP@0Vi^K0P2LW9`209^KV`<0/;2`0P2j^[X20=oOg`80Y:BT0P2d];@20<_;b`80[Zj^0P3<
c<`20=SHf080`/;20P3^k^h20>SXj0@0k^k^103`l?020?Ogm`l0oooo000=0?ooo`80moOg103`l?02
0?Ogm`80l?3`103gmoL20>k^kP@0l?3`0P3gmoL20?;blP80moOg0P3`l?020?Ogm`<0l?3`103bl_82
0?Ogm`80l?3`203gmoL40?3`l0@0k^k^0P3bl_820>k^kP80c<c<0P3;bl/209^KV`@0/K6a0P2LW9`2
0<?3``80a<C40P2n_[h20<?3``80][Jf0P32`/820<?3``80_Kfm0P36a/H40<;2`PL0c<c<103=cLd2
0=;BdP80c<c<0P3Bd]840<c<c0@0a/K6403<c<`20<71`@@0a/K61P3<c<`20<?3``80a/K60P34a<@2
0<71`@80a/K61@3<c<`20<71`@P0c<c<1036a/H20<c<c080a<C40P3<c<`20<?3``P0c<c<1P34a<@2
0=;BdP@0dm?C0P30`<0206a/K080LW9b0P2>SXh208J6QP80SXj>102KVi/209bLW080Vi^K0`2`/;02
0;Zj^P80gmoO0P2TY:@20;Bd]080bl_;0P2^[Zh20<c<c080f=SH0P32`/820>k^kP80j>SX103^k^h4
0?3`l080moOg3`3oool000d0oooo0P3`l?040?Ogm`@0l?3`0P3gmoL20?3`l0H0moOg0P3`l?040?Og
m`80l_;b0P3`l?090?Ogm`80l?3`0P3bl_840?Ogm`80l_;b103`l?020?;blPH0l?3`0P3Cdm<20<c<
c080/[:b0P2KVi/20;6a/@80QHF50P1bLW820;Jf]P80`l?3102n_[h20<?3``80_[jn0P33`l<20<30
`080_Kfm0P33`l<;0<c<c080d];B4P3<c<`20<g=c@P0c<c<1P36a/H20<c<c0@0a/K60P3<c<`20<?3
``80`L711P36a/H30<?3``80a<C40P3<c<`20<g=c@@0c<c<0P31`L440<c<c0H0a/K6103<c<`60<C4
a080`l?30P2e]KD20:b/[080YJFU0P26QXH207IfMP80QXJ60P25QHD208>3P`80QHF50P2KVi/209FE
U@80Vi^K0P2LW9`50;Bd]080]KFe0P3;bl/20:j^[P80];Bd0P32`/820;Bd]080f=SH0P3;bl/20=;B
dP80j>SX0P3^k^h20?;blP80j>SX103gmoL20?;blPl0oooo000=0?ooo`80l?3`103gmoL40?3`l080
moOg0P3`l?060?Ogm`80l?3`103gmoL20?;blP80l?3`2@3gmoL20?3`l080l_;b103gmoL20?;blP@0
l?3`0P3bl_860?3`l080dm?C0P3<c<`20;:b/P80Vi^K0P2a/K4208F5Q@80LW9b0P2f][H20<?3``@0
_[jn0P33`l<20;jn_P80`l?30P30`<020;fm_@80`l?32`3<c<`20=;BdQ80c<c<0P3=cLd80<c<c0H0
a/K60P3<c<`40<K6aP80c<c<0P33`l<20<71`@H0a/K60`33`l<20<C4a080c<c<0P3=cLd40<c<c080
`L71103<c<`60<K6aP@0c<c<1P34a<@20<?3``80]KFe0P2/[:`20:FUY@80QXJ60P1fMWH208J6QP80
QHF50P23Ph<208F5Q@80Vi^K0P2EUID209^KV`80W9bL1@2d];@20;Fe]@80bl_;0P2^[Zh20;Bd]080
`/;20P2d];@20=SHf080bl_;0P3Bd]820>SXj080k^k^0P3bl_820>SXj0@0moOg0P3bl_8?0?ooo`00
3@3oool20?Ogm`80l_;b0P3`l?020?;blP80l?3`0P3gmoL20?3`l080moOg0P3^k^h20?Ogm`80l?3`
0P3gmoL20?3`l080moOg0P3`l?070?Ogm`80l?3`0P3bl_840?Ogm`80l?3`0P3gmoL20?3`l080k^k^
0P3`l?020?Ogm`@0l?3`0P3Ph>020>SXj080f=SH0P2EUID209^KV`80QHF50P1eMGD205UIF@80_[jn
0P2f][H20<?3``80]KFe0P2f][H20;jn_P80`l?30P32`/820<?3``/0c<c<0P3=cLd:0<c<c0P0a/K6
0P3<c<`20<K6aPH0c<c<2P36a/H60<?3``P0a/K60`33`l<40<K6aP80c<c<0P33`l<40<K6aP@0c<c<
0P36a/H20<?3``H0a/K60P2m_Kd20<?3``@0]KFe0P2UYJD209^KV`80O7al0P1fMWH208J6QP@0UIFE
0P2IVIT208j>SP80QHF5102KVi/20:f][@80]KFe0`2d];@20<?3``80]KFe0P2TY:@40;Bd]0H0bl_;
0P3Hf=P20?;blP80k^k^103`l?040?;blP80k^k^3`3oool000d0oooo0P3gmoL20?;blP80l?3`0P3b
l_820?3`l080moOg0P3`l?020?Ogm`80k^k^0P3gmoL20?3`l080moOg0P3`l?020?Ogm`80l?3`1`3g
moL20?3`l080l_;b103gmoL20?3`l080moOg0P3`l?020>k^kP80l?3`0P3gmoL40?3`l080h>3P0P3X
j>P20=SHf080UIFE0P2KVi/208F5Q@80MGEe0P1IFET20;jn_P80][Jf0P33`l<20;Fe]@80][Jf0P2n
_[h20<?3``80`/;20P33`l<;0<c<c080cLg=2P3<c<`80<K6aP80c<c<0P36a/H60<c<c0X0a/K61P33
`l<80<K6aP<0`l?31036a/H20<c<c080`l?31036a/H40<c<c080a/K60P33`l<60<K6aP80_Kfm0P33
`l<40;Fe]@80YJFU0P2KVi/207alO080MWIf0P26QXH409FEU@80VIVI0P2>SXh208F5Q@@0Vi^K0P2]
[Jd20;Fe]@<0];Bd0P33`l<20;Fe]@80Y:BT102d];@60<_;b`80f=SH0P3bl_820>k^kP@0l?3`103b
l_820>k^kPl0oooo000=0?ooo`80l?3`0P3bl_820?Ogm`80l_;b0P3^k^h60?Ogm`80l?3`0P3gmoL2
0?;blP80l?3`0P3gmoL20?3`l0D0moOg103`l?020?;blP80l?3`0P3gmoL20>k^kP80moOg0P3bl_82
0?3`l080moOg103bl_820>k^kP80l?3`0P3IfMT20?3`l080bl_;0P2EUID208J6QP80QHF50P1_Kfl2
05UIF@80?clo0P2_[jl40;Fe]@80`l?30P2n_[h20<?3``80_Kfm0P32`/830<C4a0P0c<c<0P36a/H>
0<c<c080a/K60P3<c<`60<K6aPP0c<c<1030`<080<K6aP80`L710P36a/H20<?3``80`<300`32`/82
0<?3``80`L710P3<c<`20<K6aP80c<c<0P36a/H20<?3``@0c<c<1036a/H20<?3``@0_Kfm0P2e]KD2
0;Bd]0@0Y:BT0P26QXH2079bLP80SXj>0P2EUID208J6QP80UIFE0P2UYJD209FEU@80SXj>0P2EUID2
0:f][@80Vi^K0P2a/K430:BTY080/;2`0P2^[Zh60<;2`P80h>3P0P2e]KD20<c<c0@0k^k^0P3bl_82
0>[ZjP80l?3`0P3^k^h20?Ogm`80l_;b3`3oool000d0oooo0P3`l?020?;blP80moOg0P3bl_820>k^
kPH0moOg0P3`l?020?Ogm`80l_;b0P3`l?020?Ogm`80l?3`1@3gmoL40?3`l080l_;b0P3`l?020?Og
m`80k^k^0P3gmoL20?;blP80l?3`0P3gmoL40?;blP80k^k^0P3`l?020=WIf@80l?3`0P3;bl/209FE
U@80QXJ60P25QHD206m_K`80FEUI0P0o?cl20:n_[`@0]KFe0P33`l<20;jn_P80`l?30P2m_Kd20<;2
`P<0a<C4203<c<`20<K6aPh0c<c<0P36a/H20<c<c0H0a/K6203<c<`40<30`0P0a/K60P31`L420<K6
aP80`l?30P30`<030<;2`P80`l?30P31`L420<c<c080a/K60P3<c<`20<K6aP80`l?3103<c<`40<K6
aP80`l?3102m_Kd20;Fe]@80];Bd102TY:@208J6QP80LW9b0P2>SXh209FEU@80QXJ60P2EUID20:FU
Y@80UIFE0P2>SXh209FEU@80[Jf]0P2KVi/20;6a/@<0Y:BT0P2`/;020:j^[PH0`/;20P3Ph>020;Fe
]@80c<c<103^k^h20?;blP80j^[Z0P3`l?020>k^kP80moOg0P3bl_8?0?ooo`003@3oool:0?3`l080
moOg0P3^k^h20?3`l080k^k^1P3gmoL20?3`l080moOg1@3`l?020?Ogm`80l?3`0P3gmoL20?;blP80
l?3`0P3gmoL40?3`l080moOg0P3`l?020?Ogm`80l_;b0P3`l?020>k^kP80h>3P0P3Xj>P20<c<c080
`<300P25QHD208j>SP80MGEe0P1IFET403lo?`@0]KFe0P2m_Kd20;Fe]@80`l?30P32`/820;fm_@d0
c<c<1036a/H40<c<c0P0a/K60P30`<020<?3``80a/K61P3<c<`60<K6aP80`l?30P30`<020<;2`P80
_Kfm1P36a/H20<30`080`l?30`2g]kL20<?3``80`/;23036a/H20<;2`P@0];Bd0P2^[Zh80:BTY080
SXj>0P1XJ6P205UIF@80QXJ60P2TY:@209^KV`80Lg=c0P2EUID209bLW080/K6a102][Jd409FEU@80
Vi^K0`2TY:@20;Fe]@80[Zj^1032`/820>SXj080`l?30P3;bl/20=[JfP80jNWY0P3Xj>P20>WYj@H0
l?3`0P3gmoL20?;blPl0oooo000=0?ooo`X0l?3`0P3gmoL20>k^kP80l?3`0P3^k^h60?Ogm`80l?3`
0P3gmoL50?3`l080moOg0P3`l?020?Ogm`80l_;b0P3`l?020?Ogm`@0l?3`0P3gmoL20?3`l080moOg
0P3bl_820?3`l080k^k^0P3Ph>020>SXj080c<c<0P30`<0208F5Q@80SXj>0P1eMGD205UIF@@0?clo
102e]KD20;fm_@80]KFe0P33`l<20<;2`P80_Kfm3@3<c<`40<K6aP@0c<c<2036a/H20<30`080`l?3
0P36a/H60<c<c0H0a/K60P33`l<20<30`080`/;20P2m_Kd60<K6aP80`<300P33`l<30;Ng]`80`l?3
0P32`/8<0<K6aP80`/;2102d];@20:j^[PP0Y:BT0P2>SXh206QXJ080FEUI0P26QXH20:BTY080Vi^K
0P1cLg<209FEU@80W9bL0P2a/K440:f][@@0UIFE0P2KVi/30:BTY080]KFe0P2^[Zh40<;2`P80j>SX
0P33`l<20<_;b`80f][J0P3YjNT20>SXj080jNWY1P3`l?020?Ogm`80l_;b3`3oool000d0oooo2P3`
l?020?Ogm`80k^k^0P3`l?020>k^kPH0moOg0P3`l?020?Ogm`D0l?3`0P3gmoL20?3`l080moOg0P3b
l_820?3`l080moOg103`l?020?Ogm`80l?3`0P3gmoL20?;blP80l?3`0P3^k^h20>3Ph080j>SX0P3<
c<`20<30`080QHF50P2>SXh207EeM@80FEUI100o?cl40;Fe]@80_Kfm0P2e]KD20<?3``80`/;20P2m
_Kd=0<c<c0@0a/K6103<c<`80<K6aP80`<300P33`l<20<K6aPH0c<c<1P36a/H20<?3``80`<300P32
`/820;fm_@H0a/K60P30`<020<?3``<0]kNg0P33`l<20<;2`P`0a/K60P32`/840;Bd]080[Zj^202T
Y:@208j>SP80J6QX0P1IFET208J6QP80Y:BT0P2KVi/207=cL`80UIFE0P2LW9`20;6a/@@0[Jf]102E
UID209^KV`<0Y:BT0P2e]KD20:j^[P@0`/;20P3Xj>P20<?3``80bl_;0P3Jf]X20>WYj@80j>SX0P3Y
jNT60?3`l080moOg0P3bl_8?0?ooo`003@3oool20>k^kP80moOg0P3bl_820?3`l080moOg103`l?02
0?;blP80moOg103bl_820?Ogm`80l_;b0P3gmoL20?;blPD0moOg0P3bl_820?Ogm`80l_;b103`l?02
0?Ogm`80l_;b0P3`l?020>k^kP80l_;b0P3`l?020?;blP80k^k^0P3`l?040=oOg`80/K6a0P2>SXh2
08J6QP80K6a/0P1IFET204];B`80?clo0P0e=CD20;Fe]@80_[jn0P2`/;020<;2`P80_Kfm0P32`/83
0<K6aP80c<c<2036a/H20<c<c0@0a/K60P3<c<`40<K6aP80c<c<1036a/H20<30`080`/;21036a/H2
0<?3``80c<c<0P36a/H20<30`080_Kfm0P30`<080;fm_@80`/;2102m_Kd70;Ng]`80`<300P36a/H2
0;Ng]`80a/K60P2d];@20<;2`P80_Kfm0P2g]kL40:j^[P80Y:BT0P2LW9`208j>SP80O7al0P1IFET2
06MWI`80K6a/0P2>SXh409^KV`80U9BD102TY:@20:f][@@0Y:BT0P2][Jd209FEU@80Vi^K1@2^[Zh2
0;Bd]080`/;20P34a<@20<?3``80bl_;0P3Hf=P20>SXj080jNWY0P3Ogml20>WYj@@0l_;b0P3`l?04
0?Ogm`l0oooo000=0?ooo`80k^k^0P3gmoL20?;blP80l?3`0P3gmoL40?3`l080l_;b0P3gmoL40?;b
lP80moOg0P3bl_820?Ogm`80l_;b1@3gmoL20?;blP80moOg0P3bl_840?3`l080moOg0P3bl_820?3`
l080k^k^0P3bl_820?3`l080l_;b0P3^k^h20?3`l0@0gmoO0P2a/K4208j>SP80QXJ60P1/K6`205UI
F@80Bd];0P0o?cl203De=@80]KFe0P2n_[h20;2`/080`/;20P2m_Kd20<;2`P<0a/K60P3<c<`80<K6
aP80c<c<1036a/H20<c<c0@0a/K60P3<c<`40<K6aP80`<300P32`/840<K6aP80`l?30P3<c<`20<K6
aP80`<300P2m_Kd20<30`0P0_Kfm0P32`/840;fm_@L0]kNg0P30`<020<K6aP80]kNg0P36a/H20;Bd
]080`/;20P2m_Kd20;Ng]`@0[Zj^0P2TY:@209bLW080SXj>0P1lO7`205UIF@80IfMW0P1/K6`208j>
SP@0Vi^K0P2DU9@40:BTY080[Jf]102TY:@20:f][@80UIFE0P2KVi/50:j^[P80];Bd0P32`/820<C4
a080`l?30P3;bl/20=SHf080j>SX0P3YjNT20=oOg`80jNWY103bl_820?3`l0@0moOg3`3oool000d0
oooo0P3`l?020>k^kPH0moOg0P3^k^h60?Ogm`@0l?3`0P3gmoL20?3`l080l_;b0P3^k^h30?;blP@0
l?3`1P3gmoL40?;blP80moOg1P3`l?020?;blP80l?3`0P3YjNT20>SXj080d];B0P3Ph>0209FEU@80
SXj>0P25QHD206MWI`@0FEUI0P1;Bd/203De=@806ATI0P2/[:`20;Jf]P80]KFe102m_Kd30<C4a080
`l?32036a/H20<c<c080a/K60P3<c<`80<K6aP80`l?31036a/H40<30`080`/;20P30`<040<K6aP80
`l?30P32`/820<30`080_Kfm0P30`<020;Ng]`80];Bd0P2g]kL20<30`0D0]kNg0P30`<020;Ng]`80
`/;20P2m_Kd20;Ng]`80];Bd0P2m_Kd40;Fe]@80];Bd0P2^[Zh20:FUY@80UYJF0P1lO7`2079bLP80
K6a/0P1XJ6P207=cL`80TI6A0P2LW9`209FEU@80U9BD0P2KVi/20:BTY080Vi^K102>SXh209^KV`80
UIFE0P2][Jd50:j^[P80[Jf]0P32`/840<C4a080bl_;103Xj>P20>3Ph080jNWY0P3bl_820?3`l0X0
moOg3`3oool000d0oooo0P3`l?020>k^kPH0moOg0P3^k^h60?Ogm`@0l?3`0P3gmoL20?3`l080l_;b
0P3^k^h30?;blP@0l?3`1P3gmoL40?;blP80moOg1P3`l?020?;blP80l?3`0P3YjNT20>SXj080d];B
0P3Ph>0209FEU@80SXj>0P25QHD206MWI`@0FEUI0P1;Bd/203De=@806ATI0P2/[:`20;Jf]P80]KFe
102m_Kd30<C4a080`l?32036a/H20<c<c080a/K60P3<c<`80<K6aP80`l?31036a/H40<30`080`/;2
0P30`<040<K6aP80`l?30P32`/820<30`080_Kfm0P30`<020;Ng]`80];Bd0P2g]kL20<30`0D0]kNg
0P30`<020;Ng]`80`/;20P2m_Kd20;Ng]`80];Bd0P2m_Kd40;Fe]@80];Bd0P2^[Zh20:FUY@80UYJF
0P1lO7`2079bLP80K6a/0P1XJ6P207=cL`80TI6A0P2LW9`209FEU@80U9BD0P2KVi/20:BTY080Vi^K
102>SXh209^KV`80UIFE0P2][Jd50:j^[P80[Jf]0P32`/840<C4a080bl_;103Xj>P20>3Ph080jNWY
0P3bl_820?3`l0X0moOg3`3oool000d0oooo0P3^k^h20?Ogm`80l_;b1P3gmoL20?3`l080l_;b103g
moL20?;blP80l?3`0P3^k^h20?;blPT0moOg0P3bl_820?3`l0H0l_;b0P3gmoL60?;blP@0l?3`0P3b
l_820>WYj@80f=SH0P3Ogml209^KV`80SXj>0P26QXH206a/K0@0FEUI0P1;Bd/402d];@806ATI102e
]KD20<?3``80_[jn1@33`l<:0<K6aP@0c<c<3P36a/H40<;2`P80a/K60P30`<020<?3``80`<300P31
`L480;fm_@P0]kNg0P2d];@30:j^[P80];Bd0P2g]kL20;Bd]080`l?30P2^[Zh20;Fe]@@0];Bd0P2U
YJD20:n_[`80Y:BT0P26QXH206MWI`80LW9b0P19BDT207=cL`80O7al0P26QXH209^KV`80UIFE0P2D
U9@209VIV@80U9BD0P2][Jd60:BTY0@0[Jf]0P2^[Zh20;Bd]0<0/K6a0P32`/820<?3``@0a<C40P3D
e=@20=[JfP80h>3P0P3Xj>P20>k^kP80l?3`0P3gmoL20?;blP80moOg0P3bl_820?3`l080moOg3`3o
ool000d0oooo0P3^k^h20?Ogm`80l_;b1P3gmoL20?3`l080l_;b103gmoL20?;blP80l?3`0P3^k^h2
0?;blPT0moOg0P3bl_820?3`l0H0l_;b0P3gmoL60?;blP@0l?3`0P3bl_820>WYj@80f=SH0P3Ogml2
09^KV`80SXj>0P26QXH206a/K0@0FEUI0P1;Bd/402d];@806ATI102e]KD20<?3``80_[jn1@33`l<:
0<K6aP@0c<c<3P36a/H40<;2`P80a/K60P30`<020<?3``80`<300P31`L480;fm_@P0]kNg0P2d];@3
0:j^[P80];Bd0P2g]kL20;Bd]080`l?30P2^[Zh20;Fe]@@0];Bd0P2UYJD20:n_[`80Y:BT0P26QXH2
06MWI`80LW9b0P19BDT207=cL`80O7al0P26QXH209^KV`80UIFE0P2DU9@209VIV@80U9BD0P2][Jd6
0:BTY0@0[Jf]0P2^[Zh20;Bd]0<0/K6a0P32`/820<?3``@0a<C40P3De=@20=[JfP80h>3P0P3Xj>P2
0>k^kP80l?3`0P3gmoL20?;blP80moOg0P3bl_820?3`l080moOg3`3oool000d0oooo103gmoL20>k^
kP80moOg0P3bl_860?Ogm`@0l_;b0P3^k^h20?;blP80moOg0P3`l?020>k^kPD0l_;b103gmoL20?3`
l080l_;b0P3gmoL40?3`l080l_;b0P3gmoL20?;blP@0l?3`0P3^k^h20>SXj080gmoO0P3Cdm<209^K
V`80SXj>0P1fMWH206a/K080J6QX0P1IFET203lo?`80;Bd]0P0R8R8203De=@@0]KFe0P2m_Kd50<?3
``80a<C40P33`l<20<c<c080a/K60P3<c<`:0<K6aP80`<301036a/H20<;2`P80a/K60P30`<020<?3
``80`<30102m_Kd20;Ng]`P0_Kfm102g]kL20;Bd]080[jn_1`2^[Zh20;Bd]080`l?30P2d];@20:FU
Y@80Y:BT0P2UYJD40:NWY`@0UYJF0P25QHD208J6QP80DU9B0P1WIfL206QXJ080LW9b0P1XJ6P208J6
QP80UIFE102>SXh209BDU0@0Y:BT0P2a/K420;Fe]@80Y:BT0P2][Jd20<;2`P80/K6a0P2d];@50<;2
`P80a<C40P33`l<20=CDe0@0f][J103`l?040?Ogm`@0l_;b0P3gmoL20?3`l0@0moOg3`3oool000d0
oooo103gmoL20>k^kP80moOg0P3bl_860?Ogm`@0l_;b0P3^k^h20?;blP80moOg0P3`l?020>k^kPD0
l_;b103gmoL20?3`l080l_;b0P3gmoL40?3`l080l_;b0P3gmoL20?;blP@0l?3`0P3^k^h20>SXj080
gmoO0P3Cdm<209^KV`80SXj>0P1fMWH206a/K080J6QX0P1IFET203lo?`80;Bd]0P0R8R8203De=@@0
]KFe0P2m_Kd50<?3``80a<C40P33`l<20<c<c080a/K60P3<c<`:0<K6aP80`<301036a/H20<;2`P80
a/K60P30`<020<?3``80`<30102m_Kd20;Ng]`P0_Kfm102g]kL20;Bd]080[jn_1`2^[Zh20;Bd]080
`l?30P2d];@20:FUY@80Y:BT0P2UYJD40:NWY`@0UYJF0P25QHD208J6QP80DU9B0P1WIfL206QXJ080
LW9b0P1XJ6P208J6QP80UIFE102>SXh209BDU0@0Y:BT0P2a/K420;Fe]@80Y:BT0P2][Jd20<;2`P80
/K6a0P2d];@50<;2`P80a<C40P33`l<20=CDe0@0f][J103`l?040?Ogm`@0l_;b0P3gmoL20?3`l0@0
moOg3`3oool000d0oooo0P3gmoL20?;blP@0l?3`0P3bl_820?3`l080moOg0P3`l?020?Ogm`@0l?3`
103gmoL20?;blP80moOg0`3`l?020?Ogm`H0l_;b0P3gmoL40?3`l0@0moOg0P3bl_820?Ogm`80l?3`
0P3bl_820>k^kP80j^[Z0P3Hf=P20;6a/@80Vi^K0P2>SXh207alO080IfMW0P1eMGD205UIF@80DE5A
100e=CD204I6AP80C4a<0P2f][H20<;2`P80`l?30`3<c<`40<?3``80c<c<3036a/H20<?3``80a/K6
0P33`l<20;fm_@80`L710P36a/H20<;2`P@0`<300P32`/820;Ng]`80`/;20P2d];@20;fm_@80`/;2
0P2m_Kd40;Ng]`@0[jn_0P2LW9`20:BTY0<0]KFe0P33`l<20;Fe]@80UYJF0P2LW9`20:BTY080W9bL
0P2TY:@209bLW080QXJ60P25QHD206m_K`80K6a/0P26QXH207=cL`@0QXJ60P2ATI4209^KV`80W9bL
0P2DU9@209FEU@80U9BD0P2TY:@209FEU@80W9bL102TY:@20:j^[P@0Y:BT1`32`/820<?3``80d];B
0P3Jf]X40>SXj080l_;b0P3gmoL20?3`l080k^k^103gmoL40?;blP80moOg0P3bl_8?0?ooo`003@3o
ool20?Ogm`80l_;b103`l?020?;blP80l?3`0P3gmoL20?3`l080moOg103`l?040?Ogm`80l_;b0P3g
moL30?3`l080moOg1P3bl_820?Ogm`@0l?3`103gmoL20?;blP80moOg0P3`l?020?;blP80k^k^0P3Z
j^X20=SHf080/K6a0P2KVi/208j>SP80O7al0P1WIfL207EeM@80FEUI0P1ADE4403De=@80ATI60P1<
C4`20;Jf]P80`/;20P33`l<30<c<c0@0`l?30P3<c<`<0<K6aP80`l?30P36a/H20<?3``80_Kfm0P31
`L420<K6aP80`/;21030`<020<;2`P80]kNg0P32`/820;Bd]080_Kfm0P32`/820;fm_@@0]kNg102_
[jl209bLW080Y:BT0`2e]KD20<?3``80]KFe0P2FUYH209bLW080Y:BT0P2LW9`20:BTY080W9bL0P26
QXH208F5Q@80Kfm_0P1/K6`208J6QP80Lg=c1026QXH2096AT@80Vi^K0P2LW9`209BDU080UIFE0P2D
U9@20:BTY080UIFE0P2LW9`40:BTY080[Zj^102TY:@70<;2`P80`l?30P3Bd]820=[JfP@0j>SX0P3b
l_820?Ogm`80l?3`0P3^k^h40?Ogm`@0l_;b0P3gmoL20?;blPl0oooo000=0?ooo`@0moOg0P3`l?02
0?Ogm`80l?3`103bl_840?Ogm`80l?3`203gmoL20?3`l0<0l_;b0P3gmoL20?3`l080l_;b0P3^k^h2
0?3`l080moOg0P3`l?020?;blP80moOg0P3`l?020?;blP80l?3`0P3^k^h20>SXj080jNWY0P3?cll2
0;6a/@@0SXj>0P1fMWH207alO080LW9b101ADE4203lo?`80BDU90P1;Bd/202d];@80]KFe0P33`l<2
0<C4a0<0c<c<1033`l<20<K6aP80`<300P32`/820<K6aP80`<300P32`/840<K6aP80`/;20P30`<02
0<;2`P@0`<300P36a/H60;fm_@80`/;20P2d];@20<30`080];Bd0P2g]kL20;Fe]@80];Bd0P2_[jl2
0:RXZ080W9bL102TY:@30<;2`P80`l?30P2FUYH209bLW0@0Y:BT0P2FUYH208>3P`80N7Qh0P1XJ6P2
08F5Q@80MGEe0P1/K6`2079bLP80QHF50P26QXH207IfMP80SXj>102KVi/209FEU@80SXj>0P1lO7`2
0;6a/@80Vi^K0P2a/K4209bLW080`/;20P2TY:@20:j^[PT0`/;20P3;bl/20<c<c080j>SX103YjNT2
0?;blP80moOg0P3^k^h60?Ogm`80l?3`1P3gmoL?0?ooo`003@3oool40?Ogm`80l?3`0P3gmoL20?3`
l0@0l_;b103gmoL20?3`l0P0moOg0P3`l?030?;blP80moOg0P3`l?020?;blP80k^k^0P3`l?020?Og
m`80l?3`0P3bl_820?Ogm`80l?3`0P3bl_820?3`l080k^k^0P3Xj>P20>WYj@80clo?0P2a/K4408j>
SP80MWIf0P1lO7`2079bLP@0DE5A0P0o?cl204U9B@80Bd];0P0];Bd20;Fe]@80`l?30P34a<@30<c<
c0@0`l?30P36a/H20<30`080`/;20P36a/H20<30`080`/;21036a/H20<;2`P80`<300P32`/840<30
`080a/K61P2m_Kd20<;2`P80];Bd0P30`<020;Bd]080]kNg0P2e]KD20;Bd]080[jn_0P2XZ:P209bL
W0@0Y:BT0`32`/820<?3``80UYJF0P2LW9`40:BTY080UYJF0P23Ph<207QhN080J6QX0P25QHD207Ee
M@80K6a/0P1bLW8208F5Q@80QXJ60P1fMWH208j>SP@0Vi^K0P2EUID208j>SP80O7al0P2a/K4209^K
V`80/K6a0P2LW9`20<;2`P80Y:BT0P2^[Zh90<;2`P80bl_;0P3<c<`20>SXj0@0jNWY0P3bl_820?Og
m`80k^k^1P3gmoL20?3`l0H0moOg3`3oool000d0oooo0P3gmoL20?3`l080moOg0P3`l?0:0?Ogm`80
l_;b203gmoL20?;blP<0l?3`103gmoL40?;blP80k^k^0P3gmoL20?;blP80moOg103`l?040?Ogm`80
l?3`103Xj>P20;Fe]@80/K6a0P2>SXh207alO080Lg=c101XJ6P204];B`80DE5A101IFET203lo?`80
6ATI0P33`l<20;fm_@80a<C40`33`l<20<K6aP80`l?30P36a/H40<30`080a/K63030`<040<;2`P80
`<300P2m_Kd20<;2`P@0_Kfm1P2d];@20;Ng]`80];Bd102e]KD20:RXZ080Y:BT102FUYH20;Bd]0<0
]KFe0P2FUYH408n?S`80U9BD0P2?Shl208>3P`80NWYj0P1NGUh207=cL`80QHF51P1eMGD207IfMP80
Lg=c0P1fMWH208j>SP80Vi^K0P2LW9`4096AT@80Vi^K0P2UYJD209bLW080Y:BT102LW9`40:f][@80
[Zj^1@33`l<20<C4a080f][J0P3`l?020>SXj080jNWY0P3^k^h40?Ogm`80l_;b103gmoL20?3`l080
l_;b0P3`l?040?Ogm`l0oooo000=0?ooo`80moOg0P3`l?020?Ogm`80l?3`2P3gmoL20?;blPP0moOg
0P3bl_830?3`l0@0moOg103bl_820>k^kP80moOg0P3bl_820?Ogm`@0l?3`103gmoL20?3`l0@0j>SX
0P2e]KD20;6a/@80SXj>0P1lO7`207=cL`@0J6QX0P1;Bd/2055AD@@0FEUI0P0o?cl201TI6@80`l?3
0P2m_Kd20<C4a0<0`l?30P36a/H20<?3``80a/K61030`<020<K6aP`0`<301032`/820<30`080_Kfm
0P32`/840;fm_@H0];Bd0P2g]kL20;Bd]0@0]KFe0P2XZ:P20:BTY0@0UYJF0P2d];@30;Fe]@80UYJF
102?Shl209BDU080Shn?0P23Ph<207YjNP80GUiN0P1cLg<208F5Q@H0MGEe0P1fMWH207=cL`80MWIf
0P2>SXh209^KV`80W9bL102ATI4209^KV`80YJFU0P2LW9`20:BTY0@0W9bL102][Jd20:j^[PD0`l?3
0P34a<@20=[JfP80l?3`0P3Xj>P20>WYj@80k^k^103gmoL20?;blP@0moOg0P3`l?020?;blP80l?3`
103gmoL?0?ooo`003@3oool60?Ogm`80l?3`103gmoL20?;blP80moOg0P3bl_820?Ogm`80l_;b203g
moL;0?;blP@0moOg0P3bl_820?Ogm`80l?3`1P3gmoL20?3`l080j>SX0P3IfMT20;6a/@80Y:BT0P2A
TI4208>3P`80MWIf0P1cLg<2055AD@80BDU90P1IFET205mOG`80DE5A0P0k>c/203De=@80a<C40P2n
_[h20<c<c0<0a<C40P2m_Kd20<K6aP@0`l?30P36a/H20<30`080`L710P32`/820<30`080]kNg1030
`<080;Ng]`80`<300P2d];@20;Ng]`80]KFe0P2d];@20;Ng]`80[Zj^0P2_[jl20:j^[P80YJFU0P2T
Y:@2092@T080UYJF0P2KVi/20:BTY0<0W9bL0P2>SXh208n?S`@0SXj>0P23Ph<206QXJ0@0Kfm_0P1b
LW8209FEU@80QXJ60P25QHD207EeM@80LW9b0P2ATI4208J6QP80SXj>0P2ATI4209FEU@80VIVI0P2a
/K440:BTY080VIVI1P2LW9`20:BTY080`/;20P34a<@20<c<c0<0a<C40P3Jf]X20>3Ph080j>SX0P3^
k^h20>SXj080k^k^0P3`l?020>k^kP@0moOg0P3bl_8:0?Ogm`l0oooo000=0?ooo`H0moOg0P3`l?04
0?Ogm`80l_;b0P3gmoL20?;blP80moOg0P3bl_880?Ogm`/0l_;b103gmoL20?;blP80moOg0P3`l?06
0?Ogm`80l?3`0P3Xj>P20=WIf@80/K6a0P2TY:@2096AT@80Ph>30P1fMWH207=cL`80DE5A0P19BDT2
05UIF@80GemO0P1ADE4203/k>`80=CDe0P34a<@20;jn_P80c<c<0`34a<@20;fm_@80a/K61033`l<2
0<K6aP80`<300P31`L420<;2`P80`<300P2g]kL40<30`0P0]kNg0P30`<020;Bd]080]kNg0P2e]KD2
0;Bd]080]kNg0P2^[Zh20:n_[`80[Zj^0P2UYJD20:BTY080T92@0P2FUYH209^KV`80Y:BT0`2LW9`2
08j>SP80Shn?102>SXh208>3P`80J6QX101_Kfl2079bLP80UIFE0P26QXH208F5Q@80MGEe0P1bLW82
096AT@80QXJ60P2>SXh2096AT@80UIFE0P2IVIT20;6a/@@0Y:BT0P2IVIT609bLW080Y:BT0P32`/82
0<C4a080c<c<0`34a<@20=[JfP80h>3P0P3Xj>P20>k^kP80j>SX0P3^k^h20?3`l080k^k^103gmoL2
0?;blPX0moOg3`3oool000d0oooo0P3gmoL20?;blPH0moOg103bl_840?Ogm`80l_;b203gmoL20?;b
lP<0moOg103bl_840?Ogm`80l_;b0P3gmoL:0?;blP@0l?3`0P3Xj>P20=SHf080/[:b0P2LW9`208j>
SP80O7al0P1cLg<2079bLP80GemO0P1IFET2079bLP80FEUI100e=CD202d];@80a<C40P2n_[h20<?3
``<0]KFe0P33`l<40<K6aP@0]kNg0P30`<020;fm_@H0]kNg0P2d];@40;Ng]`@0];Bd0P2g]kL20:n_
[`80]kNg202_[jl40:j^[P@0Y:BT0P2LW9`209FEU@80Shn?0P2UYJD209BDU0<0Ph>30P1hN7P208J6
QP80O7al0P23Ph<206IVIP80O7al0P1eMGD2079bLP80Lg=c0P26QXH209FEU@80SXj>0P1lO7`208J6
QP80Ph>30P26QXH2096AT@80O7al0P2DU9@209VIV@H0/K6a0P2KVi/209bLW080/K6a0P2KVi/20:BT
Y080`/;20P33`l<20<_;b`<0f][J0P3Xj>P20?3`l080j>SX0P3^k^h20>SXj0@0l?3`1P3gmoL20?;b
lP80l?3`0P3bl_820?3`l080l_;b0P3gmoL?0?ooo`003@3oool20?Ogm`80l_;b1P3gmoL40?;blP@0
moOg0P3bl_880?Ogm`80l_;b0`3gmoL40?;blP@0moOg0P3bl_820?Ogm`X0l_;b103`l?020>SXj080
f=SH0P2b/[8209bLW080SXj>0P1lO7`207=cL`80LW9b0P1OGel205UIF@80LW9b0P1IFET403De=@80
;Bd]0P34a<@20;jn_P80`l?30`2e]KD20<?3``@0a/K6102g]kL20<30`080_Kfm1P2g]kL20;Bd]0@0
]kNg102d];@20;Ng]`80[jn_0P2g]kL80:n_[`@0[Zj^102TY:@209bLW080UIFE0P2?Shl20:FUY@80
U9BD0`23Ph<207QhN080QXJ60P1lO7`208>3P`80IVIV0P1lO7`207EeM@80LW9b0P1cLg<208J6QP80
UIFE0P2>SXh207alO080QXJ60P23Ph<208J6QP80TI6A0P1lO7`209BDU080VIVI1P2a/K4209^KV`80
W9bL0P2a/K4209^KV`80Y:BT0P32`/820<?3``80bl_;0`3Jf]X20>SXj080l?3`0P3Xj>P20>k^kP80
j>SX103`l?060?Ogm`80l_;b0P3`l?020?;blP80l?3`0P3bl_820?Ogm`l0oooo000=0?ooo`H0moOg
0P3bl_840?Ogm`80l_;b1P3gmoL20?;blQ<0moOg0P3bl_820?Ogm`@0l_;b0P3gmoL40?3`l0@0moOg
0P3Xj>P20<C4a0@0Y:BT0P2ATI4207alO0@0Lg=c0P1ADE4206QXJ080FEUI0P19BDT202d];@80>c/k
0P0];Bd;0<?3``80_Kfm0P36a/H20<;2`P80]kNg0P30`<020;Ng]`80];Bd0P2g]kL20;Bd]080[jn_
0P2d];@20:n_[`80];Bd1P2_[jl20;Fe]@80];Bd0P2^[Zh20:RXZ080YJFU0P2^[Zh40:FUY@80Y:BT
0P2LW9`208j>SP80W9bL0P2FUYH208>3P`<0N7Qh0P1lO7`407=cL`80GemO101_Kfl205UIF@80J6QX
0P1fMWH609FEU@80W9bL1026QXH407alO080TI6A0P2IVIT208j>SP80[:b/0P2a/K420:FUY@80VIVI
0P2a/K420;Fe]@80Y:BT0P2d];@40<;2`P80f][J0`3Shn<20>SXj080gmoO0P3Xj>P20>k^kPH0l_;b
0P3gmoL20?;blPH0moOg103bl_820?Ogm`80l_;b3`3oool000d0oooo1P3gmoL20?;blP@0moOg0P3b
l_860?Ogm`80l_;b4`3gmoL20?;blP80moOg103bl_820?Ogm`@0l?3`103gmoL20>SXj080a<C4102T
Y:@2096AT@80O7al101cLg<2055AD@80J6QX0P1IFET204U9B@80;Bd]0P0k>c/202d];@/0`l?30P2m
_Kd20<K6aP80`/;20P2g]kL20<30`080]kNg0P2d];@20;Ng]`80];Bd0P2_[jl20;Bd]080[jn_0P2d
];@60:n_[`80]KFe0P2d];@20:j^[P80Z:RX0P2UYJD20:j^[P@0YJFU0P2TY:@209bLW080SXj>0P2L
W9`209JFUP80Ph>30`1hN7P207alO0@0Lg=c0P1OGel406m_K`80FEUI0P1XJ6P207IfMPH0UIFE0P2L
W9`408J6QP@0O7al0P2ATI4209VIV@80SXj>0P2/[:`20;6a/@80YJFU0P2IVIT20;6a/@80]KFe0P2T
Y:@20;Bd]0@0`/;20P3Jf]X30>?Sh`80j>SX0P3Ogml20>SXj080k^k^1P3bl_820?Ogm`80l_;b1P3g
moL40?;blP80moOg0P3bl_8?0?ooo`003@3oool80?Ogm`@0l_;b0P3gmoL20?;blP80l?3`203gmoL2
0?;blP/0moOg0P3bl_840?Ogm`80l_;b0P3^k^h20?;blP80k^k^0P3gmoL20?;blP@0l?3`0P2`/;02
0:BTY080U9BD0P2>SXh206QXJ080Kfm_0P1OGel205MGE`80J6QX0P1GEeL204I6AP80>c/k0P16ATH2
03De=@80a<C40P2f][H20<?3``<0_Kfm0P33`l<20;fm_@80]kNg0P32`/860;Ng]`80];Bd1P2_[jl2
0:NWY`80Z:RX0P2^[Zh40:RXZ080[jn_102^[Zh20:BTY080YjNW202TY:@409JFUP80SXj>0P2LW9`2
08j>SP80O7al0`1cLg<406i^KP80IVIV0P1cLg<206m_K`@0GemO0P1XJ6P207EeM@80QHF50P2EUID2
08j>SP80UIFE0P2>SXh2096AT@@0O7al0P1fMWH208j>SP80Y:BT0P2UYJD20:BTY0@0/[:b0P2a/K42
09bLW080Y:BT0P2d];@20<?3``80c<c<0P3Ph>030=oOg`80j>SX0P3`l?020>k^kP80j>SX0P3bl_82
0?Ogm`80l_;b2P3gmoL20?;blP@0moOg0P3bl_8?0?ooo`003@3oool80?Ogm`@0l_;b0P3gmoL20?;b
lP80l?3`203gmoL20?;blP/0moOg0P3bl_840?Ogm`80l_;b0P3^k^h20?;blP80k^k^0P3gmoL20?;b
lP@0l?3`0P2`/;020:BTY080U9BD0P2>SXh206QXJ080Kfm_0P1OGel205MGE`80J6QX0P1GEeL204I6
AP80>c/k0P16ATH203De=@80a<C40P2f][H20<?3``<0_Kfm0P33`l<20;fm_@80]kNg0P32`/860;Ng
]`80];Bd1P2_[jl20:NWY`80Z:RX0P2^[Zh40:RXZ080[jn_102^[Zh20:BTY080YjNW202TY:@409JF
UP80SXj>0P2LW9`208j>SP80O7al0`1cLg<406i^KP80IVIV0P1cLg<206m_K`@0GemO0P1XJ6P207Ee
M@80QHF50P2EUID208j>SP80UIFE0P2>SXh2096AT@@0O7al0P1fMWH208j>SP80Y:BT0P2UYJD20:BT
Y0@0/[:b0P2a/K4209bLW080Y:BT0P2d];@20<?3``80c<c<0P3Ph>030=oOg`80j>SX0P3`l?020>k^
kP80j>SX0P3bl_820?Ogm`80l_;b2P3gmoL20?;blP@0moOg0P3bl_8?0?ooo`003@3oool20?Ogm`@0
l_;b0P3gmoL40?;blPH0moOg0P3bl_820?3`l0@0moOg0P3bl_850?Ogm`@0l_;b103`l?020?Ogm`@0
l_;b103gmoL20?;blP80moOg0P3^k^h20?3`l080f=SH0P2b/[820:BTY080SXj>0P23Ph<207=cL`80
O7al0P1IFET406QXJ080GemO0P0a<C4202d];@80=CDe0P0k>c/20<?3``80]KFe0P2n_[h30;Fe]@@0
_Kfm1P2g]kL20:n_[`80];Bd0P2^[Zh20:RXZ080[Zj^102XZ:P20:NWY`H0W9bL102TY:@20:RXZ0@0
Y:BT1P2LW9`409JFUP80Shn?0P2ATI4207alO080Lg=c0P1bLW8306QXJ080KVi^101cLg<606QXJ080
K6a/0P1eMGD207IfMP80QHF50P2EUID20:f][@80Y:BT0P2d];@209BDU0@0LW9b0P1lO7`209BDU080
SXj>0P2TY:@60;6a/@H0Vi^K0P32`/820<_;b`80c<c<0P3Ogml30>SXj080h>3P0P3^k^h20>SXj080
moOg0P3bl_880?Ogm`80l_;b1P3gmoL20?3`l080moOg0P3bl_8?0?ooo`003@3oool20?Ogm`@0l_;b
0P3gmoL40?;blPH0moOg0P3bl_820?3`l0@0moOg0P3bl_850?Ogm`@0l_;b103`l?020?Ogm`@0l_;b
103gmoL20?;blP80moOg0P3^k^h20?3`l080f=SH0P2b/[820:BTY080SXj>0P23Ph<207=cL`80O7al
0P1IFET406QXJ080GemO0P0a<C4202d];@80=CDe0P0k>c/20<?3``80]KFe0P2n_[h30;Fe]@@0_Kfm
1P2g]kL20:n_[`80];Bd0P2^[Zh20:RXZ080[Zj^102XZ:P20:NWY`H0W9bL102TY:@20:RXZ0@0Y:BT
1P2LW9`409JFUP80Shn?0P2ATI4207alO080Lg=c0P1bLW8306QXJ080KVi^101cLg<606QXJ080K6a/
0P1eMGD207IfMP80QHF50P2EUID20:f][@80Y:BT0P2d];@209BDU0@0LW9b0P1lO7`209BDU080SXj>
0P2TY:@60;6a/@H0Vi^K0P32`/820<_;b`80c<c<0P3Ogml30>SXj080h>3P0P3^k^h20>SXj080moOg
0P3bl_880?Ogm`80l_;b1P3gmoL20?3`l080moOg0P3bl_8?0?ooo`003@3oool20?;blP@0moOg103b
l_860?3`l080l_;b1P3gmoL20?3`l080moOg0P3bl_830?Ogm`80l_;b0P3gmoL20?3`l0X0moOg0P3b
l_820?3`l080l_;b103`l?020<C4a080/K6a0P2IVIT2096AT@80O7al0P1XJ6P206m_K`80GemO0P1b
LW82055AD@80BDU9100X:2P403De=@80`l?30P2e]KD20;fm_@<0_[jn0P2m_Kd40;Ng]`80[jn_202^
[Zh20:NWY`80YJFU0P2TY:@20:NWY`@0Y:BT202LW9`40:BTY0H0W9bL102?Shl208j>SP80Ph>30P2>
SXh207IfMP80J6QX0P1OGel307=cL`80J6QX101cLg<404I6AP80DE5A0P1_Kfl608F5Q@80SXj>0P2K
Vi/20:BTY080W9bL0P2a/K42096AT@80O7al102>SXh209bLW080SXj>102b/[8209bLW080Vi^K0P2L
W9`209^KV`80`/;20P3;bl/20>SXj080gmoO1@3Xj>P20>WYj@80l?3`0P3gmoL20>k^kP80l?3`103g
moL20?;blPH0moOg0P3bl_860?Ogm`l0oooo000=0?ooo`80l_;b103gmoL40?;blPH0l?3`0P3bl_86
0?Ogm`80l?3`0P3gmoL20?;blP<0moOg0P3bl_820?Ogm`80l?3`2P3gmoL20?;blP80l?3`0P3bl_84
0?3`l080a<C40P2a/K4209VIV@80TI6A0P1lO7`206QXJ080Kfm_0P1OGel2079bLP80DE5A0P19BDT4
02PX:0@0=CDe0P33`l<20;Fe]@80_Kfm0`2n_[h20;fm_@@0]kNg0P2_[jl80:j^[P80YjNW0P2UYJD2
0:BTY080YjNW102TY:@809bLW0@0Y:BT1P2LW9`408n?S`80SXj>0P23Ph<208j>SP80MWIf0P1XJ6P2
05mOG`<0Lg=c0P1XJ6P407=cL`@0ATI60P1ADE4206m_K`H0QHF50P2>SXh209^KV`80Y:BT0P2LW9`2
0;6a/@80TI6A0P1lO7`408j>SP80W9bL0P2>SXh40;:b/P80W9bL0P2KVi/209bLW080Vi^K0P32`/82
0<_;b`80j>SX0P3Ogml50>SXj080jNWY0P3`l?020?Ogm`80k^k^0P3`l?040?Ogm`80l_;b1P3gmoL2
0?;blPH0moOg3`3oool000d0oooo203gmoL20?;blQ00moOg0P3`l?020?;blP<0moOg0P3`l?020?Og
m`80l_;b0P3gmoL20?;blP80moOg0P3bl_820?3`l080l_;b0P3gmoL20>k^kP80l_;b0P3Ogml20;Zj
^P80/K6a0P2ATI4208>3P`80Lg=c0P1_Kfl405mOG`80J6QX0P1ADE4203lo?`80=CDe100k>c/203lo
?`T0]KFe0P2g]kL20;Fe]@80[jn_0P2e]KD40:n_[`80YJFU102WYjL609bLW080T92@102FUYH2092@
T0@0W9bL0P2@T90609bLW080Shn?0P2>SXh208n?S`80SXj>0P1lO7`209FEU@80Lg=c0P1ADE4506m_
K`80J6QX0P1OGel204U9B@80ATI60P0];Bd206a/K080QHF50P1_Kfl208F5Q@80MWIf0P26QXH209^K
V`80[Jf]0P2UYJD20;Bd]0@0TI6A0P2KVi/2096AT@80W9bL0P2IVIT20;6a/@@0W9bL0P2>SXh209FE
U@80];Bd0P3;bl/20=[JfP@0h>3P0`3Ogml20>k^kP@0l?3`0P3gmoL40?;blPH0moOg0P3`l?020?Og
m`80l_;b0P3gmoL20?;blP@0moOg3`3oool000d0oooo203gmoL20?;blQ00moOg0P3`l?020?;blP<0
moOg0P3`l?020?Ogm`80l_;b0P3gmoL20?;blP80moOg0P3bl_820?3`l080l_;b0P3gmoL20>k^kP80
l_;b0P3Ogml20;Zj^P80/K6a0P2ATI4208>3P`80Lg=c0P1_Kfl405mOG`80J6QX0P1ADE4203lo?`80
=CDe100k>c/203lo?`T0]KFe0P2g]kL20;Fe]@80[jn_0P2e]KD40:n_[`80YJFU102WYjL609bLW080
T92@102FUYH2092@T0@0W9bL0P2@T90609bLW080Shn?0P2>SXh208n?S`80SXj>0P1lO7`209FEU@80
Lg=c0P1ADE4506m_K`80J6QX0P1OGel204U9B@80ATI60P0];Bd206a/K080QHF50P1_Kfl208F5Q@80
MWIf0P26QXH209^KV`80[Jf]0P2UYJD20;Bd]0@0TI6A0P2KVi/2096AT@80W9bL0P2IVIT20;6a/@@0
W9bL0P2>SXh209FEU@80];Bd0P3;bl/20=[JfP@0h>3P0`3Ogml20>k^kP@0l?3`0P3gmoL40?;blPH0
moOg0P3`l?020?Ogm`80l_;b0P3gmoL20?;blP@0moOg3`3oool000d0oooo103gmoL20?;blP80moOg
103bl_820?3`l0@0l_;b0P3gmoL20?;blP/0moOg103`l?020?;blP80l?3`103gmoL20?;blP@0moOg
0P3`l?020?;blP80k^k^0P3<c<`20;:b/P80XJ6Q1023Ph<206m_K`80KVi^0P1XJ6P405mOG`@0>c/k
0P0e=CD603/k>`H0]KFe0`34a<@40;Rh^080/k>c0P2h^;P40;>c/`80]KFe102_[jl20:FUY@80UYJF
0P2>SXh209JFUP80R8R8202>SXh409JFUPH0SXj>1023Ph<207QhN080O7al0P2>SXh206QXJ080C4a<
0P1XJ6P307=cL`80DE5A0P16ATH203lo?`80C4a<0P1IFET206MWI`@0QHF50P1lO7`208F5Q@80LW9b
0P2KVi/20:BTY080/K6a0P2LW9`209VIV@80SXj>102DU9@2096AT@@0/K6a0P2KVi/20:BTY080Vi^K
102a/K420<W9b@80l?3`0P3Jf]X20=oOg`<0k^k^0P3YjNT80?Ogm`80l_;b3P3gmoL20?;blP80moOg
0P3bl_8?0?ooo`003@3oool40?Ogm`80l_;b0P3gmoL40?;blP80l?3`103bl_820?Ogm`80l_;b2`3g
moL40?3`l080l_;b0P3`l?040?Ogm`80l_;b103gmoL20?3`l080l_;b0P3^k^h20<c<c080/[:b0P2Q
XJ4408>3P`80Kfm_0P1^KVh206QXJ0@0GemO100k>c/203De=@H0>c/k1P2e]KD30<C4a0@0^;Rh0P2c
/k<20;Rh^0@0/k>c0P2e]KD40:n_[`80YJFU0P2FUYH208j>SP80UYJF0P28R8P808j>SP@0UYJF1P2>
SXh408>3P`80N7Qh0P1lO7`208j>SP80J6QX0P1<C4`206QXJ0<0Lg=c0P1ADE4204I6AP80?clo0P1<
C4`205UIF@80IfMW1025QHD207alO080QHF50P1bLW8209^KV`80Y:BT0P2a/K4209bLW080VIVI0P2>
SXh409BDU080TI6A102a/K4209^KV`80Y:BT0P2KVi/40;6a/@80bLW90P3`l?020=[JfP80gmoO0`3^
k^h20>WYj@P0moOg0P3bl_8>0?Ogm`80l_;b0P3gmoL20?;blPl0oooo000=0?ooo`80l_;b103gmoL4
0>k^kP80moOg0P3bl_840?Ogm`@0l_;b103gmoL20?3`l080moOg0`3bl_820?Ogm`80l?3`0P3bl_82
0?3`l0@0moOg103bl_860?3`l080j>SX0P39bLT20;6a/@80VIVI0P23Ph<207alO080Lg=c0P1XJ6P2
07alO080EeMG0P1OGel2028R8P80A4A4100k>c/203De=@80EEEE0P2e]KD20<_;b`L0cLg=103<c<`6
0<71`@80^KVi102h^;P20;Fe]@80[jn_0P2UYJD408R8R080QXJ61028R8P608>3P`80SXj>0P28R8P2
08>3P`80QXJ60P1lO7`407=cL`80QXJ60P1ADE42059BDP80J6QX0`1NGUh204U9B@80=CDe0P0k>c/2
06a/K080BDU90P1XJ6P208J6QP80QHF50P1lO7`2079bLP80O7al0P2EUID20:FUY@80];Bd0P2e]KD2
0;6a/@@0VIVI0P23Ph<207IfMP@0/K6a0P2IVIT209bLW0@0/K6a0P33`l<20>k^kPH0j>SX0`3^k^h2
0?3`l080l_;b0P3gmoL20?;blPP0moOg0P3bl_8:0?Ogm`80l_;b0P3`l?0?0?ooo`003@3oool20?;b
lP@0moOg103^k^h20?Ogm`80l_;b103gmoL40?;blP@0moOg0P3`l?020?Ogm`<0l_;b0P3gmoL20?3`
l080l_;b0P3`l?040?Ogm`@0l_;b1P3`l?020>SXj080bLW90P2a/K4209VIV@80Ph>30P1lO7`207=c
L`80J6QX0P1lO7`205MGE`80GemO0P0R8R8204A4A0@0>c/k0P0e=CD205EEE@80]KFe0P3;bl/70<g=
c@@0c<c<1P31`L420;Vi^@@0^;Rh0P2e]KD20:n_[`80YJFU1028R8P208J6QP@0R8R81P23Ph<208j>
SP80R8R80P23Ph<208J6QP80O7al101cLg<208J6QP80DE5A0P1BDU8206QXJ0<0GUiN0P19BDT203De
=@80>c/k0P1/K6`204U9B@80J6QX0P26QXH208F5Q@80O7al0P1bLW8207alO080UIFE0P2UYJD20;Bd
]080]KFe0P2a/K4409VIV@80Ph>30P1fMWH40;6a/@80VIVI0P2LW9`40;6a/@80`l?30P3^k^h60>SX
j0<0k^k^0P3`l?020?;blP80moOg0P3bl_880?Ogm`80l_;b2P3gmoL20?;blP80l?3`3`3oool000d0
oooo0P3gmoL40?;blPH0moOg0P3bl_8<0?Ogm`80l_;b1@3gmoL20?;blP@0moOg0P3^k^h20?Ogm`80
l_;b0P3gmoL40?3`l0@0l_;b0P3Bd]820;Zj^P80Y:BT0P2DU9@208>3P`80NWYj0P1OGel206QXJ080
GemO0P1XJ6P204U9B@80;Bd]0P16ATH204A4A080>c/k0P0e=CD208V9R@80cLg=0P3>c/h20=cLg0D0
dM7A103=cLd20=7Ad@@0cLg=1031`L420;jn_P80^;Rh0P2e]KD20:n_[`80Z:RX0P2LW9`208J6QP80
O7al0P23Ph<408J6QP80R8R80P1hN7P208>3P`80QXJ60P23Ph<207alO080Lg=c0P1VIVH207alO080
GemO0P1XJ6P207alO0<0BDU90P0o?cl203De=@80BTY:0P1eMGD204];B`80J6QX0P1fMWH208J6QP80
MGEe0P1bLW8207alO080SXj>0P2EUID20;Bd]080]KFe0P2a/K420:BTY080VIVI0P1lO7`2096AT@P0
Y:BT0P32`/820:BTY080`l?30P3^k^h20>3Ph080f=SH0P3Zj^X30>WYj@80moOg0P3bl_820?Ogm`80
l?3`0P3bl_820?3`l0@0l_;b103gmoL20?;blPX0moOg3`3oool000d0oooo0P3gmoL40?;blPH0moOg
0P3bl_8<0?Ogm`80l_;b1@3gmoL20?;blP@0moOg0P3^k^h20?Ogm`80l_;b0P3gmoL40?3`l0@0l_;b
0P3Bd]820;Zj^P80Y:BT0P2DU9@208>3P`80NWYj0P1OGel206QXJ080GemO0P1XJ6P204U9B@80;Bd]
0P16ATH204A4A080>c/k0P0e=CD208V9R@80cLg=0P3>c/h20=cLg0D0dM7A103=cLd20=7Ad@@0cLg=
1031`L420;jn_P80^;Rh0P2e]KD20:n_[`80Z:RX0P2LW9`208J6QP80O7al0P23Ph<408J6QP80R8R8
0P1hN7P208>3P`80QXJ60P23Ph<207alO080Lg=c0P1VIVH207alO080GemO0P1XJ6P207alO0<0BDU9
0P0o?cl203De=@80BTY:0P1eMGD204];B`80J6QX0P1fMWH208J6QP80MGEe0P1bLW8207alO080SXj>
0P2EUID20;Bd]080]KFe0P2a/K420:BTY080VIVI0P1lO7`2096AT@P0Y:BT0P32`/820:BTY080`l?3
0P3^k^h20>3Ph080f=SH0P3Zj^X30>WYj@80moOg0P3bl_820?Ogm`80l?3`0P3bl_820?3`l0@0l_;b
103gmoL20?;blPX0moOg3`3oool000d0oooo0P3bl_820?Ogm`80l?3`0P3gmoL20?;blP80l?3`0P3g
moL20?3`l0P0moOg0P3bl_820?3`l080moOg1@3bl_820?Ogm`@0l_;b0P3gmoL20?;blPH0l?3`103b
l_820=;BdP80/;2`0P2IVIT2096AT@80NWYj101cLg<206QXJ080GemO0P1XJ6P202d];@80>c/k0P1<
C4`403/k>`80T92@0P3>c/h20=KFeP80g=cL0P3Fe]H30=cLg080dM7A0P3Lg=`20=7Ad@80e]KF0P3A
dM420<g=c@80c<c<0P3=cLd40<71`@80^;Rh0P2g]kL20:n_[`80[Zj^0P2TY:@209bLW0P0O7al0P26
QXH207alO080Ph>30P1lO7`206i^KP80Kfm_0P1FEUH204U9B@80O7al0P1OGel208j>SP<0?clo0P0e
=CD2028R8P80;Bd]0P1bLW8207IfMP80FEUI0P1fMWH209FEU@80LW9b0P2ATI4207alO080SXj>0P2T
Y:@20;Bd]080`/;20P34a<@20;:b/P80MWIf102ATI4209bLW080U9BD0P2TY:@20;:b/P80/K6a0P2^
[Zh20>WYj@80h>3P0P3De=@20>SXj080l?3`0`3bl_840?Ogm`80l?3`203gmoL40?;blPP0moOg0P3b
l_840?Ogm`l0oooo000=0?ooo`80l_;b0P3gmoL20?3`l080moOg0P3bl_820?3`l080moOg0P3`l?08
0?Ogm`80l_;b0P3`l?020?Ogm`D0l_;b0P3gmoL40?;blP80moOg0P3bl_860?3`l0@0l_;b0P3Bd]82
0;2`/080VIVI0P2ATI4207YjNP@0Lg=c0P1XJ6P205mOG`80J6QX0P0];Bd203/k>`80C4a<100k>c/2
092@T080c/k>0P3Fe]H20=cLg080e]KF0`3Lg=`20=7Ad@80g=cL0P3AdM420=KFeP80dM7A0P3=cLd2
0<c<c080cLg=1031`L420;Rh^080]kNg0P2_[jl20:j^[P80Y:BT0P2LW9`807alO080QXJ60P1lO7`2
08>3P`80O7al0P1^KVh206m_K`80EUIF0P19BDT207alO080GemO0P2>SXh303lo?`80=CDe0P0R8R82
02d];@80LW9b0P1fMWH205UIF@80MWIf0P2EUID2079bLP80TI6A0P1lO7`208j>SP80Y:BT0P2d];@2
0<;2`P80a<C40P2b/[8207IfMP@0TI6A0P2LW9`209BDU080Y:BT0P2b/[820;6a/@80[Zj^0P3YjNT2
0>3Ph080e=CD0P3Xj>P20?3`l0<0l_;b103gmoL20?3`l0P0moOg103bl_880?Ogm`80l_;b103gmoL?
0?ooo`003@3oool20?Ogm`80l_;b2P3gmoL20?3`l080l_;b0P3`l?060?Ogm`80l?3`0P3bl_830?Og
m`P0l_;b203gmoL20?3`l080jNWY0P3Hf=P20<_;b`80XJ6Q0P2IVIT208>3P`80Kfm_0P1OGel406QX
J080GemO0P1?Cdl202d];@@0C4a<0P0k>c/20<c<c080e]KF0P3Bd]820=KFeP@0g=cL0`3Jf]X20=cL
g080f][J1P3AdM420=KFeP80cLg=1P3<c<`20<?3``@0]KFe0P2g]kL20:n_[`80YJFU0P2LW9`207Qh
N0@0Lg=c0P1lO7`207=cL`80N7Qh0P1cLg<206i^KP80J6QX0P19BDT204I6AP80SXj>0P19BDT209JF
UP<0J6QX0P0k>c/204Y:BP808R8R0P19BDT208J6QP80Bd];0P1fMWH208J6QP80MGEe1P2>SXh209^K
V`80Y:BT0P33`l<20<C4a080/K6a0P2DU9@208>3P`80TI6A102IVIT20;6a/@80/[:b0P2a/K420<;2
`P80gmoO0P3IfMT20=oOg`@0k^k^0`3gmoL20?3`l080moOg0P3bl_840?Ogm`@0l_;b0P3gmoL40?;b
lP`0moOg3`3oool000d0oooo0P3gmoL20?;blPX0moOg0P3`l?020?;blP80l?3`1P3gmoL20?3`l080
l_;b0`3gmoL80?;blPP0moOg0P3`l?020>WYj@80f=SH0P3;bl/20:6QX@80VIVI0P23Ph<206m_K`80
GemO101XJ6P205mOG`80Cdm?0P0];Bd404a<C080>c/k0P3<c<`20=KFeP80d];B0P3Fe]H40=cLg0<0
f][J0P3Lg=`20=[JfPH0dM7A0P3Fe]H20<g=c@H0c<c<0P33`l<40;Fe]@80]kNg0P2_[jl20:FUY@80
W9bL0P1hN7P407=cL`80O7al0P1cLg<207QhN080Lg=c0P1^KVh206QXJ080BDU90P16ATH208j>SP80
BDU90P2FUYH306QXJ080>c/k0P1:BTX2028R8P80BDU90P26QXH204];B`80MWIf0P26QXH207EeM@H0
SXj>0P2KVi/20:BTY080`l?30P34a<@20;6a/@80U9BD0P23Ph<2096AT@@0VIVI0P2a/K420;:b/P80
/K6a0P32`/820=oOg`80fMWI0P3Ogml40>k^kP<0moOg0P3`l?020?Ogm`80l_;b103gmoL40?;blP80
moOg103bl_8<0?Ogm`l0oooo000=0?ooo`P0moOg0P3`l?0>0?Ogm`80l?3`0P3bl_820?3`l0D0moOg
0P3bl_8:0?Ogm`80l_;b0P3^k^h20>WYj@80clo?0P30`<0209RHV080TI6A0P23Ph<207=cL`80IVIV
0P1XJ6P405mOG`80>c/k0P0e=CD204I6AP80>c/k0P25QHD20=?Cd`80e]KF0P3=cLd40=KFePT0g=cL
0P3Jf]X20=cLg0@0dM7A1P3=cLd20<C4a080_[jn0P33`l<20;fm_@80]kNg0P2e]KD20:n_[`80YJFU
0P2@T90209bLW0@0KVi^0P1cLg<206m_K`80KVi^0P1VIVH205MGE`80D51@0P14A4@208J6QP80NWYj
0P23Ph<307alO080=CDe0P0R8R8204I6AP80J6QX0P26QXH208j>SP@0QXJ60P2>SXh207=cL`80U9BD
0P2ATI4209VIV@80Y:BT0P2a/K420<?3``80`/;20P2ATI4207alO080TI6A0P26QXH209VIV@80^[Zj
0P32`/820;Ng]`80/[:b0P3;bl/20>SXj0@0l?3`0P3bl_830?Ogm`80l_;b0P3gmoL20?;blP80moOg
103bl_880?Ogm`80l_;b1P3gmoL20?;blP80moOg3`3oool000d0oooo203gmoL20?3`l0h0moOg0P3`
l?020?;blP80l?3`1@3gmoL20?;blPX0moOg0P3bl_820>k^kP80jNWY0P3?cll20<30`080V9RH0P2A
TI4208>3P`80Lg=c0P1VIVH206QXJ0@0GemO0P0k>c/203De=@80ATI60P0k>c/208F5Q@80dm?C0P3F
e]H20<g=c@@0e]KF2@3Lg=`20=[JfP80g=cL103AdM460<g=c@80a<C40P2n_[h20<?3``80_Kfm0P2g
]kL20;Fe]@80[jn_0P2UYJD2092@T080W9bL101^KVh207=cL`80Kfm_0P1^KVh206IVIP80EeMG0P1@
D50204A4A080QXJ60P1jNWX208>3P`<0O7al0P0e=CD2028R8P80ATI60P1XJ6P208J6QP80SXj>1026
QXH208j>SP80Lg=c0P2DU9@2096AT@80VIVI0P2TY:@20;6a/@80`l?30P32`/82096AT@80O7al0P2A
TI4208J6QP80VIVI0P2j^[X20<;2`P80]kNg0P2b/[820<_;b`80j>SX103`l?020?;blP<0moOg0P3b
l_820?Ogm`80l_;b0P3gmoL40?;blPP0moOg0P3bl_860?Ogm`80l_;b0P3gmoL?0?ooo`003@3oool2
0?3`l080moOg0P3bl_860?Ogm`80l?3`0P3gmoL40?;blP80moOg1P3bl_820?3`l0<0moOg103bl_82
0?3`l0@0moOg0P3^k^h20?Ogm`80l?3`0P3^k^h20=oOg`80clo?0P2`/;0209RHV080TI6A0P1lO7`2
06m_K`80EUIF0P1OGel2055AD@80GemO0P0X:2P203/k>`80A4A40P1NGUh20<g=c@80c/k>203Fe]H2
0=cLg0<0dM7A0P3Lg=`40=7Ad@80g=cL103AdM420<g=c@80c<c<103=cLd20<c<c0@0_[jn0P2m_Kd4
0;Fe]@80[jn_0P2UYJD209bLW080T92@0P1XJ6P406i^KP80HF5Q0P1XJ6P204m?C`80C4a<0P0];Bd2
06m_K`80YJFU0P1ADE4309bLW080IVIV0P1cLg<203De=@80K6a/0P1BDU82096AT@80K6a/0P25QHD2
08J6QP80TI6A0P29RHT209VIV@80Ph>30P2a/K4209^KV`80a<C40P3Cdm<2096AT@80O7al0P2ATI42
09BDU080XJ6Q0P2TY:@20;6a/@80/[:b0P32`/820=oOg`80j>SX0P3YjNT20?3`l080k^k^0`3bl_82
0?Ogm`80l_;b103gmoL40?;blP80moOg103bl_820?Ogm`@0l_;b0P3gmoL20?;blP@0moOg3`3oool0
00d0oooo0P3`l?020?Ogm`80l_;b1P3gmoL20?3`l080moOg103bl_820?Ogm`H0l_;b0P3`l?030?Og
m`@0l_;b0P3`l?040?Ogm`80k^k^0P3gmoL20?3`l080k^k^0P3Ogml20<o?c`80/;2`0P2HV9P2096A
T@80O7al0P1_Kfl205IFEP80GemO0P1ADE4205mOG`80:2PX0P0k>c/204A4A080GUiN0P3=cLd20<k>
cPP0e]KF0P3Lg=`30=7Ad@80g=cL103AdM420=cLg0@0dM7A0P3=cLd20<c<c0@0cLg=0P3<c<`40;jn
_P80_Kfm102e]KD20:n_[`80YJFU0P2LW9`2092@T080J6QX101^KVh2065QH@80J6QX0P1?Cdl204a<
C080;Bd]0P1_Kfl20:FUY@80DE5A0`2LW9`206IVIP80Lg=c0P0e=CD206a/K080DU9B0P2ATI4206a/
K080QHF50P26QXH2096AT@80RHV90P2IVIT208>3P`80/K6a0P2KVi/20<C4a080dm?C0P2ATI4207al
O080TI6A0P2DU9@20:6QX@80Y:BT0P2a/K420;:b/P80`/;20P3Ogml20>SXj080jNWY0P3`l?020>k^
kP<0l_;b0P3gmoL20?;blP@0moOg103bl_820?Ogm`@0l_;b0P3gmoL40?;blP80moOg0P3bl_840?Og
m`l0oooo000=0?ooo`80l_;b0P3gmoL20?;blPH0moOg103bl_880?Ogm`@0l_;b0P3gmoL30?;blP`0
moOg0P3bl_840>WYj@80d];B0P3?cll20:6QX@80U9BD0P1jNWX207alO080IVIV101OGel205EEE@80
>c/k0P0e=CD204m?C`80G5aL0P3>c/h20<g=c@80d];B1P3Fe]H20=7Ad@80d];B2`3=cLd20<c<c0@0
`L710P34a<@20<c<c080`l?30P36a/H40;jn_P80]KFe0P2g]kL40;Fe]@80[jn_0P2TY:@209bLW080
UYJF0P1XJ6P205MGE`80J6QX0P1BDU82055AD@@0>c/k0P1FEUH2096AT@80Ph>30`1_Kfl20:6QX@80
Bd];0P23Ph<205mOG`80KVi^0P1fMWH208J6QP80LW9b0P26QXH2096AT@80J6QX102ATI440:BTY080
/;2`0P2e]KD20<;2`P80TI6A0P1fMWH2096AT@80XJ6Q0P2IVIT20;6a/@80`/;20P3IfMT20>k^kP80
gmoO0P3^k^h20?3`l080k^k^0`3gmoL40?;blP80moOg0P3bl_840?Ogm`80l_;b0P3gmoL20?;blPH0
moOg0P3bl_860?Ogm`l0oooo000=0?ooo`80l_;b0P3gmoL20?;blPH0moOg103bl_880?Ogm`@0l_;b
0P3gmoL30?;blP`0moOg0P3bl_840>WYj@80d];B0P3?cll20:6QX@80U9BD0P1jNWX207alO080IVIV
101OGel205EEE@80>c/k0P0e=CD204m?C`80G5aL0P3>c/h20<g=c@80d];B1P3Fe]H20=7Ad@80d];B
2`3=cLd20<c<c0@0`L710P34a<@20<c<c080`l?30P36a/H40;jn_P80]KFe0P2g]kL40;Fe]@80[jn_
0P2TY:@209bLW080UYJF0P1XJ6P205MGE`80J6QX0P1BDU82055AD@@0>c/k0P1FEUH2096AT@80Ph>3
0`1_Kfl20:6QX@80Bd];0P23Ph<205mOG`80KVi^0P1fMWH208J6QP80LW9b0P26QXH2096AT@80J6QX
102ATI440:BTY080/;2`0P2e]KD20<;2`P80TI6A0P1fMWH2096AT@80XJ6Q0P2IVIT20;6a/@80`/;2
0P3IfMT20>k^kP80gmoO0P3^k^h20?3`l080k^k^0`3gmoL40?;blP80moOg0P3bl_840?Ogm`80l_;b
0P3gmoL20?;blPH0moOg0P3bl_860?Ogm`l0oooo000=0?ooo`@0moOg0P3bl_860?Ogm`80l_;b0P3g
moL80?;blP@0moOg0P3bl_830?Ogm`80l_;b103`l?040?;blP@0moOg0P3YjNT20=WIf@80d];B0P2g
]kL209RHV080Ph>30P1jNWX206IVIPH0GemO0P0a<C4203/k>`@0=CDe103>c/h20=KFeP80d];B103=
cLd20=7Ad@80cLg=0P36a/H30;jn_P@0^;Rh1P2e]KD20:n_[`P0]KFe1P2m_Kd20;jn_P80_Kfm102e
]KD20:n_[`80Z:RX0P2UYJD20:BTY080UYJF0P1hN7P205mOG`80EEEE0P1@D50204A4A080>c/k0P1:
BTX206IVIP80W9bL0`2ATI4207emO@80Y:BT0P26QXH208>3P`80BDU90P1bLW8208j>SP80QHF50P26
QXH2079bLP@0Ph>30P2UYJD209VIV@80Y:BT0P2a/K420<C4a080c<c<0P2ATI4209VIV@80YJFU0P2I
VIT209BDU080/;2`0P33`l<20?3`l080gmoO0P3bl_820>k^kP80l?3`0P3^k^h50?Ogm`80l_;b0P3g
moL20?3`l080l_;b0P3gmoL40?;blPh0moOg0P3bl_8?0?ooo`003@3oool40?Ogm`80l_;b1P3gmoL2
0?;blP80moOg203bl_840?Ogm`80l_;b0`3gmoL20?;blP@0l?3`103bl_840?Ogm`80jNWY0P3IfMT2
0=;BdP80]kNg0P2HV9P208>3P`80NWYj0P1VIVH605mOG`80<C4a0P0k>c/403De=@@0c/k>0P3Fe]H2
0=;BdP@0cLg=0P3AdM420<g=c@80a/K60`2n_[h40;Rh^0H0]KFe0P2_[jl80;Fe]@H0_Kfm0P2n_[h2
0;fm_@@0]KFe0P2_[jl20:RXZ080YJFU0P2TY:@209JFUP80N7Qh0P1OGel205EEE@80D51@0P14A4@2
03/k>`80BTY:0P1VIVH209bLW0<0TI6A0P1mOGd20:BTY080QXJ60P23Ph<204U9B@80LW9b0P2>SXh2
08F5Q@80QXJ60P1bLW8408>3P`80YJFU0P2IVIT20:BTY080/K6a0P34a<@20<c<c080TI6A0P2IVIT2
0:FUY@80VIVI0P2DU9@20;2`/080`l?30P3`l?020=oOg`80l_;b0P3^k^h20?3`l080k^k^1@3gmoL2
0?;blP80moOg0P3`l?020?;blP80moOg103bl_8>0?Ogm`80l_;b3`3oool000d0oooo0P3gmoL20?;b
lPH0moOg0P3bl_880?Ogm`80l_;b2`3gmoL60?;blP@0moOg103bl_820>WYj@80f=SH0P3?cll20;:b
/P80VIVI101lO7`206i^KP80DU9B0P1OGel205EEE@80=CDe0P0k>c/204m?C`80c<c<103Cdm<20=KF
eP80d];B103=cLd20<c<c080a<C40P2h^;P30;Ng]`80[jn_0P2XZ:P:0:6QX@80[jn_0P2XZ:P20:n_
[`80]KFe0P2_[jl40;fm_@80_[jn102e]KD20:n_[`80[:b/0P2UYJD409bLW080Shn?0P1NGUh204Y:
BP80C4a<0P0k>c/202PX:080>c/k0P1UIFD209bLW0<0NWYj0P1OGel20:b/[080QXJ60P2KVi/208>3
P`80J6QX0P1cLg<209FEU@80QXJ60P1lO7`2096AT@80Ph>30P2TY:@209VIV@80/K6a0P2TY:@20;6a
/@80bl_;0P2a/K420:BTY0@0XJ6Q0P2TY:@20;:b/P80a<C4103Xj>P20?3`l080k^k^0P3bl_820?Og
m`<0l_;b103gmoL20?3`l0H0moOg0P3bl_840?Ogm`80l_;b303gmoL?0?ooo`003@3oool20?Ogm`80
l_;b1P3gmoL20?;blPP0moOg0P3bl_8;0?Ogm`H0l_;b103gmoL40?;blP80jNWY0P3Hf=P20<o?c`80
/[:b0P2IVIT407alO080KVi^0P1BDU8205mOG`80EEEE0P0e=CD203/k>`80Cdm?0P3<c<`40=?Cd`80
e]KF0P3Bd]840<g=c@80c<c<0P34a<@20;Rh^0<0]kNg0P2_[jl20:RXZ0X0XJ6Q0P2_[jl20:RXZ080
[jn_0P2e]KD20:n_[`@0_Kfm0P2n_[h40;Fe]@80[jn_0P2/[:`20:FUY@@0W9bL0P2?Shl205iNGP80
BTY:0P1<C4`203/k>`80:2PX0P0k>c/206EUI@80W9bL0`1jNWX205mOG`80[:b/0P26QXH209^KV`80
Ph>30P1XJ6P207=cL`80UIFE0P26QXH207alO080TI6A0P23Ph<20:BTY080VIVI0P2a/K420:BTY080
/K6a0P3;bl/20;6a/@80Y:BT102QXJ420:BTY080/[:b0P34a<@40>SXj080l?3`0P3^k^h20?;blP80
moOg0`3bl_840?Ogm`80l?3`1P3gmoL20?;blP@0moOg0P3bl_8<0?Ogm`l0oooo000=0?ooo`80moOg
0P3bl_840?Ogm`80l_;b2P3gmoL20?;blPd0moOg0P3bl_840?3`l080moOg0P3bl_820>k^kP80fMWI
0P3Bd]820=3@d080XJ6Q0P23Ph<207YjNP80J6QX0P1^KVh205IFEP80Cdm?100k>c/203lo?`80C4a<
103>c/h80<g=c@80c<c<0P31`L4208b<S080P8201@2BTY8:09RHV0P0P8200P2UYJD40;Fe]@H0_Kfm
102e]KD20:n_[`@0YJFU0P2LW9`2092@T080SXj>0P1<C4`203/k>`80=CDe0P0R8R8203De=@80EUIF
0P1jNWX30:FUY@80RHV90P2@T9020;6a/@80Vi^K0P2TY:@209VIV@80QXJ60P1lO7`208j>SP80TI6A
0P1bLW8207alO080TI6A0P2TY:@2096AT@80];Bd0P2b/[820<;2`P80a<C40P2QXJ420;6a/@80VIVI
0P2TY:@20<;2`P80clo?0P3IfMT20>WYj@80k^k^0P3YjNT20>k^kP80l?3`0`3gmoL20?3`l080l_;b
0P3gmoL20?;blPH0moOg0P3bl_840?Ogm`80l_;b103gmoL20?;blP@0moOg3`3oool000d0oooo0P3g
moL20?;blP@0moOg0P3bl_8:0?Ogm`80l_;b3@3gmoL20?;blP@0l?3`0P3gmoL20?;blP80k^k^0P3I
fMT20=;BdP80d=3@0P2QXJ4208>3P`80NWYj0P1XJ6P206i^KP80EUIF0P1?Cdl403/k>`80?clo0P1<
C4`40<k>cPP0cLg=0P3<c<`20<71`@80S8b<0P20P80509:BTPX0V9RH2020P8020:FUY@@0]KFe1P2m
_Kd40;Fe]@80[jn_102UYJD209bLW080T92@0P2>SXh204a<C080>c/k0P0e=CD2028R8P80=CDe0P1F
EUH207YjNP<0YJFU0P29RHT2092@T080/K6a0P2KVi/20:BTY080VIVI0P26QXH207alO080SXj>0P2A
TI42079bLP80O7al0P2ATI420:BTY080TI6A0P2d];@20;:b/P80`/;20P34a<@20:6QX@80/K6a0P2I
VIT20:BTY080`/;20P3?cll20=WIf@80jNWY0P3^k^h20>WYj@80k^k^0P3`l?030?Ogm`80l?3`0P3b
l_820?Ogm`80l_;b1P3gmoL20?;blP@0moOg0P3bl_840?Ogm`80l_;b103gmoL?0?ooo`003@3oool2
0?Ogm`80l_;b0P3gmoL20?;blP80moOg0P3bl_880?Ogm`80l_;b103gmoL20?;blP80l?3`1@3gmoL2
0?;blP@0moOg0P3`l?020?Ogm`80jNWY0P3Ogml20=SHf080/[:b0P2IVIT207emO@80Kfm_0P1XJ6P2
05mOG`80C4a<0P1FEUH204A4A080>c/k0P1<C4`20=CDe080c/k>103=cLd20<c<c080d];B0P3=cLd2
0:6QX@H0V9RH0`3>c/h20<71`@@0XJ6Q0P2c/k<20<71`@@0V9RH0P2BTY82092@T080QhN70P20P802
0:FUY@@0]KFe0P2m_Kd20;jn_PH0]KFe0P2/[:`20:FUY@80W9bL0P2HV9P208n?S`80Ph>30P1:BTX4
02PX:0808R8R0P1FEUH202PX:0<0[:b/0P2e]KD206QXJ080/[:b0P23Ph<20:j^[P80/K6a0P2ATI42
08j>SP80Vi^K0P1/K6`208j>SP80Ph>30P2ATI4209VIV@80W9bL0P2UYJD20;:b/P80a<C40P3<c<`2
09RHV080RHV90P2IVIT20:BTY080/;2`103Xj>P40>k^kP80j>SX103gmoL30?3`l0@0l_;b0P3gmoL2
0?;blP80moOg103bl_840?Ogm`80l_;b103gmoL40?;blP80moOg0P3bl_8?0?ooo`003@3oool20?Og
m`80l_;b0P3gmoL20?;blP80moOg0P3bl_880?Ogm`80l_;b103gmoL20?;blP80l?3`1@3gmoL20?;b
lP@0moOg0P3`l?020?Ogm`80jNWY0P3Ogml20=SHf080/[:b0P2IVIT207emO@80Kfm_0P1XJ6P205mO
G`80C4a<0P1FEUH204A4A080>c/k0P1<C4`20=CDe080c/k>103=cLd20<c<c080d];B0P3=cLd20:6Q
X@H0V9RH0`3>c/h20<71`@@0XJ6Q0P2c/k<20<71`@@0V9RH0P2BTY82092@T080QhN70P20P8020:FU
Y@@0]KFe0P2m_Kd20;jn_PH0]KFe0P2/[:`20:FUY@80W9bL0P2HV9P208n?S`80Ph>30P1:BTX402PX
:0808R8R0P1FEUH202PX:0<0[:b/0P2e]KD206QXJ080/[:b0P23Ph<20:j^[P80/K6a0P2ATI4208j>
SP80Vi^K0P1/K6`208j>SP80Ph>30P2ATI4209VIV@80W9bL0P2UYJD20;:b/P80a<C40P3<c<`209RH
V080RHV90P2IVIT20:BTY080/;2`103Xj>P40>k^kP80j>SX103gmoL30?3`l0@0l_;b0P3gmoL20?;b
lP80moOg103bl_840?Ogm`80l_;b103gmoL40?;blP80moOg0P3bl_8?0?ooo`003@3oool20?;blP80
moOg0P3bl_820?Ogm`80l_;b0P3gmoL20?;blP80moOg103bl_820?Ogm`d0l_;b0P3`l?040?Ogm`80
l?3`0P3gmoL20=[JfP80clo?0P2`/;0209VIV@80RHV90P1mOGd205IFEP80GemO0P1BDU8205mOG`80
;Bd]100k>c/208F5Q@H0dm?C0P3=cLd60<c<c080TY:B102HV9P209:BTPL0S8b<0P2HV9P40820P080
LG5a101gMgL20:6QX@@0QhN70P1aLG420:f][@80^;Rh202m_Kd20;Fe]@80[:b/102UYJD409bLW080
SXj>0P1jNWX403/k>`805ADE0P0e=CD205iNGP<0RHV90P2IVIT208>3P`80TI6A0P2a/K4208j>SP80
];Bd0P3Bd]82096AT@80O7al102>SXh207=cL`80Ph>30P2KVi/209VIV@@0Y:BT1034a<@20:6QX@80
VIVI0P2QXJ4209RHV080/;2`0P3Xj>P20>WYj@80l?3`103YjNT?0?Ogm`80l_;b5P3gmoL?0?ooo`00
3@3oool20?;blP80moOg0P3bl_820?Ogm`80l_;b0P3gmoL20?;blP80moOg103bl_820?Ogm`d0l_;b
0P3`l?040?Ogm`80l?3`0P3gmoL20=[JfP80clo?0P2`/;0209VIV@80RHV90P1mOGd205IFEP80GemO
0P1BDU8205mOG`80;Bd]100k>c/208F5Q@H0dm?C0P3=cLd60<c<c080TY:B102HV9P209:BTPL0S8b<
0P2HV9P40820P080LG5a101gMgL20:6QX@@0QhN70P1aLG420:f][@80^;Rh202m_Kd20;Fe]@80[:b/
102UYJD409bLW080SXj>0P1jNWX403/k>`805ADE0P0e=CD205iNGP<0RHV90P2IVIT208>3P`80TI6A
0P2a/K4208j>SP80];Bd0P3Bd]82096AT@80O7al102>SXh207=cL`80Ph>30P2KVi/209VIV@@0Y:BT
1034a<@20:6QX@80VIVI0P2QXJ4209RHV080/;2`0P3Xj>P20>WYj@80l?3`103YjNT?0?Ogm`80l_;b
5P3gmoL?0?ooo`003@3oool80?Ogm`@0l_;b0P3gmoL60?;blP80moOg1P3bl_850?Ogm`@0l_;b0P3g
moL60?;blP80fMWI0P36a/H20:BTY080VIVI0P1jNWX206IVIP80DU9B0P1OGel204m?C`80=CDe0P16
ATH203De=@80GemO103De=@20=?Cd`@0cLg=0P3<c<`20:6QX@80V9RH0P1jNWX205MGE`80GEeM0P1Y
JFT307YjNP@0JFUY0P1aLG4206EUI@80EeMG0P16ATH2055AD@80GEeM0P11@D4205QHF080DE5A0P1:
BTX2065QH@80V9RH1P2m_Kd60;Fe]@@0YJFU0P2TY:@20:FUY@80Shn?0P23Ph<205iNGP806ATI0P0E
5AD203/k>`80BTY:0`1LG5`2096AT@80[:b/0P1OGel20:b/[080Ph>30P2UYJD20<?3``80d];B102L
W9`207EeM@80SXj>0P23Ph<2096AT@80U9BD0P23Ph<20;6a/@80`/;20P34a<@20<30`080Y:BT0P2a
/K420:6QX@80^[Zj0P3Ogml20>k^kP80j>SX0P3^k^h20?;blP80k^k^1@3gmoL20?;blP80moOg0P3b
l_8@0?Ogm`80l_;b0P3gmoL20?;blP@0moOg3`3oool000d0oooo203gmoL40?;blP80moOg1P3bl_82
0?Ogm`H0l_;b1@3gmoL40?;blP80moOg1P3bl_820=WIf@80a/K60P2TY:@209VIV@80NWYj0P1VIVH2
059BDP80GemO0P1?Cdl203De=@80ATI60P0e=CD205mOG`@0e=CD0P3Cdm<40<g=c@80c<c<0P2QXJ42
09RHV080NWYj0P1GEeL205eMG@80JFUY0`1jNWX406UYJ@80LG5a0P1UIFD205MGE`80ATI60P1ADE42
05eMG@80@D510P1HF5P2055AD@80BTY:0P1QHF4209RHV0H0_Kfm1P2e]KD40:FUY@80Y:BT0P2UYJD2
08n?S`80Ph>30P1NGUh201TI6@805ADE0P0k>c/204Y:BP<0G5aL0P2ATI420:b/[080GemO0P2/[:`2
08>3P`80YJFU0P33`l<20=;BdP@0W9bL0P1eMGD208j>SP80Ph>30P2ATI4209BDU080Ph>30P2a/K42
0<;2`P80a<C40P30`<020:BTY080/K6a0P2QXJ420;Zj^P80gmoO0P3^k^h20>SXj080k^k^0P3bl_82
0>k^kPD0moOg0P3bl_820?Ogm`80l_;b403gmoL20?;blP80moOg0P3bl_840?Ogm`l0oooo000=0?oo
o`H0l_;b103gmoL40?;blP80moOg0P3bl_820?Ogm`80l_;b0P3gmoL20?;blP80moOg2`3bl_820?3`
l080l_;b0P3YjNT20=WIf@80`<300P2HV9P208>3P`80IVIV0P1BDU8205iNGP80DE5A1P1<C4`204Y:
BP@0e=CD0P3>c/h20=?Cd`80e]KF0P3=cLd20<c<c080`L710P3<c<`20:6QX@80QhN70P20P80207Mg
M`<0P8200P1gMgL20820P080TY:B301gMgL20:BTY080[:b/0P2][Jd40;Fe]@@0_Kfm102g]kL20;Fe
]@80]kNg0P2_[jl40:FUY@80Y:BT0P2LW9`208n?S`80MGEe0P0g=cL401DE5@80=cLg0`1LG5`207Ee
M@80YJFU0P2IVIT206m_K`80Y:BT0P23Ph<40<?3``80dm?C0P1jNWX408j>SP80Ph>3102ATI4208>3
P`@0/K6a0P34a<@20<_;b`80VIVI0P2a/K420:BTY080f=SH103YjNT40>SXj0T0l_;b203gmoL20?;b
lP@0moOg0P3bl_840?Ogm`80l_;b103gmoL20?;blP@0moOg3`3oool000d0oooo1P3bl_840?Ogm`@0
l_;b0P3gmoL20?;blP80moOg0P3bl_820?Ogm`80l_;b0P3gmoL;0?;blP80l?3`0P3bl_820>WYj@80
fMWI0P30`<0209RHV080Ph>30P1VIVH2059BDP80GUiN0P1ADE4604a<C080BTY:103De=@20<k>cP80
dm?C0P3Fe]H20<g=c@80c<c<0P31`L420<c<c080XJ6Q0P27QhL20820P080MgMg0`20P80207MgM`80
P8200P2BTY8<07MgM`80Y:BT0P2/[:`20:f][@@0]KFe102m_Kd40;Ng]`80]KFe0P2g]kL20:n_[`@0
YJFU0P2TY:@209bLW080Shn?0P1eMGD203Lg=`@05ADE0P0g=cL305aLG080MGEe0P2UYJD209VIV@80
Kfm_0P2TY:@208>3P`@0`l?30P3Cdm<207YjNP@0SXj>0P23Ph<4096AT@80Ph>3102a/K420<C4a080
bl_;0P2IVIT20;6a/@80Y:BT0P3Hf=P40>WYj@@0j>SX2@3bl_880?Ogm`80l_;b103gmoL20?;blP@0
moOg0P3bl_840?Ogm`80l_;b103gmoL?0?ooo`003@3oool20?Ogm`@0l_;b0P3gmoL20?;blPH0moOg
0P3bl_820?Ogm`80l_;b2`3gmoL20?3`l080moOg0P3bl_820>k^kP80l?3`0P3Xj>P20=3@d080/[:b
0P29RHT406m_K`80GUiN0P1ADE4204m?C`80A4A40P1<C4`204U9B@80EEEE0P3Cdm<20<g=c@80dm?C
0P3Bd]820<g=c@80d];B0P3<c<`20=;BdP@0e]KF0P3Lg=`20=[JfP80c/k>0`3=cLd20=cLg080cLg=
0P3<c<`20=KFeP80g=cL0P3>c/h20<g=c@80a<C40P2n_[h20<C4a080_[jn102m_Kd20;jn_P80_Kfm
0P2n_[h20;fm_@80^;Rh102e]KD40:n_[`80YJFU0P2TY:@409bLW080Ph>30P1EEED202XZ:P802PX:
0P1LG5`304Y:BP80G5aL0P1eMGD2096AT@80J6QX0P2>SXh207=cL`80SXj>1033`l<20:BTY080W9bL
0P2ATI4407alO080TI6A0P2LW9`20:BTY080W9bL0P34a<@20<_;b`@0XJ6Q0P2DU9@20=oOg`@0j>SX
0P3YjNT20>SXj0H0moOg0`3bl_8<0?Ogm`80l_;b0P3gmoL20?;blPH0moOg0P3bl_860?Ogm`l0oooo
000=0?ooo`80moOg103bl_820?Ogm`80l_;b1P3gmoL20?;blP80moOg0P3bl_8;0?Ogm`80l?3`0P3g
moL20?;blP80k^k^0P3`l?020>SXj080d=3@0P2b/[8208V9R@@0Kfm_0P1NGUh2055AD@80Cdm?0P14
A4@204a<C080BDU90P1EEED20=?Cd`80cLg=0P3Cdm<20=;BdP80cLg=0P3Bd]820<c<c080d];B103F
e]H20=cLg080f][J0P3>c/h30<g=c@80g=cL0P3=cLd20<c<c080e]KF0P3Lg=`20<k>cP80cLg=0P34
a<@20;jn_P80a<C40P2n_[h40;fm_@80_[jn0P2m_Kd20;jn_P80_Kfm0P2h^;P40;Fe]@@0[jn_0P2U
YJD20:BTY0@0W9bL0P23Ph<205EEE@80:RXZ0P0:2PX205aLG0<0BTY:0P1LG5`207EeM@80TI6A0P1X
J6P208j>SP80Lg=c0P2>SXh40<?3``80Y:BT0P2LW9`2096AT@@0O7al0P2ATI4209bLW080Y:BT0P2L
W9`20<C4a080bl_;102QXJ4209BDU080gmoO103Xj>P20>WYj@80j>SX1P3gmoL30?;blP`0moOg0P3b
l_820?Ogm`80l_;b1P3gmoL20?;blPH0moOg3`3oool000d0oooo0P3bl_8:0?Ogm`80l_;b1P3gmoL2
0?;blP80moOg103bl_850?Ogm`80l_;b0P3`l?040?;blP80jNWY0P39bLT20<?3``80XJ6Q0P1jNWX2
06IVIP@0EEEE0P1@D50203De=@@0C4a<0P16ATH20;Zj^PH0dm?C0P3AdM420=KFeP80cLg=0P3Fe]H2
0<g=c@@0e]KF0P3Lg=`20=KFeP80g=cL0`3Fe]H20=cLg080c<c<1P3=cLd80;jn_P80`l?30P2n_[h2
0<?3``80c<c<0P2n_[h20;fm_@80`l?30P2n_[h40;Rh^080]KFe102_[jl20:FUY@80V9RH102LW9`2
08>3P`80HF5Q0P0R8R8201hN7P80BTY:0`1EEED208F5Q@80MGEe0P2QXJ4206QXJ080GemO0P2DU9@2
096AT@80]KFe0P33`l<20<c<c080/K6a102>SXh209BDU080O7al1023Ph<209bLW080a<C40P3;bl/2
0:BTY080/[:b0P2IVIT20>SXj080jNWY0P3Ogml20>SXj080l?3`1P3gmoL30?;blP@0moOg1P3bl_8D
0?Ogm`80l_;b3`3oool000d0oooo0P3bl_8:0?Ogm`80l_;b1P3gmoL20?;blP80moOg103bl_850?Og
m`80l_;b0P3`l?040?;blP80jNWY0P39bLT20<?3``80XJ6Q0P1jNWX206IVIP@0EEEE0P1@D50203De
=@@0C4a<0P16ATH20;Zj^PH0dm?C0P3AdM420=KFeP80cLg=0P3Fe]H20<g=c@@0e]KF0P3Lg=`20=KF
eP80g=cL0`3Fe]H20=cLg080c<c<1P3=cLd80;jn_P80`l?30P2n_[h20<?3``80c<c<0P2n_[h20;fm
_@80`l?30P2n_[h40;Rh^080]KFe102_[jl20:FUY@80V9RH102LW9`208>3P`80HF5Q0P0R8R8201hN
7P80BTY:0`1EEED208F5Q@80MGEe0P2QXJ4206QXJ080GemO0P2DU9@2096AT@80]KFe0P33`l<20<c<
c080/K6a102>SXh209BDU080O7al1023Ph<209bLW080a<C40P3;bl/20:BTY080/[:b0P2IVIT20>SX
j080jNWY0P3Ogml20>SXj080l?3`1P3gmoL30?;blP@0moOg1P3bl_8D0?Ogm`80l_;b3`3oool000d0
oooo0P3bl_820?Ogm`P0l_;b0P3gmoL20?3`l0P0moOg0P3bl_820?Ogm`80l_;b0`3gmoL40?;blP80
l?3`103bl_820=3@d080XJ6Q0P23Ph<206QXJ080Kfm_0P1?Cdl2051@D080>c/k201<C4`40=?Cd`80
c/k>0P3Cdm<20=KFeP@0dM7A0P3Fe]H20=?Cd`d0e]KF0P3Cdm<20<g=c@H0c<c<0P2n_[h20<?3``80
a/K60P2n_[h20<C4a080_[jn0P3<c<`20;jn_P80c<c<102n_[h40;Rh^080_Kfm0P2e]KD20:n_[`80
Z:RX0P2_[jl20:BTY0@0W9bL0P2?Shl206m_K`80A4A40P0g=cL201DE5@<0DE5A0P1FEUH206IVIP80
J6QX0P1jNWX206QXJ080Ph>30P1mOGd209bLW0@0`/;20P2LW9`20:BTY080SXj>0P2ATI4207alO080
TI6A0P1lO7`20:BTY080/K6a0P34a<@20;2`/080VIVI0P2UYJD20=WIf@@0j>SX0P3Hf=P20?Ogm`80
l_;b103gmoL30?;blP80moOg0P3bl_880?Ogm`80l_;b1P3gmoL40?;blPP0moOg3`3oool000d0oooo
0P3bl_820?Ogm`P0l_;b0P3gmoL20?3`l0P0moOg0P3bl_820?Ogm`80l_;b0`3gmoL40?;blP80l?3`
103bl_820=3@d080XJ6Q0P23Ph<206QXJ080Kfm_0P1?Cdl2051@D080>c/k201<C4`40=?Cd`80c/k>
0P3Cdm<20=KFeP@0dM7A0P3Fe]H20=?Cd`d0e]KF0P3Cdm<20<g=c@H0c<c<0P2n_[h20<?3``80a/K6
0P2n_[h20<C4a080_[jn0P3<c<`20;jn_P80c<c<102n_[h40;Rh^080_Kfm0P2e]KD20:n_[`80Z:RX
0P2_[jl20:BTY0@0W9bL0P2?Shl206m_K`80A4A40P0g=cL201DE5@<0DE5A0P1FEUH206IVIP80J6QX
0P1jNWX206QXJ080Ph>30P1mOGd209bLW0@0`/;20P2LW9`20:BTY080SXj>0P2ATI4207alO080TI6A
0P1lO7`20:BTY080/K6a0P34a<@20;2`/080VIVI0P2UYJD20=WIf@@0j>SX0P3Hf=P20?Ogm`80l_;b
103gmoL30?;blP80moOg0P3bl_880?Ogm`80l_;b1P3gmoL40?;blPP0moOg3`3oool000d0oooo0P3b
l_820?Ogm`P0l_;b0P3gmoL20?3`l0P0moOg0P3bl_820?Ogm`80l_;b0`3gmoL40?;blP80l?3`103b
l_820=3@d080XJ6Q0P23Ph<206QXJ080Kfm_0P1?Cdl2051@D080>c/k201<C4`40=?Cd`80c/k>0P3C
dm<20=KFeP@0dM7A0P3Fe]H20=?Cd`d0e]KF0P3Cdm<20<g=c@H0c<c<0P2n_[h20<?3``80a/K60P2n
_[h20<C4a080_[jn0P3<c<`20;jn_P80c<c<102n_[h40;Rh^080_Kfm0P2e]KD20:n_[`80Z:RX0P2_
[jl20:BTY0@0W9bL0P2?Shl206m_K`80A4A40P0g=cL201DE5@<0DE5A0P1FEUH206IVIP80J6QX0P1j
NWX206QXJ080Ph>30P1mOGd209bLW0@0`/;20P2LW9`20:BTY080SXj>0P2ATI4207alO080TI6A0P1l
O7`20:BTY080/K6a0P34a<@20;2`/080VIVI0P2UYJD20=WIf@@0j>SX0P3Hf=P20?Ogm`80l_;b103g
moL30?;blP80moOg0P3bl_880?Ogm`80l_;b1P3gmoL40?;blPP0moOg3`3oool000d0oooo0P3gmoL2
0?;blP80moOg103bl_860?Ogm`80l_;b4@3gmoL40?;blP80l?3`0P3@d=020<K6aP80V9RH0P1lO7`2
06m_K`80Cdm?0P1NGUh203/k>`80C4a<0P0e=CD204a<C080Cdm?0P0k>c/20=?Cd`@0c/k>0P3Cdm<6
0=KFeP80dM7A203Fe]H20=?Cd`D0e]KF103<c<`20;jn_P80c<c<0P2n_[h20;Ng]`80_Kfm0P33`l<2
0;jn_P80`L710P36a/H20<c<c0@0`L710P3=cLd20<c<c0@0_[jn0P2h^;P20;Ng]`@0[jn_0P2UYJD2
0:BTY080V9RH0P2@T90208n?S`80O7al0P1:BTX2028R8P80:2PX0`1:BTX206EUI@80KFe]0P1eMGD2
08V9R@80Kfm_0P1NGUh206IVIP80V9RH0P2DU9@20:f][@80c<c<0P2a/K4208J6QP80U9BD0P1_Kfl2
09VIV@80TI6A0P2UYJD20:BTY080a<C40P2`/;02096AT@80c<c<0P3Hf=P60>WYj@80l_;b3@3gmoL2
0?;blPH0moOg0P3bl_820?Ogm`80l_;b3P3gmoL?0?ooo`003@3oool20?Ogm`80l_;b0P3gmoL40?;b
lPH0moOg0P3bl_8A0?Ogm`@0l_;b0P3`l?020=3@d080a/K60P2HV9P207alO080Kfm_0P1?Cdl205iN
GP80>c/k0P1<C4`203De=@80C4a<0P1?Cdl203/k>`80dm?C103>c/h20=?Cd`H0e]KF0P3AdM480=KF
eP80dm?C1@3Fe]H40<c<c080_[jn0P3<c<`20;jn_P80]kNg0P2m_Kd20<?3``80_[jn0P31`L420<K6
aP80c<c<1031`L420<g=c@80c<c<102n_[h20;Rh^080]kNg102_[jl20:FUY@80Y:BT0P2HV9P2092@
T080Shn?0P1lO7`204Y:BP808R8R0P0X:2P304Y:BP80IFEU0P1]KFd207EeM@80RHV90P1_Kfl205iN
GP80IVIV0P2HV9P209BDU080[Jf]0P3<c<`20;6a/@80QXJ60P2DU9@206m_K`80VIVI0P2ATI420:FU
Y@80Y:BT0P34a<@20;2`/080TI6A0P3<c<`20=SHf0H0jNWY0P3bl_8=0?Ogm`80l_;b1P3gmoL20?;b
lP80moOg0P3bl_8>0?Ogm`l0oooo000=0?oooa80moOg0P3bl_880?Ogm`L0l_;b103gmoL20>WYj@80
bLW90P2YZJT209RHV080Kfm_0P1XJ6P206IVIP80BTY:101<C4`204Y:BP80C4a<0P0k>c/208V9R@80
c<c<103>c/h80=KFeP80g=cL0P3Fe]H20=?Cd`H0e]KF1@3=cLd20;jn_P80]KFe0P2_[jl20;Rh^080
]KFe0P2_[jl20;Fe]@80^;Rh0P2m_Kd20;jn_P80a/K60P34a<@20<c<c0@0cLg=1031`L420;jn_P80
^;Rh0P2e]KD40:n_[`@0YJFU0P2TY:@209bLW080R8R80P1hN7P205iNGP80=cLg0P0k>c/303hn?P80
G5aL0P1FEUH207EeM@80IVIV0P1lO7`205EEE@80J6QX0P1FEUH20;:b/P80`/;20P2TY:@20:j^[P80
U9BD0P2IVIT207emO@80Ph>30P2ATI420:6QX@80Y:BT0P33`l<20;Zj^P80VIVI0P3Ogml20<C4a080
l_;b0P3YjNT=0?Ogm`80l_;b303gmoL40?;blP@0moOg0P3bl_880?Ogm`l0oooo000=0?oooa80moOg
0P3bl_880?Ogm`L0l_;b103gmoL20>WYj@80bLW90P2YZJT209RHV080Kfm_0P1XJ6P206IVIP80BTY:
101<C4`204Y:BP80C4a<0P0k>c/208V9R@80c<c<103>c/h80=KFeP80g=cL0P3Fe]H20=?Cd`H0e]KF
1@3=cLd20;jn_P80]KFe0P2_[jl20;Rh^080]KFe0P2_[jl20;Fe]@80^;Rh0P2m_Kd20;jn_P80a/K6
0P34a<@20<c<c0@0cLg=1031`L420;jn_P80^;Rh0P2e]KD40:n_[`@0YJFU0P2TY:@209bLW080R8R8
0P1hN7P205iNGP80=cLg0P0k>c/303hn?P80G5aL0P1FEUH207EeM@80IVIV0P1lO7`205EEE@80J6QX
0P1FEUH20;:b/P80`/;20P2TY:@20:j^[P80U9BD0P2IVIT207emO@80Ph>30P2ATI420:6QX@80Y:BT
0P33`l<20;Zj^P80VIVI0P3Ogml20<C4a080l_;b0P3YjNT=0?Ogm`80l_;b303gmoL40?;blP@0moOg
0P3bl_880?Ogm`l0oooo000=0?ooo`80l_;b2P3gmoL20?;blP80moOg103bl_840?Ogm`80l_;b1`3g
moL20?3`l080moOg103bl_820<?3``80V9RH0P1jNWX206IVIP@0DU9B0P1<C4`403/k>`@0C4a<0P0e
=CD20<c<c0@0c/k>0P3AdM4<0=KFeP80d];B1P3Fe]H20<g=c@<0`L710P2i^KT20;fm_@80Z:RX102_
[jl20:FUY@80[:b/102e]KD20;fm_@80_[jn0P36a/H20<71`@H0c<c<0P31`L420<c<c080`<300P2h
^;P20;Fe]@80[jn_102UYJD20:BTY080T92@0P2?Shl208>3P`80HF5Q0P0g=cL200X:2P<092@T0P1:
BTX205EEE@80Kfm_0P1FEUH207alO0@0J6QX0P1<C4`20:b/[080SXj>0P2TY:@20=;BdP80VIVI102D
U9@208>3P`80T92@0P2>SXh209VIV@80`l?31030`<020<o?c`@0fMWI0P3Cdm<=0?Ogm`80l_;b503g
moL20?;blPP0moOg3`3oool000d0oooo0P3bl_8:0?Ogm`80l_;b0P3gmoL40?;blP@0moOg0P3bl_87
0?Ogm`80l?3`0P3gmoL40?;blP80`l?30P2HV9P207YjNP80IVIV101BDU8204a<C0@0>c/k101<C4`2
03De=@80c<c<103>c/h20=7Ad@`0e]KF0P3Bd]860=KFeP80cLg=0`31`L420;Vi^@80_Kfm0P2XZ:P4
0:n_[`80YJFU0P2/[:`40;Fe]@80_Kfm0P2n_[h20<K6aP80`L711P3<c<`20<71`@80c<c<0P30`<02
0;Rh^080]KFe0P2_[jl40:FUY@80Y:BT0P2@T90208n?S`80Ph>30P1QHF4203Lg=`802PX:0`0T92@2
04Y:BP80EEEE0P1_Kfl205IFEP80O7al101XJ6P204a<C080[:b/0P2>SXh20:BTY080d];B0P2IVIT4
09BDU080Ph>30P2@T90208j>SP80VIVI0P33`l<40<30`080clo?103IfMT20=?Cd`d0moOg0P3bl_8D
0?Ogm`80l_;b203gmoL?0?ooo`003@3oool>0?Ogm`80l_;b1P3gmoL20?;blPl0moOg0P3YjNT20;:b
/P80RHV90P1VIVH205EEE@80DU9B0P0k>c/204a<C080A4A40P1<C4`204Y:BP80=CDe0P0a<C420<k>
cP80bl_;103=cLd20=KFeP80dM7A103Lg=`60=KFeP80dM7A0P3Jf]X20:RXZ080TY:B1@3=cLd20<71
`@80/k>c101aLG42092@T080Z:RX0P23Ph<20:BTY080]KFe0P2n_[h40<c<c0H0cLg=0P3<c<`20<71
`@80_[jn0P2h^;P20;Ng]`@0[jn_0P2UYJD20:BTY080W9bL0P2?Shl207QhN080KVi^0P14A4@201DE
5@<092@T0P0a<C4204Y:BP80EUIF0P1LG5`406m_K`80EEEE0P1_Kfl205iNGP80TI6A0P2d];@20:BT
Y080];Bd0P2>SXh2096AT@80J6QX1023Ph<20:BTY080`/;20P30`<020>WYj@80/;2`0P3YjNT20;Zj
^R/0moOg0P3bl_820?Ogm`l0oooo000=0?ooo`h0moOg0P3bl_860?Ogm`80l_;b3`3gmoL20>WYj@80
/[:b0P29RHT206IVIP80EEEE0P1BDU8203/k>`80C4a<0P14A4@204a<C080BTY:0P0e=CD2034a<@80
c/k>0P3;bl/40<g=c@80e]KF0P3AdM440=cLg0H0e]KF0P3AdM420=[JfP80Z:RX0P2BTY850<g=c@80
`L710P2c/k<4075aL@80T92@0P2XZ:P208>3P`80Y:BT0P2e]KD20;jn_P@0c<c<1P3=cLd20<c<c080
`L710P2n_[h20;Rh^080]kNg102_[jl20:FUY@80Y:BT0P2LW9`208n?S`80N7Qh0P1^KVh204A4A080
5ADE0`0T92@2034a<@80BTY:0P1FEUH205aLG0@0Kfm_0P1EEED206m_K`80GUiN0P2ATI420;Bd]080
Y:BT0P2d];@208j>SP80TI6A0P1XJ6P408>3P`80Y:BT0P32`/820<30`080jNWY0P2`/;020>WYj@80
^[Zj:`3gmoL20?;blP80moOg3`3oool000d0oooo103bl_820?Ogm`@0l_;b203gmoL40?;blP80moOg
0P3bl_8;0?Ogm`80l_;b0P3Ogml209VIV@80NWYj0P1VIVH206QXJ0@0C4a<0P0k>c/204I6AP80C4a<
0P0k>c/2034a<@80EUIF0P3>c/h20<g=c@80dm?C0P3Fe]H20=cLg080e]KF0P3AdM420=cLg080dM7A
0P3Fe]H20=;BdP80e]KF0P3Lg=`20=?Cd`80c/k>1@3AdM420<g=c@80_Kfm102e]KD20;Ng]`80_Kfm
0P2_[jl209JFUP80YJFU0P2n_[h:0<g=c@80`L71103<c<`20<30`080]kNg0P2e]KD20:n_[`80YJFU
102LW9`208n?S`80R8R80P1eMGD205iNGP802PX:0`0E5AD202@T9080?Shn0P1ADE4205iNGP80EUIF
0P1eMGD205EEE@80GemO0P0X:2P20;6a/@80UYJF0P2KVi/20<?3``80Ph>30P2ATI4206m_K`80NWYj
0P2ATI4209VIV@80/;2`1039bLT20:n_[`80^[Zj103gmoL20?;blP/0moOg0P3bl_880?Ogm`80l_;b
2P3gmoL40?;blPH0moOg3`3oool000d0oooo103bl_820?Ogm`@0l_;b203gmoL40?;blP80moOg0P3b
l_8;0?Ogm`80l_;b0P3Ogml209VIV@80NWYj0P1VIVH206QXJ0@0C4a<0P0k>c/204I6AP80C4a<0P0k
>c/2034a<@80EUIF0P3>c/h20<g=c@80dm?C0P3Fe]H20=cLg080e]KF0P3AdM420=cLg080dM7A0P3F
e]H20=;BdP80e]KF0P3Lg=`20=?Cd`80c/k>1@3AdM420<g=c@80_Kfm102e]KD20;Ng]`80_Kfm0P2_
[jl209JFUP80YJFU0P2n_[h:0<g=c@80`L71103<c<`20<30`080]kNg0P2e]KD20:n_[`80YJFU102L
W9`208n?S`80R8R80P1eMGD205iNGP802PX:0`0E5AD202@T9080?Shn0P1ADE4205iNGP80EUIF0P1e
MGD205EEE@80GemO0P0X:2P20;6a/@80UYJF0P2KVi/20<?3``80Ph>30P2ATI4206m_K`80NWYj0P2A
TI4209VIV@80/;2`1039bLT20:n_[`80^[Zj103gmoL20?;blP/0moOg0P3bl_880?Ogm`80l_;b2P3g
moL40?;blPH0moOg3`3oool000d0oooo303gmoL20?;blP@0moOg103bl_880?Ogm`<0l?3`1P3gmoL2
0=WIf@80TI6A0P1VIVH2065QH@80>c/k0P1:BTX2051@D080A4A40P1<C4`2051@D0@0;Bd]0P1oOgl2
0<_;b`H0dM7A0P3Jf]X60=cLg080f][J103Fe]H20=7Ad@80g=cL0P3>c/h70=[JfP80dM7A0P3<c<`2
0;fm_@@0^KVi102e]KD40:n_[`80`L71103=cLd20=7Ad@H0cLg=1P31`L420;fm_@80]kNg0P2e]KD2
0:RXZ0@0V9RH0P2?Shl208>3P`80Lg=c0P1VIVH200X:2P<07QhN0P0E5AD204Y:BP80EUIF0P1VIVH2
04A4A080Kfm_0P1EEED205mOG`80<C4a0P2IVIT2096AT@80/K6a0P33`l<208>3P`80TI6A0P1jNWX2
08>3P`80RHV90P2HV9P20;:b/P@0bLW90P30`<020<o?c`@0moOg0P3bl_8?0?Ogm`80l_;b4P3gmoL2
0?;blPH0moOg3`3oool000d0oooo303gmoL20?;blP@0moOg103bl_880?Ogm`<0l?3`1P3gmoL20=WI
f@80TI6A0P1VIVH2065QH@80>c/k0P1:BTX2051@D080A4A40P1<C4`2051@D0@0;Bd]0P1oOgl20<_;
b`H0dM7A0P3Jf]X60=cLg080f][J103Fe]H20=7Ad@80g=cL0P3>c/h70=[JfP80dM7A0P3<c<`20;fm
_@@0^KVi102e]KD40:n_[`80`L71103=cLd20=7Ad@H0cLg=1P31`L420;fm_@80]kNg0P2e]KD20:RX
Z0@0V9RH0P2?Shl208>3P`80Lg=c0P1VIVH200X:2P<07QhN0P0E5AD204Y:BP80EUIF0P1VIVH204A4
A080Kfm_0P1EEED205mOG`80<C4a0P2IVIT2096AT@80/K6a0P33`l<208>3P`80TI6A0P1jNWX208>3
P`80RHV90P2HV9P20;:b/P@0bLW90P30`<020<o?c`@0moOg0P3bl_8?0?Ogm`80l_;b4P3gmoL20?;b
lPH0moOg3`3oool000d0oooo1P3gmoL20?;blP80moOg0P3bl_840?Ogm`80l_;b0P3gmoL20?;blP@0
moOg0P3`l?020?Ogm`D0l_;b0P3gmoL20?;blP80dm?C0P1jNWX205iNGP80GemO0P1EEED404a<C080
Cdm?0P1BDU8204I6AP80:2PX0P0g=cL20<c<c080c/k>103Fe]H60=cLg080f][J0P3Lg=`20=[JfP80
g=cL0P3AdM420<g=c@@0g=cL0P3Jf]X30>CTi080f][J0P3AdM420<g=c@80a<C40P2h^;P20;>c/`@0
]KFe0P2_[jl20;Rh^080`L71103=cLd20=;BdP80cLg=0P3AdM420<g=c@@0c<c<1031`L420;Rh^080
]kNg0P2_[jl20:RXZ080W9bL0P2@T90208>3P`80Lg=c0P1OGel202PX:0<000000P0N7Qh204A4A080
:2PX0P1XJ6P205EEE@80Kfm_0P16ATH205EEE@80GUiN0P1jNWX209BDU0@0[Zj^0P2TY:@208>3P`80
TI6A0P1jNWX408>3P`80/;2`0P3;bl/20;Zj^P80dm?C0P3bl_8>0?Ogm`D0l_;b7P3gmoL?0?ooo`00
3@3oool60?Ogm`80l_;b0P3gmoL20?;blP@0moOg0P3bl_820?Ogm`80l_;b103gmoL20?3`l080moOg
1@3bl_820?Ogm`80l_;b0P3Cdm<207YjNP80GUiN0P1OGel205EEE@@0C4a<0P1?Cdl2059BDP80ATI6
0P0X:2P203Lg=`80c<c<0P3>c/h40=KFePH0g=cL0P3Jf]X20=cLg080f][J0P3Lg=`20=7Ad@80cLg=
103Lg=`20=[JfP<0i>CT0P3Jf]X20=7Ad@80cLg=0P34a<@20;Rh^080/k>c102e]KD20:n_[`80^;Rh
0P31`L440<g=c@80d];B0P3=cLd20=7Ad@80cLg=103<c<`40<71`@80^;Rh0P2g]kL20:n_[`80Z:RX
0P2LW9`2092@T080Ph>30P1cLg<205mOG`80:2PX0`00000201hN7P80A4A40P0X:2P206QXJ080EEEE
0P1_Kfl204I6AP80EEEE0P1NGUh207YjNP80U9BD102^[Zh20:BTY080Ph>30P2ATI4207YjNP@0Ph>3
0P2`/;020<_;b`80^[Zj0P3Cdm<20?;blPh0moOg1@3bl_8N0?Ogm`l0oooo000=0?ooo`h0moOg103b
l_820?Ogm`@0l_;b103gmoL20?;blPL0moOg0P3`l?0209VIV@@0IVIV0P0k>c/404A4A080C4a<0P1@
D50204a<C0807QhN0P0];Bd201hN7P80cLg=0P3AdM420=CDe080dM7A103Lg=`20=[JfPX0g=cL103F
e]H20=7Ad@L0f][J0P3Fe]H20<g=c@80^;Rh0P2][Jd20:n_[`80]KFe0P2][Jd20;Fe]@80_[jn0P3=
cLd40<k>cP80dm?C0P3Fe]H40<g=c@80c<c<0P3=cLd20<c<c080`L710P2h^;P20;Ng]`80]KFe0P2_
[jl20:BTY080T92@0P23Ph<207YjNP80KVi^0P1:BTX300L71`805ADE0P0g=cL205UIF@80EUIF0P1N
GUh206IVIP80C4a<0P1EEED204Y:BP80MGEe0P2>SXh209bLW080]KFe0P34a<@207alO080Ph>30P1e
MGD208>3P`80VIVI0P33`l<20<_;b`80XJ6Q0P3?cll20?Ogm`80l_;b0P3gmoL60?;blPL0moOg0P3b
l_8B0?Ogm`80l_;b2P3gmoL?0?ooo`003@3oool>0?Ogm`@0l_;b0P3gmoL40?;blP@0moOg0P3bl_87
0?Ogm`80l?3`0P2IVIT406IVIP80>c/k1014A4@204a<C080D51@0P1<C4`201hN7P80;Bd]0P0N7Qh2
0<g=c@80dM7A0P3De=@20=7Ad@@0g=cL0P3Jf]X:0=cLg0@0e]KF0P3AdM470=[JfP80e]KF0P3=cLd2
0;Rh^080[Jf]0P2_[jl20;Fe]@80[Jf]0P2e]KD20;jn_P80cLg=103>c/h20=?Cd`80e]KF103=cLd2
0<c<c080cLg=0P3<c<`20<71`@80^;Rh0P2g]kL20;Fe]@80[jn_0P2TY:@2092@T080Ph>30P1jNWX2
06i^KP80BTY:0`071`L201DE5@80=cLg0P1IFET205IFEP80GUiN0P1VIVH204a<C080EEEE0P1:BTX2
07EeM@80SXj>0P2LW9`20;Fe]@80a<C40P1lO7`208>3P`80MGEe0P23Ph<209VIV@80`l?30P3;bl/2
0:6QX@80clo?0P3gmoL20?;blP80moOg1P3bl_870?Ogm`80l_;b4P3gmoL20?;blPX0moOg3`3oool0
00d0oooo103bl_860?Ogm`80l_;b303gmoL20?;blP80moOg0P3bl_870?Ogm`80l?3`0P2:RXX206IV
IP80Cdm?0P0k>c/205IFEP@0D51@0P1<C4`201DE5@80:2PX0P0R8R8203Lg=`80cLg=0P3Fe]H20=cL
g100f][J103Lg=`20=7Ad@80e=CD0P3AdM430=cLg080dM7A0P3>c/h20<71`@80_[jn0P2][Jd60;Fe
]@80_[jn1P3=cLd20<k>cP80dM7A0P3Fe]H20<k>cP80dM7A0P3=cLd20<c<c080cLg=1031`L420;Rh
^080]kNg0P2/[:`20:n_[`80W9bL0P2?Shl207YjNP80Kfm_0P1BDU8300X:2P80:RXZ0P0X:2P204A4
A080BTY:101EEED206QXJ0@0EEEE0P1mOGd2096AT@80Vi^K0P2e]KD20=;BdP80Ph>30P1lO7`206m_
K`80OGem0P29RHT20;2`/080bLW90P3?cll20?;blQd0moOg0P3bl_880?Ogm`@0l_;b203gmoL?0?oo
o`003@3oool40?;blPH0moOg0P3bl_8<0?Ogm`80l_;b0P3gmoL20?;blPL0moOg0P3`l?0208Z:RP80
IVIV0P1?Cdl203/k>`80EUIF101@D50204a<C0805ADE0P0X:2P2028R8P80=cLg0P3=cLd20=KFeP80
g=cL403Jf]X40=cLg080dM7A0P3De=@20=7Ad@<0g=cL0P3AdM420<k>cP80`L710P2n_[h20:f][@H0
]KFe0P2n_[h60<g=c@80c/k>0P3AdM420=KFeP80c/k>0P3AdM420<g=c@80c<c<0P3=cLd40<71`@80
^;Rh0P2g]kL20:b/[080[jn_0P2LW9`208n?S`80NWYj0P1_Kfl2059BDP<02PX:0P0Z:RX202PX:080
A4A40P1:BTX405EEE@80J6QX101EEED207emO@80TI6A0P2KVi/20;Fe]@80d];B0P23Ph<207alO080
Kfm_0P1mOGd208V9R@80/;2`0P39bLT20<o?c`80l_;b7@3gmoL20?;blPP0moOg103bl_880?Ogm`l0
oooo000=0?ooo`P0moOg0P3bl_8<0?Ogm`80l_;b0P3gmoL20?;blP80moOg2@3bl_8208Z:RP80GemO
101<C4`205IFEP80BTY:0P1<C4`2051@D080:2PX0P0N7Qh202PX:080/;2`103Cdm<20=cLg0P0f][J
1P3Shn<20=[JfPH0g=cL0P3Fe]H20<k>cPD0g=cL0P3=cLd20<71`@H0]KFe0P2m_Kd20;jn_P80a<C4
0P3=cLd20=?Cd`80c/k>103AdM420=cLg080e=CD0P3AdM420<k>cP@0cLg=0P31`L440;jn_P80]KFe
0P2_[jl20:FUY@80Y:BT0P2?Shl207QhN080Kfm_0P1VIVH301hN7P801`L70P0a<C4202PX:080EUIF
0P1NGUh204a<C080GemO0P1XJ6P205EEE@80MGEe0P2QXJ420:BTY080];Bd0P3Bd]8207YjNP80U9BD
0P1NGUh208V9R@80NWYj0P32`/820=;BdP80clo?<@3gmoL20?;blP80moOg3`3oool000d0oooo203g
moL20?;blP`0moOg0P3bl_820?Ogm`80l_;b0P3gmoL90?;blP80RXZ:0P1OGel404a<C080EUIF0P1:
BTX204a<C080D51@0P0X:2P201hN7P80:2PX0P2`/;040=?Cd`80g=cL203Jf]X60>?Sh`80f][J1P3L
g=`20=KFeP80c/k>1@3Lg=`20<g=c@80`L711P2e]KD20;fm_@80_[jn0P34a<@20<g=c@80dm?C0P3>
c/h40=7Ad@80g=cL0P3De=@20=7Ad@80c/k>103=cLd20<71`@@0_[jn0P2e]KD20:n_[`80YJFU0P2T
Y:@208n?S`80N7Qh0P1_Kfl206IVIP<07QhN0P071`L2034a<@80:2PX0P1FEUH205iNGP80C4a<0P1O
Gel206QXJ080EEEE0P1eMGD20:6QX@80Y:BT0P2d];@20=;BdP80NWYj0P2DU9@205iNGP80RHV90P1j
NWX20<;2`P80d];B0P3?clla0?Ogm`80l_;b0P3gmoL?0?ooo`003@3oool60?;blPh0moOg1P3bl_84
0?Ogm`D0l_;b0P3gmoL20<_;b`80MGEe0P1NGUh204A4A0@0EEEE0P1@D50204a<C080:2PX0P0N7Qh2
01DE5@80`L710P3De=@20=7Ad@80g=cL0P3Shn<40=[JfP80hn?S403Jf]X20=cLg080e]KF1@3Lg=`2
0=7Ad@80cLg=0P2n_[h20;Fe]@@0_Kfm0P2n_[h20<C4a0@0c/k>0P3Jf]X20=cLg080dM7A0P3Jf]X2
0=7Ad@80g=cL103De=@20<k>cP80cLg=0P3;bl/20<71`@80_Kfm0P2e]KD20:b/[080YJFU0P2TY:@2
08>3P`80Kfm_0P1XJ6P304A4A080;Bd]0P0k>c/404Y:BP80IVIV0P1EEED206QXJ080GUiN0P1BDU82
07EeM@80[:b/0P2TY:@20;6a/@80a<C40P2ATI4207alO080EEEE0P1mOGd208>3P`80]KFe0P3Hf=P2
0>k^kQ80moOg0`3bl_840?Ogm`@0l_;b103gmoL20?;blP80moOg0P3bl_8>0?Ogm`l0oooo000=0?oo
o`H0l_;b3P3gmoL60?;blP@0moOg1@3bl_820?Ogm`80bl_;0P1eMGD205iNGP80A4A4101EEED2051@
D080C4a<0P0X:2P201hN7P805ADE0P31`L420=CDe080dM7A0P3Lg=`20>?Sh`@0f][J0P3Shn<@0=[J
fP80g=cL0P3Fe]H50=cLg080dM7A0P3=cLd20;jn_P80]KFe102m_Kd20;jn_P80a<C4103>c/h20=[J
fP80g=cL0P3AdM420=[JfP80dM7A0P3Lg=`40=CDe080c/k>0P3=cLd20<_;b`80`L710P2m_Kd20;Fe
]@80[:b/0P2UYJD20:BTY080Ph>30P1_Kfl206QXJ0<0A4A40P0];Bd203/k>`@0BTY:0P1VIVH205EE
E@80J6QX0P1NGUh2059BDP80MGEe0P2/[:`20:BTY080/K6a0P34a<@2096AT@80O7al0P1EEED207em
O@80Ph>30P2e]KD20=SHf080k^k^4P3gmoL30?;blP@0moOg103bl_840?Ogm`80l_;b0P3gmoL20?;b
lPh0moOg3`3oool000d0oooo0P3bl_820?Ogm`80l_;b303gmoL20?;blP@0moOg0P3bl_8;0?Ogm`80
MGEe0P1OGel205EEE@80<C4a0P1IFET404Y:BP80D51@0P0X:2P203/k>`80=cLg0P3=cLd20<k>cP80
f][J0P3Lg=`40=[JfP@0hn?S103Jf]X20=cLg080hn?S203Jf]X20=cLg080e=CD1`3Lg=`20=7Ad@80
_[jn0P2e]KD20;jn_P80`l?31034a<@20<_;b`80dm?C0P3Lg=`20=CDe080g=cL0P3Jf]X20=cLg080
dM7A1P3De=@20<k>cP80cLg=0P34a<@20;jn_P@0]KFe0P2UYJD20:BTY080R8R80P1hN7P2065QH@<0
BTY:1P0k>c/205IFEP80EEEE0P1XJ6P206IVIP80GUiN0P1cLg<208Z:RP80YJFU102TY:@20;6a/@80
U9BD0P1bLW8204m?C`80OGem0P2HV9P20;:b/P80gmoO9@3gmoL20?;blPH0moOg0P3bl_880?Ogm`l0
oooo000=0?ooo`80l_;b0P3gmoL20?;blP`0moOg0P3bl_840?Ogm`80l_;b2`3gmoL207EeM@80GemO
0P1EEED2034a<@80FEUI101:BTX2051@D080:2PX0P0k>c/203Lg=`80cLg=0P3>c/h20=[JfP80g=cL
103Jf]X40>?Sh`@0f][J0P3Lg=`20>?Sh`P0f][J0P3Lg=`20=CDe0L0g=cL0P3AdM420;jn_P80]KFe
0P2n_[h20<?3``@0a<C40P3;bl/20=?Cd`80g=cL0P3De=@20=cLg080f][J0P3Lg=`20=7Ad@H0e=CD
0P3>c/h20<g=c@80a<C40P2n_[h40;Fe]@80YJFU0P2TY:@208R8R080N7Qh0P1QHF4304Y:BPH0>c/k
0P1FEUH205EEE@80J6QX0P1VIVH205iNGP80Lg=c0P2:RXX20:FUY@@0Y:BT0P2a/K4209BDU080LW9b
0P1?Cdl207emO@80V9RH0P2b/[820=oOgbD0moOg0P3bl_860?Ogm`80l_;b203gmoL?0?ooo`003@3o
ool20?;blQH0moOg0P3bl_870?Ogm`80l_;b0P3gmoL207YjNP80J6QX0P1:BTX203/k>`80GUiN0P1F
EUH204a<C080A4A40P0k>c/202PX:080QXJ60P3AdM420=CDe0H0f][J103Shn<20=[JfP80g=cL0P3J
f]X40=cLg080f][J103Shn<40=[JfPD0g=cL0P3Jf]X40=7Ad@80_[jn102e]KD20<?3``80a<C4103=
cLd60=CDe0@0f][J103AdM420=cLg080e]KF0P3Cdm<20<k>cP@0cLg=0P34a<@40;Fe]@80[:b/0P2T
Y:@208n?S`80N7Qh0P1QHF43059BDP@0<C4a0P0k>c/204Y:BP80D51@0P1VIVH206QXJ080IVIV0P1O
Gel80:BTY080[:b/0P2a/K4407=cL`80NWYj0P29RHT20;Bd]080k^k^6`3gmoL20?;blP80moOg0P3b
l_8F0?Ogm`l0oooo000=0?ooo`80l_;b5P3gmoL20?;blPL0moOg0P3bl_820?Ogm`80NWYj0P1XJ6P2
04Y:BP80>c/k0P1NGUh205IFEP80C4a<0P14A4@203/k>`80:2PX0P26QXH20=7Ad@80e=CD1P3Jf]X4
0>?Sh`80f][J0P3Lg=`20=[JfP@0g=cL0P3Jf]X40>?Sh`@0f][J1@3Lg=`20=[JfP@0dM7A0P2n_[h4
0;Fe]@80`l?30P34a<@40<g=c@H0e=CD103Jf]X40=7Ad@80g=cL0P3Fe]H20=?Cd`80c/k>103=cLd2
0<C4a0@0]KFe0P2/[:`20:BTY080Shn?0P1hN7P2065QH@<0DU9B100a<C4203/k>`80BTY:0P1@D502
06IVIP80J6QX0P1VIVH205mOG`P0Y:BT0P2/[:`20;6a/@@0Lg=c0P1jNWX208V9R@80];Bd0P3^k^hK
0?Ogm`80l_;b0P3gmoL20?;blQH0moOg3`3oool000d0oooo103gmoL20?;blP80moOg0P3bl_860?Og
m`80l_;b4@3gmoL20?;blP@0MGEe0P1FEUH204Y:BP80A4A40P1FEUH2051@D080<C4a0P14A4@205IF
EP80c/k>0P3Fe]H20=CDe0h0f][J0P3Lg=`20=[JfP80e=CD203Jf]X40=cLg0<0c/k>103Jf]X20=cL
g080a<C40P2h^;P20;Fe]@80_[jn1034a<@20<_;b`80c/k>1P3De=@20=[JfP80e=CD0P3Lg=`20=CD
e0@0c/k>0P3=cLd20<k>cP80bl_;1034a<@20;Fe]@80[:b/0P2UYJD209bLW080Ph>30P1_Kfl305IF
EP80A4A40P0e=CD403/k>`80EUIF0P1OGel206EUI@80EUIF0P1?Cdl20;:b/P80Y:BT0P2IVIT20:FU
Y@80XJ6Q0P2e]KD205mOG`@0NWYj0P25QHD20;6a/@80l?3`8`3gmoL20?;blQ80moOg3`3oool000d0
oooo103gmoL20?;blP80moOg0P3bl_860?Ogm`80l_;b4@3gmoL20?;blP@0MGEe0P1FEUH204Y:BP80
A4A40P1FEUH2051@D080<C4a0P14A4@205IFEP80c/k>0P3Fe]H20=CDe0h0f][J0P3Lg=`20=[JfP80
e=CD203Jf]X40=cLg0<0c/k>103Jf]X20=cLg080a<C40P2h^;P20;Fe]@80_[jn1034a<@20<_;b`80
c/k>1P3De=@20=[JfP80e=CD0P3Lg=`20=CDe0@0c/k>0P3=cLd20<k>cP80bl_;1034a<@20;Fe]@80
[:b/0P2UYJD209bLW080Ph>30P1_Kfl305IFEP80A4A40P0e=CD403/k>`80EUIF0P1OGel206EUI@80
EUIF0P1?Cdl20;:b/P80Y:BT0P2IVIT20:FUY@80XJ6Q0P2e]KD205mOG`@0NWYj0P25QHD20;6a/@80
l?3`8`3gmoL20?;blQ80moOg3`3oool000d0oooo0P3bl_860?Ogm`80l_;b0P3gmoL20?;blP80moOg
0P3bl_8<0?Ogm`<0l_;b0P3gmoL20:j^[P80GemO0P1UIFD205EEE@80GUiN0P1EEED2059BDP80>c/k
0P0g=cL204A4A080bl_;0P3Lg=`20<k>cP80g=cL203Jf]X20>?Sh`@0f][J0P3Lg=`20=CDe0@0c/k>
103De=@40=cLg080dM7A0`3Fe]H40=[JfP80g=cL0P3=cLd20;Rh^0@0]KFe0P2f][H20<?3``80][Jf
0P3<c<`20=;BdP80c/k>0P3Jf]X60=CDe080c/k>0P3<c<`20<k>cPH0cLg=1034a<@20;Jf]P80]KFe
0P2/[:`209RHV080Shn?0P1_Kfl305mOG`80BTY:0P0X:2P403/k>`80BTY:0P1_Kfl605iNGP80XJ6Q
0P2IVIT40:BTY080Kfm_0P32`/8204U9B@80Kfm_0P2ATI4209VIV@80/;2`8@3gmoL20?;blQH0moOg
3`3oool000d0oooo0P3bl_860?Ogm`80l_;b0P3gmoL20?;blP80moOg0P3bl_8<0?Ogm`<0l_;b0P3g
moL20:j^[P80GemO0P1UIFD205EEE@80GUiN0P1EEED2059BDP80>c/k0P0g=cL204A4A080bl_;0P3L
g=`20<k>cP80g=cL203Jf]X20>?Sh`@0f][J0P3Lg=`20=CDe0@0c/k>103De=@40=cLg080dM7A0`3F
e]H40=[JfP80g=cL0P3=cLd20;Rh^0@0]KFe0P2f][H20<?3``80][Jf0P3<c<`20=;BdP80c/k>0P3J
f]X60=CDe080c/k>0P3<c<`20<k>cPH0cLg=1034a<@20;Jf]P80]KFe0P2/[:`209RHV080Shn?0P1_
Kfl305mOG`80BTY:0P0X:2P403/k>`80BTY:0P1_Kfl605iNGP80XJ6Q0P2IVIT40:BTY080Kfm_0P32
`/8204U9B@80Kfm_0P2ATI4209VIV@80/;2`8@3gmoL20?;blQH0moOg3`3oool000d0oooo1P3gmoL2
0?;blP@0moOg0P3bl_8@0?Ogm`<0l_;b0P3gmoL207moO`80T92@0P1_Kfl204Y:BP80Kfm_0P1:BTX2
059BDP80<C4a0P1:BTX204a<C080bl_;0P3AdM420<_;b`@0f][J0P3Shn<40=[JfP80g=cL0P3Jf]X4
0=CDe080`L710P3;bl/40<g=c@80c/k>0P3De=@20=cLg080dm?C0`3Fe]H20=cLg080f][J0P3Lg=`2
0<g=c@80/k>c0P2e]KD20:f][@@0]KFe0P34a<@20<c<c080c/k>0P3De=@40<_;b`80a<C4203;bl/2
0<g=c@80c/k>103;bl/20;Zj^P80`l?30P2e]KD20:b/[080Y:BT0P2?Shl207YjNP<0GemO0P1@D502
02PX:0808R8R0P0k>c/204Y:BP80GUiN0P1XJ6P405iNGP80XJ6Q102LW9`20:BTY080D51@0P2d];@2
065QH@80GUiN0P2:RXX20:b/[080bl_;1P3gmoL20?;blQT0moOg0P3bl_8F0?Ogm`l0oooo000=0?oo
o`H0moOg0P3bl_840?Ogm`80l_;b403gmoL30?;blP80moOg0P1oOgl2092@T080Kfm_0P1:BTX206m_
K`80BTY:0P1BDU82034a<@80BTY:0P1<C4`20<_;b`80dM7A0P3;bl/40=[JfP80hn?S103Jf]X20=cL
g080f][J103De=@20<71`@80bl_;103=cLd20<k>cP80e=CD0P3Lg=`20=?Cd`<0e]KF0P3Lg=`20=[J
fP80g=cL0P3=cLd20;>c/`80]KFe0P2][Jd40;Fe]@80a<C40P3<c<`20<k>cP80e=CD103;bl/20<C4
a0P0bl_;0P3=cLd20<k>cP@0bl_;0P2j^[X20<?3``80]KFe0P2/[:`20:BTY080Shn?0P1jNWX305mO
G`80D51@0P0X:2P2028R8P80>c/k0P1:BTX205iNGP80J6QX101NGUh20:6QX@@0W9bL0P2TY:@2051@
D080];Bd0P1QHF4205iNGP80RXZ:0P2/[:`20<_;b`H0moOg0P3bl_8I0?Ogm`80l_;b5P3gmoL?0?oo
o`003@3oool60?Ogm`80l_;b1P3gmoL20?;blPH0moOg203bl_850?Ogm`80DE5A0P2FUYH205iNGP80
KFe]0P1LG5`205iNGP80BTY:0P0X:2P206QXJ080]kNg0P3=cLd20;Rh^080c/k>0P3Lg=`80=[JfP80
e=CD0P3Bd]840<k>cP80cLg=0P2f][H20;Fe]@80a<C40P3;bl/20<k>cP80e=CD0P3;bl/30<k>cP@0
f][J0P3Lg=`20<71`@80]KFe0P2XZ:P20;:b/P80[Jf]0P2`/;020;Zj^P80bl_;0P3<c<`40<C4a080
^[Zj0P2i^KT40;Fe]@80[Jf]102f][H60<C4a0@0`l?30P2e]KD20:b/[080W9bL0P2@T90207QhN0<0
Kfm_0P1FEUH204A4A0805ADE0P0];Bd203/k>`@0GUiN0P1_Kfl205IFEP80V9RH0P2UYJD208>3P`80
TI6A0P1?Cdl20<;2`P80Kfm_0P1BDU8209VIV@80/K6a0P3Hf=P@0?Ogm`80l_;b5`3gmoL20?;blPh0
moOg3`3oool000d0oooo1P3gmoL20?;blPH0moOg0P3bl_860?Ogm`P0l_;b1@3gmoL2055AD@80UYJF
0P1NGUh206e]K@80G5aL0P1NGUh204Y:BP80:2PX0P1XJ6P20;Ng]`80cLg=0P2h^;P20<k>cP80g=cL
203Jf]X20=CDe080d];B103>c/h20<g=c@80][Jf0P2e]KD20<C4a080bl_;0P3>c/h20=CDe080bl_;
0`3>c/h40=[JfP80g=cL0P31`L420;Fe]@80Z:RX0P2b/[820:f][@80/;2`0P2j^[X20<_;b`80c<c<
1034a<@20;Zj^P80^KVi102e]KD20:f][@@0][Jf1P34a<@40<?3``80]KFe0P2/[:`209bLW080T92@
0P1hN7P306m_K`80EUIF0P14A4@201DE5@80;Bd]0P0k>c/405iNGP80Kfm_0P1FEUH209RHV080YJFU
0P23Ph<2096AT@80Cdm?0P32`/8206m_K`80DU9B0P2IVIT20;6a/@80f=SH403gmoL20?;blQL0moOg
0P3bl_8>0?Ogm`l0oooo000=0?oooa80moOg0P3bl_820?Ogm`80l_;b2@3gmoL20?ooo`80Kfm_0P1o
Ogl205IFEP80GUiN0P1FEUH2065QH@808R8R0P1EEED2051@D080dM7A0P2LW9`20:n_[`80dm?C0P3L
g=`60=[JfP80e=CD0P3<c<`20;Jf]P80V9RH0P2@T9020:f][@80Zj^[0P2HV9P40;Jf]P@0e=CD1@3>
c/h60=cLg080cLg=0P2e]KD20:FUY@80XJ6Q0P2UYJD20<?3``80][Jf0P3<c<`20;Vi^@80][Jf0P2Z
ZZX209nOW`80RXZ:0P2@T9060:6QX@80Zj^[0P33`l<20<C4a0H0][Jf0P2e]KD20:b/[080XJ6Q0P2@
T90208>3P`<0HF5Q0P1FEUH204Y:BP80>c/k100a<C4205IFEP80EEEE0P1UIFD205iNGP80RXZ:0P2A
TI4408>3P`80GemO0P32`/8205mOG`80DU9B0P2QXJ420:BTY080fMWI0P3ooolg0?Ogm`l0oooo000=
0?oooa80moOg0P3bl_820?Ogm`80l_;b2@3gmoL20?ooo`80Kfm_0P1oOgl205IFEP80GUiN0P1FEUH2
065QH@808R8R0P1EEED2051@D080dM7A0P2LW9`20:n_[`80dm?C0P3Lg=`60=[JfP80e=CD0P3<c<`2
0;Jf]P80V9RH0P2@T9020:f][@80Zj^[0P2HV9P40;Jf]P@0e=CD1@3>c/h60=cLg080cLg=0P2e]KD2
0:FUY@80XJ6Q0P2UYJD20<?3``80][Jf0P3<c<`20;Vi^@80][Jf0P2ZZZX209nOW`80RXZ:0P2@T906
0:6QX@80Zj^[0P33`l<20<C4a0H0][Jf0P2e]KD20:b/[080XJ6Q0P2@T90208>3P`<0HF5Q0P1FEUH2
04Y:BP80>c/k100a<C4205IFEP80EEEE0P1UIFD205iNGP80RXZ:0P2ATI4408>3P`80GemO0P32`/82
05mOG`80DU9B0P2QXJ420:BTY080fMWI0P3ooolg0?Ogm`l0oooo000=0?ooo`80l_;b203gmoL20?;b
lP80moOg0P3bl_8A0?Ogm`80X:2P0P1mOGd207EeM@80BTY:0P1FEUH204Y:BP80HF5Q0P0a<C4205mO
G`80`<300P31`L420:6QX@80[Jf]0P3Cdm<20=CDe0@0f][J0P3>c/h20;Vi^@80RHV90P2ATI420;Jf
]P80[Zj^0P1UIFD206][J`80QXJ60P2QXJ4409RHV0@0c/k>0`3;bl/60=cLg080c<c<0P2n_[h20:FU
Y@80[:b/0P2HV9P20:b/[080EeMG0P1aLG42092@T080[Jf]0P3;bl/207]kN`80EeMG101oOgl207em
O@80Ogmo0P2:RXX20:f][@@0]KFe102f][H40:f][@80W9bL0P2@T90207QhN0<0Kfm_0P1NGUh204Y:
BP80EUIF100X:2P405IFEP80GUiN0P1_Kfl208V9R@80V9RH0P1lO7`208>3P`80FEUI0P33`l<206QX
J080MGEe102a/K420>WYjAl0moOg0P3bl_8H0?Ogm`l0oooo000=0?ooo`80l_;b203gmoL20?;blP80
moOg0P3bl_8A0?Ogm`80X:2P0P1mOGd207EeM@80BTY:0P1FEUH204Y:BP80HF5Q0P0a<C4205mOG`80
`<300P31`L420:6QX@80[Jf]0P3Cdm<20=CDe0@0f][J0P3>c/h20;Vi^@80RHV90P2ATI420;Jf]P80
[Zj^0P1UIFD206][J`80QXJ60P2QXJ4409RHV0@0c/k>0`3;bl/60=cLg080c<c<0P2n_[h20:FUY@80
[:b/0P2HV9P20:b/[080EeMG0P1aLG42092@T080[Jf]0P3;bl/207]kN`80EeMG101oOgl207emO@80
Ogmo0P2:RXX20:f][@@0]KFe102f][H40:f][@80W9bL0P2@T90207QhN0<0Kfm_0P1NGUh204Y:BP80
EUIF100X:2P405IFEP80GUiN0P1_Kfl208V9R@80V9RH0P1lO7`208>3P`80FEUI0P33`l<206QXJ080
MGEe102a/K420>WYjAl0moOg0P3bl_8H0?Ogm`l0oooo000=0?oooaH0moOg0P3bl_890?Ogm`80RXZ:
0P2OWil207EeM@80IFEU0P0a<C4205IFEP80HF5Q0P0e=CD202PX:080dM7A0P2g]kL20;>c/`80]KFe
0P3De=@20=cLg080e=CD0P3;bl/20;Vi^@80RXZ:0P2@T9020<71`@80fMWI0P1^KVh206EUI@80De=C
0P1fMWH207moO`80XJ6Q0P2HV9P20;Vi^@80]KFe0`3<c<`40=cLg080dm?C0P3=cLd20;jn_P80[jn_
0P2HV9P208Z:RP80T92@0P2QXJ4205QHF080bl_;0P3YjNT2079bLP80Lg=c0P1VIVH208R8R080G5aL
0P2PX:0207EeM@80Jf][0P2:RXX40:b/[0@0]KFe0P2][Jd20:FUY@80Y:BT0P2:RXX207YjNP<0Kfm_
0P1EEED204Y:BP80<C4a0P0:2PX201hN7P80EUIF0P1NGUh204A4A080Kfm_0P2:RXX208V9R@80Kfm_
0P1mOGd206i^KP80]KFe0P1?Cdl209RHV0@0/[:b6`3gmoL20?;blPH0moOg0P3bl_8F0?Ogm`l0oooo
000=0?oooaH0moOg0P3bl_890?Ogm`80RXZ:0P2OWil207EeM@80IFEU0P0a<C4205IFEP80HF5Q0P0e
=CD202PX:080dM7A0P2g]kL20;>c/`80]KFe0P3De=@20=cLg080e=CD0P3;bl/20;Vi^@80RXZ:0P2@
T9020<71`@80fMWI0P1^KVh206EUI@80De=C0P1fMWH207moO`80XJ6Q0P2HV9P20;Vi^@80]KFe0`3<
c<`40=cLg080dm?C0P3=cLd20;jn_P80[jn_0P2HV9P208Z:RP80T92@0P2QXJ4205QHF080bl_;0P3Y
jNT2079bLP80Lg=c0P1VIVH208R8R080G5aL0P2PX:0207EeM@80Jf][0P2:RXX40:b/[0@0]KFe0P2]
[Jd20:FUY@80Y:BT0P2:RXX207YjNP<0Kfm_0P1EEED204Y:BP80<C4a0P0:2PX201hN7P80EUIF0P1N
GUh204A4A080Kfm_0P2:RXX208V9R@80Kfm_0P1mOGd206i^KP80]KFe0P1?Cdl209RHV0@0/[:b6`3g
moL20?;blPH0moOg0P3bl_8F0?Ogm`l0oooo000=0?oooa00moOg0P3bl_8<0?Ogm`<0oooo0P3bl_82
08F5Q@80EEEE0P1<C4`2034a<@H0EUIF0P1QHF420=7Ad@80[jn_0P2QXJ420;Fe]@80c<c<0P3Cdm<2
0<g=c@80][Jf0P2HV9P207=cL`80=cLg0P2HV9P20;Ng]`80NWYj0P2b/[8200h>3P80L71`0P14A4@2
07=cL`80RXZ:0P2HV9P20;jn_P<0d];B103Lg=`20=KFeP80cLg=0P33`l<20;fm_@80V9RH0P2@T902
07EeM@80T92@0P2HV9P206m_K`80aLG50P1CDe<20;Vi^@803Ph>0P1[Jf/205=CD`80X:2P0P0Z:RX2
055AD@80Ogmo0P2@T90209RHV080[:b/0P2][Jd20:b/[080V9RH0P2IVIT208n?S`80NWYj0`1QHF42
05IFEP80D51@0P0N7Qh201DE5@807QhN0P0X:2P205IFEP80BTY:0P1jNWX207EeM@@0OGem0P23Ph<2
06i^KP80/K6a0P1?Cdl2096AT@80YJFU0P39bLTk0?Ogm`l0oooo000=0?oooa00moOg0P3bl_8<0?Og
m`<0oooo0P3bl_8208F5Q@80EEEE0P1<C4`2034a<@H0EUIF0P1QHF420=7Ad@80[jn_0P2QXJ420;Fe
]@80c<c<0P3Cdm<20<g=c@80][Jf0P2HV9P207=cL`80=cLg0P2HV9P20;Ng]`80NWYj0P2b/[8200h>
3P80L71`0P14A4@207=cL`80RXZ:0P2HV9P20;jn_P<0d];B103Lg=`20=KFeP80cLg=0P33`l<20;fm
_@80V9RH0P2@T90207EeM@80T92@0P2HV9P206m_K`80aLG50P1CDe<20;Vi^@803Ph>0P1[Jf/205=C
D`80X:2P0P0Z:RX2055AD@80Ogmo0P2@T90209RHV080[:b/0P2][Jd20:b/[080V9RH0P2IVIT208n?
S`80NWYj0`1QHF4205IFEP80D51@0P0N7Qh201DE5@807QhN0P0X:2P205IFEP80BTY:0P1jNWX207Ee
M@@0OGem0P23Ph<206i^KP80/K6a0P1?Cdl2096AT@80YJFU0P39bLTk0?Ogm`l0oooo000=0?oooah0
moOg0`2FUYH20<S8b080Rh^;0P1cLg<205ADE080BTY:101FEUH2065QH@80QhN70P31`L420:6QX@80
YJFU0P2e]KD20<k>cP80dm?C0P2n_[h20:^[Z`80T92@0P1:BTX406=SH`80?Shn0P0T92@203Lg=`80
EUIF0P1[Jf/206=SH`80Ogmo0P2HV9P20;Rh^080a/K61@3Fe]H20=cLg080e]KF0P3=cLd20<K6aP80
_[jn0P2_[jl209RHV080T92@0P1jNWX207=cL`@0SHf=0P0g=cL202PX:0@0=cLg0P1:BTX203hn?P80
EeMG0P1DE5@207moO`80RHV90P2:RXX209bLW0@0YJFU0P2HV9P208Z:RP80Ph>30P1QHF4505iNGP80
BTY:0P0k>c/201hN7P80=cLg100k>c/204Y:BP80Kfm_0P1jNWX206m_K`80J6QX0P23Ph<207YjNP80
/K6a0P1VIVH2096AT@80Y:BT0P3Xj>P[0?Ogm`80l_;b3P3gmoL?0?ooo`003@3ooolN0?Ogm`<0UYJF
0P38b<P208^;R`80Lg=c0P1DE5@204Y:BP@0EUIF0P1QHF4208N7Q`80`L710P2QXJ420:FUY@80]KFe
0P3>c/h20=?Cd`80_[jn0P2[Zj/2092@T080BTY:101SHf<203hn?P8092@T0P0g=cL205IFEP80Jf][
0P1SHf<207moO`80V9RH0P2h^;P20<K6aPD0e]KF0P3Lg=`20=KFeP80cLg=0P36a/H20;jn_P80[jn_
0P2HV9P2092@T080NWYj0P1cLg<408f=S@80=cLg0P0X:2P403Lg=`80BTY:0P0n?Sh205MGE`80E5AD
0P1oOgl208V9R@80RXZ:0P2LW9`40:FUY@80V9RH0P2:RXX208>3P`80HF5Q1@1NGUh204Y:BP80>c/k
0P0N7Qh203Lg=`@0>c/k0P1:BTX206m_K`80NWYj0P1_Kfl206QXJ080Ph>30P1jNWX20;6a/@80IVIV
0P2ATI420:BTY080j>SX:`3gmoL20?;blPh0moOg3`3oool000d0oooo203gmoL20?;blPH0moOg0P3b
l_8<0?Ogm`<0NWYj0P2PX:0209fMW@80GUiN0P1:BTX206EUI@80EUIF0P1:BTX2059BDP80Shn?0P2c
/k<40:FUY@80]KFe0P3>c/h20<c<c080bl_;0P34a<@20;Fe]@80V9RH0P1hN7P206EUI@H0E5AD0P1F
EUH207=cL`80T92@0P2/[:`20;jn_P@0cLg=0`3Fe]H40=cLg080e]KF103=cLd20<c<c080_Kfm0P2_
[jl20:FUY@80V9RH0P2:RXX2069RHP80Ogmo0P26QXH207emO@80Hf=S0P17AdL203hn?P80BTY:0P1e
MGD2096AT@@0T92@0P2LW9`40:FUY@80V9RH0P2LW9`2096AT@80N7Qh0P1QHF4305iNGP@0EUIF0P14
A4@202PX:080=cLg100a<C4204A4A080MGEe0P23Ph<207EeM@80J6QX0P23Ph<2096AT@80/K6a0P1_
Kfl2096AT@80[:b/0P3^k^hk0?Ogm`l0oooo000=0?ooo`P0moOg0P3bl_860?Ogm`80l_;b303gmoL3
07YjNP80X:2P0P2MWId205iNGP80BTY:0P1UIFD205IFEP80BTY:0P1BDU8208n?S`80/k>c102UYJD2
0;Fe]@80c/k>0P3<c<`20<_;b`80a<C40P2e]KD209RHV080N7Qh0P1UIFD605ADE080EUIF0P1cLg<2
092@T080[:b/0P2n_[h40<g=c@<0e]KF103Lg=`20=KFeP@0cLg=0P3<c<`20;fm_@80[jn_0P2UYJD2
09RHV080RXZ:0P1RHV8207moO`80QXJ60P1mOGd206=SH`80AdM70P0n?Sh204Y:BP80MGEe0P2ATI44
092@T080W9bL102UYJD209RHV080W9bL0P2ATI4207QhN080HF5Q0`1NGUh405IFEP80A4A40P0X:2P2
03Lg=`@0<C4a0P14A4@207EeM@80Ph>30P1eMGD206QXJ080Ph>30P2ATI420;6a/@80Kfm_0P2ATI42
0:b/[080k^k^>`3gmoL?0?ooo`003@3ooolH0?Ogm`80l_;b103gmoL30>SXj080S8b<0P1]KFd204Y:
BP80A4A4101:BTX203/k>`80Kfm_0P2?Shl209bLW080XJ6Q0P2HV9P20:f][@80c<c<103Cdm<20=cL
g080e=CD0P3=cLd20<k>cP80a<C40P2n_[h20;Vi^@80_[jn0P34a<@20;jn_P80YJFU0P2_[jl20;Rh
^080c<c<0P3Lg=`30=KFeP@0f][J0P3Lg=`20=KFeP80d];B0P3=cLd20;fm_@80Y:BT0P2XZ:P209RH
V080[:b/0P2][Jd20:b/[0H0V9RH0P2LW9`20:FUY@@0[:b/0P2e]KD20;Ng]`80]KFe0P2][Jd20:b/
[080YJFU0P2LW9`2092@T080TI6A0P23Ph<2065QH@<0IFEU0P1FEUH403/k>`80:2PX0P0g=cL204Y:
BP80A4A40P0k>c/206m_K`80TI6A0P1_Kfl206QXJ080SXj>0P2HV9P20;Fe]@80MGEe0P2HV9P20>3P
h080oooo=`3gmoL20?;blP80moOg3`3oool000d0oooo603gmoL20?;blP@0moOg0`3Xj>P208b<S080
KFe]0P1:BTX204A4A0@0BTY:0P0k>c/206m_K`80Shn?0P2LW9`20:6QX@80V9RH0P2][Jd20<c<c0@0
dm?C0P3Lg=`20=CDe080cLg=0P3>c/h20<C4a080_[jn0P2i^KT20;jn_P80a<C40P2n_[h20:FUY@80
[jn_0P2h^;P20<c<c080g=cL0`3Fe]H40=[JfP80g=cL0P3Fe]H20=;BdP80cLg=0P2m_Kd20:BTY080
Z:RX0P2HV9P20:b/[080[Jf]0P2/[:`609RHV080W9bL0P2UYJD40:b/[080]KFe0P2g]kL20;Fe]@80
[Jf]0P2/[:`20:FUY@80W9bL0P2@T902096AT@80Ph>30P1QHF4306EUI@80EUIF100k>c/202PX:080
=cLg0P1:BTX204A4A080>c/k0P1_Kfl2096AT@80Kfm_0P1XJ6P208j>SP80V9RH0P2e]KD207EeM@80
V9RH0P3Ph>020?ooocL0moOg0P3bl_820?Ogm`l0oooo000=0?ooo`@0moOg0P3bl_840?Ogm`80l_;b
2P3gmoL20?;blP@0moOg1@3oool204A4A080GUiN0P0a<C4403/k>`80IVIV0P0a<C4205MGE`80N7Qh
0P2HV9P209bLW080T92@0P2/[:`20=?Cd`80a<C40P3Fe]H40=cLg080f][J103Lg=`20=[JfP80/k>c
0P2@T90207moO`80MGEe0P1hN7P20;jn_P80c<c<1`3Lg=`20>?Sh`80f][J0P3Lg=`20=[JfP80e]KF
0P3Lg=`20<K6aP80^;Rh0P2@T90206i^KP80MGEe0P1hN7P2092@T080a<C40P3;bl/20<g=c@80bl_;
1034a<@60;jn_P80]KFe0P2/[:`209VIV@80RHV90P2LW9`2096AT@80Ph>30P1jNWX206m_K`<0GUiN
0P1EEED205IFEP80;Bd]100X:2P203Lg=`808R8R0P1:BTX205iNGP80NWYj0P1_Kfl206IVIP80U9BD
0P2IVIT20<?3``80OGem0P2QXJ420>WYjCd0moOg3`3oool000d0oooo103gmoL20?;blP@0moOg0P3b
l_8:0?Ogm`80l_;b103gmoL50?ooo`80A4A40P1NGUh2034a<@@0>c/k0P1VIVH2034a<@80EeMG0P1h
N7P209RHV080W9bL0P2@T9020:b/[080dm?C0P34a<@20=KFeP@0g=cL0P3Jf]X40=cLg080f][J0P2c
/k<2092@T080Ogmo0P1eMGD207QhN080_[jn0P3<c<`70=cLg080hn?S0P3Jf]X20=cLg080f][J0P3F
e]H20=cLg080a/K60P2h^;P2092@T080KVi^0P1eMGD207QhN080T92@0P34a<@20<_;b`80cLg=0P3;
bl/40<C4a0H0_[jn0P2e]KD20:b/[080VIVI0P29RHT209bLW080TI6A0P23Ph<207YjNP80Kfm_0`1N
GUh205EEE@80EUIF0P0];Bd402PX:080=cLg0P0R8R8204Y:BP80GUiN0P1jNWX206m_K`80IVIV0P2D
U9@209VIV@80`l?30P1mOGd20:6QX@80jNWY?@3gmoL?0?ooo`003@3ooolL0?Ogm`80jNWY0`3oool2
03/k>`80C4a<0P0a<C4203/k>`80BTY:0P1FEUH204Y:BP80J6QX0P1aLG4208>3P`80TI6A0P2@T902
0:6QX@80cLg=0P39bLT20<?3``80c/k>0P3Lg=`40=[JfP80dM7A0P2:RXX207moO`80Lg=c0P1hN7P2
0:b/[080c<c<103Fe]H20=cLg080hn?S0`3Lg=`20>?Sh`80f][J1P3Lg=`40=KFeP80c<c<0P2h^;P2
096AT@80HF5Q0P1FEUH2065QH@80N7Qh0P2_[jl20;Vi^@80bl_;103=cLd20<71`@80a<C40P2e]KD2
0:n_[`80V9RH0P1mOGd209bLW080T92@0P2:RXX207YjNP@0Kfm_0`1NGUh403/k>`80:2PX0P0a<C42
02PX:0808R8R0P1ADE4205aLG080KFe]0P1mOGd207EeM@80GemO102ATI420;:b/P80V9RH0P2QXJ4o
0?Ogm`l0oooo000=0?oooa`0moOg0P3YjNT30?ooo`80>c/k0P1<C4`2034a<@80>c/k0P1:BTX205IF
EP80BTY:0P1XJ6P2075aL@80Ph>30P2ATI42092@T080XJ6Q0P3=cLd20<W9b@80`l?30P3>c/h20=cL
g0@0f][J0P3AdM4208Z:RP80Ogmo0P1cLg<207QhN080[:b/0P3<c<`40=KFeP80g=cL0P3Shn<30=cL
g080hn?S0P3Jf]X60=cLg0@0e]KF0P3<c<`20;Rh^080TI6A0P1QHF4205IFEP80HF5Q0P1hN7P20:n_
[`80^KVi0P3;bl/40<g=c@80`L710P34a<@20;Fe]@80[jn_0P2HV9P207emO@80W9bL0P2@T90208Z:
RP80NWYj101_Kfl305iNGP@0>c/k0P0X:2P2034a<@80:2PX0P0R8R82055AD@80G5aL0P1]KFd207em
O@80MGEe0P1OGel4096AT@80/[:b0P2HV9P20:6QXCl0moOg3`3oool000d0oooo5P3gmoL20?;blP80
moOg0P3oool20:j^[P<0oooo0P1EEED204A4A0@0BTY:0P0a<C4205IFEP80C4a<0P1OGel4065QH@80
Ogmo0P2:RXX20:6QX@80c<c<0P3De=@209RHV080XJ6Q0P2/[:`20:FUY@80V9RH0P1hN7P207YjNP80
YJFU0P3Fe]H40=cLg0d0hn?S203Jf]X20=cLg080f][J1P3Fe]H20=;BdP80_[jn0P2/[:`2092@T080
Lg=c0P1NGUh207EeM@80KVi^0P20P804092@T080RHV90P1oOgl207emO@80RXZ:1P2HV9P2096AT@80
NWYj101_Kfl305IFEP80Kfm_0P0N7Qh404A4A080>c/k0P0X:2P202@T9080HV9R0P1_Kfl207YjNP80
Kfm_0P1VIVH2096AT@80Y:BT0P2:RXX207=cL`80clo?8`3gmoL20?;blQX0moOg3`3oool000d0oooo
5P3gmoL20?;blP80moOg0P3oool20:j^[P<0oooo0P1EEED204A4A0@0BTY:0P0a<C4205IFEP80C4a<
0P1OGel4065QH@80Ogmo0P2:RXX20:6QX@80c<c<0P3De=@209RHV080XJ6Q0P2/[:`20:FUY@80V9RH
0P1hN7P207YjNP80YJFU0P3Fe]H40=cLg0d0hn?S203Jf]X20=cLg080f][J1P3Fe]H20=;BdP80_[jn
0P2/[:`2092@T080Lg=c0P1NGUh207EeM@80KVi^0P20P804092@T080RHV90P1oOgl207emO@80RXZ:
1P2HV9P2096AT@80NWYj101_Kfl305IFEP80Kfm_0P0N7Qh404A4A080>c/k0P0X:2P202@T9080HV9R
0P1_Kfl207YjNP80Kfm_0P1VIVH2096AT@80Y:BT0P2:RXX207=cL`80clo?8`3gmoL20?;blQX0moOg
3`3oool000d0oooo5P3gmoL20?;blP@0moOg0P2YZJT307EeM@@0BTY:0P1RHV8205IFEPH0BTY:0P1F
EUH205mOG`80IFEU0P1eMGD207emO@80[:b/0P3<c<`40=?Cd`80cLg=0P2/[:`209nOW`80V9RH0P2f
][H20=[JfQ80hn?S0`3Ti>@40=[JfPH0hn?S103Lg=`20=[JfP80g=cL0P3Fe]H20=7Ad@H0cLg=103;
bl/20:6QX@80Ogmo0P1jNWX407moO`80V9RH0P2QXJ4209RHV080W9bL0P2TY:@209bLW080TI6A0P1j
NWX207EeM@80NWYj0`1FEUH203/k>`80BTY:0P0k>c/2034a<@@05ADE0P0N7Qh206EUI@80Lg=c0P1N
GUh207emO@80KVi^0P2IVIT20:6QX@80Kfm_0P2ATI420>WYjBL0moOg0P3bl_8F0?Ogm`l0oooo000=
0?oooaH0moOg0P3bl_840?Ogm`80ZJVY0`1eMGD404Y:BP80HV9R0P1FEUH604Y:BP80EUIF0P1OGel2
06EUI@80MGEe0P1mOGd20:b/[080c<c<103Cdm<20<g=c@80[:b/0P2OWil209RHV080][Jf0P3Jf]XB
0>?Sh`<0i>CT103Jf]X60>?Sh`@0g=cL0P3Jf]X20=cLg080e]KF0P3AdM460<g=c@@0bl_;0P2QXJ42
07moO`80NWYj101oOgl209RHV080XJ6Q0P2HV9P209bLW080Y:BT0P2LW9`2096AT@80NWYj0P1eMGD2
07YjNP<0EUIF0P0k>c/204Y:BP80>c/k0P0a<C4401DE5@807QhN0P1UIFD207=cL`80GUiN0P1mOGd2
06i^KP80VIVI0P2QXJ4206m_K`80TI6A0P3YjNTW0?Ogm`80l_;b5P3gmoL?0?ooo`003@3oool80?Og
m`80l_;b1P3gmoL20?;blPX0moOg0P38b<P306m_K`80FEUI0P1:BTX207emO@80Jf][0P1IFET205IF
EP80BTY:101NGUh206EUI@@0NWYj0P2UYJD20<g=c@80c/k>103Cdm<40=cLg0H0f][J3P3Shn<20>CT
i0D0hn?S0P3Jf]X60>?Sh`X0f][J0P3Lg=`40=?Cd`80e]KF1P3=cLd20<C4a0@0bl_;0P2n_[h40;Fe
]@80[Jf]0P2UYJD20:b/[080V9RH0P2@T90208>3P`80NWYj0P1mOGd207YjNP<0Kfm_0P1:BTX203/k
>`808R8R1P0E5AD201hN7P80T92@0P1UIFD205iNGP80Y:BT0P1_Kfl208>3P`80/K6a0P1_Kfl20:6Q
XD40moOg3`3oool000d0oooo203gmoL20?;blPH0moOg0P3bl_8:0?Ogm`80b<S80`1_Kfl205UIF@80
BTY:0P1mOGd206][J`80FEUI0P1FEUH204Y:BP@0GUiN0P1UIFD407YjNP80YJFU0P3=cLd20<k>cP@0
dm?C103Lg=`60=[JfPh0hn?S0P3Ti>@50>?Sh`80f][J1P3Shn<:0=[JfP80g=cL103Cdm<20=KFePH0
cLg=0P34a<@40<_;b`80_[jn102e]KD20:f][@80YJFU0P2/[:`209RHV080T92@0P23Ph<207YjNP80
OGem0P1jNWX306m_K`80BTY:0P0k>c/2028R8PH05ADE0P0N7Qh2092@T080IFEU0P1NGUh20:BTY080
Kfm_0P23Ph<20;6a/@80Kfm_0P2QXJ510?Ogm`l0oooo000=0?ooo`@0moOg0P3bl_880?Ogm`80l_;b
303gmoL20;Ng]`<0Cdm?0P1ADE4205aLG080Rh^;0P1]KFd205IFEP80G5aL0P1IFET405aLG080GUiN
0P1mOGd207EeM@80YJFU0P3;bl/40=?Cd`80e=CD103Lg=`20=[JfP@0hn?S0P3Jf]X20=cLg0H0hn?S
0P3Lg=`90>?Sh`80g=cL0P3Jf]X20>?Sh`@0f][J0P3Shn<20=[JfPP0g=cL0P3AdM420=KFeP80c/k>
0P3=cLd20<_;b`80a<C40P3=cLd40;jn_P80]KFe102/[:`40:FUY@80V9RH0P2IVIT2096AT@80N7Qh
101jNWX305iNGP80Kfm_0P14A4@402PX:0807QhN0P0a<C42028R8P80V9RH0P1mOGd205iNGP80V9RH
0P1jNWX206m_K`80/[:b0P1_Kfl20<30`080oooo?`3gmoL?0?ooo`003@3oool40?Ogm`80l_;b203g
moL20?;blP`0moOg0P2g]kL304m?C`80DE5A0P1LG5`208^;R`80KFe]0P1FEUH205aLG080FEUI101L
G5`205iNGP80OGem0P1eMGD20:FUY@80bl_;103Cdm<20=CDe0@0g=cL0P3Jf]X40>?Sh`80f][J0P3L
g=`60>?Sh`80g=cL2@3Shn<20=cLg080f][J0P3Shn<40=[JfP80hn?S0P3Jf]X80=cLg080dM7A0P3F
e]H20<k>cP80cLg=0P3;bl/20<C4a080cLg=102n_[h20;Fe]@@0[:b/102UYJD209RHV080VIVI0P2A
TI4207QhN0@0NWYj0`1NGUh206m_K`80A4A4100X:2P201hN7P80<C4a0P0R8R8209RHV080OGem0P1N
GUh209RHV080NWYj0P1_Kfl20;:b/P80Kfm_0P30`<020?ooocl0moOg3`3oool000d0oooo703gmoL2
0=3@d0<0EUIF0P1[Jf/206EUI@80MGEe0P1UIFD206][J`80IFEU0P1LG5`205IFEP@0EEEE0P1_Kfl2
07EeM@80T92@0P33`l<20<k>cP@0dm?C0P3De=@40=cLg080f][J103Shn<20=cLg1/0hn?S1P3Jf]X:
0=KFeP80cLg=0P3<c<`20<_;b`80cLg=0P34a<@20<?3``80_Kfm102e]KD20:f][@80[:b/0P2UYJD2
0:BTY080W9bL0P23Ph<207YjNP80Ph>30P1eMGD306m_K`80BTY:0P0a<C4203/k>`80<C4a100E5AD2
01hN7P80VIVI0P1oOgl206m_K`80Y:BT0P1lO7`206EUI@80V9RH0P1_Kfl20?;blT40moOg3`3oool0
00d0oooo703gmoL20=3@d0<0EUIF0P1[Jf/206EUI@80MGEe0P1UIFD206][J`80IFEU0P1LG5`205IF
EP@0EEEE0P1_Kfl207EeM@80T92@0P33`l<20<k>cP@0dm?C0P3De=@40=cLg080f][J103Shn<20=cL
g1/0hn?S1P3Jf]X:0=KFeP80cLg=0P3<c<`20<_;b`80cLg=0P34a<@20<?3``80_Kfm102e]KD20:f]
[@80[:b/0P2UYJD20:BTY080W9bL0P23Ph<207YjNP80Ph>30P1eMGD306m_K`80BTY:0P0a<C4203/k
>`80<C4a100E5AD201hN7P80VIVI0P1oOgl206m_K`80Y:BT0P1lO7`206EUI@80V9RH0P1_Kfl20?;b
lT40moOg3`3oool000d0oooo2P3gmoL20?;blQ00moOg0P3bl_8306EUI@H0EUIF0P1RHV8206EUI@80
EUIF0P1LG5`205IFEP80G5aL0P1FEUH207emO@80Ph>30P2IVIT20;jn_P80a<C40P3Bd]820=CDe080
e]KF103Lg=`40=[JfPX0hn?S103Lg=`;0>?Sh`X0f][J0P3AdM460=KFeP80d];B1P3=cLd20<71`@80
a<C40P33`l<20<C4a080_[jn102e]KD20:n_[`80[:b/0P2HV9P209bLW080T92@0P2ATI4208>3P`80
NWYj0P1_Kfl305IFEP80BTY:0P0g=cL204A4A0807QhN100E5AD2034a<@80MGEe0P2TY:@208V9R@80
YJFU0P23Ph<207EeM@80IVIV0P2`/;0Y0?Ogm`80l_;b603gmoL?0?ooo`003@3oool:0?Ogm`80l_;b
403gmoL20?;blP<0IFEU1P1FEUH2069RHP80IFEU0P1FEUH205aLG080EUIF0P1LG5`205IFEP80OGem
0P23Ph<209VIV@80_[jn0P34a<@20=;BdP80e=CD0P3Fe]H40=cLg0@0f][J2P3Shn<40=cLg0/0hn?S
2P3Jf]X20=7Ad@H0e]KF0P3Bd]860<g=c@80`L710P34a<@20<?3``80a<C40P2n_[h40;Fe]@80[jn_
0P2/[:`209RHV080W9bL0P2@T902096AT@80Ph>30P1jNWX206m_K`<0EUIF0P1:BTX203Lg=`80A4A4
0P0N7Qh401DE5@80<C4a0P1eMGD20:BTY080RHV90P2UYJD208>3P`80MGEe0P1VIVH20;2`/2T0moOg
0P3bl_8H0?Ogm`l0oooo000=0?ooo`X0moOg0P3bl_8@0?Ogm`80l_;b0`1UIFD605IFEP80HV9R0P1U
IFD205IFEP80G5aL0P1FEUH205aLG080EUIF0P1mOGd208>3P`80VIVI0P2n_[h20<C4a080d];B0P3D
e=@20=KFeP@0g=cL103Jf]X:0>?Sh`@0g=cL2`3Shn<:0=[JfP80dM7A1P3Fe]H20=;BdPH0cLg=0P31
`L420<C4a080`l?30P34a<@20;jn_P@0]KFe0P2_[jl20:b/[080V9RH0P2LW9`2092@T080TI6A0P23
Ph<207YjNP80Kfm_0`1FEUH204Y:BP80=cLg0P14A4@201hN7P@05ADE0P0a<C4207EeM@80Y:BT0P29
RHT20:FUY@80Ph>30P1eMGD206IVIP80/;2`:@3gmoL20?;blQP0moOg3`3oool000d0oooo703gmoL2
0?ooo`<0E5AD0P1[Jf/205IFEP80IFEU0P1[Jf/206e]K@80IFEU101LG5`205IFEP80IFEU0P1eMGD2
096AT@80V9RH0P2e]KD20<C4a080dm?C0P3De=@80=cLg0@0hn?S103Lg=`40>?Sh`80g=cL103Shn<2
0=[JfPL0hn?S1P3Jf]X80=cLg0@0e]KF0P3Bd]860<g=c@80`L71202n_[h20;Rh^080]KFe0P2][Jd2
0:b/[080YJFU0P2LW9`2092@T0@0RHV90P1oOgl206m_K`<0GUiN0P0k>c/204Y:BP808R8R100N7Qh2
01DE5@8092@T0P1cLg<209RHV080MGEe0P2IVIT2096AT@80QHF50P1VIVH20=?Cdd<0moOg3`3oool0
00d0oooo703gmoL20?ooo`<0E5AD0P1[Jf/205IFEP80IFEU0P1[Jf/206e]K@80IFEU101LG5`205IF
EP80IFEU0P1eMGD2096AT@80V9RH0P2e]KD20<C4a080dm?C0P3De=@80=cLg0@0hn?S103Lg=`40>?S
h`80g=cL103Shn<20=[JfPL0hn?S1P3Jf]X80=cLg0@0e]KF0P3Bd]860<g=c@80`L71202n_[h20;Rh
^080]KFe0P2][Jd20:b/[080YJFU0P2LW9`2092@T0@0RHV90P1oOgl206m_K`<0GUiN0P0k>c/204Y:
BP808R8R100N7Qh201DE5@8092@T0P1cLg<209RHV080MGEe0P2IVIT2096AT@80QHF50P1VIVH20=?C
dd<0moOg3`3oool000d0oooo703gmoL20?ooo`<0OGem0P1ADE4205iNGP@0KFe]0P1LG5`206EUI@80
EUIF0P1IFET206e]K@80IFEU0P1eMGD208Z:RP80VIVI0P2][Jd20<C4a080cLg=1P3Fe]H60=cLg0@0
hn?S0P3Jf]X20=cLg0@0hn?S0P3Jf]X20=cLg080hn?S0`3Lg=`40=[JfP80g=cL0P3Jf]X60=cLg080
e]KF0P3Lg=`40=KFeP80cLg=0P3Fe]H20<g=c@@0c<c<0P34a<@20<?3``80a<C40P2m_Kd40;Fe]@80
[Jf]0P2/[:`209RHV080W9bL0P2@T90408V9R@@0Kfm_0`1NGUh204Y:BP80>c/k0P0R8R8201DE5@@0
2PX:0P1DE5@206EUI@80OGem0P1jNWX20:6QX@80VIVI0P2b/[8209VIVDD0moOg3`3oool000d0oooo
703gmoL20?ooo`<0OGem0P1ADE4205iNGP@0KFe]0P1LG5`206EUI@80EUIF0P1IFET206e]K@80IFEU
0P1eMGD208Z:RP80VIVI0P2][Jd20<C4a080cLg=1P3Fe]H60=cLg0@0hn?S0P3Jf]X20=cLg0@0hn?S
0P3Jf]X20=cLg080hn?S0`3Lg=`40=[JfP80g=cL0P3Jf]X60=cLg080e]KF0P3Lg=`40=KFeP80cLg=
0P3Fe]H20<g=c@@0c<c<0P34a<@20<?3``80a<C40P2m_Kd40;Fe]@80[Jf]0P2/[:`209RHV080W9bL
0P2@T90408V9R@@0Kfm_0`1NGUh204Y:BP80>c/k0P0R8R8201DE5@@02PX:0P1DE5@206EUI@80OGem
0P1jNWX20:6QX@80VIVI0P2b/[8209VIVDD0moOg3`3oool000d0oooo703gmoL20?ooo`<0EUIF0P1o
Ogl207emO@80GUiN0P1UIFD2069RHP80GUiN0P1LG5`206QXJ080A4A40P1UIFD207moO`80TI6A0P2@
T9020:b/[080`l?30P3=cLd20=?Cd`80e]KF1P3Lg=`40>?Sh`80f][J1P3Shn<20=cLg080hn?S0P3L
g=`20=[JfP<0hn?S0P3Lg=`40=[JfP80g=cL103Jf]X80=cLg080cLg=0P3AdM420=;BdP@0cLg=0P31
`L420<c<c0@0_[jn1P2e]KD20:f][@80[:b/0P2HV9P20:BTY080T92@0P2:RXX207EeM@80KFe]0P1L
G5`304Y:BP80EUIF0P0a<C4201DE5@802PX:0P0T92@200X:2P80HV9R0P1]KFd206m_K`80IVIV102I
VIT20:6QX@80gmoOA@3gmoL?0?ooo`003@3ooolL0?Ogm`80oooo0`1FEUH207moO`80OGem0P1NGUh2
06EUI@80HV9R0P1NGUh205aLG080J6QX0P14A4@206EUI@80Ogmo0P2ATI42092@T080[:b/0P33`l<2
0<g=c@80dm?C0P3Fe]H60=cLg0@0hn?S0P3Jf]X60>?Sh`80g=cL0P3Shn<20=cLg080f][J0`3Shn<2
0=cLg0@0f][J0P3Lg=`40=[JfPP0g=cL0P3=cLd20=7Ad@80d];B103=cLd20<71`@80c<c<102n_[h6
0;Fe]@80[Jf]0P2/[:`209RHV080Y:BT0P2@T90208Z:RP80MGEe0P1]KFd205aLG0<0BTY:0P1FEUH2
034a<@805ADE0P0:2PX202@T90802PX:0P1RHV8206e]K@80Kfm_0P1VIVH409VIV@80XJ6Q0P3Ogmm5
0?Ogm`l0oooo000=0?ooo`@0moOg0P3bl_820?Ogm`80l_;b503gmoL30=oOg`80Ogmo101IFET405IF
EP80EEEE0P1LG5`205IFEP@0IFEU0P1mOGd2092@T080XJ6Q0P2][Jd20<?3``80cLg=0P3Cdm<40=cL
g080f][J0P3Lg=`40>?Sh`80g=cL0P3Shn<20=cLg080hn?S0P3Lg=`20=[JfP80g=cL0P3Shn<30=cL
g0@0f][J203Lg=`20=[JfP@0g=cL0P3AdM440=KFePH0cLg=0P31`L420<c<c0@0_[jn202e]KD20:b/
[080XJ6Q0P2UYJD208Z:RP80Ogmo101eMGD206m_K`<0FEUI0P0k>c/2034a<@@05ADE0P0T92@201DE
5@@0KFe]0P1eMGD206QXJ080VIVI0P2QXJ420:f][DL0moOg3`3oool000d0oooo103gmoL20?;blP80
moOg0P3bl_8D0?Ogm`<0gmoO0P1oOgl405UIF@@0EUIF0P1EEED205aLG080EUIF101UIFD207emO@80
T92@0P2QXJ420:f][@80`l?30P3=cLd20=?Cd`@0g=cL0P3Jf]X20=cLg0@0hn?S0P3Lg=`20>?Sh`80
g=cL0P3Shn<20=cLg080f][J0P3Lg=`20>?Sh`<0g=cL103Jf]X80=cLg080f][J103Lg=`20=7Ad@@0
e]KF1P3=cLd20<71`@80c<c<102n_[h80;Fe]@80[:b/0P2QXJ420:FUY@80RXZ:0P1oOgl407EeM@80
Kfm_0`1IFET203/k>`80<C4a100E5AD202@T90805ADE101]KFd207EeM@80J6QX0P2IVIT20:6QX@80
[Jf]A`3gmoL?0?ooo`003@3ooolN0?Ogm`<0oooo0P1UIFD205UIF@80EUIF0P1:BTX205EEE@80DE5A
0P1:BTX205UIF@80IFEU0P1_Kfl208V9R@80T92@0P2UYJD20;:b/P80`l?30P3=cLd20=KFeP80dM7A
0P3Lg=`20=[JfPP0g=cL0P3Jf]X80>?Sh`@0f][J0`3Shn<@0=cLg080dM7A1P3Fe]H20<g=c@80e]KF
0P3=cLd40<c<c080a/K60P2n_[h40;Fe]@80[Jf]0P2e]KD40:b/[080V9RH102:RXX207moO`80IFEU
0P1NGUh303/k>`80<C4a100N7Qh200X:2P806a/K0P0E5AD207alO080KFe]0P1XJ6P206IVIP80XJ6Q
0P2g]kL20=3@d4L0moOg3`3oool000d0oooo7P3gmoL30?ooo`80IFEU0P1IFET205IFEP80BTY:0P1E
EED2055AD@80BTY:0P1IFET206EUI@80Kfm_0P29RHT2092@T080YJFU0P2b/[820<?3``80cLg=0P3F
e]H20=7Ad@80g=cL0P3Jf]X80=cLg080f][J203Shn<40=[JfP<0hn?S403Lg=`20=7Ad@H0e]KF0P3=
cLd20=KFeP80cLg=103<c<`20<K6aP80_[jn102e]KD20:f][@80]KFe102/[:`209RHV0@0RXZ:0P1o
Ogl206EUI@80GUiN0`0k>c/2034a<@@07QhN0P0:2PX201/K6`805ADE0P1lO7`206e]K@80J6QX0P1V
IVH20:6QX@80]kNg0P3@d=170?Ogm`l0oooo000=0?ooob40moOg0P2i^KT2069RHP@0EUIF0P1EEED4
05IFEP80DE5A0P1FEUH206m_K`80Ogmo0P2@T9020:6QX@80][Jf0P34a<@20<g=c@@0e]KF0P3Lg=`4
0=[JfP80hn?S0P3Jf]X:0>?Sh`80f][J0P3Shn<20=cLg0<0f][J0P3Shn<20=[JfP80g=cL0P3Jf]X8
0=cLg080e]KF0P3Lg=`20=KFeP80dM7A0P3Bd]840<g=c@@0c<c<102n_[h20;Jf]P@0]KFe0P2/[:`2
0:f][@@0W9bL0P2ATI4207moO`80OGem0P1eMGD205iNGP<0=cLg0P0a<C4201hN7P8092@T0P0C4a<4
01hN7P80Ogmo0P2:RXX205iNGP80NWYj0P2IVIT20<?3``@0moOg0P3bl_930?Ogm`l0oooo000=0?oo
ob40moOg0P2i^KT2069RHP@0EUIF0P1EEED405IFEP80DE5A0P1FEUH206m_K`80Ogmo0P2@T9020:6Q
X@80][Jf0P34a<@20<g=c@@0e]KF0P3Lg=`40=[JfP80hn?S0P3Jf]X:0>?Sh`80f][J0P3Shn<20=cL
g0<0f][J0P3Shn<20=[JfP80g=cL0P3Jf]X80=cLg080e]KF0P3Lg=`20=KFeP80dM7A0P3Bd]840<g=
c@@0c<c<102n_[h20;Jf]P@0]KFe0P2/[:`20:f][@@0W9bL0P2ATI4207moO`80OGem0P1eMGD205iN
GP<0=cLg0P0a<C4201hN7P8092@T0P0C4a<401hN7P80Ogmo0P2:RXX205iNGP80NWYj0P2IVIT20<?3
``@0moOg0P3bl_930?Ogm`l0oooo000=0?ooo`80moOg0P3bl_8M0?Ogm`80l_;b0P1[Jf/404Y:BP@0
DE5A0P1FEUH205UIF@80DE5A0P1]KFd208V9R@80V9RH0P2/[:`20;Fe]@80c<c<0P3=cLd20<k>cP80
dm?C0P3Fe]H:0=cLg080hn?S0P3Lg=`20>?Sh`80f][J103Lg=`20=[JfP<0g=cL103Jf]X60=cLg080
f][J103Lg=`40=KFeP80d];B0P3Fe]H20=7Ad@H0cLg=1034a<@20<?3``80_Kfm102e]KD20:f][@@0
YJFU0P2@T902096AT@80Ogmo0P1eMGD206EUI@80EUIF0`0g=cL2034a<@8092@T0P0N7Qh402PX:080
5ADE0P1_Kfl208V9R@80Kfm_0P2>SXh20:b/[080dM7AB@3gmoL?0?ooo`003@3oool20?Ogm`80l_;b
7@3gmoL20?;blP80Jf][101:BTX4055AD@80EUIF0P1IFET2055AD@80KFe]0P29RHT209RHV080[:b/
0P2e]KD20<c<c080cLg=0P3>c/h20=?Cd`80e]KF2P3Lg=`20>?Sh`80g=cL0P3Shn<20=[JfP@0g=cL
0P3Jf]X30=cLg0@0f][J1P3Lg=`20=[JfP@0g=cL103Fe]H20=;BdP80e]KF0P3AdM460<g=c@@0a<C4
0P33`l<20;fm_@@0]KFe0P2][Jd40:FUY@80T92@0P2ATI4207moO`80MGEe0P1UIFD205IFEP<0=cLg
0P0a<C4202@T90807QhN100X:2P201DE5@80Kfm_0P29RHT206m_K`80SXj>0P2/[:`20=7AdDT0moOg
3`3oool000d0oooo8`3gmoL207moO`80Jf][0P1ADE4205aLG080FEUI0P1ADE4205UIF@80G5aL0P1]
KFd207EeM@80VIVI0P2b/[840<C4a080cLg=103Fe]H60=cLg0@0f][J103Shn<20=[JfP@0g=cL2@3J
f]X40=cLg080f][J203Lg=`60=KFeP@0d];B0P3=cLd40<c<c080cLg=0P34a<@20<?3``80_Kfm0P2h
^;P40;Fe]@@0[jn_0P2LW9`2092@T080RXZ:0P1jNWX206m_K`80GUiN0P1:BTX503Lg=`80:2PX0P0N
7Qh202PX:0805ADE0P0:2PX206e]K@80MGEe0P1_Kfl2096AT@80]KFe0P3^k^i90?Ogm`l0oooo000=
0?ooob<0moOg0P1oOgl206][J`80DE5A0P1LG5`205UIF@80DE5A0P1IFET205aLG080KFe]0P1eMGD2
09VIV@80/[:b1034a<@20<g=c@@0e]KF1P3Lg=`40=[JfP@0hn?S0P3Jf]X40=cLg0T0f][J103Lg=`2
0=[JfPP0g=cL1P3Fe]H40=;BdP80cLg=103<c<`20<g=c@80a<C40P33`l<20;fm_@80^;Rh102e]KD4
0:n_[`80W9bL0P2@T90208Z:RP80NWYj0P1_Kfl205iNGP80BTY:1@0g=cL202PX:0807QhN0P0X:2P2
01DE5@802PX:0P1]KFd207EeM@80Kfm_0P2ATI420;Fe]@80k^k^B@3gmoL?0?ooo`003@3ooolS0?Og
m`80oooo0P2i^KT207moO`H0KFe]101IFET206e]K@80QHF50P2@T9020:FUY@80_[jn0P3<c<`40<g=
c@80e]KF0P3Cdm<20=KFePP0f][J103Lg=`20=[JfP80hn?S0P3Lg=`20=[JfPT0g=cL0P3Fe]H20=cL
g0P0e]KF0P3Lg=`20=7Ad@80e]KF203<c<`20<71`@80a<C40P33`l<20;fm_@80]KFe0P2m_Kd60:b/
[0@0T92@0P1oOgl207emO@80IFEU0P1FEUH204A4A0<0BTY:100a<C4201hN7P805ADE0P071`L203Lg
=`80RXZ:0P1eMGD207alO080W9bL0P2`/;020?Ogm`80l_;bA`3gmoL?0?ooo`003@3ooolS0?Ogm`80
oooo0P2i^KT207moO`H0KFe]101IFET206e]K@80QHF50P2@T9020:FUY@80_[jn0P3<c<`40<g=c@80
e]KF0P3Cdm<20=KFePP0f][J103Lg=`20=[JfP80hn?S0P3Lg=`20=[JfPT0g=cL0P3Fe]H20=cLg0P0
e]KF0P3Lg=`20=7Ad@80e]KF203<c<`20<71`@80a<C40P33`l<20;fm_@80]KFe0P2m_Kd60:b/[0@0
T92@0P1oOgl207emO@80IFEU0P1FEUH204A4A0<0BTY:100a<C4201hN7P805ADE0P071`L203Lg=`80
RXZ:0P1eMGD207alO080W9bL0P2`/;020?Ogm`80l_;bA`3gmoL?0?ooo`003@3oool20?Ogm`80l_;b
4P3gmoL20?;blP/0moOg103oool20>WYj@80Lg=c0P1]KFd205aLG080IFEU0P1RHV8206EUI@80NWYj
0P2HV9P20:6QX@80]KFe0P3<c<`40<g=c@@0e]KF103Lg=`20=KFeP@0f][J303Lg=`20=[JfP/0g=cL
1P3Fe]H20=cLg080e]KF203=cLd20<c<c080cLg=0P36a/H60;jn_P80_Kfm0P2e]KD20:FUY@80[Jf]
102HV9P2096AT@80NWYj0P1QHF4205IFEP80G5aL0P14A4@503Lg=`8092@T0P0X:2P200h>3P801`L7
0P1mOGd207moO`80IVIV0P23Ph<209BDU080d];BB`3gmoL?0?ooo`003@3oool20?Ogm`80l_;b4P3g
moL20?;blP/0moOg103oool20>WYj@80Lg=c0P1]KFd205aLG080IFEU0P1RHV8206EUI@80NWYj0P2H
V9P20:6QX@80]KFe0P3<c<`40<g=c@@0e]KF103Lg=`20=KFeP@0f][J303Lg=`20=[JfP/0g=cL1P3F
e]H20=cLg080e]KF203=cLd20<c<c080cLg=0P36a/H60;jn_P80_Kfm0P2e]KD20:FUY@80[Jf]102H
V9P2096AT@80NWYj0P1QHF4205IFEP80G5aL0P14A4@503Lg=`8092@T0P0X:2P200h>3P801`L70P1m
OGd207moO`80IVIV0P23Ph<209BDU080d];BB`3gmoL?0?ooo`003@3ooolW0?Ogm`80oooo0P2PX:02
05IFEP80HV9R0P1ADE4406EUI@80OGem0P2ATI420:FUY@80][Jf0P34a<@20<71`@@0cLg=0P3Fe]H4
0=;BdP@0e]KF1P3Lg=`20=KFePH0g=cL0P3Fe]H30=cLg080dm?C0P3Fe]H20=CDe0H0e]KF0P3Bd]88
0<g=c@80c<c<0P3=cLd40<c<c080`L711P2n_[h40;Fe]@80[Jf]0P2UYJD20:b/[080T92@0P1oOgl2
06m_K`80IVIV0P1NGUh405aLG0D0<C4a0P0X:2P201DE5@802PX:0P2:RXX207alO080Kfm_0P1VIVH2
096AT@80^[Zj0P3YjNT20?Ogm`@0l_;bA@3gmoL?0?ooo`003@3ooolW0?Ogm`80oooo0P2PX:0205IF
EP80HV9R0P1ADE4406EUI@80OGem0P2ATI420:FUY@80][Jf0P34a<@20<71`@@0cLg=0P3Fe]H40=;B
dP@0e]KF1P3Lg=`20=KFePH0g=cL0P3Fe]H30=cLg080dm?C0P3Fe]H20=CDe0H0e]KF0P3Bd]880<g=
c@80c<c<0P3=cLd40<c<c080`L711P2n_[h40;Fe]@80[Jf]0P2UYJD20:b/[080T92@0P1oOgl206m_
K`80IVIV0P1NGUh405aLG0D0<C4a0P0X:2P201DE5@802PX:0P2:RXX207alO080Kfm_0P1VIVH2096A
T@80^[Zj0P3YjNT20?Ogm`@0l_;bA@3gmoL?0?ooo`003@3ooolW0?Ogm`80oooo0P3?cll203/k>`80
G5aL0P1mOGd205UIF@@0OGem0P2ATI420:6QX@80]KFe0P33`l<20<_;b`80cLg=0P3<c<`20<g=c@@0
e]KF0P3Lg=`20=KFeP80e=CD0P3Lg=`20=KFePX0g=cL1@3Fe]H20=cLg080e]KF0P3=cLd20=KFeP80
cLg=0P3Fe]H40<g=c@80c<c<103=cLd40<c<c080`l?30P36a/H40;fm_@80][Jf0P2e]KD20;2`/080
V9RH0P2UYJD209bLW080RXZ:0P1oOgl207EeM@80Kfm_0P1LG5`204Y:BP80DE5A0`1]KFd201hN7P80
5ADE0P0K6a/205UIF@80EUIF0P1mOGd206m_K`80NWYj0P2IVIT20<C4a080l_;b0P3gmoL20?;blP80
ooooA@3gmoL?0?ooo`003@3ooolW0?Ogm`80oooo0P3?cll203/k>`80G5aL0P1mOGd205UIF@@0OGem
0P2ATI420:6QX@80]KFe0P33`l<20<_;b`80cLg=0P3<c<`20<g=c@@0e]KF0P3Lg=`20=KFeP80e=CD
0P3Lg=`20=KFePX0g=cL1@3Fe]H20=cLg080e]KF0P3=cLd20=KFeP80cLg=0P3Fe]H40<g=c@80c<c<
103=cLd40<c<c080`l?30P36a/H40;fm_@80][Jf0P2e]KD20;2`/080V9RH0P2UYJD209bLW080RXZ:
0P1oOgl207EeM@80Kfm_0P1LG5`204Y:BP80DE5A0`1]KFd201hN7P805ADE0P0K6a/205UIF@80EUIF
0P1mOGd206m_K`80NWYj0P2IVIT20<C4a080l_;b0P3gmoL20?;blP80ooooA@3gmoL?0?ooo`003@3o
oolW0?Ogm`80oooo0P2g]kL207EeM@@0EUIF0P1RHV8207moO`80OGem0P2ATI420:FUY@80]KFe0P2f
][H20<C4a080cLg=0P3<c<`20<g=c@80dM7A0P3=cLd20=cLg080d];B3P3Fe]H20=cLg0D0dM7A1P3=
cLd20<71`@80cLg=2P3<c<`20<g=c@@0c<c<102m_Kd20;jn_PH0]KFe0P2/[:`409RHV080RXZ:0P1j
NWX207EeM@80IVIV101LG5`405IFEP<0=cLg0P1:BTX203Lg=`80BTY:0P14A4@207moO`80MGEe0P29
RHT2096AT@80/[:b0P30`<020?Ogm`80ooooB@3gmoL?0?ooo`003@3ooolW0?Ogm`80oooo0P2g]kL2
07EeM@@0EUIF0P1RHV8207moO`80OGem0P2ATI420:FUY@80]KFe0P2f][H20<C4a080cLg=0P3<c<`2
0<g=c@80dM7A0P3=cLd20=cLg080d];B3P3Fe]H20=cLg0D0dM7A1P3=cLd20<71`@80cLg=2P3<c<`2
0<g=c@@0c<c<102m_Kd20;jn_PH0]KFe0P2/[:`409RHV080RXZ:0P1jNWX207EeM@80IVIV101LG5`4
05IFEP<0=cLg0P1:BTX203Lg=`80BTY:0P14A4@207moO`80MGEe0P29RHT2096AT@80/[:b0P30`<02
0?Ogm`80ooooB@3gmoL?0?ooo`003@3ooolW0?Ogm`80oooo0P2YZJT20:6QX@80A4A40P1EEED205UI
F@80GUiN0P1eMGD208V9R@80V9RH0P2QXJ420;Zj^P80_[jn0P34a<@20<c<c080`L71103AdM440=?C
d`80c/k>0P3=cLd20=7Ad@@0e]KF0P3Lg=`20<k>cP80dm?C1@3=cLd20<c<c080`L71102n_[h20<30
`0@0c<c<0P36a/H20<71`@80a/K60P30`<040;jn_P80]KFe0P2h^;P20;Fe]@@0[Jf]0P2UYJD409RH
V080T92@0P2:RXX207YjNP80OGem0P1_Kfl4055AD@@0BTY:0`0n?Sh204A4A080<C4a0P25QHD206e]
K@80MGEe0P1_Kfl20:FUY@80VIVI0P33`l<60?Ogm`80l_;b103gmoL20?ooob<0moOg0P3ooolL0?Og
m`l0oooo000=0?ooobL0moOg0P3oool20:VYZ@80XJ6Q0P14A4@205EEE@80FEUI0P1NGUh207EeM@80
RHV90P2HV9P20:6QX@80^[Zj0P2n_[h20<C4a080c<c<0P31`L440=7Ad@@0dm?C0P3>c/h20<g=c@80
dM7A103Fe]H20=cLg080c/k>0P3Cdm<50<g=c@80c<c<0P31`L440;jn_P80`<30103<c<`20<K6aP80
`L710P36a/H20<30`0@0_[jn0P2e]KD20;Rh^080]KFe102][Jd20:FUY@@0V9RH0P2@T90208Z:RP80
NWYj0P1mOGd206m_K`@0DE5A101:BTX303hn?P80A4A40P0a<C4208F5Q@80KFe]0P1eMGD206m_K`80
YJFU0P2IVIT20<?3``H0moOg0P3bl_840?Ogm`80oooo8`3gmoL20?oooa`0moOg3`3oool000d0oooo
:@3gmoL20=oOg`80bl_;0P0a<C4204A4A080Kfm_0P1FEUH207EeM@80QHF50P2@T9020:f][@80]KFe
0P2f][H20;jn_P@0`L710P3<c<`20<g=c@80bl_;0P3=cLd20=?Cd`H0cLg=0P3>c/h20<g=c@80c<c<
1@3=cLd20<K6aP80_[jn0P2g]kL40;Rh^080_Kfm0P30`<080;Ng]`80[jn_0P2e]KD20;Rh^080[:b/
0P2e]KD40:b/[080XJ6Q0P2TY:@209RHV080RXZ:1029RHT207emO@80MGEe0P1NGUh205aLG080FEUI
0P1ADE4206][J`<0FEUI0P1:BTX206][J`80RXZ:0P1cLg<207moO`80TI6A0P2/[:`20<?3``80`<30
0P3bl_860?Ogm`80oooo6P3gmoL20?;blRT0moOg3`3oool000d0oooo:@3gmoL20=oOg`80bl_;0P0a
<C4204A4A080Kfm_0P1FEUH207EeM@80QHF50P2@T9020:f][@80]KFe0P2f][H20;jn_P@0`L710P3<
c<`20<g=c@80bl_;0P3=cLd20=?Cd`H0cLg=0P3>c/h20<g=c@80c<c<1@3=cLd20<K6aP80_[jn0P2g
]kL40;Rh^080_Kfm0P30`<080;Ng]`80[jn_0P2e]KD20;Rh^080[:b/0P2e]KD40:b/[080XJ6Q0P2T
Y:@209RHV080RXZ:1029RHT207emO@80MGEe0P1NGUh205aLG080FEUI0P1ADE4206][J`<0FEUI0P1:
BTX206][J`80RXZ:0P1cLg<207moO`80TI6A0P2/[:`20<?3``80`<300P3bl_860?Ogm`80oooo6P3g
moL20?;blRT0moOg3`3oool000d0oooo:`3gmoL20:VYZ@80OGem0P1IFET205aLG080KFe]0P1UIFD2
07EeM@80Ogmo0P2HV9P20:f][@80`l?30P2f][H20;Zj^P@0_[jn203=cLd20<_;b`P0a<C40P2n_[h2
0;Jf]PL0]KFe102/[:`60:FUY@80Y:BT0P2XZ:P20:FUY@@0Y:BT0P2HV9P809bLW0@0T92@0P2HV9P2
092@T080RXZ:0P23Ph<206m_K`80IFEU0P1cLg<206e]K@80EeMG101]KFd204Y:BP<0IFEU101_Kfl2
07EeM@80Kfm_0P2ATI4208V9R@80]KFe0P33`l<20?3`l4l0moOg3`3oool000d0oooo:`3gmoL20:VY
Z@80OGem0P1IFET205aLG080KFe]0P1UIFD207EeM@80Ogmo0P2HV9P20:f][@80`l?30P2f][H20;Zj
^P@0_[jn203=cLd20<_;b`P0a<C40P2n_[h20;Jf]PL0]KFe102/[:`60:FUY@80Y:BT0P2XZ:P20:FU
Y@@0Y:BT0P2HV9P809bLW0@0T92@0P2HV9P2092@T080RXZ:0P23Ph<206m_K`80IFEU0P1cLg<206e]
K@80EeMG101]KFd204Y:BP<0IFEU101_Kfl207EeM@80Kfm_0P2ATI4208V9R@80]KFe0P33`l<20?3`
l4l0moOg3`3oool000d0oooo;@3gmoL20:j^[P80Lg=c0P1LG5`206EUI@80KFe]0P1mOGd208Z:RP80
Ogmo0P2@T90209RHV080]KFe0P2j^[X20<C4a080c<c<0P3;bl/60<C4a080`l?3102e]KD20:b/[080
]KFe0P33`l<20:f][@<0[jn_0P2/[:`20:f][@80V9RH0P2QXJ42092@T080W9bL0P2ATI420:FUY@80
QhN70P2LW9`208>3P`80T92@1023Ph<2096AT@@0RHV9102:RXX207moO`80T92@0P2HV9P208F5Q@80
Rh^;0P1mOGd207moO`@0IFEU0P1cLg<207moO`80G5aL0`0k>c/205IFEP80Ph>30P29RHT208>3P`80
TI6A0P2`/;020;Zj^P80`<303P3gmoL20?;blR<0moOg0P3ooolL0?Ogm`l0oooo000=0?ooobd0moOg
0P2^[Zh207=cL`80G5aL0P1UIFD206e]K@80OGem0P2:RXX207moO`80T92@0P2HV9P20;Fe]@80^[Zj
0P34a<@20<c<c080bl_;1P34a<@20<?3``@0]KFe0P2/[:`20;Fe]@80`l?30P2][Jd30:n_[`80[:b/
0P2][Jd209RHV080XJ6Q0P2@T90209bLW080TI6A0P2UYJD208N7Q`80W9bL0P23Ph<2092@T0@0Ph>3
0P2ATI4408V9R@@0RXZ:0P1oOgl2092@T080V9RH0P25QHD208^;R`80OGem0P1oOgl406EUI@80Lg=c
0P1oOgl205aLG0<0>c/k0P1FEUH208>3P`80RHV90P23Ph<2096AT@80/;2`0P2j^[X20<30`0h0moOg
0P3bl_8S0?Ogm`80oooo703gmoL?0?ooo`003@3oool_0?Ogm`80jNWY0P2<S8`207=cL`80FEUI0P1e
MGD207emO@80IFEU0P2@T9020:6QX@80`<301P3<c<`40<C4a080^[Zj0P2f][H20:b/[080/;2`102]
[Jd20:b/[080[Jf]1@2/[:`409VIV@@0T92@0P2:RXX2092@T080RXZ:0P1jNWX208Z:RP80RHV90P1e
MGD206m_K`80RXZ:0P1eMGD208V9R@80MGEe0P1jNWX207moO`80OGem0P1oOgl206EUI@80KFe]0P1c
Lg<207YjNP80Lg=c0P1eMGD207=cL`80MGEe0P1FEUH205aLG080Jf][0`1_Kfl207EeM@@0OGem0P2I
VIT40;Zj^P80XJ6Q203gmoL20?;blR80moOg0P3bl_8U0?Ogm`l0oooo000=0?ooobl0moOg0P3YjNT2
08b<S080Lg=c0P1IFET207EeM@80OGem0P1UIFD2092@T080XJ6Q0P30`<060<c<c0@0a<C40P2j^[X2
0;Jf]P80[:b/0P2`/;040:f][@80[:b/0P2][Jd50:b/[0@0VIVI102@T90208Z:RP80T92@0P2:RXX2
07YjNP80RXZ:0P29RHT207EeM@80Kfm_0P2:RXX207EeM@80RHV90P1eMGD207YjNP80Ogmo0P1mOGd2
07moO`80IFEU0P1]KFd207=cL`80NWYj0P1cLg<207EeM@80Lg=c0P1eMGD205IFEP80G5aL0P1[Jf/3
06m_K`80MGEe101mOGd209VIV@@0^[Zj0P2QXJ480?Ogm`80l_;b8P3gmoL20?;blRD0moOg3`3oool0
00d0oooo3P3gmoL20?;blP80moOg0P3bl_8M0?Ogm`80S8b<101oOgl207MgM`80Rh^;0P2YZJT20:^[
Z`80WinO0P2f][H20:^[Z`80][Jf1030`<020;Jf]P80]KFe0P2][Jd20:b/[080[Jf]0P2HV9P20:6Q
X@80[:b/0P2QXJ4209VIV@<0XJ6Q0P2HV9P2092@T080RHV90P2:RXX207EeM@80V9RH0P1oOgl209RH
V080RHV90P1oOgl2096AT@80OGem0P1_Kfl209RHV080OGem0P2:RXX207moO`80OGem0P25QHD208^;
R`80HV9R0P1]KFd207emO@80O7al0P1[Jf/207=cL`80Ogmo0P1VIVH206m_K`80IVIV0P1_Kfl306IV
IP80MGEe0P29RHT20;6a/@80]kNg0P2`/;020;:b/P80dm?C203gmoL20?ooodT0moOg3`3oool000d0
oooo3P3gmoL20?;blP80moOg0P3bl_8M0?Ogm`80S8b<101oOgl207MgM`80Rh^;0P2YZJT20:^[Z`80
WinO0P2f][H20:^[Z`80][Jf1030`<020;Jf]P80]KFe0P2][Jd20:b/[080[Jf]0P2HV9P20:6QX@80
[:b/0P2QXJ4209VIV@<0XJ6Q0P2HV9P2092@T080RHV90P2:RXX207EeM@80V9RH0P1oOgl209RHV080
RHV90P1oOgl2096AT@80OGem0P1_Kfl209RHV080OGem0P2:RXX207moO`80OGem0P25QHD208^;R`80
HV9R0P1]KFd207emO@80O7al0P1[Jf/207=cL`80Ogmo0P1VIVH206m_K`80IVIV0P1_Kfl306IVIP80
MGEe0P29RHT20;6a/@80]kNg0P2`/;020;:b/P80dm?C203gmoL20?ooodT0moOg3`3oool000d0oooo
103gmoL20?;blR/0moOg0P3oool207=cL`80QXJ60P1gMgL206e]K@80QHF5102@T90209nOW`80][Jf
0P2j^[X20;Fe]@80/;2`0P2][Jd20;:b/PH0XJ6Q0P2@T90209RHV080T92@0P2HV9P2092@T0<0V9RH
0P2:RXX209RHV080OGem0P1eMGD207moO`80IVIV0P25QHD207emO@80T92@0P1eMGD207moO`80OGem
0P1oOgl209VIV@80IFEU101eMGD208Z:RP80OGem101]KFd205aLG080FEUI0P1:BTX2055AD@80IFEU
101FEUH405UIF@80IVIV0`1lO7`209VIV@80/K6a0P3;bl/209nOW`80/[:b0P29RHUE0?Ogm`l0oooo
000=0?ooo`@0moOg0P3bl_8[0?Ogm`80oooo0P1cLg<208J6QP80MgMg0P1]KFd208F5Q@@0T92@0P2O
Wil20;Jf]P80^[Zj0P2e]KD20;2`/080[Jf]0P2b/[860:6QX@80T92@0P2HV9P2092@T080V9RH0P2@
T90309RHV080RXZ:0P2HV9P207emO@80MGEe0P1oOgl206IVIP80QHF50P1mOGd2092@T080MGEe0P1o
Ogl207emO@80Ogmo0P2IVIT206EUI@@0MGEe0P2:RXX207emO@@0KFe]0P1LG5`205UIF@80BTY:0P1A
DE4206EUI@@0EUIF101IFET206IVIP<0O7al0P2IVIT20;6a/@80bl_;0P2OWil20;:b/P80RHV9E@3g
moL?0?ooo`003@3ooolc0?Ogm`80oooo0P2FUYH407moO`80X:2P0P2QXJ420:VYZ@P0^[Zj202QXJ42
09RHV080XJ6Q102HV9P408Z:RP80V9RH0`29RHT207emO@80Ogmo0P1VIVH408F5Q@80IFEU0P1:BTX2
07moO`80G5aL0P29RHT207emO@@0Ogmo0P1NGUh206m_K`80OGem0P14A4@204Y:BP80J6QX0P1NGUh2
05aLG080GUiN0P1XJ6P206IVIP80Kfm_101VIVH205IFEP80J6QX0P1_Kfl20;2`/0<0V9RH0P2b/[82
0<30`080IFEU0P2OWil208F5Q@80dM7A0P3oool>0?Ogm`80l_;b@`3gmoL?0?ooo`003@3ooolc0?Og
m`80oooo0P2FUYH407moO`80X:2P0P2QXJ420:VYZ@P0^[Zj202QXJ4209RHV080XJ6Q102HV9P408Z:
RP80V9RH0`29RHT207emO@80Ogmo0P1VIVH408F5Q@80IFEU0P1:BTX207moO`80G5aL0P29RHT207em
O@@0Ogmo0P1NGUh206m_K`80OGem0P14A4@204Y:BP80J6QX0P1NGUh205aLG080GUiN0P1XJ6P206IV
IP80Kfm_101VIVH205IFEP80J6QX0P1_Kfl20;2`/0<0V9RH0P2b/[820<30`080IFEU0P2OWil208F5
Q@80dM7A0P3oool>0?Ogm`80l_;b@`3gmoL?0?ooo`003@3ooole0?Ogm`80ZZZZ0P26QXH2069RHP80
MgMg0P1_Kfl208F5Q@80ZZZZ0P2g]kL20;Jf]P80^[Zj0P2YZJT409RHV080T92@102HV9P2092@T080
QHF50P2;Rh/2092@T080Ogmo1@29RHT206EUI@80VIVI0P1mOGd206EUI@80V9RH0P1UIFD205aLG080
Ogmo101UIFD206e]K@80G5aL0P1NGUh205EEE@80A4A4101FEUH206QXJ080EUIF0P1IFET206IVIP80
GUiN0P1FEUH2051@D080GUiN0P1eMGD408V9R@80XJ6Q0P2HV9P30<?3``80^[Zj0P25QHD207emO@80
WinO0P25QHD:0?Ogm`80l_;b103gmoL20?;blQ`0moOg0P3bl_840?Ogm`<0oooo803gmoL?0?ooo`00
3@3ooole0?Ogm`80ZZZZ0P26QXH2069RHP80MgMg0P1_Kfl208F5Q@80ZZZZ0P2g]kL20;Jf]P80^[Zj
0P2YZJT409RHV080T92@102HV9P2092@T080QHF50P2;Rh/2092@T080Ogmo1@29RHT206EUI@80VIVI
0P1mOGd206EUI@80V9RH0P1UIFD205aLG080Ogmo101UIFD206e]K@80G5aL0P1NGUh205EEE@80A4A4
101FEUH206QXJ080EUIF0P1IFET206IVIP80GUiN0P1FEUH2051@D080GUiN0P1eMGD408V9R@80XJ6Q
0P2HV9P30<?3``80^[Zj0P25QHD207emO@80WinO0P25QHD:0?Ogm`80l_;b103gmoL20?;blQ`0moOg
0P3bl_840?Ogm`<0oooo803gmoL?0?ooo`003@3ooole0?Ogm`80oooo0P1GEeL207emO@80WinO0P1o
Ogl208F5Q@80UYJF0P2_[jl20;Ng]`80[Jf]0P2YZJT207moO`80RXZ:0P25QHD409RHV080RXZ:0P1g
MgL208Z:RP80RHV90P1oOgl3092@T080Ogmo0P29RHT205aLG080MGEe0P1cLg<206EUI@80OGem0P1L
G5`206EUI@80IVIV0P1LG5`2069RHP80G5aL0P1ADE4605IFEP80BTY:0P14A4@205IFEP80FEUI0P1F
EUH405EEE@80IFEU201mOGd20:6QX@80]kNg1@1lO7`208F5Q@80ZJVY0P2HV9P20>WYj@@0l_;b103g
moL20?;blP@0moOg0P3bl_840?Ogm`80oooo203gmoL20?ooocL0moOg3`3oool000d0oooo=@3gmoL2
0?ooo`80EeMG0P1mOGd209nOW`80Ogmo0P25QHD209JFUP80[jn_0P2g]kL20:f][@80ZJVY0P1oOgl2
08Z:RP80QHF5102HV9P208Z:RP80MgMg0P2:RXX208V9R@80Ogmo0`2@T90207moO`80RHV90P1LG5`2
07EeM@80Lg=c0P1UIFD207emO@80G5aL0P1UIFD206IVIP80G5aL0P1RHV8205aLG080DE5A1P1FEUH2
04Y:BP80A4A40P1FEUH205UIF@80EUIF101EEED206EUI@P0OGem0P2QXJ420;Ng]`D0O7al0P25QHD2
0:VYZ@80V9RH0P3YjNT40?;blP@0moOg0P3bl_840?Ogm`80l_;b103gmoL20?ooo`P0moOg0P3ooolg
0?Ogm`l0oooo000=0?ooocT0moOg0P1mOGd204Y:BP80UYJF0P2MWId209nOW`80UYJF102j^[X20:n_
[`80OGem0P2@T90407moO`80RHV90P1mOGd207=cL`@0QHF50P1cLg<307moO`80Lg=c0P1oOgl205aL
G080OGem0P1_Kfl206e]K@80DE5A0P1:BTX207emO@80DE5A0P1IFET205aLG080FEUI0P1EEED404Y:
BP80>c/k0P0g=cL604A4A080EEEE0P1_Kfl205aLG080IFEU0P25QHD20:6QX@80V9RH0P34a<@20;Ng
]`80WinO0`2;Rh/206e]K@80XJ6Q0P1]KFd20>WYj@@0oooo0P3bl_9C0?Ogm`l0oooo000=0?ooocT0
moOg0P1mOGd204Y:BP80UYJF0P2MWId209nOW`80UYJF102j^[X20:n_[`80OGem0P2@T90407moO`80
RHV90P1mOGd207=cL`@0QHF50P1cLg<307moO`80Lg=c0P1oOgl205aLG080OGem0P1_Kfl206e]K@80
DE5A0P1:BTX207emO@80DE5A0P1IFET205aLG080FEUI0P1EEED404Y:BP80>c/k0P0g=cL604A4A080
EEEE0P1_Kfl205aLG080IFEU0P25QHD20:6QX@80V9RH0P34a<@20;Ng]`80WinO0`2;Rh/206e]K@80
XJ6Q0P1]KFd20>WYj@@0oooo0P3bl_9C0?Ogm`l0oooo000=0?ooocD0moOg0P3bl_820?Ogm`80oooo
0P1oOgl204A4A080M7Ad0P26QXH209JFUP80]kNg0P30`<020:n_[`80OGem0P1]KFd209JFUP80Ogmo
0P2@T90209JFUP80RHV90P1]KFd208F5Q@80OGem0`1UIFD407moO`80IFEU0P1eMGD207emO@80Lg=c
0P1[Jf/2034a<@80BTY:0P1IFET207emO@@0EUIF0P0k>c/205IFEP80A4A40P0k>c/2034a<@80=cLg
100a<C4204Y:BP80GUiN0P25QHD209RHV080RXZ:0P2HV9P20;Ng]`80UYJF0P1RHV8207YjNP<0RHV9
0P25QHD206m_K`80ZZZZ303gmoL20?;blP80moOg0P3ooolF0?Ogm`80l_;b4`3gmoL20?oooa`0moOg
3`3oool000d0oooo=@3gmoL20?;blP80moOg0P3oool207moO`80A4A40P1dM7@208J6QP80UYJF0P2g
]kL20<30`080[jn_0P1mOGd206e]K@80UYJF0P1oOgl2092@T080UYJF0P29RHT206e]K@80QHF50P1m
OGd306EUI@@0Ogmo0P1UIFD207EeM@80OGem0P1cLg<206][J`80<C4a0P1:BTX205UIF@80OGem101F
EUH203/k>`80EUIF0P14A4@203/k>`80<C4a0P0g=cL4034a<@80BTY:0P1NGUh208F5Q@80V9RH0P2:
RXX209RHV080]kNg0P2FUYH2069RHP80NWYj0`29RHT208F5Q@80Kfm_0P2ZZZX<0?Ogm`80l_;b0P3g
moL20?oooaH0moOg0P3bl_8C0?Ogm`80oooo703gmoL?0?ooo`003@3oool:0?Ogm`80l_;b;`3gmoL2
0=7Ad@80IVIV0P1IFET2069RHP80Rh^;0P2OWil20:n_[`80^[Zj0P25QHD206e]K@80OGem0P2@T904
07=cL`80Ogmo0P1[Jf/206EUI@80MgMg0`1cLg<206][J`80KFe]0P1oOgl207=cL`80IFEU0P1mOGd2
07EeM@80Jf][0P1UIFD404Y:BP80HV9R101FEUH205iNGP80EEEE0P1_Kfl405EEE@80GemO0P1_Kfl2
07YjNP80Ogmo0P2ATI420:6QX@80bLW90P2FUYH209nOW`80OGem0P1:BTX207=cL`<0QHF5102FUYH<
0?Ogm`80oooo0P3gmoL20?;blPX0moOg0P3oool@0?Ogm`80oooo;@3gmoL?0?ooo`003@3oool:0?Og
m`80l_;b;`3gmoL20=7Ad@80IVIV0P1IFET2069RHP80Rh^;0P2OWil20:n_[`80^[Zj0P25QHD206e]
K@80OGem0P2@T90407=cL`80Ogmo0P1[Jf/206EUI@80MgMg0`1cLg<206][J`80KFe]0P1oOgl207=c
L`80IFEU0P1mOGd207EeM@80Jf][0P1UIFD404Y:BP80HV9R101FEUH205iNGP80EEEE0P1_Kfl405EE
E@80GemO0P1_Kfl207YjNP80Ogmo0P2ATI420:6QX@80bLW90P2FUYH209nOW`80OGem0P1:BTX207=c
L`<0QHF5102FUYH<0?Ogm`80oooo0P3gmoL20?;blPX0moOg0P3oool@0?Ogm`80oooo;@3gmoL?0?oo
o`003@3ooolm0?Ogm`80`L710P1jNWX2075aL@80Hf=S0P1RHV8208J6QP80SHf=0P2j^[X206EUI@80
Jf][0P1lO7`208V9R@80Lg=c0P1]KFd205aLG0@0FEUI1@1UIFD206e]K@80Lg=c101UIFD207emO@80
QHF50P1eMGD207=cL`80FEUI0P1mOGd205IFEP80EEEE0P1cLg<206e]K@80IFEU0P1VIVH206m_K`80
OGem0P29RHT20:6QX@80T92@0P2HV9P20;Zj^P80WinO0P2MWId408^;R`80FEUI0P1gMgL208^;R`<0
QHF50P1oOgl20?ooo`80moOg103oool20?Ogm`80l_;b0P3oool20?;blP80oooo0P3gmoL20?;blP80
moOg0P3ooolP0?Ogm`80oooo8`3gmoL?0?ooo`003@3ooolm0?Ogm`80`L710P1jNWX2075aL@80Hf=S
0P1RHV8208J6QP80SHf=0P2j^[X206EUI@80Jf][0P1lO7`208V9R@80Lg=c0P1]KFd205aLG0@0FEUI
1@1UIFD206e]K@80Lg=c101UIFD207emO@80QHF50P1eMGD207=cL`80FEUI0P1mOGd205IFEP80EEEE
0P1cLg<206e]K@80IFEU0P1VIVH206m_K`80OGem0P29RHT20:6QX@80T92@0P2HV9P20;Zj^P80WinO
0P2MWId408^;R`80FEUI0P1gMgL208^;R`<0QHF50P1oOgl20?ooo`80moOg103oool20?Ogm`80l_;b
0P3oool20?;blP80oooo0P3gmoL20?;blP80moOg0P3ooolP0?Ogm`80oooo8`3gmoL?0?ooo`003@3o
oole0?Ogm`80oooo203gmoL20:j^[P80Lg=c0P1dM7@207MgM`80QHF50P2<S8`20:6QX@80ZJVY101[
Jf/408F5Q@80KFe]0P25QHD205IFEPD0G5aL0P1_Kfl206e]K@80MGEe0P1FEUH207moO`80MGEe0P2@
T90207moO`80RXZ:0P2FUYH206e]K@@0GUiN101eMGD408V9R@@0TI6A102/[:`20:VYZ@80Ogmo101m
OGd205iNGP80A4A40P1FEUH207moO`80QHF50P1lO7`309RHV080oooo1P3gmoL40?ooo`@0moOg0P3o
oom?0?Ogm`l0oooo000=0?ooocD0moOg0P3oool80?Ogm`80[Zj^0P1cLg<207AdM080MgMg0P25QHD2
08b<S080XJ6Q0P2YZJT406][J`@0QHF50P1]KFd208F5Q@80EUIF1@1LG5`206m_K`80KFe]0P1eMGD2
05IFEP80Ogmo0P1eMGD2092@T080Ogmo0P2:RXX209JFUP80KFe]101NGUh407EeM@@0RHV9102ATI44
0:b/[080ZJVY0P1oOgl407emO@80GUiN0P14A4@205IFEP80Ogmo0P25QHD207alO0<0V9RH0P3oool6
0?Ogm`@0oooo103gmoL20?ooodl0moOg3`3oool000d0oooo=@3gmoL20?;blP@0moOg0P3bl_840?Og
m`80^KVi0P1SHf<207AdM080Rh^;0P2FUYH209nOW`80ZJVY0P2_[jl207=cL`80QHF50P1UIFD208J6
QP80Lg=c0P1oOgl206e]K@<0EUIF0P1DE5@204Y:BP80IFEU0P1IFET207MgM`80MGEe0P2HV9P2092@
T080bLW90P3<c<`20;Zj^P80XJ6Q0P2f][H60:f][@@0bl_;0P2e]KD20;Ng]`80Rh^;0P1[Jf/207al
O080KFe]0P1LG5`205UIF@80IFEU0P29RHT209JFUP@0Ogmo0`3oool40?Ogm`80oooo3P3gmoL20?;b
lP@0moOg103ooom30?Ogm`l0oooo000=0?ooocD0moOg0P3bl_840?Ogm`80l_;b103gmoL20;Vi^@80
Hf=S0P1dM7@208^;R`80UYJF0P2OWil20:VYZ@80[jn_0P1cLg<208F5Q@80IFEU0P26QXH207=cL`80
Ogmo0P1]KFd305IFEP80E5AD0P1:BTX206EUI@80FEUI0P1gMgL207EeM@80V9RH0P2@T9020<W9b@80
c<c<0P2j^[X20:6QX@80][Jf1P2][Jd40<_;b`80]KFe0P2g]kL208^;R`80Jf][0P1lO7`206e]K@80
G5aL0P1IFET206EUI@80RHV90P2FUYH407moO`<0oooo103gmoL20?ooo`h0moOg0P3bl_840?Ogm`@0
oooo@`3gmoL?0?ooo`003@3ooolm0?Ogm`80oooo103gmoL20?3`l080Q8B40P1dM7@205iNGP80Rh^;
102g]kL20;2`/080QXJ60P2@T90208J6QP80S8b<0P1oOgl209RHV0<0ZJVY0P1mOGd205ADE080Jf][
0P1DE5@207=cL`80UYJF0P2YZJT209nOW`80S8b<0P30`<020<71`@80`<300P39bLT20=SHf080dm?C
0P30`<020:6QX@@0UYJF0P26QXH207AdM080Lg=c0P1]KFd2055AD@80EUIF0P1cLg<207alO080V9RH
0P1oOgl209JFUPL0moOg0P3bl_840?Ogm`@0l_;b1P3gmoL20?;blP`0moOg0P3bl_8o0?Ogm`l0oooo
000=0?ooocd0moOg0P3oool40?Ogm`80l?3`0P24Q8@207AdM080GUiN0P2;Rh/40;Ng]`80/;2`0P26
QXH2092@T080QXJ60P2<S8`207moO`80V9RH0`2YZJT207emO@80E5AD0P1[Jf/205ADE080Lg=c0P2F
UYH20:VYZ@80WinO0P2<S8`20<30`080`L710P30`<020<W9b@80f=SH0P3Cdm<20<30`080XJ6Q102F
UYH208J6QP80M7Ad0P1cLg<206e]K@80DE5A0P1FEUH207=cL`80O7al0P2HV9P207moO`80UYJF1`3g
moL20?;blP@0moOg103bl_860?Ogm`80l_;b303gmoL20?;blSl0moOg3`3oool000d0oooo?@3gmoL2
0?ooo`H0moOg0P3oool207emO@80Hf=S0P23Ph<208b<S080[jn_0P3;bl/40:n_[`80`L710P2^[Zh2
0<o?c`80`L710`2ZZZX20=?Cd`80f][J0P3`l?020>SXj080f][J0P3Cdm<20=;BdP80`<300P3?cll6
0<W9b@80d];B0P2g]kL208^;R`80ZJVY0P2;Rh/207alO0@0OGem0P1UIFD206][J`80EeMG0P1oOgl2
08^;R`@0QHF50P1oOgl20?ooo`@0moOg0`3oool20?;blPP0moOg0P3bl_880?Ogm`80l_;b103gmoL2
0?ooo`@0moOg0P3bl_840?Ogm`80l_;b0P3gmoL20?ooocD0moOg3`3oool000d0oooo?@3gmoL20?oo
o`H0moOg0P3oool207emO@80Hf=S0P23Ph<208b<S080[jn_0P3;bl/40:n_[`80`L710P2^[Zh20<o?
c`80`L710`2ZZZX20=?Cd`80f][J0P3`l?020>SXj080f][J0P3Cdm<20=;BdP80`<300P3?cll60<W9
b@80d];B0P2g]kL208^;R`80ZJVY0P2;Rh/207alO0@0OGem0P1UIFD206][J`80EeMG0P1oOgl208^;
R`@0QHF50P1oOgl20?ooo`@0moOg0`3oool20?;blPP0moOg0P3bl_880?Ogm`80l_;b103gmoL20?oo
o`@0moOg0P3bl_840?Ogm`80l_;b0P3gmoL20?ooocD0moOg3`3oool000d0oooo:@3gmoL20?oooa80
moOg0P3oool:0?Ogm`80gmoO0P1SHf<2079bLP80UYJF0P2WYjL20<71`@80clo?0P3IfMT20=3@d0L0
clo?0P3IfMT20<W9b@80c<c<0P3Bd]820<c<c080f][J0P3Ph>020=WIf@80clo?0P3Cdm<20;Ng]`80
X:2P0P30`<0209nOW`80WIfM0P2PX:02075aL@80OGem0P1UIFD206][J`80OGem0P26QXH209nOW`80
XJ6Q0P2@T90208F5Q@80ZZZZ103gmoL20?;blP80moOg0`3bl_8>0?Ogm`80l_;b;03gmoL20?ooo`D0
moOg0P3oool20?Ogm`80l_;b603gmoL?0?ooo`003@3ooolY0?Ogm`80oooo4P3gmoL20?ooo`X0moOg
0P3Ogml206=SH`80LW9b0P2FUYH20:NWY`80`L710P3?cll20=WIf@80d=3@1`3?cll20=WIf@80bLW9
0P3<c<`20=;BdP80c<c<0P3Jf]X20>3Ph080fMWI0P3?cll20=?Cd`80]kNg0P2PX:020<30`080WinO
0P2MWId20:2PX080LG5a0P1mOGd206EUI@80Jf][0P1mOGd208J6QP80WinO0P2QXJ42092@T080QHF5
0P2ZZZX40?Ogm`80l_;b0P3gmoL30?;blPh0moOg0P3bl_8/0?Ogm`80oooo1@3gmoL20?ooo`80moOg
0P3bl_8H0?Ogm`l0oooo000=0?ooobT0moOg0P3ooolB0?Ogm`80oooo2P3gmoL20=oOg`80Hf=S0P1b
LW8209JFUP80YjNW0P31`L420<o?c`80fMWI0P3@d=070<o?c`80fMWI0P39bLT20<c<c080d];B0P3<
c<`20=[JfP80h>3P0P3IfMT20<o?c`80dm?C0P2g]kL20:2PX080`<300P2OWil209fMW@80X:2P0P1a
LG4207emO@80IFEU0P1[Jf/207emO@80QXJ60P2OWil20:6QX@80T92@0P25QHD20:ZZZP@0moOg0P3b
l_820?Ogm`<0l_;b3P3gmoL20?;blR`0moOg0P3oool50?Ogm`80oooo0P3gmoL20?;blQP0moOg3`3o
ool000d0oooo>@3gmoL20?ooo`80moOg103oool20?Ogm`80oooo103gmoL20?ooo`80jNWY0P26QXH2
08>3P`80SHf=102g]kL20<71`@80a/K60P3?cll90=WIf@80j>SX0P3Ogml20=[JfP80fMWI0P3Ph>02
0=?Cd`80clo?0P31`L420<G5a@80WIfM0P2=SHd20:2PX080O7al0P1mOGd207=cL`80Rh^;0P1SHf<2
08b<S080WinO0P2QXJ4209fMW@80S8b<0P2QXJ420=oOg`H0moOg0P3bl_870?Ogm`80oooo0P3gmoL2
0?ooo`@0moOg0P3bl_8B0?Ogm`80oooo3P3gmoL20?ooo`P0moOg0P3oool90?Ogm`80oooo6P3gmoL?
0?ooo`003@3oooli0?Ogm`80oooo0P3gmoL40?ooo`80moOg0P3oool40?Ogm`80oooo0P3YjNT208J6
QP80Ph>30P2=SHd40;Ng]`80`L710P36a/H20<o?c`T0fMWI0P3Xj>P20=oOg`80f][J0P3IfMT20>3P
h080dm?C0P3?cll20<71`@80aLG50P2MWId208f=S@80X:2P0P1lO7`207emO@80Lg=c0P2;Rh/206=S
H`80S8b<0P2OWil20:6QX@80WIfM0P2<S8`20:6QX@80gmoO1P3gmoL20?;blPL0moOg0P3oool20?Og
m`80oooo103gmoL20?;blQ80moOg0P3oool>0?Ogm`80oooo203gmoL20?ooo`T0moOg0P3ooolJ0?Og
m`l0oooo000=0?ooodL0moOg0P3bl_820?Ogm`80oooo103gmoL209RHV080OGem0P26QXH20;Vi^@80
bl_;103IfMT30=SHf080dm?C0P3;bl/20=[JfP80d=3@0P3;bl/20<71`@80[jn_0P2OWil209JFUP80
ZJVY0P2_[jl209fMW@80S8b<0P1XJ6P207moO`80WIfM0P2<S8`40:n_[`80]kNg0P2_[jl208f=S@80
[jn_0P3bl_8<0?Ogm`80oooo2@3gmoL20?;blP@0moOg0P3oool20?Ogm`80oooo1P3gmoL20?;blP80
moOg0P3oool:0?Ogm`80oooo5`3gmoL60?ooo`80l_;b303gmoL20?ooo`X0moOg3`3oool000d0oooo
A`3gmoL20?;blP80moOg0P3oool40?Ogm`80V9RH0P1mOGd208J6QP80^KVi0P3;bl/40=WIf@<0f=SH
0P3Cdm<20<_;b`80f][J0P3@d=020<_;b`80`L710P2_[jl209nOW`80UYJF0P2YZJT20:n_[`80WIfM
0P2<S8`206QXJ080Ogmo0P2MWId208b<S0@0[jn_0P2g]kL20:n_[`80SHf=0P2_[jl20?;blP`0moOg
0P3oool90?Ogm`80l_;b103gmoL20?ooo`80moOg0P3oool60?Ogm`80l_;b0P3gmoL20?ooo`X0moOg
0P3ooolG0?Ogm`H0oooo0P3bl_8<0?Ogm`80oooo2P3gmoL?0?ooo`003@3ooolW0?Ogm`80oooo6P3g
moL20?;blP80oooo103gmoL20?ooo`X0moOg0P2PX:0209RHV080]kNg0P2i^KT30<71`@@0f][J0P3I
fMT40=[JfP80fMWI1031`L420:ZZZP80YjNW0P2HV9P20;Ng]`80clo?0P2PX:020<71`@80bl_;0P31
`L420:2PX080UYJF0P30`<020>WYj@H0oooo1P3gmoL20?ooo`/0moOg0P3oool<0?Ogm`80l_;b3P3g
moL20?ooo`80moOg2P3oool:0?Ogm`80oooo1`3gmoL40?ooo`80moOg0P3ooolH0?Ogm`l0oooo000=
0?ooobL0moOg0P3ooolJ0?Ogm`80l_;b0P3oool40?Ogm`80oooo2P3gmoL20:2PX080V9RH0P2g]kL2
0;Vi^@<0`L71103Jf]X20=WIf@@0f][J0P3IfMT40<71`@80ZZZZ0P2WYjL209RHV080]kNg0P3?cll2
0:2PX080`L710P3;bl/20<71`@80X:2P0P2FUYH20<30`080jNWY1P3oool60?Ogm`80oooo2`3gmoL2
0?ooo``0moOg0P3bl_8>0?Ogm`80oooo0P3gmoL:0?ooo`X0moOg0P3oool70?Ogm`@0oooo0P3gmoL2
0?oooaP0moOg3`3oool000d0oooo9@3gmoL20?;blRX0moOg0P3oool20?Ogm`80oooo103gmoL20:j^
[P80YjNW0`31`L420:ZZZP80`<30103@d=020=oOg`80f][J0P3Xj>P20?3`l080j>SX0P3IfMT20<o?
c`80fMWI0P3@d=020<o?c`80ZZZZ0P2OWil20;Ng]`80clo?0P3YjNT40?Ogm`@0oooo0P3bl_8>0?Og
m`<0l_;b103gmoL20?;blPH0moOg0P3bl_8>0?Ogm`80l_;b3P3gmoL20?;blP80moOg0P3oool20?;b
lPX0moOg0`3bl_880?Ogm`80l_;b5P3gmoL?0?ooo`003@3ooolU0?Ogm`80l_;b:P3gmoL20?ooo`80
moOg0P3oool40?Ogm`80[Zj^0P2WYjL30<71`@80ZZZZ0P30`<040=3@d080gmoO0P3Jf]X20>SXj080
l?3`0P3Xj>P20=WIf@80clo?0P3IfMT20=3@d080clo?0P2ZZZX209nOW`80]kNg0P3?cll20>WYj@@0
moOg103oool20?;blPh0moOg0`3bl_840?Ogm`80l_;b1P3gmoL20?;blPh0moOg0P3bl_8>0?Ogm`80
l_;b0P3gmoL20?ooo`80l_;b2P3gmoL30?;blPP0moOg0P3bl_8F0?Ogm`l0oooo000=0?ooobL0moOg
0P3ooolR0?Ogm`80l_;b103gmoL20?ooo`@0l_;b1P3gmoL70?;blP@0jNWY0P3Ogml20?3`l080j>SX
0P3?cll40<71`@80clo?0P3@d=040<_;b`80dM7A0P3YjNT20?;blPX0moOg103oool20?Ogm`H0oooo
2`3gmoL40?;blP`0moOg0P3bl_820?Ogm`80oooo0P3bl_860?Ogm`80oooo4P3gmoL20?ooo`80moOg
0P3ooolA0?Ogm`80oooo3P3gmoL20?ooo`H0moOg3`3oool000d0oooo9`3gmoL20?ooob80moOg0P3b
l_840?Ogm`80oooo103bl_860?Ogm`L0l_;b103YjNT20=oOg`80l?3`0P3Xj>P20<o?c`@0`L710P3?
cll20=3@d0@0bl_;0P3AdM420>WYj@80l_;b2P3gmoL40?ooo`80moOg1P3oool;0?Ogm`@0l_;b303g
moL20?;blP80moOg0P3oool20?;blPH0moOg0P3ooolB0?Ogm`80oooo0P3gmoL20?oooa40moOg0P3o
ool>0?Ogm`80oooo1P3gmoL?0?ooo`003@3ooolY0?Ogm`80l_;b5P3gmoL20?ooo`80l_;b203gmoL2
0?;blQ<0moOg0P3oool:0?Ogm`P0l_;b0P3oool<0?Ogm`@0oooo1P3gmoL20?ooo`P0moOg0P3bl_82
0?Ogm`80oooo1@3gmoL20?ooo`H0moOg0P3oool20?Ogm`80oooo0P3gmoL20?ooo`80moOg0P3bl_84
0?Ogm`80l_;b5P3gmoL20?;blP@0moOg0P3oool90?Ogm`80oooo703gmoL?0?ooo`003@3ooolY0?Og
m`80l_;b5P3gmoL20?ooo`80l_;b203gmoL20?;blQ<0moOg0P3oool:0?Ogm`P0l_;b0P3oool<0?Og
m`@0oooo1P3gmoL20?ooo`P0moOg0P3bl_820?Ogm`80oooo1@3gmoL20?ooo`H0moOg0P3oool20?Og
m`80oooo0P3gmoL20?ooo`80moOg0P3bl_840?Ogm`80l_;b5P3gmoL20?;blP@0moOg0P3oool90?Og
m`80oooo703gmoL?0?ooo`003@3ooom;0?Ogm`80l_;b103gmoL20?;blP80oooo1P3gmoL20?;blP80
moOg0`3bl_840?Ogm`80oooo0P3bl_8<0?Ogm`80oooo103gmoL20?;blP`0moOg0P3oool20?Ogm`80
oooo1P3gmoL20?;blP80oooo0P3gmoL40?oooa<0moOg0P3oool40?;blP80moOg0P3bl_8@0?Ogm`80
oooo303gmoL20?ooo`L0moOg0P3bl_820?Ogm`@0oooo403gmoL20?ooo`80moOg0P3bl_820?Ogm`l0
oooo000=0?oood/0moOg0P3bl_840?Ogm`80l_;b0P3oool60?Ogm`80l_;b0P3gmoL30?;blP@0moOg
0P3oool20?;blP`0moOg0P3oool40?Ogm`80l_;b303gmoL20?ooo`80moOg0P3oool60?Ogm`80l_;b
0P3oool20?Ogm`@0oooo4`3gmoL20?ooo`@0l_;b0P3gmoL20?;blQ00moOg0P3oool<0?Ogm`80oooo
1`3gmoL20?;blP80moOg103oool@0?Ogm`80oooo0P3gmoL20?;blP80moOg3`3oool000d0oooo:`3g
moL20?ooob80moOg103oool60?Ogm`80l_;b103gmoL30?ooo`H0moOg0P3oool40?Ogm`80oooo1P3g
moL20?;blP`0moOg0P3bl_820?Ogm`80oooo103gmoL40?ooo`H0moOg0P3bl_840?Ogm`80l_;b0`3g
moL20?ooo`P0moOg0P3ooolB0?Ogm`80oooo0P3bl_880?Ogm`80oooo103gmoL20?ooo`@0moOg0P3b
l_8=0?Ogm`80l_;b0P3ooolD0?Ogm`80oooo0P3gmoL?0?ooo`003@3oool[0?Ogm`80oooo8P3gmoL4
0?ooo`H0moOg0P3bl_840?Ogm`<0oooo1P3gmoL20?ooo`@0moOg0P3oool60?Ogm`80l_;b303gmoL2
0?;blP80moOg0P3oool40?Ogm`@0oooo1P3gmoL20?;blP@0moOg0P3bl_830?Ogm`80oooo203gmoL2
0?oooa80moOg0P3oool20?;blPP0moOg0P3oool40?Ogm`80oooo103gmoL20?;blPd0moOg0P3bl_82
0?oooa@0moOg0P3oool20?Ogm`l0oooo000=0?ooob<0moOg0P3oool40?Ogm`80l_;b103gmoL20?;b
lQH0moOg0P3bl_820?ooo`H0moOg0P3bl_880?Ogm`80l_;b0P3oool30?;blPH0moOg0P3oool60?Og
m`80oooo0P3gmoL20?;blP@0moOg0P3bl_8D0?Ogm`80oooo103gmoL20?;blP80moOg0P3oool70?Og
m`80l_;b103oool40?Ogm`80l_;b0P3oool80?Ogm`80oooo1P3gmoL20?ooo`H0moOg0P3oool40?Og
m`80oooo103gmoL40?ooo`@0moOg0P3oool70?Ogm`80l_;b403gmoL20?ooo`X0moOg3`3oool000d0
oooo8`3gmoL20?ooo`@0moOg0P3bl_840?Ogm`80l_;b5P3gmoL20?;blP80oooo1P3gmoL20?;blPP0
moOg0P3bl_820?ooo`<0l_;b1P3gmoL20?ooo`H0moOg0P3oool20?Ogm`80l_;b103gmoL20?;blQ@0
moOg0P3oool40?Ogm`80l_;b0P3gmoL20?ooo`L0moOg0P3bl_840?ooo`@0moOg0P3bl_820?ooo`P0
moOg0P3oool60?Ogm`80oooo1P3gmoL20?ooo`@0moOg0P3oool40?Ogm`@0oooo103gmoL20?ooo`L0
moOg0P3bl_8@0?Ogm`80oooo2P3gmoL?0?ooo`003@3oool]0?Ogm`80oooo;03gmoL20?;blPL0moOg
0P3oool20?;blP80moOg0P3oool80?Ogm`80oooo0P3gmoL20?ooo``0moOg0P3bl_820?Ogm`80oooo
6`3gmoL20?;blP`0moOg0P3bl_820?ooo`80l_;b0P3oool40?Ogm`80oooo103gmoL20?;blQP0moOg
0`3bl_8B0?Ogm`80l_;b0P3oool:0?Ogm`l0oooo000=0?ooobd0moOg0P3oool/0?Ogm`80l_;b1`3g
moL20?ooo`80l_;b0P3gmoL20?ooo`P0moOg0P3oool20?Ogm`80oooo303gmoL20?;blP80moOg0P3o
oolK0?Ogm`80l_;b303gmoL20?;blP80oooo0P3bl_820?ooo`@0moOg0P3oool40?Ogm`80l_;b603g
moL30?;blQ80moOg0P3bl_820?ooo`X0moOg3`3oool000d0oooo:@3gmoL20?oooaX0moOg0P3bl_8D
0?Ogm`@0l_;b2@3gmoL20?;blP@0oooo103gmoL20?ooo`80l_;b2P3gmoL20?ooo`80moOg103bl_84
0?Ogm`80oooo0P3bl_820?Ogm`80oooo0P3gmoL20?ooo`@0moOg0P3oool20?Ogm`<0oooo2P3gmoL2
0?ooo`X0moOg0P3bl_820?Ogm`80oooo1P3gmoL20?ooo`H0moOg0P3oool20?Ogm`80oooo103gmoL2
0?ooo`80l_;b2`3gmoL20?ooo`@0moOg0P3ooolB0?Ogm`@0l_;b3`3oool000d0oooo:@3gmoL20?oo
oaX0moOg0P3bl_8D0?Ogm`@0l_;b2@3gmoL20?;blP@0oooo103gmoL20?ooo`80l_;b2P3gmoL20?oo
o`80moOg103bl_840?Ogm`80oooo0P3bl_820?Ogm`80oooo0P3gmoL20?ooo`@0moOg0P3oool20?Og
m`<0oooo2P3gmoL20?ooo`X0moOg0P3bl_820?Ogm`80oooo1P3gmoL20?ooo`H0moOg0P3oool20?Og
m`80oooo103gmoL20?ooo`80l_;b2`3gmoL20?ooo`@0moOg0P3ooolB0?Ogm`@0l_;b3`3oool000d0
oooo;@3gmoL20?oooaP0moOg0P3oool40?Ogm`80l_;b0P3gmoL20?;blP`0moOg0`3oool>0?Ogm`80
l_;b0P3ooolF0?Ogm`80l_;b0P3gmoL20?ooo`80moOg0P3oool60?Ogm`80l_;b0P3oool20?;blP<0
oooo1P3gmoL20?;blQ00moOg0P3oool40?;blPH0moOg0P3bl_880?Ogm`80oooo3P3gmoL30?oooaP0
moOg0P3bl_820?Ogm`80oooo0P3gmoL?0?ooo`003@3oool]0?Ogm`80oooo603gmoL20?ooo`@0moOg
0P3bl_820?Ogm`80l_;b303gmoL30?ooo`h0moOg0P3bl_820?oooaH0moOg0P3bl_820?Ogm`80oooo
0P3gmoL20?ooo`H0moOg0P3bl_820?ooo`80l_;b0`3oool60?Ogm`80l_;b403gmoL20?ooo`@0l_;b
1P3gmoL20?;blPP0moOg0P3oool>0?Ogm`<0oooo603gmoL20?;blP80moOg0P3oool20?Ogm`l0oooo
000=0?ooobl0moOg0P3bl_8@0?Ogm`80l_;b0P3oool40?Ogm`80l_;b103gmoL40?;blPH0moOg103o
ool70?Ogm`80l_;b203gmoL20?;blP@0moOg0P3oool20?Ogm`80l_;b0P3oool:0?Ogm`80oooo0P3g
moL20?ooo`80moOg0P3bl_820?ooo`80moOg0P3bl_820?Ogm`80l_;b103gmoL20?ooo`D0moOg0P3b
l_840?Ogm`80oooo0P3bl_820?ooo`80moOg0P3bl_820?Ogm`80l_;b0P3oool20?Ogm`80oooo1P3g
moL20?;blQl0moOg0P3bl_8L0?Ogm`l0oooo000=0?ooobl0moOg0P3bl_8@0?Ogm`80l_;b0P3oool4
0?Ogm`80l_;b103gmoL40?;blPH0moOg103oool70?Ogm`80l_;b203gmoL20?;blP@0moOg0P3oool2
0?Ogm`80l_;b0P3oool:0?Ogm`80oooo0P3gmoL20?ooo`80moOg0P3bl_820?ooo`80moOg0P3bl_82
0?Ogm`80l_;b103gmoL20?ooo`D0moOg0P3bl_840?Ogm`80oooo0P3bl_820?ooo`80moOg0P3bl_82
0?Ogm`80l_;b0P3oool20?Ogm`80oooo1P3gmoL20?;blQl0moOg0P3bl_8L0?Ogm`l0oooo000=0?oo
odT0moOg0P3oool20?Ogm`80oooo0P3gmoL20?;blP@0oooo0P3gmoL20?;blP80oooo4@3gmoL40?oo
o`P0moOg0P3oool<0?Ogm`80oooo2P3gmoL80?ooo`T0moOg0P3bl_820?Ogm`80oooo1P3gmoL80?oo
o``0moOg103oool80?Ogm`80l_;b303gmoL20?ooo`T0moOg0P3oool80?Ogm`80oooo0P3gmoL20?oo
o`@0moOg0P3oool40?Ogm`l0oooo000=0?ooodT0moOg0P3oool20?Ogm`80oooo0P3gmoL20?;blP@0
oooo0P3gmoL20?;blP80oooo4@3gmoL40?ooo`P0moOg0P3oool<0?Ogm`80oooo2P3gmoL80?ooo`T0
moOg0P3bl_820?Ogm`80oooo1P3gmoL80?ooo``0moOg103oool80?Ogm`80l_;b303gmoL20?ooo`T0
moOg0P3oool80?Ogm`80oooo0P3gmoL20?ooo`@0moOg0P3oool40?Ogm`l0oooo000=0?ooobD0moOg
0P3oool20?Ogm`80oooo103gmoL20?;blP80moOg0P3bl_8:0?Ogm`80oooo303gmoL20?;blP80moOg
0P3bl_820?Ogm`80l_;b3`3gmoL20?;blP`0moOg0P3oool80?Ogm`80oooo0P3bl_820?Ogm`@0oooo
5P3gmoL20?ooo`/0moOg0P3bl_8<0?Ogm`80oooo0P3gmoL20?ooo`@0moOg0P3bl_820?Ogm`80oooo
1P3gmoL20?oooa00moOg0`3bl_820?Ogm`80l_;b703gmoL?0?ooo`003@3ooolU0?Ogm`80oooo0P3g
moL20?ooo`@0moOg0P3bl_820?Ogm`80l_;b2P3gmoL20?ooo``0moOg0P3bl_820?Ogm`80l_;b0P3g
moL20?;blPl0moOg0P3bl_8<0?Ogm`80oooo203gmoL20?ooo`80l_;b0P3gmoL40?oooaH0moOg0P3o
ool;0?Ogm`80l_;b303gmoL20?ooo`80moOg0P3oool40?Ogm`80l_;b0P3gmoL20?ooo`H0moOg0P3o
ool@0?Ogm`<0l_;b0P3gmoL20?;blQ`0moOg3`3oool000d0oooo9@3gmoL20?ooo`@0moOg0P3ooolL
0?Ogm`80l_;b303gmoL20?ooo`80moOg0P3ooolE0?Ogm`@0oooo1P3gmoL20?;blP@0moOg103ooolF
0?Ogm`L0oooo5P3gmoL60?oooah0moOg0P3oool20?Ogm`<0l_;b0P3gmoL20?;blP@0moOg0P3oool4
0?Ogm`80oooo0P3bl_8>0?Ogm`l0oooo000=0?ooobD0moOg0P3oool40?Ogm`80oooo703gmoL20?;b
lP`0moOg0P3oool20?Ogm`80oooo5@3gmoL40?ooo`H0moOg0P3bl_840?Ogm`@0oooo5P3gmoL70?oo
oaH0moOg1P3ooolN0?Ogm`80oooo0P3gmoL30?;blP80moOg0P3bl_840?Ogm`80oooo103gmoL20?oo
o`80l_;b3P3gmoL?0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00F@3oool2@00006T0oooo0T00001J0?ooo`00F`3o
ool00d000000oooo0?ooo`1X0?ooo`03@000003oool0oooo05L0oooo001=0?ooo`=000000`3oool3
@00000<0oooo0d0000050?ooo`03@000003oool0oooo0080oooo00=000000?ooo`3oool0103oool0
0d000000oooo0?ooo`070?ooo`=0000000@0oooo@000003oool0oooo0T0000020?ooo`=000000`3o
ool2@00000<0oooo0T0000030?ooo`9000000P3oool3@00000<0oooo0T0000030?ooo`=00000403o
ool3@00000070?oood000000oooo@000003ooom000000?ooo`04@0000080oooo0d0000020?ooo`90
0000E@3oool004h0oooo00=000000?ooo`3oool00`3oool01D000000oooo0?ooo`3ooom000000080
oooo00=000000?ooo`3oool01`3oool00d000000oooo@000000@0?ooo`06@000003oool0oooo@000
003ooom00000103oool00d000000oooo0?ooo`020?ooo`04@000003oool0oooo@0000080oooo0T00
00020?ooo`03@000003oool0oooo00<0oooo00E000000?ooo`3oool0oooo@00000040?ooo`04@000
003oool0oooo@0000140oooo00U000000?ooo`3ooom000000?oood000000oooo@000003oool00d00
00020?ooo`06@000003oool0oooo@000003ooom00000E`3oool004h0oooo00=000000?ooo`3oool0
0`3oool01D000000oooo0?ooo`3ooom000000080oooo00=000000?ooo`3oool01`3oool00d000000
oooo@000000@0?ooo`=000000P3oool3@0000080oooo00=000000?ooo`3oool00P3oool01T000000
oooo0?oood000000oooo@0000080oooo00=000000?oood0000000T0000030?ooo`04@000003oool0
oooo0?ooo`=000000P3oool014000000oooo0?oood00000A0?ooo`08@000003oool0oooo@000003o
oom000000?oood0000030?ooo`04@000003oool0oooo@0000080oooo00=000000?oood0000000T00
001E0?ooo`00CP3oool2@00000<0oooo0T0000040?ooo`=000002P3oool00d000000oooo0?ooo`0?
0?ooo`05@000003oool0oooo@000003oool00d0000020?ooo`=000000`3oool2@00000030?oood00
001000000080oooo00=000000?oood0000000T0000020?ooo`A0000000@0oooo@000040000100000
0`3oool3@0000100oooo0T0000020?ooo`90000000<0oooo@000003oool00P3oool2@00000<0oooo
0d000000103ooom00000@0000400001E0?ooo`00CP3oool014000000oooo0?oood00000C0?ooo`03
@000003ooom000000100oooo00A000000?ooo`3ooom000009`3oool00d000000oooo0?ooo`1j0?oo
o`00C@3oool5@0000080oooo00=000000?ooo`3oool03`3oool00d000000oooo0?ooo`0>0?ooo`A0
00009`3oool2@0000140oooo00=000000?ooo`3oool0J03oool00?l0oooo8@3oool00?l0oooo8@3o
ool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-6.47761, -2.56068, 0.491133, 
  0.491133}}]
}, Open  ]],

Cell[TextData[{
  StyleBox["\t",
    FontFamily->"Times New Roman"],
  StyleBox[
  "To check up the validity of solution, we print out the maximum difference \
between the original and recovered image data. Consequently, it is revealed \
that our solution has a good accuracy.",
    FontFamily->"Times New Roman"]
}], "Text"],

Cell[CellGroupData[{

Cell["Max[Abs[monoSample-recoverMono]]", "Input",
  CellLabel->"In[48]:="],

Cell[BoxData[
    \(4.10691293195597495`*^-7\)], "Output",
  CellLabel->"Out[48]="]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["2.8  Image resolution",
  FontFamily->"Times New Roman",
  FontSize->16,
  FontWeight->"Bold"]], "Section"],

Cell[TextData[{
  StyleBox["\t",
    FontFamily->"Times New Roman",
    FontSize->10.5],
  StyleBox[
  "The image governing equation has been successfully solved with good \
accuracy. This mean when we change a number of pixels representing a \
recovered image then it is possible to change a resolution of the image. \n\t\
Using this function \[OpenCurlyDoubleQuote]poissonSOR2D\
\[CloseCurlyDoubleQuote], we produce the two images whose resolutions are \
lower (100 by 100) and higher (150 by 150) than those of the original 128 by \
128 image. ",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell[CellGroupData[{

Cell["low=poissonSOR2D[-source,{100,100}];//Timing", "Input",
  CellLabel->"In[49]:="],

Cell[BoxData[
    \({10.7499999999999995`\ Second, Null}\)], "Output",
  CellLabel->"Out[49]="]
}, Open  ]],

Cell[CellGroupData[{

Cell["high=poissonSOR2D[-source,{150,150}];//Timing", "Input",
  CellLabel->"In[50]:="],

Cell[BoxData[
    \({45.2899999999999636`\ Second, Null}\)], "Output",
  CellLabel->"Out[50]="]
}, Open  ]],

Cell[TextData[{
  StyleBox["\t",
    FontFamily->"Times New Roman",
    FontSize->10.5],
  StyleBox[
  "The left and right in Fig. 9 show the images having 100 by 100 and 150 by \
150 resolutions, respectively.",
    FontFamily->"Times New Roman"]
}], "Text"],

Cell[CellGroupData[{

Cell["\<\
lowG=ListDensityPlot[low,PlotRange->All,Mesh->False,
\tFrame->False,PlotLabel->\"100 by 100 image\",
\tDisplayFunction->Identity];
highG=ListDensityPlot[high,PlotRange->All,Mesh->False,
\tFrame->False,PlotLabel->\"150 by 150 image\",
\tDisplayFunction->Identity];
Show[GraphicsArray[{lowG,highG}],ImageSize->{400,200},
\tPlotLabel->\"Fig.9. Low and high resolution images\"];\
\>", "Input",
  CellLabel->"In[51]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .47619 
%%ImageSize: 400 200 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0113379 0.47619 [
[.5 .48869 -113 0 ]
[.5 .48869 113 12.5625 ]
[ 0 0 0 0 ]
[ 1 .47619 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .48869 -174 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Fig) show
81.000000 12.812500 moveto
(.9) show
93.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(.) show
105.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Low) show
129.000000 12.812500 moveto
(and) show
153.000000 12.812500 moveto
(high) show
183.000000 12.812500 moveto
(resolution) show
249.000000 12.812500 moveto
(images) show
285.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
0 0 m
1 0 L
1 .47619 L
0 .47619 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0113379 0.477324 0.464853 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00961538 0.0192308 0.00961538 [
[.5 1.0125 -50 0 ]
[.5 1.0125 50 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(100) show
87.000000 12.812500 moveto
(by) show
105.000000 12.812500 moveto
(100) show
129.000000 12.812500 moveto
(image) show
159.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
100 string
100 100 8 [100 0 0 100 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
E8E0E7E0DFDDE4DAD8C2C4C4C8C4C4C5D4E07EBDBBBAB4BD
B5BDBCBCB3B4BBC0C1BCBCBCBBB5B9BCBFC6C6C6C6C5C1C3
BCC0C6BDBDBDBDBCBCBCBDBBBDBDBCBDBED7D58CB9B5BAB2
B3B8B9B9B9B9C3C0C0CCC6CBCBC2C8BDBAADAFB3B1B3D0A8
C6DAE3E6
DDCFCDCED4D2CDD2CEC4B6B6B6B6B6B6B3C6A0A5B0ADABA6
A9AAAEADAEADA9B3AEAEADA5A8ADA7ACAEAEB2B2AFB4AFB1
B3B1B1B1B2B1AFAFAFAFAFB0AEAAB0AFAFB0C2A28EA8ACA5
A7A6A5AEACAEB3B1B1B4B4B4B4BAB2AEABACA8A6ACC2B1A6
A8C8CCDC
DFCDD1CED2D0D0D0CECFC2C1B6B5B3B3B2B4CC99ACAEABA8
ACACADAFAFAEA6AFB0AFAAADA6A4A6A3A7AFAFB3B1B0B0B0
B1BAB7B7B8B7B4B3B5B0B0B0B1B1B0B0B0AEABBBC192A9A9
ADAAADADABADB4B1B2B4B4B8B9B4B4AEABAFAFB3B3B8B6AA
A7C3C9DE
DFD0CFD4D0CFD3D4D3CED0CAC4B6B9B2B3B5CAB6A8AFB2A9
AAB2A9AEAFB1AFB0B0A9A9AFAEAEAFA8A4A9B1A7A7AFB2B2
B2B2B9B0BABDB2B5B8B3B2B6B2B3B6B6B0B3AEADB9AE9CB0
B1B1ADADB0B3B3B4B4B4B6B9B7B6B2B3ACB9C2C0C1C4B9A6
A6CBCDDD
DFD0CFCDD0D3CED0CDCFD1CDD1C6B7B8B7B6B5CBBAB6B5B1
ADACB3B2B2A9ACAAA3AAA7AFADAEAEAFAEA4A3ACACADB4B4
B4B3B3B8BAB0B8B7B7BAB8B8B8B6B5B2B2B0B3AFAEC2B09E
B0B2B3AFB2B5B6B6B4B6B2B4B7B6B0A9A3B8C3ABB6AABEA5
BDCDCEDC
DFD4D4CED7D0D1D3CCD1CED0D1D2CFC0BEBEBFC0C7BAA5BB
B5B1ADACABA5A0A2A3A3A3ACAFB2B2B2B5B1A6ABAAA8AEAB
AEB0B4B4B5B2B2B2B6B1B6B5B4B5B3B1B1B0AEAEB1ADC3C6
A9AEB0AFB0B4B6B4B5BBB2B5B5AB9D96A7C0B3ABB1AEB1A2
C9CCCFDE
E0D4D3D5D6D0D1D0D2CECDD1D0D2CACFCBCBCBCECFCEB7AF
BAB3B0AEA8A7A4A8A8ACA9A3ABB1B2B2B4B5B0A7AFACB1AF
AEAAACA6A8A1A7A6A9A1A7A6A8A8A6A6A4ACABAAADA7ADA8
B6A68BA6AEAFB3B3B6B6BAB69596999C9FB2A7A3A7B5ACB3
C7CDCCDD
E9D3D3D6D8D6D2CCCFCDCDD4CBD0C9D1CFCDCAD0CDCBD3C1
98C8ACA9ACA99F9AA1A6A8A2A8AEB5B3B6B1B1ABADAEB7B2
B8B9B5BBB7B3AEB1B0AFB1ACB6B4B5B2B8B1B1B5B5B3AFAE
AFB8B9996E9DB1B5B49E726E7CA0AAA3A8A6ACB093BAA2BE
BDCED4DF
E1D1D3D2D0D2D2D6CFD3D3D1D0D2CFD1D1CDCFCDD0CCD0C2
A3A1A3A6AFABAAA1A4A7A8A3A7AFAEAFB3B4B7B2AEB3B6B7
B7B8B9B3B7BAB9B7B4B4B6B9B3B5B2B8B6B6B6AEB6B3B4B6
B2B2AFB8BCA38D8E8179837B8D8DA29ACD9EA894B7B7B7AF
CCC8CBE7
E4D4D4D0D8D4D5D5D4D5D0D3D2D2D6CDD2D4D1CECFCDD0C5
BD98A0908AB0A8A2AAA5A6A4A7AFAFB0B2B3B4B3B3B2B7B7
B7B8B8BAB4B5B5B8B6B5B1B0B2B5B1B7B7B7AFB3B5B2AFB6
B5B1ADACA5A79882727E7B898988969EBD90A298B7B0BBC5
CBCBD1E4
E7D2D1D1D8D3D2DAD2D4D6CFD6D6D0D2D6CFD6CECED6D0CD
CEC2908C7971B0A99D9FA6A6A8AFAFB0B1B2B3B4B5B1B1B2
B6B3B9B9B4B4B4B4B1B1B1B2B2B2B0B1B6AFAFB7B5AFB1B2
B0AFA5A3968275858C8B7F8388969EA7A38E9AA5B0AEC3C7
CCCDD0DD
E0D4D6CFDAD9D4DAD3D5D1D7D4D0D4D1D1D6D1D3D5D3D0C9
D5B58A85735A6AA19DA9A7A2A6ABAFB0AFB0B3B4B5B7B9B5
B5B2B3B8B9BAADB1B3B2B0B0AEACAEABB7B3B2ADB7B5B4B2
ADA8A79990758D8A869686829685989595ACA7BC96B6C9CC
C6CBD2E1
E0D3D1D4D6D1D3D8D7D5D8D1D5D4D9D2D3D4D2D4D5D3D3D0
CEC0A58977604670A8A1A3A5A5AFAEAFB0B0AEB3B4B1B5B2
AFB2B7B6B6B3B1AEAEABB0B1AAACA7AAAFAFB0AAB1A9A3A1
9998947764809A8A868DA0998E838B9A97AAB2AAB1C0C1C3
CDCDD2E3
E1D2D6D9D0D8D9D3D4D6D6D1D5D2D9D7D5D5D7D2D3D5D4D1
C2D1938C70635E454DAC9DA3A5AAABADADB2AEB4B2B2B5B2
B3AFB0B0B4B3AFAEABADA6A7ACA6A8A4AEA9A7A8A8A7A29F
9081796B7D918E8E958F87888A939595A3A9A8B9C0BFC6C8
D1D1D4E6
DED7D5D8D7D1D7DAD4D1D5DBDBDAD5D2D4D4DBD5D6D4D7D6
C7D3958E766362494747A1AAA4A9ACADAEAEB5B6B2B3B4B3
B4B1B1B2B1AEADABABABA7A7A6A19EA29FABA3A4A49F9E82
705E7C838E908D8E9796979A99979BA2A8A8ACB6BAC3C7D0
CCD1CDE7
E8D5D4D3D7D9D6D4D2D9D4D3D5D8DAD4D7D4D5D8D8D4D6D3
CEC1978474745D484064A0A3A8AAAAB5B0B2B0B1B2AFB4B2
B2AFB1ADABA8A9ABABA5A5A09A9C9FAC9B949699978B7E81
637179728B898990979FA297A797A2A8A8AAB8B8CCCCCFCD
CECFD3E5
E9D5D4D3D3D6D9D2D7D9D8D7D7D6D7D5D7D4D9DAD8D5D6D4
C9A994867A7A6250535380A5A8AEABB3ADB0AFB1B2B2B0AF
B0B3ACAEACA9A8A9A7A3A0999498B0998C97938C837B746E
7F837A8C928E8C89949C949F949DA8A6A9AFC1C2CBCECAD0
D2CFD4E4
E9D3D5D7D8D9D9D3D9D9DAD5D7DAD7D5D6D6DBD6D9DBD6D4
B5AF8C7F75735D616446819EA7ABACB1ABB0ADAEB0B0AFB2
B0AEB0ADA7A3A5A5A4A49A8F8BA39A85878B857E677C7574
7774708A938B8992939B8E959696A7A5B4C6C1C5CFCFCED1
CCCED3E6
E9D8D4D8D8D6D5DAD5D9DADAD6D6D6D8DBD7DCD8DDDCD5CC
AEA39285825E5F695D4D8E9EB0A7ADAEB1B0AFB1ACAEB0A7
A7A7AEA5A6A4A59D9D958F888F93898886856E7073838583
72848087898DA6969090908FA6A9ACB1BAC0C4C5C8C9D1CD
D4D5D5E7
E9D5D8D9D6D6DAD6D9D9DAD7D9D7DBDAD8D8D8DAD7D8D7CB
AD9F8F8182697368444A8AA0A6A6ACB2A7ACACA7AAA6AAA7
A5A7A0A6A19E9D9E96968C879580767C7670766E737D8C89
827E7B828488A2A19294A190A5A4B3BFC3C0C5C7C8CFCFCF
CECFD1E5
E9D8D8D6D7D8D5DBD9DAD7DADADBDBD8DBD8D5D8D9DAD9C3
A49B8D7C7767705E4D548C9CA9AAA9A9AFABAAA7A6A5A1A1
A29FA3A39D9C9999988D888E8776726F6B716C616E7E8C85
8A8476777F8E99999AA29398A4A8BBBEC2C4C4CCC9CFCFD1
D2D0D5E1
E9D3D7D5D6DCDCD6D4DBD6DBD9D6D5D5D9D7DDDDDDD4D6B9
A7928A896A787752484E919AA6A3ABA7ABA7A9A3A2A2A09B
94939C9C9A9A91918D8C86796E6D6972736E707074798AA2
9E936A6E7F81979E9F8D8D9AACA8BCBBC5C0CCCDCECFCDD0
D2D0D2E1
E4D8D6D4D5D4D6DBDBD7DAD6DADBD5DDDCDDDCD9D8D8D3B1
9D96817A6E7E614B4950909EA8ABA8A9A4A5A4A5A09EA19C
9A9596969A92928A86847C7561626B6E6C4A5573807F838F
939C8678838E7EA1928B8D9AAAC4B9C0C1C7C9C7CECECED1
D1D1D4E6
E9D7D8D5D8D8D8DBD9DBD9DADAD9D8DADCDADCDDD9DCC1AC
948E807770755D535A568DA1A4ABA9A4ACA8A6A4A2989392
908D9290928D8C84837D7B724B6C6659494E6282747A7491
9A97868388889599908494A1BDB5BAC0C9C8CBC9CECFCED1
CFD1D3E4
E4D9D4D1DAD8DAD7D7DBD6DDDAD9DAD9DFDADCD9DAD9BBA6
8E8B80866B72525B5D5892B4B7BBBBBBB3B4B0AFAFA9A089
898C8A84838B84817C72775D4E655A4342605E7E7B72718D
999D9C87846EA3998B989DB2C1BDBFC3C6CBCACCCECDCED1
D1D3D1DF
E9D3D8DBDAD8DBDBDBDCD9DEDCDDE0D7DDE0DADBDEC3AF9E
8E8772747F605A666066B5BCC8C0BFBEC3C2B8B8B4AFABA5
918087898A7782827B736D635E6F49414F635B6C7B6C7082
8C9C9A927F84979593AD8CB3BAAFBFC6C6CAC5C5C9CBD0CB
D2D3D5E7
E5D6D7D7D6D8D8D9DCDBD7DDDADDDBDCDEDCDDDBDBC7A699
877D81777E4D695883BDCBCDC8CACCC3C7C5C3C3BCB7B1AB
A8A1867D7B877A7C706E4F70437D433D306D596D82787881
93A2A9957A858F8A9B999EBDAEC1C5C8CBC5CCCBCCCBCCD0
D1D1D4E7
E9D7D9D4DADAD9D9DCDAD9D8DFDBDEDEE0E1DFDACCC29C95
85777C7A6357636EDACDC9CCD0D0D0CCCCCAC6C5C3BAB8B2
AEA79E8A7A7977746E615177567E5137406671767A738180
8B98A69F7C837F91A49B9BB2BFC4C6C6CBC6CAC8CBCECDCD
D1D3D2E7
E1D7D7D9DAD7D7D6DBD9DAD8DDDAD9E0DCE2DCD9CBB39E93
846B737A4C5F64BBC9D0CFCFD4D0CDCAD3CDCBC8C8C7B7B7
B2ADA69B916A766D6F564B5D9B557974325A6F5B797D7E8B
808BA7AE7384868F9494A4BBBDC4C2C8C6CBC9C7CDC8CDCB
CDD1D3E7
E4D7D7D9DAD6DADCDDDCDADEDDE0E1E1E3E1D7D2C9A5988A
7E7878645C6EAFCFCFD1D2CFD0CCCDCDCCC6C2C4C5C0B8B5
B0ADACA399986A675C5A485282787F557C5C667A677C6281
868C949B996F858A8FA1BABCBFC4C4C7C5CBC8CDC7CCCDCF
D1D0D4E6
E9D6D8DAD8DADADBD9DDDFDDDFDCDDE1E1E4DACCBDA58E88
747C6F5D619ED8D2D1CDD0D0C8C4C0BBBBB8B9BDB7BAB3B9
B7ADACA49F99926F59594A49609166966F735C717D6B7A70
8C8D8FA0998A8F888F9EC5BDC2C5C6C9C8C7C8CBC7CCCDCF
D1D3D4E4
EAD5DAD6DADBDCDEDADFDFE0E1DFDEE0E3E1D0CDB8988C86
7774656559DBCDCFCED2D4ABA1ACB4B6B3B4A19F98ACB5B5
B7B4ACA89F9B9289574C41415D847C8393898172717E6C6C
84829694A28C99869BA7B5C0BEC2C6C6C6C9C9CBCCCACECC
D1D1D2E6
EAD5D6DAD6DCDDDFDBE0DCDBE3E0E5E5E4DFD9CBAC948781
707D6D67E4D1D0CFD3C8ACB5C2EFCEC9DDCDBEB1A592ACB4
B4B6ACAAA59C928B86513935683DA45D9B77977B7F717A73
7F838995A68571868DBFBEC1BCCBC7C3C4C9C8C7C7CDCBCF
D0CDD3E1
E5D8D8D5DADADAD9DFDBDCDFDFDEE6E4E5D4CAAD9D94737A
7A5E6498D8D6D4D4C7C2A9B0B0AFB1BFA79C9E9EA5977AA9
B8B6B4AEA69A9A95887B4B3148647A816B8E85B08077786B
7681808EA18D7F868AB9BDBEBDC6C9C8C9C8C9CACCCDCED0
CFD2D3E6
E6D6D8D9D6DADADEDDDDDFDFE0E0E3E2E2D6C4A690797C77
6B767FD3D2D7D6D7C0C6A39EA1A8A7BAA19B9A9A96A69DA5
B7B8B1ACAB9F999A8E825B2C364866946C7878A4A5866F7D
747D679899A2778E9AB6BBBAC2C0C5C6C9C8C9CACCCACECC
CFD1D3E6
E9D4D7D5DCDDDAE0DCE1E2E2E1E4E2E0E3D2B9958D817771
706D8AD2D5D6D6D5DBE3ECF3EAF3F2F1F9F4EDDED2C8C0BC
BBB8B4ADA9A19F99908F70461A614D627D676773A190827B
6775848B8EA3797C9CB5B8B8C3C5C5C6C8C9CBCBC6CCCCCF
D0CFD4E7
E4D9D9DADBDADEDFDCDEDDE2E2DFE1E2D0C4A98B79787069
7265D4D4D7D7D8DDD7E2E8E7F0EFE9E9E6DDD7D3CFC8C9C7
BBBDB5AFAAA29F928E8E7340334F6D6A8D56717494A6977A
7C70716E90A38088A3B6B0BBC3C4C5C6C7C4C5CACBCDCFCF
D1D3D4E2
E6D6D6D6D9DBDBDFDFDFE1DFE3E1E0E2D5AE93847D6D6C70
765FE1D4D9DCDADBDEE2E4E6E9E9E6DFE4D9D8D8CECAD2BF
C2BEB1B1ABA29D9B8E897F5A3F3157616270625E868F928F
74698571899C8D7CA3B5B6B6C1C4C5C6C5C7CACBC6CDCECD
CFD2D4E7
E9D7D9D9DBDCDDDADFE0E2DEE0E3E5DABFAE8A8778707672
6A94DDD7DDDDDDE1DFE0E4E6E2E0D5CDD8D0D1D0CCCDC9C9
C6BBB6B0AAA19F98958C7B663E4652546C67555E5D978F8D
7A6D737A859B9385A1BFB7C0C2C3C5C4C7C7C9CACBC9CDD0
CDD2D4E7
E3D8D8D9DAD9D9D9DFDDE1E3E2E3E0E2B595847474636779
5EEDDCDBDFDDDCDDDFDFE4EAE2D3D7C7D5CDCACDC8C6C9C0
C5C4B6BCAEA89E979681846C43183E4F685862614C7E7BAF
777B6C7874969599A7A9A4C1C1C3C4C3C7C8C9CACCCECFD0
CDD3D4E7
E8D7D8D9DBDBDCDDDEDEE2E3E4E5E6D6A5867C706D6E776C
5FEEDBDAE1DAE2DDDFDEE5C7B9E2DAD09EADC7A4B8C2CDC8
C5C3BCB5AEA9A19B948E7E73582331444E56604258598578
89745069769295A6A097C4BEC1C2C4C5C7C8C9C9CCCDCFD0
D0D2D1E7
E7D7D8D8DBDADEDADDE0E2E3E2E6E7CE948671756E737862
86E3DCDBE2DFDFDEDDDDE1DAE1E0DED7CECCC9C1B2C0CBC7
C4C1BAB5B1AAA49C8C8C82756F1928414D4D554048536E7F
876D5A6875869E9990C1BDBDC0C2C4C4C7C5C9C9CCCDCFD0
CFD0D4E7
E9D8D6DAD7DDDBE0DDE1DCE4E0E6E7CA84847B75767C7360
CED7DEE0E1E0DFDFE0D6DDE1E1E5DAD8CFC5C3BFB9BFC9C5
C3C2BDBBB1AEA5A0978C817363291E44235557344A566882
7E6A735F6380A097B2BEBEBFC0C1C2C0C6C7C9CACCCDCED0
D1D3D4E7
E9D8D9DBDBDBD9DFDCDFE3DFE6E8EC9583656F7179755555
C9D2D7DCDFDEDFDFDFDFDBD6DDDEDDD4C1BBBFB6BDC7C6C4
C7BEBCB9B8ABA4A19B937E746C471D32534A523E4147646F
8B6D675A6D939E82B2B6BCB9BBC1C3C2C6C7C9CACCCDCFCB
D1D3D4E7
E6D6DAD8D9DDDEDFE0DFE0E1E3E5EF8D74677D747C4E596A
D0D4DCDCDCDDE0E0DCDEDBD9D3DCD4C7C2BCBFBDC4C8C3C2
C5BEBCB7B6A8A7A2989688736750223035494152474C6A6F
896C6B4C60849CA5BABABBBDBFC0C2C4C6C7C9C8CCCDCECD
CFD3D2E7
E5D5D8D9DBDCDDDFDCDEE1E3DFE4D6816F747974685857CB
D4D9DFDAE1DBDDDCDADBDBDCD5DCD4CFC1BFBFBDC2C4C9C7
C3BCC2BAB5B0ABA49D938F7A645D333A3E4A46514742746E
7F6B623A5980A0AFB8B9BABCBEC0C1C2C6C3C7CAC7CCCCCF
D1D2D3E7
E4D8D7DADBDCDEDAE1DFE2E3E3EA737060756B7363726ED3
D7D9D8DEE2DADCE2D9D8D9DBD3D9DBD2BFBDC1BFBDC3CBC2
C5C5B7B8B8B0ADA49C9A8D7D6C54413B35484E4F495C6D6A
6B63482D617BA4B6B6B8BABCBEC0C2C4C6C8C9CACCC9CED0
CCD2D4E7
E5D8D9D9DCDDDDE0E0E0E2E2E0E87A7A6476776E6B53BAD3
D7D8DBDFD9DBDBDADADFDAD8D9D5D0D1BDB5BDBDC0C2C1C0
C2B9BABCB5B0AEAA9E998F826B563E2F363D494D45596C65
687237484E73B1B4B5B7B9BBBDBFC1C3C5C3C7C9CACDCECF
D1D2D4E7
E6D8D9D6DDDCDAE0E0E2E2E3E2D47182757078655FA9DBD1
D6D7D8DCD9DADBD3D4D6D7D8D1D0D3D5C1B4B4B4B5B8BEBB
BEBABCB3B1AFAEA7A7979285765B482C37344B443D556260
5C6E1243556CB3B2B4B6B8BABCBFC1C3C4C6C7C9C8CCCECF
D1D2D4E7
E8D9D7DADCDADEE0E1E2E3E4E5ABA6847D7179615DCECECE
D5DED8DBDBD6CECED1CFD1D8CED1D0D1C0B0A8ADAFB7B7BA
B4AEB4B2B0AFAEAB9CA2938B78614A27233541473C535D5A
4D561A2C5B7DB1AFAFB4B7B9BCBEC0C2C4C6C6C8CACCCECF
D1D2D4E7
E9D8D7DADCDBDDDFE0DDDFE0EB89B87F85836B63B7CCB9D1
D5D6D8D7D6D3D6C4BAC9CCCFC4CACDCFB4A6A99FA3B0B1AC
A8A39E9A9997A5A3A3A193857862534111263C3A4746643D
3D5D291E6387ACACB0B3B6B9B7BEC0C2C4C6C8C9CACBCCCF
D1D2D4E7
E7D9DADBDADDDEDCE1E1E4E4E4A19F757A864D82BB9DB6D1
D4D6D4C5B7B5ADA8A3B9B9CFC7C7CCCCBAA39E979A9594A2
976F84888289A29C9897928777644E3E3C2033323E46553E
385E19266188ACAAAEB2B5B8BBBDC0C2C4C6C7C9CBCCCECF
D1D2D4E7
E8D9DADBDBDDDEDFE0E1E5E6C8A3927A6B84577CC2B1B7D1
D1CEBCA6C6DD8C7F9CA7A4C0B6C6CAC2B8A596848E5AAEB6
736488737A6C899799968D897362513D2F0A333E2A4C5431
3958064D6396A2A9ADB1B5B8BBBDC0BFC4C6C5C9CBCCCECF
D1D2D4E7
E9D9DADADBDDDAE0E2E4E6EEFFB46E6767767898BBA2B6C8
CBB9A164ACD2C7529D698D97BAC7C8C1B6AF8D82728B4E9E
9D20787746547880918F877F776149461510103B2E474542
3C55004B679AA1A8ADB1B5B8BBBDC0C2C4C6C8CACBCDCED0
D1D2D4E7
E9D9DADADCDDDEE0E1E3E4EB9EAC8A6F73727BA8AAA8B6C9
BFB19280836157758B889BB5BBC3C4BEB4AC9E897B666F6E
3B46414554597677828883766B4D4D41321C28202D463D2E
42591C4D779FA4A9ADB1B5B8BBBDC0C2C4C6C8C9CBCCCDD0
D1D2D4E7
E9D9DAD9DCDDDDE0E1E0E2E5AD9C6F6971617FA3A7A1B2C6
C7CBC3B6A79FA1A2AAA4ADBCC2C0C1BEB6B2A38D8A897584
80766B6F7D8E8B8A8D887B79694E4B39331F292525514131
4E6229568FA1A6AAAFB2B5B8BBBEC0C2C4C6C8C9CBCDCED0
D1D3D2E7
E9D8D8DBD8DDDEE0E0DFE0E4BA75535F72557794A495B1C3
C9D1CFCFCFCFA58B7A85B6C4C3C3BFBEB9B8A59269646B8C
ABAAA59F9B9B9A9183707D6E65554948221B230A2C423F32
577136649DA3A8ACB0B3B6B9BCBEC0C3C5C6C8CACBCDCED0
D1D3D4E7
E9D9DADBDDDDDFE0E2E2E3C8B9655564706985899695A6C4
BCC8D3D1CA827A77ABC3BFC1C6C1BDBCBAB4B1A68E5B4954
7E9AABACA2A494856681716558573B2B1E211238404E4A2E
5665576CA9A8ACAFB2B5B8BABDBFC1C3C5C6C8CACBCDCED0
D1D3D4E7
E9D9DADBDCDEDFE0E1E1EF9BAC69756C666A7878828BAAC7
ACAEA4988A9DBDCBC7C8C6C5C3BFB9BBB8B6B0AEADA49783
6E796569706B6E717C7E796659584A27372B180B4A4F4C3C
6453429EABACAFB2B4B7B9BBBEC0C2C4C6C4C8CACCCDCFD0
D1D3D4E7
E9D9DAD8DDDEDDE1E2E4EABA7A6D937F726879798481ACC1
C4C4BFBABEC6C8C6C5C5C4C3C0BCBBBCBAB2B1AEADA6A4A5
A1A493918D848B8385796F636362443720140B0764437042
655065B4AFB1B2B4B6B9BBBDBFC1C2C4C6C7C8CACCCDCFD0
D2D3D4E7
E9D8D8DBDCDCDEE1E3E5ECB46673A68173757775877CACC2
C2C1C4C0C7C6BEC4C3C0BFC0BFBBB4BBB0B6B0B0AEADA0A5
A09D94958E88828181767A66625D58452523270B7A517054
5D5989BFB3B4B5B7B9BABCBEC0C1C3C5C6C8C9CBCCCECFD0
D2D3D4E7
E9D9DADBDCDEE0E1E3E5EBD878838B818279706F7A7F98BB
C0BEBFC2BEC5C3C3C2C1BFBFBDBCBCB8B8B2AFABA8A7A6A3
9E9A9B93908889857F8173646B5E4C2D3C2412117861825A
5458BEB6B7B7B8B9BBBCBEBFC1C2C4C6C7C9C9CBCDCECFD1
D2D3D4E7
E9D9DADCDADEDFE1E3E5E8F875797B847E77737181919CB2
BEBEC2C1BFC2C2BFC1BEBBBFB8BBBBB0B0B0AFA9A9A7A39E
9F939392918A89857C7A716E6658423F31211C236C79816A
567CBCB9BABABBBCBDBEBFC1C2C4C5C6C8C9C9CCCDCED0D1
D2D3D5E7
E9D9DADBDCDDDFE0E2E4E6FC827487847C7374817E919CAE
BABFBDBEBEBEC3BBBBC0BAB7BAB4B2B2AFAFAEA8A9A79EA3
9D9D9596928A8985777A70715B5D4940281D154F626F877B
82A5BBBCBCBCBDBEBFC0C1C2C3C5C6C7C8CACBCCCDCFD0D1
D2D3D5E7
E9D9DADBDCDDDEE0E1E3E3EF759A7A807B768064869794AD
B9BDBFC0BEC3BDC0BFBCBCB6B4B7B1AFAFADADACACA1A2A0
9E919D908B8A8885768471625A4949391F24216A6A61817F
92BFBEBEBEBFBFC0C0C1C2C3C4C6C7C8C9CACBCDCECFD0D1
D2D4D5E7
E9D8D9D8DCDDDEDFE0E1E3E6C87578707272717D8692A3AD
B9BEBFBEBEC0BDBCB9BCB8B4B7B2B0B0AEADABABA5A4A69C
9E959C928C8B8887817E6B645C5A40342729297E6E68868F
A6C5C1C1C1C1C1C1C2C3C4C5C6C7C8C9CACBCCCDCECFD0D2
D3D4D5E7
E9D9D9DADBDCDDDEDFE0E1E1D2837872736F6F778892A2B0
B8C0BDBEBCC0BCBCBDBCB8B8B1B4B0AFACACABAAA6A6A19F
9C9B9B918C8A87867D796E695E4E372B34282E897D6785A3
C4C2C4C3C3C3C3C3C4C4C5C6C7C8C8C9CBCCCDCECFD0D1D2
D3D4D5E7
E9D5D9DADBDBDCDDDEDEDFDFE69C6B6A6D7174708E9AA8B3
BAB7BABDBDBCB9BCB5B9B3B3B0AFACADACAAAAA9A3A0A49E
9B9B949593898980826F6F63554A38312F3D307B887A94AF
CAC7C6C5C4C4C4C4C5C5C6C7C8C8C9CACBCCCDCECFD0D1D2
D3D4D5E7
E9D9D9D9DADBDBDCDDDDDDDEE0AC896E766F72778099AEB7
B8BEBEBFBDBABCBDB4B4B3B0AFAEADA9ABA9A9A2A3A09E9A
9A9993918C8B87877871695E52423C372F35247C747B96CF
CAC8C7C6C6C6C6C6C6C7C7C8C9C9CACBCCCDCECFCFD0D1D2
D3D4D5E7
E9D6D9D9DADADBDBDBDBDCDBD9E7CEA57D7C76748597A2B6
BBB8BDBCBEB9B9B7B6B5B4B0AFAEACA8A9A3A2A5A09D9999
999290908D8F7F7F7373605251403F37361E4D886E819FD3
CACAC8C8C7C7C7C7C7C8C8C9C9CACBCCCDCDCECFD0D1D2D3
D3D4D5E7
E9D8D9D9D9DADADADBDBDBDAD9D8D7D67E7869788195A5B2
B1BABABAB7B7B8B8B6B0B2B1AAAAA6A4A4A3A09B9A999898
98908D8E8A8A818173655751534A34382A3E81726992BDCE
C7C8C9C9C8C8C8C8C8C9C9CACACBCCCCCDCECFCFD0D1D2D3
D4D4D5E7
E9D8D8D9D9D9DADADADADAD9D8D7D5E1856B93778A95A2B2
BABAB7BAB9BDB4B7B0B5B2AFAEA7ABA49D9DA29998989796
91938B89858470796B655F5240524621315D6B6C799AC7CB
CBCDCAC9C9C9C9C9C9C9CACACBCCCCCDCECFCFD0D1D1D2D3
D4D5D5E7
E9D8D8D8D9D9D9D9D9D9D9D9D8D7D4D9986B6F7C8694A4AB
B3B9B8B7B2BBB4B1B0AFAEA7ABA19E989593989895959493
8C89898282796F695B5D4E4947444039645D6D8A89A9C8D0
C9C9CDC9C9C9C9CACACACBCBCCCCCDCDD1CED0D0D1D2D2D3
D4D5D5E8
E9D8D8D8D8D9D9D9D9D9D9D8D8D7D5D7C05669797C909AAC
ADB2B2B4B5B2B3AEADACAAA3A49E968B8B8D928C8A8B8388
83867F7C786C64655D5B4B473F55434B836873979DB6CBCA
CBCBCDC9CACACACACACBCBCACCCDCECED1CFD0D1D1D2D3D3
D4D5D6E8
E9D7D8D8D8D8D8D8D8D8D8D8D8D8D8DAB9856F7979818AA3
BBABADAAB5B3B1ADA5A4A1978D8A897F7E7978787B7A7A70
71706F646C635D5143574E515842615F656B759AABCACAC9
C9C9CACACACACACBCBCCCCCDCDCDCECFCFD0D0D1D2D2D3D4
D4D5D6E8
E8D7D8D8D8D8D8D8D8D8D8D8D8D8D8D8E1BA8A72798A9189
92AEB0B7B3ABA8A698948F9B8583806A706B6473665E655C
625E5F61576067615C5E4D5564463C6973759095ABCAC9C8
C9C9C6CACACBCBCBCCCCCDCDCECDCFCFD7D0D1D2D2D3D3D4
D5D5D6E8
E8D7D8D7D8D7D8D5D8D8D8D8D8D8D9D9D9DEE1857D828F96
9DB5B0B3AEA79F97998B8F87807B6E6461645B60605E515A
5F5A55565F3C4D5950565B4C48585A657A8F968ECEC6C7CA
C8C9CACACACBCBCCCCCDCDCECECCCFD0D0D1D1D2D2D3D4D4
D5D5D6E8
E8D6D6D7D8D8D8D7D8D8D8D8D8D9D9D9DADCE1B783837F94
92A0ADAAA49E9991917E7F7F72727159514C5C5B5D57585E
5952545E4F483D39364A40413F4D677EA38572C3C4C5C6C9
C8C9CACACBCBCCCCCDCDCECECFCFD0D0D1D1D2D2D3D3D4D4
D5D5D6E8
E8D8D8D7D7D7D7D7D8D8D8D8D8D9D9DADADCDDEBBB8F94AE
AEB9B0AE9592928B91877B7179625A3F5F4C2355475C5950
445E20303C3A434E574C45454C897B973D7593CAC1C4C6C7
C8C6CACACBCBCCCDCDCDCECFCFD0D0D0D1D2D2D3D3D4D4D5
D5D6D6E8
E8D7D7D7D7D7D7D7D8D8D8D8D8D8D9D9DADBDCDECD7D7D86
87A4AEAAA086848A887A7477626A50634C554C374B3E483A
3A2A3A36363A423B3A4B5C60797985606A73ADBBC1C2C2C7
C6C8CCCACBCBCFCCCDCECECFCDD1D2D3D2D2D3D3D4D4D4D5
D5D6D6E8
E8D7D7D7D7D7D7D7D7D8D8D8D8D8D9D9D9DADBDAE5B57687
9B9DA0AAA678807B816E70725E60613455463F3146363D39
323228252D303B3F40606674827751735AAAC1B7C0C1C5C6
C7C8CCCACBCBD0CDCECECFCFD0D1D1D2D2D3D3D3D4D4D5D5
D5D6D6E8
E8D7D7D7D8D7D7D7D7D7D8D8D8D8D8D9D9D9D9D9D4D7D563
778C9BB0A4747C79888667726155613F5452490E2F56302F
2C291E1A19142E4E6A5A74713D5A624E7ABDB9BCBFBFC3CE
C7C9C9CACBCCCDCECBCECED0D0D1D2D2DBD3D3D4D4D4D5D5
D6D6D6E8
E8D7D7D7D3D7D7D7D7D7D7D8D8D8D8D8D8D8D8D8D7D6D6A1
686C8C9AA7806C82696863525E554C5C484C4F4636293C34
3E37503C425559626C9367582E586574C1B8BABCC2C6C1C5
C8C8C9D1CBCCCDCECFCED6D0D1D1D2D3D3D3D4D4D4D5D5D5
D6D6D6E8
E8D7D7D7D7D7D7D7D7D7D7D7D7D7D8D8D8D8D7D7D9D6D7D6
97736F797EA06C677C685E47474C50543E4D5C494A4B3039
4B504F5A697A6D6C695949465C5D70BBB5BFC0BAC4C4C6C4
C9C9CACBCCCDCDCECFCFD0D1D1D1D5D3D3D4D4D4D5D5D5D6
D6D6D6E8
E8D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D4D5D5D5
D49662818D939669795E655F4B39354A3B47615986745D70
6D728E878666525649404B6A5A60BAB6BFBABEBFC1C4C2C7
CACFCACBCCCDCECECFD0D1D1D2D2D3D4D4D4D4D5D5D5D6D6
D6D6D7E8
E8D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D7D6D6D6D6D6D9
D4D9BC725B87A29B6F766D5E7A73333F274F6A5A5776798B
9D8E68635D515742395966585FBEB3B3B9BABAC1C2C2C6C7
C7C7CAC7CDCECECED0D0D1D2D2D3D3D4D5D5D5D5D5D6D6D6
D6D6D7E8
E8D7D7D7D7D7D7D7D7D7D7D7D7D6D6D6D7D6D6D6D5D5D5D8
D3D3DAAD806E83A2959A96A59491A2AFA3949182877E7888
64775453554A505C6D6167ADB5B4B7B9BBBEBEC3C2C6C4C9
CBCCCBC9CDCBCFD4D0D1D2D2D3D2D5D4D7D4D5D5D6D6D6D6
D6D7D7E8
E8D7D7D7D7D7D7D7D7D7D7D6D6D6D6D6D7D6D5D5D5D4D8D6
D7D1D2D2DA926A78A09EA0A1A5A39BA199949B908881606C
67634C55546E756F6B91B0B9B0B7B9C0BDC3C2C1C4C6C8C9
CACACBD1CDCFCFD0D1D7D2D2D2D8D6D4D7D9D4D6D6D6D7D6
D7D7D7E8
E8D7D7D7D7D7D7D7D7D6D6D6D6D6D5D5D6D5D5D5D4D3D3D2
D2D0D0CBCED5D0885F75A5AFABA395A09186746465766451
4B6E638A8D80619EBABBB8B9B9C2BCBEBEBEC3CDC8CCC9CA
C8D1CCCDCECED7CFD1D3D2D3D3D4D4D9DBDBD2D6D6D7D6DE
D6D7D7E8
E8D7D7D7D7D7D7D7D7D6D6D6D6D6D4DCD5D5D5D5D4D4D3D3
D2D1D0D2CED2C8CFD0BA7A8B8F9EA8A4A19F8B8975668496
8B9B937389B6CEC6BCBCC0BFBEBEC0C8C1C4C5C5C7C7CACB
CDCCCDD5D3D8D8D9D5D5D3D4DAD4D5D9DCD6DBD6D7D7D7D6
D7D7D7E8
E8D7D7D7D7D7D7D7D6D6D6D6D6D6D2D8D5D5D5D4D4D4D3D3
D2D1D1CFCFCACBD0C3C8CCA29CA19DA7A2A7A19F9C979A98
9890A2B2BEBCC5BFC2C2C2C1C1C2C1C2C3C6C7C5C9C9CFCA
CECCD3CFD1D1D2D1D2D8D5D6D5D5D5D5D5D6D7D7D7D7D7D7
D7D9D7E8
E8D7D7D7D7D7D7D7D6D6D6D6D6D5D5D6D3D5D4D4D4D4D3D3
D2D8CED0CFCCC9CCC6C6C3C2BFC1BDBBB8B9B0ADAEB7B1B3
B7BABCC3BFBFC2C3C3C3C2C2CBC5C9C6C8CACAD1CBCECCCD
CECED2D1D2D2D2D3D4D4D3D6DAD5D6D6DDD5D7D7D7D7D7D7
D6D7D7E8
E8D7D7D7D7D7D7D7D6D6D6D6D6D6D5D6D5D4D4D4D4D4D3D3
D2D1D1D0D0CACCC5D2C7C6BFC1BCBEC6B7BBB9B8B8BEB6B7
B8BCBEBEBFCBC3C6C4C6C8CAD0CFC6C7C9C9C9CBCDCEC9CF
CDD1D2D2D3D3D2D9D4D5D6D6DDD5D6D3D5DFDBD7D7D7D8D8
D8DCD2E8
E8D7D7D7D7D7D7D7D6D6D6D6D6D7D5D5D8D6D3D4D4D4D4D3
D3D2D2D0D3CFD0D2CBCAC5C4C7C6C1BFC5BDC3BEBCB9BDBD
BFC0C1C0C8C3C6CDC7C9C7CACAC7CDCDCDCBCFCFCDCECFD2
D1D2DCCFD3D5D2D8D4DBD7D5D5D8D6D7D6D4DBD8D8D7D8D9
D6D6DCE7
E8D7D7D7D7D7D7D7D7D7D6D6D6D8D5D5D4DAD2D5D4D4D4D3
D3D2D2D0D4D0CFCCCDCCCAC3CBC4C9C0C6C3C1C4C1C1C7C0
C3C3C4C4C5CCC7CAC9CACACFCCCDCBD0CDCECCD2CFCED4D1
D5D2DCD3D2D7D3D5D6D4D8D7D6DAD6D6D5D8D7D7D8D8D5DF
D6D7D6E8
E8D6D6D6D6D7D7D7D7D7D7D7D7D7D7D8D9D5D4D5D5D4D4D4
D3D3D1D0D1D1D1D0CFCECDC7C6C9C8C7C5CEC6C6C6C3C5C5
C5CEC6C3C7C9CFC8D2CCD2CED7D0D2D0D0D0D6D1D1D1D3CD
D6D7D6D6D9D5D5DADAD6D7D9D6D7D7D6DFD7DBD9D8D8D8D8
D7D7D2E3
E8D6D6D6D6D7D7D7D7D7D7D7D7D7D7D6D5DDD4D5D5D5D5D4
D4D2D4D9D2D2CFCED2D0CFCFCED0CBCBCAC8C9C5CDC8C7C9
C9C9CACCCBC8CED1D4CDCFCDD8CED4D1D1CFD1D3D2D3D3D5
D7CFD5D5D2D5D5D5DAD6D6D6D7D7D9DAD6D7D7D7D8D8D8D8
D7D3DCE7
E7D6D6D6D6D7D7D7D7D7D7D7D7D7D7D7D7D6D3D6D6D5D5D5
D4D1D8D3D4D3D4CED7D4D2D9CFCFCCCECDCDCDCFCDCDC8D3
CCCDCECFD2D4CED1D0D1D3D5D1D6D2CED3D7D2D8D6D6D5D9
D6D7D6D6D7D6D6D6D4D6D6D7D7D7D9D7D4D7D9D7D7D8D8DB
D6D8D6E7
E5D5D6D6D6D7D7D7D7D7D7D7D7D7DED8DAD7D3D5D5D6D6D5
DAD4D4D4D7D3D3D0D7D3D3D5D2D2D2CDD1D0D2D1D1D0CFD1
D4CDD1D7D4D1D2D2D2D4D4D5D2D9D4D3D4D4D3D4D6D6D7DC
D7D8D7D3DBD7D7D8D8D7D7D7D7D6D8D6D3D7D8D7D7D7D8D9
D6D6D5E5
F0E5E7E8E8E8E8E8E8E8E8E8E8E8F1E7EDEAE9E8E8E8E8E7
E7E7E7E7E2E8E8E8E9EBEAF0E6E6E6E6E5E5E6E6EDE6E5E4
E2E4EEE9E5E6E6E6E6E7E7E7EFEFEBE7E7E8E8E7E8E8E8F1
F0EBE9E9E8E7E8E7E7E8E8E8E8F1E7E7E4E9EDEBE8EEE6E9
E8E7E6F0
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0113379 0.97619 0.464853 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00641026 0.0192308 0.00641026 [
[.5 1.0125 -50 0 ]
[.5 1.0125 50 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(150) show
87.000000 12.812500 moveto
(by) show
105.000000 12.812500 moveto
(150) show
129.000000 12.812500 moveto
(image) show
159.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
150 string
150 150 8 [150 0 0 150 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
EEF1F1F4F1EEF0EEEDF3F2F0EBD8D7D8D9DCDDD9D9D9D9D7
E3F4DDA2CBDED8D3D2CFD4D4CDCFD4D4D4D5CFCDD1D4D5D9
D9D5D4D4D3D3D4D5CDD0D6D4D5DADADADADADADADBD8DAD8
D4D4D7DAD5D3D4D4D4D4D4D4D4D4D4D5D4D3D3D4D3D3D4D4
D2DEEDF2D6AAC6CFD4D6D3CECDCDD1D3D3D4D4D4D3D8D9D6
D5D9DFDBDDDFDFDDDAE0DBD5D3D0CACBCECECECBD4E7E0C1
CDE2EDF1F7EE
F1F8F2F1F0F4FAFAF4F2F7F8F3EDDADADCDDDCDCDCDCDBDB
DBE7E5B5D9E3DBD6D6D5D1CFCECED2D6D7D7D7D7D3D3DADC
D7D6D6D7D3CCD1D7D8D3D3D8D7D5D6D9DAD7D5D7DED8D6DB
DCD6D6D6D5D5D8D9D6D7D6D6D7D7D7D7D7D7D5D0D1D6D6D5
D5D5E1F6E8B0A1D1DDD9D6D0CFCFD0D0D4D9DAD9D8DBD9D8
D9D6DBDBDCDCDBDDE2DEDDD7D5D6D6D5D1CFD1E2F3E9CCC9
CADFF2F2F5F2
EBEFE7E7E8EBEDEDECEAECEFF3F2E8D7D2D3D3D3D2D4D4D1
D0DAE8DBAAC3D6D2CFCAC4C6CBCDCDCFD0D0D1D1CCC7CBD5
D3D0CFCDC8C6C6C9C8C4C4C7CBCDCDCED1D0CDCED0CFCDD0
D1CFD2D3D4D3D2D3D4CFCFCFD0D0D0D0D0D0CECCCDCFCFCE
CECDCFD8DFDECCABBDCFCACACECDC9C7CCD0CCCCD0D5D4D4
D4D2D3D3D3D5D8DADBD5D4D2CFD0D1D0CDD0D7DEE7E7D0C4
C1D2E4EBF4ED
EDEFE8ECECEAEFEFEBEDF0F0F0F1F0E4E1DCD4D0D2D0D0CF
CFD3E0EEC1BECDD2CFCBC6C7CACBCACCD0D0D1D0CBC5C8D1
D2D0D0CCC9CBC5C2C3C3C1C0C3C9CDCDCFD0CECECECECDCD
CFD4D9D7D7D7D7D8D7D4D2D4D5D2CFD0D0D0CFCFCFCFCFCE
CECECDCDD5E7F0CAB1BECFCFD1D1CECFD1D0CDCED0D5D4D3
D4D2D4D5D7DADBDBD8D9D3D1D0D1D3D0DEDCDBE0DED8DCCB
C2D3E3E6F1EE
EEF2EAEDEEEEF0F0EBF0F4F2F0F0EEF0F0EADDD2D3D1CECF
D0CFD8EEEBC5C4D2D2D1C9C7C7C9C9C8CCD0D0D0CECACCCF
D0CDCCCACACEC9C6C9CAC7C1BFC5C9CDCBC8C8C8CDCECECE
CFD3D7D7D4D3D8DDD9D5D5D6D8D5D0D0D2D2D1CFD0D2D2D1
CFD0D0CECFD4E7F1BEB2CED4D4D4D4D5D3D2D2D4D4D5D4D4
D5D3D5D6DBDDDBDAD8DAD5D4D1D3DBE0ECE8E2EBE2D0E0CD
C1D6E9E8EDED
EEF4EAEAEEEFECEDEDEFF1F2F3F1F0F5F2F1EDDFD6D5D1D2
D2D2DAE7EFD4CCD3D6D5CBC9C8CBCCC9CACFD0CECDCED0CD
CBC8C8C7CACECECECFCFCCC8C3C3C3C7C6C1C1C5CBCECFCF
CFCECFD4D1CFD6DBD7D2D6D4D5D6D3D2D6D6D3D1D2D4D5D4
D0D2D2D0D1D0D4E9D9C2C2CDD6D7D8D5D2D2D4D7D8D7D7D8
D8D6D6D7DADCDCDCDCD7D6D5D0D1E2F1EFE7E6E8E0DAE5CA
C4DAEEF0F2ED
EFF5EBECECEAECECF1EDEDEFEEEDF4F5F2F4F6F0E3D9D7D6
D6D6D6D9E9EFDED3D8D9D2D0CBC8CBCECDCECFCAC6C8CAC5
C1C5C7C6C8CECECFD0CFCFD0CEC4C1BFC4C4C3CBC5CACDCD
CDCFCFCFD1D5D7D3D0D5D4D4D4D5D5D5D7D6D5D5D2D1D4D0
D0D1D0D2D3D0D1D5EAE3C9C6D2D7D7D6D4D4D7D7D9DAD9D9
D8D7D9D7D7DADDDCDAD6CEC9C6CFE1ECF4D9D5D6D0DBE4CA
D1E7F0EEF6EE
EFF8F1F1EDEBF0EAECEEF1F0EDF4F5F0F2F6F6F6F5F0E0DA
DCDDDDDEE0EFE8D8D4D8D8D6D1CECBC8C7C7C6C7C3BDBABF
BFBFC3C2C4CECFD3D4D3D3D5D5CDCCC3C2C5C5C5C0C3C5C3
C6CDCDCECED2D1CECECFCFCFCFD0CFD0D5D5D1D0D0D0CFCF
CFD0D0CFCFD1D1CFD9EAEFE0D0D1D2D2D2D3D7D6DADAD8D8
D8D8DED9DADDDDD9CFCDBEB5BCD5E9E4EED7D1D5D4D5D2C5
DBEDEEEFFAEF
EEF3EDEEECEEF1ECF0EEEDECEBEFEFF3F2F4F6F7F7F4EEE6
E2E3E3E4E2E5EDEACBAFD7D7D2CDC8C7C7C6C6BEB9BABDBE
BFBEBFBFC1C9CED0D3D4D3D5D5CFCEC5C0C0BFBFBEC3C1BE
BFC1C3C7C7C7CBCCC7C7C8C7CCCBC9CECECACCCECFCDC8C9
C9C9C9C9C9CBD0CCCAD8EBE9D1CFD1D2D2D3D3D4D8DBD9D7
D9DEDFD9D8D9D6D0C5B1B2B2BFD6DDD1C5C8CFCCCED7CCC3
DCEEEDEBF5EF
EEF6EBEDF0F1F1ECEDEDEDEFF0EEEDEEF2F3F4F7F6F1F4F0
EFF1EFEFF1F2F4F4E7D2C9CFD3CFC9C7C7C7C3C1BCBDC3C3
C4C8C9C6C2C2C9CDD2D4D3D3D4D4D2CCC3C0C4C6C0C4C4C2
C2C0BEBFBBBABCBAB7BBBBBBBDBAB9BEBDBCBDBEBFBEBCBC
BCC3C5C4C6C7CAC6C3C9CECED6D5C5B3B6C8D1CED5D6D5D6
D9DBDBDEDBD8C4AEB1B1B6B7BAC7D2CCC1C3C7D0D7D1C7CF
E0EBEDECF1EE
F2F6EDEDEFF2F1EFECEDECEDF0EEEDECF2F3EFF3F6F0F5F4
F5F8F4F3F9F9F6F5F9F8DDCDBFCAD2C5C1C6C4C5C0BCBFBE
C2C8CAC9C3BFC5CCCFD3D4D4D5D5D1CEC7C4C7C8C4C8C7C7
C9C8C5C2C1BFBEBBB9BABCBBBAB8B9BCBABABEBEBEBFBFBF
C3C9C5C4CCCCCCC7C8C9C3C3D1D6CBBEBFAF9BC5CACED2D4
D6D5C8B9B0ADA19DB1BEC2BBB9C1CACBCFCCC0CCDECFBCD8
E0E7EEEEF5ED
F0F1EEECEBEFEEEFEEEEEEECEBEEF0F1F2F1EEF0F6F1F5F5
F5F6F2F2F6F5F5F5F5FAF5CFACBBCBBDBAC6C7C5C2BFBDB8
BDC2C6C7C3BEC4CCCDD0D2D2D5D2D0D0CCC7C5C6C8CCCACA
CDCDCDC9CAC7C7CAC8C5C8C4C1C2C4C6C6C6C8C7C7C8C8CA
CFD0CBCAD0CFD0CBCFCFCDCDCDCFD5D9D8B89ACEC0B7B9C1
C4B8A495898691A3B5C6C4B9C5D0C6C8D0C7C1D0DBCDC4D3
DFE7EBECF6F1
EDEFECEDEBEBEAECECECEFEFEDEFF4F4F2F0F0F2F4F3F4F4
F6F6F3F5F4F2F5F5F3F7F3D1B7AFB2B4B8BDC6C7C4C4C2BA
BEC3C4C5C4BFC3CBCECDCDCFD2D2D1D2D0CAC6C6CACCCCCC
CCCCCDCDC9C5C6CBCBCCCDC9C7C6C6C8CCCBC8C8CAC8C7CF
D0CFD0D0CDCAD0CCCED0D0D2D1CCD1D1D2D4DADFC9B5ACA7
9B8C8C948F8F9CA5A8B9B8B4D2DABDC3CBB6C4DCD5C9E1D4
E4EAE7E8F0F4
F3F2E9EDEDEBF1F1EBEBEDEFF2F0F4EFF1F2EFF1F2F6F1F3
F7F8F8F7F2F1F1F0F2F5F0D6CEB4A4B4B09EB4C4C3C1C0B9
C1C4C0C1C4C1C3CBCDCCCDCDCED2CED0CFCCCAC6C6CBCDCC
CCCCCCCCCCCDC7C3C6C7CCCDCDC9C6C6C5C3C6CBCECAC5CE
D0D0D0CDC9CBD0CBCECCCBD2D1D1D1CDCAC9CCD4D5D2C89D
737D908C90999E9E9FA1B0B8D0CCAAB9CAB8C1D5CFCDEBE9
EAEAEAEBF3F4
EEF6EFECE9ECF0ECF0F2F2F0EEF3F4F0EEF1F5F5F5F6F1F1
F5F8F7F4F1F1F2F3F2F3F1DBD1C0A9A6AE8C7BA2C1C2BEBE
C3C0C1C2BFBEC3CBCDCCCCCCCDD2CDCCCCCCCCCBCBCCCCCC
CCCDCCCCCCCDC9C5C5C6CCC9C7CACAC4C2C6C7C8C7C6C7CE
D0D0D0CBC7D0D1CCCACACDD2D1CBCACAC9C5BBB5B19D8985
89888889979C9B9DA1B2B6B6C5C3AFB7C4B9CAD3CCD6E7EC
EFE8EAF2F7F1
F2F5EBEAEAECF0EAF0EEEFF0EDF3EFF2EFF0F5F6F5F1F0F3
F7F5F2F6F2EFF0F5F6F3F1E3E1DCBA9A9F88766C9AC2BBC2
BAB7BCC1C1C1C3CBCCCCCCCCCCCECCCCCCCCCCCBC7C7C7C7
C9CBC8CCCCCDC9C6C6C6C7C7C5C5C6C4C6C7C7C7C6C5C8CA
CECBC9C9CAD1D1CCC8C9CBCDCCC5C7C3BEB9ADA38D7E7F8D
989797918D969DA1AEB7B7BEC0B3ABB6B8C3CDCDCDDBEEED
EDECECEFF5EE
F0F3ECEDEAEBF0EFF1EDEEF1EDEEF1EFF0F4F3F0F0EFEFF4
F4F1F5F4F1F3F3F4F4F1F1E2EAE4B9928E87775F5E89B9BA
B6BBBEC0C1BFC2C6CACCCCCCCBC8CBCCCCCCCCCBC9C9C6C7
C9C7C5C7CBCCCBCBC9C2C2C5C6C5C6C5C4C6C6C4C4C6C6C5
CDCACACCCACBD0D0CCCACBC9C6C3C0BCB5AFA8937B829093
949CA5998D92A1A8A8B4AFB5B6B3BABEBDD5C9C0D4E8EEEF
EAEBECEDF8F0
EEF1ECECE9EBF1EDEEEBEEF2F0EFF0F0F0F1F1F0EEF2F1F1
F2F2F3F1F4F5F5F5F2F1F0E0E8DDBFA1878A7A64464C89B9
B7BDBCBEC1BEBFC6CBCCCCCCCBC8C8C8CACCCAC8C8C8C6C5
C5C4C6C8CCCDCBC9C8C3C2C3C4C4C4C6C5C6C4C3C1C1C5C5
CACACBCCC9C9CDCDC5C1C1BCB6B6B3B4AB9A87747D97A18F
859AA4A6A2A1A4A09CA7A7AFB1B7C4C6D6D5C5C5DBEBE9EB
EAEBEBEDFAF1
EEF4EAE9EAEDEDE8EAEBEEF1F2F2EDF2F0EEF2F3EFF4F2EF
F1F4F1F1F4F1F3F5F2F1EEE8E6DCCCB08B8B7A634E3D4A8D
B7BFB6B9C2BFBEC7CBCAC9C9C9C9C7C5C6CACAC4C4C6C6C2
C0C1C4C9CAC9C9C7C5C4C2C0C1BFBFC4C4C6C2C2BFBBC1C1
C5C9C6C6C8C4C8C6BDB7B5B0AAA8A49F8F78676487A2A591
899EA2B1B1AEA89C979BA7B1B2B7C3C6DACAC9D7E3E6E2E4
EBEEECEDFAF3
EDF6EEEBEEEFE9EBEEF1EFECEFF2EEF1EFEFF3F1EFF4F3F1
F0F2F5F3F0EEF0F1F1F1ECEEE1DFCCA38F877260554B3C3B
89B7B7B7BEBCC0C3C8C6C4C4C4C5CAC7C4C8C8C4C4C9C6C4
C3C0C1C3C4C2C6CAC5C1BFC0BFBEBEBCBCC0C0BFBCBBBBBB
C2C7C0BFC3BBC3C1BDB7B2B0A89C92856F63707B929D9E9B
9EA7A5A6A2A1A6A59CA1ADAFB3BDC4C5C5CFD8E0E6E5E1E6
EEF0EEEEFAF5
EEEFEEF1F1EEE9F0F1F2EFEBEDF1EDEDECEDEFEDEEF3F5F5
F3F1F3F6F1EFF0F1F1EFE9E8D8DBC4938E876F5E5A564732
207FB2B5B7BCBCC1C2C3C4C4C4C4C9C7C8C9C4C4C4C4C3C3
C5C3BFBFC1C0C2C6C5C3C2C1BFBFBEB8B5B8BFBDB9BCC0BB
C2C3BEB9BAC0BAB8B8B6AFA59783787371727F96A09C989A
A2A79E9391999C9EAEAFAFAFB9C5C5C5CBE0E7E2E1E9EFEE
F1F3F2F1F8F4
EDF7EDEFF1F0EFECEDF0F2F0EDECEAEDF1F2F3F3F3F1EFF0
F1F1F2F6F2F1F1F0EFEFF0E9DBDCC4968E87725F5956452E
28267FBAB8C0BCC0C1C3C4C4C4C4C5C9CBC8C4C4C4C4C4C4
C5C4C1C1C4C1C1C2C1C1BFBEBEBEBDB8B8B8BAB8B4B3B9BB
B9C2BCB4B9B9B8AEB1B1A28773775C687D828F9F9D999B9A
9FADA6A3A2A7ABACB0B4B2BBC3C5C4C6D2DBDFE3E7EBEEF3
F0F1F1ECF3F4
F3F9EBECEFEEF1EFF0EEEEEDEAEDF0EDECEEF0F1F4F3EFEE
F2F3EFF0F1F4F3F0EFEFEEE8E0DBBF978C7C70675F513D2C
25237FBBB6BDC0C1C2C2C5C7C5C9C5C5C6C5C4C3C0C3C5C3
C3C3C0C2C1BFBEBDBABEBEBDBEBCB9B8B6B3B2B2B0B1B8C3
BAB3ADABAEAFAFA3A09A917F5C6B6770767B909C9693979E
A5ABB1B4ABAAB7BDB2B4BDC3C5C4C6D1D8D8E3ECEEF3F2F0
EEF1EFEBF7F5
F5F6E9EAECEBEDF1EEEEEEEAEBF1F3EEEEEEEFF1F1F1F0F2
F2F0EFF3F4F4F4F2EFEFECE8DFCBAF988B7A6B6D66534431
2C3A5F95B9BEC2C6C3C1C6C9C5C7C5C4C4C4C3C2C1C2C0BF
C2C3C0C0BFC0BCBBBCB7BDC1C0BBB8B8B2B1A8A7AEB7C0BF
AAA1A5A6A5ABA69690857B7A76727D84848B9A9E979697A0
A59FA7AEA9ABB2B0ADBCC4C4C3C6CFD8E1E1EAF2F2F0EEF1
F1F0EDEDF9F2
F4F6E9EAEBE9EAEEEDF0EEEBEFF3F3F1F0EEF0F2EDEFEEF0
F2EFEFF4F6F2F2F1EEEDE9E8DBC0A3938C7B727365544B39
3D473B71BCC1C2CAC4C0C4C6C1C2C4C2C2C3C4C3C2C0BEBE
BFC2C2BEBDBFBEBCBBB9B9BDBCB8B6B3ADA9A3A3B0C3C5AB
9DA0A8A59D9991808480727484838B888C9BA2A19B978E9B
A99DA8A5B1B2AAABB6C3C4C3C4C8D2E0E7E7ECF3F2EBEEF3
F4EFEDF0F8F2
F3F5EAECECEBEDEDF0F2EEEEF2F2F2F3EEECF0F3EFEFEDEC
F0F3EFF2F3F0F0F2F0EBE6E7D1BAA28B857574725E4E4D47
4D4A2C68BFC0C2C7C4C1C2C2BEBFC3C0BEC0C2C2BFBEC0C0
BEBFC1BEBDBCBEBAB5BCB6B6B6B5B3ADA89D9FA7B6C2B398
99A1A39E9182746F808376747985857D8598A1A09A938A9B
ACA3B0A3B1B2AAB2BEC3C4C2C9D2DBE7E7E8EEF4F1EDF4F4
F1EDECF0F9F5
F3F0ECEBEBF0F0F0F0F0EFEFF1F2F2F3F1EDEEF3F2EFEFEE
F1F3F2F5EFEFF3F6F4ECE6E3C2AFA2897B746B65554A5259
5845236AC5BEC4C3C2C2C2C2BFBFC2BFBEBEBDBCBEBEBEBE
BDBCBBC0BCBBB8B3B4B5B6B4B3B4B0A7A29997A8B7AD9793
9396958B8079687387867C7C7A7A7D7E8898A0A099999EA5
A5A1A5A09EA7B1B2B6C5C5C5D0E2EDE7E7EAF0F3F1F0F3F3
EEEEEDEDF9F4
F3F5EEEAEBF0EFECEFEEEFF0EEF2F2F3F3F0EEEEEFEFEFF2
F5F3F1F4EFF2F5F5F3ECE5DABCA89B8C8075725D4B4E5A5C
513F3077C4C0C9C4BDC0C3C0C1C2BEBEBFBFBAB6BCBDB8B5
B5B5B7BDB5B5B5B3B4B6AFAEAFABA7A292969CA3A49A9192
91918C7C6F7473758D938B867A788E908E94979A9EAEAFA8
A59D9FA09FA2B3C4C7CCC7D2DEE2E8EBE6E9EDECEEF4F3EF
F1F2F1F1F8F4
F3F2EDEEEFEEEBEBEFF1EEEEF1F2F2F3F0F0F1EEEEF2F3F1
F2F3F0F0F0F1F1F0EFECE5D8BCA496887B737163555E6A56
3C352C74C5BEC2B8BCC2C4BFB6B7BCBCB8B6B5B4B3B5B5B3
B1B3B4B0B4B1AFAFAFB0AEAEA9A6A39C9591A0A09285818B
85877A737B7877778594978D80878A8B918F88989EAFB5B3
AC9D9FADA4A0B3C5C6CCD5E1EAEAE7EBE6EBEDEFF2F3F3EE
ECEDEDEBF5F4
F3F5EEEDEDEFEEEBF0F2F1EFEFF2F2F3F2F2F3F2F2F3F4F1
F1F3EFF0F3F0EDEFF3F2E5CEB1A39A897A72725E5A635C49
30342B72C5C1C0BDBFBEC0C1B9B4BBB8B3B2B4B1ADB0B0B0
B0AEAFACB2B2AFACA9A8ADAAA6A6A49A92989D93847D7E7C
7A706D7473676E778B999998978D89868589939C96A9B5B2
A69EADB6AAA9B9C3C5D5DFE6E5E3E7EBECEEEEF1F2F0F3F1
F0EEECECF7F2
F3F7EFEEEDEDEEEEEEEDEFF1F0F2F2F0F2F3F3F3F4F4F2F1
F3F3EEEDF1EEEEF2F2F2EAC0A69D96856F6E69585C625144
363D3274C3BBC1BFC0BDB9BCBDB4B6B5B1B0AFADABA9A8AB
ACA8A9ADAFB0ABA7A6A5A8A6A6A39D98909D99897D787773
706D717065606A76899697969C8F8F877F818A979EA8ACAD
ACACB4ABA7AEBBC4CBDDE0E5E7E7E9E8EFF2F0F1F2F1F3F3
F2EFEDF0F9F0
F4F5ECEFEEEAECF1EFEDEEEFEFF2F3EEF0F3F2F1F1F0EEF1
F3F0EEEEF1EEF1F2EDEDE4B8A5988C7F6D72605A6364533B
343B3578C0B5BEB8BBBCB6B5B9B4B0B1AFAAA8AAA8A4A4A3
A19FA1A8A8A9A6A4A4A1A0A2A19C97949191898077717274
7073746D6769707782919C9FA0A399847A7A7F939EA6AAAF
B5B4A99E9FAFC0C7CDDEE2E2E9EDE9ECEFF3F2F1F3F2F0F2
F2F0EEEFF9F0
F2F4EBEDEDEBEBEEEFF0EFEDEEF2F0EFF0F2F1EEEFEDEDF2
F2EFF1F4F3EFF1EFEDEAD0B4A495877970766063665E4D2B
28303179C0B4BAB6B8B9B6B2B0B0AAACACA6A4A7A3A4A49F
9A999A9FA0A4A5A3A09C9C9A9695938F928075716E6E7177
7969616266717D7E858F9FABA9B0A58B7A7B8895949CACB5
B2AA9D9C9AB0C7CDD5DDE6E3E5E9EBF4EEF0F3F3F2F0EFF1
F2F1EEEDF9F2
F0F7F0EDEBEBEBEBEBEDF0F2F2F1ECF0EFF0F1EFF3EEF1F3
F3F3F2F2EFEDEEEEEEE4C1B19E908573686A6069614C3F29
29323076BEB3B8B9B8B5B2AFAAA9A8A7A7A5A19F9FA19F9E
9C98989A9A9DA1A09C9C9A9290918C88917E6D656C736D73
7256444B60778488868A95A1A8A2B0A38A8792929C94A4B4
AA9C9A9A9DB3C8D3E5DEE2E6E7E9EFF3ECECF1F3F1EEF1F1
F1EEEEF0F8F5
F4F7EFF0EEEDF0F1F1F1F1F2F2F2F2EDECF0F0EEF2EFF1F0
F0F2EEEDEEF2EEECEAD6B8AE98867A706B5F5D635B483A33
37393674B5B1B1B1B3B1ADACAEA9A9A3A1A39F989898908F
93918E989A92949B9B9A918E8F908985967E5E6473706A62
524B3A48778476837F8090A2AEA9B3A291979B949C9BA9AA
9E9A9094A9C0D1DBDFDFDDE6EDEDEFF3EFEEF1F3F2F0EBF0
EEEFEFEDF9F5
F4F8EDEEEFECEDECEDEEF0F0EFF2F2F1F1F2F0ECEDEEEDF0
F3F1EEF1F2EEEDEDE2C7B0A38C80786C6B645E5E4E3B3834
393A3572B4AFB0BAB5B2AFAEB1ADACACA9A7A59D928C8E8B
888B8B8D8E9094938F8F8E8786827D849175575E736E584E
4549505C74888480837D85A1A9B1A79D9693979594A6B2A8
9DA199A8B0BDD8E8DADCE6E8EDF3F3F4F3EFF1F3F2F2F0F1
F0F1EEEDF9F1
F1F7EFECE8EAEEEBEEF0EFEDEEF2F2EEF0F1EFEFECEDECF0
F3F1EEF0EEECECEBDDC2AE9B867C766D69725D5B412E3D37
38353B78B8BEC0C4C2C0BFBCB7B6B6B3B0AFAEA9A1998C84
83858786848587898C888685817A757E8964525F6C624C3E
3E595C5A738989817C79859CA8B4B0ADA298978A80A4B6A8
9BA1AAB2B9D0E6E8E2E2EAEBEEF2F3F1F3F2F2F3F1EFF2F2
F1F1F0EEF4EE
F2F5EDECEBEEF0ECF0F2F0EFF0F2F2EDF0F1F0F0F0F0ECEF
F2F0F0ECEBECEDE4D0BAA796857B706465696057382D423D
382E4F94C2C9D0CAC9C8C7C6C2C1C1BAB6B6B4B0ADA79990
897F7D8182818282808483848078717482615C6D6851453A
44685F557282877F74778695A0B3B7B5AAA0977F82A0AEA7
9FA5BBAEB8DCECE0DEE6E8EEF0F1F2EDF0EFEFEFEFF0F1EF
F0F1F1F0F5F1
F2F5EAEDF0EEEEEEEEF0F2F2F2F2F0EDF0F2EFEEF3F1ECEF
F0EEEEEBEBEDF0E1C5AF9C9182786E63635B644B3137443C
324782B9CECFD3CFCBCBCAC9CBC8C6C1BFBDB7B4B0ADA9A3
988B837C7E80817F7B7F838179746B61686B687B6B423B31
3E696D5F6A7C8E7D7C7F83919EB3BBBBB4A08986909D9FA0
A6AEBBABC2E0E2D8DDE9EAF1F3F0F0EFEFEEEFEEEEF1F1EE
F0F1EFEEF8F4
F1F7ECEEEFECECF0EBEDF0F0F2F1EFECEFF0EEEEF1EEEDF0
F1EEEDEDEBEBEADDC1A6968B7A6D6B6C635C5E3B2F434338
568FBDCFD2D4D0D4CED1CFCACCC9C8C6C6C2BDBDB6B1ACAB
A9A299827875757B7F787D7A716D644C4977657A77453931
2C54796D5C7C927D888C8593A4AFBFC6BF9F7F8E9199989C
ABB2B1B2D7E3D7D8E7ECF0F1F3F1EEF3F3F2F1F0EDEDF0F1
F1F0EEEDF8F4
F4F3EEF0F0F0F1F1ECECECEEF2F2F1ECECF0F1EEEDEEEEF0
F2F2F2F1EBE6DACEB99C948372635F65635B4E3437483E49
B7D2CDCCD0D4D4D3D4D4CFCAC9C9CCC8C5C5C5C3BCB3B0B1
B0A9A2997F747272767174726E695B44487F6275885C3E45
304073775E7E897E858F8F929CA4BBC5BDA88F838E9597A4
B4B3B2BCD2DADAE2EBEBF2EFF0F1EFF3F2EEEDF0F1EDEDF0
F1F0F0EFF7F4
F4F7F0F0EDEBF0F1F0F0F0F1F2F1EBECEBEEF2F0EDF1F2F2
F2F2F1EDE9E5D5C5B0948D82746762625D5A41313A3C4481
C6D3CACACED0D4D4D3D3D2D2D0C9C8C6C5C6C4BDB8BBB9B4
B1AFA9A28F92826A6D706D6C685E534745787D7D8469372B
415C7A8B8A87888D7E8594939AA3AFBDC5B18B7D8C8A90A7
BCBEB6B2C1D9E8ECEDEEF2F0F0F1EFF2EEEDF0F2F1F1F0ED
EFF0F0EEF3F3
EFF8EEEEEFEFEFECF0EFEDEFF1EDECECEBEEF1EEEDEDF1F3
EEEDF0EBE8E0D2BFA7938C7D71605959535A342E3A4066BA
C8CDCDCDCDCFD3CCD1CFCACED2C8C8C6C4C5C5C4C2BBB8B7
B4B0AEA9A09B9179666D6C63645B4D433265957773875D61
425E68768F77868A8B8B92938BAAA4B4CEBC897C8C8F97A3
ADB4B2B9CEE0E7E9EDEBEEF1F0EFF2F2EDECF0F0EDEFF1EC
ECEFEEECF6F3
EFF8EDEDF0F1EFEBECEEEFF0F1EFECECEEEFEFF0F0EFF1F2
F0EEECE6E5D7CEBA9D8F7F796C5D58585044303A4367ACC8
CACDCECECCCBCCC7C8C8C5C8CAC6BFBDBEC2C4C1C1BAB8B5
B1B1B0AEAAA29A8F7C655C615D53493A35548A837286895E
64666471827D7A8492837F928DA6A3ADBCBBA7887D8A9B9E
A0B0BACAE0E3E1EAECEAEFF0EEEFF2EFF0F0EFEFEEEDF1EF
EEEDEDEEF8F4
F2F8ECEDF0F0EFEBEDEEEEEEEEEFEFEFEFEFEFEFEEEEEFEF
F0F2EDE3DCD0C5AE9284756E635C5C543E35313061A9CDCA
CAC9C9C9C9C5C2BDB9B9B9B8B8B8B0B1B3B6B7B5BAB9B7B5
B4B3B0B0ACA5A09E967A6561574F493C3B4A6C8989859079
867A64647D8C7E84857A7A8E9C9EA2ABB5C2BD8F84939C97
9AB0C1DDE4E4E7EBEBE9F1F1EEEFF1EBEEF1EEEDEEEFF1F1
F0EEEEF0F7F1
F4F6ECEEF0EFEEEDF0EEEDEDECEEF1F2EFF0F0ECEBEBEDEE
EFF0EEE3D5CDBDA58D7B77685A585C4C2E3539519BD0CACE
CAC5C3C5C5C0B8B3ADA9A6A3A4A4A1A3A9AAA9ADB2B1B5B8
B8B6AFAFABA7A3A19D958162514E493D34405987987E79A8
8F8C746074868D897A7F878BA59BA5ABB2C4C19B9BA19E98
9DAFC1E4E3E6EDEBEDEDF0F2F1EFEEEDEEF1EEECEFF0EFF0
F0F0F0F0F7F1
F3F2EDEFEFEDECF0F0F0F1EEEDF1F1F1F1F2F0EDECECEEF1
EFECE9DFD2CDB99E8876736C5752534332353E98CECACACB
C8C5C4C4BAA99FA09D9A9794949495919598969EA9AAB0B6
B8B7B1B0ACA9A59F9A988D705145423426355482927871A4
98999782737B8E8A848685889F9DA6A8AAB9C4B3A5A3A19F
A8B5C3DBE4E9EBE9EDF0EFEFF1EFECF0F1F1EFEEF0F0EDEE
F0F0EFEFF8F4
F3F1ECEFEDECEFF0F0F0F1EEEDF1F1F1F0F1F1F0ECEBEBEF
F0ECE5D5CECBB18E7B726568594E4437363A4A9ECCC5C5C4
C4C4C1BBA37F7A8A8E8F9091939492817A7A787D99AAAEB2
B7B7B7B1AFADA6A2A0988E8C6743382F23304B658A9F8B8D
AAA29FA396867F8B9081768192A196A4B2B6C3C1A5A7A09A
ABC1CED6E1E9E8E6EAECF0EDEBEFF0EDF0F1F0EEEDF0EFEC
EEF0EDECF8F4
F3F2EDECECEEECEFF0F0F0EEEDF1F1EDEBEEF1F0ECF0F1ED
EEEDE2D8D3BAA189756B635E4F4D493B3545A3C8C5C4C4C3
C7C5AB958F888CB3B6A0949BAAB2968C8885827C7D99AAAF
B2B8B8B1AFB0ABA5A098948E83643C292725473E63B3A471
A39699B2A9908C977F7C878490999AA1ABB7C6C7A08D929C
A5B9E1E5E8EAE7E7F1F1ECECECEEF0ECF0EEECEEF0EFECEF
F0EDEBECF8F0
F0F6ECECEDECEEECEFEEECEEEFEDEDECEBECEDECEBF1F2ED
EEEAD7CEBAA290836F595C53564334363A6CBED1CAC8C4C3
C5C5A0888E8E8C93948D8E90898B7977778592807D7898B0
B4B7B7B6B6B3ACA5A19F9996907F5A35361D2F456B9A9B7D
92A39CA1BBBD9484828A867887979AA0A4AFC5C3A393989B
9DB7E4E8EBE9E4E8F3F2F0F0F0F0F1EFEDEEEFF0F0F0EFF0
F0EFEEEFF7F3
F2F8EEEEEDEAEDEEEDEBEAEDEFEBEBEBEEEFEEEBECF1F0EC
EEE7D2C4A999877562515A50443B333353AACBCEC9C6C5C1
AAA1886C65696E736D6A7272645C4F525B5E5E605C4F648A
A9B8B7B8B4B1AFA8A1A29F9F9487724926162C4A5E77979C
779C9C91B6CABB94938B7D818291958F99B2C3C1B4A4A5A2
A0BADEE9E8E8E9EBEDF2F2F0F0F0EEF1EFF0F1F0F0F0F0F0
EDEEEEEDF8F4
F2F5EDEEEEECEAEDEDECECEEEEEDEBEDEEEEEEECECEEECEC
ECE3D2BEA08F7A625655544C3E403D4E99CECECBCBC7C5C0
A7A38F6D5B5D616D65626D6E5F5851535B5455717270778D
A8B8B7B5B1B0B1AEA5A1A2A3998D7F5D2514223549668CAA
85869392A1C6CEBE9A81838A838D918394B4BAC2C4A8A7A9
ABCADFE8E5E5EAEDEBEFEFEFF0F0EFF0EEEFF0EFEEF0F0EE
EDEFEDEBF8F4
F1F2E9EDEFEDECECEFECEDEEECF0EEF0EFEDECECEEECEAEB
EADFCEB7957E6D5C53554D464748406AD1CDC8CACBC9C6C2
BFC5B6A198938A8F909097998F918F8D8B8791AAADAEB1B2
B4B7B7B4B3B0B1B0AAA5A2A29D978C6F4120102B4D5B7194
9A78879287B3C2CF9F8791897E858D8B99AAABC1C8A7A0A1
ADDAE5E5E4E3E7EFEFEEEDEFF1F1F1F0EDEFEFEDEDEFEFED
EFEFEDEDF8F4
F3F4EBEEEEEDEFEFEFEDEEEEECF0EFEFF0F1EEEBEFEDE9E9
E4D7C5AB896E6661554C454246454C80CCCACBCBC8C7C8C5
C7CACBCED1CDC6C4CECAC1C4CCCEC4C0BDB7B7BAB6B6B8B8
B7B7B9B8B4B1B0AEABAAA39F9B9A947A552E103858546877
917875817D94BDC4B5A69A8A7D7D879097989FC1C8ABA098
A8DFE4E2E3E4EAF2F2F1EDEFF1F0EFEFEFF0EDEEEFECF0F0
F0EDEDEFF7F3
F0F7EFEFEFEFEEEBEEF0F0EEECEFECEBEEF1EFEBEAECECE9
D6C3B89B7B6858505047354349406EBECDCDCCCACBCAC7CB
C5C9CBCDCECBCFCBCEC8C1C2C3C2B7B4B4B4B6B9B6BAC2BE
B7B8BCB9B4B3B2AEABAAA399979B947D5F2D1D364D627F76
967D60739193B1C0C9BEA18B8C8F7F7C7E859FBFC6ACA7A0
ADE3E4DCDFE7EEF1F1F1EDEFF1EEEBEBEBEFF0F0F0F0F0EF
EFEFEFEFF7F0
EFF7EDEBEBEBECEEEBEEF0EFF0EFEBEEEDEEEFECEBEBECED
DDBD9D826A69584B473B444748427CD0CDC8CBCDCBC8C9CC
C9CACBCBCACACBCAC9C4C1C1C1C0B5B5B9B7B6B9B6C0BDBE
BFB8B8B4B3B6B4AEA9A6A9A29B9A97876B4636243258606A
6F776D7184839CBBC5B19D9A8C8D7D828082A1AFBEB2A099
B0D9E3E2D8E3F0EEF1F1EDEFEEEDEFEFEFEFEDEDF0F0EFEC
EBEDEFEFF7F3
F2F3ECEBE9EBEEEFEEECEEF0F0F0EFF0EFF0F0EFECEBECDF
CFB790796B59564C3E4139454C3B75D1C9C7CACDCDCCCBC9
CBCCCBCBCAC9CACBC5C3BDBBC1B8B1B3B9B8B6B9BBC3BCBA
BFC3C1B8B7B6B4B0AAA9A6A39B93918B775131213252606A
6D7F7A696770969EA9B8B9A2868C76848D8D9FA3BAB3979F
C4D6E2E4DFE6EFF0F1F0EFF0EFEDEDF0F0F0ECEDEEECEFEE
EDEEEFEEF7F4
F4F4EEEEECEDEFEFF0EEEDEEF0F0F0F0EEEDEEEEEFEFE9D3
BCA98F71695D544944483E46434D8BCBC7C7CCCECECDCDCE
CCCBCBCBCBC9C6C7BEB6AFAFB7B0AAADB2B4B5B7BDBFC0C0
C3C6BFBBB9B5B2AFABABA3A29F999287785B38303C4D6060
7077786958657196B2B8B2A28B917A7D8A929C9FB8B699AC
D0CCE8E6E9EDEFF1F0F0F0EEEEEFEEEFEFEFEEEDEBEBEFEF
EDEDEEEEF6F3
F1F7EEEFEFEFEEEDEFEEEBECF0F0EEEFEEEDECECF1F0EAD3
B19783695C5D51444142494A386EB7C8C8C9CDCFCECDCED0
CDCACBCCCCCCC5BEB4AFA8A5AEACA4A6ADB1B3B6BABCBEC3
C7C5BEBBBEBBB4B0ADAAA3A2A39D91887B64422B293C5355
6D646E705F624F9AB2A2ABB39291877E838D929AB6BAA8B7
D0CAE1DAE8F2F0F0F0F0F0ECEDF0F0EFEFEFEFEEECEDEFEF
EAECEEEEF6F3
F0F6EEEEEFEFEEEBEDECECEEEFEEEDEFF1F1EFEDF1EEEDD0
A7866D5E514A4A443B3F49443081CFC7C7C9CDCDCED0CECD
CCCBCACDC8B9B0B8B8B6AE9C9191959E9FA0ABB3B6BEBEC1
C6C6C6C0C2BEB7B3B0ABA6A3A39B908B7E68471E132D4451
635B6874685E57868F96B3BB9B8E8E7E7B848497B6BAC1C3
C7D5C7D2E9F1F0F0F0F0EFEDEEEFEFEFEFEFEFEFEFEFEFEE
ECEDEEEDF4F3
F2F5EEEDEDEEEFEFECEEEFEFEEECEFF0F0F1F1F1F1F1E7C2
987A635851414245454A46362D84CEC6C8C9CECCCDD2D1CC
CCCCCACFC5A196BEC8C0B79D75778CA1928A9EABB6C2C6C6
C6C7C7C5BFBDB9B5B2ACABA5A19E978A7A71552817253247
5259646E675768597AA3A7A4AE8D89726C7B829BB3B8CFC4
B5D3BFE6F1EFEFEFEFEFEFEEEFEFEFEFEFEEEEEFEFEEEEEE
EDEDEDECF2F3
EFF1ECECE9EBEFEFEFEFEDEAECEFECEFF0F0F1F1F1EDE1B3
867165644F4A413E48493B304394CDC9CDCFD3D1CBCDD1C9
CCCACBD0D0C8C4C8C9C7BFB2ACADAFB5AF9C92A1B5C3C6C6
C6C7C6BDC4C8C2B8B3B1ACA59D9A968C8677662E0C19293E
4F5B59636C575C347CA693A4B88786766B7A8992A5BAC3B5
A8BCEBF0ECEDEFEFEFEFEFECECEFEFEFEFEBEDEFEEEEEEEE
EBE9EBEDF5F3
F2F5EDEDEDEEEEEBEEF0ECEAECF0EFF0F1EEEDF1F2F1DEAC
7A655B44484E47444D4A302B5AA4CCCCCCCCD2D4D2D2D2CF
CDCCCACED0CBD2D1D1CCC7C0B8B6B5B3B0A9A2A7B7C4C6C8
C8C7C7C5BFBEBEBBB7B3B0A89B96948C83766C310E1A1F46
5561545669575B37729996B2B986857C747C8490A4BAC0B9
B5C9EEF1EBECEFEFEFEFEFEEEEEDEBEFEFEEEEEEEEEEEEEE
EDEAEAEEF6F3
F3F6EEECECEEEBEDEFEDEDECECF0F0ECEFEEEBEEF2EFDCA0
6C5E5B4B4A4C4C4E50452A2F88C4CCCFCFD2D4D5D4D3D3D2
D1CBC6CCD2D0D3D8D5CDC8C4BBB3AFAFAFACA9AFB8C3C6C9
C9C7C9C8C4C3C0BCBAB5B3ACA49D958C8175673C120D2446
3B585C5C654C55526E899BAFAE9885837D777B81A1BBBBBA
CCE1EEEFEDEEEFEFEFEFECEBEDEEEDEEEEEFEEEEEEEEEEEE
EEEDEDEDF6F3
F3F6EEEDEDEEEDEFEDEAEDEEEBEDF0EEEDEEEFF0F2EDC285
655A4B4B48494E5248302B2797D4CDCFCED5D5D4D3D3D3D2
D3CFCACCCFCED2D6D4CECAC2B4ABA9ACABA9ADB5BFC5C6C9
CCCAC8C7C7C8C6C1BBB4B4B1ACA5998C81786C512207203D
43565E6361495254668094A3ADB1877D7A727A87ABBFADAD
D3EDEBEDECEBEBECEEEEECEAECEFEFEEEEEEEEEEEEEEEEEC
EDEEEEEDF6F3
F1F4EDEEEFEEEDEFEDECEEEEECEDEEF0EDEEF2F2F3ECA871
60503C4A4A4C4F442E23282192D5D1D1D0D4D5D3D3D3D2D2
D2D3D1CDC9C9CED1CFCCC6BCB0A5A8ACAAABB4BEC5C6C6C9
CDCDC7C8C7C7C9C5BBB8B5B3AFAAA191867C735F2F0D2231
4F53555D5D57534D66818E9BB3C38E75716E798CABBDB1B9
DCEDEBEDECEBEBECEEEEEEECEDEEEEEEEEECEDEEEEEEEEE9
EAEDEEEDF6F3
F0F3EDEFEEECEBEFEFEFEFEFEFEEECEEEEEEF0F0F2EEA46E
58464354504E50371C25204AA8D4D4D6D5D4D3D3D4D5D4D4
D1D2D3CFCAC9C7D0CDC7BFB6B1A7ABAFB0B3BCC6C7C6C6C8
CCCEC9CAC8C7C8C4BCBCB7B4AEAAA79B8D7C71653712232B
3949545457645A546A86949DB3CA92786F69767DA2BCC2D5
ECEDEDEDEEEEEEEEEEEEEEEEEEEEEEEEEEEBEDEEEEEEEEEB
EAECEEEDF4F3
F3F6EEEFEDEBEFEFEFEFEFEFEDEBEFEDEFEFECEDF0ECA269
524A4E544C4A4C3B21203EA0CCD2D4D7D4D4D4D3D6D9D9D7
D2D1D2D2D0CBC6D0D3CABFB5ADADADB2B5B8BEC6CAC8C9C9
CDD2CDCCCAC9C9C5BEBCBBB6B0A9A5A1907C716D4C1B1432
30485D58516065566389A0A2B2C88E8170617974AAC5C7D8
EEEDEDEDEDEEEEEEEEEEEDEEEEEEEDEDEEEEEDEEEEEDEEEE
EEEEEEECF1F3
F0F3EAEDEFEEEFEFEFEFEFEDEAEAEBEFF1EFECF0F0CE8962
4F4753534E4C3825162EB0D3D1D3DADBD4D4D9D6D2D2D2D1
D1D0D0D0D1D0CCD0D2CCC5BFB3ADB2B4B5B8BEC5C6CFD3CD
CDD0CBD3D0CECCC9C8C5BEBBB5AEA8A5A187736C593B2E3B
474A5A5F59665E53638EA6A1AEBC997D6059737AA2C4D9E7
EDEDEDEDEDEDEEEEEEEEEAECEEECE9EAEDEEEBEBECEAEEEE
EEEEEDEDF5F3
F0F6EBECEFEFEFEFEFEFEDECEEEDEBEEF0F0F1F6EB906459
433D544A494D362A2C48C8D6D4D7D8D6D5D9DBD5D1D1D3D6
D1D0D0D0D1D0CBD0D2D1CCC1B3ACB3B8B9BABDC3C9D1D0CF
D2D2D2CDCECFCFCDCAC9C1BCB6B2ADA5A38C7A6B58463B3D
404D575D65655D667893A29FA3AD97795753778BA2C6E2ED
ECEDEDEDEDEDEDEEEEEEEDEDEEEDECECEEEEEDEBEAEDEEEE
EBECEEEEF6F3
F0F7EFEEEFEFEFEFEEEFEEEDEFEEEBEEF0F1F0F5E8825F52
3D40594F49483C2D3A79CAD4D5D7D5D5DADCD7D3D2D1D3D4
D1D4D6D3D0CFCFD1D1CDC9C1B2ACAEB7BBBDC1C4CBCECCCF
D3D1CDC9D0D1CFCDCAC9C7C1B7B2B0A8A38F7D6A59483535
3A49505968666364859EA09F9FA5A38062637486A3CFE9ED
ECEDEDEDEDEDEDEEEEEEEEEEEEECEBEDEBEDEEEDECEEEEEE
ECEDEEEEF6F3
F2F7EDEEEEEDEEEFEEEDEDEFEFEEEDEEEFF0F0F4E8846858
44434E534D3D3B3657B2D0D2D4D6D4D5D8D6D3D2D2D2D0CE
D0D3D5D2CFD0D1CBCDCDCCC6B5ADABB3BABDC0C4C8CACBCD
D0D0CBCFD2CECBCAC9C9C9C3BDB7B0A9A39783705F4C3934
393F4A5963655D538AA99D9A9EA1AA7F6570707DA1D4EBEC
ECEDEDEDEDEDEDEDEEEEEEEEEEEDECEDECEDECECEEEEEEEE
EEEEEEEEF6F3
F2F7EDEEECEAEEEDEEEBEBEEEEEEEFEFEFEEEFEECB71635B
4F4B4950483435599AD2D0D1D4D5D4D3D3D5D3D1D2D1CDC8
CACDCDCED0D0CCC6CCD0D1CCBBAFABAFB3B7B9BAC3C9C9CB
CFCFCED2CDC8C8C8C8C9C8C2C2BBB0ACA69B8C7965534331
393A45596460575189A69A9B9C8CA77557737A83A0D5EDEC
ECEDEDEDEDEDEDEDEEEEEEEEEEEEEEEDECEDEBECEEEEEEEE
EEEEEEEEF6F3
F0F7EFEEECECEDE9EDECECEEEEEEEEEEEEEBEEDE99686054
54594F4D3A353579D1D3C9D3D5D5D5D2D3D8D3D0D0CCC4C3
C4C7C7CBD0CEC6CACECFD0CDBFADAAA9AAB0B4B2C1C7C7CB
CDC9C9CBC8C6C7C9C9C9C9C4C0BAB5B1AA9C917D68594428
31394157685F5C5B869C98A298689E744C6E8894A8DAEFEC
ECECEDEDEDEDEDEEEEEEEEEEEEEEEEEDE9ECEEEEEEEEEEEE
EEEEEEEEF6F3
F3F6EEEBEBEEEDEAECEEEEEEEEEDEDEDEDEAEFD076817151
575E4A4C323F4B84CBC8C6D1D4D8D8D2D2D2D1CDCBC4B9BE
C0C1C2C5CBCDC7C8CECFD0CDBDAAA8A5A7AAADBAC1C4C8C5
C1BFBCC1C2C1C2C4C6C8C6C6BDBBBCB0A9A293816D5B4A2B
202F41505F655E5A859E979A9354907F526287A3BDE0EEEC
EBE9EDEDEDEDEDEDEDEEEEEEEEEEEEEDEAECEEEEEDEDEEEE
EEEEEEEEF6F3
F3F6EEEBEBEEEEEDEAECEEEEECE9E9E9E8EAF3C55480695D
5F585545294B8AB9C1B7C7D3D5D3D3D2D0CBC8C5C3C3BCAD
ACB5BDC1C5C7C0C2CBCFD1C9B5AAA0A4A5A4A8B3BFC2BEBB
B7B1B1AEAFABADB2B6C0C1C0BFBFBCB1A99D918072655240
1C2334485C5F69587C9F95868451988C525E91A7C6E4EDEC
ECECEDEDEDEEEBEAEEEEEEEEEEEEEEEDEDEDEEEEECEAEEEE
EEEEEEEEF6F3
F3F6EEEDEDEEEEEEEDEDEBEBECE8EBEBEBEBF5D061725D56
575650283E4997BEA2B0CBD5D4D2D2D0CCC5B7A2949CABA1
95A6AFBBC9C6C1C1CBD0D1CCBCAB9D9A9BA6B1B1C0B7B0AA
A2998E909B9E9EA2ADBEC0B8B5B6B4B0A89F9185725E5348
342D2E3F5557635B77908A80795A9E864A61969FC5EAF1EC
EDEDEDEDEDEDEDECEDEEEEEEEEEEEEEEEEEEEEEEEDECEEEE
EEEEEEEEF6F3
F0F6EEEEEEEDEBEDEBECECECECEBEDEDEDEEDEA8706C504C
4D504E274E7FB0B198ADCCD1D2D3D0C7B79990979B897278
80979A9AAFC5C3C0CBD1D1CDC0B09D9C97A09B7188909CB0
A47462788483838898B1B6B3B1B2B0ACA99D918271635649
4C37273A53535D64798D897C765A9F8655749FA3CEEBEFED
EDEDEDEDEDEDEEEEEEEEEEEEEEEEEDEBEDEEEEEEEEEEEEEE
EEEEEEEEF6F3
F1F6EEEEEEEDEBEDEBECEDEDECEAECECECF1C68185705743
4151522E379FC4ADA5B1CCD2D1CEC6B3948494B5A46F4F56
6E838F8C9AB9B6BDCBD1CFC9C0B3A29A8E8D8B685692BBAF
85605C776C797F737B97AAAEB0B2AEA8A69E8F7D72685548
4525183657554F637D8C827375619D7C628EA6AADBEDEDED
EDEDEDEDEDEEEEEEEEEEEEECECEEEDEBEBEDEEEEEEEEEEEE
EEEEEDEDF6F3
F3F6EEEEEEEEEEEDEDECECEDECE9ECECECF4D9A08B655738
3855523A329EC2AAA9B4CAD2CEC3B398736698C2966C6332
5E6175878FA2ACBFCDD1CDC7C0B5AB95857C828C6892CA96
6972456F5B827D5161809AA0A8AEACA69D9D8F7F7161524A
2D12102A4A5545637A807A72766B9A6E6298A4B2E4F0EDED
EDEDEEEEEEEEEEEEEEEEEEEBECEEEEEDEBEDEEEEEEEEEEEE
EDEDEDEDF6F3
F3F6EEEEEEEEEDEDEDEAEBEDECECECECECE5E4CD7B564937
3D51505461ABB99FA0B3C5CCC6B69E7F56366C8E716D6C18
564955758698B5C5CDD0CEC8C1B9B49C8C7C7280866E9973
5D6C124C4F715A305378888E9BA5A7A394918C7C685A554C
2A171B24334B486873727477796D99726490A3C7E9EFEEEE
EEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEDEDEDEE
EDEDEDEDF6F3
F3F6EEEEEDEDEDEDEDEDECECECECECECEFB99BB2836B5346
4A50505B7BABAB9CA4B3C7CCBFAE9B7547555740241F3048
5B5C6A829AB0BBC8CBCFCFC8C1BCB6AA998C81716B7A8459
2A262F2E3D3B445059798385909CA19E9488816C5B5C594A
3C25283637384562747167697B779D7E6F8EA9DEEEEFEEEE
EEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEECEAEDEE
EDEDEDEDF6F3
F3F6EEEEEBEAEDEDEDEAEAECECECECECF0AD7B9B8F614852
584C465180A6A89EA4B3C8C8C3BDB29D806B5B483E3D414D
637A91A5B5C0C2C9CFD1CFC8C2C2C1B7A99F95897D646C74
6C60523D373A5374848789919AA09C95968D7B665B595451
452E2D342F2F40657A7769687D88A3837491B1E5F0EFEEEE
EEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEDEDEDEE
EDEDEDEDF6F3
F3F6EEEEEDECEDEDEDEBEBECECEBE8EAEDD7AA85704E4048
4C41406385999F9A9CAFC6CCCBCDCBC0B6ACA0979293979B
9F999EAAB6C5CDCBCED0D0CEC9C7C4BAA89F9B939B929391
8B88817C7E858F9CA6A6A5A3A5A49D948E8D81695D5D5040
3D2D2C3A403B3A60827D676B8692A88778A3D4F2F1EFEFEE
EEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEED
EDEDEDECF2F3
F3F6EBECEEECEAEDEDEDECECEBE8E9EAEFF8BB59593A3639
4948365D798F9A9494AECAC8CCD3D4D0CECFCCCCBEA89B94
8A7F99B4BFCDD1CFD3D2D1D1CECBCCC0AF9D8778848A92A4
B0B1B3B3B3B5B4B2B5B6B2ABA29692968C857E6F625B5248
34282734392E3E597777666D8D96B2907FB0E5F3F0EFEFEF
EFEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEED
EDEDEDECF3F3
F3F6ECECEEECEAEDEDECECECEAE9EBEAECFAB0394B2F3039
4D4F3D5A6E84928F91AACAC4C6CED3D5D4D5D3BB9E836E6B
7C8CADC4CAD3D4D2D7D4D1D2D1CFD0C9C0AD8D6F5F5B6787
ABBFC3C9C6C4BFBBBBB6AFA38F878E91897C736E65544548
2D2626252C384D5D7075676A8E92B09C8AB4EBEFEFEFEFEF
EFEFEFEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEED
EDEDEDEDF6F3
F3F6EEEDEDEDEDEDECECECEBEAE9EAEDD5E9B83B4035373B
464D4C6168707F898EA4C7CAB6B1BDC5C1BCAE877781878F
AEC7D0D0D1D5D8D5D5D3D1D1D2D2CFCECBC4B59A796A6767
778F9AA4ACB2AFAAA89C9890848A958E88796D6B6355452E
2D33322728455968767767688D949F9293C2F1F0EFEFEFEF
EFEFEFEFEFEEEEEEEEEEEEEEEEEDEDEEEEEEEEEEEEEEEEEE
EDEDEDEDF6F3
F3F6EDEDEDEDEDEDECECECEBE9E5EAF1BBBFAA443E464737
3D4C4A595D5D6D7E8BA6C7D2AF9FA5A29A8F7E7E95B8D1D3
D3D7D9D8D8D9D9D9D3D0D1D3D3D5D3D0CFCFCFCABCB09F8C
79747F73757E82817E7C7E85909697958D7A6E6D60575827
3941382B1F27596D7270686F91A08B759CDDF1F0F0EFEFEF
EFEFEFEFEFEFEEEEEEEEEEEEEEECEBEEEDEDEEEEEEEEEEEE
EEEDEDEDF6F3
F3F6EEEDEDEDEDEDECECECEBE9E6E9EBBC845B3F44585448
454548525A5F6A7487ADC7D0CFCCBCA59A95A8C5D6D9D9D9
D8D8D9D9D9D9D9DAD4D0D5DADADAD5D3D3D3D3CECAC8C8C8
C7C7C2A18277797A80949B97969C9E978C7A7275684A3B44
3A311F1112255E72646C7575979F7A7BB6EBF1F0F0F0F0EF
EFEFEFEFEFEFEFEEEEEEEEEEEEEEEEEDEAECEEEEEEEEEEEE
EEEEEDEDF6F3
F3F6EEEEEBEAEDEDECE9E9EBEAE9EAEACC8A5546456A6757
4F4A49585B5F6D7583AAC9CDD0D1CFCECBC9CFD5DBDDDAD9
D9D9D9D9D9DAD9D9D3D5DADBDAD4D3D3D3D3D4D3CDCED2D1
CFD0CDBFB9B8B2AAA7ABA9A2A3A0958D82787878715C423B
281912100F297D725C7D8C7089A77E83C6F4F1F1F0F0F0F0
EFEFEFEFEFEFEFEFEEEEEEEEEEEEEEEEEDEDEEEEEEEEEEEE
EEEEEEEEF6F3
F3F7EBECEDECEDEDE9E9EBEBEBEBEAEBCA7D484751797058
51535158595B6E767FA9C7CFD0D0D4D9D9D7DBDBD7D5D7DA
DAD9D6D6DADAD9DAD4D3D7D9D4D2D7D5D3D4D5D5D4CED0CF
CBCBC8C3CAC5BEB9B1ABA9A4A49D9392887876786D615E3F
261E1A1E202E8A82627C907179A98091D7F9F1F1F1F0F0F0
EFEFEFEFEFEFEFEFEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEE
EEEEEEEEF6F3
F3F6ECECEDEDEDEDEAEBECEBEBEBEBEBCE7C47555B74695C
5B5A5654535465717A9DC2CED0D0D1D4D6D6D7DCDAD5D5DA
DADAD8D8DAD9DADAD8D6D8DAD7D8D7D4D4D3D2D2D3D0D1CE
CAC9C8C6C5BFBAB6B0ACA9A6A39F9B96857779786D625438
302E20191A2D8E896B8193726C9B79A9ECF6F1F1F1F0F0F0
F0EFEFEFEFEFEFEFEFEEEEEEEEEEEEEEEEEEEEEEEEEEEEEE
EEEEEEEEF6F3
F3F6EEEDEDECEBECEDECECECEBEBEBEBE0935057565C5C60
5E585551535163747C97BCC7CDD0CFD1D6D6D4D6DADAD8DB
DADAD8D7D8DADADADADBD9D7D8D8D3D3D1CFCFD0D0D0CFCC
C9C7C4C6C1C0BDB6B1B1ABA9A19C9B91857C7B756A5A4230
3B301B1012318091819098766B7D83C8F7F2F1F1F1F0F0F0
F0EFEFEFEFEFEFEFEFEEEEEEEEEEEDECEEEEEEEEEEEEEEEE
EEEEEEEEF6F3
F3F6EDEDEDECEAECEDECECECECEBEBEBF1A24F514C4F5A60
5B5456535555697D889BB7C0CAD0D1D4D7D6D5D5D9DBD9D9
DBDBD6D3D7DAD8DADBDBD7D2D2D3D3D4D0CFD1D0D0CECAC8
CAC6BDBEBEBEBDB7B2B1ABA99F98948C8B837B72624F423A
3926181416326D9B9091988273639FDFF5F2F1F1F1F0F0F0
F0F0EFEFEFEFEFEFEFEFEEEEEEEEEDEBEEEEEEEEEEEEEEEE
EEEEEEEEF6F3
F3F6EDEDEDEDEDEDECECECECECECECEBF7A550594E5B6264
615B5556565E697C8E99AFBECACFD2D6D5D6D6D9DCDAD5D4
D9DBD7D6D9D8D4D8D9DAD6D2D3D3D4D5D4D5D4D0D0CECBC9
C9C7BFBBBBBBBBB8B3B0AAA8A39C948B86867E7267523D45
281C1A1515306B8F81869891866EB6EBF4F2F1F1F1F0F0F0
F0F0EFEFEFEFEFEFEFEFEEEEEEEEEEEEEEEEEEEEEEEEEEEE
EEEEEEEEF6F3
F3F6EDEDEDEDEDEDECECECECECECECECF6B65E4C5662665B
595A51556463697A8A98A9BCC7CED1D1D1D6D6D6D9DCD9D3
D4D9DBD7D3D5D9D5D3D3D3D4D3D4D5D5D2D2D4D0D0CACECD
C8C8C7C1BFC0BDB6B1B0AAA89D96948B8685746C6656463A
25170E061B5264787A8C9D9DA999D8F6F2F2F1F1F1F0F0F0
F0F0EFEFEFEFEFEFEFEFEEEEEEEEEEEEEEEEEEEEEEEEEEEE
EEEEEEEEF6F3
F3F6EDEDEDEDEDEDECECECECECECECECF8A5566E6D5B5C5C
5957575F4C586E818B91A7BBC6CCCFD1D5D6D6D9DCD9D6DA
DADBD8D7D7D4D4D9D5D2D2D3D4D4D4D5D4D4D6D3CACACDCC
C9C6C0C6BFBBB7B2B1B0AAA89B98998B86786D63544E4E32
1A0C15121E606B6E6A819A99A6CBECF5F2F2F1F1F1F0F0F0
F0F0EFEFEFEFEFEFEFEFEEEEEEEEEEEEEEEEEEEEEEEEEEEE
EEEEEEEEF6F3
F3F6EBECECEAEDEDECECECECECECECECF0CD93725D535253
52535757545B6E828F99A8BBC6CCD1D6D6D5D5DADDD9D6DC
D8DAD7D4D5D5D8D7D4D3D3D4D5D4D4D4D5D6D4CECDCFCCC9
C9C5BDC7BEB9B5B0B0B0AEA99F9E9A877E726F6A5D4E402F
170F1C1A27686E70687D999AAAE5F4F2F2F1F1F1F1F0F0F0
F0F0EFEFEFEFEFEFEFEFEFEEEEEEEEEEEEEEEEEEEEEEEEEE
EEEEEEEEF6F3
F3F6ECECECEBEDEDEDECECECECECECECEBF2BD5C4E4E484A
4D4B4D526064748591A1ABBBC6CDD0D2D6D5D6D8D9D7D5D7
D8DBDAD8D6D4D7D8D5D3D4D5D5D5D5D5D5D3CFCDD0D1CBCA
CCC7C3C7C1BBB5B1AFACB0AAA5A0938580786C6658413025
1A1017172E736D6C657EA1ABBFEDF5F2F2F1F1F1F0F0F0F0
F0F0EFEFEFEFEFEFEFEFEFEEEEEEEEEEEEEEEEEEEEEEEEEE
EEEEEEEEF6F3
F3F6EDEDEDEDEDEDEDECECECECECECECEBF5C96D534D484A
4D4B49505965778590A1AFBCC6CED0D0D6D5D5D8D7D6D8D7
DCDCDCDBD8D6D4D7D8D5D4D4D4D5D5D5D6D1CED2D0CFCBCC
CCC8C8C8C1BBB5B0AFABACA9A49C9187827C6D614B332B1C
1E111216337C79666481A5C0DDF0F1F1F1F1F1F1F0F0F0F0
F0F0EFEFEFEFEFEFEFEFEFEEEEEEEEEEEEEEEEEEEEEEEEEE
EEEEEEEEF6F3
F3F4ECEDEDEDEDEDEDECECECECECECECECEEE0A85A47494B
4C4E504E4F61758492A1B1BFC7CCCFD1D5D5D5D9D8D6DBDC
DBDCDBD6D6D9D4D3D8D6D4D5D4D5D5D5D6D3D1D4D0CDCDCA
C8C8C8C6BDBBB8B2B0AFA8A69F9793897A77716348322B1E
1F1A1C1B347B896A6F8BA7CDF2F3EFF0F1F1F1F0F0F0F0F0
F0EFEFEFEFEFEFEFEFEFEFEEEEEEEEEEEEEEEEEEEEEEEEEE
EEEEEEEEF6F3
F2F1EBEDEDEDEDEDEDEDECECECECECECECECEFC95F424047
4B4C50534F5F778A9AA9B3C3C9CACCD0D2D6D7D6D6D6D8DC
D6DAD7D4D5D4D3D4D4D3D4D5D5D5D4D5D5D3D0CFCDCFCDC9
C8C9C8C0BFBEBBB5B0AFA9A3A1968B887971655844312D22
1C232719286F84727D99B6D7F1F2F1F1F1F1F0F0F0F0F0F0
F0EFEFEFEFEFEFEFEFEFEFEEEEEEEEEEEEEEEEEEEEEEEEEE
EEEEEEEEF6F3
F3F5EDEDEDEDEDEDEDEDEDECECECECECECEBF1D2745E4D4E
534F4D5356636D809CAFBEC0C6CDD1D2D6D7D7D6D4D7DDDC
D5D5D5D4D4D3D3D3D4D5D4D4D5D5D5D5D3D0D0CFCDCDCAC8
C7C8C7C0BEBBB6B2AFAFAAA99F918A83766C5F4F3E333126
1D231E0B226B746D7F9DC4E9F1F1F1F1F0F0F0F0F0F0F0F0
EFEFEFEFEFEFEFEFEFEFEEEEEEEEEEEEEEEEEEEEEEEEEEEE
EEEEEEEEF6F3
F3F6EDEDEDEDEDEDEDEDEDECECECECECECECECE8D4A37462
61625F545462748494A8BBC5C8CACED1D1D2D5D5D5D6D7D7
D6D4D8D8D4D4D5D5D5D5D3D2D4D1D1D1D0D2D2CDCFCAC7C7
C8C5BFBFBFBAB4B3B3A9A7A9988C867C78665748423D2E2C
1E180D0F407E7372889FC5F0EDF0F0F0F0F0F0F0F0F0F0EF
EFEFEFEFEFEFEFEFEFEFEEEEEEEEEEEEEEEEEEEEEEEEEEEE
EEEEEEEEF6F3
F2F2ECEDEDEDEDEDEDEDEDEDECE9ECECECECEBEFF8E3C487
65655D5C5A60708595A1B4C6CAC9CCD1D0D5D7D4D4D5D5D6
D6D5D7D7D5D5D4D5D5D5D4D4D4CFCFCFD2D4D0C9CBC8C8C8
C8C6BEBBBBBAB7B5AFA2A69D938F8674665855483D382F26
231400236E7D6A7588A6D3F1EFF0F0F0F0F0F0F0F0F0EFEF
EFEFEFEFEFEFEFEFEFEFEEEEEEEEEEEEEEEEEEEEEEEEEEEE
EEEEEEEEF6F3
F2F3ECEDEDEDEDEDEDEDEDEDECEAECEDECECECEDF0F4F3AE
6B5B58555F5F6C8395A2B1C1C4C6CBCFD2D3D2D1D2D4D6D6
D6D4D4D5D6D4D2D5D2D1D2D2D2D0D0CECECECAC8C8C8C8C8
C8C6BEB9B9B9B7B3ADA4A39F958A7D6C5D5557533E2D2F23
1C09245F7B6F627A95BCE3F0EEEDEFF0F0F0F0F0F0EFEFEF
EFEFEFEFEFEFEFEFEFEFEEEEEEEEEEEEEEEEEEEEEEEEEEEE
EEEEEEEEF6F3
F3F6EDEDEDEDEDEDEDEDEDEDEDEDEDEDEDEDEDEDECEDF6CF
77485C5E5D65738292A3B2BEC1C5C9CACFCFCFD2D2D2D5D6
D5D2D4D6D6D5D2D3CFD0D1CECDD0CDCDCAC7C7C8C8C8C8C8
C7C3BDB9B9B8B3AFABA19FA29481756B655B52524F3A231B
12194F7B74676784A9D1EBEEEBEFF0F0F0F0F0EFEFEFEFEF
EFEFEFEFEFEFEFEFEFEEEEEEEEEEEEEEEEEEEEEEEEEEEEEE
EEEEEEEEF6F3
F3F6EDEDEDEDEDEDEDEDEDEDEDEDEDEDEDEDEDEDEDEDF5DE
84425C705C707C8293A2B2BBC3C8C9C8CBD0D0D5D4D0D1D5
D1D4D5D4D4D5D6D0CED1D1CCC8CBC8CCCAC7C8C8C8C9C8C8
C4BEBFB9B7B3B1AFA5949B96887C736B65594C49574E2118
1C405565756F7991AED4F0F0EDF5F2EFEFEFEFEFEFEFEFEF
EFEFEFEFEFEFEFEFEFEEEEEEEEEEEEEEEEEEEEEEEEEEEEEE
EEEEEEEEF6F3
F3F6EDEDEDEDEDEDEDEDEDEDEDEDEDEDEDEDEDEDEDEEF6CF
916551535D727A8193A3B0B3BCC6C9C8C9CCCAD2D3CFD0D0
D0D0D1D1D0D1D4CCCAC9C7C7C4BBC4C7C7C7C6C6C7C7C7C7
C1B8B8B9B2AFAFACA19492897B736C605655515042373F31
42445F7574858BA5B7D7F4F5EFEFEFF0F0EFEFEFEFEFEFEF
EFEFEFEFEFEFEFEFEEEEEEEEEFEFEEEEEEEEEEEEEEEEEEEE
EEEEEEEEF6F3
F3F6EDEDEDEDEDEDEDEDEDEDEDEDEDEDEDEDEDEEEEEEF7C6
9E7B4451575D6A7C8C98A1B2BABFC5C6C0CBCDCFD0CDCACA
CCD0D0D3D1CBCEC9C7C7C2BBB9B8BAC3C7C5C0BEC1BEBBBC
B7B2B4B2ABA9A69E95938C867B7573634D4C49473F3A3B2F
696C696D779B95B0DAEEF0EFEBEEEFF4F3EFEFEFEFEFEFEF
EFEFEFEFEFEFEFEFEEEEEEEEF2F3EEEEEEEEEEEEEEEEEEEE
EEEEEEEEF6F3
F3F6EDEDEDEDEDEDEDEDEDEDEDEDEDEDEEEEEEEEEEEEF1DA
C98E3146635A637A8692A6B2B5B9BEBFBEC9CBC9C9CCCCC9
C9CACBCCCAC8C9C8C4BFB8B3B3B4B7BCBBB7B6B5B6B0B0B5
B1ABB0ABA8A3A09C918986867E766C5B54504A5457474255
7C7770798BA6B2B7DBF1EFEEEEF5F1F0F1EFEFEFEFEFEFEF
EFEFEFEFEFECECEFEEEEEEEEF0F0EEEEEEEEEEEEEEEEEEEE
EEEEEEEEF6F3
F3F6EDEDEDEDEDEDEDEDEDEDEDEDEEEEEEEEEEEEEEEFEFEE
D391554D5E63656F7A869FADB9BAB7B9BCBFC8C9C9CBCBC7
C4C3C4C4C1BDBAB9B7B4AFABAAA8A9ABA8A7AAA8A8A5A1A2
A19FA29F989396978D8581776D6C6B5F545D5E56565C5D68
746E77848FADBED0E6EFEFEFF0F2F0EFEFEFEFEFEFEFEFEF
EFEFEFEFEFEDEDEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEE
EEEEEEEEF6F3
F3F6EEEEEEEEEDEDEDEDEDEDEEEEEEEEEEEEEEEEEFEFEFF2
E0B5865E5662676D7A838B9AA9B1B4B8BDC1C7C7C5C6C6C3
BAB9B6B6BBB9ACABACADA69F9F9699979D9C969B92968E89
8E928F8F8A8888898E8E827A707070615969735C474E6071
77727D8D9CB2B9E2F2F0EFEFEFEFEFEDEDEFEFEFEFEFEFEF
EFEFEFEEEEEFEFEEEFEEEEEEF1F1EEEEEEEEEEEEEEEEEEEE
EEEEEEEEF6F3
F3F6EEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEFEFEFEFF0
F4E6BC956F65646C7E81748695A9BBC0C5C9C6C2BFBDBBB7
B0AFABAAB2B5A9A8A3A19A929389908C8E8B878F7A7E827C
7F887E7F81827D7A81867D817C78726466646C6551495E79
7E818EA2ADADC8E9F2F0EEEEEFEFEFEDEDEFEFEFEFEFEFEF
EFEEEEEEEEEEEEEEEDEEEEEEF2F2EEEEEEEEEEEEEEEEEEEE
EEEEEEEEF6F3
F3F6EEEEEEEEEEEEEDEDEDEDEEEEEEEEEEEEEEEFEFEFF0F0
F0F2F4E3957566667A7E748F9EB0C0C3C4C6C2BFBAB4AFA9
ACA8A6A8A8A6A4A599938E8A88828B887F808783786F7B7C
7D827677797A7E73626B7378747072736E5A576167686F77
7E91A8B5ADACEAF3F0F0EFEDEFEFEFEFEFEFEFEFEFEFEEEE
EEEEEEEEEEEEEFEDEBEEEEEEEEEEEEEEEEEEEEEEEEEEEEEE
EEEEEEEEF6F3
F3F6EEEEEEEEEEEEEAECEBEBEEEEEEEEEEEEEFEFEFEFF0F0
F0F1F5EE9E7D7B787A8DA4A9A0A9B0ACB5BCBCB6B3AFA9A9
A99A99A3A49B969B978F888580738B83888F827E8A7F6F82
8B7C847C7A7E8578606A76776C6972746267636565657284
A4B0ADA8B1D0EDF1EFEFF2F5EFEFEFEFEFEFEFEEEEEEEEEE
EEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEE
EEEEEEEEF6F3
F3F7EBECEEEEEEEEEDEDEDEDEEEEEEEEEEEFEFEFEFEFF0F0
F0F0F1F1EC93777F74768C959398A7B2B5B3B0ACAEAAA0A1
A092939493948D948C8F897874796C79808585757E7C788A
85687474807F746C655B5B524F5A60565457575C687990A4
BEAAA59AA1ECF1EFEFEFF0F0EFEFEFEFEEEEEEEEEEEEEEEE
EEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEE
EEEEEEEEF6F3
F3F6EDEDEEEEEEEEEEEEEEEEEEEEEEEEEEEFEFEFEFEFF0F0
F0F0F0F2F7E1AB83787D969C9EA8B2B6B7B5A6A1A3A29D99
9D96958F878C928B7F81766C7D7F64576C736D807B7B7D74
696E73525464645D5B585D595D615F574F595E7F9190AAB7
888D9197C5F6F1EFEFEFEFEEEFEFECEDEFEEEEEEEEEEEEEE
EEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEE
EEEEEEEEF6F3
F3F6EEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEFEFEFEFEFF0F0
F0F0F1F1F1FDC78E7B7185858DA3B4B6B5B7A79C99989596
99948E8988898685827273827A6F7D615B696D716D706B5F
595C5649475A5C52565E5E5A58585F6A6E748194A6B2B299
6F87859FEAF3EFEEEFEDEDEFEEECECEDEEEEEEEEEEEEEEEE
EEEEEEEEEEEEEDECEEEEF2F0EEEEEEEEEEEEEEEEEEEEEEEE
EEEEEEEEF6F3
F3F6EEEEEEEEEEEEEEEEEEEEEEEEEEEEEFEFEFEFEFEFF0F0
F0F0F1F1F2F3E1A0657087777990A6B3B3B0A8938C8C8C97
978F81818A877C878677767C71677B7660616D615D635C55
534D46514E5051505559534F4F5968737E7C929F9F9F957D
89909AC4EFECEEEFEDECEDEEECEBEEF1F0EEEEEEEEF1F0EE
EEEEEEEEEEEEEDECEEEEF2F0EEEEEEEEEEEEEEEEEEEEEEEE
EEEEEEEEF6F3
F3F6EEEEEEEEEEEEEEEEEEEEEEEEEEEEEFEFEFEFEFEFF0F0
F0F0F1F1F1F1FDC9797783878A919BA9B3ADA98A8186838F
9288787C888279867D806F5E736E636A5F5D675C565B5A53
4E4D4D48403C434B4C4F545055697D807E8A9EAC97727287
8F9CCCEFECEAEEEFECECEFEDEBEEEEF2F2EEEEEEEEF2F1ED
EEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEE
EEEEEEEEF6F3
F3F6EEEEEEEEEEEEEEEEEEEEEEEEEEEEEFEFEFEFEFEFF0F0
F0F0F1F1F1F2F1F7DB8352799197959BB6B7AE8B7F867F7E
88857A7A83807376747A6C63786F6B59455569525C5A5550
494641342E343936394A605D5F6E869797B1AA998C7A6F8E
73B9F2F6F2EAEDEEEDEEEFEFEEEEEEEEEEEEEEEEEEEEEEEE
EDEDEDEDEEEEEEEEEEEEEEEEEFEFEEEEEEEEEEEEEEEEEEEE
EEEEEEEEF6F3
F3F6EEEEEEEEEEEEEEEEEEEEEEEEEEEEEFEFEFEFEFEFEFF0
F0F0F0F1F1F1EFF0F9E5804B607C889AB4BBB08C6F7A8E7F
8B938D7974827A67747E70677479726B47384C5B755C5243
414C3E362D2D2D292F44557289898697AC956B677A81796C
95D6F1EEEEEDEEEEEBEBF1F4EEEEEEEEEEEEEEEEEEEEEEEE
ECEAEDEEEEEEEEEEEEEEEEEEF2F3EEEEEEEEEEEEEEEEEEEE
EEEEEEEEF6F3
F3F6EEEEEEEDEAEEEEEEEEEEEEEEEEEEEFEFEFEFEFEFEFF0
F0F0F0F0F1F1F1F1F7F3C06A535C7290A2ADB5947171848A
7A797F76696D77706D6E74776F697675655C564C515C564D
4F534D5B4C44484F5B676E8091A8A9929B7F505673828886
CFEDEEEDEDEEEDF3F0EAECEFEEEEEEEDF1F3EEEEEEEEEEEE
EDECEDF3F0EDEEEEEEEEEEEEEFEFEEEEEEEEEEEEEEEEEEEE
EEEEEEEEF6F3
F3F6EEEEEEEDECEEEEEEEEEEEEEEEEEEEFEFEFEFEFEFEFEF
F0F0F0F0F1F1F1F1F2F2E8AD7664686B748D97A585637281
807471695C5C6269666872736763787F77706353665B515B
655F596160646C7B8880879E9FA09E8B88625B6F7D7886D3
EEF4F3F1ECEBF3EEF1F0EBEAEEF3EFEDEFF0EEEEEEEEEEED
EDEDEEF0EFEDEEEDEFF3EFEEEEEEEEEEEEEEEEEEEEEEEEEE
EEEEEEEEF6F3
F3F6EEEEEEEEEEEEEEEEEEEEEEEEEEEEEFEFEFEFEFEFEFEF
F0F0F0F0F0F0F4F4F1F2F3E2A97868666A7D85A09C786571
8481716E6854585E686D726B5F72788581797A7670595060
6C6B706E757C8999A096848D8C7C695D6363727B7C90C4F3
F1EFF4F5F0ECF1F0F1F0EDEBEEF1EEEDEDEDEEEEEEEDEDED
EDEDEDEDEDEEEEEDEEF2EFEDEEEEEEEEEEEEEEEEEDEDEDED
EDEDEDEDF6F3
F3F6EEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEFEFEFEFEFEFEF
EFF0F0F0F0F0F2F2F1F0EFF3D8A5766573838D97A59C7B6B
7F7A747A766460575F6167665E7C76888A90A9A88A777880
8386929DA29CA1A59386756D695C4B49607E7E708BCDF7EE
F0EEF0F3F1EDEDF2EFECECEDEEF0F1EFEDEEEDEDEDEDEDED
EDEDEDEDEDEDEDEEEEEDEEEEEEEEEDEDEDEDEDEDEDEDEDED
EDEDEDEDF6F3
F3F6EEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEFEFEFEFEFEFEF
EFEFF0F0F0F0EEEEF0EFEDF1F5DEAA7A717E838EA1AFA580
80717A7E787C776D604E535C58717B91959FBBC4BAA9B1B7
B4B1ADB8B7ABA49575636D605150586985847A84C0F7EDEC
F2F0ECEBECEDEDEDECEAEBEDEEF2F4F0ECECEDEDEEEDEDED
EDEDEDEDEDEDEDEDEDEDEDEDEDEDEDEDEDEDEDEDEDEDEDED
EDEDEDEDF6F3
F3F6EEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEFEFEFEFEFEF
EFEFEFEFF0F0F0F0F0EFF0F7F3F0F2D48A6F5A739CB2B4AD
8C8D8D8C8C8C9DA8937372796E839BAAA99A9EBEBFBDC1C9
C9BFB1998B8A8474686760514E5F6E77898792CAF2EEECE9
ECEEEBE8E9EDEDEDEAEAEDEDEDEEEEEDEBEAEDEDEDEDEEEE
EDEDEDEDEDEDEDEDEDEDEDEDEDEDEDEDEDEDEDEDEDEDEDED
EDEDEDEDF6F3
F3F6EEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEFEFEFEFEF
EFEFEFEFEFEFF0F0EFEFF0F6F3F0F1F5E3815F718495B2C2
ADA8B5B2B4C7BDADC3D0DCE5DCD4CFCFC4C0C7C5C4C3C9C1
A1909F867573746B5E6052687A7D7B787DD9EDEBF2F2E9EC
EDEDEDEBE9EDEDEDEDEAEAEDEEF4EFEDEBEAEDEDE9ECF2F2
EDEDEDEDEDEDEDEDEDEDEDEDEDEDEDEDEDEDEDEDEDEDEDED
EDEDEDEDF6F3
F3F6EEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEFEFEEF3
F3EFEFEFEFEFEFEFEFEFEFF6F2EFF0F3F2D9C381637E9CAD
BAC4CFCECBCFCBC7D5D8D6DDDDD5DADED9D2D0CCB9A8B6AE
959394716F6760666E75838F8C8080A0D2EFF1EEEDEBECED
EDEDEDEDECECE9ECEDECECEDEDEFEEEDECECEDEDECEDEFEF
EDEDEDEDEDEDEDEDEEF3EFECF1F2ECE9EDEDEDEDEDEDEDED
EDEDEDEDF6F3
F3F6EEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEF1
F1EFEFEFEFEFEFEFF1F4EFF6F6F2F2F4F0F5F4CB8F758193
B5BFC4C8CACED4D6D8D5D8DDD9D5D9E0DCD3CDC5BC9F969A
91817C6A7664627C8A90958B899EBED9F1EEE9EBECEBEEF2
EEF1F0EDECE9EBECEDEDEDEDEDECECEDF0F1EDEDEDEDEDED
EDEEF3EFEDEDEDEFF3F1EEECEEF1F1EBECEDEDEDEDEDEDED
EDEDEDEDF6F3
F3F6EEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEE
EEEFEFEFEFEFEFEFF0F2EFF2F4F1F1F3EEEDF3F7D7B9AC89
8D92ABC1CBD4D8D8D5D1D8DFD6D1CCC7BCB2AFB2B69E877D
76757E768D898C9C978A95ACBDD3EAF0ECEDEBEFF0EDEEF1
EEEEEEECEDEEEDF0EFECEDECEAECF0EFEFF0EDEDEDF0EFEC
EDEEF2EEEDEDEDEEF1EDEDF0F1F3F3EAECEDEDEDEDEDEDF1
EFEDEDEDF6F3
F3F6EEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEF1F0
EEEEEFEFEFEFEFEFEFEEEFEEEFEFEEEFF2EDEEF6F7F7E7B4
A3A7A9ABB9CACACCD2D1D2D6D1CEC8B8AA9F99A19FA0A086
7A97A6999C9CA4B4B6ADBFE5F2EEECEDF0EDEDF0F0EDEDF0
EEEAEBECEEF2EDEFEEECEDECE9ECF1EFEEEFEEF0F0F5F3F0
F0EDEDEDEDEDEFF0EDEDEDF3F6F5F1EDEDEDEDEDEDEDEDF2
EFEDEDEDF6F3
F3F6EEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEDF2F1
EEEEEEEEEFEFEFEFEFEFEFEFEFEFEDEEF5F0EFF4F3EFF0F3
F3F7CCA9AAADAEB8C4CCD0D2D5D7D7CDCBC4B6ADA1B4C7B6
A7B2B4B3A49DAFCEE7F6F5F2EDEBEBEDF2EEECECECEBEEF3
EDECECECECEBECE9EBECECEDEDECEBEBF0F1EEF3F3F3F3F3
F0EEEFECECECF0F2EDEDECF0F4F0EEF2ECECEDEDEDEDEDED
EDEDEDEDF6F3
F3F6EEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEAEDEF
EEEEEEEEEEEEEEEEEFEFEFEFEFEFEFEFEFEFEFEFEFEFF2F7
F1F5F4F4DCAEACBEB3B6C7CED0DCD8DDE4E3DBCFC8CDCAC7
BAA3A0B2C4D7E6ECEEF4F4EAEAEDEDEDECECECECEAE9ECEC
E9EBECECEBE8ECECECEDEDECECEDE9EBEDECEDEDEDEDEDEB
E9EEF4ECEBEEEDEDEDEDE9EBEDECEDECEAECEDEDEDEDEDED
EDEEEEEEF6F3
F3F6EEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEDF3F1
EEEEEEEEEEEEEEEEEEEEEEEEEFEFEFEFEFEFEFECEDEFF2F6
EDECF1F4F1E9E5E7E6E1E0DEDCE9E4D4C7C1C4CCCBC7C4C5
CED9DFE5E9ECEEEDEEF4F4EDEFF3F4F2ECECECECECEAE7E8
EBECECECECECECE9EAF1F0E9ECECECF1F1ECECECECECECEC
ECEDEEF3EFF1F1ECEDECECECECECECEDF3EEECEDEDEDEDED
EDF2F2EDF6F3
F3F6EEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEF0ED
ECEEEEEEEEEEEEEEEEEEEEEEEEF2F1EBEFEFEFEEECECF0F1
EEEEF0F1F3F5F4F3F9F5EFEEEEF1EFE6DFDDDEE3EBE5E3E3
E8EDF0F0F4F5F0ECECEEF3EEEDEEEFEDE8EBF1EFEBEEF0EB
EBECF0F0EEF2EDF0EEEBEBEBECE9EBEEEEECECECECECECEC
EDEDEDECECEEF1F1ECECEDECF0F1ECEDEFEDECEDEDEDEDED
EDEFEFEEF6F3
F3F6EEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEC
EDEEEEEEEEEEEEEEEEEEEEEEEEF1F0EDEEEFEFEDECEEEDEC
F4F2F0F1F0EFF2EFF3F4F5F5EFF1F2F1F0F0F0F1F9F3F0EE
EDEEEEEEF0F1EEEEF0ECF3EEEBECEAEAEFEDF2F4EFEDEFEC
EBECEEEEECEFECF3EEE7E9ECE9EAECECECECECECECECF0F0
ECEDECEBECECF0F3ECECECEAECF1F2F1EDECEDEDEDEDEDED
EDF1F1ECF3F3
F3F6EDEDEDEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEE
F0F1EEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEFEEECEDF1F2F1
F3F1F0EFEEEFF1F3F1F1F3F5F2F1F0F4F2F0F0F0F1EFEFED
ECEEEEEDEBEBEFF1F0EDF3F2EDECEBEAEEECEEEFEDEDEFEB
EBEBEBEDEFEBECEFECE9EAEBEAECECEFEDEAECECECECF2F2
ECEDF1EDECEBEDF0ECECECEAEBEDF1F5EEECECECECEDEDEC
EDF0F0EEF8F3
F3F6EDEDEDEDEDEEEEEEEEEEEEEEEEEEEEEEEEEFF1EEEEEC
F0F2EDECEDEEEEEEEEEEEEEEEEEEEEEEEEEDF0F0EEF0F4F2
EFEFEFEEEDF0F4F5F2F0F0F4F8F0F0F4F4F1EFEDEBEEEDED
EEEEEEEDEBEBF0F0EBECF1F4F0EBEBE9E8EEEDE9E9EDEFEF
EFEDEBEDF0EEECEBECECEDEFECECECF2EFE9ECECEFEDEFF1
EEEDF2F0F0ECEAEDEFECECECEBE9EBF1EDECECECECECEDEF
EEEDEDF0FCF4
F3F6EDEDEDEDEDEDEEEEEEEEEEEEEEEEEEEEEDEFF4EFEEEB
EBEFEEEAEDEEEEEEEEEEEEEEEEEEEEEEEDEAF2F1EEEEEDEB
EEEFEFEFEDEDF6EEEFF2F0F1F6F2EFEFF3F3EEEDEFF0ECEC
EEEEEDEDEEEDECEDEEECECF1EFEBEAE7EBF1EDEBEBE9E9F1
F2EDEBE9EAF1ECEBEBECF0F1EEECECF2F1ECEBEBF1EEEBEF
F1ECECF2F3EFECEEF2ECEBECEAE9ECECECECECECECEBECF4
F0EDEDEEF6F3
F3F6EDEDEDEDEDEDEDEEEEEEEEEEEEEEEEEEEEEEEEEEEEEE
EEF0F4EDEDEDEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEE
EEEEEEEFEDEBEFF0EFF5F2ECF1F7F1EFEFEFF1F5EFF4F1EE
EEEEEEEEEDEAEAF0F3EDECECECECECECEBEBECEBEBEBEBEB
E8EAECECECECECECE8EEEFEAF3EEECF1F1ECEBE8EBECECED
EDEDECECEDECECECECECE8EAEDECECECEDECECECECEBE9F2
EFEDEDEDF6F3
F3F6EDEDEDEDEDEDEDEDEEEEEEEEEEEEEEEEEEEEEDEEEDF2
F2EEEEEEEDEDEDEEEEEEEEEEEEEEEEEDEAEDEEEDEDEEEEEE
EEEEEEEEEDE9EBEEEFF0F0EDEDF7F7F1EEF2F3ECEEEFEFEE
EEF0F4EEEAE8EAEDF0F3EAEAF0EFEEF1EBEAF0EEEEF1EBEB
EAEBEBEFF1EBEBEBEBECEBE8EEF3EEECECEFF2EBEBECF1F0
EEF2EDEBF1EDE9ECECECEBEBF0F1ECEDF2EEECECECECEBED
EDEDEDECF1EF
F3F6EDEDEDEDEDEDEDEDEDEEEEEEEEEEEEEEEEEEEEEEEEEF
EFEFF2EDEDEDEDEDEEEEEEEEEEEEEEEDEDF3EFEDEBEBECEA
EDEDEEEEEDECEDF3F1EEEFEEEEF1F1F0ECF0F4ECEEEEEEEE
EEEFF0EEECEBEDEBEAEFF1EDF1F1ECEDEBE8F0EDEDF2EBEB
ECE9E9EDEEEBEBECECECEBECF1ECE9EAECEDEEE9EBECEEEE
F0F4EDECEEEDEBECECECF1EEEDEEECECEEEDECECECECECEC
ECEAEAEFFAF2
F3F5EDEDEDEDEDEDEDEDEDEEEEEEEEEEEEEEEEEEEEEEEEED
EDEFEFEAECEDEDEDEDEEEEEEEEECEEF2EEF1ECECECEAE9E8
ECEDEDF0F3F1EEF1EFECECEEEEEEEEEBEAEEF2F3EEEBF0F1
EEEEEDEDEDF1F0EEEFECEDF0F1ECE9EAE8E8EDEFEFEEEBE9
EBEAEDEDEAF0ECE8EAE9EBF1F0EFEBEBECEBE8EAECEDEDEC
EEF0EDECECECECECECECEFEEEAEAECECECECECECECEBECEC
ECEBEBEEF9F3
F2F5ECEDEDEDEDEDEDEDEDEDEEEEEEEEEEEEEEEEEEEDEEED
EDEDECEAECEDEDEDEDEEEEEEEEECEEF2EDEDEEEDEFEEE8E8
EFF1EEEDF2F4EDEDEEECECEEEEEEEEEEF0F0EEF2EEEBF3F3
EDEDEEEDEDF0F2F2F1EDE9EFEEEBEDEEECEEECEEEEEBEBE7
EAEFF1EDEAF0F0EDEEEEEEEFECF0EEECECEDEEF0EDEDEDED
ECEBEDEDEDEDECECEDF0EDECEBEAEDEFECECECECEDEFECEF
EDECEEEFF3F2
F1F4ECECEDEDEDEDEDEDEDEDEEEEEEEEEEEEEEEDEEF0EFEF
EFEDECEBECEBECEDEDEEEEEEF0F0EEEDEDEDF2EFEEEFEAE8
F0F1EDE9ECF1EDEDEDEDEDECEDEDEDF1F3F0EDEFEEEDF1F1
EFEFECECEFF0F2F1EDEDEDECECEEF1F0F1F0ECECEDEBEBE9
EBF0EEEAECECF1F1F1F1F0EDECEEEDECEBEDF3F5EEEDEDEF
EFEBEDEDEDEDECECECF1ECEBEBEBEDF1ECEBECEBEEF1ECF1
EEEBEEEFF3F1
F6FBF4F5F5F6F6F6F6F6F6F6F6F6F6F6F6F6F6F6F7FEF9FB
FBF6F4F0F4F2F3F6F6F6F6F6FCFBF6F6F6F6F4F5F2F1F3F0
F3F0F2F6F6F5F5F5F6F6F3F2F6F6F5F4F4F4F9FEF6F5F5F5
FAFBF1F6FDFFFAF5F6F6F5F5F5F4F3F2F2F2F4FAFAF5F5F5
F5F4F1F2F5F5F3F3F3F2F7FCF6FDF8F5F2F1F6FCF7F5F6FA
FDF7F6F6F6F5F5F5F5F4F0F3F2F1F4F4F5F5F4F5F4F3F4F4
F4F4F3F2FAF6
F3F6F1F2F3F3F3F3F3F3F3F3F3F3F3F3F3F3F3F3F4FAF5F3
F7F8F2F2F2F2F2F3F3F3F3F3F4F4F3F3F3F3EFF1F2F2F2F2
F2F1F6F6F4F8F2F2F3F3F3F3F3F3F3F2F2F5FAF9F3F2F3F1
F1F3F3F9FBF6F3F3F3F3F3F3F2F2F2F1F1F1F6F9FAF7F2F2
F2F2F2F2F2F2F2F1F1F1F4FAF9FAF4F2F2F2F2F3F3F3F3F4
F4F3F3F3F3F3F2F4F9F2EEF1F0EFF2F3F8F4F1F6F6EEF2F2
F2F2F2F1F6F3
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[51]:=",
  ImageSize->{400, 190.438},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0000_R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`009@3oool0103Xj>P0h>3P0>3Ph03WinL20>3Ph004
0=oOg`3MgMd0gMgM0>CTi080f][J00<0f=SH0<;2`P34a<@00P34a<@20<S8b0<0a<C400D0aLG50=CD
e03Ph>00h>3P07inOP020;fm_@040;^k^`2j^[X0^[Zj0;Bd]080_Kfm00<0]KFe0;fm_@2l_;`00P2l
_;`20;>c/`040;Bd]02k^k/0^k^k0<30`080`L71102l_;`0102k^k/0]KFe0;Fe]@2i^KT20;bl_003
0;no_`36a/H0a/K600@0a/K600@0aLG50<71`@31`L40`l?30P2l_;`00`30`<00a/K60;fm_@050;fm
_@D0_;bl00<0_Kfm0;^k^`2m_Kd00P2m_Kd20;bl_0050;fm_@2n_[h0_[jn0=OGe`3EeMD00P2<S8`0
102i^KT0]KFe0;Fe]@2j^[X20;:b/P030;>c/`2h^;P0^;Rh00D0^KVi0P33`l<30<30`0030<c<c036
a/H0a/K60080bl_;0P32`/801038b<P0_Kfm0;fm_@2j^[X20:f][@050:n_[`2c/k<0/K6a0;6a/@2c
/k<00P3@d=00102XZ:P0a/K60<K6aP3Jf]X20>?Sh`030>KViP3oool0oooo0280oooo0180k^k^0?7a
l@3alO40m?Cd0?7al@3^k^h0l?3`0>k^kP3]kNd0lo?c0?;blP3[jn/0f=SH0=OGe`3Hf=P0fMWI0=cL
g03MgMd40=WIf@0;0=OGe`3Shn<0m?Cd0=gMg@2RXZ80bl_;0=kNgP3Hf=P0dm?C0=;BdP3?cll00P3D
e=@02P3?cll0e=CD0=CDe03De=@0eMGE0<o?c`3=cLd0dM7A0=CDe03EeMD20=WIf@030=GEe@3De=@0
e=CD0080dm?C00L0e=CD0=GEe@3=cLd0d=3@0=KFeP3De=@0eMGE00H0f][J00@0fm_K0=SHf03Jf]X0
f=SH0P3De=@0103GemL0f][J0=GEe@3Cdm<80=CDe0050=GEe@3De=@0dm?C0=?Cd`3De=@00P3Cdm<2
0=CDe00<0=;BdP3Ng]h0kNg]0?;blP3Fe]H0ZZZZ0<K6aP3?cll0e=CD0=KFeP3Cdm<0c/k>0P3=cLd0
0`3AdM40dm?C0=CDe0020=CDe0090=?Cd`3Hf=P0fMWI0=KFeP3EeMD0fMWI0=oOg`3Kfm/0gMgM0080
gmoO00T0gMgM0=[JfP3Ph>00fm_K0=GEe@3Cdm<0d=3@0<[:bP3;bl/00P3>c/h02`3;bl/0e=CD0>OW
i`3Ph>00`L710<g=c@3Rh^80kNg]0?7al@3gmoL0k^k^02L0oooo000U0?ooo`040=gMg@3?cll0clo?
0<g=c@80c/k>00@0e=CD0=;BdP3Bd]80cLg=0P3Bd]800`3>c/h0a<C40;Jf]P080;Jf]P040;>c/`36
a/H0a/K60:2PX080YJFU00@0/;2`0:f][@2][Jd0Zj^[0P2VYZH01@2YZJT0ZZZZ0:j^[P2^[Zh0[Jf]
0080[Zj^00@0[Jf]0:VYZ@2YZJT0/k>c0`2^[Zh0102][Jd0YJFU0:FUY@2XZ:P20:f][@030:NWY`2/
[:`0[:b/0080[Zj^0`2b/[820:n_[`040;Bd]02_[jl0[jn_0;6a/@80/k>c102a/K400`2b/[80/K6a
0;6a/@070:n_[`040;2`/02^[Zh0[Zj^0:ZZZP80/;2`0`2_[jl01@2`/;00`/;20::RXP2RXZ80SXj>
0080Z:RX00@0[:b/0:FUY@2UYJD0YjNW0P2VYZH01@2UYJD0[Zj^0:b/[02/[:`0[Zj^0080/k>c0`2a
/K450;Bd]080^[Zj00@0/[:b0:j^[P2^[Zh0Zj^[0P2/[:`01@2XZ:P0YZJV0:b/[02/[:`0`/;20080
/K6a00@0YZJV0:RXZ02XZ:P0b<S80P3<c<`00`3Lg=`0oooo0?ooo`0R0?ooo`060?7al@3hn?P0l_;b
0?7al@3`l?00m?Cd0P3jn_X01@3dm?@0l_;b0?Ogm`3clo<0kNg]0080f][J00<0g=cL0=gMg@3Lg=`0
0`3Lg=`30=_Kf`060>OWi`3UiND0]KFe0=WIf@3Shn<0fm_K0P3Fe]H01P3EeMD0dM7A0<o?c`3>c/h0
d];B0=KFeP@0emOG0P3Cdm<00`3Jf]X0g=cL0=OGe`020=KFeP060=OGe`3Cdm<0c<c<0=7Ad@3GemL0
f=SH0P3Cdm<03@3Hf=P0emOG0=KFeP3IfMT0f][J0=OGe`3EeMD0emOG0=kNgP3Hf=P0e]KF0=_Kf`3L
g=`00`3Fe]H20=GEe@040=SHf03IfMT0e]KF0=OGe`80e]KF1@3GemL00`3EeMD0d=3@0=7Ad@020=KF
eP<0eMGE00X0hN7Q0?KfmP3Xj>P0/;2`0:6QX@3AdM40gMgM0=WIf@3Fe]H0d=3@0P3?cll02`3@d=00
e=CD0=WIf@3Jf]X0fMWI0=SHf03Kfm/0fMWI0=SHf03IfMT0e]KF0080fm_K0P3Lg=`01`3Kfm/0gMgM
0>;RhP3Ng]h0gMgM0=OGe`3EeMD00P3Fe]H02P3EeMD0clo?0=7Ad@3Rh^80lo?c0>WYj@3<c<`0bLW9
0<[:bP3Ogml20?;blP030?Gem@3bl_80oooo02H0oooo000U0?ooo`040=gMg@3?cll0clo?0<g=c@80
c/k>00@0e=CD0=;BdP3Bd]80cLg=0P3Bd]800`3>c/h0a<C40;Jf]P080;Jf]P040;>c/`36a/H0a/K6
0:2PX080YJFU00@0/;2`0:f][@2][Jd0Zj^[0P2VYZH01@2YZJT0ZZZZ0:j^[P2^[Zh0[Jf]0080[Zj^
00@0[Jf]0:VYZ@2YZJT0/k>c0`2^[Zh0102][Jd0YJFU0:FUY@2XZ:P20:f][@030:NWY`2/[:`0[:b/
0080[Zj^0`2b/[820:n_[`040;Bd]02_[jl0[jn_0;6a/@80/k>c102a/K400`2b/[80/K6a0;6a/@07
0:n_[`040;2`/02^[Zh0[Zj^0:ZZZP80/;2`0`2_[jl01@2`/;00`/;20::RXP2RXZ80SXj>0080Z:RX
00@0[:b/0:FUY@2UYJD0YjNW0P2VYZH01@2UYJD0[Zj^0:b/[02/[:`0[Zj^0080/k>c0`2a/K450;Bd
]080^[Zj00@0/[:b0:j^[P2^[Zh0Zj^[0P2/[:`01@2XZ:P0YZJV0:b/[02/[:`0`/;20080/K6a00@0
YZJV0:RXZ02XZ:P0b<S80P3<c<`00`3Lg=`0oooo0?ooo`0R0?ooo`060>_[j`3_knl0inOW0>OWi`3X
j>P0jn_[0P3]kNd0203/k>`0j^[Z0>c/k03clo<0l_;b0>SXj03GemL0d];B0`3Cdm<0403Bd]80e=CD
0=CDe03AdM40d=3@0=[JfP3Xj>P0fm_K0:ZZZP33`l<0e]KF0=;BdP3?cll0b/[:0<C4a036a/H20<g=
c@030<o?c`3@d=00d=3@0080dM7A00T0c<c<0<O7a`3;bl/0eMGE0=?Cd`3@d=00clo?0<g=c@38b<P0
0P36a/H06@39bLT0b<S80<C4a034a<@0alO70<_;b`3=cLd0c/k>0=7Ad@3@d=00cLg=0<k>cP3@d=00
clo?0<g=c@3@d=00dM7A0<o?c`3Bd]80dm?C0=CDe03Cdm<0d];B0=?Cd`3De=@00`3?cll50=3@d003
0<k>cP3<c<`0cLg=0080clo?0P3>c/h02@3=cLd0clo?0=SHf03Ogml0g]kN0<c<c02[Zj/0_Kfm0<o?
c`020<[:bP050<k>cP3=cLd0bLW90<c<c03@d=000P3<c<`00`3@d=00eMGE0=CDe0020=CDe00>0=;B
dP3Cdm<0dm?C0=?Cd`3EeMD0f=SH0=[JfP3Kfm/0eMGE0=CDe03Bd]80clo?0=3@d03AdM420=3@d00<
0=OGe`3Ng]h0inOW0>OWi`3@d=00a<C40<71`@3Bd]80i>CT0>_[j`3dm?@0kNg]9`3oool002D0oooo
00@0gmoO0<g=c@3=cLd0dM7A0P3>c/h00`3Bd]80d=3@0=3@d0030=3@d0050<k>cP3?cll0`/;20<;2
`P31`L400P2f][H01@2e]KD0/k>c0;>c/`2c/k<0/[:b0080];Bd00@0c<c<09VIV@2IVIT0[:b/0P2^
[Zh00`2[Zj/0Z:RX0:RXZ0020:b/[080[Jf]0`2_[jl0102^[Zh0YZJV0:JVYP2_[jl20;2`/0050:n_
[`2ZZZX0[Jf]0:f][@2VYZH00P2TY:@0102VYZH0Xj>S0:>SX`2WYjL30:n_[`030;>c/`2a/K40/K6a
00@0/;2`0P2a/K401@2j^[X0]kNg0;Ng]`2g]kL0^;Rh0080]kNg00@0];Bd0;>c/`2c/k<0]KFe102`
/;030;6a/@D0/;2`00D0[Zj^0:^[Z`2k^k/0^k^k0<71`@0209:BTP<0ZJVY00<0[Jf]0:ZZZP2ZZZX0
0P2][Jd20:^[Z`040:f][@2d];@0];Bd0;6a/@80/[:b0`2d];@00`2h^;P0^KVi0;Bd]0020;Bd]080
[Zj^00@0Zj^[0:n_[`2_[jl0[jn_0`2c/k<0102h^;P0][Jf0;Jf]P2ZZZX20:NWY`040<?3``39bLT0
bLW90=kNgR@0oooo00<0kNg]0>o_k`3Xj>P00P3/k>`01@3Zj^X0kno_0>o_k`3[jn/0kNg]0080l?3`
00P0lO7a0?3`l03Ti>@0hN7Q0=cLg03De=@0d=3@0=;BdP80d=3@0P3?cll03P3Cdm<0h>3P0>k^kP31
`L40_[jn0<g=c@3Bd]80clo?0<_;b`36a/H0alO70<_;b`3:b/X0c<c<0P3@d=001`3AdM40d=3@0<_;
b`35aLD0b<S80=7Ad@3Bd]800P3@d=001@3<c<`0bLW90<_;b`35aLD0`/;20080`l?300<0`L710<30
`033`l<00P3=cLd00`3?cll0d=3@0<k>cP030<k>cP80cLg=00<0clo?0=CDe03IfMT0103GemL01`3H
f=P0emOG0=CDe03Bd]80e=CD0=GEe@3Bd]800`3@d=050<o?c`<0c/k>0P3=cLd01P3EeMD0inOW0?3`
l03:b/X0/K6a0;jn_P80clo?0P3AdM403`3>c/h0dM7A0=3@d03=cLd0c/k>0=3@d03EeMD0e=CD0=?C
d`3De=@0d];B0=CDe03EeMD0emOG0=[JfP020=_Kf`0E0=SHf03IfMT0dm?C0=7Ad@3@d=00dM7A0=?C
d`3@d=00g=cL0=_Kf`3Ph>00g]kN0=SHf03Lg=`0bl_;0<;2`P3Cdm<0hn?S0>KViP3alO40k^k^02L0
oooo000U0?ooo`040=oOg`3@d=00d=3@0<o?c`80e=CD00@0d=3@0<o?c`3?cll0dm?C0P3De=@01@3C
dm<0c/k>0=3@d03@d=00b/[:0080a<C400D0][Jf0;Vi^@2i^KT0/[:b0;>c/`020;Fe]@040<[:bP2f
][H0][Jf0:RXZ080[jn_00D0/[:b0:VYZ@2YZJT0ZZZZ0;:b/P020:VYZ@040:j^[P2_[jl0[jn_0;6a
/@80[jn_0`2`/;020:VYZ@80[jn_0`2^[Zh01@2_[jl0Z:RX0:RXZ02TY:@0ZJVY0080/K6a0`2WYjL0
0`2_[jl0/[:b0;:b/P040;:b/P040;Vi^@2`/;00/;2`0;Zj^P80_Kfm00@0/[:b0;Fe]@2e]KD0^;Rh
0P2c/k<01@2b/[80][Jf0;:b/P2b/[80/k>c00<0][Jf0P2`/;001@2c/k<0[Zj^0:f][@2][Jd0^KVi
0080[Zj^00<0W9bL0;2`/02`/;000`2a/K420:f][@80/;2`0`2c/k<40;Bd]080][Jf00D0^KVi0;Ng
]`2f][H0][Jf0;:b/P020;>c/`050:b/[02i^KT0^KVi0<;2`P30`<000P31`L400`34a<@0^KVi0;Vi
^@030:JVYP040<_;b`3=cLd0cLg=0=gMgB@0oooo00@0k^k^0?;blP3Zj^X0kNg]0P3^k^h20?3`l003
0>_[j`3`l?00m?Cd0080l?3`0140k^k^0?3`l03`l?00j^[Z0=gMg@3Bd]80dm?C0=7Ad@3>c/h0clo?
0=3@d03?cll0f=SH0>k^kP3[jn/0aLG50<C4a0020=;BdP030=7Ad@39bLT0alO70080bLW900<0b<S8
0<c<c03@d=000P3@d=001`3>c/h0b/[:0<c<c03?cll0d=3@0<g=c@3<c<`00P3:b/X02`3>c/h0bLW9
0<K6aP39bLT0b/[:0<O7a`31`L40_kno0<W9b@3=cLd0bl_;00<0b<S800H0cLg=0<k>cP3>c/h0c/k>
0<o?c`3Cdm<20=OGe`050=CDe03Cdm<0f=SH0=gMg@3IfMT00P3EeMD0103Fe]H0f=SH0=GEe@3@d=02
0=;BdP030=7Ad@3?cll0d=3@0080d];B00`0dM7A0<o?c`3@d=00d=3@0<k>cP3?cll0e=CD0>OWi`3a
lO40_[jn0;:b/P3>c/h40=CDe0030=?Cd`3Bd]80d];B0080e=CD01h0eMGE0=CDe03De=@0eMGE0=?C
d`3EeMD0e]KF0=_Kf`3MgMd0fm_K0=[JfP3Hf=P0f][J0=GEe@3De=@0dM7A0=?Cd`3Kfm/0h>3P0>SX
j03Rh^80jn_[0>;RhP3@d=00h>3P0<g=c@31`L40e]KF0>WYj@3Xj>P20>g]kBL0oooo000U0?ooo`04
0=oOg`3@d=00d=3@0<o?c`80e=CD00@0d=3@0<o?c`3?cll0dm?C0P3De=@01@3Cdm<0c/k>0=3@d03@
d=00b/[:0080a<C400D0][Jf0;Vi^@2i^KT0/[:b0;>c/`020;Fe]@040<[:bP2f][H0][Jf0:RXZ080
[jn_00D0/[:b0:VYZ@2YZJT0ZZZZ0;:b/P020:VYZ@040:j^[P2_[jl0[jn_0;6a/@80[jn_0`2`/;02
0:VYZ@80[jn_0`2^[Zh01@2_[jl0Z:RX0:RXZ02TY:@0ZJVY0080/K6a0`2WYjL00`2_[jl0/[:b0;:b
/P040;:b/P040;Vi^@2`/;00/;2`0;Zj^P80_Kfm00@0/[:b0;Fe]@2e]KD0^;Rh0P2c/k<01@2b/[80
][Jf0;:b/P2b/[80/k>c00<0][Jf0P2`/;001@2c/k<0[Zj^0:f][@2][Jd0^KVi0080[Zj^00<0W9bL
0;2`/02`/;000`2a/K420:f][@80/;2`0`2c/k<40;Bd]080][Jf00D0^KVi0;Ng]`2f][H0][Jf0;:b
/P020;>c/`050:b/[02i^KT0^KVi0<;2`P30`<000P31`L400`34a<@0^KVi0;Vi^@030:JVYP040<_;
b`3=cLd0cLg=0=gMgB@0oooo00L0k^k^0?Cdm03Zj^X0j^[Z0>k^kP3_knl0k>c/0080kNg]00d0kno_
0?7al@3clo<0lO7a0?3`l03emOD0l_;b0?7al@3]kNd0gmoO0=KFeP3EeMD0dM7A00<0d];B01H0f][J
0>OWi`3_knl0e=CD0<c<c03Cdm<0e]KF0=GEe@3;bl/0bLW90<_;b`3<c<`0bLW90<[:bP3?cll0d=3@
0<k>cP3=cLd0c/k>0=3@d03=cLd0bl_;0P38b<P00`37alL0b/[:0<k>cP020<k>cP80clo?00H0c<c<
0<S8b033`l<0`l?30<O7a`36a/H20<71`@030<G5a@3;bl/0c/k>00<0clo?00h0c/k>0<o?c`3De=@0
dM7A0<o?c`3Fe]H0fm_K0=OGe`3Bd]80e]KF0=CDe03EeMD0e]KF0=;BdP80e]KF00L0dm?C0=7Ad@3B
d]80e=CD0=GEe@3De=@0d=3@0080d];B00H0d=3@0=7Ad@3@d=00e=CD0>WYj@3IfMT20<;2`P040<g=
c@3Fe]H0emOG0=SHf080d];B00<0e=CD0=OGe`3Hf=P00P3GemL20=SHf080e]KF00<0emOG0=[JfP3L
g=`00`3Lg=`0503GemL0e]KF0=GEe@3@d=00dM7A0>;RhP3alO40inOW0>KViP3Xj>P0h>3P0=[JfP3U
iND0b/[:0<C4a03Jf]X0k^k^0?3`l03bl_80kNg]9`3oool002D0oooo00@0gmoO0=3@d03@d=00clo?
0P3=cLd0103@d=00dm?C0=?Cd`3>c/h20=3@d0050<g=c@3?cll0dM7A0=7Ad@3=cLd00P3AdM401@36
a/H0]kNg0;Ng]`2h^;P0]kNg0080][Jf00@0]KFe0<_;b`3;bl/0^[Zj0P2f][H01@2e]KD0/K6a0;6a
/@2][Jd0[:b/0080/k>c0`2b/[80102YZJT0[:b/0:b/[02ZZZX20:>SX`050:ZZZP2WYjL0[jn_0:n_
[`2][Jd00`2^[Zh20:n_[`040:j^[P2TY:@0Xj>S0:>SX`<0[:b/00<0[Jf]0;Bd]02d];@00`2d];@2
0;>c/`80^;Rh00@0^[Zj0;2`/02`/;00^;Rh0`2g]kL20;Zj^P@0^;Rh00<0][Jf0;Fe]@2e]KD00`2b
/[801@2`/;00/k>c0:n_[`2_[jl0[Zj^0080`/;200@0/;2`09jNWP2NWYh0/;2`0P2b/[801@2c/k<0
[jn_0;:b/P2b/[80]KFe00<0][Jf0P2d];@01@2f][H0/[:b0;:b/P2d];@0]kNg0080][Jf00@0/;2`
0:VYZ@2YZJT0Xj>S0P2h^;P01@33`l<0Zj^[0;Jf]P2f][H0ZZZZ0080_[jn00@0YJFU0;fm_@2m_Kd0
cLg=0P3>c/h00`3Lg=`0oooo0?ooo`0R0?ooo`030>o_k`3emOD0jn_[0080k>c/00@0j^[Z0>c/k03/
k>`0lO7a0P3]kNd02`3^k^h0kNg]0?Cdm03emOD0l_;b0?Cdm03fm_H0l?3`0>?Sh`3IfMT0emOG00@0
e]KF01T0fMWI0>WYj@3_knl0g]kN0=?Cd`3Hf=P0fMWI0=;BdP3@d=00b<S80<_;b`3>c/h0cLg=0<k>
cP3?cll0b/[:0<K6aP38b<P0b/[:0<G5a@31`L40aLG50<O7a`36a/H0b<S80080c/k>00P0clo?0=3@
d03?cll0clo?0=3@d03>c/h0`L710;no_`80a<C400@0`l?30<_;b`35aLD0b/[:0`3=cLd30<o?c`06
0=7Ad@3EeMD0emOG0=?Cd`3@d=00eMGE0`3De=@20=GEe@070=OGe`3Fe]H0eMGE0=GEe@3Bd]80dM7A
0=CDe0020=3@d00<0=7Ad@3@d=00d];B0=?Cd`3@d=00dM7A0=GEe@3Zj^X0hn?S0<W9b@36a/H0d];B
0P3GemL20=CDe080emOG00L0fMWI0=[JfP3IfMT0fMWI0=SHf03GemL0fMWI0080emOG01P0f][J0=gM
g@3Lg=`0f][J0=KFeP3>c/h0bLW90<K6aP3?cll0hN7Q0>c/k03IfMT0eMGE0=KFeP3@d=00fm_K0>CT
i03:b/X0dM7A0>OWi`3`l?00k^k^0?KfmP3^k^hW0?ooo`009@3oool0103Ogml0e=CD0=CDe03De=@2
0<k>cP040=OGe`3@d=00d=3@0=7Ad@80dm?C00D0c<c<0=7Ad@3>c/h0c/k>0=3@d0020=7Ad@040=;B
dP3?cll0clo?0<30`0<0_[jn00@0_kno0<30`030`<00alO70P2j^[X01@2UYJD0^k^k0;^k^`2e]KD0
/K6a0080[Jf]00@0[:b/0:^[Z`2[Zj/0YJFU0P2PX:000`2RXZ80Xj>S0:>SX`020:>SX`80[:b/00<0
[jn_0;:b/P2b/[800`2b/[801@2e]KD0/K6a0:JVYP2VYZH0Zj^[0080ZZZZ00@0Z:RX0:j^[P2^[Zh0
Zj^[0P2^[Zh01@2`/;00];Bd0;Bd]02d];@0]KFe00D0/[:b00D0][Jf0;6a/@2a/K40][Jf0;Fe]@02
0;Bd]0030;Fe]@2c/k<0/k>c00<0/K6a00D0/;2`0:j^[P2^[Zh0[Zj^0;6a/@020:f][@040<?3``36
a/H0a/K60:VYZ@80[Zj^00D0/;2`0:n_[`2`/;00/;2`0;Bd]0020;Jf]P040;Bd]02e]KD0]KFe0;^k
^`80/[:b0P2e]KD20:^[Z`0409fMW@2FUYH0UYJF0:NWY`80`<3000D0/k>c0:^[Z`2a/K40/K6a0:j^
[P020;6a/@040::RXP39bLT0bLW90<c<c080clo?00<0g]kN0?ooo`3oool08P3oool0403_knl0n?Sh
0?7al@3alO40kNg]0>_[j`3`l?00j^[Z0>c/k03^k^h0lO7a0>g]k@3dm?@0mOGe0?3`l03bl_830?Kf
mP050?Gem@3`l?00h>3P0=[JfP3Lg=`00P3MgMd01P3Ng]h0h>3P0>o_k`3Xj>P0f=SH0=CDe080f=SH
00@0e]KF0<k>cP3;bl/0b<S80P37alL01@36a/H0alO70<?3``2m_Kd0^[Zj00<0_kno00L0`l?30<;2
`P34a<@0c/k>0<o?c`3Cdm<0e=CD0080dm?C0P3EeMD00`3<c<`0`l?30<;2`P030<G5a@050<30`033
`l<0aLG50<?3``36a/H00P3=cLd20<k>cP040=;BdP3AdM40c/k>0<k>cP@0clo?0P3@d=020=GEe@04
0=7Ad@3@d=00d=3@0=3@d0<0clo?0P3@d=020<o?c`80dM7A00L0clo?0=WIf@3Zj^X0kno_0>3Ph03@
d=00dM7A0080d];B00<0dm?C0=OGe`3Fe]H00P3Jf]X40=SHf0030=kNgP3IfMT0f][J0080gMgM01H0
fMWI0<o?c`3=cLd0_[jn0;Fe]@2l_;`0eMGE0>WYj@3Ti>@0emOG0=7Ad@3EeMD0e=CD0=GEe@3Bd]80
aLG50=_Kf`3]kNd0k^k^0>o_k`3jn_X0kno_9`3oool002D0oooo00@0gmoO0=CDe03De=@0e=CD0P3>
c/h0103GemL0d=3@0=3@d03AdM420=?Cd`050<c<c03AdM40c/k>0<k>cP3@d=000P3AdM40103Bd]80
clo?0<o?c`30`<030;jn_P040;no_`30`<00`<300<O7a`80^[Zj00D0YJFU0;^k^`2k^k/0]KFe0;6a
/@020:f][@040:b/[02[Zj/0Zj^[0:FUY@80X:2P00<0XZ:R0:>SX`2SXj<00P2SXj<20:b/[0030:n_
[`2b/[80/[:b00<0/[:b00D0]KFe0;6a/@2VYZH0YZJV0:^[Z`020:ZZZP040:RXZ02^[Zh0[Zj^0:^[
Z`80[Zj^00D0/;2`0;Bd]02d];@0];Bd0;Fe]@050;:b/P050;Jf]P2a/K40/K6a0;Jf]P2e]KD00P2d
];@00`2e]KD0/k>c0;>c/`030;6a/@050;2`/02^[Zh0[Zj^0:j^[P2a/K400P2][Jd01033`l<0a/K6
0<K6aP2YZJT20:j^[P050;2`/02_[jl0/;2`0;2`/02d];@00P2f][H0102d];@0]KFe0;Fe]@2k^k/2
0;:b/P80]KFe0P2[Zj/0102MWId0UYJF09JFUP2WYjL20<30`0050;>c/`2[Zj/0/K6a0;6a/@2^[Zh0
0P2a/K40102RXZ80bLW90<W9b@3<c<`20<o?c`030=kNgP3oool0oooo0280oooo00`0k^k^0??cl`3]
kNd0k^k^0>c/k03^k^h0lO7a0>c/k03`l?00k^k^0>g]k@3[jn/20>o_k`040??cl`3bl_80m?Cd0?Kf
mP80moOg00@0m?Cd0>k^kP3Vi^H0h^;R0P3Shn<01`3Ti>@0h^;R0>GUi@3]kNd0j^[Z0<_;b`2_[jl0
0P3GemL0103=cLd0b<S80<O7a`37alL20<K6aP070;jn_P2i^KT0^[Zj0;fm_@2n_[h0_kno0;jn_P02
0;no_`070<71`@39bLT0c/k>0=3@d03Cdm<0e=CD0=?Cd`020=GEe@040<k>cP35aLD0`<300<30`080
_kno00L0_[jn0<?3``31`L40_[jn0;no_`31`L40`l?300<0alO700P0bl_;0<c<c037alL0alO70<S8
b037alL0c<c<0<_;b`80c/k>00H0b/[:0<c<c03>c/h0clo?0<g=c@38b<P60<W9b@0;0<_;b`3@d=00
c<c<0<[:bP3Hf=P0jn_[0>WYj@3AdM40clo?0=7Ad@3Bd]800P3Cdm<03`3De=@0f=SH0=_Kf`3IfMT0
emOG0=WIf@3Ng]h0gmoO0=WIf@3Hf=P0fMWI0=KFeP3@d=00aLG50;6a/@020;:b/P0A0;no_`3Fe]H0
gMgM0=7Ad@38b<P0clo?0<c<c03>c/h0emOG0<c<c033`l<0g=cL0>k^kP3]kNd0jn_[0?Gem@3_knl0
9`3oool002D0oooo00@0h>3P0=CDe03De=@0dm?C0P3EeMD0103Fe]H0d=3@0=3@d03AdM420=3@d005
0=;BdP3>c/h0cLg=0<g=c@3AdM400P3@d=00103Bd]80b/[:0<[:bP3?cll40<_;b`80c/k>00@0clo?
0<k>cP3>c/h0]kNg0P2_[jl01@2j^[X0/k>c0;2`/02`/;00[Zj^0080Z:RX00<0YjNW0:BTY02TY:@0
0`2XZ:P01@2/[:`0ZJVY0:>SX`2SXj<0Zj^[0080/K6a0`2b/[801@2d];@0]KFe0;2`/02`/;00YjNW
0080[jn_00@0[:b/0;6a/@2a/K40[jn_0P2^[Zh01@2ZZZX0[:b/0:JVYP2VYZH0Z:RX0080XJ6Q00@0
YjNW0:JVYP2VYZH0ZJVY0P2QXJ400`2WYjL0YZJV0:RXZ0020:RXZ0<0YZJV0P2TY:@01@2/[:`0Zj^[
0:ZZZP2ZZZX0[Jf]0080YjNW00@0[Jf]0:RXZ02XZ:P0][Jf0P2VYZH01@2;Rh/0YZJV0:j^[P2^[Zh0
[jn_00<0/k>c0`2f][H20;Zj^P050;Jf]P2EUID0UYJF09JFUP2IVIT00P2LW9`01@2OWil0/[:b0;:b
/P2WYjL0Xj>S0080YjNW00@0]KFe0:b/[02/[:`0/k>c0P37alL0103=cLd0c<c<0<c<c03MgMdT0?oo
o`050>k^kP3fm_H0jn_[0>g]k@3`l?000P3alO404P3/k>`0kNg]0>g]k@3]kNd0l?3`0>k^kP3]kNd0
k^k^0?;blP3clo<0m?Cd0?Ogm`3fm_H0lO7a0?Cdm03`l?00kno_0?7al@80kno_00L0lO7a0?;blP3d
m?@0m?Cd0>OWi`3Bd]80bLW90080clo?00P0bLW90<O7a`37alL0alO70<?3``31`L40_;bl0;fm_@80
`l?300@0a<C40<S8b039bLT0a/K60P32`/801039bLT0cLg=0=;BdP3De=@20=?Cd`080=CDe03Bd]80
c<c<0<?3``30`<00a<C40<K6aP30`<020<C4a080`/;200P0`<300;jn_P2o_kl0^k^k0;Zj^P2l_;`0
^[Zj0;Ng]`<0^k^k00T0_Kfm0;Zj^P2n_[h0_Kfm0;bl_02m_Kd0_[jn0;no_`2n_[h00`2l_;`02@33
`l<0aLG50<C4a036a/H0alO70<[:bP36a/H0`l?30<W9b@020<k>cP0<0=KFeP3EeMD0aLG50;Jf]P38
b<P0dM7A0<k>cP3EeMD0e]KF0=GEe@3Fe]H0fMWI0P3Kfm/01@3Ng]h0fm_K0=SHf034a<@0[Zj^0080
/K6a01<0][Jf0;Ng]`2j^[X0alO70=;BdP3<c<`0`l?30<O7a`3@d=00emOG0=7Ad@37alL0clo?0>3P
h03[jn/0kNg]0>c/k03alO40k^k^02L0oooo000U0?ooo`040>WYj@3Cdm<0dm?C0=?Cd`80e]KF00@0
f=SH0=KFeP3Fe]H0d];B0P3<c<`01@3?cll0cLg=0<g=c@3=cLd0e=CD0080bl_;00D0d=3@0<W9b@39
bLT0dM7A0<o?c`020<g=c@040<[:bP3@d=00d=3@0<g=c@80bl_;00D0dm?C0<71`@31`L40V9RH0<S8
b0020:b/[0040:VYZ@2/[:`0[:b/0:VYZ@80WinO00D0VYZJ0:6QX@2QXJ40YZJV0:RXZ0020::RXP04
0:RXZ02^[Zh0[Zj^0;Fe]@80/k>c00D0][Jf0;6a/@2a/K40/K6a0:^[Z`020:f][@040:j^[P2g]kL0
]kNg0;:b/P80^;Rh00D0^KVi0;Fe]@2k^k/0^k^k0;Ng]`020;>c/`040:j^[P2a/K40/K6a0;2`/080
[jn_00D0/K6a0:b/[02f][H0][Jf0;Bd]0020;Fe]@030;:b/P2h^;P0^;Rh0080/K6a0`2e]KD20;>c
/`040:n_[`2^[Zh0[Zj^0:n_[`80^;Rh00D0^KVi09VIV@1^KVh0KVi^09fMW@020;6a/@040;Fe]@2d
];@0];Bd09jNWP80LW9b00D0KVi^07alO02PX:00X:2P0:ZZZP020:>SX`050:RXZ02VYZH0YZJV0:b/
[02`/;000P2CTi<0102j^[X0XZ:R0::RXP2n_[h20;fm_@040<k>cP3De=@0e=CD0=oOgb@0oooo01/0
l_;b0?KfmP3]kNd0kNg]0>o_k`3bl_80lO7a0>o_k`3/k>`0kNg]0>c/k03`l?00k^k^0>g]k@3/k>`0
l_;b0??cl`3_knl0lo?c0?KfmP3`l?00mOGe0?Cdm03emOD0n?Sh0?Cdm03clo<00P3inOT06`3fm_H0
mOGe0?Win@3hn?P0gMgM0<g=c@3:b/X0d];B0<G5a@31`L40a/K60<C4a035aLD0`<300;bl_02o_kl0
_[jn0<;2`P38b<P0b/[:0<W9b@33`l<0_kno0<G5a@3<c<`0clo?0=?Cd`020=CDe0090=GEe@3AdM40
c/k>0<O7a`34a<@0alO70<S8b034a<@0b<S80080alO700l0bLW90<S8b035aLD0`/;20<71`@2o_kl0
_[jn0;^k^`2i^KT0^[Zj0;bl_02k^k/0^[Zj0;Rh^02l_;`00P2j^[X30;jn_P<0_kno00@0`l?30<W9
b@35aLD0a<C40`3<c<`00`37alL0b<S80<W9b@020<?3``0T0=7Ad@3Fe]H0bl_;0;no_`2_[jl0Vi^K
0<G5a@3:b/X0c/k>0=;BdP3De=@0e]KF0=GEe@38b<P0^KVi0;2`/02][Jd0XJ6Q09fMW@2a/K40_[jn
0<;2`P2k^k/0^KVi0<71`@3:b/X0bl_;0<c<c030`<00c<c<0=kNgP3?cll0_;bl0=SHf03Ph>00inOW
0P3^k^h00`3emOD0kNg]0?ooo`0V0?ooo`009@3oool0103YjNT0dm?C0=?Cd`3Cdm<20=KFeP040=SH
f03Fe]H0e]KF0=;BdP80c<c<00D0clo?0<g=c@3=cLd0cLg=0=CDe0020<_;b`050=3@d039bLT0bLW9
0=7Ad@3?cll00P3=cLd0103:b/X0d=3@0=3@d03=cLd20<_;b`050=?Cd`31`L40`L7109RHV038b<P0
0P2/[:`0102YZJT0[:b/0:b/[02YZJT209nOW`0509ZJVP2QXJ40XJ6Q0:JVYP2XZ:P00P2RXZ80102X
Z:P0[Zj^0:j^[P2e]KD20;>c/`050;Jf]P2a/K40/K6a0;6a/@2[Zj/00P2][Jd0102^[Zh0]kNg0;Ng
]`2b/[820;Rh^0050;Vi^@2e]KD0^k^k0;^k^`2g]kL00P2c/k<0102^[Zh0/K6a0;6a/@2`/;020:n_
[`050;6a/@2/[:`0][Jf0;Jf]P2d];@00P2e]KD00`2b/[80^;Rh0;Rh^0020;6a/@<0]KFe0P2c/k<0
102_[jl0[Zj^0:j^[P2_[jl20;Rh^0050;Vi^@2IVIT0KVi^06i^KP2MWId00P2a/K40102e]KD0];Bd
0;Bd]02NWYh2079bLP0506i^KP1lO7`0X:2P0:2PX02ZZZX00P2SXj<01@2XZ:P0YZJV0:JVYP2/[:`0
/;2`0080Ti>C00@0^[Zj0::RXP2RXZ80_[jn0P2m_Kd0103>c/h0e=CD0=CDe03OgmlT0?ooo`080?3`
l03alO40k^k^0>c/k03[jn/0kno_0>k^kP3_knl30>k^kP0:0>_[j`3^k^h0l?3`0?7al@3bl_80lO7a
0>k^kP3`l?00m_Kf0?7al@<0mOGe00@0m_Kf0?;blP3bl_80m_Kf103emOD0603jn_X0mOGe0<o?c`2k
^k/0bl_;0;fm_@2j^[X0a/K60<O7a`35aLD0`/;20;no_`2m_Kd0^;Rh0;fm_@32`/80a/K60<O7a`33
`l<0_[jn0<C4a03<c<`0cLg=0=3@d080d];B00T0eMGE0=3@d03@d=00c<c<0<O7a`35aLD0a/K60<S8
b03<c<`00P3:b/X30<g=c@0;0<W9b@3:b/X0alO70<O7a`3:b/X0b<S80<G5a@38b<P0a<C40<71`@32
`/800`36a/H00`38b<P0alO70<O7a`020<S8b0090<[:bP3?cll0d=3@0<_;b`3:b/X0d=3@0<o?c`3@
d=00bl_;0080clo?0`3=cLd09`3?cll0eMGE0=SHf02h^;P0VYZJ0<k>cP30`<00]kNg0;Vi^@31`L40
a<C40;Rh^02TY:@0UIFE08V9R@26QXH0TI6A0:>SX`2e]KD0a/K60<C4a02i^KT0aLG50=3@d036a/H0
b<S80<O7a`31`L40d=3@0=_Kf`3=cLd0a<C40=?Cd`3Ogml0inOW0>_[j`3/k>`0m_Kf0?7al@0W0?oo
o`009@3oool0103QhN40dM7A0=7Ad@3Cdm<20=;BdP040=3@d03Bd]80d];B0=;BdP80e]KF00D0clo?
0=?Cd`3Cdm<0dm?C0=7Ad@020=3@d0030=;BdP3?cll0clo?0080dM7A0P3=cLd0103?cll0cLg=0<g=
c@3@d=020<c<c0050=3@d032`/80`/;20:>SX`2QXJ400P2SXj<0102VYZH0[jn_0:n_[`2[Zj/20:ZZ
ZP050:6QX@2TY:@0Y:BT0:NWY`2XZ:P00P2SXj<0102WYjL0[jn_0:n_[`2^[Zh20:n_[`050;>c/`2d
];@0]kNg0;Ng]`2b/[800P2^[Zh00`2c/k<0][Jf0;Jf]P030;Ng]`050;Rh^02i^KT0/k>c0;>c/`2g
]kL00P2j^[X00`2i^KT0]kNg0;Ng]`030;Bd]0050;Jf]P2i^KT0/k>c0;>c/`2e]KD00P2b/[800`2h
^;P0][Jf0;Jf]P020;Jf]P80[Zj^00@0][Jf0;>c/`2c/k<0];Bd0P2f][H30;:b/P050:n_[`2h^;P0
_;bl0;bl_02SXj<00P2=SHd0102>SXh0PH610861P@1iNGT208>3P`0507]kN`2=SHd0SHf=08f=S@2R
XZ800P2JVYX01@3=cLd0WYjN09jNWP2XZ:P0U9BD00D0]kNg00@0[jn_0<c<c03<c<`0b<S80P3;bl/0
0`3WinL0oooo0?ooo`0R0?ooo`030??cl`3bl_80jNWY0080kNg]00<0jn_[0?7al@3alO400P3[jn/0
3P3]kNd0l_;b0?3`l03dm?@0kno_0?7al@3bl_80kno_0?7al@3bl_80m_Kf0?7al@3clo<0moOg0P3h
n?P07P3gmoL0l_;b0?7al@3alO40l?3`0?;blP3emOD0l?3`0=KFeP2d];@0Y:BT0;Bd]02`/;00WYjN
0;Bd]034a<@0`l?30<71`@30`<00^KVi0<71`@34a<@0`<300<71`@34a<@0`L710<?3``3;bl/0cLg=
0<c<c080cLg=0P3>c/h0103@d=00clo?0<c<c03:b/X20<K6aP030<_;b`3=cLd0c<c<00D0c<c<00H0
cLg=0<O7a`33`l<0a/K60<O7a`3<c<`20<g=c@0:0<W9b@36a/H0aLG50<?3``36a/H0bl_;0<k>cP3:
b/X0aLG50<k>cP<0d=3@00T0cLg=0<W9b@3;bl/0d=3@0<_;b`3>c/h0c<c<0<_;b`3Bd]800`3AdM40
3P3:b/X0bLW90<c<c03De=@0eMGE0=;BdP38b<P0WIfM07=cL`1mOGd0T92@08b<S02@T900VIVI0P2N
WYh03`2OWil0XJ6Q0;2`/02h^;P0d=3@0<c<c02ZZZX0^KVi0;Rh^031`L40eMGE0<o?c`3=cLd0jn_[
0>WYj@030>[ZjP030>_[j`3clo<0m?Cd02L0oooo000U0?ooo`040>CTi03De=@0e=CD0=CDe080d=3@
00<0f=SH0=CDe03De=@00`3EeMD01@3De=@0eMGE0=3@d03@d=00dm?C00<0d];B0P3Fe]H01@3=cLd0
d];B0=CDe03De=@0dM7A0080c/k>00@0clo?0<g=c@3=cLd0d=3@0P35aLD01@2m_Kd0V9RH0:2PX02P
X:00T92@0080RXZ:00@0/;2`0:RXZ02XZ:P0XZ:R0P2ZZZX01@2UYJD0YZJV0:BTY02TY:@0YjNW00<0
[jn_0P2`/;00102b/[80/k>c0;Bd]02d];@30;>c/`030;:b/P2g]kL0]kNg00<0]kNg0P2h^;P20;Zj
^P040;Bd]02e]KD0]KFe0;Fe]@80^;Rh00D0][Jf0;Fe]@2e]KD0/K6a0;2`/0020;:b/P030;Fe]@2a
/K40/K6a00@0]kNg00@0[jn_0;>c/`2c/k<0]KFe0P2b/[80102_[jl0][Jf0;Jf]P2e]KD20;6a/@05
0:f][@2/[:`0YJFU0:FUY@2WYjL00P2HV9P01022PX80LW9b079bLP1nOWh207]kN`80RHV90P28R8P0
102FUYH0WYjN09jNWP2m_Kd2092@T0050::RXP2HV9P0]kNg0;Ng]`2`/;000P2k^k/01035aLD0bl_;
0<_;b`3;bl/20=7Ad@030>CTi03oool0oooo0280oooo00T0k^k^0?KfmP3_knl0k>c/0>WYj@3/k>`0
l?3`0>c/k03`l?000P3bl_801P3^k^h0lo?c0?Cdm03`l?00k^k^0?7al@<0mOGe00L0m_Kf0?7al@3a
lO40mOGe0?Shn03gmoL0m?Cd0080lO7a00l0l_;b0??cl`3bl_80lo?c0?7al@3Kfm/0`<300:VYZ@2V
YZH0[Zj^08b<S01kNg/0XZ:R0<71`@32`/800P2n_[h02@33`l<0`<300<71`@32`/80_kno0;jn_P33
`l<0bl_;0<g=c@030<c<c080cLg=103<c<`20<_;b`@0c<c<00H0cLg=0<c<c03<c<`0c<c<0<g=c@39
bLT20<G5a@0>0<K6aP3<c<`0bLW90<O7a`3:b/X0a<C40<;2`P36a/H0alO70<S8b037alL0a/K60<O7
a`3>c/h30=3@d0050<_;b`37alL0d=3@0=7Ad@3<c<`00P3:b/X03P3=cLd0d];B0=7Ad@3;bl/0b/[:
0<W9b@35aLD0^k^k0;Fe]@2a/K40WIfM08V9R@25QHD0RHV90P28R8P01`29RHT0UiNG09bLW02KVi/0
WIfM0:6QX@2b/[800P2f][H04@35aLD0`l?30:n_[`2g]kL0^KVi0<[:bP3Cdm<0c<c<0=KFeP3WinL0
k>c/0>o_k`3Xj>P0j^[Z0?;blP3gmoL0lO7a02L0oooo000U0?ooo`030>OWi`3Bd]80d];B00<0dM7A
00@0f=SH0=?Cd`3Cdm<0d];B0P3Jf]X01@3Bd]80e=CD0=KFeP3Fe]H0clo?00<0e]KF0P3@d=001@3B
d]80e]KF0<o?c`3?cll0e]KF00<0c/k>0P3Fe]H01@3@d=00cLg=0<g=c@3>c/h0`/;20080T92@00@0
S8b<07UiN@1iNGT0LG5a0P2`/;00102YZJT0WIfM09fMW@2OWil30:JVYP040:RXZ02_[jl0[jn_0:n_
[`80/;2`00D0/K6a0;:b/P2c/k<0/k>c0;Bd]0020;Fe]@<0/K6a00@0/[:b0;Jf]P2f][H0/k>c0`2i
^KT60;Bd]0@0/K6a102b/[820;2`/0030;6a/@2f][H0][Jf0080[jn_0P2g]kL0102e]KD0[jn_0:n_
[`2a/K420;:b/P050;2`/02_[jl0[jn_0:FUY@2SXj<00P2FUYH01022PX80MGEe07EeM@25QHD208b<
S00508^;R`1oOgl0Ogmo08>3P`28R8P00P2FUYH0102NWYh0YjNW0:NWY`2SXj<208j>SP0509ZJVP2U
YJD0/;2`0;2`/02^[Zh00P33`l<01037alL0c<c<0<c<c03=cLd20=3@d0030=gMg@3oool0oooo0280
oooo00<0l_;b0?Gem@3[jn/00P3Zj^X0;03/k>`0l?3`0>[ZjP3`l?00k^k^0>o_k`3]kNd0lo?c0>o_
k`3bl_80kno_0?3`l03emOD0m_Kf0?Gem@3alO40l?3`0??cl`3gmoL0mOGe0?;blP3fm_H0l_;b0>o_
k`3`l?00mOGe0?KfmP3clo<0lO7a0>?Sh`3Lg=`0^[Zj09ZJVP2OWil0R8R807IfMP1/K6`0VYZJ0<;2
`P2k^k/0`/;20;Zj^P2g]kL0_;bl0`31`L400`33`l<0bl_;0<c<c0090<c<c0030<_;b`37alL0alO7
0080alO700<0bLW90<_;b`38b<P00P3<c<`00`3=cLd0bLW90<K6aP020<K6aP80alO70P35aLD00`34
a<@0a/K60<O7a`020<O7a`060<K6aP35aLD0b<S80<[:bP3>c/h0bl_;0P39bLT0503:b/X0dM7A0=7A
d@3<c<`0b<S80<W9b@3;bl/0cLg=0<c<c035aLD0alO70;jn_P2i^KT0[Jf]0:>SX`2=SHd0OWin07mo
O`2=SHd0V9RH0P2GUiL01P2ATI40SHf=09JFUP2MWId0XJ6Q0:j^[P80]kNg00H0_[jn0<30`02c/k<0
Zj^[0;Jf]P33`l<30<g=c@040=_Kf`3^k^h0kNg]0>g]k@80k>c/00<0kno_0?Gem@3^k^h09`3oool0
02D0oooo00<0inOW0=;BdP3Bd]800`3AdM40103Hf=P0dm?C0=?Cd`3Bd]820=[JfP050=;BdP3De=@0
e]KF0=KFeP3?cll00`3Fe]H20=3@d0050=;BdP3Fe]H0clo?0<o?c`3Fe]H00`3>c/h20=KFeP050=3@
d03=cLd0cLg=0<k>cP32`/800P2@T900102<S8`0NGUi07UiN@1aLG420;2`/0040:VYZ@2MWId0WIfM
09nOW`<0YZJV00@0Z:RX0:n_[`2_[jl0[jn_0P2`/;001@2a/K40/[:b0;>c/`2c/k<0];Bd0080]KFe
0`2a/K40102b/[80][Jf0;Jf]P2c/k<30;Vi^@H0];Bd102a/K440;:b/P80/;2`00<0/K6a0;Jf]P2f
][H00P2_[jl20;Ng]`040;Fe]@2_[jl0[jn_0;6a/@80/[:b00D0/;2`0:n_[`2_[jl0YJFU0:>SX`02
09JFUP0408:2PP1eMGD0MGEe08F5Q@80S8b<00D0Rh^;07moO`1oOgl0Ph>308R8R00209JFUP0409jN
WP2WYjL0YjNW0:>SX`80SXj>00D0VYZJ0:FUY@2`/;00/;2`0:j^[P020<?3``040<O7a`3<c<`0c<c<
0<g=c@80d=3@00<0gMgM0?ooo`3oool08P3oool04P3`l?00lo?c0>c/k03]kNd0j^[Z0>_[j`3`l?00
kno_0?7al@3]kNd0k^k^0>g]k@3^k^h0lO7a0>o_k`3`l?00m?Cd0??cl`80l?3`0P3_knl20?Cdm004
0?7al@3emOD0m?Cd0?7al@80lo?c0P3dm?@20?7al@0E0>;RhP3Ti>@0^KVi09:BTP2>SXh0QhN707Mg
M`1OGel0GUiN08V9R@2i^KT0^[Zj0;Jf]P2k^k/0_[jn0<30`031`L40_kno0<;2`P36a/H0b/[:00<0
c<c<0P3;bl/40<c<c00;0<_;b`39bLT0bLW90<K6aP37alL0bLW90<O7a`35aLD0alO70<_;b`3<c<`0
0P3;bl/01@39bLT0`/;20<;2`P35aLD0a/K60080aLG500<0a<C40<K6aP36a/H00P34a<@20<K6aP07
0<G5a@3=cLd0b/[:0<[:bP3<c<`0b/[:0<_;b`020=3@d00F0<c<c03:b/X0bl_;0<W9b@36a/H0`l?3
0<30`02e]KD0[jn_0:RXZ02CTi<0Ng]k08:2PP2@T900Ti>C09BDU02LW9`0YJFU09VIV@2=SHd0TY:B
0:6QX@80Z:RX01@0];Bd0:n_[`2e]KD0][Jf0;>c/`2j^[X0_[jn0=GEe@39bLT0`<300=CDe03Xj>P0
k^k^0>o_k`3Zj^X0jn_[0>c/k03]kNd0n?Sh0?3`l2L0oooo000U0?ooo`040>3Ph03De=@0e=CD0=KF
eP80clo?00@0f][J0=WIf@3IfMT0e=CD0P3Jf]X01@3Cdm<0eMGE0=7Ad@3AdM40emOG0080e=CD00<0
d=3@0=CDe03De=@00P3AdM420=KFeP040=7Ad@3Cdm<0dm?C0=GEe@80dm?C00D0d=3@0<W9b@39bLT0
eMGE0;Fe]@0208Z:RP0408F5Q@1cLg<0Lg=c05YJFP80JVYZ00D0XJ6Q09fMW@2MWId0ZJVY0:NWY`02
0::RXP040:JVYP2[Zj/0Zj^[0:n_[`80/;2`00D0[jn_0;2`/02c/k<0/k>c0;Bd]0020;Fe]@030;Ng
]`2i^KT0^KVi00<0]KFe00D0/[:b0;>c/`2h^;P0^;Rh0;Vi^@020;Zj^P040:f][@2a/K40/K6a0;>c
/`80/[:b0P2`/;020:j^[P040:b/[02^[Zh0[Zj^0:^[Z`80]kNg00D0/k>c0;:b/P2][Jd0[Jf]0;Ng
]`020;Fe]@040;Bd]02b/[80/[:b0:f][@80Z:RX00D0YjNW09VIV@2@T900T92@07EeM@0208f=S@04
08Z:RP26QXH0QXJ609JFUP80QXJ600D0PX:209JFUP25QHD0QHF509RHV00309FEU@80[:b/00D0YjNW
0;bl_02FUYH0UYJF0;Jf]P020<W9b@040<c<c036a/H0a/K60<_;b`80d];B00<0hN7Q0?ooo`3oool0
8P3oool03@3^k^h0lO7a0>c/k03/k>`0jNWY0>_[j`3alO40kNg]0>k^kP3[jn/0k^k^0?3`l03_knl0
0`3`l?020?7al@030?3`l03^k^h0l_;b0080lO7a0P3bl_800`3clo<0lO7a0?Cdm0030?Gem@0H0?;b
lP3alO40l?3`0>3Ph03MgMd0_kno0:6QX@27QhL0RXZ:07YjNP1TI6@0ATI604a<C029RHT0^KVi0;Ng
]`2m_Kd0_;bl0;jn_P31`L40_[jn0;no_`36a/H0bl_;0`3<c<`01P3;bl/0b<S80<S8b03:b/X0c<c<
0<[:bP<0b<S800h0a/K60<G5a@35aLD0a<C40<K6aP38b<P0c<c<0<g=c@3;bl/0bLW90<S8b033`l<0
`/;20<?3``80a<C400D0a/K60<G5a@36a/H0a<C40<?3``020<71`@80aLG50P3:b/X0103;bl/0c<c<
0<W9b@39bLT20<g=c@040<G5a@31`L40`L710;bl_080][Jf0180/k>c0:^[Z`2JVYX0QhN707AdM01m
OGd0UiNG0:6QX@2?Shl0QHF509ZJVP2TY:@0YZJV0::RXP2QXJ40Y:BT0:2PX02LW9`20:NWY`060:n_
[`2a/K40]kNg0<C4a036a/H0eMGE0P35aLD01@3Kfm/0jn_[0>WYj@3[jn/0j^[Z0080jn_[00<0kNg]
0?[jnP3alO409`3oool002D0oooo00@0h>3P0=?Cd`3Cdm<0dM7A0P3De=@0103Fe]H0dM7A0=7Ad@3C
dm<20=SHf0050=OGe`3EeMD0f=SH0=SHf03AdM400P3EeMD01@3De=@0fMWI0=WIf@3Bd]80dm?C0080
e=CD00@0d];B0=CDe03De=@0eMGE0`3Cdm<20=3@d0050<k>cP30`<00YJFU0:FUY@29RHT00P1gMgL0
101PH600ATI604I6AP1`L7020:RXZ0030:6QX@2SXj<0YJFU0080YJFU0P2_[jl00`2^[Zh0[jn_0:n_
[`020;2`/080[Zj^00@0/k>c0;Bd]02d];@0/K6a0P2e]KD01@2b/[80[jn_0:n_[`2b/[80]kNg00<0
][Jf0P2c/k<0102a/K40[Zj^0:j^[P2^[Zh20:^[Z`050;2`/02a/K40ZZZZ0:ZZZP2/[:`00P2WYjL0
1@2ZZZX0[jn_0:n_[`2_[jl0/;2`0080ZZZZ00@0/K6a0:VYZ@2YZJT0Xj>S0P2QXJ401@2IVIT0V9RH
09RHV02DU9@0MgMg0080I6AT00@0P82009ZJVP2JVYX0RXZ:0P26QXH01@2=SHd0X:2P0:2PX02IVIT0
SXj>0080Ph>300@0Rh^;09ZJVP2JVYX0UiNG0P2ZZZX01@2b/[80ZZZZ0;6a/@2a/K40`<300080`L71
00@0`l?30<g=c@3=cLd0cLg=0P3Bd]800`3Shn<0oooo0?ooo`0R0?ooo`050>k^kP3dm?@0j^[Z0>WY
j@3Zj^X00P3]kNd0103Xj>P0j^[Z0>_[j`3^k^h20?;blP0<0>g]k@3bl_80l?3`0>k^kP3bl_80lo?c
0>o_k`3dm?@0l_;b0>o_k`3alO40m?Cd0P3alO402`3dm?@0lO7a0??cl`3emOD0l_;b0?7al@3^k^h0
j>SX0=cLg03<c<`0/;2`0080Rh^;0100NWYj06=SH`1>CTh0?Cdm04Y:BP2=SHd0]kNg0;no_`2f][H0
^KVi0<;2`P2o_kl0_[jn0<O7a`3;bl/0b/[:0`39bLT00`37alL0aLG50<K6aP020<[:bP80a<C40P36
a/H01P32`/80`<300<71`@34a<@0bLW90<[:bP80bLW900L0alO70<G5a@34a<@0`/;20<30`031`L40
_kno0080a<C400D0a/K60<;2`P32`/80_kno0;^k^`020<71`@0J0<G5a@39bLT0a/K60<K6aP38b<P0
a<C40<S8b036a/H0_Kfm0;Ng]`2e]KD0/;2`0:ZZZP2XZ:P0Y:BT08n?S`1hN7P0IfMW06ATI027QhL0
XZ:R0:FUY@2ATI40RHV909jNWP2RXZ820;6a/@0H0:j^[P2XZ:P0W9bL09NGU`2KVi/0YjNW0;6a/@2b
/[80]kNg0<?3``36a/H0b/[:0<W9b@3GemL0hn?S0>KViP3Rh^80i>CT0>_[j`3^k^h0k>c/0>g]k@3j
n_X0lo?c9`3oool002D0oooo00@0h>3P0=?Cd`3Cdm<0dM7A0P3De=@0103Fe]H0dM7A0=7Ad@3Cdm<2
0=SHf0050=OGe`3EeMD0f=SH0=SHf03AdM400P3EeMD01@3De=@0fMWI0=WIf@3Bd]80dm?C0080e=CD
00@0d];B0=CDe03De=@0eMGE0`3Cdm<20=3@d0050<k>cP30`<00YJFU0:FUY@29RHT00P1gMgL0101P
H600ATI604I6AP1`L7020:RXZ0030:6QX@2SXj<0YJFU0080YJFU0P2_[jl00`2^[Zh0[jn_0:n_[`02
0;2`/080[Zj^00@0/k>c0;Bd]02d];@0/K6a0P2e]KD01@2b/[80[jn_0:n_[`2b/[80]kNg00<0][Jf
0P2c/k<0102a/K40[Zj^0:j^[P2^[Zh20:^[Z`050;2`/02a/K40ZZZZ0:ZZZP2/[:`00P2WYjL01@2Z
ZZX0[jn_0:n_[`2_[jl0/;2`0080ZZZZ00@0/K6a0:VYZ@2YZJT0Xj>S0P2QXJ401@2IVIT0V9RH09RH
V02DU9@0MgMg0080I6AT00@0P82009ZJVP2JVYX0RXZ:0P26QXH01@2=SHd0X:2P0:2PX02IVIT0SXj>
0080Ph>300@0Rh^;09ZJVP2JVYX0UiNG0P2ZZZX01@2b/[80ZZZZ0;6a/@2a/K40`<300080`L7100@0
`l?30<g=c@3=cLd0cLg=0P3Bd]800`3Shn<0oooo0?ooo`0R0?ooo`0:0>g]k@3fm_H0k^k^0>_[j`3^
k^h0kno_0>WYj@3[jn/0k^k^0?7al@80kno_00<0l_;b0>k^kP3alO400P3_knl03@3clo<0lO7a0>o_
k`3dm?@0lo?c0?7al@3`l?00l_;b0?Gem@3clo<0l?3`0>k^kP3`l?000`3alO403P3/k>`0k^k^0=oO
g`3<c<`0Xj>S08n?S`27QhL0LW9b061PH01EEED0Bd];03`l?00k>c/0RHV90`2g]kL01P2n_[h0_;bl
0<30`033`l<0b<S80<K6aP<0a<C400<0b/[:0<O7a`34a<@00P38b<P20<C4a00A0<W9b@36a/H0a<C4
0<?3``30`<00`L710<?3``34a<@0`/;20<K6aP3:b/X0aLG50<71`@2o_kl0`<300;no_`2n_[h00P2l
_;`20<30`0030;no_`2l_;`0^k^k0080^k^k0300`/;20<O7a`30`<00_kno0<?3``2k^k/0`l?30<71
`@2m_Kd0]kNg0;:b/P2`/;00Z:RX09bLW02BTY80Kfm_06=SH`1`L700Ng]k09:BTP2MWId0WYjN09^K
V`2NWYh0YjNW0:FUY@2VYZH0XZ:R0:6QX@2VYZH0YJFU09bLW02QXJ40[Jf]0:n_[`2c/k<0_Kfm0<C4
a035aLD0clo?0=SHf03Ph>00i^KV0>GUi@3QhN40i^KV0>k^kP3`l?020>k^kP030?[jnP3emOD0oooo
02H0oooo000U0?ooo`040>7Qh@3Bd]80d];B0=KFeP80fMWI00@0d=3@0=SHf03Hf=P0fMWI0P3Cdm<0
1@3De=@0e]KF0=KFeP3Fe]H0dM7A0080eMGE00@0d];B0=WIf@3IfMT0emOG0`3EeMD0103GemL0d];B
0=;BdP3Cdm<20=GEe@050=CDe03AdM40dM7A0<;2`P3AdM400P2CTi<0102<S8`0L71`071`L01SHf<2
05iNGP0504E5A@1=CDd0CDe=0:b/[02MWId00P2SXj<0102UYJD0ZZZZ0:ZZZP2[Zj/30:f][@040;:b
/P2^[Zh0[Zj^0;Bd]0<0/[:b0P2e]KD0102b/[80/k>c0;>c/`2_[jl30;2`/0040;Bd]02c/k<0/k>c
0:n_[`80[Zj^00D0Zj^[0:f][@2][Jd0YZJV0:NWY`020:b/[0040:JVYP2XZ:P0Z:RX0:BTY080[Zj^
00<0ZJVY0:NWY`2XZ:P00P2XZ:P20:NWY`040::RXP2OWil0WinO092@T080PH6100D0NGUi06][J`1m
OGd0OGem096AT@0308j>SP80UIFE00D0Shn?08N7Q`27QhL0R8R808Z:RP0209>CT`<0UIFE00D0Xj>S
0:VYZ@2YZJT0Z:RX0;Vi^@020<30`0040;no_`36a/H0a/K60<S8b0<0dM7A0P3De=@00`3Vi^H0oooo
0?ooo`0R0?ooo`030>k^kP3_knl0k^k^0080lO7a00P0k^k^0>WYj@3`l?00lO7a0?;blP3_knl0kNg]
0?7al@80kNg]00H0k>c/0>g]k@3_knl0kNg]0>k^kP3clo<20?Gem@070??cl`3alO40lo?c0?KfmP3a
lO40kno_0?3`l0020?7al@0C0>o_k`3YjNT0j>SX0=_Kf`34a<@0Ti>C08j>SP27QhL0Kfm_05iNGP1J
FUX0EUIF04M7A`0b<S80820P07moO`2b/[80]KFe0;Ng]`020;bl_0030<71`@32`/80`l?300<0a<C4
00@0bLW90<O7a`38b<P0bLW91034a<@20<?3``0<0<G5a@33`l<0_kno0;no_`31`L40`<300<;2`P36
a/H0aLG50<?3``32`/80`L710P2o_kl0402h^;P0]KFe0;Rh^02o_kl0_Kfm0;Vi^@2l_;`0`<300;^k
^`32`/80`l?30;jn_P2i^KT0^[Zj0<30`02j^[X20;Rh^00G0;Jf]P2_[jl0YJFU09NGU`23Ph<0N7Qh
075aL@1bLW80Ogmo09JFUP2PX:00W9bL09RHV02JVYX0XZ:R0:NWY`2NWYh0Ti>C096AT@2IVIT0W9bL
09jNWP2^[Zh00`2_[jl04@2i^KT0aLG50<G5a@35aLD0h>3P0>OWi`3Rh^80hN7Q0>WYj@3_knl0k^k^
0?7al@3clo<0l_;b0?7al@3hn?P0m?Cd02L0oooo000U0?ooo`040=kNgP3GemL0emOG0=GEe@80f=SH
00@0emOG0=7Ad@3AdM40emOG0P3Jf]X0103De=@0dM7A0=GEe@3EeMD30=_Kf`040=[JfP3EeMD0eMGE
0=;BdP<0e=CD00@0fm_K0=GEe@3EeMD0e]KF0P3De=@01@3GemL0e]KF0=KFeP37alL0dm?C0080UIFE
00@0SXj>07IfMP1fMWH0Hf=S0P1RHV801@19BDT0AdM704M7A`17AdL0XJ6Q0080ZZZZ00@0Y:BT0:VY
Z@2YZJT0[:b/0P2][Jd20:j^[P80]KFe00@0][Jf0;:b/P2b/[80/k>c0P2d];@00`2c/k<0];Bd0;Bd
]0020;6a/@80/[:b00@0/K6a0:j^[P2^[Zh0[Jf]1@2[Zj/20:NWY`80YZJV00@0XJ6Q09jNWP2NWYh0
XZ:R0P2OWil00`2[Zj/0Xj>S0:BTY0020:BTY080WinO00@0WYjN08:2PP22PX80L71`0P1NGUh01@1l
O7`0Ph>308j>SP2>SXh0T92@0080SHf=00@0SXj>09NGU`2GUiL0UYJF0P2GUiL01@2JVYX0VIVI09NG
U`2GUiL0Vi^K0080XZ:R0`2XZ:P01@2/[:`0][Jf0;Zj^P2j^[X0`l?30080alO700@0d=3@0<c<c03<
c<`0dM7A0P3=cLd00`3WinL0oooo0?ooo`0R0?ooo`0A0>g]k@3gmoL0kNg]0>o_k`3alO40l?3`0>o_
k`3/k>`0kNg]0?3`l03bl_80kNg]0>c/k03Zj^X0kNg]0?7al@3bl_800`3clo<00`3alO40kno_0?3`
l0020?7al@030?;blP3fm_H0l_;b0080lO7a01X0l?3`0>o_k`3_knl0l?3`0>WYj@3Lg=`0a<C409JF
UP2>SXh0QhN7079bLP1OGel0FEUI05IFEP15ADD0;Rh^02PX:00V9RH0Ogmo0;Zj^P2h^;P0`<300;bl
_030`<00`L710<?3``<0a<C400@0aLG50<W9b@3;bl/0b<S81P34a<@01@35aLD0a<C40<71`@31`L40
a<C40080`L7100@0`/;20<71`@31`L40_kno0`2n_[h30;Rh^00:0;Zj^P2h^;P0];Bd0;>c/`2i^KT0
^k^k0;Vi^@32`/80_;bl0;Bd]080^KVi02T0^;Rh0:j^[P2a/K40/K6a0::RXP27QhL0Lg=c07MgM`1L
G5`0OGem08:2PP2?Shl0WinO09fMW@2IVIT0Vi^K09ZJVP2OWil0[Jf]0:JVYP2SXj<0XZ:R0:NWY`2[
Zj/0[:b/0;2`/02d];@0/[:b0;^k^`33`l<0aLG50<C4a036a/H0fm_K0=oOg`3Shn<0inOW0>_[j`3^
k^h0lo?c0?3`l0020?7al@030>c/k03clo<0m?Cd02L0oooo000U0?ooo`040=kNgP3GemL0emOG0=GE
e@80f=SH00@0emOG0=7Ad@3AdM40emOG0P3Jf]X0103De=@0dM7A0=GEe@3EeMD30=_Kf`040=[JfP3E
eMD0eMGE0=;BdP<0e=CD00@0fm_K0=GEe@3EeMD0e]KF0P3De=@01@3GemL0e]KF0=KFeP37alL0dm?C
0080UIFE00@0SXj>07IfMP1fMWH0Hf=S0P1RHV801@19BDT0AdM704M7A`17AdL0XJ6Q0080ZZZZ00@0
Y:BT0:VYZ@2YZJT0[:b/0P2][Jd20:j^[P80]KFe00@0][Jf0;:b/P2b/[80/k>c0P2d];@00`2c/k<0
];Bd0;Bd]0020;6a/@80/[:b00@0/K6a0:j^[P2^[Zh0[Jf]1@2[Zj/20:NWY`80YZJV00@0XJ6Q09jN
WP2NWYh0XZ:R0P2OWil00`2[Zj/0Xj>S0:BTY0020:BTY080WinO00@0WYjN08:2PP22PX80L71`0P1N
GUh01@1lO7`0Ph>308j>SP2>SXh0T92@0080SHf=00@0SXj>09NGU`2GUiL0UYJF0P2GUiL01@2JVYX0
VIVI09NGU`2GUiL0Vi^K0080XZ:R0`2XZ:P01@2/[:`0][Jf0;Zj^P2j^[X0`l?30080alO700@0d=3@
0<c<c03<c<`0dM7A0P3=cLd00`3WinL0oooo0?ooo`0R0?ooo`090??cl`3inOT0jn_[0>c/k03_knl0
k^k^0?7al@3_knl0l?3`0080k^k^01@0j^[Z0>g]k@3`l?00kNg]0>c/k03^k^h0l?3`0?7al@3dm?@0
lo?c0>o_k`3^k^h0l_;b0??cl`3_knl0l?3`0?7al@3dm?@0lo?c0?3`l080kno_01D0k^k^0>SXj03K
fm/0_kno09NGU`2<S8`0O7al071`L01WIfL0GemO055AD@0m?Cd0;2`/02DU9@0S8b<0Ogmo0;^k^`2f
][H0_Kfm0<30`031`L400P32`/800`35aLD0alO70<G5a@020<G5a@070<K6aP35aLD0a<C40<?3``30
`<00`l?30<G5a@030<?3``070<30`032`/80`L710;no_`2n_[h0_Kfm0;Zj^P020;jn_P060;fm_@2n
_[h0_;bl0;Rh^02f][H0/k>c0P2b/[802@2`/;00/K6a0;Rh^033`l<0^[Zj0;>c/`2][Jd0Zj^[0:j^
[P020:n_[`0]0:>SX`2PX:00VYZJ096AT@1oOgl0G5aL06][J`1WIfL0MWIf07]kN`2@T900W9bL09JF
UP2CTi<0UiNG09jNWP2UYJD0Zj^[0;6a/@2d];@0Zj^[0:ZZZP2g]kL0_Kfm0;:b/P2d];@0_Kfm0<?3
``35aLD0a<C40<K6aP3AdM40f=SH0>?Sh`3/k>`0k^k^0??cl`3bl_80l?3`0>k^kP3alO40kno_0>_[
j`3gmoL0mOGe02L0oooo000U0?ooo`040>SXj03EeMD0eMGE0=CDe080dm?C00@0emOG0=WIf@3IfMT0
e]KF0P3De=@01@3Bd]80fMWI0=CDe03De=@0dm?C0080eMGE00D0f=SH0=[JfP3Jf]X0e=CD0=OGe`02
0=CDe0040=GEe@3Hf=P0f=SH0=SHf080e=CD00D0e]KF0=?Cd`3Cdm<0c/k>0<71`@0209NGU`0408B4
Q01dM7@0M7Ad07AdM080GEeM00D0B4Q80410@010@400I6AT0:2PX0020:>SX`040:RXZ02ZZZX0ZZZZ
0:ZZZP80]KFe00D0/;2`0;:b/P2`/;00/;2`0;6a/@020;:b/P030:n_[`2d];@0];Bd00<0/[:b00D0
[jn_0;6a/@2][Jd0[Jf]0:^[Z`020:RXZ0040:VYZ@2[Zj/0Zj^[0:^[Z`<0YJFU00@0X:2P09ZJVP2J
VYX0W9bL0P2OWil01@2/[:`0Vi^K09^KV`2DU9@0UYJF0080VIVI00@0UiNG08^;R`2;Rh/0OWin0P21
PH401@1SHf<0LG5a075aL@1iNGT0LW9b0080Rh^;0`29RHT0102@T900UiNG09NGU`2OWil20::RXP05
09NGU`2WYjL0UiNG09NGU`2RXZ800`2XZ:P20:ZZZP80^;Rh0`3<c<`20<o?c`040<g=c@3>c/h0c/k>
0<o?c`80dm?C00<0iNGU0?ooo`3oool08P3oool0203emOD0m_Kf0>WYj@3Zj^X0k>c/0>_[j`3]kNd0
lO7a0`3^k^h00`3[jn/0lO7a0??cl`030>k^kP050>o_k`3alO40lO7a0?7al@3`l?000P3bl_800`3`
l?00kno_0??cl`030?Cdm00L0?;blP3_knl0kno_0>c/k03Xj>P0bl_;0:n_[`2HV9P0Rh^;07YjNP1[
Jf/0KFe]06IVIP1CDe<0A4A4034a<@0/;2`0>SXj05mOG`2EUID0^KVi0;jn_P32`/80a/K60<?3``31
`L40a/K60<W9b@80aLG50`34a<@02033`l<0`/;20<71`@32`/80`<300;no_`32`/80`l?30P30`<00
=02o_kl0`<300;bl_02k^k/0_;bl0;Ng]`2m_Kd0`L710<30`02k^k/0^;Rh0;:b/P2a/K40Z:RX0:NW
Y`2^[Zh0]kNg0<30`02o_kl0ZZZZ0:6QX@2UYJD0YZJV0:FUY@2[Zj/0YZJV09JFUP2@T900QHF507]k
N`1jNWX0MWIf079bLP1mOGd0Q8B408^;R`2JVYX0WYjN09NGU`2FUYH0UiNG0:2PX02UYJD0WinO0:NW
Y`2^[Zh0ZJVY0:^[Z`2b/[80/;2`0:f][@2l_;`20<C4a0060<?3``36a/H0clo?0=SHf03QhN40j^[Z
0P3bl_801@3`l?00k^k^0?7al@3alO40l?3`0080kNg]00<0nOWi0?;blP3oool09P3oool002D0oooo
00@0jNWY0=GEe@3EeMD0e=CD0`3Cdm<20=KFeP050=WIf@3Bd]80d];B0=OGe`3IfMT00P3Hf=P30=OG
e`050=KFeP3GemL0emOG0=GEe@3GemL00P3De=@0103IfMT0f][J0=[JfP3Hf=P20=GEe@050=KFeP3D
e=@0e=CD0<W9b@2YZJT00P2DU9@01026QXH0NWYj07YjNP1jNWX2069RHP05051@D01CDe<0De=C05=C
D`20P8000P2UYJD0102XZ:P0[Zj^0:j^[P2[Zj/20;>c/`050:f][@2`/;00[jn_0:n_[`2a/K400`2b
/[820;2`/0050:n_[`2`/;00/;2`0;>c/`2/[:`00P2^[Zh0102/[:`0ZJVY0:VYZ@2XZ:P20:VYZ@05
0:NWY`2SXj<0Xj>S0:2PX02IVIT00P2DU9@0102HV9P0/;2`0;2`/02IVIT208b<S00509NGU`2CTi<0
S8b<08b<S023Ph<00P1kNg/0101dM7@0KVi^06i^KP1oOgl208>3P`0507YjNP2<S8`0TY:B09:BTP2>
SXh00P2<S8`01029RHT0U9BD09BDU02LW9`209BDU00509nOW`2DU9@0WIfM09fMW@2XZ:P00P2VYZH0
1@2YZJT0[jn_0:n_[`31`L40`/;20080bl_;00@0c/k>0<[:bP3:b/X0d=3@0P3Bd]80103?cll0e=CD
0=CDe03Ti>@T0?ooo`0<0?Cdm03fm_H0jNWY0>[ZjP3[jn/0jNWY0>[ZjP3^k^h0kNg]0?3`l03^k^h0
kno_0P3clo<02P3alO40l?3`0>k^kP3`l?00l_;b0>g]k@3_knl0k^k^0?3`l03bl_820>o_k`0R0?Cd
m03fm_H0l_;b0?;blP3alO40k^k^0>g]k@3YjNT0j>SX0<30`02SXj<0Ti>C08b<S01kNg/0LW9b07=c
L`1UIFD0E5AD04];B`0i>CT0?Cdm04M7A`0k>c/0LG5a0;bl_031`L40`/;20<[:bP34a<@0`<300<C4
a036a/H0`L710<C4a080`/;200D0`l?30<C4a033`l<0`/;20<30`0020;jn_P090;no_`32`/80`/;2
0;jn_P2m_Kd0_kno0;jn_P2l_;`0^k^k0080^KVi00H0_Kfm0;bl_02h^;P0/k>c0:f][@2YZJT20:>S
X`0h0;2`/033`l<0aLG50:^[Z`2MWId0X:2P0:RXZ02UYJD0WIfM09VIV@2ATI40P82008B4Q020P800
LW9b07AdM024Q8@0Ph>308^;R`2<S8`0Vi^K0::RXP2QXJ40Vi^K09NGU`2>SXh0Vi^K0:VYZ@2MWId0
Z:RX0:FUY@2a/K40/[:b0:ZZZP2[Zj/0][Jf0<?3``34a<@0`l?30<C4a038b<P0d];B0>3Ph03WinL0
k>c/0??cl`3bl_80jn_[0>k^kP3clo<0m?Cd0>o_k`3]kNd0l?3`0?Shn03bl_8W0?ooo`009@3oool0
103YjNT0dm?C0=?Cd`3EeMD20=OGe`040=SHf03IfMT0fMWI0=WIf@80dm?C0P3IfMT20=[JfP040=GE
e@3GemL0emOG0=[JfP80emOG00D0eMGE0=KFeP3Fe]H0e]KF0=_Kf`020=KFeP040=WIf@3Kfm/0fm_K
0=KFeP80e=CD00D0]KFe0:n_[`2<S8`0S8b<07moO`0207EeM@0407=cL`1MGEd0GEeM065QH@80I6AT
00D0ATI60861P@2NWYh0WYjN0:NWY`020:^[Z`050:b/[02a/K40/K6a0:^[Z`2`/;000P2][Jd0102^
[Zh0/;2`0;2`/02`/;020:n_[`050;:b/P2`/;00/;2`0:j^[P2`/;000P2][Jd00`2WYjL0Xj>S0:>S
X`030:FUY@<0Y:BT00D0VYZJ08n?S`2;Rh/0Rh^;0:>SX`0209ZJVP0508F5Q@27QhL0QhN708^;R`25
QHD00P1nOWh0101WIfL0O7al07alO01eMGD207AdM00507MgM`1dM7@0M7Ad071`L02:RXX00P2CTi<0
102;Rh/0RHV908V9R@2BTY8209>CT`0409^KV`2>SXh0SXj>09FEU@<0UYJF00@0YjNW0:FUY@2UYJD0
];Bd0P36a/H00`31`L40aLG50<o?c`020<o?c`80c/k>00@0dM7A0<c<c03<c<`0c/k>0P3Cdm<00`3V
i^H0oooo0?ooo`0R0?ooo`030??cl`3emOD0j^[Z0080k>c/00H0jn_[0>g]k@3]kNd0l?3`0?;blP3^
k^h30?;blP050??cl`3^k^h0k>c/0?3`l03clo<00P3_knl01`3]kNd0k>c/0?3`l03clo<0kno_0?;b
lP3clo<00P3`l?006P3bl_80l?3`0>_[j`3Vi^H0inOW0;Zj^P2RXZ80Rh^;08F5Q@1eMGD0M7Ad079b
LP1NGUh0CTi>04e=C@17AdL0CDe=04Y:BP0/;2`0J6QX0;no_`30`<00`/;20<O7a`34a<@0`L710P32
`/801@2n_[h0`l?30<30`02n_[h0`<300080`/;200h0_kno0;jn_P30`<00`<300;jn_P2o_kl0`L71
0;jn_P2m_Kd0_;bl0;jn_P2j^[X0]KFe0;bl_0<0][Jf01L0]KFe0:f][@2XZ:P0WIfM09nOW`2WYjL0
][Jf0<;2`P2c/k<0V9RH09VIV@2QXJ40Xj>S09jNWP2ATI40PX:207AdM01_Kfl0P82008>3P`1fMWH0
M7Ad07UiN@0308F5Q@0L09RHV02QXJ40X:2P09ZJVP2CTi<0RXZ:09^KV`2/[:`0Xj>S0;2`/02SXj<0
/K6a0;:b/P2ZZZX0/[:b0;jn_P33`l<0a<C40<;2`P39bLT0d];B0=_Kf`3WinL0j>SX0>k^kP3dm?@0
lO7a0>g]k@80m?Cd00H0lO7a0>g]k@3/k>`0l?3`0?Win@3emODW0?ooo`009@3oool0103YjNT0dm?C
0=?Cd`3EeMD20=OGe`040=SHf03IfMT0fMWI0=WIf@80dm?C0P3IfMT20=[JfP040=GEe@3GemL0emOG
0=[JfP80emOG00D0eMGE0=KFeP3Fe]H0e]KF0=_Kf`020=KFeP040=WIf@3Kfm/0fm_K0=KFeP80e=CD
00D0]KFe0:n_[`2<S8`0S8b<07moO`0207EeM@0407=cL`1MGEd0GEeM065QH@80I6AT00D0ATI60861
P@2NWYh0WYjN0:NWY`020:^[Z`050:b/[02a/K40/K6a0:^[Z`2`/;000P2][Jd0102^[Zh0/;2`0;2`
/02`/;020:n_[`050;:b/P2`/;00/;2`0:j^[P2`/;000P2][Jd00`2WYjL0Xj>S0:>SX`030:FUY@<0
Y:BT00D0VYZJ08n?S`2;Rh/0Rh^;0:>SX`0209ZJVP0508F5Q@27QhL0QhN708^;R`25QHD00P1nOWh0
101WIfL0O7al07alO01eMGD207AdM00507MgM`1dM7@0M7Ad071`L02:RXX00P2CTi<0102;Rh/0RHV9
08V9R@2BTY8209>CT`0409^KV`2>SXh0SXj>09FEU@<0UYJF00@0YjNW0:FUY@2UYJD0];Bd0P36a/H0
0`31`L40aLG50<o?c`020<o?c`80c/k>00@0dM7A0<c<c03<c<`0c/k>0P3Cdm<00`3Vi^H0oooo0?oo
o`0R0?ooo`030??cl`3`l?00k>c/0080jn_[1@3`l?002P3_knl0lO7a0?;blP3bl_80lo?c0?7al@3]
kNd0k^k^0??cl`3bl_820>o_k`050>k^kP3alO40lo?c0?;blP3emOD00P3_knl06@3clo<0m_Kf0?Cd
m03/k>`0i^KV0>?Sh`2_[jl0XZ:R08V9R@1kNg/0M7Ad06][J`1UIFD0EEEE04Y:BP1BDU80FEUI05QH
F015ADD08b<S06YZJP35aLD0_[jn0<C4a033`l<01032`/800`2o_kl0`/;20;no_`020;jn_P030;fm
_@2l_;`0_[jn00<0_[jn01H0_Kfm0;bl_02k^k/0`<300;bl_02k^k/0^;Rh0;>c/`2d];@0]KFe0;Jf
]P2d];@0/k>c0;Bd]02WYjL0XZ:R09VIV@2GUiL0Z:RX0;Ng]`2][Jd0UiNG0P2CTi<02@2FUYH0UIFE
08^;R`20P800NGUi06QXJ01cLg<0QhN708J6QP0207alO080NWYj00<0OGem08R8R02HV9P00P2PX:02
09VIV@0;09jNWP2UYJD0YJFU0:6QX@2UYJD0X:2P09jNWP2WYjL0/K6a0;:b/P2f][H00`35aLD02@3@
d=00h^;R0>g]k@3WinL0j^[Z0?3`l03clo<0lO7a0?3`l0020??cl`80k^k^0P3]kNd00`3inOT0m?Cd
0?ooo`0V0?ooo`009@3oool0103YjNT0f=SH0=SHf03De=@30=SHf080e]KF00D0eMGE0=[JfP3Jf]X0
eMGE0=WIf@030=[JfPD0e]KF00D0f=SH0=_Kf`3GemL0emOG0=cLg0020=SHf0040=gMg@3Lg=`0g=cL
0=GEe@80c<c<00D0[Zj^0:>SX`2BTY80TY:B08F5Q@0208:2PP0405iNGP1OGel0GemO06UYJ@80GEeM
00D0CDe=08j>SP2NWYh0WYjN0;2`/0020:NWY`050:f][@2^[Zh0[Zj^0;6a/@2`/;000P2_[jl0102a
/K40[:b/0:b/[02^[Zh20;2`/0@0YjNW00@0[Zj^0:FUY@2UYJD0YZJV0P2TY:@0102UYJD0WIfM09fM
W@2MWId209FEU@0508n?S`28R8P0Shn?08n?S`2CTi<00P29RHT01@28R8P0QXJ608J6QP25QHD0KVi^
0080L71`00@0Lg=c08>3P`23Ph<0QHF50P23Ph<01@1bLW80Q8B408B4Q020P800QhN70080RHV900@0
SHf=0:JVYP2VYZH0UYJF1@2@T9001@2?Shl0YZJV0:VYZ@2YZJT0[:b/0080/K6a00D0^[Zj0<30`030
`<00a<C40<G5a@020<S8b0040<W9b@3AdM40dM7A0<g=c@80e=CD0`3EeMD00`3WinL0oooo0?ooo`0R
0?ooo`0<0??cl`3emOD0k^k^0>[ZjP3[jn/0l?3`0>o_k`3/k>`0kno_0>k^kP3_knl0k^k^0P3bl_82
0??cl`030?3`l03^k^h0k^k^00<0kno_00L0l_;b0?Gem@3clo<0lO7a0?Cdm03_knl0l_;b0080mOGe
01`0lo?c0>c/k03UiND0f][J0:RXZ02KVi/0S8b<0820P01eMGD0LW9b05eMG@1;Bd/0CTi>05YJFP1L
G5`0DE5A03lo?`0`<300MgMg0<C4a030`<00bLW90<C4a02m_Kd0`<300<?3``30`<00`L710P2n_[h2
0;no_`050;Zj^P2f][H0_;bl0;fm_@2h^;P00`2e]KD00`2g]kL0_Kfm0;Fe]@020;Fe]@0@0;>c/`2d
];@0][Jf0:n_[`2^[Zh0[jn_0:^[Z`2RXZ80TY:B09JFUP2LW9`0Xj>S0:BTY02JVYX0TI6A09:BTP80
TI6A00`0S8b<07alO01_Kfl0M7Ad07=cL`1eMGD0SHf=09>CT`2;Rh/0QXJ607YjNP1hN7P208j>SP0P
09BDU02GUiL0VYZJ09jNWP2^[Zh0[jn_0:RXZ02UYJD0WIfM09nOW`2PX:00WinO0::RXP2c/k<0a<C4
0<O7a`3<c<`0alO70=;BdP3Ng]h0h^;R0>SXj03[jn/0jNWY0>g]k@3/k>`0k^k^0?Cdm03clo<0kno_
0?7al@3bl_820?7al@030?Shn03dm?@0oooo02H0oooo000U0?ooo`040>WYj@3EeMD0eMGE0=SHf080
fMWI0`3Fe]H00`3Jf]X0e]KF0=KFeP020=WIf@80f][J00@0emOG0=WIf@3IfMT0emOG0P3Kfm/00`3J
f]X0f=SH0=SHf0020=SHf080f][J00@0emOG0=SHf03Hf=P0emOG0P3;bl/01@2][Jd0WinO08n?S`2?
Shl0PH610080PX:200@0JFUY07=cL`1cLg<0J6QX0P14A4@0101:BTX0RXZ:0:2PX02PX:030:JVYP04
0:b/[02b/[80/[:b0:NWY`<0[:b/00@0YjNW0:ZZZP2ZZZX0YZJV0P2ZZZX01@2WYjL0YJFU0:FUY@2W
YjL0X:2P0080YZJV00@0XJ6Q09jNWP2NWYh0WIfM0P2NWYh309JFUP0508b<S027QhL0UIFE09FEU@20
P8000P1fMWH01@1lO7`0MWIf07IfMP1`L700MWIf0080KVi^00@0Lg=c07emO@1mOGd0S8b<0P29RHT0
1@22PX80OWin07inOP1kNg/0PX:20080Q8B400@0R8R80::RXP2RXZ80XJ6Q0P2BTY801@2DU9@0XJ6Q
0:6QX@2@T900YJFU0080Y:BT00@0/k>c0;no_`2o_kl0`l?30P30`<001035aLD0alO70<S8b038b<P4
0<o?c`80c/k>00@0clo?0=7Ad@3AdM40iNGU903oool01P3clo<0l_;b0>g]k@3^k^h0kno_0>k^kP80
jn_[00@0kno_0?7al@3^k^h0lO7a0P3bl_80103clo<0l?3`0?3`l03alO420>k^kP050?;blP3clo<0
lO7a0?;blP3clo<00`3`l?020?7al@0M0?3`l03_knl0k>c/0>GUi@3Hf=P0Y:BT09JFUP28R8P0Ng]k
07=cL`1aLG40Hf=S05EEE@1NGUh0JVYZ05IFEP0l?3`0=CDe02`/;01dM7@0aLG50;jn_P32`/80^;Rh
0;bl_032`/80a<C40;no_`2f][H00P2l_;`01@2h^;P0][Jf0;Fe]@2d];@0/k>c0080]KFe00L0/k>c
0;6a/@2c/k<0];Bd0;2`/02d];@0/K6a00<0[jn_00P0/;2`0:j^[P2^[Zh0ZJVY0:JVYP2LW9`0UIFE
096AT@80X:2P00X0TY:B08F5Q@21PH40Rh^;08F5Q@27QhL0NWYj07=cL`1kNg/0N7Qh0P1gMgL06`25
QHD0U9BD09NGU`2=SHd0P82008N7Q`2:RXX0TI6A08n?S`28R8P0V9RH09jNWP2_[jl0]KFe0;>c/`2/
[:`0WIfM09nOW`2][Jd0Y:BT0:2PX02c/k<0aLG50<K6aP3<c<`0eMGE0>7Qh@020>[ZjP060>OWi`3[
jn/0jn_[0>g]k@3_knl0l_;b0P3clo<01`3^k^h0k>c/0>g]k@3]kNd0jn_[0?Gem@3dm?@09`3oool0
02D0oooo00@0jNWY0=GEe@3EeMD0f=SH0P3IfMT30=KFeP030=[JfP3Fe]H0e]KF0080fMWI0P3Jf]X0
103GemL0fMWI0=WIf@3GemL20=_Kf`030=[JfP3Hf=P0f=SH0080f=SH0P3Jf]X0103GemL0f=SH0=SH
f03GemL20<_;b`050:f][@2OWil0Shn?08n?S`21PH400P22PX80101YJFT0Lg=c07=cL`1XJ6P204A4
A00404Y:BP2:RXX0X:2P0:2PX0<0YZJV00@0[:b/0;:b/P2b/[80YjNW0`2/[:`0102WYjL0ZZZZ0:ZZ
ZP2VYZH20:ZZZP050:NWY`2UYJD0YJFU0:NWY`2PX:000P2VYZH0102QXJ40WYjN09jNWP2MWId209jN
WP<0UYJF00D0S8b<08N7Q`2EUID0UIFE0820P00207IfMP0507alO01fMWH0MWIf071`L01fMWH00P1^
KVh0101cLg<0OGem07emO@2<S8`208V9R@0508:2PP1nOWh0OWin07]kN`22PX800P24Q8@01028R8P0
XZ:R0::RXP2QXJ4209:BTP0509BDU02QXJ40XJ6Q092@T02UYJD00P2TY:@0102c/k<0_kno0;no_`33
`l<20<30`0040<G5a@37alL0b<S80<S8b0@0clo?0P3>c/h0103?cll0dM7A0=7Ad@3UiNDT0?ooo`03
0??cl`3emOD0k^k^0080kNg]00L0kno_0>k^kP3[jn/0l?3`0?;blP3alO40kno_0080l_;b00@0lo?c
0?;blP3bl_80lo?c0P3bl_804`3clo<0m?Cd0?7al@3alO40lo?c0>o_k`3`l?00lo?c0?3`l03]kNd0
kno_0??cl`3bl_80iNGU0<k>cP2SXj<0VYZJ08V9R@1jNWX00P1bLW806@1NGUh0FUYJ06=SH`1LG5`0
BDU9030`<00d=3@0:b/[079bLP35aLD0`L710<30`02m_Kd0_kno0;jn_P30`<00`L710;Vi^@2k^k/0
^;Rh0;>c/`2b/[80];Bd0;6a/@2][Jd0102`/;000`2^[Zh0[jn_0:b/[0020;:b/P060:n_[`2/[:`0
ZJVY0:RXZ02][Jd0ZZZZ0P2VYZH04P2JVYX0TY:B09RHV02MWId0Ti>C08B4Q01mOGd0OWin07alO01j
NWX0L71`06e]K@1dM7@0Lg=c06MWI`1^KVh0MgMg08^;R`80VIVI01`0V9RH09NGU`2=SHd0RHV908F5
Q@29RHT0Ti>C09bLW02FUYH0ZJVY0;Fe]@2b/[80YZJV09jNWP2][Jd0][Jf0:ZZZP2YZJT0^KVi0<?3
``35aLD0eMGE0=oOg`3Vi^H0iNGU0>?Sh`3WinL0jn_[0P3^k^h01`3alO40l_;b0?3`l03clo<0lO7a
0?3`l03^k^h00P3/k>`00`3gmoL0l_;b0?ooo`0V0?ooo`009@3oool0103YjNT0f=SH0=SHf03Hf=P2
0=KFeP040=OGe`3Hf=P0f=SH0=GEe@80fm_K00@0fMWI0=[JfP3GemL0emOG0`3Jf]X30=_Kf`050=SH
f03Kfm/0f=SH0=SHf03EeMD00P3Hf=P0103IfMT0f][J0=[JfP3IfMT20<?3``050:BTY02KVi/0SHf=
08f=S@1lO7`00P1gMgL0101WIfL0L71`071`L01NGUh204e=C@0505ADE02<S8`0W9bL09bLW02YZJT0
0P2ZZZX30:VYZ@050:n_[`2[Zj/0ZZZZ0:ZZZP2WYjL00P2VYZH0102UYJD0XJ6Q0:6QX@2QXJ420::R
XP0509nOW`2SXj<0Xj>S0:>SX`2MWId00P2LW9`309VIV@0509RHV02=SHd0SHf=08R8R02>SXh00P27
QhL0101fMWH0LW9b079bLP1_Kfl206][J`05075aL@1/K6`0HF5Q065QH@1^KVh00P1nOWh0102<S8`0
QHF508F5Q@2:RXX208B4Q00507IfMP1gMgL0Ogmo07moO`2>SXh00`2IVIT209ZJVP050::RXP2CTi<0
Ti>C09RHV02TY:@00P2XZ:P0102k^k/0_[jn0;jn_P32`/830<C4a0030<c<c039bLT0bLW900<0clo?
00@0dM7A0=;BdP3Bd]80d=3@0P3EeMD00`3QhN40oooo0?ooo`0R0?ooo`040??cl`3gmoL0kno_0>k^
kP80kNg]0`3^k^h00`3]kNd0kno_0?3`l0020?;blP030?3`l03bl_80lo?c0080lo?c0P3dm?@01`3b
l_80lO7a0??cl`3clo<0k^k^0>g]k@3alO400P3^k^h30?;blP0_0>[ZjP30`<00WIfM09JFUP25QHD0
Kfm_06i^KP1YJFT0F5QH05aLG01RHV80DE5A04A4A00f=SH0?Cdm038b<P1dM7@0`l?30;^k^`31`L40
_kno0<30`02m_Kd0^KVi0;bl_02m_Kd0][Jf0;Fe]@2a/K40/;2`0:n_[`2][Jd0Zj^[0:VYZ@2XZ:P0
Zj^[0:b/[02XZ:P0ZJVY0:f][@2_[jl0/;2`0:^[Z`2WYjL0YZJV0:FUY@2XZ:P00P2VYZH05`2SXj<0
V9RH092@T02MWId0VIVI08V9R@1mOGd0N7Qh07MgM`1cLg<0L71`06e]K@1aLG40L71`06EUI@1PH600
JVYZ07IfMP29RHT0UYJF09NGU`2FUYH0W9bL0080Shn?00P0Ogmo0861P@2:RXX0UiNG09jNWP2XZ:P0
[:b/0:f][@80[:b/00X0];Bd0:^[Z`2WYjL0[Zj^0;^k^`34a<@0bl_;0=gMg@3Ph>00iNGU0P3WinL0
1`3YjNT0j>SX0?;blP3`l?00lO7a0?;blP3alO400P3clo<01P3bl_80kno_0>g]k@3`l?00nOWi0?3`
l2L0oooo000U0?ooo`040>WYj@3Cdm<0dm?C0=OGe`80eMGE00@0e]KF0=cLg03Lg=`0g=cL0P3Fe]H0
1@3De=@0fm_K0=KFeP3Fe]H0fm_K0080fMWI00D0e]KF0=GEe@3EeMD0eMGE0=WIf@020=OGe`@0gMgM
0P3De=@01@3Fe]H0^KVi0;Vi^@2WYjL0TY:B0080RXZ:00@0RHV906YZJP1ZJVX0N7Qh0P1gMgL01@1B
DU80B4Q804Q8B01>CTh0TI6A0080VYZJ00@0YZJV0:>SX`2SXj<0Zj^[0P2WYjL01@2[Zj/0YjNW0:VY
Z@2YZJT0Xj>S00<0XZ:R0P2PX:00102KVi/0U9BD09BDU02CTi<309bLW0<0VYZJ0`2ATI401@2=SHd0
S8b<08b<S026QXH0NGUi0080KVi^00@0KFe]06UYJ@1YJFT0LW9b0P1cLg<01@1^KVh0L71`071`L01`
L700M7Ad0080NGUi00@0RXZ:0::RXP2RXZ80WYjN0P2CTi<01@1ZJVX0KVi^07moO`1oOgl0PH610080
UiNG00<0WYjN09nOW`2OWil00`2=SHd01@2JVYX0[:b/0:RXZ02XZ:P0_;bl0080^k^k00D0aLG50<30
`030`<00c<c<0<g=c@020<k>cP040<o?c`3=cLd0cLg=0=3@d080d];B00@0d=3@0=;BdP3Bd]80hN7Q
903oool04P3dm?@0mOGe0>c/k03_knl0k^k^0>[ZjP3/k>`0lO7a0>o_k`3]kNd0k^k^0>o_k`3bl_80
lo?c0>k^kP3`l?00lo?c0?;blP80lO7a00D0l?3`0>k^kP3alO40lo?c0?3`l0020>k^kP040?7al@3^
k^h0lO7a0?;blP80kNg]0240i>CT0;Rh^02HV9P0S8b<07moO`1]KFd0LW9b061PH01JFUX0Hf=S06AT
I01CDe<0>c/k03@d=00k>c/0=CDe07QhN030`<00]KFe0;jn_P2h^;P0^k^k0;bl_02f][H0]KFe0;Vi
^@2`/;00/K6a0:n_[`2ZZZX0Z:RX0:ZZZP2XZ:P00P2TY:@0102SXj<0XJ6Q09nOW`2QXJ420:RXZ00:
0:VYZ@2VYZH0Y:BT0:BTY02QXJ40X:2P0::RXP2QXJ40W9bL09BDU080TI6A01D0RHV90820P01gMgL0
LG5a079bLP1dM7@0L71`07=cL`1dM7@0KFe]06MWI`1YJFT0L71`07MgM`22PX80TI6A09bLW02OWil0
X:2P0:>SX`2IVIT00P1jNWX0401oOgl0Ti>C09jNWP2VYZH0ZZZZ0:n_[`2e]KD0];Bd0:VYZ@2NWYh0
WinO0:n_[`30`<00alO70<g=c@3Ng]h20>;RhP0:0>WYj@3]kNd0jNWY0>c/k03clo<0l_;b0?7al@3c
lo<0l_;b0?3`l080l_;b00D0l?3`0>k^kP3_knl0nOWi0?3`l00W0?ooo`009@3oool0103YjNT0dm?C
0=?Cd`3GemL20=GEe@040=KFeP3Lg=`0g=cL0=cLg080e]KF00D0e=CD0=_Kf`3Fe]H0e]KF0=_Kf`02
0=WIf@050=KFeP3EeMD0eMGE0=GEe@3IfMT00P3GemL40=gMg@80e=CD00D0e]KF0;Vi^@2i^KT0YjNW
09:BTP0208Z:RP0408V9R@1ZJVX0JVYZ07QhN080MgMg00D0DU9B04Q8B018B4P0CTi>096AT@0209ZJ
VP040:JVYP2SXj<0Xj>S0:^[Z`80YjNW00D0Zj^[0:NWY`2YZJT0ZJVY0:>SX`030::RXP80X:2P00@0
Vi^K09BDU02DU9@0Ti>C0`2LW9`309ZJVP<0TI6A00D0SHf=08b<S02<S8`0QXJ607UiN@0206i^KP04
06e]K@1YJFT0JFUY079bLP80Lg=c00D0KVi^071`L01`L700L71`07AdM00207UiN@0408Z:RP2RXZ80
XZ:R09jNWP80Ti>C00D0JVYZ06i^KP1oOgl0Ogmo0861P@0209NGU`0309jNWP2OWil0WinO00<0SHf=
00D0VYZJ0:b/[02XZ:P0Z:RX0;bl_0020;^k^`050<G5a@30`<00`<300<c<c03=cLd00P3>c/h0103?
cll0cLg=0<g=c@3@d=020=;BdP040=3@d03Bd]80d];B0>7QhB@0oooo00<0l_;b0?Cdm03[jn/00P3]
kNd20>_[j`0=0>k^kP3_knl0l?3`0>o_k`3^k^h0l_;b0?3`l03_knl0l?3`0?;blP3alO40k^k^0>o_
k`020>g]k@80l_;b02@0kno_0?7al@3dm?@0lo?c0>o_k`3alO40kno_0>g]k@3Zj^X0d=3@0;Bd]02E
UID0QhN707UiN@1`L700MWIf061PH01SHf<0IVIV05iNGP1=CDd0:b/[02PX:00`<300<C4a07UiN@30
`<00];Bd0;Zj^P2f][H0^;Rh0;Vi^@2f][H0/[:b0;2`/02ZZZX20:b/[0040:JVYP2TY:@0YjNW0:>S
X`80Y:BT00X0WinO09ZJVP2IVIT0VYZJ09nOW`2PX:00Y:BT0:FUY@2SXj<0X:2P0P2LW9`0202JVYX0
UYJF09FEU@2?Shl0TY:B0820P01eMGD0LG5a0P1^KVh0:P1aLG40MgMg07UiN@1YJFT0HF5Q069RHP1V
IVH0LG5a07emO@1nOWh0QHF508n?S`2OWil0Zj^[0:VYZ@2`/;00YJFU07YjNP1kNg/0R8R809FEU@2D
U9@0W9bL0:b/[02e]KD0/[:b0:ZZZP2MWId0W9bL09ZJVP2`/;00alO70<g=c@3EeMD0gMgM0>KViP3S
hn<0iNGU0>WYj@3[jn/0m?Cd0?3`l080lo?c00X0l_;b0?3`l03_knl0lO7a0?;blP3alO40k^k^0>g]
k@3inOT0l_;b9`3oool002D0oooo00@0i>CT0=SHf03Hf=P0e]KF0P3De=@0103EeMD0e=CD0=CDe03F
e]H30=_Kf`040=OGe`3Jf]X0f][J0=KFeP80f][J00D0fm_K0=GEe@3EeMD0gMgM0=cLg0020=gMg@03
0=cLg03IfMT0fMWI00<0f=SH00D0dm?C0;6a/@2a/K40WIfM09JFUP020861P@0407YjNP1^KVh0KVi^
07inOP80HF5Q00D0Bd];04U9B@19BDT0D51@092@T00209jNWP040:RXZ02[Zj/0Zj^[0:RXZ080ZJVY
00D0Y:BT0:FUY@2TY:@0Y:BT0:FUY@020:2PX00409jNWP2QXJ40XJ6Q09bLW080VYZJ00D0UIFE09JF
UP2FUYH0UYJF09ZJVP0309:BTP80RXZ:00D0QXJ608B4Q024Q8@0O7al07EeM@02065QH@04069RHP1[
Jf/0Jf][06i^KP80K6a/00D0BTY:05EEE@1cLg<0Lg=c0820P00207moO`0408>3P`2?Shl0Shn?09>C
T`80W9bL00D0QXJ607QhN023Ph<0Ph>308j>SP0207inOP040:6QX@2BTY80TY:B08^;R`80SHf=00D0
VYZJ0:ZZZP34a<@0a<C40;Vi^@020<30`0050<71`@37alL0alO70<W9b@37alL01@3>c/h40=7Ad@80
e=CD00<0i^KV0?ooo`3oool08P3oool0103`l?00moOg0?3`l03]kNd50>_[j`0=0>g]k@3`l?00l_;b
0?7al@3/k>`0l?3`0>o_k`3`l?00lO7a0>o_k`3clo<0k^k^0?7al@030??cl`80l_;b00<0kno_0>g]
k@3^k^h00P3^k^h03@3Ti>@0`L710;6a/@2@T900QHF507=cL`1XJ6P0JVYZ061PH01YJFT0HF5Q04a<
C00o?cl00P0Y:BT03@0b<S80<30`07IfMP2n_[h0/k>c0;Rh^02i^KT0^;Rh0;Fe]@2b/[80[jn_0:ZZ
ZP2XZ:P00P2WYjL0202UYJD0XJ6Q09nOW`2OWil0XJ6Q09nOW`2NWYh0W9bL0P2HV9P209ZJVP0309fM
W@2QXJ40X:2P0080W9bL01h0VYZJ09:BTP2@T900TI6A08R8R02ATI40OWin06e]K@1UIFD0K6a/07=c
L`1]KFd0Lg=c079bLP1FEUH0A4A404];B`1PH600MgMg08B4Q028R8P0QXJ608Z:RP2EUID0XJ6Q0:RX
Z02RXZ80/;2`08Z:RP27QhL209:BTP0609bLW02DU9@0Y:BT0;Bd]02ZZZX0W9bL0P2JVYX04@2MWId0
/k>c0<S8b03Cdm<0iNGU0=kNgP3Rh^80i^KV0>OWi`3YjNT0kno_0??cl`3/k>`0lO7a0??cl`3alO40
k^k^00<0lO7a0P3^k^h00`3`l?00n?Sh0?Gem@0W0?ooo`009@3oool0103YjNT0emOG0=OGe`3Hf=P2
0=GEe@@0f=SH0P3Kfm/0103IfMT0fm_K0=WIf@3IfMT30=[JfP050=WIf@3Hf=P0f=SH0=[JfP3Lg=`0
0P3Jf]X0103Lg=`0gMgM0=gMg@3IfMT20=cLg0050<71`@2/[:`0[:b/09BDU02>SXh00P20P800101g
MgL0L71`071`L01eMGD205eMG@0505=CD`1JFUX0FUYJ05IFEP2=SHd00P2QXJ40102TY:@0Zj^[0:^[
Z`2YZJT20:BTY0050:b/[02XZ:P0YZJV0:JVYP2TY:@00P2RXZ80102HV9P0Ti>C09>CT`2BTY82092@
T00508f=S@2BTY80T92@092@T02BTY800P2=SHd0102<S8`0Q8B408B4Q023Ph<207emO@0507]kN`1b
LW80Bd];04];B`1/K6`00P1VIVH01@1IFET0BDU904U9B@1>CTh0HV9R0080PX:200@0M7Ad07YjNP1j
NWX0M7Ad0P2ATI401@2JVYX0UiNG09NGU`26QXH0Ph>300<0R8R80P2EUID0102IVIT0T92@092@T024
Q8@209BDU0050:6QX@2m_Kd0]KFe0;Fe]@2j^[X00P30`<001@39bLT0b<S80<S8b03;bl/0bLW90080
c/k>00@0clo?0<k>cP3>c/h0dM7A0P3?cll0103AdM40dm?C0=?Cd`3Ti>@T0?ooo`070?Cdm03gmoL0
kno_0?3`l03^k^h0kNg]0?3`l0040?7al@<0l_;b00P0kNg]0>c/k03`l?00l?3`0>k^kP3bl_80kno_
0?7al@80l?3`01/0l_;b0>k^kP3]kNd0k^k^0?;blP3^k^h0k>c/0>[ZjP3Fe]H0^;Rh0:j^[P26QXH0
NWYj071`L01[Jf/0GemO05eMG@1SHf<0Fe]K04Q8B00j>SX0<c<c03Lg=`0i>CT0=SHf07AdM02e]KD0
0`2a/K402P2c/k<0/K6a0:f][@2/[:`0[Zj^0:VYZ@2SXj<0XJ6Q0:>SX`2OWil309RHV009092@T02?
Shl0Ti>C096AT@2>SXh0V9RH09ZJVP2BTY80U9BD0080Vi^K02d0VYZJ096AT@2>SXh0Shn?092@T025
QHD0UYJF07inOP1NGUh0I6AT07=cL`1`L700JVYZ069RHP1BDU80Bd];03Xj>P18B4P0MgMg08B4Q01f
MWH0Ph>307moO`20P800T92@0::RXP2^[Zh0ZJVY0;>c/`2ATI40UiNG09^KV`2DU9@0W9bL09^KV`2Y
ZJT0ZZZZ09jNWP2JVYX0T92@09BDU02YZJT0`<300=7Ad@3Kfm/00P3Ogml03P3MgMd0i^KV0>g]k@3]
kNd0kno_0??cl`3^k^h0lO7a0??cl`3bl_80l?3`0>_[j`3`l?00k^k^0P3_knl00`3]kNd0nOWi0?Ge
m@0W0?ooo`009@3oool0103YjNT0emOG0=OGe`3Hf=P20=GEe@@0f=SH0P3Kfm/0103IfMT0fm_K0=WI
f@3IfMT30=[JfP050=WIf@3Hf=P0f=SH0=[JfP3Lg=`00P3Jf]X0103Lg=`0gMgM0=gMg@3IfMT20=cL
g0050<71`@2/[:`0[:b/09BDU02>SXh00P20P800101gMgL0L71`071`L01eMGD205eMG@0505=CD`1J
FUX0FUYJ05IFEP2=SHd00P2QXJ40102TY:@0Zj^[0:^[Z`2YZJT20:BTY0050:b/[02XZ:P0YZJV0:JV
YP2TY:@00P2RXZ80102HV9P0Ti>C09>CT`2BTY82092@T00508f=S@2BTY80T92@092@T02BTY800P2=
SHd0102<S8`0Q8B408B4Q023Ph<207emO@0507]kN`1bLW80Bd];04];B`1/K6`00P1VIVH01@1IFET0
BDU904U9B@1>CTh0HV9R0080PX:200@0M7Ad07YjNP1jNWX0M7Ad0P2ATI401@2JVYX0UiNG09NGU`26
QXH0Ph>300<0R8R80P2EUID0102IVIT0T92@092@T024Q8@209BDU0050:6QX@2m_Kd0]KFe0;Fe]@2j
^[X00P30`<001@39bLT0b<S80<S8b03;bl/0bLW90080c/k>00@0clo?0<k>cP3>c/h0dM7A0P3?cll0
103AdM40dm?C0=?Cd`3Ti>@T0?ooo`0<0?Cdm03hn?P0kNg]0>k^kP3_knl0k>c/0>g]k@3/k>`0kNg]
0>k^kP3`l?00kno_0P3bl_820?7al@0=0?;blP3`l?00k>c/0>g]k@3^k^h0kNg]0?3`l03clo<0lO7a
0>k^kP3alO40l_;b0>k^kP020>g]k@090>;RhP37alL0/;2`0:>SX`20P800N7Qh06a/K01[Jf/0I6AT
0080GUiN0140CTi>03/k>`0h>3P0=3@d03Ti>@0j>SX0=CDe079bLP2d];@0[jn_0;2`/02j^[X0]KFe
0;:b/P2_[jl0[Zj^0;6a/@020:b/[0090:VYZ@2WYjL0YJFU09fMW@2BTY80S8b<08j>SP2;Rh/0R8R8
0080Rh^;00D0SHf=08j>SP2@T900U9BD09>CT`0208n?S`0a08j>SP27QhL0QXJ608:2PP24Q8@0TI6A
07EeM@1GEeL0GUiN07=cL`1^KVh0F5QH04i>CP15ADD0BDU9051@D01LG5`0M7Ad08R8R024Q8@0P820
08>3P`1mOGd0QHF50:6QX@2YZJT0/K6a0:NWY`2FUYH0Ti>C09NGU`2EUID0U9BD0:JVYP2b/[80Z:RX
09fMW@2QXJ40VIVI0:RXZ02`/;00_Kfm0=SHf03Xj>P0f][J0=cLg03Vi^H0j>SX0>g]k@020??cl`04
0?Cdm03_knl0lO7a0??cl`80l_;b00P0l?3`0?7al@3`l?00lO7a0>k^kP3]kNd0nOWi0?7alBL0oooo
000U0?ooo`040>CTi03IfMT0fMWI0=CDe080dM7A00@0f][J0=SHf03Hf=P0f][J0`3GemL0103Kfm/0
e]KF0=KFeP3MgMd20=[JfP050=WIf@3Jf]X0f][J0=WIf@3Ogml00P3Jf]X0103Lg=`0fMWI0=WIf@3J
f]X20=WIf@050;^k^`2VYZH0YZJV08j>SP2;Rh/00P20P8001026QXH0Jf][06][J`1bLW82059BDP05
05]KF`1MGEd0GEeM05QHF02BTY800P2d];@00`2g]kL0^k^k0;^k^`030;^k^`040;>c/`2d];@0/;2`
0;2`/0<0[jn_00<0ZJVY0:2PX02PX:000`29RHT01@2<S8`0RXZ:08B4Q024Q8@0Ph>30080Rh^;00@0
Q8B40861P@21PH40O7al0P1bLW801@1gMgL0GEeM04i>CP1>CTh0IFEU0080FUYJ00D0@d=30492@P12
@T80H61P05iNGP0207inOP0407]kN`1bLW80LW9b075aL@80SHf=00D0VIVI09fMW@2MWId0W9bL08N7
Q`0208B4Q00406i^KP2SXj<0Xj>S09VIV@80Rh^;00D0V9RH09fMW@2MWId0/[:b0<71`@020;fm_@04
0;no_`33`l<0`l?30<K6aP80bl_;00D0b/[:0<c<c03>c/h0c/k>0<g=c@020<k>cP<0dM7A00@0dm?C
0=7Ad@3AdM40gmoO903oool0303alO40moOg0>o_k`3/k>`0j>SX0>[ZjP3^k^h0jn_[0>k^kP3`l?00
kno_0>k^kP80l_;b00<0k^k^0?3`l03alO400P3_knl02@3/k>`0kNg]0>c/k03`l?00lo?c0?7al@3^
k^h0l?3`0>k^kP020>c/k00m0>_[j`3MgMd0`/;20:j^[P2KVi/0O7al07IfMP1]KFd0JFUY079bLP1M
GEd0Fe]K0451@@0^;Rh0?Cdm03Lg=`0h>3P0=CDe03/k>`1hN7P0^;Rh0;jn_P30`<00a<C40<;2`P30
`<00_kno0;bl_02g]kL0][Jf0;>c/`2`/;00[jn_0:j^[P2YZJT0XJ6Q09VIV@2<S8`0Q8B408>3P`25
QHD0QhN708J6QP24Q8@0QHF508N7Q`29RHT0S8b<08R8R026QXH0QHF50861P@1jNWX0OWin08V9R@1T
I6@0DU9B05mOG`1/K6`0HV9R04a<C00203hn?P0405UIF@1LG5`0FUYJ07=cL`80RHV901P0PH6107al
O01iNGT0QHF509bLW02XZ:P0];Bd0;2`/02RXZ80V9RH09NGU`2:RXX0P8200:BTY02f][H0Z:RX09^K
V`2QXJ40ZZZZ0;:b/P2i^KT0d=3@0>KViP3Xj>P20>;RhP060>[ZjP3[jn/0k^k^0?;blP3clo<0lO7a
0P3bl_800`3clo<0lO7a0>o_k`020?;blP80lO7a00@0l?3`0>k^kP3dm?@0k^k^9`3oool002D0oooo
00@0jNWY0=?Cd`3Cdm<0f=SH0P3Kfm/00`3Jf]X0f=SH0=SHf0040=_Kf`040=cLg03IfMT0fMWI0=kN
gP80g=cL00D0gMgM0>3Ph03Ph>00emOG0=gMg@020>3Ph0040=[JfP3Kfm/0fm_K0=kNgP80`l?300D0
[jn_09jNWP2NWYh0SXj>08N7Q`02079bLP0407AdM01oOgl0Ogmo061PH080FUYJ00D0IVIV061PH01P
H600IVIV0;Fe]@020;bl_0040<S8b030`<00`<300;no_`80_[jn00<0`l?30<;2`P2h^;P00P2h^;P2
0;Bd]0040:n_[`2[Zj/0Zj^[0:FUY@80TI6A00D0P82008N7Q`29RHT0RHV908Z:RP0207MgM`<0PX:2
00D0Ng]k07=cL`1cLg<0KFe]06=SH`0205iNGP0406m_K`19BDT0BDU90451@@80Cdm?00D0Hf=S05]K
F`1/K6`0K6a/07]kN`0206a/K004071`L022PX80PX:208b<S080W9bL00D0VYZJ09:BTP1oOgl0Ogmo
08B4Q00209NGU`0409FEU@2CTi<0Ti>C0:f][@80S8b<00D0/k>c0;Zj^P2_[jl0[jn_0;no_`030<K6
aP80b/[:0P35aLD20<W9b@040<_;b`3@d=00d=3@0<_;b`80d];B00@0dm?C0=GEe@3EeMD0inOW903o
ool01@3bl_80mOGe0>[ZjP3]kNd0l?3`00@0k^k^00l0l?3`0?;blP3bl_80l_;b0?3`l03]kNd0l?3`
0?;blP3_knl0k^k^0??cl`3alO40k>c/0>o_k`3`l?000P3^k^h20>_[j`090>g]k@3`l?00hN7Q0<G5
a@2_[jl0W9bL096AT@1hN7P0KVi^0080Hf=S00l0Fe]K06ATI01;Bd/0<C4a03Lg=`14A4@0?3`l038b
<P17AdL0PX:20;Vi^@3>c/h0clo?0=?Cd`3?cll00P3;bl/0B03:b/X0bLW90<_;b`36a/H0`L710;no
_`2m_Kd0]kNg0;Bd]02`/;00[Jf]0:VYZ@2SXj<0V9RH08^;R`23Ph<0O7al07inOP20P800PH6107mo
O`1kNg/0Ogmo08>3P`21PH40NGUi07AdM01QHF40J6QX06][J`1XJ6P0Ng]k06][J`12@T80>c/k034a
<@0n?Sh0JFUY06e]K@1OGel0JVYZ07alO02>SXh0OGem07alO01oOgl0Ph>3096AT@2NWYh0/k>c0;^k
^`2d];@0X:2P08V9R@26QXH0T92@09fMW@2OWil0X:2P0:JVYP2^[Zh0^k^k0:^[Z`32`/80h>3P0>;R
hP3Hf=P0gMgM0>WYj@3Zj^X0lO7a0??cl`80l?3`00<0kno_0>k^kP3_knl00P3^k^h20?7al@070>k^
kP3`l?00lO7a0>o_k`3^k^h0n?Sh0?Cdm00W0?ooo`009@3oool00`3UiND0e]KF0=KFeP030=OGe`04
0=KFeP3Hf=P0f=SH0=SHf080fMWI00D0g=cL0=_Kf`3GemL0emOG0=gMg@020=[JfP050=gMg@3Kfm/0
fm_K0=cLg03Ng]h00P3Lg=`0103MgMd0fm_K0=_Kf`3Kfm/20<O7a`050:JVYP2IVIT0VIVI08N7Q`1m
OGd00P21PH40101gMgL0OWin07inOP1=CDd206UYJ@0505QHF023Ph<0Ph>30;fm_@3;bl/00P3=cLd0
1038b<P0b/[:0<[:bP3<c<`20<?3``030<O7a`35aLD0`l?30080`l?30P2l_;`0102g]kL0/K6a0;6a
/@2[Zj/20:RXZ0050:6QX@26QXH0OGem07emO@1kNg/00P27QhL0101jNWX0O7al07alO01`L70206i^
KP0504m?C`1`L700@d=304=3@`1mOGd00P13@d<01@0m?Cd0<30`030`<01]KFd0FEUI0080KFe]00@0
PX:207QhN01hN7P0N7Qh0P21PH401@2CTi<0XZ:R0::RXP2YZJT0UIFE0080NWYj00@0QHF508n?S`2?
Shl0RXZ:0P2KVi/01@2IVIT0WYjN09jNWP2m_Kd0[Zj^0080`L7100@0aLG50<S8b038b<P0bl_;0P35
aLD01@3<c<`0bl_;0<c<c03<c<`0bl_;0080c<c<00@0d=3@0=7Ad@3AdM40dM7A0P3De=@00`3WinL0
oooo0?ooo`0R0?ooo`050?7al@3gmoL0k>c/0>k^kP3_knl00P3/k>`02P3`l?00jn_[0>g]k@3`l?00
l_;b0?7al@3_knl0k>c/0>o_k`3`l?020>k^kP060?7al@3^k^h0kNg]0?3`l03alO40k^k^0P3]kNd2
0>_[j`0>0>[ZjP3MgMd0`L710:JVYP2FUYH0Rh^;06e]K@1[Jf/0K6a/06=SH`1LG5`0GUiN03/k>`0_
;bl204=3@`0?03Ph>01FEUH0Shn?0;fm_@3?cll0d];B0=CDe03@d=00e=CD0<k>cP3AdM40clo?0<[:
bP3<c<`0b<S80080a/K600`0`/;20;fm_@2m_Kd0][Jf0;6a/@2/[:`0Zj^[0:VYZ@2RXZ80VIVI08:2
PP1hN7P207EeM@0N07]kN`1oOgl0N7Qh07emO@1jNWX0LG5a06e]K@1<C4`0BDU907MgM`1UIFD0NWYj
07MgM`15ADD0>CTi034a<@0/;2`0E5AD07UiN@1]KFd0G5aL07alO02BTY80OGem08R8R02<S8`0QHF5
09>CT`2TY:@0[jn_0P2o_kl06P2OWil0Ogmo08j>SP2ATI40VIVI09RHV02LW9`0Zj^[0;:b/P2a/K40
/[:b0=OGe`3Shn<0emOG0=SHf03WinL0k>c/0?3`l03alO40lo?c0?7al@3^k^h0lo?c0?;blP3alO40
l?3`0P3]kNd0203`l?00lO7a0?7al@3`l?00k^k^0>g]k@3hn?P0m?Cd9`3oool002D0oooo00<0iNGU
0=KFeP3Fe]H00`3GemL0103Fe]H0f=SH0=SHf03Hf=P20=WIf@050=cLg03Kfm/0emOG0=OGe`3MgMd0
0P3Jf]X01@3MgMd0fm_K0=_Kf`3Lg=`0g]kN0080g=cL00@0gMgM0=_Kf`3Kfm/0fm_K0P37alL01@2V
YZH0VIVI09VIV@27QhL0OGem0080PH6100@0MgMg07inOP1nOWh0CDe=0P1YJFT01@1HF5P0Ph>308>3
P`2m_Kd0bl_;0080cLg=00@0b<S80<[:bP3:b/X0c<c<0P33`l<00`37alL0aLG50<?3``020<?3``80
_;bl00@0]kNg0;6a/@2a/K40Zj^[0P2XZ:P01@2QXJ40QXJ607emO@1mOGd0Ng]k0080QhN700@0NWYj
07alO01lO7`0L71`0P1^KVh01@1?Cdl0L71`04=3@`13@d<0OGem0080@d=300D0?Cdm030`<00`<300
KFe]05UIF@0206e]K@0408:2PP1hN7P0N7Qh07QhN080PH6100D0Ti>C0::RXP2RXZ80ZJVY09FEU@02
07YjNP0408F5Q@2?Shl0Shn?08Z:RP80Vi^K00D0VIVI09jNWP2NWYh0_Kfm0:j^[P020<71`@040<G5
a@38b<P0b<S80<_;b`80aLG500D0c<c<0<_;b`3<c<`0c<c<0<_;b`020<c<c0040=3@d03AdM40dM7A
0=7Ad@80e=CD00<0inOW0?ooo`3oool08P3oool00`3dm?@0lo?c0>k^kP030?3`l080lO7a0`3/k>`2
0?;blP070?7al@3/k>`0k>c/0?3`l03alO40k^k^0>g]k@020>k^kP0M0?3`l03bl_80l_;b0?;blP3a
lO40jn_[0>KViP3Jf]X0c/k>0;Vi^@2LW9`0U9BD08>3P`1SHf<0GemO06EUI@1SHf<0Fe]K04i>CP0d
=3@0=cLg04Q8B00n?Sh0BDU90;Ng]`3Bd]80cLg=0<c<c03@d=000P3De=@0203Cdm<0e=CD0=CDe03?
cll0b/[:0<W9b@3<c<`0b<S80`35aLD02`33`l<0_;bl0;>c/`2`/;00/K6a0;2`/02YZJT0XZ:R09VI
V@1oOgl0M7Ad0080LW9b01P0MWIf075aL@1dM7@0LW9b06i^KP1YJFT0A4A404Q8B01oOgl0HV9R07Ee
M@28R8P0G5aL03hn?P15ADD0<30`0410@01cLg<0MgMg05iNGP1nOWh0RHV907inOP25QHD208n?S`0A
09:BTP2LW9`0Y:BT0;^k^`2m_Kd0Z:RX08n?S`23Ph<0SXj>09FEU@2GUiL0Y:BT0;Bd]02c/k<0/[:b
0;bl_03Bd]800P3Jf]X03@3Rh^80jn_[0>_[j`3bl_80kno_0?3`l03alO40kno_0??cl`3^k^h0kNg]
0?3`l03alO400P3]kNd01`3`l?00lO7a0?3`l03`l?00kno_0?Ogm`3dm?@09`3oool002D0oooo00@0
jNWY0=OGe`3GemL0fMWI0P3De=@30=[JfP<0fMWI00D0g=cL0=[JfP3IfMT0fMWI0=SHf0020=oOg`05
0=_Kf`3Ng]h0g]kN0=kNgP3Ph>000P3QhN40103Ogml0f][J0=[JfP3<c<`20<;2`P0509bLW02EUID0
UIFE08F5Q@1gMgL00P1lO7`0101jNWX0Hf=S06=SH`1GEeL206=SH`0506i^KP3Jf]X0f][J0<g=c@39
bLT00P3<c<`40=3@d0<0c<c<00@0b/[:0<K6aP36a/H0aLG50P33`l<0102j^[X0^;Rh0;Rh^02b/[82
0:j^[P050:NWY`2NWYh0RXZ:08Z:RP1jNWX00P1iNGT0101gMgL0M7Ad07AdM01^KVh2065QH@05055A
D@1gMgL0EUIF05IFEP1nOWh00P1ADE401@0g=cL0@4100410@01VIVH0LG5a0080MWIf00@0NWYj07=c
L`1cLg<0PH610P20P8001@2;Rh/0V9RH09RHV02VYZH0WinO0080O7al00@0Ph>307moO`1oOgl0TI6A
0P2TY:@309^KV`040;:b/P2o_kl0a<C40<C4a0<0a/K600D0bl_;0<K6aP36a/H0b/[:0<S8b0020<_;
b`040<k>cP3=cLd0cLg=0<g=c@80dM7A00@0dm?C0=;BdP3Bd]80inOW903oool0203dm?@0moOg0?3`
l03`l?00kNg]0>_[j`3`l?00lO7a0`3`l?002P3bl_80lO7a0>_[j`3/k>`0jn_[0>k^kP3bl_80l?3`
0>g]k@3alO440?;blP0;0?7al@3]kNd0jNWY0>GUi@3EeMD0aLG50;2`/02DU9@0SHf=08:2PP1WIfL0
0P1RHV802P1MGEd0FUYJ0451@@0a<C40>SXj03`l?014A4@0PH610<K6aP3Cdm<20<[:bP040<k>cP3@
d=00e=CD0=CDe080dm?C0P3Bd]80703@d=00b<S80<K6aP35aLD0a/K60<C4a02m_Kd0^;Rh0;^k^`2i
^KT0];Bd0;6a/@2_[jl0ZJVY0::RXP2?Shl0TY:B08:2PP1ZJVX0KFe]071`L01]KFd0K6a/06QXJ01N
GUh0AdM704E5A@1hN7P207emO@0V08B4Q01YJFT0=cLg02/[:`11@D40G5aL07YjNP2;Rh/0RXZ:08N7
Q`28R8P0SHf=07inOP25QHD0U9BD09>CT`2JVYX0Xj>S0:n_[`35aLD0/K6a08^;R`1mOGd0S8b<08Z:
RP2@T900YjNW0;bl_02n_[h0][Jf0;:b/P31`L40fMWI0>SXj03/k>`0kNg]0>k^kP3bl_820?3`l006
0?7al@3_knl0l_;b0>g]k@3`l?00l_;b0P3alO400`3`l?00kNg]0>o_k`020?3`l0030>k^kP3clo<0
lo?c02L0oooo000U0?ooo`040>7Qh@3GemL0emOG0=OGe`80fMWI00@0f][J0=OGe`3GemL0emOG0P3F
e]H01@3Kfm/0fMWI0=[JfP3Jf]X0f=SH0080gMgM00D0f][J0=WIf@3IfMT0h>3P0=cLg0020>;RhP04
0=cLg03IfMT0fMWI0<_;b`80/k>c00D0WYjN09>CT`2CTi<0Q8B406][J`0207=cL`0407YjNP1<C4`0
C4a<05mOG`80I6AT00@0^k^k0<W9b@39bLT0d=3@0`3?cll0103De=@0d=3@0=3@d03=cLd20<[:bP04
0=?Cd`3=cLd0bl_;0<_;b`<0b<S800@0alO70;Ng]`2g]kL0]kNg0P2b/[801@2][Jd0YZJV09^KV`2K
Vi/0TI6A0080JVYZ00@0MWIf06e]K@1]KFd0Kfm_0P1FEUH01@1;Bd/0GEeM09^KV`2KVi/0EEEE0080
NGUi00D0M7Ad038b<P0b<S80FUYJ06m_K`0205]KF`0407UiN@1mOGd0OGem07inOP80Rh^;00D0P820
08^;R`2;Rh/0YjNW0:j^[P0207=cL`0408B4Q026QXH0QXJ608n?S`<0U9BD0P2TY:@01@2k^k/0_Kfm
0<C4a034a<@0`/;20080b<S800D0a/K60<_;b`3;bl/0bLW90<O7a`020<g=c@040<S8b03=cLd0cLg=
0<_;b`80cLg=00@0dM7A0=?Cd`3Cdm<0inOW903oool0103_knl0n?Sh0>k^kP3^k^h30>o_k`060>c/
k03`l?00kno_0>g]k@3alO40kNg]0P3/k>`0103[jn/0k^k^0?7al@3^k^h20>g]k@0?0?7al@3clo<0
k^k^0>g]k@3`l?00jn_[0>SXj03Ph>00d];B0;no_`2WYjL0Ti>C08b<S01mOGd0H61P0080FEUI00T0
De=C05YJFP0d=3@0;Rh^03Xj>P10@400IVIV0;Zj^P38b<P0103=cLd02`3?cll0dm?C0<c<c03AdM40
clo?0<[:bP3>c/h0d];B0<S8b036a/H0a<C40080aLG502@0a<C40<;2`P2k^k/0^;Rh0;Ng]`2d];@0
/;2`0:j^[P2YZJT0X:2P09^KV`2ATI40NGUi06IVIP1]KFd0K6a/06=SH`1TI6@0Fe]K04=3@`0b<S80
IFEU09FEU@1gMgL0Lg=c08N7Q`1MGEd0HF5Q0492@P1NGUh0J6QX07IfMP2?Shl0MgMg08J6QP2:RXX2
08^;R`0K09:BTP2CTi<0Rh^;0:ZZZP2TY:@0c/k>0;bl_029RHT0O7al08b<S02?Shl0UiNG0:>SX`2]
[Jd0];Bd0;:b/P2i^KT0c/k>0>3Ph03WinL0jNWY0>g]k@3[jn/0k^k^0?7al@3`l?00kno_0080l_;b
00H0k>c/0?3`l03`l?00kNg]0>o_k`3alO420>c/k0050>o_k`3^k^h0k>c/0?KfmP3clo<09`3oool0
02D0oooo00@0hN7Q0=OGe`3GemL0emOG0P3IfMT0103Jf]X0emOG0=OGe`3GemL20=KFeP050=_Kf`3I
fMT0f][J0=[JfP3Hf=P00P3MgMd01@3Jf]X0fMWI0=WIf@3Ph>00g=cL0080h^;R00@0g=cL0=WIf@3I
fMT0bl_;0P2c/k<01@2NWYh0Ti>C09>CT`24Q8@0Jf][0080Lg=c00@0NWYj04a<C01<C4`0GemO0P1T
I6@0102k^k/0bLW90<W9b@3@d=030<o?c`040=CDe03@d=00d=3@0<g=c@80b/[:00@0dm?C0<g=c@3;
bl/0bl_;0`38b<P01037alL0]kNg0;Ng]`2g]kL20;:b/P050:f][@2VYZH0Vi^K09^KV`2ATI400P1Z
JVX0101fMWH0KFe]06e]K@1_Kfl205IFEP0504];B`1MGEd0Vi^K09^KV`1EEED00P1iNGT01@1dM7@0
<S8b038b<P1JFUX0Kfm_0080Fe]K00@0NGUi07emO@1mOGd0OWin0P2;Rh/01@20P800Rh^;08^;R`2W
YjL0[Zj^0080Lg=c00@0Q8B408J6QP26QXH0Shn?0`2DU9@20:BTY0050;^k^`2m_Kd0a<C40<C4a032
`/800P38b<P01@36a/H0bl_;0<_;b`39bLT0alO70080cLg=00@0b<S80<g=c@3=cLd0bl_;0P3=cLd0
103AdM40dm?C0=?Cd`3WinLT0?ooo`0=0>o_k`3hn?P0kNg]0>g]k@3`l?00lO7a0>o_k`3[jn/0k>c/
0>k^kP3_knl0lO7a0>o_k`020>c/k0030>k^kP3_knl0kno_0080l?3`0100kno_0?7al@3bl_80l?3`
0>k^kP3/k>`0i^KV0>GUi@3GemL0c/k>0;Zj^P2MWId0Shn?07moO`1iNGT0GEeM0P1HF5P02P1@D500
A4A4030`<00j>SX0@d=306MWI`2/[:`0b<S80<[:bP3=cLd20<k>cP040<c<c03;bl/0c<c<0<O7a`80
b<S800P0aLG50<S8b03:b/X0_kno0;fm_@2n_[h0`/;20<C4a080`L7100<0^[Zj0;Rh^02e]KD00P2a
/K40?@2`/;00[Zj^0:ZZZP2RXZ80VYZJ08n?S`1lO7`0IFEU05aLG01QHF40GEeM05=CD`0j>SX0=CDe
05ADE02:RXX0Ph>3079bLP26QXH0RHV905iNGP1TI6@0IVIV06ATI01aLG40PX:207emO@1jNWX0Q8B4
09:BTP23Ph<0Ogmo09:BTP2=SHd0YZJV0:>SX`2l_;`0^k^k0:NWY`28R8P0OGem08Z:RP2KVi/0WYjN
0:2PX02`/;00^[Zj0<[:bP3Ph>00hn?S0>7Qh@3Zj^X0k>c/0>[ZjP3_knl0l?3`0>k^kP3_knl0l_;b
0>o_k`3`l?000P3_knl01@3^k^h0kNg]0?7al@3_knl0k^k^0080kNg]00<0k^k^0?Shn03dm?@09`3o
ool002D0oooo00@0i>CT0=OGe`3GemL0emOG0P3IfMT0103Jf]X0e]KF0=KFeP3Jf]X20=cLg0050=gM
g@3Lg=`0f][J0=[JfP3Ng]h00P3MgMd01@3Ph>00hN7Q0>7Qh@3QhN40hn?S0080hN7Q00@0emOG0=;B
dP3Bd]80bLW90P2UYJD0102HV9P0RXZ:08Z:RP1nOWh307QhN00406ATI01LG5`0G5aL06i^KP80[jn_
0`3?cll01@3AdM40d];B0<o?c`3?cll0d=3@0080c<c<0`3=cLd01@3<c<`0a/K60<;2`P32`/80a<C4
0080aLG500@0`<300;Rh^02h^;P0]KFe0P2`/;001@2][Jd0[:b/0:>SX`2SXj<0VIVI0080V9RH00@0
JVYZ06MWI`1WIfL0G5aL0P1JFUX01@18B4P0DU9B08:2PP22PX80N7Qh0080Ogmo00D0EEEE07alO01l
O7`0G5aL06IVIP0207YjNP0406MWI`1lO7`0O7al069RHP80PH6100D0QXJ608b<S02<S8`0U9BD09^K
V`0209VIV@0406m_K`25QHD0QHF508Z:RP80Shn?00D0XJ6Q0;Zj^P2j^[X0_;bl0;no_`030<C4a080
alO700D0aLG50<_;b`3;bl/0b<S80<g=c@020<O7a`040<c<c03=cLd0cLg=0<o?c`80dM7A00@0d=3@
0=CDe03De=@0i^KV903oool0103bl_80n?Sh0>c/k03]kNd20?3`l0030>o_k`3[jn/0kNg]00<0k^k^
1`3_knl20>k^kP80kno_00`0l?3`0?;blP3]kNd0hn?S0=cLg03@d=00aLG50:j^[P2BTY80Q8B407Ee
M@1^KVh205aLG00805ADE00n?Sh0=CDe034a<@0`<300HF5Q0:VYZ@3=cLd20<[:bP@0bLW900<0aLG5
0<;2`P2m_Kd00`2i^KT20;Rh^00<0;2`/02a/K40/k>c0;Jf]P2g]kL0]KFe0;Zj^P2i^KT0]kNg0;Fe
]@2d];@0/k>c0P2`/;003P2/[:`0YJFU0:2PX02NWYh0UYJF07YjNP1UIFD0HF5Q05MGE`1?Cdl0?3`l
03/k>`1:BTX0K6a/0P29RHT01@25QHD0T92@07UiN@26QXH0NWYj0080I6AT00D0OGem08b<S01nOWh0
Q8B408F5Q@0207YjNP0@08j>SP2LW9`0WYjN0::RXP2e]KD0`/;20;fm_@2?Shl0Q8B409>CT`2LW9`0
UiNG09ZJVP2`/;00`L710=gMg@80i>CT00@0inOW0>_[j`3[jn/0jNWY0P3alO402@3^k^h0kno_0?7a
l@3[jn/0lO7a0>k^kP3]kNd0k^k^0>o_k`020?7al@060?3`l03^k^h0k^k^0?3`l03gmoL0lO7a9`3o
ool002D0oooo00@0jNWY0=KFeP3Fe]H0f=SH0P3Jf]X0103Hf=P0f][J0=[JfP3Jf]X20=_Kf`050=WI
f@3MgMd0gmoO0=oOg`3MgMd00P3Ogml00`3Lg=`0gMgM0=gMg@020>7Qh@80i>CT00@0f][J0<c<c03<
c<`0_Kfm0P2UYJD01@2>SXh0R8R808R8R01dM7@0O7al0080Kfm_00@0GEeM065QH@1QHF40WYjN0P3H
f=P0103Bd]80dM7A0=7Ad@3=cLd30=3@d0040<S8b034a<@0a<C40<30`0<0^k^k00@0^;Rh0;Vi^@2i
^KT0_Kfm0P2g]kL0102j^[X0/k>c0;>c/`2i^KT20;Ng]`050:f][@2/[:`0Y:BT0:BTY02OWil00P2I
VIT00`2BTY80Kfm_06m_K`0305UIF@0504Y:BP19BDT0H61P061PH02ATI400P1VIVH01@2FUYH0Kfm_
06m_K`1cLg<0G5aL0080LG5a00@0OGem06][J`1[Jf/0NWYj0P1`L7001@2<S8`0SHf=08f=S@2?Shl0
X:2P0080VIVI00@0RXZ:08n?S`2?Shl0R8R80P2?Shl01@2NWYh0aLG50<G5a@2m_Kd0`/;20080aLG5
00@0a/K60<W9b@39bLT0b<S80P37alL01@38b<P0bl_;0<O7a`37alL0c<c<0080cLg=00@0clo?0=7A
d@3AdM40dm?C0P3De=@00`3Ti>@0oooo0?ooo`0R0?ooo`0@0?Cdm03fm_H0k>c/0>k^kP3`l?00kno_
0>k^kP3]kNd0l?3`0>k^kP3]kNd0k>c/0>k^kP3alO40l_;b0>o_k`80l?3`01l0k>c/0>_[j`3[jn/0
kNg]0>k^kP3_knl0l?3`0>k^kP3Shn<0eMGE0<g=c@2m_Kd0YJFU08f=S@1kNg/0MgMg06QXJ01HF5P0
G5aL04a<C00^;Rh0=CDe03Ti>@1ADE40Vi^K0=3@d03:b/X0c/k>0<[:bP35aLD0`l?30080aLG50140
`<300;Rh^02c/k<0[Jf]0:VYZ@2VYZH0Xj>S0:BTY02QXJ40Xj>S0:VYZ@2ZZZX0ZJVY0:f][@2b/[80
/K6a0;Fe]@020;Rh^00X0;Jf]P2_[jl0[jn_0:^[Z`2WYjL0Xj>S0:6QX@2MWId0UIFE0861P@1RHV80
DE5A04i>CP0m?Cd0=3@d0410@01IFET0QhN709RHV01nOWh0NGUi0:RXZ02?Shl0S8b<07AdM01PH600
M7Ad08J6QP2=SHd0RHV907YjNP1oOgl0QhN708^;R`2UYJD0Vi^K0:FUY@2b/[80a<C40<71`@80Vi^K
00/0XJ6Q09jNWP2HV9P0WIfM0:n_[`31`L40i>CT0>?Sh`3Vi^H0kNg]0>_[j`020>g]k@0<0?3`l03b
l_80lO7a0>o_k`3^k^h0kNg]0?7al@3^k^h0k>c/0>o_k`3`l?00kno_1@3`l?000`3gmoL0lO7a0?oo
o`0V0?ooo`009@3oool0103YjNT0e]KF0=KFeP3Hf=P20=[JfP040=SHf03Jf]X0f][J0=[JfP80fm_K
00D0fMWI0=gMg@3Ogml0gmoO0=gMg@020=oOg`030=cLg03MgMd0gMgM0080hN7Q0P3Ti>@0103Jf]X0
c<c<0<c<c02m_Kd20:FUY@0508j>SP28R8P0R8R807AdM01lO7`00P1_Kfl0101MGEd0HF5Q065QH@2N
WYh20=SHf0040=;BdP3AdM40dM7A0<g=c@<0d=3@00@0b<S80<C4a034a<@0`<300`2k^k/0102h^;P0
^KVi0;Vi^@2m_Kd20;Ng]`040;Zj^P2c/k<0/k>c0;Vi^@80]kNg00D0[Jf]0:b/[02TY:@0Y:BT09nO
W`0209VIV@0309:BTP1_Kfl0Kfm_00<0FEUI00D0BTY:04U9B@1PH600H61P096AT@0206IVIP0509JF
UP1_Kfl0Kfm_07=cL`1LG5`00P1aLG40101mOGd0Jf][06][J`1jNWX2071`L00508b<S02=SHd0SHf=
08n?S`2PX:000P2IVIT0102:RXX0Shn?08n?S`28R8P208n?S`0509jNWP35aLD0aLG50;fm_@32`/80
0P35aLD01036a/H0bLW90<W9b@38b<P20<O7a`050<S8b03;bl/0alO70<O7a`3<c<`00P3=cLd0103?
cll0dM7A0=7Ad@3Cdm<20=CDe0030>CTi03oool0oooo0280oooo00<0lo?c0?;blP3]kNd00P3_knl0
0`3]kNd0k>c/0?3`l0020?3`l0030?7al@3]kNd0lO7a00<0lO7a00<0l_;b0?3`l03]kNd00P3/k>`0
5P3^k^h0lO7a0>o_k`3/k>`0jNWY0=oOg`3Bd]80cLg=0;Vi^@2NWYh0R8R807IfMP1cLg<0K6a/059B
DP1CDe<0@d=3038b<P0e=CD0?Shn09RHV03>c/h20<[:bP030<_;b`38b<P0aLG50080a<C400L0^[Zj
0:VYZ@2OWil0X:2P09fMW@2JVYX0UiNG0080U9BD0480UIFE096AT@2EUID0V9RH09JFUP2NWYh0ZJVY
0:ZZZP2`/;00][Jf0;Rh^02g]kL0/K6a0;2`/02/[:`0ZJVY0:FUY@2OWil0VYZJ09RHV02=SHd0L71`
055AD@15ADD0=3@d02HV9P0e=CD0E5AD08:2PP2BTY80N7Qh075aL@2TY:@0V9RH09VIV@2GUiL0PX:2
07=cL`1kNg/0SXj>08Z:RP24Q8@0QXJ608F5Q@28R8P0WinO09fMW@2VYZH0ZZZZ0;Vi^@34a<@0/k>c
0:FUY@2SXj<0XJ6Q09nOW`2XZ:P0]KFe0<?3``3Kfm/0i>CT0>WYj@3[jn/0jNWY0>g]k@3`l?020>o_
k`070?7al@3_knl0k>c/0?3`l03alO40kno_0>k^kP020?3`l0040>g]k@3^k^h0l?3`0?3`l080kno_
00<0n?Sh0?Cdm03oool09P3oool002D0oooo00@0j^[Z0=GEe@3EeMD0f][J0P3Fe]H0103Jf]X0fm_K
0=_Kf`3Lg=`20=kNgP050=[JfP3Ogml0gmoO0=oOg`3Ph>000P3QhN401@3Ogml0g]kN0=kNgP3Ph>00
hn?S0080hN7Q00@0d=3@0<g=c@3=cLd0^;Rh0P2HV9P01@2<S8`0QXJ608J6QP1gMgL0M7Ad00<0IFEU
0P1IFET0103Kfm/0cLg=0<g=c@3?cll20<k>cP050=;BdP3De=@0Zj^[0:^[Z`2QXJ400P2/[:`01@2d
];@0][Jf0;Jf]P2c/k<0];Bd0080XJ6Q00@0WinO09RHV02HV9P0[:b/0`2e]KD20;Ng]`050;Bd]02/
[:`0Z:RX0:RXZ02OWil00P2KVi/0102BTY80RHV908V9R@1GEeL204a<C080@D510P1MGEd01024Q8@0
O7al07alO023Ph<209>CT`0508V9R@21PH40LW9b079bLP1aLG400P1nOWh306a/K00508B4Q022PX80
PX:209JFUP2DU9@00P2RXZ80102<S8`0VIVI09VIV@26QXH209^KV`050:NWY`2e]KD0]KFe0<30`02n
_[h00P32`/840<K6aP<0bLW900@0bl_;0<c<c03<c<`0b/[:0P3>c/h0103<c<`0dM7A0=7Ad@3AdM42
0=;BdP030>KViP3oool0oooo0280oooo00L0lo?c0?7al@3/k>`0kno_0>g]k@3/k>`0kno_00<0l?3`
00<0lO7a0>g]k@3alO400P3alO401@3`l?00lO7a0?7al@3`l?00k>c/0080jn_[01D0kno_0?3`l03/
k>`0iNGU0=GEe@3>c/h0bl_;0;6a/@2>SXh0Ng]k079bLP1UIFD0J6QX04i>CP14A4@0=cLg03Hf=P0j
>SX0BTY:09jNWP3<c<`00P35aLD30<C4a00=0<71`@2k^k/0Xj>S07moO`1jNWX0RXZ:08j>SP2?Shl0
T92@096AT@2CTi<0TY:B0861P@0207YjNP0607QhN01mOGd0VIVI0:ZZZP2^[Zh0/[:b0`2g]kL0B02a
/K40[jn_0:f][@2VYZH0XZ:R0:2PX02HV9P0SXj>08b<S01WIfL0@d=302l_;`0S8b<0<30`04];B`1U
IFD0RXZ:09nOW`2;Rh/0SHf=0:ZZZP2RXZ80WinO0:>SX`2FUYH0QXJ607moO`2;Rh/0T92@0861P@1f
MWH0PH6109:BTP2QXJ40UYJF0;:b/P2f][H0`l?30<71`@2UYJD0YjNW0:2PX02JVYX0Zj^[0<71`@3>
c/h0e]KF0>7Qh@3YjNT0j>SX0>KViP3Zj^X0k>c/0?3`l03]kNd0jn_[0>o_k`3`l?00kNg]0?7al@3`
l?00k^k^0>g]k@3`l?00kno_0>c/k03^k^h0l?3`0>g]k@3/k>`0n?Sh0?Cdm2L0oooo000U0?ooo`04
0>[ZjP3EeMD0eMGE0=KFeP80f][J00@0e]KF0=cLg03Lg=`0gMgM0P3Ogml01@3Kfm/0h>3P0=cLg03L
g=`0fm_K0080hn?S00D0h>3P0>GUi@3UiND0iNGU0>CTi0020=oOg`040=WIf@3;bl/0bl_;0:b/[080
U9BD00D0QhN70861P@21PH40L71`07emO@0206e]K@0406MWI`3Ti>@0i>CT0=7Ad@80d=3@00D0clo?
0=?Cd`3Cdm<0b<S80:b/[0020;Fe]@040<;2`P3_knl0kno_0<k>cP80bLW900D0gMgM0<g=c@2n_[h0
_[jn0;6a/@020:FUY@0309:BTP2/[:`0[:b/00<0];Bd00D0][Jf0:b/[02ZZZX0ZZZZ0:FUY@0209bL
W00409:BTP2;Rh/0Rh^;08J6QP80DE5A00D0>CTi03De=@1XJ6P0J6QX03dm?@020:BTY00505eMG@2K
Vi/0Vi^K07MgM`2GUiL00P1kNg/0101oOgl0LG5a075aL@1jNWX207=cL`0507moO`23Ph<0Ph>308V9
R@2EUID00P2VYZH01025QHD0LG5a075aL@26QXH208f=S@050;no_`2n_[h0_[jn0<71`@2l_;`00P3;
bl/01037alL0`l?30<?3``34a<@20<W9b@050<S8b037alL0alO70<O7a`3=cLd00P3;bl/0103?cll0
d=3@0=3@d03=cLd20=?Cd`030>7Qh@3oool0oooo0280oooo00<0lo?c0?;blP3]kNd00P3/k>`00`3^
k^h0k>c/0>o_k`030?3`l00P0>g]k@3alO40lO7a0>g]k@3[jn/0k^k^0?7al@3`l?00k>c/0?3`l03a
lO40kNg]0>k^kP3]kNd0h^;R0=SHf03Cdm<0^[Zj0:6QX@29RHT0MGEe06][J`1SHf<0GUiN04e=C@19
BDT0>c/k03De=@15ADD0Xj>S0<S8b035aLD20<C4a00I0<?3``37alL0aLG50:^[Z`2EUID0Shn?08R8
R02<S8`0/k>c0;Jf]P2PX:00U9BD09^KV`2ZZZX0UYJF08b<S028R8P0QHF508:2PP1lO7`0OGem09VI
V@2ZZZX0[jn_0;:b/P020;Rh^00a0;6a/@2_[jl0/;2`0:^[Z`2UYJD0X:2P09RHV02DU9@0SXj>08>3
P`1TI6@0:BTY02LW9`0U9BD0AdM703hn?P1SHf<0/k>c0:BTY01aLG40Xj>S09JFUP2IVIT0/[:b0:VY
Z@2@T900S8b<09NGU`1oOgl0O7al08N7Q`24Q8@0T92@09VIV@2JVYX0Zj^[0;Ng]`36a/H0alO70:2P
X02=SHd0TY:B09bLW02UYJD0^KVi0>7Qh@3UiND0j>SX0>[ZjP020>OWi`80lO7a0`3/k>`0403^k^h0
l?3`0>c/k03^k^h0k>c/0>k^kP3`l?00kno_0>c/k03_knl0l?3`0>g]k@3[jn/0k>c/0?Shn03`l?0W
0?ooo`009@3oool0103Zj^X0eMGE0=GEe@3Fe]H20=[JfP040=KFeP3Lg=`0g=cL0=gMg@80gmoO00D0
fm_K0>3Ph03Lg=`0g=cL0=_Kf`020>?Sh`050>3Ph03UiND0iNGU0>GUi@3Ti>@00P3Ogml0103IfMT0
bl_;0<_;b`2/[:`209BDU00508N7Q`21PH40PH61071`L01mOGd00P1]KFd0101WIfL0i>CT0>CTi03A
dM420=3@d0050<o?c`3Cdm<0dm?C0<S8b02/[:`00P2e]KD01032`/80kno_0>o_k`3>c/h20<W9b@05
0=gMg@3=cLd0_[jn0;jn_P2a/K400P2UYJD00`2BTY80[:b/0:b/[0030;Bd]0050;Jf]P2/[:`0ZZZZ
0:ZZZP2UYJD00P2LW9`0102BTY80Rh^;08^;R`26QXH2055AD@0503Ti>@0e=CD0J6QX06QXJ00m?Cd0
0P2TY:@01@1MGEd0Vi^K09^KV`1gMgL0UiNG0080Ng]k00@0Ogmo075aL@1aLG40NWYj0P1cLg<01@1o
Ogl0Ph>308>3P`29RHT0UIFE0080YZJV00@0QHF5075aL@1aLG40QXJ60P2=SHd01@2o_kl0_[jn0;jn
_P31`L40_;bl0080bl_;00@0alO70<?3``33`l<0a<C40P39bLT01@38b<P0alO70<O7a`37alL0cLg=
0080bl_;00@0clo?0=3@d03@d=00cLg=0P3Cdm<00`3QhN40oooo0?ooo`0R0?ooo`0<0?3`l03fm_H0
k>c/0>c/k03]kNd0k>c/0>k^kP3/k>`0kno_0>k^kP3/k>`0kno_0P3]kNd0803/k>`0jn_[0>c/k03]
kNd0k>c/0>_[j`3alO40l_;b0>g]k@3^k^h0j^[Z0=OGe`3>c/h0^[Zj0::RXP2@T900Ph>306m_K`1I
FET0G5aL05=CD`13@d<0=3@d03Hf=P0j>SX0K6a/0;jn_P3AdM40b/[:0<S8b034a<@0`l?30P35aLD0
302PX:00R8R808j>SP2>SXh0S8b<09>CT`2DU9@0SHf=08j>SP2@T900RHV907UiN@80MgMg00P0QHF5
09:BTP20P800OGem07QhN02HV9P0/;2`0;Bd]080]kNg0P2f][H0<`2c/k<0[:b/0:FUY@2QXJ40WinO
09VIV@2FUYH0T92@07moO`0e=CD0=SHf01dM7@0_;bl0ADE506][J`2JVYX0Vi^K07emO@2BTY80Xj>S
09bLW02QXJ40^k^k0;fm_@2DU9@0Q8B408:2PP2:RXX0QXJ607QhN027QhL0UiNG09ZJVP2TY:@0[jn_
0<G5a@33`l<0Xj>S09>CT`2HV9P0Vi^K09fMW@2g]kL0i>CT0>SXj03[jn/0jNWY0>CTi03Xj>P0lo?c
0?;blP040?3`l0040?7al@3_knl0k^k^0>o_k`<0l?3`00P0kno_0?3`l03`l?00kno_0>k^kP3_knl0
moOg0??clbL0oooo000U0?ooo`040>GUi@3Hf=P0f=SH0=SHf080eMGE103Jf]X20=WIf@040=oOg`3K
fm/0g=cL0=cLg0<0gmoO00D0g]kN0>KViP3Vi^H0i>CT0>GUi@020=CDe0040<[:bP2][Jd0[Jf]09fM
W@80U9BD00D0Lg=c07YjNP1jNWX0NWYj05iNGP0206ATI00409RHV03Hf=P0f=SH0=KFeP<0e=CD0P37
alL00`32`/80ZJVY0;2`/0020;2`/080[jn_00D0/K6a0;no_`2o_kl0YjNW09bLW00309jNWP80YJFU
00@0UiNG07YjNP1jNWX0ZJVY0P2h^;P01@2f][H0];Bd0:j^[P2^[Zh0YZJV00<0VYZJ0P2EUID01@28
R8P0Ng]k07]kN`1;Bd/0<C4a0080B4Q800@0I6AT07YjNP1jNWX0PH610P1[Jf/01@2>SXh0QHF50;2`
/02`/;00P8200080MgMg00@0N7Qh06][J`1[Jf/0MWIf0P21PH401@20P800SXj>0:6QX@2QXJ40SHf=
0080Ogmo00@0QXJ608Z:RP2:RXX0^KVi0P2m_Kd01@2n_[h0_Kfm0<K6aP36a/H0bLW90080b<S800D0
bLW90<S8b038b<P0bLW90<[:bP020<c<c0040<g=c@3>c/h0c/k>0=3@d080clo?00@0d];B0=?Cd`3C
dm<0i^KV903oool0303bl_80n?Sh0>k^kP3^k^h0kNg]0>[ZjP3]kNd0k^k^0>g]k@3[jn/0j^[Z0>o_
k`<0jn_[01D0k^k^0>o_k`3^k^h0jn_[0>c/k03alO40l?3`0>c/k03^k^h0inOW0=;BdP34a<@0ZJVY
09VIV@27QhL0MGEe069RHP1ADE40FUYJ051@D00k>c/00P0c<c<04P1CDe<0ZZZZ0<_;b`3>c/h0bLW9
0<K6aP35aLD0`L710:ZZZP2QXJ40R8R806a/K01UIFD0JFUY06i^KP1cLg<0KFe]06YZJP80LW9b00@0
I6AT04m?C`1BDU80Fe]K0P1NGUh03`1PH600G5aL04m?C`1TI6@0RXZ:0:VYZ@2h^;P0]kNg0;Rh^02d
];@0/K6a0:n_[`2XZ:P0XJ6Q0::RXP0209nOW`0<09BDU027QhL0BDU902HV9P0F5QH0;2`/04Y:BP1N
GUh0MgMg09NGU`2LW9`0MgMg0P2LW9`0602ATI40][Jf0<[:bP2k^k/0U9BD09>CT`2;Rh/0OGem0861
P@22PX80TI6A09FEU@2IVIT0/[:b0<?3``31`L40];Bd0:BTY02UYJD0XZ:R0:2PX02j^[X0g]kN0>WY
j@80j>SX00<0jNWY0>_[j`3]kNd00P3bl_830?3`l0040>k^kP3alO40l?3`0?7al@D0l?3`00H0kNg]
0>k^kP3^k^h0kNg]0?Shn03dm?@W0?ooo`009@3oool0103Vi^H0e]KF0=KFeP3Hf=P20=WIf@040=KF
eP3Jf]X0f][J0=[JfP80g]kN0P3MgMd30=oOg`<0h>3P0P3Shn<20>;RhP80e]KF00@0a<C40:JVYP2V
YZH0T92@0P1iNGT01@1lO7`0MgMg07MgM`1[Jf/0MWIf0080Ogmo00@0dm?C0=;BdP3Bd]80emOG0P3F
e]H01@3GemL0`<300<30`036a/H0Xj>S0080WYjN00@0XJ6Q0:RXZ02XZ:P0YjNW0P2j^[X00`2QXJ40
Vi^K09ZJVP0209ZJVP80UYJF00@0YZJV09fMW@2MWId0YJFU0P2g]kL01@2h^;P0/K6a0:b/[02/[:`0
Zj^[0080WinO00@0VIVI09ZJVP2JVYX0SXj>0P22PX801@1KFe/0;2`/03Hf=P0f=SH0B4Q80080IVIV
00<0U9BD06a/K01/K6`00P1hN7P20:BTY0040:FUY@26QXH0QXJ606m_K`80OGem00D0M7Ad07emO@1m
OGd0IfMW09RHV00209VIV@040::RXP1gMgL0MgMg08j>SP80VYZJ00D0][Jf0;^k^`2k^k/0^[Zj0<;2
`P020<30`0040<G5a@36a/H0a/K60<W9b@80b<S800D0bLW90<[:bP3<c<`0c<c<0<[:bP020<k>cP04
0<c<c03?cll0clo?0=7Ad@80dm?C00<0i^KV0?ooo`3oool08P3oool00`3bl_80mOGe0>g]k@020>k^
kP040>c/k03Zj^X0kNg]0>g]k@80k>c/00@0k^k^0>g]k@3[jn/0kNg]0`3^k^h20>c/k00C0>k^kP3/
k>`0k>c/0>c/k03Shn<0d];B0;jn_P2PX:00Shn?07YjNP1RHV80EUIF05EEE@1DE5@0C4a<0410@00m
?Cd0CTi>09VIV@020<k>cP80bl_;04`0alO70<G5a@30`<00YjNW0:>SX`2?Shl0KFe]05]KF`1MGEd0
HF5Q06e]K@1UIFD0HV9R06e]K@1^KVh0GemO055AD@1CDe<0Fe]K05ADE01EEED0LG5a079bLP1`L700
MgMg08f=S@2XZ:P0^;Rh0;Ng]`2e]KD0/K6a0;2`/02a/K40[Zj^0:FUY@2QXJ40XZ:R0:>SX`2IVIT0
SHf=05eMG@0U9BD051@D028R8P0e=CD0BDU906IVIP2<S8`0ZZZZ08F5Q@26QXH0Ti>C09:BTP2QXJ40
a/K60<k>cP2n_[h0VYZJ0861P@23Ph<0RXZ:08>3P`2=SHd0TI6A09BDU02d];@0^[Zj0<;2`P34a<@0
Z:RX0:NWY`2YZJT0Zj^[0<[:bP3Ogml0j>SX0P3UiND00`3Zj^X0kNg]0>_[j`030>o_k`80l?3`00H0
kno_0?3`l03_knl0l?3`0>o_k`3^k^h20?3`l0070>k^kP3]kNd0kno_0>g]k@3[jn/0n?Sh0?Cdm00W
0?ooo`009@3oool0103YjNT0e=CD0=CDe03GemL20=GEe@040=cLg03MgMd0gMgM0=[JfP80h>3P00<0
g=cL0>7Qh@3Rh^800P3Rh^820>7Qh@050>CTi03Rh^80h^;R0>3Ph03Shn<00P3Bd]80102i^KT0UIFE
09FEU@2=SHd20861P@0507MgM`1aLG40LG5a071`L01]KFd00P2:RXX00`3Bd]80eMGE0=GEe@030=KF
eP050=GEe@3Kfm/0fm_K0>?Sh`3/k>`00P3clo<0103Zj^X0lo?c0??cl`3bl_820?7al@050?Win@3d
m?@0kNg]0>g]k@3Ng]h00P3Bd]801038b<P0`<300<30`02l_;`20;^k^`050;Rh^02d];@0[Jf]0:f]
[@2YZJT00P2QXJ40102OWil0VIVI09VIV@2@T90208n?S`05071`L016ATH06QXJ01XJ6P1QHF400P1=
CDd00`1RHV80OGem07emO@0206MWI`80Lg=c00@0XJ6Q092@T02@T900PX:20P1kNg/01@1WIfL0MGEe
07EeM@24Q8@0Rh^;0080SXj>00@0Xj>S07UiN@1iNGT0O7al0P2LW9`01@2e]KD0^;Rh0;Rh^02h^;P0
`l?300<0aLG50P36a/H00`38b<P0bLW90<W9b@020<_;b`80a/K60`3<c<`0103?cll0d=3@0=3@d03?
cll20=CDe0030>OWi`3oool0oooo0280oooo00H0lO7a0?;blP3YjNT0kNg]0>o_k`3]kNd20>c/k009
0>o_k`3/k>`0kNg]0>c/k03`l?00k^k^0?3`l03_knl0kNg]0080k>c/02<0k^k^0>c/k03Zj^X0jn_[
0>[ZjP3Ogml0c/k>0;Ng]`2EUID0OWin06e]K@1LG5`0De=C05EEE@1=CDd0ATI604Q8B010@400JVYZ
0=7Ad@3=cLd0b<S80<[:bP3;bl/0bLW90<K6aP32`/80_kno0<G5a@2f][H0XJ6Q09RHV02CTi<0RXZ:
08n?S`02092@T00>09NGU`2IVIT0Shn?08n?S`2=SHd0Rh^;08N7Q`2ATI40ZZZZ0:f][@2^[Zh0/K6a
0;:b/P2d];@20;Ng]`070;Bd]02c/k<0/;2`0;6a/@2`/;00ZZZZ0:FUY@020::RXP0T09fMW@2GUiL0
Kfm_0451@@0P8200410@02/[:`1=CDd0Fe]K075aL@2DU9@0VYZJ07QhN027QhL0TY:B08N7Q`2c/k<0
`/;20<o?c`2OWil0QhN7096AT@29RHT0OWin08F5Q@2=SHd0VIVI0:ZZZP2[Zj/0`L710<S8b02WYjL0
X:2P0:6QX@2][Jd0f][J0P3UiND00`3Ti>@0hn?S0>OWi`020>o_k`030>k^kP3]kNd0kno_00<0lO7a
00<0l?3`0>o_k`3_knl00P3]kNd20>o_k`030>g]k@3_knl0kno_0080kNg]00<0n?Sh0?Cdm03oool0
9P3oool002D0oooo00@0jNWY0=CDe03De=@0emOG0P3EeMD0103Lg=`0gMgM0=gMg@3Jf]X20>3Ph003
0=cLg03QhN40h^;R0080h^;R0P3QhN401@3Ti>@0h^;R0>;RhP3Ph>00hn?S0080d];B00@0^KVi09FE
U@2EUID0SHf=0P21PH401@1gMgL0LG5a075aL@1`L700KFe]0080RXZ:00<0d];B0=GEe@3EeMD00`3F
e]H01@3EeMD0fm_K0=_Kf`3Shn<0k>c/0080lo?c00@0j^[Z0??cl`3clo<0l_;b0P3alO401@3inOT0
m?Cd0>g]k@3]kNd0g]kN0080d];B00@0b<S80<30`030`<00_;bl0P2k^k/01@2h^;P0];Bd0:f][@2]
[Jd0ZJVY0080XJ6Q00@0WinO09VIV@2IVIT0T92@0P2?Shl01@1`L700ATI601XJ6P0J6QX0HF5Q0080
CDe=00<0HV9R07emO@1mOGd00P1WIfL207=cL`040:6QX@2@T900T92@08:2PP80Ng]k00D0IfMW07Ee
M@1eMGD0Q8B408^;R`0208j>SP040:>SX`1iNGT0NGUi07alO080W9bL00D0]KFe0;Rh^02h^;P0^;Rh
0<?3``030<G5a@80a/K600<0b<S80<W9b@39bLT00P3;bl/20<K6aP<0c<c<00@0clo?0=3@d03@d=00
clo?0P3De=@00`3WinL0oooo0?ooo`0R0?ooo`030??cl`3dm?@0jn_[0080k^k^00P0kNg]0>o_k`3_
knl0kno_0>g]k@3^k^h0k>c/0?3`l080kno_00H0l?3`0?7al@3^k^h0jn_[0>o_k`3]kNd20>WYj@0A
0>CTi03GemL0aLG50:^[Z`29RHT0KVi^06IVIP1QHF40EEEE04a<C015ADD0@T9204E5A@1<C4`0P820
0<c<c03:b/X00P3;bl/05038b<P0alO70<S8b035aLD0alO70<[:bP3;bl/0c/k>0=7Ad@3=cLd0a/K6
0<C4a03>c/h0b/[:0<71`@34a<@0c<c<0<C4a030`<00_Kfm0P2g]kL00`2j^[X0][Jf0;Jf]P020;Rh
^080]kNg0240^KVi0;Rh^02d];@0/K6a0;2`/02^[Zh0Zj^[0:ZZZP2SXj<0WinO09^KV`2JVYX0NWYj
05EEE@0^;Rh0410@03Ph>01HF5P0E5AD06QXJ01gMgL0TI6A07QhN01eMGD0PH6107emO@2DU9@0_Kfm
0<C4a02e]KD0YZJV09ZJVP2:RXX00P1mOGd04027QhL0UiNG09RHV02OWil0`L710<S8b02[Zj/0X:2P
09RHV02XZ:P0gmoO0>CTi03Rh^80hn?S0>CTi03Zj^X20?;blP050?7al@3]kNd0kno_0?7al@3`l?00
0P3_knl01@3`l?00kNg]0>k^kP3_knl0k>c/00<0l?3`0P3]kNd00`3_knl0moOg0??cl`0W0?ooo`00
9@3oool0103Ti>@0fMWI0=WIf@3IfMT20=[JfP040=_Kf`3Jf]X0f][J0=kNgP80gmoO00@0g=cL0=kN
gP3MgMd0gMgM0`3Rh^801@3Ogml0hN7Q0>7Qh@3Rh^80d=3@0080a<C400@0ZJVY08^;R`2;Rh/0NGUi
0P1hN7P01@1`L700JFUY06UYJ@1bLW80IFEU00<0e=CD0`3GemL20=SHf0050=gMg@3GemL0emOG0>;R
hP3Xj>P00P3WinL00`3`l?00kno_0>o_k`030>WYj@050>KViP3MgMd0emOG0=OGe`3Cdm<00P3?cll0
1038b<P0bLW90<W9b@37alL20;^k^`050;fm_@2e]KD0[jn_0:n_[`2ZZZX00P2RXZ800`2OWil0TY:B
09:BTP0308j>SP0507=cL`10@400<c<c03<c<`1?Cdl00P1]KFd01@1ZJVX0SHf=08f=S@1FEUH0LG5a
0080M7Ad00@0U9BD0:JVYP2VYZH0UiNG0P1jNWX01@1lO7`0L71`071`L01aLG40KVi^0080T92@00@0
Xj>S0820P020P800R8R80P2SXj<01@2f][H0/;2`0;2`/02k^k/0`l?30080a<C400@0aLG50<K6aP36
a/H0alO70P34a<@01@35aLD0b/[:0<_;b`3;bl/0cLg=00<0clo?0P3AdM40103Cdm<0e=CD0=CDe03R
h^8T0?ooo`030?3`l03gmoL0kno_00<0kno_00<0k^k^0>_[j`3^k^h00P3`l?002@3/k>`0kno_0>c/
k03[jn/0k^k^0?7al@3_knl0jn_[0>[ZjP020>c/k0080>WYj@3Fe]H0`l?30;Rh^02KVi/0Ng]k06QX
J01HF5P2051@D00604M7A`0e=CD0@d=30410@01^KVh0_[jn0P3=cLd0503<c<`0b/[:0<_;b`3:b/X0
alO70<_;b`35aLD0bLW90<_;b`3=cLd0c/k>0<_;b`3?cll0bl_;0<k>cP38b<P0`L710<;2`P33`l<0
]kNg0`2d];@0>`2f][H0^KVi0;Jf]P2j^[X0`/;20;jn_P2g]kL0^;Rh0;bl_02i^KT0];Bd0;>c/`2b
/[80[Zj^0:^[Z`2ZZZX0Xj>S09VIV@2GUiL0Vi^K07emO@1OGel0;Bd]01dM7@0f=SH0CDe=069RHP1o
Ogl0MWIf09JFUP1mOGd0H61P07=cL`2ATI40Ti>C0;6a/@30`<00bLW90;jn_P2QXJ40Rh^;08b<S02?
Shl0Ogmo07inOP25QHD0WinO0;no_`36a/H0[:b/0:NWY`2PX:00[Jf]0>?Sh`3Ti>@0g=cL0=oOg`3W
inL0k^k^00<0lO7a00@0kNg]0>o_k`3alO40k^k^0P3[jn/00`3_knl0l?3`0?3`l0030?3`l0D0kno_
00<0moOg0?3`l03oool09P3oool002D0oooo00<0i^KV0=KFeP3Fe]H00`3Fe]H0103IfMT0fm_K0=_K
f`3Kfm/40=oOg`80hN7Q00@0gmoO0>?Sh`3Shn<0hN7Q0P3Ph>001@3Rh^80eMGE0:j^[P2^[Zh0Ti>C
0080Q8B400@0OGem06e]K@1]KFd0K6a/0P1`L7001@1fMWH0GemO0>7Qh@3QhN40e=CD0080fMWI00@0
g=cL0=[JfP3Jf]X0fm_K0P3Ng]h0103Rh^80i>CT0>KViP3Vi^H30>WYj@050>KViP3Ogml0gmoO0>CT
i03IfMT00`3Hf=P20<k>cP040<[:bP3Bd]80d];B0;no_`80`/;200D0_[jn0;6a/@2a/K40/K6a0:^[
Z`020::RXP0409fMW@2KVi/0Vi^K08j>SP80RHV900D0Ogmo05YJFP0o?cl0?clo034a<@0205MGE`05
065QH@1RHV80HV9R071`L01RHV800P1NGUh01026QXH0Shn?08n?S`2BTY8208n?S`0507AdM01YJFT0
JFUY08F5Q@1aLG400P29RHT0102LW9`0SHf=08f=S@1lO7`20:>SX`050;Fe]@2f][H0][Jf0;Jf]P31
`L400P34a<@01035aLD0a/K60<K6aP35aLD20<O7a`050<[:bP3;bl/0a/K60<K6aP3=cLd00P3>c/h0
103=cLd0clo?0<o?c`3Bd]820=CDe0030>OWi`3oool0oooo0280oooo00<0kno_0?Ogm`3]kNd00`3[
jn/0103/k>`0k^k^0>_[j`3^k^h20?3`l0070>o_k`3[jn/0k^k^0>g]k@3^k^h0kno_0>c/k0020>_[
j`0K0>c/k03]kNd0gMgM0;fm_@2MWId0PX:206YZJP1YJFT0F5QH04];B`17AdL0>c/k04A4A017AdL0
@T9207alO03@d=00cLg=0<S8b03;bl/0cLg=0<_;b`38b<P0bLW90<c<c039bLT0b/[:0080bl_;0P3:
b/X0103;bl/0b/[:0<W9b@34a<@30<71`@80]KFe00T0^KVi0;Ng]`2f][H0^KVi0;Jf]P30`<00_Kfm
0;jn_P2o_kl00P2h^;P0<`2d];@0/k>c0;Jf]P2d];@0[Zj^0:VYZ@2VYZH0ZJVY0::RXP2KVi/0VYZJ
08N7Q`1[Jf/0ATI603Hf=P0T92@0<S8b05QHF01PH600JVYZ06m_K`1gMgL0KFe]075aL@24Q8@0Ph>3
09bLW02k^k/0aLG50;6a/@2MWId0VYZJ08b<S02=SHd0OGem0820P022PX80XJ6Q0:n_[`2n_[h0/[:b
0:2PX02IVIT0/;2`0=WIf@3Shn<0h^;R0=SHf03Shn<0l?3`0>k^kP020?7al@040>g]k@3_knl0k^k^
0>g]k@<0kno_0P3]kNd20?3`l0040>o_k`3/k>`0jn_[0>g]k@80kno_00<0moOg0??cl`3oool09P3o
ool002D0oooo00<0i^KV0=KFeP3Fe]H00`3Fe]H0103IfMT0fm_K0=_Kf`3Kfm/40=oOg`80hN7Q00@0
gmoO0>?Sh`3Shn<0hN7Q0P3Ph>001@3Rh^80eMGE0:j^[P2^[Zh0Ti>C0080Q8B400@0OGem06e]K@1]
KFd0K6a/0P1`L7001@1fMWH0GemO0>7Qh@3QhN40e=CD0080fMWI00@0g=cL0=[JfP3Jf]X0fm_K0P3N
g]h0103Rh^80i>CT0>KViP3Vi^H30>WYj@050>KViP3Ogml0gmoO0>CTi03IfMT00`3Hf=P20<k>cP04
0<[:bP3Bd]80d];B0;no_`80`/;200D0_[jn0;6a/@2a/K40/K6a0:^[Z`020::RXP0409fMW@2KVi/0
Vi^K08j>SP80RHV900D0Ogmo05YJFP0o?cl0?clo034a<@0205MGE`05065QH@1RHV80HV9R071`L01R
HV800P1NGUh01026QXH0Shn?08n?S`2BTY8208n?S`0507AdM01YJFT0JFUY08F5Q@1aLG400P29RHT0
102LW9`0SHf=08f=S@1lO7`20:>SX`050;Fe]@2f][H0][Jf0;Jf]P31`L400P34a<@01035aLD0a/K6
0<K6aP35aLD20<O7a`050<[:bP3;bl/0a/K60<K6aP3=cLd00P3>c/h0103=cLd0clo?0<o?c`3Bd]82
0=CDe0030>OWi`3oool0oooo0280oooo00/0l_;b0??cl`3/k>`0jn_[0>WYj@3[jn/0k^k^0>o_k`3^
k^h0k>c/0>k^kP020?3`l0030>o_k`3`l?00kno_0080l?3`01L0kno_0>c/k03[jn/0k>c/0=oOg`3?
cll0]kNg092@T01iNGT0Jf][05UIF@1FEUH0C4a<03hn?P11@D40>CTi04E5A@0k>c/0MGEe0=7Ad@39
bLT0alO70<[:bP020<g=c@050<c<c03;bl/0bLW90<_;b`3<c<`00P3;bl/0>@3:b/X0bLW90<[:bP3;
bl/0aLG50<?3``2m_Kd0^k^k0<71`@2a/K40/k>c0;Vi^@2h^;P0][Jf0;Vi^@2k^k/0`l?30;bl_02j
^[X0_kno0<?3``31`L40^;Rh0;Ng]`2f][H0];Bd0;2`/02ZZZX0ZJVY0:JVYP2SXj<0Vi^K09>CT`2;
Rh/0MgMg055AD@0a<C408B4Q038b<P1BDU80H61P06YZJP1]KFd0Ogmo07YjNP1YJFT0IfMW071`L02F
UYH0WYjN0:VYZ@2h^;P0^KVi0::RXP26QXH0S8b<07IfMP0208f=S@0C09nOW`2SXj<0^[Zj0;>c/`2G
UiL0WinO0<C4a03Fe]H0h^;R0>CTi03Ogml0i^KV0>o_k`3`l?00lO7a0?3`l03_knl0l?3`0>o_k`02
0>g]k@80l?3`00`0k>c/0>g]k@3^k^h0k>c/0>o_k`3^k^h0kNg]0>k^kP3_knl0k^k^0?Ogm`3dm?@W
0?ooo`009@3oool00`3YjNT0emOG0=OGe`030=WIf@040=_Kf`3Lg=`0g=cL0=gMg@80f][J00D0gmoO
0>3Ph03Rh^80h^;R0=kNgP020>3Ph0050>?Sh`3UiND0iNGU0=[JfP2o_kl00P2^[Zh0102:RXX0QhN7
08N7Q`1hN7P2071`L00507IfMP1bLW80LW9b06YZJP2DU9@00P3MgMd00`3GemL0gMgM0=gMg@030=gM
g@050>7Qh@3Ogml0gmoO0>3Ph03Ti>@00P3Vi^H0103Rh^80h>3P0>3Ph03EeMD20<g=c@050=SHf03@
d=00dM7A0=7Ad@3@d=000P3<c<`0103=cLd0bLW90<W9b@39bLT20<K6aP050;^k^`2f][H0/;2`0;2`
/02ZZZX00P2QXJ40102OWil0V9RH09RHV02EUID208b<S00507]kN`1VIVH0?Shn03hn?P16ATH00P1B
DU801@1DE5@0K6a/06a/K01WIfL0EEEE0080GUiN00@0GEeM09NGU`2GUiL0Shn?0P2=SHd01@1jNWX0
KFe]06e]K@1cLg<0NWYj0080QHF500@0Vi^K09>CT`2CTi<0QHF50P2QXJ401@2o_kl0]kNg0;Ng]`30
`<00`/;20080`l?300<0aLG50<C4a034a<@00`37alL01@39bLT0b/[:0<_;b`3;bl/0bLW90080cLg=
00@0d=3@0<g=c@3=cLd0d];B0P3De=@00`3WinL0oooo0?ooo`0R0?ooo`80m?Cd0P3^k^h01`3/k>`0
kNg]0>o_k`3_knl0l?3`0>k^kP3]kNd0103`l?00103^k^h0kNg]0>k^kP3^k^h20>o_k`0A0>WYj@3C
dm<0_;bl0:VYZ@2?Shl0LG5a06UYJ@1MGEd0E5AD04U9B@14A4@0B4Q803hn?P16ATH0CDe=08^;R`3;
bl/00P37alL00`3<c<`0c/k>0<k>cP020<g=c@030<k>cP3<c<`0bl_;00<0bl_;00D0bLW90<K6aP37
alL0_[jn0;Jf]P020:n_[`090;Ng]`2ZZZX0[Jf]0;:b/P2d];@0]KFe0;Ng]`2m_Kd0_kno0080`<30
00P0`l?30<K6aP2o_kl0^k^k0;Vi^@2e]KD0/[:b0:n_[`80Zj^[00/0Xj>S0::RXP2OWil0VIVI08N7
Q`1hN7P0Fe]K03Ph>00`<300?3`l04e=C@02061PH00O071`L01gMgL0N7Qh06UYJ@1HF5P0IFEU075a
L@2FUYH0/[:b0;Rh^02b/[80XZ:R08^;R`2ATI40NWYj08Z:RP2BTY80W9bL09nOW`2h^;P0][Jf09VI
V@2/[:`0d=3@0<c<c03Xj>P0i^KV0>WYj@3]kNd0kno_0?7al@030?3`l080k^k^00H0kno_0>k^kP3_
knl0kno_0>k^kP3]kNd20>_[j`80kno_0P3]kNd20>k^kP030?KfmP3clo<0oooo02H0oooo000U0?oo
o`040>?Sh`3Hf=P0f=SH0=SHf080fMWI00<0f][J0=WIf@3IfMT00`3IfMT01@3Ogml0gMgM0>7Qh@3Q
hN40hn?S0080h^;R00D0hn?S0>3Ph03Ph>00h^;R0;Fe]@0209FEU@0408B4Q01dM7@0M7Ad07AdM080
Hf=S00D0IfMW07UiN@1iNGT0GUiN0>g]k@020=cLg0040=_Kf`3Ogml0gmoO0=gMg@80g=cL00D0gMgM
0=oOg`3Ogml0gmoO0>CTi0020>[ZjP040>;RhP3Cdm<0dm?C0=OGe`80alO700D0eMGE0<g=c@3:b/X0
b/[:0<g=c@020<S8b0040<K6aP39bLT0bLW90<30`080aLG500D0a<C40;Jf]P2l_;`0_;bl0:j^[P02
0:RXZ00409jNWP2GUiL0UiNG09JFUP80PH6100D0Q8B406a/K013@d<0@d=301PH600203hn?P0504m?
C`1XJ6P0J6QX05QHF01RHV800P1QHF40101<C4`0OWin07inOP1kNg/20:n_[`0507MgM`1kNg/0Ng]k
06a/K01hN7P00P1dM7@0102FUYH0UIFE09FEU@2IVIT20:NWY`030:VYZ@2TY:@0Y:BT0080`L710P33
`l<01034a<@0`l?30<?3``37alL20<S8b0050<W9b@3:b/X0c<c<0<c<c03>c/h00P3?cll0103@d=00
cLg=0<g=c@3Cdm<20=CDe0030>OWi`3oool0oooo0280oooo00<0lO7a0?Ogm`3^k^h00`3_knl01@3^
k^h0kNg]0>o_k`3^k^h0jn_[0080l?3`00@0k^k^0>o_k`3^k^h0kNg]0P3/k>`04P3alO40l?3`0>[Z
jP3Cdm<0/K6a09NGU`23Ph<0JFUY05aLG01MGEd0DE5A04A4A011@D40@T9204U9B@1:BTX0KVi^0;Ng
]`80b<S800X0bLW90<g=c@3?cll0c/k>0<g=c@3>c/h0d=3@0<g=c@3:b/X0bl_;0`3<c<`0A@35aLD0
_[jn0;Bd]02_[jl0Z:RX0:FUY@2^[Zh0Y:BT0:JVYP2][Jd0/K6a0;>c/`2f][H0^[Zj0;bl_02n_[h0
`l?30<O7a`35aLD0_[jn0;^k^`2n_[h0^k^k0;Bd]02`/;00[Jf]0:ZZZP2SXj<0XZ:R0:>SX`2MWId0
R8R807]kN`1TI6@0@T9202/[:`0Y:BT0?3`l05=CD`1EEED0KFe]06ATI01^KVh0L71`05mOG`1RHV80
Cdm?09ZJVP2b/[80XZ:R0:^[Z`2c/k<0TY:B096AT@27QhL0Ph>308f=S@2BTY80VYZJ0;Jf]P2j^[X0
Z:RX0;Ng]`3@d=00b/[:0>7Qh@3Jf]X0j>SX0?;blP050?3`l0040>c/k03]kNd0l?3`0?3`l0<0kno_
00<0k^k^0>c/k03]kNd00P3_knl01P3Zj^X0k>c/0>k^kP3^k^h0m_Kf0??clbL0oooo000U0?ooo`04
0>?Sh`3Hf=P0f=SH0=SHf080fMWI00<0f][J0=WIf@3IfMT00`3IfMT01@3Ogml0gMgM0>7Qh@3QhN40
hn?S0080h^;R00D0hn?S0>3Ph03Ph>00h^;R0;Fe]@0209FEU@0408B4Q01dM7@0M7Ad07AdM080Hf=S
00D0IfMW07UiN@1iNGT0GUiN0>g]k@020=cLg0040=_Kf`3Ogml0gmoO0=gMg@80g=cL00D0gMgM0=oO
g`3Ogml0gmoO0>CTi0020>[ZjP040>;RhP3Cdm<0dm?C0=OGe`80alO700D0eMGE0<g=c@3:b/X0b/[:
0<g=c@020<S8b0040<K6aP39bLT0bLW90<30`080aLG500D0a<C40;Jf]P2l_;`0_;bl0:j^[P020:RX
Z00409jNWP2GUiL0UiNG09JFUP80PH6100D0Q8B406a/K013@d<0@d=301PH600203hn?P0504m?C`1X
J6P0J6QX05QHF01RHV800P1QHF40101<C4`0OWin07inOP1kNg/20:n_[`0507MgM`1kNg/0Ng]k06a/
K01hN7P00P1dM7@0102FUYH0UIFE09FEU@2IVIT20:NWY`030:VYZ@2TY:@0Y:BT0080`L710P33`l<0
1034a<@0`l?30<?3``37alL20<S8b0050<W9b@3:b/X0c<c<0<c<c03>c/h00P3?cll0103@d=00cLg=
0<g=c@3Cdm<20=CDe0030>OWi`3oool0oooo0280oooo00@0l?3`0?KfmP3^k^h0k^k^0P3_knl00`3^
k^h0jn_[0>g]k@020>c/k0040>o_k`3^k^h0kNg]0>o_k`80lO7a00/0kno_0>g]k@3alO40k^k^0>g]
k@3@d=00YjNW08J6QP1]KFd0GUiN055AD@0204Y:BP0704A4A00k>c/0?clo04U9B@14A4@0PH610<o?
c`020<O7a`0>0<W9b@3=cLd0cLg=0<k>cP3@d=00c/k>0<g=c@3<c<`0bl_;0<[:bP3=cLd0b<S80;Vi
^@2`/;020;Rh^00;0;Jf]P2^[Zh0W9bL096AT@2EUID0WYjN09nOW`2PX:00Zj^[0;>c/`2f][H00P2n
_[h03031`L40a/K60<K6aP36a/H0`<300<;2`P2n_[h0]kNg0;>c/`2`/;00Zj^[0:JVYP80Xj>S01L0
Vi^K08^;R`1nOWh0J6QX04M7A`0N7Qh04a<C02d];@14A4@0DE5A06=SH`1KFe/0J6QX07AdM01XJ6P0
GUiN05MGE`26QXH0Shn?09JFUP2c/k<0^k^k09^KV`0208j>SP0>07]kN`24Q8@0Q8B409NGU`2f][H0
^[Zj0<71`@33`l<0alO70=GEe@37alL0d];B0>WYj@3alO440?3`l0030>o_k`3]kNd0k^k^00T0kno_
00L0k^k^0>c/k03]kNd0k^k^0>g]k@3dm?@0lo?c02L0oooo000U0?ooo`040>SXj03GemL0emOG0=SH
f080fMWI0`3Kfm/00`3Lg=`0gMgM0=gMg@020=kNgP80h^;R00@0hn?S0>CTi03Ti>@0iNGU0P3Vi^H0
1@3Fe]H0YJFU08J6QP26QXH0O7al0080L71`00@0KFe]06i^KP1^KVh0MgMg0P1/K6`01@1OGel0k^k^
0=_Kf`3Kfm/0f][J0080hN7Q00@0f][J0>;RhP3Rh^80gMgM0P3Ogml01@3Ng]h0iNGU0<O7a`37alL0
^KVi0080h^;R00D0f][J0=3@d03@d=00WYjN0:f][@020<O7a`040:BTY02h^;P0^;Rh0<;2`P80cLg=
00D0b<S80<G5a@35aLD0`l?30;bl_0020;Fe]@040:j^[P2YZJT0ZJVY0:6QX@80Vi^K00D0U9BD08j>
SP2>SXh0OWin07=cL`0205QHF00402<S8`0a<C40<C4a04A4A080CTi>00D0EUIF061PH012@T80@T92
05QHF00205UIF@0408F5Q@1hN7P0N7Qh08V9R@80M7Ad00D0D51@06UYJ@1fMWH0MWIf09:BTP0209FE
U@040:JVYP2PX:00X:2P09NGU`80a<C400D0_[jn0<71`@32`/80`/;20<C4a0020<G5a@030<O7a`38
b<P0b<S80080bLW90P3<c<`00`3=cLd0clo?0<o?c`030=3@d0040=;BdP3AdM40dM7A0>OWib@0oooo
00<0l_;b0?Gem@3^k^h00P3]kNd02@3^k^h0kno_0>o_k`3/k>`0k^k^0>o_k`3^k^h0k>c/0>o_k`02
0?3`l0D0lO7a00T0inOW0<;2`P2HV9P0NWYj06=SH`1HF5P0DE5A0451@@12@T800P15ADD03@1:BTX0
ATI603Hf=P24Q8@0c/k>0<K6aP38b<P0bLW90<k>cP3<c<`0cLg=0=;BdP3AdM400`3<c<`04`3:b/X0
clo?0<G5a@2QXJ40UYJF0;jn_P38b<P0`<300;Ng]`2MWId0MGEe08b<S02QXJ40TY:B08Z:RP2NWYh0
Zj^[0;Jf]P32`/800`36a/H20<O7a`0`0<G5a@2o_kl0_Kfm0;Vi^@2e]KD0/[:b0:b/[02[Zj/0YJFU
0:6QX@2NWYh0RXZ:07YjNP1aLG40EEEE02PX:00G5aL09BDU038b<P17AdL0DU9B05UIF@1TI6@0KVi^
06MWI`1GEeL0J6QX05UIF@1jNWX0Xj>S0:NWY`2TY:@0[Zj^08f=S@29RHT0K6a/07]kN`22PX80Vi^K
0;>c/`2h^;P0clo?0<C4a02e]KD0dm?C0;no_`3Vi^H0lO7a1P3_knl00`3^k^h0kno_0>o_k`020>o_
k`80k^k^0P3_knl30>k^kP<0kNg]00<0k>c/0?;blP3clo<09`3oool002D0oooo00<0inOW0=OGe`3G
emL00`3Hf=P0103Kfm/0f][J0=[JfP3Ng]h20=[JfP050=gMg@3Ph>00h^;R0>;RhP3Shn<00P3Rh^80
1@3Vi^H0inOW0>OWi`3>c/h0U9BD0080QXJ600@0LG5a07EeM@1eMGD0KVi^0P1cLg<01@1hN7P0HV9R
069RHP26QXH0hn?S0080g=cL00<0fm_K0>;RhP3Rh^800`3Ogml01@3Ng]h0gMgM0=gMg@3MgMd0hN7Q
0080f][J00@0hN7Q0>3Ph03Ph>00g]kN0P3GemL01@3>c/h0c<c<0<W9b@39bLT0`L710080/[:b00@0
`<300<_;b`3;bl/0alO70P34a<@01@31`L40^[Zj0;Fe]@2e]KD0/K6a0080ZZZZ00<0Y:BT09bLW02L
W9`00`2<S8`01@22PX80MGEe06m_K`1_Kfl06ATI0080:2PX00D0@D5104e=C@1=CDd0CDe=05EEE@02
0410@00404Q8B01CDe<0De=C06i^KP80Ogmo00D0QhN706e]K@1]KFd0FUYJ06QXJ00207EeM@0408J6
QP2NWYh0WYjN09VIV@80T92@00D0`L710;fm_@2m_Kd0_Kfm0<30`0020<;2`P<0a<C400<0alO70<G5
a@35aLD00P39bLT20<c<c0040<g=c@3?cll0clo?0=3@d080clo?00@0d=3@0=CDe03De=@0inOW903o
ool01P3_knl0lO7a0>c/k03/k>`0jNWY0>_[j`@0kno_00D0kNg]0>c/k03_knl0k>c/0>o_k`020?3`
l0<0lO7a01d0kNg]0>7Qh@2c/k<0QXJ6075aL@1UIFD0I6AT04m?C`1:BTX0@D5103hn?P18B4P0BDU9
03/k>`0`<300U9BD0<g=c@39bLT0cLg=0<o?c`3Cdm<0dM7A0<_;b`3=cLd0dM7A0<W9b@3<c<`0b/[:
0<_;b`020=3@d00@0<S8b034a<@0b<S80<W9b@37alL0_kno0;:b/P2/[:`0[jn_0;Fe]@2_[jl0W9bL
09:BTP2QXJ40]KFe0<?3``<0a/K603<0alO70<K6aP2m_Kd0a<C40<S8b032`/80^;Rh0;>c/`2a/K40
[:b/0:FUY@2MWId0VYZJ08b<S026QXH0MgMg06IVIP0^;Rh030`<01TI6@0Y:BT0?Shn04m?C`1KFe/0
FEUI06=SH`1/K6`0EeMG05aLG00d=3@0O7al0:JVYP2CTi<0Y:BT0;Rh^027QhL0QXJ606][J`1jNWX0
RHV909:BTP2UYJD0^[Zj0<?3``2e]KD0Z:RX0;bl_03[jn/0l?3`0>c/k03]kNd01@3_knl20>c/k0<0
kno_00<0jn_[0>g]k@3_knl0103^k^h01P3[jn/0jNWY0>_[j`3]kNd0mOGe0??clbL0oooo000U0?oo
o`040>WYj@3Hf=P0f=SH0=KFeP80f][J00@0emOG0=gMg@3MgMd0fm_K0P3Ph>001@3MgMd0hN7Q0=cL
g03Lg=`0i>CT0080h>3P00@0i^KV0>OWi`3WinL0b/[:0`24Q8@0101kNg/0MGEe07EeM@1fMWH207al
O00507=cL`1PH600H61P0<k>cP3GemL00P3Ng]h0103Ph>00hN7Q0>7Qh@3Ph>030=oOg`80h>3P00<0
e]KF0=gMg@3QhN400P3QhN420>GUi@050=[JfP3Hf=P0f=SH0<o?c`35aLD00P33`l<0102o_kl0^KVi
0;Vi^@2o_kl20<W9b@050<G5a@33`l<0`l?30<;2`P2m_Kd00P2k^k/0102a/K40[Zj^0:j^[P2UYJD2
0:2PX00509NGU`2<S8`0S8b<0861P@1cLg<00P1SHf<0100Y:BT07QhN01hN7P14A4@202<S8`0505EE
E@1GEeL0=3@d03@d=01:BTX00P1FEUH0101XJ6P0PX:208:2PP1nOWh206YZJP0507=cL`1OGel0Hf=S
06=SH`20P8000P2PX:000`2GUiL0/[:b0;:b/P030;jn_P050;no_`30`<00`L710<71`@32`/800P30
`<001@36a/H0alO70<O7a`39bLT0b/[:0080c<c<00@0cLg=0<k>cP3>c/h0d=3@0P3AdM40103Cdm<0
e=CD0=CDe03WinLT0?ooo`030??cl`3fm_H0k^k^0080k>c/00@0k^k^0>_[j`3]kNd0kno_0P3]kNd0
4@3/k>`0l?3`0?3`l03/k>`0kno_0>k^kP3[jn/0k^k^0?;blP3_knl0g=cL0:2PX01/K6`0GUiN05]K
F`1;Bd/0BTY:0080C4a<00L0CTi>051@D015ADD0:RXZ02l_;`34a<@0c<c<0080clo?00@0d];B0=CD
e03EeMD0e=CD0P3Cdm<03P3Bd]80dM7A0<_;b`36a/H0c<c<0=;BdP3@d=00dm?C0=SHf03EeMD0cLg=
0<S8b034a<@0^k^k0`2_[jl01P2/[:`0ZJVY0:n_[`2h^;P0`l?30<K6aP80bLW901P0alO70<W9b@38
b<P0a<C40<?3``30`<00_;bl0;Zj^P2e]KD0/k>c0:b/[02TY:@0WIfM08b<S021PH40MGEe06MWI`0l
?3`04Q8B00d=3@0T92@0ATI603/k>`1HF5P205aLG00@06EUI@1<C4`0EEEE059BDP1^KVh0RHV909^K
V`2_[jl0[Zj^09RHV025QHD0OGem07MgM`1kNg/0PH610:6QX@80^k^k00L0^[Zj0<c<c03QhN40k^k^
0>o_k`3]kNd0k^k^00@0kno_00L0k>c/0>_[j`3]kNd0k^k^0>g]k@3^k^h0kno_00L0k^k^0`3]kNd0
0`3fm_H0lo?c0?ooo`0V0?ooo`009@3oool0103YjNT0f=SH0=SHf03Fe]H20=[JfP040=OGe`3MgMd0
gMgM0=_Kf`80h>3P00D0gMgM0>7Qh@3Lg=`0g=cL0>CTi0020>3Ph0040>KViP3WinL0inOW0<[:bP<0
Q8B400@0Ng]k07EeM@1eMGD0MWIf0P1lO7`01@1cLg<0H61P061PH03>c/h0emOG0080g]kN00@0h>3P
0>7Qh@3QhN40h>3P0`3Ogml20>3Ph0030=KFeP3MgMd0hN7Q0080hN7Q0P3UiND01@3Jf]X0f=SH0=SH
f03?cll0aLG50080`l?300@0_kno0;Vi^@2i^KT0_kno0P39bLT01@35aLD0`l?30<?3``32`/80_Kfm
0080^k^k00@0/K6a0:j^[P2^[Zh0YJFU0P2PX:001@2GUiL0S8b<08b<S021PH40Lg=c0080Hf=S00@0
:BTY01hN7P0N7Qh0A4A40P0S8b<01@1EEED0EeMG03@d=00d=3@0BTY:0080EUIF00@0J6QX08:2PP22
PX80OWin0P1ZJVX01@1cLg<0GemO06=SH`1SHf<0P8200080X:2P00<0UiNG0;:b/P2b/[800`2n_[h0
1@2o_kl0`<300<71`@31`L40`/;20080`<3000D0a/K60<O7a`37alL0bLW90<[:bP020<c<c0040<g=
c@3>c/h0c/k>0=3@d080dM7A00@0dm?C0=CDe03De=@0inOW903oool00`3clo<0m_Kf0>k^kP020>g]
k@0D0>k^kP3]kNd0kno_0>g]k@3Zj^X0kNg]0>_[j`3]kNd0l?3`0>k^kP3]kNd0k^k^0>o_k`3`l?00
l_;b0>g]k@32`/80QHF506EUI@1JFUX204];B`0<04Q8B019BDT0CTi>059BDP18B4P0<30`02/[:`0W
9bL0e=CD0<g=c@3?cll0c/k>0P3EeMD07`3De=@0dm?C0=?Cd`3Cdm<0d];B0=?Cd`3?cll0b/[:0<c<
c03?cll0c/k>0=;BdP3Fe]H0e=CD0<k>cP3:b/X0`/;20;Bd]02YZJT0[:b/0:^[Z`2YZJT0[Jf]0;Fe
]@2o_kl0aLG50<K6aP39bLT0c<c<0<[:bP38b<P00P37alL01038b<P0a/K60<71`@2k^k/20;Bd]00Q
0;6a/@2/[:`0YJFU08b<S021PH40N7Qh06a/K01ADE408R8R00L71`0P8200?Cdm04=3@`1FEUH0GUiN
06=SH`1QHF40BDU9059BDP1DE5@0IVIV0820P02DU9@0Xj>S0:f][@2a/K40QhN707YjNP1bLW80NWYj
08N7Q`2[Zj/0_kno0080[Jf]00D0dm?C0>g]k@3[jn/0kNg]0>c/k0020>_[j`060>c/k03^k^h0k^k^
0>c/k03Zj^X0k>c/0P3_knl70>k^kP070>c/k03]kNd0k^k^0>k^kP3]kNd0m_Kf0??cl`0W0?ooo`00
9@3oool0103YjNT0f=SH0=SHf03IfMT50=_Kf`050=WIf@3Ogml0gmoO0=cLg03Ogml00P3Shn<0103O
gml0i^KV0>KViP3Xj>P20>c/k00509FEU@23Ph<0IFEU06EUI@1_Kfl00P1aLG400`1iNGT0MGEe07Ee
M@0305EEE@050<W9b@3Bd]80emOG0=OGe`3Lg=`00P3Ogml00`3Ng]h0gmoO0=oOg`040=oOg`040=_K
f`3Fe]H0e]KF0=gMg@80g]kN00D0gMgM0=CDe03De=@0`L710;^k^`020;no_`040;Jf]P2m_Kd0_Kfm
0<O7a`80a/K600D0a<C40<O7a`37alL0_[jn0;bl_0020;Vi^@040;Rh^02[Zj/0Zj^[0:BTY080XJ6Q
00D0Vi^K09>CT`2CTi<0OWin07AdM00206a/K00404M7A`0M7Ad07AdM038b<P80De=C00D0BTY:059B
DP0n?Sh0?Shn0451@@0204M7A`0406ATI01_Kfl0Kfm_08^;R`80KFe]00D0IfMW05YJFP1]KFd0KFe]
09>CT`0209jNWP0408:2PP2b/[80/[:b0;Jf]P80_;bl00D0^KVi0;^k^`31`L40`L710<?3``020<;2
`P050<K6aP37alL0alO70<W9b@3:b/X00P3<c<`0103=cLd0clo?0<o?c`3;bl/20=7Ad@040=?Cd`3D
e=@0e=CD0>OWib@0oooo0140lO7a0?Cdm03]kNd0k^k^0>o_k`3^k^h0kNg]0>o_k`3]kNd0k>c/0>k^
kP3/k>`0kNg]0>k^kP3`l?00kNg]0>k^kP020?;blP070??cl`3/k>`0Z:RX075aL@1PH600D51@03`l
?00204Y:BP0804a<C01?Cdl0A4A402h^;P0S8b<0:2PX024Q8@3EeMD20=7Ad@030=3@d03De=@0eMGE
00<0dm?C0`3Bd]800`3Cdm<0dM7A0<g=c@020<W9b@0>0<k>cP3AdM40clo?0<c<c036a/H0_;bl0;2`
/02XZ:P0[:b/0:ZZZP2[Zj/0];Bd0;jn_P35aLD20<K6aP050<W9b@3=cLd0cLg=0<O7a`38b<P00P37
alL05039bLT0aLG50;^k^`2h^;P0]KFe0;>c/`2_[jl0ZZZZ096AT@26QXH0O7al07=cL`1OGel0;bl_
00d=3@0R8R80<C4a04m?C`1CDe<0EEEE0P1MGEd05`1GEeL0De=C04e=C@1VIVH0PH6108j>SP2KVi/0
/k>c0<?3``2>SXh0LG5a06i^KP1iNGT0S8b<0:^[Z`2m_Kd0/K6a0;Vi^@3Lg=`0kNg]0>_[j`3]kNd0
k>c/0080jn_[00H0k>c/0>k^kP3^k^h0k^k^0>c/k03]kNd30>k^kP030>c/k03]kNd0k^k^00<0k^k^
00L0jNWY0>[ZjP3]kNd0k^k^0>g]k@3fm_H0lo?c02L0oooo000U0?ooo`040>KViP3Fe]H0e]KF0=[J
fP80f=SH00@0fMWI0=gMg@3MgMd0g]kN0P3Ogml01@3Ph>00gmoO0>3Ph03Ph>00hN7Q0080hn?S00D0
iNGU0>o_k`3_knl0SHf=07AdM00206MWI`0407emO@1dM7@0M7Ad07alO080CTi>00D0FEUI06YZJP1Z
JVX0d=3@0=CDe0050=cLg0040=gMg@3Ph>00h>3P0>3Ph080g=cL00D0g]kN0=_Kf`3IfMT0fMWI0=?C
d`020=cLg0050=CDe037alL0alO70<;2`P2l_;`00P2o_kl0102m_Kd0a<C40<C4a038b<P20<?3``05
0<;2`P35aLD0aLG50;jn_P2l_;`00P2g]kL0102f][H0Z:RX0:RXZ02WYjL20::RXP0509RHV02FUYH0
UYJF08R8R01cLg<00P1WIfL0101@D5008R8R028R8P0`<30203De=@0504U9B@11@D40DU9B059BDP17
AdL00P1<C4`0101ZJVX0Kfm_06m_K`29RHT206a/K00506][J`1<C4`0H61P061PH024Q8@00P2LW9`0
102UYJD0^[Zj0;Zj^P2j^[X20;^k^`050;fm_@2o_kl0`<300<30`032`/800P34a<@01@36a/H0alO7
0<O7a`39bLT0b<S80080c<c<00@0cLg=0<k>cP3>c/h0cLg=0P3?cll0103Cdm<0d];B0=;BdP3WinLT
0?ooo`070?3`l03clo<0kNg]0>o_k`3^k^h0k>c/0>_[j`050>o_k`030>k^kP3/k>`0k^k^0080k^k^
0P3`l?00403bl_80k^k^0:BTY01^KVh0F5QH04I6AP13@d<0E5AD051@D01>CTh0D51@03Lg=`0L71`0
9BDU020P801:BTX20=CDe0030=KFeP3EeMD0e=CD0080dm?C01P0e=CD0=GEe@3De=@0e=CD0=7Ad@3B
d]80dm?C0<o?c`3:b/X0bLW90<O7a`3@d=00cLg=0<O7a`2o_kl0][Jf0;6a/@2[Zj/0[jn_0;2`/02c
/k<0_;bl0<K6aP37alL20<K6aP090<S8b03<c<`0c/k>0<W9b@3:b/X0b<S80<O7a`38b<P0a<C40080
_;bl00l0]kNg0;Bd]02^[Zh0ZZZZ09^KV`2=SHd0O7al075aL@1UIFD0=cLg018B4P0S8b<0:b/[03Ti
>@19BDT00P1DE5@0501GEeL0I6AT05YJFP1DE5@0JVYZ08J6QP2DU9@0WIfM0;>c/`3:b/X0TY:B06m_
K`1YJFT0MWIf07emO@2RXZ80_;bl0<;2`P3EeMD0k>c/0`3]kNd<0>k^kP030>_[j`3]kNd0k^k^00<0
k^k^00L0jn_[0>[ZjP3/k>`0k^k^0>g]k@3dm?@0lo?c02L0oooo000U0?ooo`040>KViP3Fe]H0e]KF
0=[JfP80f=SH00@0fMWI0=gMg@3MgMd0g]kN0P3Ogml01@3Ph>00gmoO0>3Ph03Ph>00hN7Q0080hn?S
00D0iNGU0>o_k`3_knl0SHf=07AdM00206MWI`0407emO@1dM7@0M7Ad07alO080CTi>00D0FEUI06YZ
JP1ZJVX0d=3@0=CDe0050=cLg0040=gMg@3Ph>00h>3P0>3Ph080g=cL00D0g]kN0=_Kf`3IfMT0fMWI
0=?Cd`020=cLg0050=CDe037alL0alO70<;2`P2l_;`00P2o_kl0102m_Kd0a<C40<C4a038b<P20<?3
``050<;2`P35aLD0aLG50;jn_P2l_;`00P2g]kL0102f][H0Z:RX0:RXZ02WYjL20::RXP0509RHV02F
UYH0UYJF08R8R01cLg<00P1WIfL0101@D5008R8R028R8P0`<30203De=@0504U9B@11@D40DU9B059B
DP17AdL00P1<C4`0101ZJVX0Kfm_06m_K`29RHT206a/K00506][J`1<C4`0H61P061PH024Q8@00P2L
W9`0102UYJD0^[Zj0;Zj^P2j^[X20;^k^`050;fm_@2o_kl0`<300<30`032`/800P34a<@01@36a/H0
alO70<O7a`39bLT0b<S80080c<c<00@0cLg=0<k>cP3>c/h0cLg=0P3?cll0103Cdm<0d];B0=;BdP3W
inLT0?ooo`060??cl`3fm_H0k^k^0>o_k`3]kNd0jn_[1@3_knl0103]kNd0jn_[0>o_k`3]kNd20>o_
k`0E0>c/k03]kNd0l?3`0>c/k02RXZ80JFUY059BDP1:BTX0CTi>05ADE01<C4`0BTY:04a<C00k>c/0
8B4Q020P800n?Sh0X:2P0=;BdP3De=@0emOG00<0e=CD00L0dm?C0=KFeP3IfMT0fMWI0=OGe`3Bd]80
dM7A0080d];B00P0d=3@0<_;b`36a/H0d=3@0=?Cd`3:b/X0_kno0;Fe]@80[Jf]00L0/[:b0;Fe]@2h
^;P0_[jn0<K6aP3:b/X0b<S80080bLW900D0cLg=0=;BdP3=cLd0c<c<0<[:bP020<W9b@0X0<G5a@2n
_[h0_;bl0;^k^`2f][H0/;2`0:VYZ@2QXJ40T92@07alO01aLG40KFe]04a<C00K6a/051@D038b<P0`
<300B4Q805eMG@1HF5P0DE5A061PH01UIFD0EUIF06=SH`29RHT0X:2P0::RXP2b/[80b<S808j>SP1`
L700HF5Q07UiN@1dM7@0ZZZZ0<G5a@37alL0f=SH0>k^kP@0kNg]1@3^k^h0103]kNd0k^k^0>k^kP3^
k^h20>g]k@050>k^kP3]kNd0k^k^0>k^kP3]kNd01@3^k^h00`3/k>`0lO7a0??cl`0W0?ooo`009@3o
ool0103UiND0eMGE0=GEe@3Hf=P20=WIf@040=_Kf`3Lg=`0g=cL0=gMg@80gmoO00D0g=cL0=kNgP3Q
hN40hN7Q0>?Sh`020=oOg`050>CTi03Fe]H0e]KF0861P@1_Kfl00P1dM7@0101iNGT0M7Ad07AdM01X
J6P205QHF00505MGE`3;bl/0bl_;0=CDe03IfMT00P3Ogml0103Jf]X0hN7Q0>7Qh@3Kfm/20=gMg@03
0=cLg03Jf]X0f][J0080fm_K0P3Lg=`0103EeMD0g=cL0=cLg03De=@20<o?c`050<71`@2o_kl0_kno
0;no_`2m_Kd00P32`/801034a<@0bLW90<W9b@37alL20<?3``050;bl_032`/80^[Zj0;Zj^P2e]KD0
0P2`/;00102[Zj/0Y:BT0:BTY02MWId209>CT`0508n?S`1jNWX0I6AT06ATI01MGEd00P0c<c<01@0j
>SX0?Shn03hn?P1:BTX0ATI60080DE5A00@0AdM70492@P12@T80M7Ad0P1^KVh01@1oOgl0Jf][06][
J`1RHV80>SXj0080FEUI00@0P8200:2PX02PX:00[jn_0P2h^;P01@2i^KT0^[Zj0;Zj^P2l_;`0_[jn
0080`<3000@0`L710<;2`P32`/80a/K60P33`l<01037alL0b/[:0<O7a`37alL30<c<c0040<o?c`3A
dM40dM7A0=;BdP80dm?C00<0inOW0?ooo`3oool08P3oool01P3`l?00lo?c0>[ZjP3]kNd0kno_0>k^
kPD0kno_0P3Zj^X01@3[jn/0kno_0?7al@3_knl0k>c/0080l?3`00D0c/k>08V9R@1RHV80Cdm?04M7
A`0205=CD`0704i>CP1<C4`0>3Ph02DU9@0F5QH0;Rh^0;2`/0020=?Cd`060=[JfP3Kfm/0e=CD0=CD
e03IfMT0e]KF0`3Bd]820=7Ad@<0d=3@0180dM7A0=3@d03<c<`0d=3@0=;BdP3<c<`0aLG50;no_`2c
/k<0/[:b0;Bd]02e]KD0^;Rh0;jn_P35aLD0a/K60<o?c`3Cdm<20<g=c@0]0=3@d03;bl/0dm?C0=3@
d03>c/h0c<c<0<W9b@38b<P0aLG50;jn_P2k^k/0]KFe0:j^[P2UYJD0XJ6Q08N7Q`1cLg<0K6a/05UI
F@0k>c/0;Rh^03/k>`17AdL0BTY:05YJFP1OGel0FEUI06IVIP1NGUh0De=C06=SH`2>SXh0YZJV0:6Q
X@2^[Zh0_;bl09VIV@1PH600FEUI07=cL`1jNWX0XZ:R0<C4a03IfMT0inOW00H0kNg]103^k^h01`3Z
j^X0k>c/0>k^kP3/k>`0jNWY0>[ZjP3^k^h00P3[jn/00`3/k>`0j^[Z0>k^kP030>k^kP80kNg]00<0
mOGe0??cl`3oool09P3oool002D0oooo00@0i>CT0=SHf03Hf=P0emOG0P3Jf]X0103Kfm/0g=cL0=cL
g03Ng]h20=[JfP040>7Qh@3Ogml0h^;R0>;RhP<0hn?S00D0j^[Z07=cL`1cLg<0L71`061PH00207Ee
M@0406][J`1cLg<0Lg=c06=SH`80LW9b00D0KVi^0=?Cd`3Cdm<0emOG0=WIf@020=SHf0040=kNgP3R
h^80h^;R0=[JfP80g=cL00D0h^;R0=WIf@3IfMT0f=SH0=WIf@020=_Kf`040=?Cd`3IfMT0fMWI0=_K
f`80d];B00D0_kno0;fm_@31`L40`L710;no_`020;fm_@040<?3``3;bl/0bl_;0<;2`P<0aLG500@0
]kNg0;Rh^02h^;P0^;Rh0P2`/;00102][Jd0Y:BT0:BTY02LW9`209ZJVP0508f=S@1mOGd0K6a/06a/
K01DE5@00P11@D401@0k>c/0=CDe03De=@18B4P0CTi>0080Cdm?00@0BDU905aLG01LG5`0KFe]0P1Z
JVX01@1[Jf/0Hf=S06=SH`18B4P0;Bd]0080HF5Q00<0Ng]k0:BTY02TY:@00`2f][H01@2h^;P0^[Zj
0;Zj^P2l_;`0_[jn0080`<3000@0`/;20<C4a034a<@0a/K60P38b<P01@39bLT0b/[:0<c<c03<c<`0
bLW90080c/k>00@0d=3@0<c<c03<c<`0d];B0P3De=@00`3WinL0oooo0?ooo`0R0?ooo`040?3`l03f
m_H0jn_[0>c/k0H0kno_00D0kNg]0>k^kP3]kNd0jn_[0>k^kP020?3`l00I0?7al@3fm_H0jn_[092@
T01TI6@0FEUI04=3@`0m?Cd0E5AD04Y:BP19BDT0CDe=03Hf=P0Z:RX0;2`/04Q8B038b<P0e]KF0=OG
e`3Hf=P0e]KF0=GEe@3IfMT0fm_K0=GEe@020=7Ad@030=?Cd`3Fe]H0dM7A00<0d=3@00P0dM7A0=3@
d03;bl/0d=3@0=;BdP3AdM40c<c<0<71`@80/k>c00T0^;Rh0;Vi^@2j^[X0_Kfm0<?3``39bLT0dM7A
0=3@d03?cll00`3Bd]80603=cLd0c/k>0<o?c`3?cll0cLg=0<[:bP39bLT0`L710;bl_02f][H0/[:b
0:FUY@2SXj<0S8b<07YjNP1[Jf/0F5QH04I6AP0k>c/0?Cdm0410@01=CDd0EeMG05eMG@80IFEU0180
GEeM06IVIP1hN7P0Ti>C0::RXP2OWil0Xj>S0:f][@2GUiL0EeMG05=CD`1gMgL0Rh^;0::RXP36a/H0
h^;R0>g]k@3/k>`60>g]k@<0k^k^0P3]kNd02@3^k^h0kNg]0>c/k03/k>`0k^k^0>g]k@3[jn/0j^[Z
0>g]k@020>k^kP060>_[j`3/k>`0k^k^0>k^kP3fm_H0lo?c9`3oool002D0oooo00@0i>CT0=SHf03H
f=P0emOG0P3Jf]X0103Kfm/0g=cL0=cLg03Ng]h20=[JfP040>7Qh@3Ogml0h^;R0>;RhP<0hn?S00D0
j^[Z07=cL`1cLg<0L71`061PH00207EeM@0406][J`1cLg<0Lg=c06=SH`80LW9b00D0KVi^0=?Cd`3C
dm<0emOG0=WIf@020=SHf0040=kNgP3Rh^80h^;R0=[JfP80g=cL00D0h^;R0=WIf@3IfMT0f=SH0=WI
f@020=_Kf`040=?Cd`3IfMT0fMWI0=_Kf`80d];B00D0_kno0;fm_@31`L40`L710;no_`020;fm_@04
0<?3``3;bl/0bl_;0<;2`P<0aLG500@0]kNg0;Rh^02h^;P0^;Rh0P2`/;00102][Jd0Y:BT0:BTY02L
W9`209ZJVP0508f=S@1mOGd0K6a/06a/K01DE5@00P11@D401@0k>c/0=CDe03De=@18B4P0CTi>0080
Cdm?00@0BDU905aLG01LG5`0KFe]0P1ZJVX01@1[Jf/0Hf=S06=SH`18B4P0;Bd]0080HF5Q00<0Ng]k
0:BTY02TY:@00`2f][H01@2h^;P0^[Zj0;Zj^P2l_;`0_[jn0080`<3000@0`/;20<C4a034a<@0a/K6
0P38b<P01@39bLT0b/[:0<c<c03<c<`0bLW90080c/k>00@0d=3@0<c<c03<c<`0d];B0P3De=@00`3W
inL0oooo0?ooo`0R0?ooo`040?3`l03gmoL0kno_0>k^kP@0kno_01`0k^k^0>o_k`3^k^h0kno_0>k^
kP3[jn/0k^k^0?3`l03alO40l?3`0?Gem@3Xj>P0PX:205mOG`1BDU80?Cdm0410@01IFET0Cdm?04U9
B@18B4P0?3`l02d];@0j>SX0NGUi0<[:bP3De=@0emOG0P3EeMD03@3Jf]X0g=cL0=OGe`3Cdm<0d];B
0=7Ad@3Cdm<0e=CD0=7Ad@3De=@0e]KF0=?Cd`3@d=000P3?cll20=7Ad@0S0<g=c@39bLT0`L710;:b
/P2^[Zh0]kNg0;^k^`2m_Kd0`L710<C4a03;bl/0c/k>0<c<c03?cll0dm?C0=7Ad@3=cLd0bLW90=3@
d03AdM40clo?0<g=c@3:b/X0bLW90<O7a`31`L40]kNg0;:b/P2XZ:P0Xj>S08n?S`1mOGd0JVYZ05UI
F@18B4P00P0e=CD02`0j>SX0BDU9051@D01IFET0J6QX06IVIP1SHf<0I6AT08F5Q@2NWYh0X:2P0080
WinO00/0YJFU0:>SX`1RHV80Hf=S07AdM026QXH0Xj>S0<o?c`3YjNT0kNg]0>c/k0060>g]k@H0k^k^
00L0k>c/0>_[j`3]kNd0kNg]0>k^kP3]kNd0k>c/00<0k^k^00H0k>c/0>g]k@3^k^h0k^k^0?KfmP3c
lo<W0?ooo`009@3oool00`3UiND0f=SH0=SHf0030=WIf@040=cLg03MgMd0gMgM0=gMg@@0h>3P0`3R
h^820>3Ph0050>SXj01jNWX0NWYj07YjNP1TI6@00P1fMWH0101gMgL0KVi^06i^KP1[Jf/205=CD`05
0;Zj^P3Cdm<0dm?C0=OGe`3Hf=P00P3Kfm/00`3Ogml0fMWI0=WIf@030=_Kf`<0f][J00D0gmoO0=[J
fP3Hf=P0f=SH0=WIf@020=GEe@050=3@d03AdM40dM7A0;fm_@2e]KD00`2m_Kd20<30`0040<;2`P31
`L40`L710<30`080`/;200D0^KVi0;Zj^P2l_;`0_;bl0;Fe]@020;2`/0040:j^[P2ZZZX0ZZZZ09jN
WP80VIVI00D0Shn?08:2PP1[Jf/0Jf][05IFEP0203hn?P0502l_;`0f=SH0=SHf03dm?@19BDT00P1=
CDd01015ADD0FEUI05UIF@1/K6`206EUI@0506QXJ01bLW80LW9b03Lg=`18B4P00P1>CTh0101cLg<0
/K6a0;6a/@2d];@20;Fe]@050;Ng]`2i^KT0^KVi0;^k^`2m_Kd00P2o_kl01031`L40`l?30<?3``35
aLD20<?3``050<O7a`39bLT0b/[:0<[:bP3=cLd00P3>c/h0103?cll0dM7A0=7Ad@3Bd]820=CDe003
0>OWi`3oool0oooo0280oooo00<0l_;b0?Ogm`3]kNd00P3^k^h0103]kNd0k^k^0>o_k`3^k^h20>g]
k@050>o_k`3^k^h0kNg]0>k^kP3_knl00P3`l?005`3dm?@0j>SX08B4Q01XJ6P0F5QH04A4A013@d<0
CTi>05=CD`1=CDd0?Cdm03/k>`0f=SH0EeMG0;:b/P3@d=00d];B0=KFeP3De=@0eMGE0=SHf03Fe]H0
dm?C00<0d];B00X0d=3@0<k>cP3@d=00dm?C0=GEe@3Bd]80clo?0=3@d03AdM40bl_;0P3=cLd03@3<
c<`0a/K60;Fe]@2[Zj/0/k>c0;Zj^P2m_Kd0`<300<C4a038b<P0b/[:0<_;b`3=cLd00P3@d=001P3;
bl/0clo?0=;BdP3>c/h0bl_;0<[:bP<0bLW901`0`l?30;fm_@2g]kL0ZJVY0:>SX`2GUiL0Ph>3071`
L01OGel0C4a<03Ti>@0d=3@0>CTi03lo?`1:BTX0FEUI06=SH`1UIFD0GEeM05=CD`2:RXX0ZJVY09fM
W@2JVYX0WYjN0:6QX@2ZZZX0IFEU0P1`L700101mOGd0XJ6Q0=CDe03[jn/20>c/k0L0kNg]1@3^k^h0
103]kNd0k>c/0>g]k@3]kNd20>c/k0P0k^k^00<0m_Kf0??cl`3oool09P3oool002D0oooo00@0i^KV
0=SHf03Hf=P0fMWI0P3Fe]H0103MgMd0g=cL0=cLg03Jf]X30>3Ph0<0h^;R00@0hn?S0>;RhP3Rh^80
e=CD0P1aLG401@22PX80MGEe071`L01`L700N7Qh0080IFEU00@0GemO0:VYZ@2YZJT0fm_K0P3AdM40
1@3Fe]H0emOG0=SHf03Hf=P0g=cL0080fMWI00@0f][J0=_Kf`3Kfm/0dm?C0P3De=@01@3Fe]H0emOG
0=SHf03Hf=P0dM7A0080d=3@00@0dm?C0=GEe@3EeMD0`L71102d];@20;Fe]@040;Rh^02n_[h0_[jn
0;^k^`80_[jn00D0^[Zj0;bl_02c/k<0/k>c0;6a/@020:n_[`040:j^[P2WYjL0YjNW0:NWY`80UiNG
00D0TY:B08F5Q@1fMWH0MWIf05]KF`0204Q8B00502`/;00g=cL0=cLg03@d=01;Bd/00P14A4@0100m
?Cd0EEEE05EEE@1RHV82061PH00505aLG01^KVh0KVi^018B4P13@d<00P1EEED0101/K6`0/k>c0;>c
/`2b/[820;Bd]0050;Jf]P2h^;P0^;Rh0;Zj^P2l_;`00P2o_kl01031`L40`l?30<?3``34a<@20<K6
aP050<O7a`39bLT0b<S80<S8b03<c<`00P3>c/h0103?cll0dM7A0=7Ad@3Bd]820=CDe0030>OWi`3o
ool0oooo0280oooo00T0l_;b0?Ogm`3]kNd0k^k^0>c/k03Zj^X0k^k^0>g]k@3^k^h00P3[jn/20>k^
kP<0kno_01D0k^k^0>o_k`3^k^h0bl_;075aL@1SHf<0Fe]K04m?C`1;Bd/0BDU9051@D018B4P0=3@d
03De=@1IFET0VYZJ0=;BdP3@d=00dM7A0=GEe@3De=@00P3Cdm<0203EeMD0dm?C0=7Ad@3Bd]80dM7A
0<g=c@38b<P0b/[:0P3=cLd04@3>c/h0d=3@0=3@d03<c<`0a/K60<c<c03@d=00dM7A0<c<c02k^k/0
Zj^[0:n_[`2c/k<0]kNg0;Vi^@2j^[X0`l?30080bLW900H0bl_;0<o?c`3?cll0c/k>0=;BdP3=cLd4
0<S8b00T0<W9b@38b<P0`/;20<;2`P2k^k/0[:b/0:JVYP2KVi/0S8b<07UiN@1UIFD0De=C04=3@`0a
<C40>CTi03Xj>P15ADD0FEUI06ATI01PH600EeMG055AD@29RHT0YZJV09ZJVP2KVi/0W9bL08b<S02W
YjL0EeMG07=cL`1jNWX0Ph>30:2PX03EeMD0kNg]0P3/k>`70>g]k@L0k^k^0P3]kNd00`3[jn/0k>c/
0>k^kP070>k^kP030?KfmP3clo<0oooo02H0oooo000U0?ooo`040>KViP3Hf=P0f=SH0=WIf@80e]KF
00@0gMgM0=cLg03Lg=`0f][J0`3Ph>030>;RhP040>?Sh`3Rh^80h^;R0=CDe080LG5a00D0PX:207Ee
M@1`L700L71`07QhN00206EUI@0405mOG`2YZJT0ZJVY0=_Kf`80dM7A00D0e]KF0=OGe`3Hf=P0f=SH
0=cLg0020=WIf@040=[JfP3Kfm/0fm_K0=?Cd`80e=CD00D0e]KF0=OGe`3Hf=P0f=SH0=7Ad@020=3@
d0040=?Cd`3EeMD0eMGE0<71`@@0];Bd0P2e]KD0102h^;P0_[jn0;jn_P2k^k/20;jn_P050;Zj^P2l
_;`0/k>c0;>c/`2a/K400P2_[jl0102^[Zh0YjNW0:NWY`2WYjL209NGU`0509:BTP25QHD0MWIf07If
MP1KFe/00P18B4P01@0/;2`0=cLg03Lg=`0d=3@0Bd];0080A4A400@0?Cdm05EEE@1EEED0HV9R0P1P
H6001@1LG5`0KVi^06i^KP0B4Q80@d=30080EEEE00@0K6a/0;>c/`2c/k<0/[:b0P2d];@01@2f][H0
^;Rh0;Rh^02j^[X0_;bl0080_kno00@0`L710<?3``33`l<0a<C40P36a/H01@37alL0bLW90<S8b038
b<P0c<c<0080c/k>00@0clo?0=7Ad@3AdM40d];B0P3De=@00`3WinL0oooo0?ooo`0R0?ooo`040?3`
l03gmoL0kno_0>k^kP80k>c/00<0kNg]0>WYj@3]kNd00P3/k>`50>k^kP060>_[j`3^k^h0g]kN09VI
V@1XJ6P0H61P0P1DE5@0101IFET0Cdm?04e=C@0j>SX203De=@0507UiN@3AdM40dm?C0<W9b@3Cdm<0
0P3EeMD0103Bd]80dm?C0=SHf03Cdm<20=3@d0040<c<c034a<@0`l?30<C4a080alO70140bl_;0=3@
d03>c/h0a/K60<[:bP3>c/h0clo?0=3@d03=cLd0_kno0:ZZZP2YZJT0ZZZZ0;2`/02d];@0/[:b0<71
`@020<O7a`080<_;b`3=cLd0bLW90<W9b@3;bl/0b<S80<K6aP37alL40<W9b@0R0<C4a030`<00^[Zj
0;6a/@2ZZZX0W9bL096AT@1mOGd0J6QX05UIF@14A4@0:2PX034a<@0i>CT0@D5105MGE`1XJ6P0GemO
05aLG01KFe/0QXJ609bLW02HV9P0XZ:R09RHV01XJ6P0WYjN04a<C01^KVh0R8R809BDU02XZ:P0f][J
0>o_k`<0k>c/1@3]kNd80>k^kP030>g]k@3/k>`0k^k^00T0k^k^00<0m_Kf0??cl`3oool09P3oool0
02D0oooo00@0j>SX0=WIf@3IfMT0emOG0P3Jf]X0103Lg=`0f][J0=[JfP3Ng]h20>3Ph0050>7Qh@3R
h^80hn?S0>?Sh`3Ti>@00P3UiND01@2[Zj/0YZJV0:JVYP24Q8@0OGem0080LG5a00@0NGUi065QH@1Q
HF40GEeM1@3>c/h0103EeMD0g]kN0=SHf03Hf=P30=_Kf`040=KFeP3>c/h0c/k>0<k>cP80dM7A00D0
clo?0=7Ad@3Hf=P0f=SH0<k>cP020=7Ad@050=3@d03AdM40dM7A0<30`02`/;000P2XZ:P00`2][Jd0
[jn_0:n_[`030;Ng]`050;Zj^P2d];@0];Bd0:j^[P2d];@00P2b/[80102`/;00[jn_0:n_[`2^[Zh2
0:^[Z`0509bLW02RXZ80XZ:R09>CT`2;Rh/00P1hN7P0101QHF40BTY:04Y:BP0W9bL202<S8`0503De
=@11@D40AdM704M7A`0l?3`00P1CDe<0101MGEd0FUYJ05YJFP1=CDd205IFEP0501XJ6P0/;2`0Fe]K
05]KF`1mOGd00P2a/K430:n_[`050;Bd]02g]kL0]kNg0;Vi^@2l_;`00P2n_[h01030`<00`/;20<;2
`P34a<@30<K6aP040<S8b03:b/X0b/[:0<c<c080c/k>00@0clo?0=7Ad@3AdM40d];B0P3De=@00`3W
inL0oooo0?ooo`0R0?ooo`030??cl`3fm_H0k^k^0080jn_[00@0k^k^0>g]k@3Zj^X0k>c/0`3^k^h4
0>g]k@0C0>[ZjP3_knl0d=3@07IfMP21PH40LG5a055AD@1GEeL0GUiN04Y:BP1<C4`0<S8b03lo?`1;
Bd/0Q8B40<_;b`38b<P0a/K60=7Ad@020=SHf0<0d];B02L0dM7A0<g=c@3;bl/0a<C40;Vi^@2n_[h0
`<300<71`@32`/80aLG50<_;b`3=cLd0alO70<S8b03>c/h0clo?0=3@d03=cLd0_Kfm0:RXZ02UYJD0
YjNW0:ZZZP2][Jd0^[Zj0<71`@34a<@0b<S80<G5a@31`L40_kno0;bl_031`L40`/;20<71`@32`/80
a<C40<K6aP38b<P00P36a/H0902m_Kd0^k^k0;2`/02YZJT0XZ:R09>CT`21PH40KFe]05]KF`1:BTX0
:b/[020P800_;bl0@D51051@D01OGel0IFEU05iNGP1JFUX0QHF509jNWP2GUiL0VYZJ09>CT`1DE5@0
T92@059BDP1RHV80QhN70:>SX`2m_Kd0h>3P0>k^kP3/k>`0jn_[0>WYj@L0kNg]1P3^k^h0103]kNd0
k>c/0>k^kP3^k^h20>g]k@H0k^k^00<0m_Kf0??cl`3oool09P3oool002D0oooo00@0jNWY0=SHf03H
f=P0emOG0P3Jf]X0103Lg=`0fm_K0=_Kf`3MgMd20=oOg`050>3Ph03MgMd0gmoO0=oOg`3Ph>000P3[
jn/01@29RHT0^;Rh0;Rh^01oOgl0QHF50080Ph>300@0Jf][06=SH`1SHf<0]kNg0P3<c<`01@2i^KT0
dM7A0=7Ad@3EeMD0e]KF0080f=SH00@0emOG0=KFeP3Fe]H0dm?C0P3Fe]H01@34a<@0^[Zj0;Zj^P39
bLT0c<c<0080clo?00@0a<C40<[:bP3:b/X0cLg=0P3?cll01@2d];@0YZJV0:VYZ@2YZJT0WinO0080
Xj>S00@0/;2`0;6a/@2a/K40[:b/0P2XZ:P01@2SXj<0WYjN09ZJVP2JVYX0VIVI0080UiNG00@0YJFU
0:>SX`2SXj<0Xj>S0P2QXJ401@2CTi<0QHF507QhN01hN7P0HV9R0080De=C00D0@D51014A4@0A4A40
9RHV03`l?00203Xj>P0404M7A`16ATH0ATI606ATI0<0?Cdm0P1MGEd01@0Y:BT07QhN06=SH`1SHf<0
QhN700<0[:b/0P2`/;001@2c/k<0][Jf0;Jf]P2i^KT0]kNg0080_[jn00@0`<300<;2`P32`/80a<C4
0P36a/H01@38b<P0bLW90<[:bP3:b/X0bl_;0080c<c<00@0clo?0=7Ad@3AdM40d];B0P3De=@00`3W
inL0oooo0?ooo`0R0?ooo`030??cl`3fm_H0k^k^0080jn_[0P3^k^h01@3]kNd0j^[Z0>c/k03^k^h0
k>c/00<0jNWY01<0j>SX0>[ZjP3clo<0aLG505ADE020P800JFUY05eMG@1OGel0F5QH05EEE@15ADD0
:BTY04];B`2:RXX0^KVi0<71`@2g]kL0alO700<0dm?C00D0d];B0=3@d03;bl/0b<S80<G5a@020<?3
``0J0;bl_02][Jd0[:b/0;Fe]@2m_Kd0`L710<G5a@37alL0`<300<;2`P3;bl/0clo?0=7Ad@39bLT0
]KFe0:2PX02TY:@0YJFU0:BTY02XZ:P0/k>c0;no_`32`/80_[jn0;^k^`2g]kL20;6a/@090:j^[P2_
[jl0Zj^[0:f][@2b/[80][Jf0<30`031`L40`<300080_kno01l0/K6a0:VYZ@2MWId0TI6A0820P01b
LW80IFEU059BDP10@40071`L02<S8`0d=3@0B4Q805aLG01OGel0JFUY05QHF01lO7`0WinO09FEU@26
QXH0Q8B4055AD@2HV9P0DU9B05iNGP2ATI40YjNW0<K6aP3Ti>@0kNg]00<0k>c/0`3]kNd00`3^k^h0
jn_[0>[ZjP070>k^kP80kNg]0P3^k^h00`3/k>`0j^[Z0>k^kP050>k^kP030?KfmP3clo<0oooo02H0
oooo000U0?ooo`040>OWi`3IfMT0fMWI0=[JfP80fm_K00@0f][J0=gMg@3MgMd0g]kN0P3Lg=`20>7Q
h@D0i>CT00D0XJ6Q09nOW`2OWil0MGEe07YjNP0208J6QP0404e=C@22PX80PX:20;^k^`80WIfM00D0
][Jf0=7Ad@3AdM40e=CD0=KFeP020=CDe0040<G5a@2g]kL0]kNg0;Fe]@80[Jf]00<0Z:RX0:>SX`2S
Xj<00P2i^KT20<o?c`<0alO70`3<c<`01@2j^[X0Xj>S09jNWP2NWYh0UiNG0080VYZJ00@0UIFE09BD
U02DU9@0XZ:R0P2GUiL01@1_Kfl0Q8B408R8R028R8P0PX:20080RHV900@0XZ:R09bLW02LW9`0V9RH
0P2GUiL01@2BTY80QhN707MgM`1gMgL0I6AT0080CTi>00D0?Shn03`l?00l?3`0820P03<c<`02038b
<P0403hn?P16ATH0ATI605EEE@80?Shn00D0>3Ph05iNGP1NGUh06ATI02HV9P02065QH@0408R8R02/
[:`0[:b/0:ZZZP80[Zj^00D0/[:b0;Fe]@2e]KD0^;Rh0;^k^`020;fm_@040<30`032`/80`/;20<C4
a080a/K600D0alO70<W9b@3;bl/0bl_;0<c<c0020<k>cP040<o?c`3AdM40dM7A0=;BdP80e=CD00<0
inOW0?ooo`3oool08P3oool00`3clo<0m_Kf0>k^kP020>g]k@<0k^k^0P3]kNd00`3[jn/0k>c/0>SX
j0040>_[j`0B0?Gem@3@d=00HF5Q079bLP1MGEd0EUIF05MGE`1FEUH0D51@02PX:00n?Sh0BDU909NG
U`2n_[h0XZ:R0;2`/03;bl/0eMGE0P3Bd]803`3@d=00c<c<0<G5a@2g]kL0XZ:R09BDU02LW9`0Zj^[
0:6QX@2EUID0YZJV0:n_[`2k^k/0bLW90<K6aP020<71`@090<_;b`3@d=00dM7A0<c<c02l_;`0WIfM
09ZJVP2KVi/0YZJV0080/K6a00T0`<300;Ng]`2`/;00ZZZZ0::RXP2IVIT0SXj>092@T02KVi/00P2N
WYh09`2RXZ80[Jf]0;jn_P30`<00^;Rh0;Fe]@2f][H0/;2`0:RXZ02OWil0TI6A08F5Q@1bLW80GUiN
05=CD`18B4P0=3@d02d];@0^;Rh0?clo05EEE@1GEeL0Hf=S05]KF`1gMgL0T92@08Z:RP20P800NGUi
05YJFP2NWYh0BTY:065QH@2FUYH0WinO0<G5a@3Zj^X0lO7a0>c/k0070>g]k@030>c/k03]kNd0k^k^
00T0k^k^00<0kNg]0>c/k03^k^h01@3^k^h00`3fm_H0lo?c0?ooo`0V0?ooo`009@3oool0103WinL0
fMWI0=WIf@3Jf]X20=_Kf`040=[JfP3MgMd0gMgM0=kNgP80g=cL0P3QhN450>CTi0050:6QX@2OWil0
WinO07EeM@1jNWX00P26QXH0101=CDd0PX:208:2PP2k^k/209fMW@050;Jf]P3AdM40dM7A0=CDe03F
e]H00P3De=@01035aLD0]kNg0;Ng]`2e]KD20:f][@030:RXZ02SXj<0Xj>S0080^KVi0P3?cll30<O7
a`<0c<c<00D0^[Zj0:>SX`2NWYh0WYjN09NGU`0209ZJVP0409FEU@2DU9@0U9BD0::RXP80UiNG00D0
Kfm_08B4Q028R8P0R8R808:2PP0208V9R@040::RXP2LW9`0W9bL09RHV080UiNG00D0TY:B08N7Q`1g
MgL0MgMg06ATI00204i>CP0503hn?P0l?3`0?3`l020P800c<c<00P0b<S80100n?Sh0ATI604I6AP1E
EED203hn?P0503Ph>01NGUh0GUiN01TI6@0V9RH00P1QHF401028R8P0[:b/0:b/[02ZZZX20:j^[P05
0;:b/P2e]KD0]KFe0;Rh^02k^k/00P2m_Kd01030`<00`/;20<;2`P34a<@20<K6aP050<O7a`39bLT0
bl_;0<_;b`3<c<`00P3>c/h0103?cll0dM7A0=7Ad@3Bd]820=CDe0030>OWi`3oool0oooo0280oooo
00<0l?3`0?KfmP3^k^h00P3^k^h0103]kNd0jn_[0>g]k@3[jn/30>c/k00T0>_[j`3]kNd0kNg]0>g]
k@3^k^h0g]kN0:RXZ01`L700K6a/051@D01<C4`0CDe=051@D01>CTh09bLW04i>CP1oOgl0/;2`0;6a
/@2HV9P0[Jf]0<c<c03AdM40dm?C0=3@d037alL0]kNg09VIV@2@T900UiNG09^KV`29RHT0LW9b07Qh
N020P800UiNG0P2JVYX01@2_[jl0aLG50<?3``30`<00bl_;0080dM7A0140cLg=0<30`02MWId0W9bL
09NGU`2PX:00Vi^K075aL@28R8P0T92@09bLW02`/;00Y:BT07AdM01RHV80N7Qh08B4Q00208>3P`0D
08R8R02HV9P0/K6a0;Jf]P2c/k<0/K6a0;:b/P2/[:`0ZJVY09fMW@2ATI40PX:2075aL@1SHf<0EUIF
04U9B@1<C4`0=cLg02LW9`0j>SX205=CD`0@05eMG@1TI6@0NGUi08f=S@29RHT0O7al07IfMP1JFUX0
WinO05EEE@1dM7@0WinO0:>SX`3>c/h0jn_[0>o_k`L0kNg]203^k^h00`3]kNd0jn_[0>k^kP0:0>k^
kP030?KfmP3clo<0oooo02H0oooo000U0?ooo`040>SXj03IfMT0fMWI0=[JfP<0fm_K0P3MgMd01@3N
g]h0gmoO0=oOg`3Ph>00hN7Q0080iNGU00@0i^KV0<S8b038b<P0Xj>S0P2BTY801@1jNWX0Jf][08B4
Q024Q8@0EeMG0080O7al00@0`/;20;6a/@2a/K40]kNg0`3AdM40103>c/h0_;bl0;bl_02VYZH20<K6
aP040=gMg@2<S8`0S8b<07moO`80W9bL00D0YjNW0:BTY030`<00`<300;Jf]P020<K6aP050<[:bP32
`/80`/;20;Rh^02UYJD00P2FUYH01024Q8@0SXj>08j>SP1JFUX20:j^[P050;Jf]P1cLg<0Lg=c06AT
I028R8P00P1cLg<0101jNWX0K6a/06a/K029RHT209NGU`0509VIV@2FUYH0UYJF08f=S@29RHT00P1c
Lg<0101RHV80DE5A055AD@0m?Cd202l_;`0500X:2P0c<c<0?Shn03hn?P0Z:RX00P1<C4`0101DE5@0
<C4a034a<@0i>CT205QHF00500H61P1=CDd0Hf=S06=SH`2FUYH00P2RXZ80102YZJT0[Jf]0:f][@2a
/K420;Fe]@050;Rh^02k^k/0_Kfm0;fm_@30`<000P2o_kl01@34a<@0a/K60<K6aP35aLD0bLW90080
bl_;00@0c<c<0<k>cP3>c/h0clo?0P3AdM40103Bd]80e=CD0=CDe03WinLT0?ooo`030?7al@3fm_H0
k^k^0080k^k^00P0kNg]0>_[j`3]kNd0jn_[0>c/k03]kNd0k>c/0>[ZjP<0k>c/0600lO7a0<K6aP21
PH40QHF5071`L01GEeL0@d=30451@@1ADE40DU9B02h^;P0g=cL0WinO0<C4a02][Jd0YJFU0;6a/@3<
c<`0d];B0<k>cP36a/H0/k>c09BDU024Q8@0U9BD0;Fe]@2TY:@0Kfm_04m?C`1FEUH0KVi^08>3P`2?
Shl0S8b<09ZJVP2i^KT0][Jf0;fm_@3;bl/0dM7A0<o?c`39bLT0`<300::RXP2JVYX0SXj>08f=S@2;
Rh/0J6QX05IFEP2BTY80^k^k0:n_[`25QHD0H61P05aLG01gMgL0K6a/07UiN@1oOgl0Lg=c07]kN`2G
UiL0ZZZZ0:j^[P2`/;00/[:b0:RXZ02VYZH0WYjN08n?S`1mOGd0LW9b06QXJ01EEED0B4Q804E5A@0U
9BD061PH03Hf=P1GEeL0EEEE04m?C`1SHf<0OGem08b<S022PX80Lg=c07EeM@1QHF40WIfM069RHP2>
SXh0YZJV0:ZZZP3Kfm/80>g]k@H0k^k^0P3/k>`0103^k^h0kNg]0>_[j`3]kNd80>k^kP80kNg]00<0
m_Kf0??cl`3oool09P3oool002D0oooo00<0jNWY0=WIf@3IfMT00`3Jf]X0103Kfm/0gMgM0=gMg@3J
f]X20>3Ph0050>;RhP3Ti>@0i^KV0>KViP3^k^h00P3oool00`2d];@0KVi^06i^KP0206MWI`80MWIf
00@0N7Qh09RHV02HV9P0^k^k0P2RXZ801@2f][H0b<S80<S8b03;bl/0^KVi0080XJ6Q00@0I6AT0:b/
[02/[:`0d];B0P37alL01@1BDU80WIfM09fMW@1YJFT0SHf=0080UiNG00@0^[Zj0<O7a`37alL0b<S8
0P31`L401@2f][H0[jn_08f=S@2=SHd0PX:20080LW9b00@0Rh^;04i>CP1>CTh0WYjN0P2MWId01@0P
8200N7Qh07MgM`1gMgL0ATI60080E5AD00@0N7Qh0820P020P800TI6A0P2?Shl01@27QhL0Ogmo07Mg
M`1gMgL0HF5Q0080BDU900<0ATI601DE5@0E5AD00P0@410203/k>`0402h^;P17AdL0AdM704E5A@80
@T9200D0?3`l05EEE@1EEED0000004];B`0206MWI`0409ZJVP2QXJ40XJ6Q0:RXZ080[Jf]00D0/K6a
0;Fe]@2e]KD0^;Rh0;^k^`020;fm_@040<30`032`/80`/;20<C4a080a/K600D0b<S80<[:bP3;bl/0
bl_;0<g=c@020<k>cP040=3@d03AdM40dM7A0=;BdP80e=CD00<0inOW0?ooo`3oool08P3oool00`3c
lo<0m_Kf0>k^kP040>k^kP80kNg]0`3/k>`02P3YjNT0k>c/0>c/k03/k>`0m?Cd0=WIf@2PX:00Rh^;
06EUI@1GEeL203Ph>00l05EEE@1BDU80>SXj038b<P2NWYh0`/;20:ZZZP2YZJT0];Bd0<[:bP3Bd]80
`l?30;>c/`2HV9P0Lg=c06IVIP2HV9P0`/;209JFUP1/K6`0Hf=S038b<P1NGUh0HF5Q07EeM@27QhL0
Shn?0::RXP2/[:`0_kno0<g=c@3AdM40cLg=0<O7a`30`<00Zj^[09FEU@25QHD0O7al08:2PP2<S8`0
J6QX09:BTP3:b/X0UYJF06UYJ@1bLW80ADE506m_K`1KFe/0PX:207emO@1ADE40HF5Q0820P02JVYX0
X:2P0:RXZ02^[Zh0YZJV0P2MWId06`2?Shl0Ogmo075aL@1QHF40DU9B04Y:BP0];Bd04Q8B010@400Z
:RX0BTY:05EEE@15ADD0Hf=S07YjNP20P800NWYj079bLP1fMWH0Jf][09ZJVP1RHV80V9RH0:BTY02b
/[80i>CT0?3`l0040>g]k@T0k^k^00@0jn_[0>c/k03^k^h0k^k^0P3]kNd60>k^kP@0kNg]00<0m_Kf
0??cl`3oool09P3oool002D0oooo00<0jNWY0=WIf@3IfMT00`3Jf]X0103Kfm/0gMgM0=gMg@3Jf]X2
0>3Ph0050>;RhP3Ti>@0i^KV0>KViP3^k^h00P3oool00`2d];@0KVi^06i^KP0206MWI`80MWIf00@0
N7Qh09RHV02HV9P0^k^k0P2RXZ801@2f][H0b<S80<S8b03;bl/0^KVi0080XJ6Q00@0I6AT0:b/[02/
[:`0d];B0P37alL01@1BDU80WIfM09fMW@1YJFT0SHf=0080UiNG00@0^[Zj0<O7a`37alL0b<S80P31
`L401@2f][H0[jn_08f=S@2=SHd0PX:20080LW9b00@0Rh^;04i>CP1>CTh0WYjN0P2MWId01@0P8200
N7Qh07MgM`1gMgL0ATI60080E5AD00@0N7Qh0820P020P800TI6A0P2?Shl01@27QhL0Ogmo07MgM`1g
MgL0HF5Q0080BDU900<0ATI601DE5@0E5AD00P0@410203/k>`0402h^;P17AdL0AdM704E5A@80@T92
00D0?3`l05EEE@1EEED0000004];B`0206MWI`0409ZJVP2QXJ40XJ6Q0:RXZ080[Jf]00D0/K6a0;Fe
]@2e]KD0^;Rh0;^k^`020;fm_@040<30`032`/80`/;20<C4a080a/K600D0b<S80<[:bP3;bl/0bl_;
0<g=c@020<k>cP040=3@d03AdM40dM7A0=;BdP80e=CD00<0inOW0?ooo`3oool08P3oool00`3clo<0
m_Kf0>k^kP030>k^kP<0kNg]00<0j^[Z0>_[j`3/k>`0103/k>`0H@3UiND0i>CT0<g=c@1kNg/0EUIF
04U9B@0g=cL0?Cdm055AD@1@D500E5AD065QH@2[Zj/0^KVi09nOW`2PX:00/k>c0<G5a@3<c<`0][Jf
09jNWP1oOgl0EUIF03Hf=P1/K6`0SXj>075aL@1]KFd0K6a/01PH601FEUH0BDU905EEE@1eMGD0QXJ6
09RHV02e]KD0aLG50<g=c@3@d=00c/k>0<S8b031`L40];Bd09bLW02<S8`0O7al079bLP20P800QXJ6
06i^KP2IVIT0Lg=c05eMG@1/K6`04Q8B04a<C01?Cdl0LG5a05YJFP0`<300De=C07QhN028R8P0SXj>
09^KV`2UYJD0Xj>S09BDU02ATI40S8b<07alO01XJ6P0FUYJ05EEE@1<C4`0:RXZ01LG5`0K6a/092@T
03<c<`1;Bd/0B4Q806QXJ01cLg<0LW9b07AdM01gMgL0NGUi06e]K@2IVIT0I6AT092@T02SXj<0alO7
0>WYj@3_knl05@3^k^h30>g]k@030>k^kP3]kNd0kNg]0080kNg]00<0m_Kf0??cl`3oool09P3oool0
02D0oooo00<0jNWY0=WIf@3IfMT00`3Jf]X0103Lg=`0gMgM0=gMg@3Ng]h20>3Ph0050>7Qh@3Shn<0
i>CT0>CTi03[jn/00P2NWYh01@2/[:`0RXZ:08Z:RP1_Kfl0Lg=c0080LW9b00@0Ng]k0:RXZ02XZ:P0
ZZZZ0P2XZ:P01@2f][H0bLW90<W9b@2o_kl0/K6a0080TY:B00@0P82008>3P`23Ph<0HF5Q0P1GEeL0
1@1eMGD0Rh^;08^;R`28R8P0Vi^K0080]KFe00@0^k^k0<?3``33`l<0a<C40P2n_[h01@2d];@0[:b/
09jNWP2NWYh0RHV90080Ng]k00@0IVIV06m_K`1_Kfl0KVi^0P0k>c/01@16ATH0@D5104E5A@15ADD0
E5AD0080FEUI00@0MWIf07MgM`1gMgL0PX:20P28R8P01023Ph<0MWIf06][J`1[Jf/304e=C@050451
@@0b<S80<S8b01`L700X:2P00P0P8200100];Bd0ATI604I6AP0m?Cd202h^;P050492@P1IFET0FEUI
01`L701=CDd00P1gMgL0102OWil0Y:BT0:BTY02YZJT20:f][@050;6a/@2e]KD0]KFe0;Rh^02k^k/0
0P2m_Kd01030`<00`/;20<;2`P34a<@20<K6aP050<S8b039bLT0bl_;0<_;b`3<c<`00P3=cLd0103@
d=00dM7A0=7Ad@3Bd]820=CDe0030>OWi`3oool0oooo0280oooo00@0lo?c0?KfmP3^k^h0k^k^1P3]
kNd50>c/k0090>o_k`2i^KT0Vi^K0;:b/P23Ph<0Jf][05=CD`16ATH0BTY:0080D51@01d0Fe]K07]k
N`2[Zj/0Zj^[09bLW02TY:@0/k>c0<O7a`3<c<`0[Zj^09^KV`1eMGD0AdM705EEE@1GEeL0@41002@T
900O7al0<30`04Q8B01KFe/0G5aL06YZJP22PX80VYZJ0;2`/02k^k/0b<S80<_;b`020<o?c`0h0<S8
b031`L40][Jf0:ZZZP2IVIT0S8b<0861P@1aLG40Jf][07YjNP24Q8@0FEUI02XZ:P0V9RH0;bl_02h^
;P0m?Cd0>c/k04A4A01@D500FEUI07UiN@23Ph<0QHF5092@T02LW9`0WYjN09BDU028R8P0PH6106a/
K01KFe/0G5aL05UIF@1:BTX0?3`l02DU9@0X:2P0=SHf03Lg=`0h>3P0ADE5069RHP1dM7@0LG5a06MW
I`1YJFT0Ng]k07MgM`2MWId0Kfm_08j>SP2YZJT0g]kN0>k^kP3_knlE0>k^kP040>c/k03Zj^X0kNg]
0>k^kP@0kNg]00<0m_Kf0??cl`3oool09P3oool002D0oooo00@0jNWY0=WIf@3IfMT0f][J0P3IfMT0
103Lg=`0gMgM0=gMg@3MgMd20>3Ph0050>7Qh@3Ph>00h^;R0>;RhP3UiND00P2][Jd01@2LW9`0Kfm_
06m_K`1YJFT0LG5a0080HF5Q00@0Ogmo0:>SX`2SXj<0YjNW0P2QXJ401@2b/[80a/K60<K6aP37alL0
bl_;0080`l?300@0][Jf0:NWY`2WYjL0WinO0P2QXJ401@2RXZ80ZZZZ0:ZZZP2TY:@0[Jf]0080_;bl
00@0`/;20<30`030`<00`L710P2n_[h01@2f][H0/[:b0:>SX`2SXj<0SHf=0080RXZ:00@0RHV907Ee
M@1eMGD0Q8B40P20P8001@1fMWH0Jf][06m_K`1_Kfl0OGem0080SXj>00@0Rh^;08Z:RP2:RXX0SHf=
0P28R8P01@1kNg/0NGUi06UYJ@1YJFT0CTi>0080Bd];00D0>CTi03<c<`0c<c<07alO02TY:@0302DU
9@80DE5A00@0@D51034a<@0a<C40CTi>0P1RHV801@0Y:BT0EUIF08n?S`2?Shl0XJ6Q0080YZJV00@0
ZZZZ0:n_[`2_[jl0/[:b0P2e]KD01@2h^;P0^k^k0;jn_P2n_[h0`<300080`/;200D0a<C40<K6aP36
a/H0b<S80<W9b@020<_;b`040<g=c@3>c/h0c/k>0=3@d080dM7A00@0dm?C0=;BdP3Bd]80inOW903o
ool01P3clo<0m_Kf0>k^kP3^k^h0jn_[0>[ZjP<0kNg]0P3Zj^X40>c/k00B0?3`l02][Jd0Ng]k09^K
V`2?Shl0HF5Q04Q8B01BDU80F5QH04a<C016ATH0DE5A0820P02VYZH0Z:RX09jNWP2TY:@0/k>c0P38
b<P0?@2m_Kd0/[:b09fMW@20P800Jf][05]KF`18B4P0?Shn03dm?@11@D40CDe=06=SH`1jNWX0TI6A
0:FUY@2e]KD0`<300<;2`P39bLT0clo?0=7Ad@3?cll0b<S80<;2`P31`L40]kNg0:VYZ@2OWil0UIFE
08V9R@1mOGd0I6AT06a/K01dM7@0K6a/061PH01BDU80?Cdm03Lg=`0j>SX0De=C07AdM024Q8@0QhN7
08V9R@2ATI40VYZJ0:2PX02EUID0UYJF08f=S@1kNg/0IVIV05]KF`1IFET0E5AD055AD@15ADD0;Rh^
02d];@0d=3@00P0_;bl03`10@400IFEU07YjNP1gMgL0JFUY06QXJ01mOGd0R8R80:>SX`1dM7@0TI6A
0;6a/@3UiND0l?3`0>o_k`0E0>k^kP<0kNg]00<0k^k^0>g]k@3]kNd00P3]kNd00`3fm_H0lo?c0?oo
o`0V0?ooo`009@3oool0103YjNT0fMWI0=WIf@3Jf]X20=WIf@040=cLg03MgMd0gMgM0=gMg@80h>3P
00D0hN7Q0>3Ph03Rh^80h^;R0>GUi@020:f][@0509bLW01_Kfl0Kfm_06UYJ@1aLG400P1QHF40101o
Ogl0Xj>S0:>SX`2WYjL20:6QX@050;:b/P36a/H0a/K60<O7a`3;bl/00P33`l<0102f][H0YjNW0:NW
Y`2OWil20:6QX@050::RXP2ZZZX0ZZZZ0:BTY02][Jd00P2l_;`01032`/80`<300<30`031`L420;jn
_P050;Jf]P2b/[80Xj>S0:>SX`2=SHd00P2:RXX01029RHT0MGEe07EeM@24Q8@20820P00507IfMP1[
Jf/0Kfm_06m_K`1mOGd00P2>SXh0102;Rh/0RXZ:08Z:RP2=SHd208R8R00507]kN`1iNGT0JFUY06UY
J@1>CTh00P1;Bd/01@0i>CT0<c<c03<c<`0O7al0:BTY00<09BDU0P1ADE401011@D40<C4a034a<@1>
CTh2069RHP0502TY:@1FEUH0Shn?08n?S`2QXJ400P2VYZH0102ZZZX0[jn_0:n_[`2b/[820;Fe]@05
0;Rh^02k^k/0_[jn0;jn_P30`<000P32`/801@34a<@0a/K60<K6aP38b<P0bLW90080bl_;00@0cLg=
0<k>cP3>c/h0d=3@0P3AdM40103Cdm<0d];B0=;BdP3WinLT0?ooo`060??cl`3fm_H0k^k^0>k^kP3]
kNd0k>c/0`3]kNd20>_[j`0/0>c/k03[jn/0j>SX0>[ZjP3]kNd0emOG0:ZZZP25QHD0L71`04i>CP10
@400B4Q804a<C011@D40@41006=SH`25QHD0VIVI09nOW`2JVYX0W9bL0:n_[`36a/H0c<c<0<g=c@3;
bl/0`<300;Jf]P2/[:`0X:2P09NGU`2BTY80Ti>C09NGU`2KVi/0WinO09VIV@2NWYh0ZZZZ0;Jf]P35
aLD0cLg=0<_;b`3>c/h20=3@d00D0<k>cP39bLT0a<C40;Zj^P2XZ:P0WinO09^KV`2CTi<0Vi^K09:B
TP2CTi<0TI6A08^;R`28R8P0PH6107alO01nOWh0QHF508n?S`2LW9`20:JVYP090:FUY@2SXj<0YJFU
0:BTY02DU9@0SXj>08f=S@21PH40JFUY0080GEeM01H0D51@0410@00m?Cd0;Bd]02`/;00j>SX0@410
03/k>`0j>SX0H61P08:2PP1mOGd0IfMW06][J`26QXH0TY:B0:RXZ01hN7P0Xj>S0=CDe03bl_80lO7a
0P3_knlG0>k^kP@0kNg]00<0k>c/0?;blP3clo<09`3oool002D0oooo00@0jNWY0=SHf03Hf=P0f=SH
0P3Kfm/0103Hf=P0gMgM0=gMg@3Ng]h30>3Ph0040=oOg`3Ph>00h>3P0>CTi080^[Zj00D0MGEe05=C
D`1CDe<0GemO079bLP0205EEE@0407MgM`2DU9@0U9BD0:BTY080UIFE00D0/K6a0<?3``33`l<0bLW9
0=7Ad@060<o?c`80YJFU00D0Rh^;07YjNP1jNWX0QHF50;Jf]P020<C4a0<0`l?300D0_kno0;jn_P2n
_[h0^KVi0;Rh^0020:FUY@0409:BTP1YJFT0JFUY06ATI080Jf][00D0S8b<0:^[Z`2[Zj/0ZZZZ0:FU
Y@0209nOW`<0Vi^K00@0VYZJ096AT@2ATI40Ph>30P1`L7001@1mOGd0KVi^06EUI@1UIFD0EEEE0080
BDU900D0B4Q8028R8P0R8R806a/K02<S8`0200X:2P0402`/;012@T80@T9203lo?`80<S8b00D0EeMG
075aL@1aLG40=SHf06ATI00209fMW@040:>SX`2XZ:P0Z:RX0:b/[080/;2`00D0/k>c0;Jf]P2f][H0
^KVi0;bl_0020;jn_P040<30`033`l<0`l?30<G5a@80a/K600D0b<S80<[:bP3;bl/0bl_;0<g=c@02
0<k>cP040=3@d03AdM40dM7A0=?Cd`80e=CD00<0inOW0?ooo`3oool08P3oool01`3clo<0m_Kf0>_[
j`3/k>`0k^k^0>c/k03Zj^X00`3]kNd0203/k>`0jn_[0>SXj03YjNT0j^[Z0>o_k`3hn?P0^k^k0P1I
FET02P0j>SX0=SHf03Ti>@19BDT0B4Q803Hf=P1MGEd0NGUi08n?S`2JVYX209BDU0080:j^[P3:b/X0
b<S80=?Cd`3De=@0d=3@0<k>cP3?cll20<c<c00>0;jn_P2XZ:P0Vi^K09BDU02:RXX0Ogmo09VIV@2d
];@0_kno0<g=c@3AdM40clo?0=?Cd`3Bd]820=7Ad@0=0<k>cP3<c<`0`<300:n_[`2MWId0QhN707Qh
N024Q8@0RXZ:09:BTP2TY:@0/;2`0;6a/@030;>c/`080;Fe]@2d];@0/[:b0;Fe]@2f][H0/[:b0:^[
Z`2RXZ8209JFUP0@08b<S025QHD0OWin06m_K`1RHV80Fe]K059BDP18B4P0=3@d02PX:00W9bL0=3@d
03Ti>@0^;Rh0?Shn05UIF@80MgMg00X0IVIV06e]K@2=SHd0UYJF0;:b/P1oOgl0/;2`0>GUi@3clo<0
l?3`103_knlE0>k^kP@0kNg]00<0k>c/0??cl`3clo<09`3oool002D0oooo00@0jNWY0=WIf@3IfMT0
f][J0P3Kfm/30=gMg@030=oOg`3Ph>00h>3P0080h^;R0P3Shn<01038b<P0^KVi0;Vi^@1UIFD205EE
E@0506ATI01`L700JFUY06UYJ@25QHD00P29RHT0102FUYH0UIFE09FEU@2VYZH20<C4a0050;bl_038
b<P0dm?C0=?Cd`3AdM400P3:b/X01022PX80NWYj07YjNP1gMgL20:^[Z`050<?3``2o_kl0`L710<71
`@36a/H00P31`L401@2m_Kd0_;bl0;bl_02j^[X0];Bd0080/K6a00@0YZJV08j>SP2>SXh0Fe]K0P19
BDT01@1DE5@0OWin07inOP2JVYX0Zj^[0080[:b/00@0XZ:R0:BTY02TY:@0U9BD0P25QHD01@1VIVH0
PH610861P@1aLG40IFEU0080F5QH00@0EeMG03/k>`0k>c/0:b/[0P0N7Qh01@0Q8B404Q8B03Ph>00h
>3P0@4100080CTi>00@0BTY:02h^;P0^;Rh0EUIF0P1UIFD01@1GEeL0K6a/0:VYZ@2YZJT0Z:RX0080
[:b/00@0[jn_0;:b/P2b/[80]KFe0P2h^;P01@2j^[X0_Kfm0;no_`2o_kl0`L710080`l?300D0aLG5
0<K6aP36a/H0b<S80<[:bP020<_;b`040<g=c@3>c/h0c/k>0=3@d080dM7A00@0dm?C0=CDe03De=@0
inOW903oool01`3clo<0m_Kf0>c/k03/k>`0k^k^0>c/k03Zj^X00P3]kNd20>c/k0110>[ZjP3YjNT0
jn_[0>[ZjP3/k>`0n_[j0;2`/00i>CT0Bd];02l_;`0`<300>CTi04e=C@1?Cdl0?Cdm05YJFP1^KVh0
Q8B409:BTP2?Shl0TI6A0:ZZZP3:b/X0a<C40<k>cP3Cdm<0eMGE0=CDe03EeMD0dm?C0;^k^`2NWYh0
Ph>306i^KP1[Jf/0O7al08b<S02][Jd0a<C40<[:bP3Cdm<0e=CD0=;BdP3GemL0e=CD0=7Ad@3Bd]80
dM7A0=3@d039bLT0`<300:f][@2=SHd0Kfm_05mOG`1KFe/0IfMW08N7Q`2[Zj/0_kno0<?3``39bLT0
a/K60<C4a02o_kl00P2k^k/03`2f][H0[jn_0:>SX`2?Shl0QhN7096AT@29RHT0O7al07=cL`1^KVh0
IFEU05ADE015ADD0B4Q802d];@0202HV9P0?02DU9@0/;2`0>3Ph04e=C@1MGEd0L71`07EeM@1WIfL0
JVYZ08j>SP2BTY80/;2`08Z:RP2d];@0jn_[00P0kno_4`3^k^h50>g]k@030?KfmP3clo<0oooo02H0
oooo000U0?ooo`040>WYj@3IfMT0fMWI0=[JfP80fm_K0`3MgMd00`3Ogml0h>3P0>3Ph0020>;RhP80
hn?S00@0b<S80;Vi^@2i^KT0IFEU0P1EEED01@1TI6@0L71`06UYJ@1YJFT0QHF50080RHV900@0UYJF
09FEU@2EUID0YZJV0P34a<@01@2l_;`0b<S80=?Cd`3Cdm<0dM7A0080b/[:00@0PX:207YjNP1jNWX0
MgMg0P2[Zj/01@33`l<0_kno0<71`@31`L40a/K60080`L7100D0_Kfm0;bl_02l_;`0^[Zj0;Bd]002
0;6a/@040:JVYP2>SXh0SXj>05]KF`80BDU900D0E5AD07inOP1nOWh0VYZJ0:^[Z`020:b/[0040::R
XP2TY:@0Y:BT09BDU080QHF500D0IVIV0861P@21PH40LG5a06EUI@0205QHF00405MGE`0k>c/0>c/k
02/[:`807QhN00D08B4Q018B4P0h>3P0>3Ph0410@00204i>CP0404Y:BP0^;Rh0;Rh^05IFEP80IFEU
00D0EeMG06a/K02YZJT0ZJVY0:RXZ0020:b/[0040:n_[`2b/[80/[:b0;Fe]@80^;Rh00D0^[Zj0;fm
_@2o_kl0_kno0<71`@020<?3``050<G5a@36a/H0a/K60<S8b03:b/X00P3;bl/0103=cLd0c/k>0<k>
cP3@d=020=7Ad@040=?Cd`3De=@0e=CD0>OWib@0oooo00<0lo?c0?KfmP3^k^h01@3]kNd30>c/k00U
0>[ZjP3YjNT0j^[Z0>g]k@3EeMD0jNWY0;Rh^00k>c/0@41003De=@0g=cL0>c/k04I6AP1=CDd0C4a<
065QH@1XJ6P0L71`07moO`29RHT0SXj>0:BTY037alL0b/[:0;6a/@2m_Kd0aLG50<71`@2l_;`0[Zj^
08N7Q`1gMgL0PH6108N7Q`2?Shl0[Zj^0<O7a`020=3@d0030=7Ad@3EeMD0f=SH0080eMGE00`0dm?C
0=7Ad@3AdM40d];B0<o?c`3>c/h0bl_;0<C4a02e]KD0VYZJ07UiN@1ZJVX206MWI`0Z07MgM`2?Shl0
VYZJ0:BTY02/[:`0/[:b0:n_[`2ZZZX0Z:RX09bLW02HV9P0T92@08B4Q02:RXX0SXj>08R8R01iNGT0
KFe]06][J`1SHf<0EEEE04E5A@0^;Rh0;Bd]03<c<`0b<S809bLW02PX:015ADD0FEUI06QXJ01fMWH0
MgMg06MWI`1XJ6P0SHf=09BDU02OWil0Ti>C0<;2`P3alO40l?3`2@3_knl80>k^kP80kNg]203^k^h4
0>g]k@030?KfmP3clo<0oooo02H0oooo000U0?ooo`040>WYj@3IfMT0fMWI0=[JfP80fm_K00@0g=cL
0=kNgP3Ng]h0gmoO0P3Ph>020>7Qh@80kno_00@0Vi^K0:b/[02/[:`0JFUY0P1eMGD0101/K6`0IVIV
06YZJP1ZJVX307QhN00408:2PP2;Rh/0Rh^;0:ZZZP80alO700D0[:b/0:j^[P2TY:@0Y:BT09RHV002
08Z:RP0409fMW@2m_Kd0_Kfm0<_;b`80alO700D0b<S80<K6aP35aLD0aLG50<?3``020;no_`050;Vi
^@2k^k/0^k^k0;Rh^02f][H00P2`/;00102^[Zh0[Jf]0:f][@2TY:@209NGU`0508>3P`1^KVh0KVi^
07UiN@1UIFD00P1YJFT0101`L700Jf][06][J`1^KVh2075aL@0507alO01nOWh0OWin07UiN@1VIVH0
0P1IFET0101HF5P0BTY:04Y:BP0W9bL203Lg=`0502/[:`0H61P02`/;00/;2`1:BTX00P1?Cdl0101<
C4`0?3`l03`l?01TI6@205=CD`050492@P2NWYh0Zj^[0:^[Z`2/[:`00P2_[jl0102b/[80];Bd0;Bd
]02g]kL20;Vi^@050;^k^`2n_[h0`<300<30`032`/800P34a<@01@36a/H0a<C40<C4a038b<P0b/[:
0080c<c<00@0cLg=0<o?c`3?cll0d=3@0P3AdM40103Cdm<0e=CD0=CDe03WinLT0?ooo`030??cl`3f
m_H0k^k^00D0kNg]0`3/k>`0303YjNT0i^KV0>WYj@3[jn/0_;bl08B4Q01KFe/0?clo04A4A01HF5P0
E5AD04Q8B080ADE50180B4Q8059BDP1JFUX0GemO06YZJP1dM7@0QhN70:f][@37alL0d=3@0<c<c02l
_;`0YJFU09ZJVP2EUID0Z:RX0<G5a@3Fe]H30=WIf@80f=SH1@3IfMT0103Jf]X0e=CD0=3@d03EeMD2
0=[JfP030=GEe@3Cdm<0dm?C0080dm?C00<0c/k>0<[:bP38b<P00P38b<P20<O7a`0O0<;2`P2QXJ40
PX:207MgM`1iNGT0NWYj0820P02DU9@0Vi^K09NGU`2FUYH0W9bL09NGU`2<S8`0NWYj079bLP1eMGD0
J6QX04Y:BP0k>c/0A4A403Xj>P0a<C407alO014A4@0B4Q809BDU05iNGP1bLW80I6AT06a/K00207Ee
M@0609NGU`2OWil0NWYj0;Jf]P3[jn/0lO7a103`l?080>o_k`P0k^k^00<0kNg]0>c/k03^k^h01`3^
k^h20>g]k@030?KfmP3clo<0oooo02H0oooo000U0?ooo`040>WYj@3IfMT0fMWI0=[JfP80f=SH00@0
gMgM0=kNgP3Ng]h0gMgM0P3QhN401@3Rh^80i>CT0>[ZjP3Zj^X0^[Zj0080NWYj00D0KFe]09>CT`2C
Ti<0Ogmo079bLP0206QXJ0<0NGUi00@0Q8B40861P@21PH40[:b/0P31`L420<C4a080_kno00@0^[Zj
0;jn_P2n_[h0a/K60P38b<P01@36a/H0aLG50<G5a@35aLD0a<C40080`l?300@0`<300;bl_02l_;`0
^k^k0P2l_;`01@2j^[X0/[:b0;6a/@2a/K40[Zj^0080[Jf]00@0YZJV0:BTY02TY:@0YJFU0P2QXJ40
1@2TY:@0Ti>C096AT@2ATI40SHf=0080Q8B400@0Rh^;08>3P`23Ph<0QHF50P1iNGT01@1_Kfl0Hf=S
06=SH`1SHf<0HV9R0080A4A400D0=cLg020P800P820051@D00/;2`0200L71`0406ATI013@d<0@d=3
071`L080@T9200D0IFEU051@D01@D500IFEU0;Bd]0020:n_[`040;6a/@2b/[80/[:b0;Bd]080][Jf
00D0^KVi0;^k^`2k^k/0_Kfm0;no_`020<71`@040<;2`P34a<@0a<C40<K6aP80alO700D0b<S80<[:
bP3<c<`0c<c<0<g=c@020<o?c`040=3@d03Bd]80d];B0=?Cd`80e=CD00<0inOW0?ooo`3oool08P3o
ool01P3clo<0m_Kf0>k^kP3^k^h0jn_[0>[ZjP80kNg]00D0k>c/0>WYj@3YjNT0j^[Z0>WYj@020>[Z
jP0N0<c<c02:RXX0EEEE04I6AP15ADD0JVYZ06MWI`1GEeL0Cdm?04Y:BP19BDT0F5QH05]KF`1OGel0
KFe]07EeM@23Ph<0ZZZZ0<W9b@3=cLd0dM7A0<o?c`3>c/h0bl_;0<W9b@3?cll0eMGE0=_Kf`3MgMd0
f][J1P3IfMT0203Jf]X0fMWI0=WIf@3Cdm<0eMGE0=[JfP3Kfm/0f][J103Cdm<05P3De=@0dm?C0<g=
c@3>c/h0d];B0=7Ad@3?cll0d=3@0<g=c@2o_kl0^KVi0;Rh^02b/[80ZZZZ0:NWY`2[Zj/0ZJVY0::R
XP2SXj<0X:2P08f=S@22PX8307QhN00E075aL@1LG5`0@T9203/k>`0X:2P06ATI018B4P0@41003`l?
02TY:@1mOGd0LW9b05aLG01mOGd0S8b<071`L029RHT0YjNW07inOP36a/H0m?Cd0080lO7a103`l?08
0>o_k`P0k^k^00<0kNg]0>k^kP3^k^h0203^k^h00`3fm_H0lo?c0?ooo`0V0?ooo`009@3oool0103Y
jNT0f=SH0=SHf03Hf=P20=_Kf`<0g=cL00D0g]kN0>7Qh@3QhN40hn?S0>GUi@020>c/k0040;Bd]01V
IVH0IVIV07=cL`80YZJV00D0PH6107=cL`1eMGD0MGEe07MgM`0207EeM@0408N7Q`1lO7`0O7al0:b/
[0<0`/;200@0`L710<C4a034a<@0`<300P37alL01036a/H0_[jn0;jn_P34a<@20<?3``050<30`02o
_kl0`<300<30`02o_kl00P2k^k/01@2d];@0^k^k0;^k^`2`/;00][Jf00<0/;2`0P2^[Zh0102][Jd0
X:2P0:2PX02UYJD20:2PX00509fMW@2DU9@0UIFE09FEU@2>SXh00P28R8P01022PX80PH610861P@21
PH4207IfMP0507YjNP1VIVH0HV9R069RHP1MGEd00P1HF5P01@15ADD09BDU02DU9@0S8b<09bLW0080
2`/;00@0NWYj055AD@1ADE40L71`0P1DE5@01@1MGEd0FEUI05UIF@29RHT0_kno0080/k>c00@0];Bd
0;Fe]@2e]KD0]kNg0P2i^KT01@2j^[X0_;bl0;bl_02n_[h0`<300080`L7100@0`l?30<G5a@35aLD0
a/K60P38b<P01@39bLT0bl_;0<c<c03<c<`0c/k>0080clo?00@0d=3@0=;BdP3Bd]80dm?C0P3De=@0
0`3WinL0oooo0?ooo`0R0?ooo`060??cl`3gmoL0jn_[0>c/k03]kNd0k>c/0P3]kNd20>WYj@<0jn_[
01P0j^[Z0>_[j`3:b/X0OGem04Q8B017AdL0DE5A07UiN@1`L700F5QH055AD@1CDe<0DE5A05QHF01I
FET0Fe]K06i^KP1fMWH0Ogmo0:VYZ@37alL0clo?0=3@d03De=@20=WIf@060=OGe`3Kfm/0fm_K0=OG
e`3EeMD0emOG0P3Jf]X00`3IfMT0e]KF0=KFeP020=[JfP0;0=WIf@3Jf]X0e=CD0=?Cd`3GemL0fMWI
0=CDe03GemL0eMGE0=?Cd`3De=@00P3EeMD0103De=@0c/k>0=3@d03?cll20<_;b`090<S8b033`l<0
b/[:0<G5a@2n_[h0^KVi0;6a/@2[Zj/0ZJVY0080Y:BT01/0WIfM09:BTP28R8P0N7Qh07IfMP1hN7P0
KFe]065QH@1NGUh0?clo02HV9P0N7Qh06QXJ01hN7P0P8200;Rh^08Z:RP22PX80HV9R07alO02@T900
LG5a07UiN@2YZJT0P8200=OGe`3inOT00`3alO430?3`l0P0kno_4`3^k^h00`3fm_H0lo?c0?ooo`0V
0?ooo`009@3oool0103YjNT0f=SH0=SHf03Hf=P20=_Kf`<0g=cL00D0g]kN0>7Qh@3QhN40hn?S0>GU
i@020>c/k0040;Bd]01VIVH0IVIV07=cL`80YZJV00D0PH6107=cL`1eMGD0MGEe07MgM`0207EeM@04
08N7Q`1lO7`0O7al0:b/[0<0`/;200@0`L710<C4a034a<@0`<300P37alL01036a/H0_[jn0;jn_P34
a<@20<?3``050<30`02o_kl0`<300<30`02o_kl00P2k^k/01@2d];@0^k^k0;^k^`2`/;00][Jf00<0
/;2`0P2^[Zh0102][Jd0X:2P0:2PX02UYJD20:2PX00509fMW@2DU9@0UIFE09FEU@2>SXh00P28R8P0
1022PX80PH610861P@21PH4207IfMP0507YjNP1VIVH0HV9R069RHP1MGEd00P1HF5P01@15ADD09BDU
02DU9@0S8b<09bLW00802`/;00@0NWYj055AD@1ADE40L71`0P1DE5@01@1MGEd0FEUI05UIF@29RHT0
_kno0080/k>c00@0];Bd0;Fe]@2e]KD0]kNg0P2i^KT01@2j^[X0_;bl0;bl_02n_[h0`<300080`L71
00@0`l?30<G5a@35aLD0a/K60P38b<P01@39bLT0bl_;0<c<c03<c<`0c/k>0080clo?00@0d=3@0=;B
dP3Bd]80dm?C0P3De=@00`3WinL0oooo0?ooo`0R0?ooo`040??cl`3fm_H0k>c/0>c/k0@0kNg]00<0
j^[Z0>_[j`3/k>`0103[jn/05`3>c/h0O7al04M7A`1EEED0Fe]K07AdM01YJFT0G5aL05]KF`1JFUX0
EUIF05ADE01CDe<0E5AD06EUI@1aLG40NWYj09fMW@32`/80c/k>0=3@d03AdM40e=CD0080e]KF00<0
emOG0=cLg03Jf]X00P3EeMD30=[JfP80f=SH00P0f][J0=WIf@3Jf]X0f][J0=SHf03Fe]H0f=SH0=[J
fP80emOG0P3De=@0;`3Cdm<0d];B0=;BdP3Cdm<0d=3@0=7Ad@3>c/h0b/[:0<W9b@38b<P0a/K60<G5
a@2o_kl0^[Zj0;Jf]P2`/;00[:b/0:VYZ@2VYZH0Xj>S09nOW`2FUYH0QHF507MgM`1iNGT0N7Qh06e]
K@1RHV80E5AD03Ph>00`<300;Rh^020P800I6AT06QXJ02d];@2>SXh0RHV906][J`21PH40Ti>C079b
LP1/K6`0Vi^K07UiN@3/k>`0m_Kf00<0lO7a103`l?080>o_ka80k^k^00<0m_Kf0??cl`3oool09P3o
ool002D0oooo00@0jNWY0=WIf@3IfMT0f][J0P3Kfm/0103Lg=`0g]kN0=kNgP3Ph>020>7Qh@050>?S
h`3UiND0jn_[0>_[j`3Hf=P00P1hN7P01@23Ph<0Rh^;08^;R`21PH40PX:20080NGUi00@0L71`06m_
K`1_Kfl0NWYj0P1oOgl01@2HV9P0^k^k0;^k^`30`<00_[jn0080_kno00@0`/;20;jn_P2n_[h0aLG5
0`33`l<20<;2`P050<71`@2o_kl0_kno0;no_`2m_Kd00`2l_;`30;Rh^0040;:b/P2_[jl0[jn_0:^[
Z`80Z:RX00@0YjNW0:JVYP2VYZH0Xj>S0P2NWYh01@2JVYX0Vi^K09>CT`2CTi<0T92@0080R8R800@0
RHV908F5Q@25QHD0Ogmo0P21PH401@1cLg<0I6AT06][J`1[Jf/0GUiN0080C4a<00D0;Bd]03`l?00l
?3`092@T018B4P02014A4@0407QhN01QHF40HF5Q08:2PP80FUYJ00D0E5AD05QHF01HF5P0_[jn0;Jf
]P030;Ng]`80^;Rh00@0^KVi0;^k^`2k^k/0_;bl0P2n_[h01@2o_kl0`L710<;2`P32`/80a<C40080
a/K600D0alO70<W9b@39bLT0bLW90<_;b`020<g=c@040<k>cP3?cll0clo?0=7Ad@80d];B00@0dm?C
0=CDe03De=@0inOW903oool00`3clo<0m_Kf0>k^kP020>g]k@040>c/k03[jn/0k>c/0>g]k@80k>c/
103[jn/01@3Ph>00Ti>C051@D01GEeL0EUIF0080G5aL0100H61P05iNGP1HF5P0EEEE055AD@1CDe<0
DE5A06=SH`1dM7@0O7al09NGU`2l_;`0alO70=3@d03?cll0dM7A0P3Fe]H01P3De=@0e]KF0=[JfP3J
f]X0f=SH0=_Kf`80f][J00<0f=SH0=OGe`3Hf=P0103Jf]X0103Kfm/0fMWI0=OGe`3Hf=P20=?Cd`03
0=7Ad@3?cll0clo?00<0d=3@00X0clo?0<c<c039bLT0alO70<C4a036a/H0`L710<30`02m_Kd0][Jf
0P2a/K407P2[Zj/0ZJVY0:6QX@2LW9`0TI6A08F5Q@1lO7`0Ng]k07EeM@1ZJVX0FUYJ0492@P0`<300
>c/k030`<00K6a/0410@018B4P0a<C40P820096AT@21PH40T92@09RHV01fMWH0Jf][07emO@23Ph<0
moOg0?;blP<0lO7a103`l?080>o_k`D0k^k^00<0kNg]0>c/k03^k^h02P3^k^h00`3fm_H0lo?c0?oo
o`0V0?ooo`009@3oool0103YjNT0fMWI0=WIf@3Jf]X20=cLg0040=[JfP3Ng]h0g]kN0=oOg`80hN7Q
00D0hn?S0>GUi@3Xj>P0j>SX0?Shn00207EeM@0507UiN@1kNg/0Ng]k08B4Q01nOWh00P1gMgL0101c
Lg<0LG5a075aL@21PH42096AT@0309bLW02b/[80/[:b0080_[jn0P32`/800`31`L40_kno0;no_`03
0<;2`P050;no_`31`L40`L710;jn_P2k^k/00P2o_kl0102h^;P0^k^k0;^k^`2k^k/40;2`/080[jn_
0`2YZJT0102WYjL0Xj>S0:>SX`2NWYh209nOW`80Ti>C0P2BTY80102ATI40RXZ:08Z:RP29RHT208F5
Q@0507alO01jNWX0NWYj075aL@1^KVh00P1VIVH0101HF5P0@T920492@P0o?cl2034a<@05024Q8@0L
71`08b<S02<S8`1/K6`00P1iNGT01021PH40JVYZ06YZJP1FEUH207alO0030;bl_02i^KT0^[Zj0080
^[Zj0P2k^k/0102l_;`0_Kfm0;fm_@2n_[h20;no_`050<71`@32`/80a<C40<C4a035aLD00P36a/H0
1@38b<P0bLW90<W9b@39bLT0c<c<0080cLg=00@0c/k>0=3@d03@d=00dM7A0P3Bd]80103Cdm<0eMGE
0=GEe@3WinLT0?ooo`030??cl`3fm_H0kNg]0080kNg]00@0k>c/0>[ZjP3/k>`0kNg]0`3/k>`30>_[
j`0<0?7al@2RXZ80Cdm?055AD@1<C4`0Cdm?05YJFP1PH600Fe]K05ADE01FEUH0De=C0P1EEED02`1Y
JFT0OGem08R8R02KVi/0]kNg0<30`03@d=00dM7A0=CDe03GemL0e]KF0080eMGE00@0fMWI0=_Kf`3I
fMT0fMWI0P3Kfm/01P3Fe]H0dm?C0=OGe`3Jf]X0f=SH0=[JfP80fm_K00P0emOG0=;BdP3Bd]80dm?C
0=CDe03@d=00clo?0=7Ad@80d=3@00H0c/k>0<[:bP38b<P0b/[:0<K6aP2m_Kd30;jn_P0R0;fm_@2g
]kL0/[:b0;6a/@2[Zj/0ZJVY09nOW`2HV9P0S8b<08^;R`23Ph<0Ng]k079bLP1RHV80Cdm?0492@P0j
>SX0>CTi02HV9P0H61P051@D01HF5P0b<S80KFe]09^KV`2@T900TI6A09RHV022PX80Lg=c06=SH`2O
Wil0mOGe0?;blP<0lO7a1@3`l?080>o_k`@0k^k^00<0kNg]0>_[j`3^k^h02P3^k^h00`3fm_H0lo?c
0?ooo`0V0?ooo`009@3oool0103YjNT0fMWI0=WIf@3Jf]X20=cLg0040=[JfP3Ng]h0g]kN0=oOg`80
hN7Q00D0hn?S0>GUi@3Xj>P0j>SX0?Shn00207EeM@0507UiN@1kNg/0Ng]k08B4Q01nOWh00P1gMgL0
101cLg<0LG5a075aL@21PH42096AT@0309bLW02b/[80/[:b0080_[jn0P32`/800`31`L40_kno0;no
_`030<;2`P050;no_`31`L40`L710;jn_P2k^k/00P2o_kl0102h^;P0^k^k0;^k^`2k^k/40;2`/080
[jn_0`2YZJT0102WYjL0Xj>S0:>SX`2NWYh209nOW`80Ti>C0P2BTY80102ATI40RXZ:08Z:RP29RHT2
08F5Q@0507alO01jNWX0NWYj075aL@1^KVh00P1VIVH0101HF5P0@T920492@P0o?cl2034a<@05024Q
8@0L71`08b<S02<S8`1/K6`00P1iNGT01021PH40JVYZ06YZJP1FEUH207alO0030;bl_02i^KT0^[Zj
0080^[Zj0P2k^k/0102l_;`0_Kfm0;fm_@2n_[h20;no_`050<71`@32`/80a<C40<C4a035aLD00P36
a/H01@38b<P0bLW90<W9b@39bLT0c<c<0080cLg=00@0c/k>0=3@d03@d=00dM7A0P3Bd]80103Cdm<0
eMGE0=GEe@3WinLT0?ooo`030??cl`3fm_H0kNg]00D0kNg]1P3/k>`0303[jn/0moOg0:FUY@1@D500
FEUI04i>CP1KFe/0HV9R06ATI01QHF40Fe]K05EEE@80EUIF00/0GUiN06UYJ@1lO7`0SXj>09VIV@2_
[jl0_[jn0<o?c`3Bd]80e]KF0=GEe@020=KFeP0G0=WIf@3Lg=`0f][J0=GEe@3De=@0fMWI0=_Kf`3G
emL0e]KF0=WIf@3Hf=P0e=CD0=SHf03IfMT0f][J0=KFeP3Bd]80dm?C0=CDe03EeMD0e=CD0=GEe@3D
e=@00P3@d=001P3>c/h0bl_;0<W9b@39bLT0alO70;no_`@0^k^k00P0^;Rh0;>c/`2`/;00ZZZZ0:RX
Z02SXj<0W9bL08^;R`80QXJ600T0OWin079bLP1WIfL0DU9B03dm?@15ADD0:2PX01`L700J6QX00P0E
5AD0300`<300Jf][08n?S`21PH40QXJ609RHV02ATI40QXJ606i^KP2f][H0m?Cd0?;blP<0lO7a1@3`
l?080>o_ka40k^k^00<0m_Kf0??cl`3oool09P3oool002D0oooo00@0jNWY0=WIf@3IfMT0f][J0P3K
fm/0103Lg=`0gMgM0=gMg@3Ogml20>3Ph0050>;RhP3Ti>@0i^KV0>KViP3lo?`00P22PX801@1dM7@0
QhN708N7Q`24Q8@0O7al0080Lg=c00@0M7Ad0861P@21PH40OWin0P2ATI401@2LW9`0[Zj^0:j^[P2j
^[X0_kno0080_Kfm102n_[h20<?3``<0^k^k00D0`<300;Zj^P2g]kL0]kNg0;Zj^P020;Bd]0<0/[:b
0P2_[jl20:j^[P040:RXZ02YZJT0ZJVY0:NWY`80WYjN00D0Xj>S09fMW@2MWId0WIfM09FEU@0209JF
UP0409:BTP2:RXX0RXZ:08V9R@80QHF500D0MgMg07YjNP1jNWX0L71`075aL@0205]KF`0405eMG@19
BDT0BDU90410@080:2PX00D07AdM01DE5@1?Cdl0Cdm?069RHP0206m_K`0408N7Q`1kNg/0Ng]k08:2
PP80YJFU00<0^k^k0;bl_02l_;`00P2l_;`20;fm_@040;jn_P2o_kl0_kno0<30`080`L7100D0`/;2
0<?3``35aLD0aLG50<K6aP020<O7a`050<S8b03:b/X0b/[:0<_;b`3<c<`00P3=cLd0103?cll0d=3@
0=3@d03AdM420=;BdP040=?Cd`3EeMD0eMGE0>OWib@0oooo00<0lo?c0?KfmP3]kNd01@3]kNd70>c/
k00E0?KfmP2f][H0GUiN04a<C01FEUH0HV9R06IVIP1KFe/0FEUI05YJFP1ADE40EEEE06ATI01SHf<0
JFUY07YjNP2:RXX0V9RH0:VYZ@2l_;`0c/k>00<0dM7A0`3Fe]H0303IfMT0g=cL0=WIf@3Cdm<0e=CD
0=WIf@3Kfm/0emOG0=?Cd`3EeMD0fMWI0=GEe@<0dm?C00@0e=CD0=?Cd`3EeMD0eMGE0P3Bd]801P3D
e=@0d=3@0=3@d03:b/X0c/k>0<g=c@80b<S801l0alO70<71`@2o_kl0`<300;fm_@2f][H0/K6a0;2`
/02ZZZX0Z:RX09fMW@2FUYH0Rh^;08J6QP25QHD0M7Ad06a/K01VIVH0EUIF04I6AP0j>SX09BDU01LG
5`0>3Ph01PH601/K6`1BDU80I6AT07QhN01jNWX0S8b<0080WIfM00<0ZJVY09VIV@3Hf=P00P3bl_83
0?7al@D0l?3`203_knlA0>k^kP030?KfmP3clo<0oooo02H0oooo000U0?ooo`040>WYj@3IfMT0fMWI
0=[JfP80fm_K00@0g=cL0=gMg@3MgMd0g]kN0P3Ph>001@3QhN40hn?S0>?Sh`3Shn<0kno_0080MGEe
00D0VYZJ07YjNP1jNWX0P82007]kN`0207IfMP040820P01TI6@0I6AT08J6QP80UiNG00D0U9BD0:f]
[@2][Jd0^KVi0;fm_@020;no_`040<30`02n_[h0_[jn0<?3``80_Kfm00<0`<300;no_`2o_kl00P2l
_;`20;Jf]P040;Bd]02g]kL0]kNg0;6a/@<0[jn_0`2][Jd30:b/[0040:6QX@2RXZ80XZ:R0:2PX080
WYjN00D0TI6A09fMW@2@T900T92@08^;R`0208Z:RP0408R8R025QHD0QHF507IfMP80Q8B400@0LG5a
069RHP1JFUX0FUYJ0`19BDT01@0i>CT07alO01lO7`0T92@08B4Q00<0JVYZ0P1QHF401021PH40Ogmo
07moO`2BTY820;no_`@0_[jn0`2o_kl30<30`0050<71`@32`/80`/;20<?3``34a<@00P36a/H01037
alL0b<S80<S8b039bLT20<[:bP050<_;b`3=cLd0c/k>0<k>cP3?cll00P3@d=00103AdM40d];B0=;B
dP3De=@20=GEe@030>OWi`3oool0oooo0280oooo00<0lo?c0?KfmP3]kNd01@3]kNd70>c/k0060?Sh
n02UYJD0EUIF06i^KP1]KFd0Fe]K0P1LG5`0401IFET0EeMG05MGE`1OGel0C4a<05QHF01^KVh0PH61
08^;R`2ATI40YjNW0;^k^`3<c<`0clo?0=7Ad@3EeMD20=KFeP040=WIf@3Lg=`0fMWI0=KFeP80f][J
00@0fm_K0=SHf03GemL0emOG0P3De=@01@3IfMT0eMGE0=;BdP3Bd]80dm?C0080e=CD00D0eMGE0=CD
e03De=@0e]KF0=?Cd`020<[:bP0F0<g=c@3<c<`0bLW90<K6aP30`<00a/K60;no_`2k^k/0]kNg0;:b
/P2a/K40/;2`0:ZZZP2XZ:P0Vi^K09RHV02;Rh/0QXJ607QhN01]KFd0Hf=S05ADE080CTi>0100<S8b
01XJ6P0<30`05ADE018B4P0N7Qh0H61P06][J`1^KVh0JVYZ0861P@2JVYX0VIVI0:JVYP3;bl/0k>c/
0P3bl_830?7al@D0l?3`203_knlA0>k^kP030?KfmP3clo<0oooo02H0oooo000U0?ooo`040>WYj@3I
fMT0fMWI0=[JfP80fm_K00@0g=cL0=gMg@3MgMd0g]kN0P3Ph>001@3QhN40hn?S0>?Sh`3Shn<0kno_
0080MGEe00D0VYZJ07YjNP1jNWX0P82007]kN`0207IfMP040820P01TI6@0I6AT08J6QP80UiNG00D0
U9BD0:f][@2][Jd0^KVi0;fm_@020;no_`040<30`02n_[h0_[jn0<?3``80_Kfm00<0`<300;no_`2o
_kl00P2l_;`20;Jf]P040;Bd]02g]kL0]kNg0;6a/@<0[jn_0`2][Jd30:b/[0040:6QX@2RXZ80XZ:R
0:2PX080WYjN00D0TI6A09fMW@2@T900T92@08^;R`0208Z:RP0408R8R025QHD0QHF507IfMP80Q8B4
00@0LG5a069RHP1JFUX0FUYJ0`19BDT01@0i>CT07alO01lO7`0T92@08B4Q00<0JVYZ0P1QHF401021
PH40Ogmo07moO`2BTY820;no_`@0_[jn0`2o_kl30<30`0050<71`@32`/80`/;20<?3``34a<@00P36
a/H01037alL0b<S80<S8b039bLT20<[:bP050<_;b`3=cLd0c/k>0<k>cP3?cll00P3@d=00103AdM40
d];B0=;BdP3De=@20=GEe@030>OWi`3oool0oooo0280oooo00<0lo?c0?KfmP3[jn/00P3/k>`00`3Z
j^X0kNg]0>g]k@070>c/k00:0?3`l03=cLd0Ti>C079bLP1MGEd0De=C059BDP1CDe<0DU9B05=CD`80
EeMG00X0E5AD05]KF`1^KVh0PX:208n?S`2IVIT0Z:RX0;^k^`3<c<`0dM7A0P3Fe]H20=GEe@090=[J
fP3MgMd0fMWI0=KFeP3Lg=`0f=SH0=[JfP3GemL0e=CD0080eMGE00<0f=SH0=OGe`3De=@00P3Cdm<0
2`3De=@0eMGE0=CDe03De=@0eMGE0=KFeP3De=@0c/k>0<g=c@3?cll0c<c<0080bLW900H0aLG50;fm
_@37alL0_[jn0;Vi^@2e]KD30;2`/00M0:j^[P2YZJT0WinO09jNWP27QhL0OWin079bLP1_Kfl0JVYZ
05eMG@1>CTh0@41002l_;`0G5aL03`l?01`L700J6QX09bLW06QXJ01^KVh0L71`06QXJ01mOGd0VIVI
09ZJVP2ZZZX0iNGU0?Cdm03bl_80103alO450?3`l0T0kno_403^k^h00`3fm_H0lo?c0?ooo`0V0?oo
o`009@3oool0103YjNT0f=SH0=SHf03IfMT20=SHf0040=cLg03MgMd0gMgM0=kNgP80gmoO00D0h>3P
0>7Qh@3Shn<0hn?S0>KViP020<S8b00407EeM@1hN7P0N7Qh071`L0<0LW9b00@0LG5a07emO@1mOGd0
QXJ60P2BTY801@2SXj<0[Jf]0:f][@2i^KT0_[jn0080_kno0`2n_[h01030`<00_Kfm0;fm_@2l_;`2
0;Vi^@050;bl_02h^;P0];Bd0;Bd]02g]kL00P2b/[830;2`/0030:j^[P2][Jd0Zj^[0080Zj^[0P2U
YJD0102TY:@0YZJV0:JVYP2LW9`209jNWP0509FEU@2LW9`0TY:B09:BTP2<S8`00P2;Rh/01028R8P0
QhN708N7Q`21PH4207inOP0506][J`1TI6@0G5aL05aLG01JFUX00P10@4000`0d=3@09bLW02LW9`02
02TY:@80OWin00@0KVi^06QXJ01XJ6P0QXJ60P2?Shl00`2VYZH0aLG50<G5a@080<71`@80`/;200D0
`l?30<C4a034a<@0aLG50<K6aP020<O7a`040<S8b039bLT0bLW90<[:bP80bl_;00D0c<c<0<g=c@3>
c/h0c/k>0<o?c`020=3@d0040=;BdP3Cdm<0dm?C0=CDe080eMGE00<0inOW0?ooo`3oool08P3oool0
0`3clo<0m_Kf0>c/k0020>c/k0040>_[j`3]kNd0kNg]0>g]k@H0k>c/00@0jn_[0?;blP2m_Kd0G5aL
0P1>CTh09018B4P0BTY:04e=C@1;Bd/0CDe=059BDP1PH600I6AT07AdM025QHD0TI6A0:6QX@2[Zj/0
^k^k0<g=c@3@d=00d];B0=KFeP3EeMD0e]KF0=SHf03IfMT0emOG0=GEe@3GemL0f=SH0=_Kf`3Jf]X0
f=SH0=KFeP3De=@0emOG0=SHf03EeMD0dm?C0=CDe0D0eMGE0200dm?C0<o?c`3=cLd0d=3@0=7Ad@3;
bl/0b/[:0<c<c037alL0`l?30<O7a`31`L40^k^k0;Fe]@2a/K40[jn_0:b/[02`/;00ZZZZ0:FUY@2P
X:00QHF50820P01hN7P0K6a/06IVIP1HF5P0@D51030`<00U9BD06QXJ010@40805aLG00`0;Rh^07=c
L`1]KFd0K6a/06EUI@1nOWh0XJ6Q0:^[Z`2o_kl0kNg]0?Gem@3bl_830?7al@H0l?3`2@3_knl@0>k^
kP030?KfmP3clo<0oooo02H0oooo000U0?ooo`040>WYj@3IfMT0fMWI0=WIf@80f][J00@0fm_K0=cL
g03Lg=`0gMgM0P3Ng]h00`3Ogml0h>3P0>7Qh@020>7Qh@80d];B00D0Ph>307QhN01hN7P0LW9b07=c
L`0306m_K`80MgMg00@0R8R809:BTP2BTY80XZ:R0P2`/;001@2h^;P0`<300;fm_@2m_Kd0_[jn0080
_;bl00@0`<300;bl_02l_;`0_;bl0P2m_Kd01@2l_;`0^;Rh0;Rh^02h^;P0/K6a0080];Bd00<0/;2`
0:n_[`2_[jl00P2/[:`20:^[Z`040:ZZZP2VYZH0YZJV0:JVYP80XJ6Q00<0WinO09bLW02LW9`00P2K
Vi/2096AT@0408b<S02:RXX0RXZ:08N7Q`80QXJ600D0OGem07UiN@1iNGT0KVi^06UYJ@0205iNGP04
04i>CP0g=cL0=cLg02/[:`80=3@d00D0:2PX02h^;P29RHT0RHV907emO@0206MWI`0408F5Q@2SXj<0
Xj>S0<C4a080`/;200<0a<C40<?3``33`l<01@33`l<30<C4a080aLG500<0a/K60<O7a`38b<P00P38
b<P20<W9b@050<_;b`3<c<`0c<c<0<g=c@3>c/h00P3?cll0103@d=00dM7A0=7Ad@3Bd]820=?Cd`04
0=CDe03EeMD0eMGE0>OWib@0oooo00<0lo?c0?KfmP3]kNd01P3]kNd60>c/k00E0>_[j`3emOD0bLW9
06e]K@1CDe<0CDe=04Q8B01:BTX0CDe=04];B`19BDT0D51@05UIF@1UIFD0MgMg08F5Q@2@T900XJ6Q
0:n_[`2l_;`0c/k>0080d=3@00P0e]KF0=GEe@3EeMD0f=SH0=OGe`3Fe]H0f=SH0=OGe`<0g=cL00L0
fm_K0=SHf03Fe]H0e=CD0=OGe`3Hf=P0eMGE00<0e=CD0P3EeMD01`3Fe]H0dM7A0<k>cP3Bd]80d=3@
0<o?c`3;bl/00P3<c<`30<S8b00Q0<71`@2k^k/0]KFe0;2`/02_[jl0Zj^[0:b/[02YZJT0Y:BT09bL
W027QhL0PX:207alO01]KFd0HF5Q04];B`0c<c<0:b/[01`L700N7Qh04A4A018B4P0F5QH0<c<c07al
O01iNGT0IVIV06ATI021PH40YJFU0<30`03MgMd0l?3`00D0lO7a1P3`l?090>o_ka00k^k^00<0m_Kf
0??cl`3oool09P3oool002D0oooo00@0jNWY0=GEe@3EeMD0fMWI0P3Jf]X30=_Kf`030=cLg03MgMd0
gMgM0080g]kN0`3Ogml20>KViP0509bLW01[Jf/0Jf][06YZJP1]KFd00P1aLG40101dM7@0L71`071`
L02>SXh209ZJVP050:RXZ02c/k<0/k>c0;Zj^P2g]kL00P2j^[X30;fm_@040;bl_02i^KT0^KVi0;bl
_080]KFe00D0^KVi0;>c/`2c/k<0/k>c0;2`/0020:n_[`040:b/[02][Jd0[Jf]0:b/[0<0ZZZZ00@0
ZJVY0:>SX`2SXj<0X:2P0P2TY:@01@2NWYh0Vi^K09^KV`2KVi/0U9BD0080UIFE00@0Ti>C08V9R@29
RHT0RHV90P20P8001@22PX80Kfm_06m_K`1_Kfl0Hf=S0080EEEE00@0BTY:03Ph>00h>3P0<C4a0P0_
;bl01@0m?Cd0<30`07]kN`1kNg/0R8R80080NWYj00@0U9BD0:n_[`2_[jl0b/[:0P37alL00`36a/H0
aLG50<C4a0050<C4a0<0aLG50P36a/H01@37alL0b<S80<S8b038b<P0bLW90080b/[:00D0bl_;0<c<
c03<c<`0cLg=0<k>cP020<o?c`040=3@d03AdM40dM7A0=;BdP80dm?C00@0e=CD0=GEe@3EeMD0inOW
903oool00`3clo<0m?Cd0>c/k0060>g]k@L0k>c/01H0k^k^0>3Ph02XZ:P0FUYJ04M7A`19BDT0Bd];
04a<C01>CTh0D51@04i>CP1?Cdl0HF5Q07EeM@24Q8@0TY:B0:6QX@2a/K40_kno0<c<c03?cll0dM7A
0`3EeMD0203IfMT0f=SH0=KFeP3Kfm/0g=cL0=_Kf`3Lg=`0fm_K0P3Fe]H0203IfMT0e=CD0=?Cd`3H
f=P0e]KF0=CDe03EeMD0e=CD0P3EeMD01@3Fe]H0dm?C0=7Ad@3De=@0d=3@0080cLg=02L0b/[:0<S8
b038b<P0b<S80<K6aP2m_Kd0^k^k0;Rh^02b/[80/;2`0:n_[`2XZ:P0YZJV09nOW`2GUiL0RHV907Yj
NP1gMgL0LG5a06=SH`18B4P0<S8b02/[:`0N7Qh07alO01XJ6P0L71`06a/K03@d=01kNg/0RHV906YZ
JP1_Kfl0Rh^;0:NWY`3=cLd0l_;b0??cl`3_knl00`3alO460?3`l0X0kno_403^k^h00`3fm_H0lo?c
0?ooo`0V0?ooo`009@3oool0103YjNT0eMGE0=GEe@3IfMT20=[JfP<0fm_K00<0g=cL0=gMg@3MgMd0
0P3Ng]h30=oOg`80i^KV00D0W9bL06][J`1[Jf/0JVYZ06e]K@02075aL@0407AdM01`L700L71`08j>
SP80VYZJ00D0Z:RX0;>c/`2c/k<0^[Zj0;Ng]`020;Zj^P<0_Kfm00@0_;bl0;Vi^@2i^KT0_;bl0P2e
]KD01@2i^KT0/k>c0;>c/`2c/k<0/;2`0080[jn_00@0[:b/0:f][@2][Jd0[:b/0`2ZZZX0102YZJT0
Xj>S0:>SX`2PX:020:BTY00509jNWP2KVi/0Vi^K09^KV`2DU9@00P2EUID0102CTi<0RHV908V9R@29
RHT20820P00508:2PP1_Kfl0Kfm_06m_K`1SHf<00P1EEED0101:BTX0>3Ph03Ph>00a<C4202l_;`05
03dm?@0`<300Ng]k07]kN`28R8P00P1jNWX0102DU9@0[jn_0:n_[`3:b/X20<O7a`030<K6aP35aLD0
a<C400D0a<C40`35aLD20<K6aP050<O7a`38b<P0b<S80<S8b039bLT00P3:b/X01@3;bl/0c<c<0<c<
c03=cLd0c/k>0080clo?00@0d=3@0=7Ad@3AdM40d];B0P3Cdm<0103De=@0eMGE0=GEe@3WinLT0?oo
o`030?;blP3alO40jn_[00L0kNg]1`3/k>`0603_knl0bLW905mOG`12@T80@41004M7A`1;Bd/0C4a<
051@D01CDe<0Cdm?05mOG`1gMgL0RXZ:09ZJVP2YZJT0/k>c0<?3``3:b/X0c<c<0=3@d03Bd]80e]KF
0=OGe`<0e]KF00T0f=SH0=cLg03Fe]H0f][J0=OGe`3De=@0eMGE0=CDe03Cdm<00P3De=@01@3Cdm<0
e=CD0=GEe@3EeMD0e=CD0080eMGE02`0dm?C0=3@d03?cll0cLg=0<o?c`3=cLd0bLW90<S8b039bLT0
b<S80<30`02o_kl0_[jn0;^k^`2e]KD0/;2`0:n_[`2YZJT0Xj>S0:6QX@2FUYH0R8R807UiN@1aLG40
IFEU05QHF014A4@0<C4a02d];@0R8R8071`L02<S8`0W9bL06ATI02PX:01_Kfl0Q8B4079bLP1mOGd0
VIVI0;Jf]P3GemL0lO7a0?;blP<0lO7a1`3`l?0:0>o_ka00k^k^00<0m_Kf0??cl`3oool09P3oool0
02D0oooo00<0jNWY0=WIf@3IfMT00`3IfMT0103Jf]X0fm_K0=_Kf`3Kfm/20=cLg0@0gMgM00@0g]kN
0>3Ph03Ph>00[:b/0P29RHT01@1^KVh0MWIf06m_K`1_Kfl0LW9b0080MgMg00@0P82009VIV@2IVIT0
[Zj^0P2g]kL01@2h^;P0_[jn0;jn_P2n_[h0_kno0080_Kfm00@0^[Zj0;bl_02l_;`0_Kfm0`2d];@0
102c/k<0/;2`0;2`/02_[jl20:j^[P040:f][@2YZJT0ZJVY0:^[Z`<0ZJVY00@0XZ:R0:>SX`2SXj<0
X:2P0P2NWYh309ZJVP0509VIV@2CTi<0TI6A096AT@2<S8`00P2;Rh/308N7Q`0507QhN01aLG40LG5a
06UYJ@1NGUh00P1BDU801012@T80?3`l03`l?00g=cL202l_;`0503De=@0T92@0O7al07alO01dM7@0
0P1kNg/0102FUYH0clo?0<o?c`3:b/X20<S8b0030<O7a`36a/H0a/K600L0a/K60`37alL01@38b<P0
bLW90<W9b@39bLT0b/[:0080bl_;00@0c<c<0<g=c@3=cLd0c/k>0`3?cll0103@d=00dM7A0=7Ad@3B
d]820=?Cd`040=CDe03EeMD0eMGE0>OWib@0oooo00<0lo?c0?Gem@3]kNd0203]kNd50>c/k00G0>_[
j`3alO40d];B07AdM01NGUh0CDe=04i>CP1CDe<0Cdm?04e=C@1CDe<0EUIF06=SH`1]KFd0P82009bL
W02_[jl0_[jn0<30`03=cLd0dM7A0=;BdP3Fe]H00P3GemL01@3Fe]H0e=CD0=OGe`3MgMd0g=cL00<0
eMGE0P3De=@30=?Cd`040=CDe03EeMD0e=CD0=CDe0<0eMGE00@0dm?C0=3@d03@d=00clo?0P3=cLd0
2P3:b/X0b<S80<O7a`38b<P0alO70<30`02n_[h0^k^k0;Jf]P2b/[820:n_[`0I0:ZZZP2YZJT0WinO
096AT@23Ph<0MWIf06a/K01OGel0Cdm?03hn?P0c<c<0<C4a02HV9P0M7Ad08b<S01hN7P0;2`/08R8R
06][J`1dM7@0KFe]07moO`2MWId0a<C40>WYj@030?7al@P0l?3`2P3_knlA0>k^kP030?KfmP3clo<0
oooo02H0oooo000U0?ooo`030>WYj@3Fe]H0e]KF00<0fMWI0`3Jf]X50=_Kf`80g=cL00@0fm_K0=WI
f@3IfMT0inOW0P3>c/h01@2UYJD0OGem07alO01lO7`0MWIf0080M7Ad00@0QHF509NGU`2GUiL0XZ:R
0P2f][H01@2k^k/0^;Rh0;fm_@2m_Kd0_;bl0080_[jn0`2i^KT01@2g]kL0][Jf0;Jf]P2e]KD0];Bd
0080/;2`00@0[jn_0:j^[P2^[Zh0[:b/0P2XZ:P01@2YZJT0Xj>S0::RXP2RXZ80YJFU0080X:2P00<0
WIfM09VIV@2IVIT00`2IVIT01@2BTY80T92@092@T02@T900SHf=0080Shn?0`1oOgl307=cL`05061P
H01BDU80DE5A055AD@10@4000P0o?cl01@0g=cL0=SHf03Hf=P0N7Qh0CDe=0080R8R800@0KVi^0861
P@21PH40WinO0P3Cdm<30<[:bP80b<S82037alL30<S8b080bLW90P3:b/X00`3;bl/0c<c<0<c<c003
0<g=c@050<k>cP3?cll0d=3@0=3@d03AdM400P3Bd]830=?Cd`040=CDe03EeMD0eMGE0>OWib@0oooo
00<0lo?c0?KfmP3]kNd0203]kNd70>c/k0080>SXj03De=@0Xj>S07AdM01RHV80HF5Q069RHP1OGel2
05ADE009069RHP1dM7@0Q8B409BDU02XZ:P0^k^k0<G5a@3:b/X0c/k>0080dM7A00D0d];B0=GEe@3E
eMD0eMGE0=KFeP020=OGe`040=KFeP3De=@0f=SH0=SHf080e=CD103EeMD00`3Cdm<0d];B0=CDe002
0=7Ad@060=3@d03Bd]80d];B0<g=c@3?cll0b/[:0P37alL00`38b<P0aLG50;no_`020;no_`0O0;Zj
^P2d];@0/k>c0;>c/`2YZJT0YjNW0:VYZ@2HV9P0S8b<07alO01hN7P0IVIV05MGE`18B4P0@T9203dm
?@0^;Rh0;2`/01hN7P0H61P03@d=00l?3`10@400OWin07=cL`1bLW80R8R809nOW`35aLD0l?3`0>g]
k@090?3`l0/0kno_4@3^k^h00`3fm_H0lo?c0?ooo`0V0?ooo`009@3oool00`3YjNT0e]KF0=KFeP03
0=WIf@<0f][J1@3Kfm/20=cLg0040=_Kf`3IfMT0fMWI0>OWi`80c/k>00D0YJFU07emO@1lO7`0O7al
07IfMP0207AdM00408F5Q@2GUiL0UiNG0::RXP80][Jf00D0^k^k0;Rh^02m_Kd0_Kfm0;bl_0020;jn
_P<0^KVi00D0]kNg0;Jf]P2f][H0]KFe0;Bd]0020;2`/0040:n_[`2^[Zh0[Zj^0:b/[080Z:RX00D0
ZJVY0:>SX`2RXZ80XZ:R0:FUY@020:2PX00309fMW@2IVIT0VIVI00<0VIVI00D0TY:B092@T02@T900
T92@08f=S@0208n?S`<0Ogmo0`1cLg<01@1PH600DU9B055AD@1ADE40@4100080?clo00D0=cLg03Hf
=P0f=SH07QhN04e=C@0208R8R00406i^KP21PH40PH6109nOW`80dm?C0`3:b/X20<S8b0P0alO70`38
b<P20<W9b@80b/[:00<0bl_;0<c<c03<c<`00`3=cLd01@3>c/h0clo?0=3@d03@d=00dM7A0080d];B
0`3Cdm<0103De=@0eMGE0=GEe@3WinLT0?ooo`80l_;b00<0k>c/0>g]k@3]kNd01P3]kNd00`3/k>`0
jNWY0>c/k0030>c/k0060>_[j`3_knl0n?Sh0>?Sh`34a<@0QhN70P1UIFD0401MGEd0G5aL05YJFP1P
H600L71`08F5Q@2EUID0XJ6Q0;Bd]036a/H0bLW90<c<c03AdM40d=3@0=GEe@3GemL20=CDe080eMGE
0P3Fe]H00`3EeMD0emOG0=OGe`020=GEe@040=CDe03EeMD0eMGE0=GEe@<0e=CD0P3?cll01@3Bd]80
e=CD0=3@d039bLT0bl_;00@0b<S802<0a/K60;jn_P2k^k/0^k^k0;Zj^P2g]kL0]KFe0:n_[`2RXZ80
YZJV09fMW@2CTi<0Shn?07AdM01VIVH0F5QH05EEE@18B4P0?Cdm03Ph>00_;bl09RHV02<S8`0D51@0
000002<S8`1^KVh0OGem06YZJP1eMGD0R8R80:JVYP3Cdm<0lO7a0>o_k`080?3`l0`0kno_4@3^k^h0
0`3fm_H0lo?c0?ooo`0V0?ooo`009@3oool00`3YjNT0f=SH0=SHf0040=WIf@D0f][J103Kfm/0103J
f]X0fMWI0=WIf@3Hf=P20=OGe`050=KFeP1nOWh0N7Qh07QhN01YJFT00P1hN7P01021PH40UIFE09FE
U@2UYJD20;:b/P030;6a/@2j^[X0^[Zj0080^[Zj0`2g]kL30;Rh^080][Jf00@0/;2`0;:b/P2a/K40
/K6a0`2ZZZX01@2VYZH0Y:BT0:BTY02TY:@0Xj>S0080X:2P00@0Vi^K09ZJVP2JVYX0VIVI1@2HV9P0
102@T900SHf=08j>SP2>SXh308Z:RP<0PH6100D0Lg=c06EUI@1UIFD0EeMG055AD@0205=CD`0404Y:
BP0d=3@0=3@d03Ph>080:RXZ00D0?Shn0861P@1bLW80LW9b06UYJ@0209:BTP040;fm_@3>c/h0c/k>
0<O7a`80b<S80P39bLT80<S8b0<0bLW90P3:b/X20<_;b`<0c<c<00<0cLg=0<k>cP3>c/h00P3?cll2
0=3@d0040=7Ad@3Bd]80d];B0=?Cd`<0e=CD0P3EeMD00`3WinL0oooo0?ooo`0R0?ooo`030?;blP3c
lo<0k>c/00P0kNg]00@0k>c/0>[ZjP3/k>`0kNg]0`3/k>`02@3]kNd0l?3`0?Cdm03clo<0[Zj^06][
J`1KFe/0F5QH05EEE@0205mOG`0?06a/K023Ph<0UIFE0::RXP2a/K40`L710<K6aP3;bl/0clo?0=;B
dP3Cdm<0d];B0=7Ad@3Bd]80e=CD00<0e]KF0P3De=@01`3EeMD0e]KF0=CDe03Bd]80eMGE0=;BdP3A
dM400`3Bd]801@3@d=00c/k>0<k>cP3>c/h0b/[:00H0b<S800<0a/K60;jn_P2i^KT00P2i^KT0802g
]kL0/k>c0:f][@2TY:@0Xj>S09nOW`2EUID0RXZ:06a/K01MGEd0EEEE05MGE`1CDe<0?Shn02d];@0_
;bl08b<S01`L70092@T092@T05mOG`1kNg/0Kfm_069RHP1jNWX0UIFE0;bl_03Shn<0l?3`0>k^kP3]
kNd0kno_1@3`l?0=0>o_ka40k^k^00<0m_Kf0??cl`3oool09P3oool002D0oooo00@0jNWY0=SHf03H
f=P0f=SH1@3IfMT70=[JfP040=WIf@3Hf=P0f=SH0=OGe`80eMGE00D0hN7Q08F5Q@1[Jf/0Jf][09>C
T`0207MgM`0408Z:RP2EUID0UIFE0::RXP80/[:b0P2j^[X20;Ng]`040;Zj^P2i^KT0^KVi0;fm_@80
];Bd00D0]kNg0;2`/02`/;00]KFe0;:b/P020:n_[`040:j^[P2WYjL0YjNW0:^[Z`80Y:BT0P2MWId2
0::RXP0409VIV@2HV9P0V9RH09RHV080UiNG00D0UYJF096AT@2ATI40Ti>C08^;R`0208V9R@0408F5
Q@24Q8@0Q8B4071`L080NGUi00D0Jf][06EUI@1UIFD0GemO059BDP020410@004059BDP16ATH0ATI6
024Q8@80<C4a00D0GEeM06][J`1/K6`0K6a/07UiN@0209ZJVP040<O7a`3;bl/0bl_;0<_;b`80cLg=
00<0b/[:0<W9b@39bLT02039bLT30<[:bP040<_;b`3<c<`0c<c<0<c<c080cLg=00D0c/k>0<o?c`3?
cll0clo?0=3@d0030=7Ad@80d];B00<0dm?C0=CDe03De=@00`3EeMD00`3WinL0oooo0?ooo`0R0?oo
o`030??cl`3fm_H0kNg]0100kNg]01<0k>c/0>g]k@3fm_H0clo?07MgM`18B4P0G5aL05iNGP1MGEd0
IFEU07=cL`22PX80TY:B0:>SX`2b/[80_[jn0<G5a@39bLT0b/[:00<0clo?0`3Bd]801@3EeMD0e]KF
0=GEe@3Bd]80e=CD0080e]KF00L0eMGE0=;BdP3Cdm<0clo?0=3@d03AdM40c/k>00<0cLg=00<0b/[:
0<O7a`37alL01@38b<P00`37alL0`l?30;fm_@020;Vi^@0<0;Rh^02c/k<0[jn_0:^[Z`2QXJ40WinO
0::RXP2DU9@0PH6106][J`1UIFD0Fe]K0P1BDU802@1?Cdl0>SXj02<S8`0K6a/04Q8B01TI6@1?Cdl0
Ng]k07AdM00206MWI`0708B4Q02YZJT0dM7A0>_[j`3^k^h0jn_[0>o_k`040?3`l0h0kno_4P3^k^h0
0`3fm_H0lo?c0?ooo`0V0?ooo`009@3oool0103YjNT0f=SH0=SHf03Hf=P50=WIf@L0f][J00@0fMWI
0=SHf03Hf=P0emOG0P3EeMD01@3QhN40QHF506][J`1[Jf/0Ti>C0080MgMg00@0RXZ:09FEU@2EUID0
XZ:R0P2b/[820;Zj^P80]kNg00@0^[Zj0;Vi^@2i^KT0_Kfm0P2d];@01@2g]kL0/;2`0;2`/02e]KD0
/[:b0080[jn_00@0[Zj^0:NWY`2WYjL0Zj^[0P2TY:@209fMW@80XZ:R00@0VIVI09RHV02HV9P0V9RH
0P2GUiL01@2FUYH0TI6A096AT@2CTi<0Rh^;0080RHV900@0QHF508B4Q024Q8@0L71`0P1iNGT01@1[
Jf/0IFEU06EUI@1OGel0DU9B0080@41000@0DU9B04I6AP16ATH08B4Q0P0a<C401@1MGEd0Jf][06a/
K01/K6`0NGUi0080VYZJ00@0alO70<_;b`3;bl/0bl_;0P3=cLd00`3:b/X0bLW90<W9b@080<W9b@<0
b/[:00@0bl_;0<c<c03<c<`0c<c<0P3=cLd01@3>c/h0clo?0<o?c`3?cll0d=3@00<0dM7A0P3Bd]80
0`3Cdm<0e=CD0=CDe0030=GEe@030>OWi`3oool0oooo0280oooo00<0lo?c0?KfmP3]kNd04P3]kNd0
4P3emOD0g]kN08B4Q012@T80G5aL071`L01LG5`0L71`07alO022PX80Ti>C0::RXP2b/[80^k^k0<S8
b039bLT0b<S80<_;b`80d=3@00P0eMGE0=CDe03@d=00dM7A0=GEe@3AdM40e=CD0=GEe@80e=CD00@0
eMGE0=KFeP3@d=00c/k>0P3AdM401P3<c<`0b<S80<S8b03<c<`0b/[:0<O7a`<0b<S802@0bLW90<S8
b038b<P0a<C40;jn_P2o_kl0^KVi0;Ng]`2c/k<0/K6a0:n_[`2UYJD0U9BD09^KV`2FUYH0R8R807al
O01[Jf/0IFEU05UIF@1<C4`0BDU905MGE`1>CTh08B4Q01PH600L71`0@41005EEE@1UIFD0MGEe06m_
K`1iNGT0TI6A0:j^[P3De=@20?3`l0030>g]k@3emOD0l_;b0140kno_4P3^k^h00`3fm_H0lo?c0?oo
o`0V0?ooo`009@3oool00`3YjNT0f=SH0=SHf0030=SHf0/0fMWI0P3Hf=P01@3GemL0e=CD0=CDe03I
fMT0V9RH0080Jf][00@0Kfm_07alO01lO7`0QXJ60P2DU9@01@2TY:@0Zj^[0:^[Z`2c/k<0^KVi0080
^;Rh00@0]kNg0;:b/P2b/[80^k^k0P2d];@01@2a/K40/;2`0;2`/02_[jl0[Zj^0080YjNW00@0Zj^[
0:6QX@2QXJ40WYjN0P2HV9P00`2EUID0Ti>C09RHV00209RHV0<0UIFE0P2DU9@00`2CTi<0S8b<08b<
S00208V9R@<0PX:20P1iNGT0101_Kfl0JFUY06UYJ@1KFe/205eMG@0504i>CP19BDT0AdM704M7A`14
A4@00P10@4001@0i>CT0I6AT06ATI01MGEd0KFe]0080RXZ:00@0RHV90:VYZ@2YZJT0b<S80P3@d=03
0<W9b@030<g=c@39bLT0bLW900@0bLW9103:b/X30<_;b`<0c<c<0`3=cLd00`3AdM40c/k>0<k>cP02
0=3@d080dM7A0`3Bd]800`3Cdm<0e=CD0=CDe0030=GEe@030>SXj03oool0oooo0280oooo00<0lo?c
0?KfmP3]kNd04@3]kNd0603^k^h0m_Kf0<o?c`2ATI40IFEU055AD@1CDe<0GEeM079bLP1jNWX0PH61
09>CT`2SXj<0/;2`0;>c/`36a/H0bLW90<S8b039bLT0c<c<0<[:bP3Bd]80dm?C0<o?c`@0d=3@0P3A
dM401P3@d=00dM7A0=CDe03<c<`0b/[:0<W9b@80alO70P34a<@30<O7a`80a/K61037alL01@31`L40
^;Rh0;Rh^02i^KT0/[:b0080[jn_01`0[:b/0:6QX@2DU9@0TY:B08V9R@1kNg/0Lg=c061PH01FEUH0
EEEE055AD@1@D500@T9203Lg=`0o?cl0<C4a0492@P14A4@0GemO07EeM@1dM7@0QHF508^;R`2UYJD0
]kNg0=OGe`3dm?@0mOGe0`3_knl00`3`l?00kno_0>o_k`0=0>o_k`@0k^k^0P3_knl=0>k^kP030?Kf
mP3clo<0oooo02H0oooo000U0?ooo`030>WYj@3Hf=P0f=SH00@0f=SH2@3IfMT30=SHf0050=OGe`3E
eMD0eMGE0=OGe`30`<000P1FEUH0101YJFT0NGUi07UiN@1lO7`2092@T00409ZJVP2/[:`0[:b/0:f]
[@<0/[:b00@0];Bd0;Fe]@2e]KD0/[:b0P2c/k<01@2^[Zh0[Jf]0:f][@2/[:`0ZZZZ0080Xj>S00@0
Y:BT09jNWP2NWYh0UYJF0`2;Rh/0102=SHd0TY:B09:BTP2<S8`208Z:RP0408^;R`23Ph<0Ph>308R8
R080Ph>300D0QXJ607moO`1lO7`0O7al07QhN00206a/K00406ATI01UIFD0IFEU05eMG@80Fe]K00D0
Bd];04M7A`0o?cl0?clo05EEE@0204=3@`0504];B`23Ph<0Ph>306QXJ01cLg<00P2GUiL0102MWId0
][Jf0;Jf]P3;bl/20<[:bP<0bl_;00<0cLg=0<W9b@3:b/X01`3:b/X30<_;b`040<[:bP3<c<`0cLg=
0<g=c@<0c/k>00@0dM7A0<o?c`3?cll0d=3@0`3AdM40103Bd]80dm?C0=?Cd`3Cdm<20=CDe0040=GE
e@3Fe]H0e]KF0>SXj2@0oooo00<0lo?c0?KfmP3]kNd03`3]kNd30>k^kP0G0?Ogm`36a/H0WYjN07]k
N`14A4@0DE5A05MGE`1MGEd0JVYZ07alO02<S8`0V9RH0:6QX@2b/[80_kno0<G5a@36a/H0`<300<_;
b`3=cLd0clo?0=3@d03=cLd00P3:b/X0203<c<`0d=3@0=3@d03Cdm<0dM7A0<_;b`3>c/h0bLW90P37
alL0=032`/80^k^k0;Vi^@2j^[X0`l?30<O7a`35aLD0`<300;jn_P31`L40_[jn0;^k^`2l_;`0]kNg
0;:b/P2d];@0/[:b0:^[Z`2YZJT0YZJV09jNWP2EUID0Ti>C08b<S026QXH0Ng]k07EeM@1SHf<0CDe=
04a<C019BDT0AdM703lo?`0j>SX0>c/k02l_;`1YJFT0K6a/06UYJ@1]KFd0MgMg09^KV`2EUID0/;2`
0=[JfP3^k^h0l?3`0>o_k`3[jn/0k^k^0>o_k`3clo<?0>o_k`@0k^k^00<0l_;b0??cl`3^k^h0303^
k^h00`3fm_H0lo?c0?ooo`0V0?ooo`009@3oool00`3YjNT0f=SH0=SHf0040=SHf0T0fMWI0`3Hf=P0
1@3GemL0eMGE0=GEe@3GemL0`<300080EUIF00@0JFUY07UiN@1iNGT0O7al0P2@T900102JVYX0[:b/
0:b/[02][Jd30;:b/P040;Bd]02e]KD0]KFe0;:b/P80/k>c00D0[Zj^0:f][@2][Jd0[:b/0:ZZZP02
0:>SX`040:BTY02NWYh0WYjN09JFUP<0Rh^;00@0SHf=09:BTP2BTY80S8b<0P2:RXX0102;Rh/0Ph>3
08>3P`28R8P208>3P`0508J6QP1oOgl0O7al07alO01hN7P00P1/K6`0101TI6@0IFEU06EUI@1MGEd2
05]KF`0504];B`17AdL0?clo03lo?`1EEED00P13@d<01@1;Bd/0Ph>308>3P`1XJ6P0Lg=c0080UiNG
00@0WIfM0;Jf]P2f][H0bl_;0P3:b/X30<_;b`030<g=c@39bLT0b/[:00L0b/[:0`3;bl/0103:b/X0
c<c<0<g=c@3=cLd30<k>cP040=7Ad@3?cll0clo?0=3@d0<0dM7A00@0d];B0=?Cd`3Cdm<0dm?C0P3D
e=@0103EeMD0e]KF0=KFeP3Xj>PT0?ooo`030??cl`3fm_H0kNg]00`0kNg]1P3^k^h0503alO40f][J
0<W9b@2>SXh0<C4a04I6AP1SHf<0FUYJ06=SH`1jNWX0QXJ609:BTP2VYZH0/[:b0;Vi^@2n_[h0_kno
0;jn_P39bLT0bl_;0P39bLT20<c<c080bLW900X0b/[:0<_;b`3<c<`0b/[:0<S8b039bLT0b<S80<C4
a02o_kl0^;Rh0P2c/k<01`2g]kL0_;bl0;^k^`2g]kL0][Jf0;Fe]@2f][H00P2`/;002`2e]KD0/K6a
0:^[Z`2`/;00Zj^[0:RXZ02SXj<0X:2P09bLW02ATI40RHV90080QXJ601H0OWin07IfMP1KFe/0E5AD
051@D01:BTX0E5AD05MGE`17AdL0@T9205EEE@1lO7`0MgMg071`L01iNGT0Rh^;0:JVYP2b/[80]kNg
0=_Kf`3alO40kno_0P3^k^h00`3emOD0lO7a0?7al@0<0>o_k`80k>c/00<0kno_0>k^kP3^k^h00P3^
k^h20?3`l0d0k^k^00<0m_Kf0??cl`3oool09P3oool002D0oooo00<0jNWY0=OGe`3GemL04`3Hf=P0
1@3Jf]X0^KVi08F5Q@25QHD0Kfm_00<0NGUi0P21PH401@2:RXX0Xj>S0:>SX`2k^k/0Zj^[0080[Jf]
00@0ZZZZ0;Fe]@2e]KD0/k>c0P2a/K401@2][Jd0YJFU0:FUY@2TY:@0XJ6Q0080UiNG00@0SHf=08Z:
RP2:RXX0RHV90P1oOgl00`1nOWh0NGUi07QhN00207QhN080Ng]k0`1jNWX01@1`L700LG5a075aL@1`
L700Kfm_0080I6AT00@0K6a/06=SH`1SHf<0GEeM0P1ADE401@13@d<0EeMG05MGE`1>CTh0DE5A0080
F5QH00@0@T92065QH@1QHF40GemO0P1UIFD01@1[Jf/0MGEe09ZJVP2JVYX0Zj^[00<0b/[:1@39bLT7
0<[:bP<0bl_;0`3<c<`40<g=c@040<k>cP3?cll0clo?0<o?c`<0d=3@00@0dM7A0=;BdP3Bd]80d];B
0P3Cdm<30=CDe0040=GEe@3Fe]H0e]KF0>SXj2@0oooo00<0lo?c0?KfmP3]kNd02P3]kNd70>k^kP80
kno_01<0k^k^0=?Cd`2ATI40EEEE04e=C@1NGUh0Hf=S06EUI@1_Kfl0NWYj08J6QP2OWil0[Jf]0;Zj
^P2g]kL0^KVi0;bl_02o_kl0b<S80080bLW90P3;bl/00`37alL0a<C40<?3``020<C4a00>0<71`@2m
_Kd0^[Zj0;Vi^@2g]kL0];Bd0:n_[`2[Zj/0ZZZZ0:VYZ@2[Zj/0Z:RX0:NWY`2ZZZX20:RXZ00E0:FU
Y@2QXJ40XZ:R0:6QX@2OWil0XZ:R09nOW`2HV9P0Ti>C09JFUP2GUiL0SHf=08F5Q@21PH40MgMg06e]
K@1/K6`0GemO05ADE01MGEd0GUiN0080EUIF00`0G5aL05eMG@1XJ6P0M7Ad06i^KP1gMgL0Q8B408n?
S`2][Jd0_[jn0=3@d03Vi^H30>o_k`030?3`l03bl_80l?3`00d0kno_0P3]kNdD0>k^kP030?KfmP3c
lo<0oooo02H0oooo000U0?ooo`030>SXj03GemL0emOG01@0f=SH00@0hN7Q0;Zj^P2j^[X0RXZ:0P1b
LW80101iNGT0RXZ:08Z:RP2ATI4208V9R@0509:BTP2^[Zh0/;2`0;2`/02g]kL00P2c/k<0102[Zj/0
Z:RX0:RXZ02VYZH209RHV00509BDU02?Shl0Vi^K09^KV`25QHD00P23Ph<01@20P800JVYZ06YZJP1`
L700Jf][0080I6AT00@0Lg=c06IVIP1VIVH0GUiN0P1UIFD01@1LG5`0HV9R069RHP1NGUh0GemO0080
HF5Q00@0EeMG061PH01PH600IfMW0P1QHF401@1LG5`0GUiN05iNGP1=CDd0EEEE0080I6AT00@0ATI6
03`l?00l?3`0JFUY0P1cLg<01@1eMGD0T92@09FEU@2EUID0Zj^[0080b/[:00<0bLW90<S8b038b<P0
0`39bLT01036a/H0b/[:0<[:bP3:b/X40<_;b`<0c<c<0`3=cLd00`3>c/h0cLg=0<g=c@030<o?c`04
0=OGe`3@d=00d=3@0=7Ad@<0d];B0`3Cdm<0103De=@0eMGE0=GEe@3EeMD20=KFeP030>SXj03oool0
oooo0280oooo00<0lo?c0?KfmP3^k^h03`3^k^h40>o_k`1:0?3`l03dm?@0i^KV0;bl_02EUID0Kfm_
06EUI@1TI6@0K6a/07inOP21PH40M7Ad08J6QP2YZJT0^k^k0<30`035aLD0bLW90<K6aP32`/80_kno
0;fm_@2k^k/0]kNg0;2`/02_[jl0Zj^[0:ZZZP2b/[80]KFe0:VYZ@2XZ:P0Xj>S0:6QX@2JVYX0TY:B
09>CT`2@T900S8b<08j>SP2;Rh/0QhN708n?S`1jNWX0OWin08:2PP1lO7`0Ogmo08R8R01nOWh0Ogmo
0861P@22PX80OGem07YjNP21PH40QXJ607emO@21PH40O7al07QhN01TI6@0IVIV06ATI01/K6`0IFEU
055AD@19BDT0GUiN07UiN@1nOWh0PH6108j>SP2RXZ820:f][@040<S8b03YjNT0l_;b0?3`l080k^k^
0`3_knl00`3]kNd0kno_0>o_k`060>o_k`L0k^k^00@0kNg]0>k^kP3^k^h0k^k^0P3bl_8=0>k^kP03
0?KfmP3clo<0oooo02H0oooo000U0?ooo`040>SXj03GemL0emOG0=SHf080emOG00@0f=SH0=OGe`3G
emL0f=SH0P3EeMD80=SHf0@0fMWI0P3Ng]h0103QhN40QHF508F5Q@1mOGd208:2PP0508n?S`2FUYH0
UYJF09fMW@2e]KD00P2`/;00102c/k<0[Zj^0:j^[P2WYjL209nOW`0509NGU`2IVIT0VIVI08^;R`2?
Shl00P27QhL01020P800Ng]k07]kN`1^KVh206ATI004065QH@1TI6@0Fe]K05]KF`<0H61P00@0GUiN
055AD@1ADE40FUYJ0P1OGel01@1JFUX0EEEE05IFEP1FEUH0GemO0080?3`l00@0CDe=05UIF@1IFET0
D51@0P1FEUH01@1KFe/0C4a<04Q8B018B4P0F5QH0080FUYJ00D0IFEU07YjNP1jNWX0Shn?09JFUP02
08j>SP040<k>cP36a/H0a/K60<O7a`80b/[:00<0b<S80<W9b@39bLT0103:b/X30<_;b`<0c<c<0`3=
cLd20<k>cP80c<c<00@0clo?0=3@d03@d=00d=3@0`3AdM430=;BdP040=?Cd`3De=@0e=CD0=CDe0<0
eMGE0P3Fe]H00`3Xj>P0oooo0?ooo`0R0?ooo`030??cl`3fm_H0k^k^00D0k^k^0`3]kNd70>k^kP<0
kno_0`3`l?001@3bl_80m?Cd0>?Sh`2EUID0MGEe0080IVIV0180NWYj07inOP1dM7@0Shn?0;2`/030
`<00`l?30<C4a036a/H0`/;20;no_`2j^[X0];Bd0:n_[`2YZJT0[:b/0:RXZ02VYZH20:RXZ00a0:JV
YP2TY:@0YJFU09VIV@2CTi<0SXj>08Z:RP28R8P0Rh^;08R8R01oOgl0P82008N7Q`23Ph<0N7Qh06m_
K`1kNg/0O7al07emO@22PX80MWIf07MgM`1iNGT0NWYj07inOP1cLg<0HV9R06][J`1cLg<0N7Qh07Ad
M01`L700Lg=c06i^KP1JFUX0EeMG065QH@1WIfL0J6QX06m_K`1gMgL0OWin096AT@2XZ:P0]KFe0:f]
[@2/[:`0j^[Z0??cl`020?3`l0030>o_k`3]kNd0kno_00P0kno_203^k^h00`3_knl0kNg]0>_[j`0B
0>k^kP030?KfmP3clo<0oooo02H0oooo000U0?ooo`040>SXj03GemL0emOG0=SHf080emOG00@0f=SH
0=OGe`3GemL0f=SH0P3EeMD80=SHf0@0fMWI0P3Ng]h0103QhN40QHF508F5Q@1mOGd208:2PP0508n?
S`2FUYH0UYJF09fMW@2e]KD00P2`/;00102c/k<0[Zj^0:j^[P2WYjL209nOW`0509NGU`2IVIT0VIVI
08^;R`2?Shl00P27QhL01020P800Ng]k07]kN`1^KVh206ATI004065QH@1TI6@0Fe]K05]KF`<0H61P
00@0GUiN055AD@1ADE40FUYJ0P1OGel01@1JFUX0EEEE05IFEP1FEUH0GemO0080?3`l00@0CDe=05UI
F@1IFET0D51@0P1FEUH01@1KFe/0C4a<04Q8B018B4P0F5QH0080FUYJ00D0IFEU07YjNP1jNWX0Shn?
09JFUP0208j>SP040<k>cP36a/H0a/K60<O7a`80b/[:00<0b<S80<W9b@39bLT0103:b/X30<_;b`<0
c<c<0`3=cLd20<k>cP80c<c<00@0clo?0=3@d03@d=00d=3@0`3AdM430=;BdP040=?Cd`3De=@0e=CD
0=CDe0<0eMGE0P3Fe]H00`3Xj>P0oooo0?ooo`0R0?ooo`030??cl`3fm_H0k^k^00D0k^k^00<0j^[Z
0>c/k03[jn/01P3^k^h40>o_k`<0l?3`00X0lO7a0?Gem@3^k^h0WYjN07emO@1kNg/0N7Qh07YjNP2=
SHd0Y:BT0P2YZJT00`2`/;00[:b/0;Fe]@020;bl_0030;Jf]P2c/k<0[jn_00<0ZJVY02P0VYZJ09VI
V@2SXj<0Y:BT09^KV`2FUYH0Vi^K09NGU`2?Shl0R8R808F5Q@20P800Rh^;08>3P`28R8P0Shn?08:2
PP1nOWh0RXZ:07moO`1_Kfl0PX:208^;R`1lO7`0Q8B407alO01jNWX0OWin08F5Q@1hN7P0H61P06YZ
JP1fMWH0MgMg06a/K01YJFT0M7Ad069RHP1WIfL0Hf=S0`1UIFD02P1bLW80Q8B40:BTY02`/;00[Jf]
0:RXZ02a/K40d=3@0>g]k@3alO420>o_k`030?;blP3emOD0kno_00D0kno_803^k^h00`3fm_H0lo?c
0?ooo`0V0?ooo`009@3oool0103Xj>P0e]KF0=KFeP3Fe]H20=OGe`@0f=SH0P3GemL70=SHf0@0fMWI
00@0f][J0=cLg03Lg=`0hN7Q0P2g]kL308>3P`0507moO`2DU9@0U9BD09:BTP2PX:000P2][Jd0102Z
ZZX0Y:BT0:BTY02NWYh209VIV@<0TI6A00@0OWin07moO`1oOgl0Ogmo0`1bLW801@1aLG40FEUI05UI
F@1ADE40C4a<0080G5aL00@0Fe]K05eMG@1MGEd0EeMG0P1HF5P01@1NGUh0FEUI05UIF@1BDU80E5AD
0080GUiN00@0Cdm?04Q8B018B4P0?Cdm0P0i>CT01@0f=SH0BTY:04Y:BP10@400@D510080?clo00@0
CDe=06MWI`1WIfL0OWin0P2SXj<01@25QHD0LW9b0<?3``33`l<0a<C40080aLG500@0a/K60<W9b@39
bLT0b<S80P39bLT20<[:bP<0bl_;0`3<c<`30<g=c@<0c/k>0`3?cll30=3@d0<0dM7A0P3Bd]830=?C
d`<0e=CD0`3EeMD20=KFeP030>SXj03oool0oooo0280oooo00@0lo?c0?Ogm`3[jn/0k>c/103^k^h3
0>g]k@D0k^k^1@3_knl40?3`l080lO7a02<0k>c/09>CT`1gMgL0Ogmo07AdM01fMWH0S8b<09FEU@2H
V9P0YjNW0;:b/P2e]KD0/k>c0;2`/02/[:`0[Zj^0:ZZZP2PX:00XJ6Q0:2PX02BTY80Ti>C09BDU02C
Ti<0U9BD08f=S@2DU9@0S8b<08n?S`29RHT0N7Qh07AdM01/K6`0NGUi0820P00208F5Q@0707EeM@1n
OWh0O7al07QhN02:RXX0QHF506QXJ00207AdM0050820P01oOgl0M7Ad06a/K01UIFD00P1KFe/01@1B
DU80Cdm?05YJFP1FEUH0E5AD0080EeMG00`0G5aL06QXJ01iNGT0T92@0:BTY02n_[h0ZZZZ0:FUY@2J
VYX0XJ6Q0>c/k03alO430>o_k`80l?3`0`3_knlS0>k^kP030?KfmP3clo<0oooo02H0oooo000U0?oo
o`040>SXj03Hf=P0f=SH0=SHf0P0emOG1`3Hf=P30=WIf@80f][J0P3Lg=`0103MgMd0jn_[0>_[j`2k
^k/208n?S`0509BDU02^[Zh0[Zj^0:j^[P2i^KT00P2`/;000`2^[Zh0UIFE09FEU@0309:BTP0508^;
R`2ATI40TI6A08N7Q`1kNg/00P1aLG40101iNGT0HV9R069RHP1JFUX203lo?`0505mOG`1<C4`08b<S
02<S8`1EEED00P17AdL0101LG5`0FEUI05UIF@1@D50204A4A00505iNGP0P8200<30`030`<00l?3`0
0P0j>SX01013@d<0CTi>04i>CP1GEeL204a<C080ADE50P1<C4`01029RHT0Ng]k07]kN`2GUiL203dm
?@0507EeM@2CTi<0b/[:0<[:bP31`L400P34a<@01036a/H0alO70<O7a`38b<P20<K6aP80b/[:0`3;
bl/20<c<c0@0cLg=0P3>c/h20<o?c`D0d=3@00@0dM7A0=;BdP3Bd]80d];B0`3Cdm<30=CDe0<0eMGE
0`3Fe]H00`3Xj>P0oooo0?ooo`0R0?ooo`040??cl`3fm_H0kNg]0>g]k@`0k^k^1@3_knl50?3`l00W
0?;blP3gmoL0hN7Q0:^[Z`23Ph<0N7Qh07emO@2FUYH0W9bL0:RXZ02b/[80][Jf0;Ng]`2e]KD0YZJV
0:6QX@2SXj<0XZ:R09fMW@2IVIT0WIfM09JFUP2EUID0Shn?08N7Q`2<S8`0TY:B08^;R`1oOgl0PH61
07IfMP1/K6`0OGem06ATI01GEeL0K6a/07=cL`1]KFd0P8200080Ng]k00L0OGem07AdM01YJFT0KVi^
07=cL`1BDU80E5AD0080I6AT01L0GEeM05]KF`1HF5P0GEeM05UIF@1MGEd0HF5Q05MGE`1?Cdl0FEUI
05iNGP1oOgl0TI6A092@T02ZZZX0]kNg08R8R02=SHd0TI6A09NGU`35aLD0m_Kf0?7al@040>o_k`05
0>k^kP3_knl0kno_0>c/k03_knl08P3^k^h00`3fm_H0lo?c0?ooo`0V0?ooo`009@3oool0103Xj>P0
f=SH0=SHf03Hf=P80=OGe`L0f=SH0`3IfMT20=[JfP80g=cL00@0gMgM0>_[j`3[jn/0^k^k0P2?Shl0
1@2DU9@0[Zj^0:j^[P2^[Zh0^KVi0080/;2`00<0[Zj^09FEU@2EUID00`2BTY801@2;Rh/0TI6A096A
T@27QhL0Ng]k0080LG5a00@0NGUi069RHP1RHV80FUYJ0P0o?cl01@1OGel0C4a<02<S8`0S8b<0EEEE
0080AdM700@0G5aL05UIF@1IFET0D51@0P14A4@01@1NGUh0820P030`<00`<300?3`l0080>SXj00@0
@d=304i>CP1>CTh0EeMG0P1<C4`204E5A@80C4a<00@0RHV907]kN`1kNg/0UiNG0P0m?Cd01@1eMGD0
Ti>C0<[:bP3:b/X0`L710080a<C400@0a/K60<O7a`37alL0b<S80P36a/H20<[:bP<0bl_;0P3<c<`4
0<g=c@80c/k>0P3?cll50=3@d0040=7Ad@3Bd]80d];B0=;BdP<0dm?C0`3De=@30=GEe@<0e]KF00<0
j>SX0?ooo`3oool08P3oool00`3clo<0m_Kf0>k^kP0=0>k^kPD0kno_103`l?030?7al@050?gmo@37
alL0SXj>07]kN`1aLG400P25QHD0:`2SXj<0];Bd0;Jf]P2e]KD0]kNg0:NWY`2LW9`0VIVI09RHV02E
UID0UYJF09VIV@2DU9@0SXj>08V9R@28R8P0RHV908J6QP25QHD0PX:2079bLP1cLg<0PX:207YjNP1m
OGd0HF5Q05]KF`1YJFT0KFe]075aL@1]KFd0L71`06][J`1OGel0FEUI05aLG01FEUH0BDU904M7A`1J
FUX0G5aL059BDP1FEUH00P1NGUh02@1JFUX0F5QH05QHF01ZJVX0KVi^07AdM021PH40U9BD0:JVYP02
0;:b/P0:09VIV@1_Kfl0QhN708F5Q@2OWil0j^[Z0??cl`3_knl0k^k^0>o_k`80kNg]00@0kno_0>k^
kP3/k>`0k>c/3P3^k^h01P3]kNd0k>c/0>k^kP3^k^h0l_;b0?3`l0l0k^k^00<0m_Kf0??cl`3oool0
9P3oool002D0oooo00<0j>SX0=OGe`3GemL02@3GemL80=SHf0<0fMWI00@0f][J0=_Kf`3Kfm/0g=cL
0P3Ng]h0103=cLd0OGem07emO@1mOGd208J6QP0508N7Q`2TY:@0[Zj^0:j^[P2ZZZX00P2PX:001026
QXH0Q8B408B4Q02:RXX208R8R00507YjNP1dM7@0MgMg07MgM`1RHV800P1ZJVX01@1@D500Hf=S06=S
H`1<C4`0EEEE0080C4a<00@0=cLg04];B`1;Bd/0?Shn0P18B4P303Xj>P0302XZ:P0j>SX0=SHf0080
=SHf0P0j>SX01012@T80>c/k03/k>`0j>SX204];B`0305aLG01PH600NGUi0080NGUi0P25QHD01@1P
H600JVYZ06YZJP1cLg<0[Jf]0080^k^k00@0`L710<;2`P32`/80`/;20P37alL01@36a/H0b<S80<S8
b03<c<`0b/[:00<0bl_;0P3?cll00`3<c<`0cLg=0<g=c@030<k>cP050<o?c`3=cLd0dM7A0=7Ad@3B
d]800P3Cdm<30=;BdP80dm?C1@3De=@30=GEe@<0e]KF00<0j>SX0?ooo`3oool08P3oool00`3clo<0
m_Kf0>k^kP0<0>k^kPH0kno_103`l?020?7al@0:0?;blP3clo<0hN7Q0:2PX01UIFD0L71`08N7Q`1g
MgL0T92@0:JVYP80/k>c00<0/;2`0:RXZ02CTi<00`2<S8`209NGU`0Q08n?S`21PH40PH6108Z:RP27
QhL0O7al08N7Q`26QXH0MgMg07IfMP1lO7`0LG5a07]kN`1fMWH0H61P065QH@1]KFd0HF5Q05eMG@1S
Hf<0G5aL05EEE@1CDe<0CDe=04I6AP1ADE40CTi>051@D01ADE40D51@05EEE@1IFET0De=C0080Cdm?
00D0FEUI07=cL`1nOWh0O7al09:BTP0309nOW`0B09FEU@1mOGd0RHV9092@T02JVYX0a<C40>o_k`3/
k>`0k^k^0>o_k`3]kNd0k>c/0>g]k@3^k^h0k>c/0>_[j`3^k^h0l?3`103^k^h00`3alO40l?3`0>k^
kP060>k^kP060>g]k@3/k>`0k^k^0>k^kP3bl_80l?3`3`3^k^h00`3fm_H0lo?c0?ooo`0V0?ooo`00
9@3oool00`3Xj>P0emOG0=OGe`0:0=OGe`L0f=SH103IfMT20=[JfP040=_Kf`3Jf]X0f][J0>GUi@80
]KFe00D0MWIf08N7Q`27QhL0Vi^K09fMW@020:2PX0040:ZZZP2VYZH0YZJV07QhN080P82000D0Ng]k
0861P@21PH40KVi^071`L002079bLP0405iNGP1PH600H61P065QH@80=3@d00D0EEEE04I6AP0o?cl0
?clo034a<@0204I6AP0403Hf=P0m?Cd0?Cdm03Ti>@<0<S8b00@0:2PX02DU9@0U9BD0;Bd]0P0`<300
100k>c/0?clo03lo?`10@402061PH00506IVIP1dM7@0PX:208:2PP1gMgL00P1ADE401@1cLg<0FUYJ
05YJFP2ZZZX0`L710080]kNg00@0`<300<71`@31`L40aLG50P36a/H01@37alL0b<S80<S8b03<c<`0
b/[:00<0bl_;0P3@d=00103=cLd0c/k>0<k>cP3>c/h30<o?c`040=3@d03AdM40dM7A0=7Ad@<0d];B
103Cdm<30=CDe0D0eMGE0`3Fe]H00`3Xj>P0oooo0?ooo`0R0?ooo`030??cl`3fm_H0k^k^00`0k^k^
1P3_knl40?3`l0@0lO7a02T0oOgm0<W9b@1iNGT0MgMg08>3P`27QhL0TI6A09^KV`2YZJT0/k>c0:f]
[@2YZJT0RXZ:0861P@26QXH0Ph>308n?S`2BTY80R8R807QhN01lO7`0R8R808:2PP1iNGT0QXJ607em
O@20P800Kfm_05iNGP1cLg<0Hf=S06YZJP1OGel0GEeM06MWI`1LG5`0EUIF05]KF`1JFUX0De=C04i>
CP0204e=C@0A04Q8B010@400?3`l04=3@`1;Bd/0C4a<04m?C`1DE5@0D51@05EEE@1YJFT0P82007in
OP2:RXX0WYjN0:b/[02GUiL00P1bLW802@27QhL0Shn?09bLW03<c<`0kno_0>c/k03Zj^X0k^k^0>o_
k`020>c/k0030>o_k`3]kNd0jn_[0080k^k^00<0l_;b0>k^kP3^k^h00P3^k^h00`3bl_80lO7a0>g]
k@0K0>k^kP030?KfmP3clo<0oooo02H0oooo000U0?ooo`030>SXj03GemL0emOG00X0emOG1`3Hf=P4
0=WIf@80f][J00@0fm_K0=[JfP3Jf]X0iNGU0P2e]KD01@1fMWH0QhN708N7Q`2KVi/0WIfM0080X:2P
00@0ZZZZ0:JVYP2VYZH0N7Qh0P20P8001@1kNg/0PH610861P@1^KVh0L71`0080LW9b00@0GUiN061P
H01PH600HF5Q0P0d=3@01@1EEED0ATI603lo?`0o?cl0<C4a0080ATI600@0=SHf03dm?@0m?Cd0>CTi
0`0b<S80100X:2P09BDU02DU9@0];Bd2030`<00403/k>`0o?cl0?clo0410@080H61P00D0IVIV07Ad
M022PX80PX:207MgM`02055AD@0507=cL`1JFUX0FUYJ0:ZZZP31`L400P2g]kL01030`<00`L710<71
`@35aLD20<K6aP050<O7a`38b<P0b<S80<c<c03:b/X00`3;bl/20=3@d0040<g=c@3>c/h0c/k>0<k>
cP<0clo?00@0d=3@0=7Ad@3AdM40dM7A0`3Bd]840=?Cd`<0e=CD1@3EeMD30=KFeP030>SXj03oool0
oooo0280oooo00<0lo?c0?KfmP3^k^h0303^k^h60>o_k`@0l?3`0`3alO40503bl_80lO7a0?Ogm`3K
fm/0Ph>3059BDP1iNGT0UiNG09FEU@2KVi/0][Jf0;Ng]`2^[Zh0Rh^;07moO`26QXH0Ogmo07inOP28
R8P0QHF50P1jNWX08@23Ph<0P82007=cL`1fMWH0M7Ad07YjNP1/K6`0Hf=S07QhN01[Jf/0FEUI04E5
A@1EEED0JFUY059BDP1LG5`0FUYJ05EEE@1@D500BDU904I6AP11@D40=3@d02h^;P0d=3@0>CTi03Hf
=P0i>CT0BTY:061PH01MGEd0GemO06i^KP0209NGU`0A0;6a/@2ZZZX0VIVI08b<S01jNWX0Kfm_08j>
SP1cLg<0^KVi0?;blP3fm_H0l_;b0>[ZjP3]kNd0k^k^0>g]k@3^k^h00P3_knl;0>k^kP@0kNg]203^
k^h20>o_k`d0k^k^00<0m_Kf0??cl`3oool09P3oool002D0oooo00<0j>SX0=OGe`3GemL00`3GemL0
0`3Hf=P0emOG0=OGe`050=OGe`P0f=SH1`3IfMT0103De=@0emOG0=OGe`3EeMD206=SH`0507MgM`2<
S8`0Vi^K09^KV`2`/;000P2TY:@0101dM7@0O7al07alO01iNGT208R8R00508J6QP1WIfL0LW9b079b
LP1QHF400P1EEED01@1QHF40?clo03lo?`1DE5@0DU9B0080BDU900@03Ph>02l_;`0_;bl0EUIF0P0`
<3001@0_;bl0;2`/02`/;00Y:BT07QhN00806QXJ00@06ATI01@D500D51@0;Rh^0P1>CTh01@1ZJVX0
FUYJ05YJFP1dM7@0LG5a0080?Cdm00@0FUYJ069RHP1RHV80CTi>0P1jNWX0102m_Kd0^KVi0;bl_02l
_;`30;no_`040<?3``3>c/h0c/k>0<O7a`<0bLW900@0b/[:0<_;b`3;bl/0c<c<0P3=cLd00`3>c/h0
bl_;0<_;b`030<k>cP80d=3@0P3AdM430=;BdP040=_Kf`3Cdm<0dm?C0=?Cd`@0e=CD0`3EeMD50=KF
eP030>SXj03oool0oooo0280oooo00<0lo?c0?KfmP3^k^h0303^k^h70>o_k`@0l?3`0`3alO40;03_
knl0l?3`0?Win@3UiND0P82004];B`1lO7`0R8R809ZJVP2d];@0^k^k0;2`/02<S8`0Kfm_07YjNP2>
SXh0Ogmo08^;R`2CTi<0SHf=07UiN@1dM7@0PX:207YjNP1WIfL0M7Ad07inOP1`L700IfMW07AdM01b
LW80Jf][04M7A`0h>3P0C4a<05]KF`1eMGD0G5aL059BDP13@d<0@D5104a<C00n?Sh0=SHf0`0];Bd0
1@0Y:BT0;bl_04A4A01EEED0LW9b0080RHV900`0UiNG0:b/[02EUID0Jf][06MWI`1jNWX0PH6107Ui
N@1/K6`0UIFE0=KFeP3alO420>k^kP030>g]k@3^k^h0k^k^0080jn_[00<0lO7a0?Cdm03^k^h02P3^
k^h00`3/k>`0j^[Z0>g]k@090>k^kP030?;blP3clo<0k^k^00`0k^k^00<0m_Kf0??cl`3oool09P3o
ool002D0oooo00<0j>SX0=OGe`3GemL00`3GemL00`3Cdm<0emOG0=OGe`070=OGe`d0f=SH00@0emOG
0=KFeP3Fe]H0e]KF0P2QXJ401@1XJ6P0K6a/08b<S02<S8`0VYZJ0080YjNW00@0P82006a/K01/K6`0
PX:20P1YJFT01@1XJ6P0Hf=S059BDP1BDU80GUiN0080EEEE00D0C4a<05aLG01LG5`0B4Q804a<C002
04m?C`0404I6AP0f=SH0=SHf02TY:@80?3`l00D0=3@d03hn?P0n?Sh0=cLg051@D00203`l?0040492
@P1EEED0EEEE05UIF@80HV9R00D0K6a/09>CT`2CTi<0IfMW05QHF00202h^;P0405QHF01UIFD0IFEU
07AdM080`L7100D0^;Rh0;Zj^P2l_;`0_;bl0<;2`P020<K6aP030<71`@35aLD0aLG500<0b<S800D0
bLW90=7Ad@3;bl/0bl_;0<c<c0020<g=c@040<k>cP3?cll0clo?0<k>cP80e]KF00D0d=3@0=7Ad@3A
dM40dM7A0=;BdP050=?Cd`@0e=CD103EeMD50=KFeP030>SXj03oool0oooo0280oooo00<0lo?c0?Kf
mP3^k^h00P3^k^h00`3]kNd0j^[Z0>k^kP070>k^kPL0kno_1@3`l?040?7al@0;0?Ogm`3clo<0`<30
06YZJP1LG5`0LW9b092@T02RXZ80[Jf]0;Fe]@2DU9@00P1aLG40<`24Q8@0RXZ:07YjNP1iNGT0Ogmo
07IfMP1YJFT0KFe]07MgM`1`L700KFe]06i^KP1dM7@0MgMg06m_K`1fMWH0MGEe06EUI@1LG5`0EUIF
04a<C01ADE40G5aL05IFEP1=CDd0Cdm?05=CD`1=CDd0Fe]K04a<C014A4@0B4Q804m?C`1KFe/0IfMW
06i^KP20P800TI6A0:RXZ02BTY80Vi^K07moO`1@D500EUIF07=cL`22PX80R8R808J6QP3?cll0kNg]
0>k^kP020>g]k@070>k^kP3]kNd0lo?c0?3`l03Zj^X0k>c/0>o_k`030>k^kP030?7al@3clo<0k^k^
00D0k^k^00H0kNg]0>c/k03]kNd0lo?c0?3`l03]kNd60>k^kP80kno_3@3^k^h00`3fm_H0lo?c0?oo
o`0V0?ooo`009@3oool00`3Xj>P0emOG0=OGe`030=OGe`030=?Cd`3GemL0emOG00L0emOG3@3Hf=P0
103GemL0e]KF0=KFeP3Fe]H20:6QX@0506QXJ01/K6`0S8b<08b<S02JVYX00P2WYjL01020P800K6a/
06a/K022PX8206UYJ@0506QXJ01SHf<0DU9B059BDP1NGUh00P1EEED01@1<C4`0G5aL05aLG018B4P0
C4a<0080Cdm?00@0ATI603Hf=P0f=SH0:BTY0P0l?3`01@0d=3@0?Shn03hn?P0g=cL0D51@0080?3`l
00@0@T9205EEE@1EEED0FEUI0P1RHV801@1/K6`0Ti>C09>CT`1WIfL0F5QH0080;Rh^00@0F5QH06EU
I@1UIFD0M7Ad0P31`L401@2h^;P0^[Zj0;bl_02l_;`0`/;20080a/K600<0`L710<G5a@35aLD00`38
b<P01@39bLT0dM7A0<_;b`3;bl/0c<c<0080cLg=00@0c/k>0<o?c`3?cll0c/k>0P3Fe]H01@3@d=00
dM7A0=7Ad@3AdM40d];B00D0dm?C103De=@40=GEe@D0e]KF00<0j>SX0?ooo`3oool08P3oool00`3c
lo<0m_Kf0>k^kP020>k^kP030>g]k@3/k>`0k^k^00L0k^k^203_knl40?3`l0@0lO7a0P3bl_804@3X
j>P0[Jf]06ATI01XJ6P0Jf][07AdM02=SHd0UiNG0:FUY@25QHD0Hf=S079bLP21PH40P82007AdM01a
LG40JFUY0080G5aL03H0HV9R06UYJ@1VIVH0J6QX079bLP1cLg<0IfMW07QhN01oOgl0MgMg071`L01S
Hf<0De=C06IVIP1KFe/0DE5A05]KF`1UIFD0GemO05UIF@1QHF40H61P06ATI01/K6`0Ng]k08R8R020
P800QhN709jNWP2OWil0X:2P08^;R`28R8P0HV9R05]KF`1_Kfl0OGem07QhN026QXH0dm?C0>k^kP3d
m?@0lo?c0?7al@3/k>`0jn_[0??cl`3^k^h0lO7a0?3`l03[jn/0j^[Z0>k^kP3clo<20>o_k`030?3`
l03^k^h0k^k^00<0k^k^0`3]kNd02@3^k^h0l?3`0>o_k`3]kNd0k^k^0>g]k@3_knl0lo?c0>o_k`0@
0>k^kP030?KfmP3clo<0oooo02H0oooo000U0?ooo`030>SXj03GemL0emOG0140emOG1P3Hf=P30=OG
e`040=WIf@3Fe]H0e]KF0=OGe`80e]KF00D0UiNG07=cL`1_Kfl0Kfm_07UiN@0207inOP040:2PX01/
K6`0K6a/06MWI`80O7al00<0J6QX05iNGP17AdL00P17AdL204a<C005051@D01DE5@0E5AD03hn?P1=
CDd00P1LG5`01019BDT0BTY:04Y:BP1;Bd/2030`<00503Ti>@1;Bd/0Bd];051@D01?Cdl00P1JFUX0
101YJFT0NWYj07YjNP1]KFd206a/K00506UYJ@1IFET0FEUI04U9B@16ATH00P1LG5`0101MGEd0L71`
071`L02k^k/20;Fe]@040;no_`30`<00^[Zj0;Zj^P<0a<C400<0a/K60<C4a034a<@00`39bLT0103:
b/X0bl_;0<c<c03<c<`30<g=c@040<k>cP3?cll0clo?0<o?c`80d=3@103AdM40103EeMD0dm?C0=?C
d`3Cdm<40=CDe0D0eMGE1P3Fe]H00`3Xj>P0oooo0?ooo`0R0?ooo`030??cl`3fm_H0k^k^00`0k^k^
203_knl60?3`l080m?Cd03D0lO7a0?;blP3clo<0h^;R07QhN01XJ6P0IVIV06YZJP1mOGd0QHF50:2P
X02LW9`0N7Qh06EUI@1aLG40Q8B40861P@1aLG40KVi^06QXJ01DE5@0F5QH05iNGP1XJ6P0KFe]079b
LP1[Jf/0GemO07QhN025QHD0PH6107UiN@1jNWX0MWIf071`L01IFET0D51@061PH01/K6`0Jf][071`
L01^KVh0MGEe07alO029RHT0VIVI0:2PX02FUYH0Q8B408f=S@2<S8`0O7al05eMG@0206=SH`0E079b
LP1kNg/0O7al092@T034a<@0lo?c0?7al@3_knl0m?Cd0?Gem@3`l?00k>c/0?7al@3`l?00lO7a0?3`
l03]kNd0jn_[0>k^kP3alO40k^k^0080kNg]0`3^k^h80>g]k@80k^k^00D0kNg]0>k^kP3bl_80kno_
0>g]k@070>k^kPP0kNg]00<0m_Kf0??cl`3oool09P3oool002D0oooo00<0j>SX0=OGe`3GemL06P3G
emL00`3De=@0eMGE0=GEe@030=GEe@050=CDe02FUYH0HV9R069RHP21PH400P2=SHd0102CTi<0UYJF
09JFUP1YJFT207UiN@0505iNGP1UIFD0GemO05mOG`1;Bd/00P0i>CT01@0e=CD0BTY:04Y:BP0k>c/0
AdM70080HF5Q00@0FEUI08J6QP26QXH0M7Ad0P1MGEd01@1`L700KFe]06e]K@1bLW80SXj>0080QhN7
00@0QXJ606IVIP1VIVH0DU9B0P1FEUH01@19BDT0@4100410@01;Bd/0JVYZ0080FUYJ00@0H61P0;Zj
^P2j^[X0][Jf0P2o_kl01@2j^[X0_[jn0;no_`2o_kl0`L710080a<C400@0`/;20<O7a`37alL0b/[:
0P3?cll01@3:b/X0bl_;0<c<c03<c<`0cLg=00<0c/k>0P3?cll0103@d=00dM7A0=7Ad@3AdM430=;B
dP030=?Cd`3De=@0e=CD00@0e=CD103EeMD60=KFeP80emOG00<0j>SX0?ooo`3oool08P3oool00`3c
lo<0m_Kf0>k^kP0=0>k^kPP0kno_1@3`l?020?;blP0f0?7al@3`l?00kno_0??cl`2UYJD0MWIf06EU
I@1cLg<0Ph>308f=S@2GUiL0YJFU09bLW01kNg/0Jf][07moO`1jNWX0M7Ad07YjNP1fMWH0I6AT061P
H01GEeL0GemO065QH@1WIfL0IVIV05iNGP1fMWH0R8R808Z:RP2@T900ZJVY0:RXZ02:RXX0MgMg07Qh
N020P800Ph>308J6QP2BTY80WIfM0::RXP2LW9`0XJ6Q0:FUY@2CTi<0QXJ607EeM@1]KFd0JFUY05aL
G019BDT0H61P0P1nOWh02P1`L700Rh^;0<g=c@3gmoL0k^k^0?3`l03^k^h0l?3`0??cl`3alO420>g]
k@0:0?;blP3_knl0k>c/0>c/k03]kNd0k^k^0?3`l03alO40kNg]0>k^kPd0kNg]0P3^k^h00`3]kNd0
k^k^0>k^kP020>k^kPd0kNg]00<0m_Kf0??cl`3oool09P3oool002D0oooo00<0j>SX0=OGe`3GemL0
5`3GemL70=KFeP80fMWI00D0e=CD0=WIf@2l_;`0_;bl079bLP0205]KF`0408N7Q`2RXZ80XZ:R09^K
V`80Kfm_00D0MWIf06e]K@1NGUh0GUiN07YjNP0207=cL`0503<c<`0o?cl0?clo02LW9`1?Cdl00P1Z
JVX0101JFUX0EeMG05MGE`1fMWH207UiN@0508^;R`2MWId0WIfM08j>SP1XJ6P00P1SHf<0101MGEd0
DE5A055AD@1GEeL20492@P0503Ti>@1IFET0FEUI06IVIP1HF5P00P1OGel0102n_[h0/k>c0;>c/`2c
/k<20;Vi^@80^[Zj0P31`L430<;2`P030<K6aP37alL0alO700<0alO700@0b/[:0<O7a`3=cLd0cLg=
103>c/h30=3@d080dM7A0P3Bd]830=?Cd`80e=CD1`3EeMD70=KFeP80emOG00<0j>SX0?ooo`3oool0
8P3oool00`3clo<0m_Kf0>k^kP0=0>k^kPT0kno_103`l?020>k^kP0>0?3`l03_knl0kNg]0?7al@3N
g]h0ZZZZ07YjNP1aLG40OWin08>3P`2>SXh0XJ6Q0:n_[`2UYJD20820P00b075aL@1jNWX0OWin07Qh
N01lO7`0MgMg06e]K@1PH600CTi>05=CD`1LG5`0F5QH07]kN`2ATI40UIFE09nOW`2k^k/0a<C40;Zj
^P2YZJT0/K6a0;Ng]`2d];@0/K6a0:f][@2h^;P0]kNg0:^[Z`2TY:@0UIFE07EeM@1SHf<0KFe]061P
H01ADE40D51@06UYJ@25QHD0Q8B407YjNP24Q8@0`<300?Ogm`3]kNd0k>c/0?;blP3`l?00k>c/0>_[
j`3/k>`30>g]k@070>c/k03Zj^X0jn_[0>g]k@3^k^h0l_;b0?Cdm0020>c/k080kNg]00<0k^k^0>g]
k@3]kNd0703]kNd00`3fm_H0lo?c0?ooo`0V0?ooo`009@3oool00`3Xj>P0emOG0=OGe`0G0=OGe`L0
e]KF0P3IfMT01@3De=@0fMWI0;bl_02l_;`0LW9b0080Fe]K00@0QhN70::RXP2RXZ80Vi^K0P1_Kfl0
1@1fMWH0KFe]05iNGP1NGUh0NWYj0080Lg=c00D0<c<c03lo?`0o?cl09bLW04m?C`0206YZJP0405YJ
FP1GEeL0EeMG07IfMP80NGUi00D0Rh^;09fMW@2MWId0SXj>06QXJ00206=SH`0405eMG@1ADE40DE5A
05MGE`80@T9200D0>CTi05UIF@1IFET0IVIV05QHF00205mOG`040;jn_P2c/k<0/k>c0;>c/`80^KVi
0P2j^[X20<71`@<0`/;200<0a/K60<O7a`37alL00`37alL0103:b/X0alO70<g=c@3=cLd40<k>cP<0
d=3@0P3AdM420=;BdP<0dm?C0P3De=@70=GEe@L0e]KF0P3GemL00`3Xj>P0oooo0?ooo`0R0?ooo`03
0??cl`3fm_H0k^k^00h0k^k^2P3_knl50?3`l00?0>o_k`3`l?00moOg0?3`l03bl_80e=CD08Z:RP1_
Kfl0FUYJ07=cL`2LW9`0/[:b0;Bd]02][Jd0S8b<0080SHf=0`2<S8`0402MWId0Z:RX09>CT`1cLg<0
LW9b07UiN@1^KVh0Vi^K0:ZZZP2YZJT0VYZJ09jNWP2n_[h0_kno0;fm_@31`L420<W9b@0K0;no_`2a
/K40VIVI08^;R`2:RXX0Q8B407AdM01XJ6P0IfMW061PH01ADE40CTi>05mOG`1gMgL0RHV908N7Q`2B
TY80b/[:0?;blP3^k^h0k>c/0>WYj@3/k>`0k^k^0>_[j`3Xj>P0jNWY00<0kNg]0P3Zj^X30>g]k@80
k^k^00<0jn_[0>[ZjP3]kNd00`3]kNd20>k^kQ/0kNg]00<0m_Kf0??cl`3oool09P3oool002D0oooo
00<0j>SX0=OGe`3GemL0403GemL40=KFeP030=OGe`3Fe]H0e]KF00<0e]KF103EeMD20=SHf080dm?C
0P3Jf]X0102][Jd0P8200820P01^KVh208>3P`050::RXP2EUID0UIFE09ZJVP2FUYH00P2UYJD0102D
U9@0TI6A096AT@2RXZ820:n_[`050:>SX`2DU9@0TI6A096AT@22PX800P27QhL0101nOWh0N7Qh07Qh
N028R8P206ATI00507MgM`1DE5@0De=C05=CD`1EEED00P1:BTX0101@D500G5aL05aLG01]KFd2065Q
H@0506MWI`2][Jd0]KFe0;Fe]@2d];@00P2g]kL00`2i^KT0^k^k0;^k^`020;jn_P80`l?300@0`/;2
0<K6aP36a/H0a<C40P39bLT01@3;bl/0c<c<0<c<c03;bl/0bLW90080cLg=00@0bl_;0<o?c`3?cll0
e=CD0P3@d=001@3AdM40d];B0=;BdP3Bd]80dm?C0080d];B00@0eMGE0=CDe03De=@0emOG0P3De=@2
0=GEe@P0e]KF0`3GemL00`3Xj>P0oooo0?ooo`0R0?ooo`030??cl`3fm_H0k^k^00l0k^k^2`3_knl2
0?3`l080kno_01X0l?3`0?KfmP3`l?00lO7a0?Gem@3Shn<0PH6105mOG`1aLG40Q8B409FEU@2b/[80
`/;20:f][@2XZ:P0]KFe0;:b/P2d];@0alO70;fm_@2][Jd0`l?30=3@d03Lg=`0iNGU0=cLg080clo?
01/0a<C40<30`037alL0aLG50<C4a033`l<0bLW90<71`@2QXJ40T92@09nOW`26QXH0MGEe07=cL`1d
M7@0Jf][05iNGP1PH600DU9B06QXJ01jNWX0OGem07QhN01mOGd0fMWI0>g]k@3[jn/00P3bl_800`3Y
jNT0k>c/0>g]k@020>g]k@030>_[j`3YjNT0kNg]00<0kNg]0P3Zj^X01P3]kNd0k^k^0?Cdm03_knl0
jn_[0>[ZjP80kNg]00@0jNWY0>c/k03bl_80l_;b6`3]kNd00`3fm_H0lo?c0?ooo`0V0?ooo`009@3o
ool00`3Xj>P0emOG0=OGe`0=0=OGe`L0e]KF00<0emOG0=KFeP3Fe]H0103EeMD20=CDe0050=SHf03F
e]H0e]KF0=OGe`3AdM400`3Bd]820=[JfP0409:BTP1ZJVX0JVYZ07QhN080X:2P00D0WYjN0:2PX02Q
XJ40XJ6Q0:FUY@020:>SX`0509^KV`2QXJ40XJ6Q09VIV@2DU9@00P2KVi/0102@T900R8R808R8R021
PH42061PH00506a/K01WIfL0IfMW06=SH`1<C4`00P1EEED0101DE5@0KVi^06i^KP1eMGD206m_K`05
06][J`2ATI40TI6A0;2`/02i^KT00P2`/;00102g]kL0^KVi0;Vi^@30`<020;fm_@050<?3``32`/80
`L710<71`@34a<@00P36a/H00`38b<P0bLW90<W9b@030<[:bP040<_;b`3AdM40cLg=0<g=c@<0clo?
00@0d=3@0=7Ad@3AdM40emOG103Bd]820=SHf0040=KFeP3De=@0e=CD0=OGe`80fMWI00<0e=CD0=KF
eP3Fe]H00P3Fe]H20=OGe`030=KFeP3GemL0emOG00<0emOG00<0j>SX0?ooo`3oool08P3oool00`3c
lo<0m_Kf0>k^kP0@0>k^kP80kno_00<0k^k^0??cl`3clo<02P3_knl05`3fm_H0kno_0?3`l03clo<0
l_;b0=WIf@33`l<0PH6106=SH`1nOWh0W9bL0:f][@2j^[X0a<C40<o?c`3>c/h0bl_;0<o?c`3;bl/0
alO70=GEe@3Hf=P0e]KF0080gMgM0200f][J0=kNgP3IfMT0d];B0=3@d03<c<`0^KVi0:RXZ02f][H0
[Zj^09FEU@2CTi<0U9BD075aL@1_Kfl0IfMW061PH01VIVH0KVi^07EeM@23Ph<0Shn?08b<S020P800
X:2P0=;BdP3_knl0lO7a0>k^kP3]kNd0jn_[0>c/k0D0kNg]0P3/k>`00`3YjNT0k>c/0>g]k@020>c/
k080kNg]00@0kno_0>k^kP3/k>`0k>c/0P3]kNd0103/k>`0kNg]0>o_k`3_knl80>g]k@080>k^kP3c
lo<0kno_0>c/k03alO40l_;b0>c/k03YjNT;0>g]k@030?KfmP3clo<0oooo02H0oooo000U0?ooo`03
0>SXj03GemL0emOG00d0emOG1`3Fe]H00`3GemL0e]KF0=KFeP040=GEe@80e=CD00D0f=SH0=KFeP3F
e]H0emOG0=7Ad@030=;BdP80f][J00@0TY:B06YZJP1ZJVX0N7Qh0P2PX:001@2NWYh0X:2P0:6QX@2Q
XJ40YJFU0080Xj>S00D0Vi^K0:6QX@2QXJ40VIVI09BDU00209^KV`04092@T028R8P0R8R80861P@80
H61P00D0K6a/06MWI`1WIfL0Hf=S04a<C00205EEE@0405ADE01^KVh0KVi^07EeM@80Kfm_00D0Jf][
096AT@2ATI40/;2`0;Vi^@020;2`/0040;Ng]`2i^KT0^KVi0<30`080_Kfm00D0`l?30<;2`P31`L40
`L710<C4a0020<K6aP030<S8b039bLT0bLW900<0b/[:00@0bl_;0=7Ad@3=cLd0cLg=0`3?cll0103@
d=00dM7A0=7Ad@3GemL40=;BdP80f=SH00@0e]KF0=CDe03De=@0emOG0P3IfMT00`3De=@0e]KF0=KF
eP020=KFeP80emOG00<0e]KF0=OGe`3GemL00`3GemL00`3Xj>P0oooo0?ooo`0R0?ooo`030??cl`3f
m_H0k^k^01<0k^k^0P3alO470>o_k`040?7al@3dm?@0kno_0?KfmP80l_;b01D0m?Cd0?3`l03emOD0
m?Cd0<_;b`2?Shl0MGEe0861P@2CTi<0]KFe0;no_`34a<@0b<S80<[:bP3>c/h0e=CD0=KFeP3Hf=P0
eMGE0=SHf03MgMd00P3IfMT0:03Ph>00g=cL0=?Cd`3=cLd0aLG50;bl_02OWil0UYJF09ZJVP2ATI40
PH6107alO01ZJVX0MWIf06ATI01RHV80O7al08Z:RP2@T900UIFE08^;R`29RHT0WYjN0=WIf@3alO40
k^k^0>WYj@3[jn/0k>c/0>_[j`3^k^h0l_;b0>k^kP3alO40l?3`0>g]k@3/k>`0jNWY0>_[j`3/k>`5
0>g]k@80k>c/00<0l?3`0?7al@3]kNd01P3]kNd00`3^k^h0lo?c0>o_k`030>g]k@060>o_k`3clo<0
lO7a0>k^kP3/k>`0k^k^0P3alO400`3[jn/0kNg]0>g]k@090>g]k@030?KfmP3clo<0oooo02H0oooo
000U0?ooo`030>SXj03GemL0emOG00X0emOG1`3Fe]H30=GEe@030=KFeP3EeMD0eMGE00<0eMGE00@0
e=CD0=?Cd`3Cdm<0dm?C0`3Bd]830=3@d0040<_;b`3>c/h0c/k>0=GEe@80d=3@00D0R8R805mOG`1O
Gel0MGEe0:FUY@020:n_[`040:^[Z`2SXj<0Xj>S09FEU@80X:2P00D0TI6A08J6QP1dM7@0M7Ad06AT
I00206EUI@0407IfMP1TI6@0I6AT055AD@80Bd];00D0KVi^06=SH`2:RXX0RXZ:08f=S@020820P004
065QH@2NWYh0WYjN0;Zj^P80^k^k00D0^;Rh0;Vi^@2i^KT0^KVi0<;2`P020;bl_0@0_[jn00@0`l?3
0<g=c@3=cLd0b<S80P3<c<`01039bLT0b/[:0<[:bP38b<P20=7Ad@030<c<c03=cLd0c/k>0080c/k>
0P3GemL0103?cll0dM7A0=7Ad@3Cdm<20=;BdP80dm?C0`3De=@20=WIf@<0fm_K00D0d];B0=KFeP3F
e]H0e]KF0=OGe`020=KFeP030=kNgP3Fe]H0e]KF00<0emOG00<0j>SX0?ooo`3oool08P3oool00`3c
lo<0m_Kf0>k^kP0E0>k^kPL0kno_00@0l?3`0?;blP3_knl0l_;b0P3alO403`3clo<0k^k^0>g]k@3c
lo<0moOg0=OGe`2i^KT0[:b/08V9R@2=SHd0TY:B0:^[Z`31`L40bl_;0=CDe0020=SHf00V0=GEe@3A
dM40f=SH0=oOg`3Fe]H0c<c<0<O7a`2l_;`0/[:b0:n_[`2b/[80][Jf09jNWP27QhL0OGem07IfMP1e
MGD0OWin07IfMP2=SHd0RHV908b<S02LW9`0UiNG08Z:RP2EUID0[:b/0;fm_@3Cdm<0l?3`0>c/k03]
kNd0jn_[0>o_k`3`l?00kNg]0>k^kP3alO430>k^kP0>0>c/k03]kNd0k^k^0>g]k@3`l?00kno_0>c/
k03]kNd0k>c/0>[ZjP3/k>`0l?3`0>o_k`3`l?030>g]k@070?3`l03_knl0k>c/0>g]k@3^k^h0l_;b
0>k^kP030>g]k@060>k^kP3alO40kNg]0>g]k@3`l?00lO7a0P3clo<00`3Zj^X0kNg]0>g]k@040>g]
k@030?7al@3_knl0kNg]0080kNg]00<0m_Kf0??cl`3oool09P3oool002D0oooo00<0j>SX0=OGe`3G
emL02P3GemL70=KFeP80e=CD00<0g=cL0=GEe@3EeMD0103EeMD30=CDe0<0dm?C00D0d];B0=7Ad@3@
d=00d=3@0=;BdP020<k>cP040=;BdP38b<P0b<S80<o?c`80d=3@00D0^[Zj07YjNP2;Rh/0Rh^;08n?
S`0209jNWP050:RXZ02TY:@0Y:BT0:6QX@2OWil00P2;Rh/01029RHT0MGEe07EeM@1VIVH208B4Q005
09JFUP2;Rh/0Rh^;09^KV`2CTi<00P1cLg<01029RHT0][Jf0;Jf]P3>c/h20<K6aP<0_;bl00<0`<30
0;no_`2n_[h00P2n_[h20<30`0040<S8b031`L40`L710<C4a0<0aLG50`37alL0103:b/X0bl_;0<_;
b`3=cLd20<c<c0040<g=c@3EeMD0dm?C0=?Cd`<0f=SH00@0fMWI0=GEe@3EeMD0eMGE0P3Cdm<01@3D
e=@0f][J0=CDe03De=@0eMGE0080fMWI00D0g=cL0=KFeP3Fe]H0fm_K0=KFeP050=OGe`030=KFeP3G
emL0emOG00<0emOG00<0j>SX0?ooo`3oool08P3oool00`3clo<0m_Kf0>k^kP0B0>k^kP040?7al@3`
l?00k^k^0>k^kPL0kno_00X0k^k^0>o_k`3^k^h0kno_0>k^kP3_knl0l_;b0>g]k@3^k^h0m_Kf0P3g
moL01`3WinL0];Bd0:>SX`2WYjL0ZJVY0:^[Z`2i^KT00P3:b/X03@3<c<`0d];B0=7Ad@3Bd]80e]KF
0=7Ad@38b<P0^;Rh0:ZZZP2OWil0VIVI0:6QX@2OWil00P2PX:001@26QXH0NWYj09NGU`2VYZH0VIVI
0080W9bL00X0Y:BT0;Bd]02f][H0[Jf]0;no_`3UiND0l_;b0>k^kP3]kNd0l?3`0P3]kNd20?3`l080
kNg]01<0l?3`0>k^kP3Zj^X0jn_[0>c/k03^k^h0l_;b0>g]k@3_knl0k^k^0>c/k03]kNd0k>c/0>WY
j@3/k>`0lO7a0>k^kP3_knl0k^k^0080l?3`00@0mOGe0??cl`3`l?00l?3`1@3]kNd00`3_knl0l?3`
0>g]k@020>g]k@040??cl`3fm_H0mOGe0?7al@L0kNg]00<0l_;b0>o_k`3]kNd00P3]kNd00`3fm_H0
lo?c0?ooo`0V0?ooo`009@3oool00`3Xj>P0emOG0=OGe`0:0=OGe`L0e]KF0P3De=@00`3Lg=`0eMGE
0=GEe@040=GEe@<0e=CD0`3Cdm<01@3Bd]80dM7A0=3@d03@d=00d];B0080c/k>00@0d];B0<S8b038
b<P0clo?0P3@d=001@2j^[X0NWYj08^;R`2;Rh/0Shn?0080WYjN00D0Z:RX0:BTY02TY:@0XJ6Q09nO
W`0208^;R`0408V9R@1eMGD0MGEe06IVIP80Q8B400D0UYJF08^;R`2;Rh/0Vi^K09>CT`0207=cL`04
08V9R@2f][H0][Jf0<k>cP80a/K60`2l_;`00`30`<00_kno0;jn_P020;jn_P80`<3000@0b<S80<71
`@31`L40a<C40`35aLD30<O7a`040<[:bP3;bl/0bl_;0<g=c@80c<c<00@0cLg=0=GEe@3Cdm<0dm?C
0`3Hf=P0103IfMT0eMGE0=GEe@3EeMD20=?Cd`050=CDe03Jf]X0e=CD0=CDe03EeMD00P3IfMT01@3L
g=`0e]KF0=KFeP3Kfm/0e]KF00D0emOG00<0e]KF0=OGe`3GemL00`3GemL00`3Xj>P0oooo0?ooo`0R
0?ooo`030??cl`3fm_H0k^k^0140k^k^00<0kNg]0?;blP3alO40103^k^h90>o_k`090>g]k@3^k^h0
mOGe0?3`l03_knl0m?Cd0??cl`3_knl0l?3`0080lo?c02L0moOg0<c<c02YZJT0ZZZZ0:f][@2^[Zh0
^;Rh0<C4a03<c<`0d=3@0=;BdP3EeMD0emOG0<g=c@3;bl/0a<C40;Jf]P2][Jd0XJ6Q0;Bd]037alL0
][Jf0:NWY`2b/[80];Bd0;>c/`2TY:@0WIfM0:n_[`3>c/h0inOW0?KfmP3emOD0l_;b0>g]k@3[jn/0
kNg]0?;blP3^k^h00`3/k>`0103[jn/0k^k^0??cl`3]kNd40>c/k0040>_[j`3/k>`0jNWY0>_[j`80
k>c/0P3]kNd01@3/k>`0jn_[0?3`l03alO40k^k^00D0lo?c00<0l?3`0>k^kP3_knl00`3/k>`02`3`
l?00l_;b0>g]k@3]kNd0k>c/0?3`l03dm?@0l?3`0>k^kP3bl_80k>c/00X0kNg]00<0m_Kf0??cl`3o
ool09P3oool002D0oooo00<0j>SX0=OGe`3GemL02@3GemL80=KFeP80d];B00<0f=SH0=GEe@3EeMD0
0P3EeMD50=CDe0<0dm?C00@0d];B0=7Ad@3AdM40dM7A0`3?cll0103:b/X0bl_;0<_;b`3@d=020<?3
``050<S8b03<c<`0XZ:R0::RXP2LW9`00P2QXJ401@2MWId0YjNW0:NWY`2RXZ80YjNW0080XJ6Q00@0
WinO09bLW02LW9`0UiNG0P2JVYX309RHV005092@T02RXZ80/[:b0;:b/P2n_[h00P2l_;`00`35aLD0
_kno0;no_`040<;2`P<0`L7100@0`/;20<71`@31`L40`/;20P33`l<01036a/H0alO70<G5a@35aLD3
0<W9b@040<o?c`3:b/X0b/[:0<k>cP80c<c<00<0dm?C0<o?c`3AdM400P3AdM420=;BdP040=7Ad@3B
d]80d];B0=SHf080eMGE00<0e]KF0=GEe@3EeMD01@3EeMD20=KFePX0emOG00@0fMWI0=OGe`3GemL0
j>SX903oool00`3clo<0m_Kf0>k^kP0A0>k^kP030>[ZjP3]kNd0kno_00P0k^k^3@3_knl0103bl_80
moOg0?7al@3emOD20?Cdm00L0=cLg02^[Zh0[:b/0;jn_P2c/k<0][Jf0<O7a`3>c/h0d=3@0=SHf03M
gMd0i>CT0>?Sh`3Kfm/0clo?0<S8b03=cLd0b/[:0<O7a`2j^[X0Xj>S0:2PX02b/[80a<C40=OGe`3V
i^H0k>c/0>k^kP80m?Cd0P3Zj^X20>g]k@@0k>c/00H0j^[Z0>WYj@3/k>`0k>c/0>WYj@3[jn/20>c/
k0030>_[j`3Xj>P0k>c/0080k>c/0P3]kNd20>c/k0040>g]k@3YjNT0kNg]0>c/k0D0kNg]00L0jn_[
0>WYj@3^k^h0m?Cd0>c/k03[jn/0k^k^00@0kNg]00D0jNWY0>_[j`3]kNd0k>c/0>g]k@020>c/k0L0
kNg]0`3^k^h00`3fm_H0lo?c0?ooo`0V0?ooo`009@3oool00`3Xj>P0emOG0=OGe`090=OGe`L0e]KF
0`3EeMD0103Fe]H0dm?C0=GEe@3EeMD60=CDe0<0dm?C00D0d];B0=SHf03>c/h0c/k>0=3@d0020<o?
c`040<c<c039bLT0bLW90<c<c0<0a/K600@0`l?30<;2`P32`/80_kno0P31`L401@2m_Kd0^k^k0;^k
^`2h^;P0^KVi0080/;2`00@0[Jf]0:j^[P2^[Zh0]kNg0P2a/K401@2c/k<0]kNg0;Ng]`2j^[X0_;bl
0080`l?30`2o_kl00`32`/80`l?30<?3``030<?3``80`/;20P3;bl/01035aLD0bLW90<W9b@36a/H2
0<S8b080b/[:0P3AdM40103;bl/0c/k>0<k>cP3<c<`20<g=c@<0c/k>00<0d];B0=7Ad@3Bd]80103B
d]80103Cdm<0e=CD0=CDe03De=@20=?Cd`040=KFeP3Jf]X0eMGE0=GEe@<0e]KF00<0gMgM0=GEe@3E
eMD0203GemL20=KFeP<0emOG00<0j>SX0?ooo`3oool08P3oool00`3clo<0m_Kf0>k^kP0A0>k^kP03
0>g]k@3clo<0lO7a00`0k^k^1P3_knl09@3/k>`0kNg]0>o_k`3bl_80m_Kf0>g]k@3/k>`0lO7a0?Cd
m03alO40jNWY0>GUi@3WinL0i^KV0>7Qh@3Ph>00g]kN0=cLg03Ti>@0e=CD0<O7a`31`L40a<C40<c<
c03;bl/0alO70<C4a035aLD0c/k>0=WIf@3Ogml0iNGU0>WYj@3/k>`0k^k^0>g]k@3^k^h00P3dm?@0
103]kNd0kno_0??cl`3bl_850>c/k0040>[ZjP3WinL0j>SX0>_[j`H0k>c/00D0jNWY0>[ZjP3alO40
l?3`0>WYj@030>c/k0030?7al@3/k>`0k>c/00H0k>c/00@0kNg]0>k^kP3clo<0kno_0P3alO400`3/
k>`0kNg]0>c/k0050>c/k0030>g]k@3^k^h0k>c/00H0kNg]0P3bl_800`3]kNd0m_Kf0??cl`0W0?oo
o`009@3oool00`3Xj>P0emOG0=OGe`090=OGe`P0e]KF0P3EeMD00`3Fe]H0eMGE0=CDe0070=CDe0<0
dm?C00@0d];B0=7Ad@3AdM40dM7A0`3@d=00103:b/X0c<c<0<c<c035aLD20=;BdP050<O7a`36a/H0
_kno0;no_`31`L400P2l_;`01@2n_[h0a/K60<K6aP2g]kL0^k^k0080^KVi0`2h^;P0102n_[h0][Jf
0;Jf]P2g]kL20;Rh^0050;bl_02n_[h0_[jn0;jn_P2o_kl00P3;bl/01033`l<0a/K60<K6aP34a<@2
0<K6aP050<S8b03:b/X0d=3@0=3@d03?cll00P36a/H00`37alL0bLW90<W9b@020<W9b@80bl_;00@0
cLg=0<k>cP3>c/h0bLW90P3?cll00`3=cLd0dM7A0=7Ad@020=;BdP<0dm?C0P3Bd]80103IfMT0e=CD
0=CDe03EeMD30=KFeP040=gMg@3EeMD0eMGE0=KFeP80dm?C00@0eMGE0=oOg`3Ogml0fm_K103GemL5
0=SHf0040=cLg03Bd]80d];B0>SXj2@0oooo00<0lo?c0?KfmP3^k^h04`3^k^h00`3/k>`0kNg]0>k^
kP0:0>k^kP040?7al@3`l?00kNg]0>k^kP80kno_00l0kNg]0>c/k03^k^h0kNg]0>c/k03dm?@0l_;b
0?3`l03alO40l?3`0>o_k`3bl_80kno_0??cl`3dm?@00P3emOD00`3_knl0l_;b0?7al@030?3`l006
0?7al@3inOT0lo?c0?3`l03^k^h0kNg]0`3^k^h05@3`l?00lO7a0>k^kP3^k^h0l?3`0>c/k03clo<0
k^k^0>_[j`3/k>`0j^[Z0>o_k`3]kNd0l_;b0?Cdm03_knl0kNg]0>o_k`3/k>`0jn_[0>c/k0020>k^
kP0:0>c/k03_knl0k>c/0??cl`3^k^h0inOW0>WYj@3/k>`0jNWY0>[ZjPL0k>c/0P3`l?00103/k>`0
kNg]0>c/k03[jn/20>c/k0030?3`l03clo<0k>c/0080k>c/00H0j^[Z0>c/k03alO40l_;b0?7al@3/
k>`70>g]k@80lO7a00<0k>c/0??cl`3clo<09`3oool002D0oooo00<0j>SX0=OGe`3GemL02@3GemL8
0=KFeP80eMGE00<0e]KF0=GEe@3De=@01`3De=@30=?Cd`040=;BdP3AdM40dM7A0=7Ad@<0d=3@00@0
b/[:0<c<c03<c<`0aLG50P3Bd]801@37alL0a/K60;no_`2o_kl0`L710080_;bl00D0_[jn0<K6aP36
a/H0]kNg0;^k^`020;Vi^@<0^;Rh00@0_[jn0;Jf]P2f][H0]kNg0P2h^;P01@2l_;`0_[jn0;jn_P2n
_[h0_kno0080bl_;00@0`l?30<K6aP36a/H0a<C40P36a/H01@38b<P0b/[:0=3@d03@d=00clo?0080
a/K600<0alO70<W9b@39bLT00P39bLT20<_;b`040<g=c@3>c/h0c/k>0<W9b@80clo?00<0cLg=0=7A
d@3AdM400P3Bd]830=?Cd`80d];B00@0fMWI0=CDe03De=@0eMGE0`3Fe]H0103MgMd0eMGE0=GEe@3F
e]H20=?Cd`040=GEe@3Ogml0gmoO0=_Kf`@0emOG1@3Hf=P0103Lg=`0d];B0=;BdP3Xj>PT0?ooo`03
0??cl`3fm_H0kNg]0080kNg]4P3^k^h00`3`l?00lO7a0>k^kP0=0>k^kP0?0>o_k`3^k^h0k>c/0>g]
k@3alO40l_;b0?7al@3clo<0lO7a0?3`l03_knl0k^k^0>o_k`3alO40lo?c0080lO7a00H0lo?c0?Ge
m@3bl_80l?3`0?Cdm03bl_830?3`l0050?7al@3_knl0kno_0>g]k@3/k>`00P3^k^h0403]kNd0jn_[
0>_[j`3_knl0lO7a0?3`l03]kNd0lo?c0?;blP3]kNd0k>c/0>[ZjP3^k^h0k>c/0>k^kP3_knl20>g]
k@030>o_k`3[jn/0jn_[0080jn_[00X0kNg]0>o_k`3[jn/0k>c/0>o_k`3/k>`0jNWY0>[ZjP3[jn/0
j^[Z0P3/k>`00`3]kNd0j^[Z0>c/k0030>c/k080l_;b00P0k>c/0>g]k@3alO40kNg]0>c/k03[jn/0
kNg]0?3`l0<0k>c/00D0j^[Z0>_[j`3]kNd0lO7a0?Gem@040>c/k080kNg]00L0k>c/0>g]k@3`l?00
l?3`0>k^kP3hn?P0lo?c02L0oooo000U0?ooo`030>SXj03GemL0emOG00T0emOG1`3Fe]H01@3GemL0
eMGE0=GEe@3EeMD0f=SH0080e]KF00<0dm?C0=CDe03De=@0103De=@30=?Cd`<0d];B00@0d=3@0=?C
d`3Cdm<0clo?0P3@d=001@3Bd]80bl_;0<_;b`3:b/X0aLG50080a<C400@0alO70<K6aP36a/H0`L71
0P2o_kl01@35aLD0_Kfm0<?3``33`l<0_[jn0080_;bl00@0^KVi0;fm_@2m_Kd0_Kfm0P2o_kl01@30
`<00`L710<30`030`<00b<S80080`l?300@0a/K60<g=c@3=cLd0alO70P39bLT01@37alL0b/[:0<[:
bP3:b/X0alO700D0cLg=00D0bl_;0<o?c`3?cll0clo?0<g=c@020<k>cP040<o?c`3Bd]80d];B0=7A
d@80d];B00D0g=cL0<o?c`3Cdm<0dm?C0=GEe@020=;BdP040=SHf03De=@0e=CD0=_Kf`80emOG0P3E
eMD20=SHf0040=KFeP3GemL0emOG0=KFeP80e=CD00D0fm_K0=SHf03Hf=P0f=SH0=OGe`020=SHf004
0=WIf@3Fe]H0e]KF0=KFeP80g=cL00<0inOW0?ooo`3oool08P3oool00`3clo<0m_Kf0>g]k@040>g]
k@/0k^k^00X0kno_0?7al@3^k^h0k^k^0>c/k03`l?00l_;b0>g]k@3/k>`0kNg]2`3^k^h01`3]kNd0
l?3`0?3`l03^k^h0l?3`0?Cdm03bl_800`3_knl01P3^k^h0kNg]0?3`l03dm?@0mOGe0?;blP80l?3`
00<0m?Cd0?Shn03`l?000P3dm?@01@3alO40kno_0>g]k@3[jn/0k^k^0080kNg]0`3^k^h00`3]kNd0
jn_[0>_[j`020?3`l00:0>_[j`3/k>`0lO7a0?Cdm03`l?00jn_[0>WYj@3Xj>P0k^k^0>g]k@80jNWY
00/0kNg]0>o_k`3_knl0kno_0>g]k@3[jn/0kNg]0?3`l03^k^h0k>c/0>_[j`020>c/k0030>g]k@3_
knl0k>c/0080k>c/00/0kno_0>WYj@3/k>`0k>c/0>o_k`3]kNd0kno_0?7al@3^k^h0kNg]0?;blP02
0?3`l0040>c/k03Zj^X0kNg]0>o_k`<0k>c/00@0jn_[0>WYj@3[jn/0lO7a1@3/k>`00`3]kNd0kno_
0>k^kP020>g]k@030?3`l03lo?`0m?Cd02L0oooo000U0?ooo`030>SXj03GemL0emOG00/0emOG1@3F
e]H01@3Hf=P0eMGE0=GEe@3EeMD0e=CD0080f][J00<0d];B0=GEe@3EeMD0103De=@30=?Cd`<0d];B
00@0d=3@0=CDe03De=@0d=3@0P3?cll01@3<c<`0cLg=0<g=c@3<c<`0b/[:0080`l?300@0bl_;0<C4
a034a<@0bLW90P30`<001@36a/H0`l?30<71`@31`L40a<C400<0`L710P37alL01030`<00`l?30<?3
``33`l<30<C4a0040<G5a@3<c<`0c<c<0<O7a`80b/[:00D0bLW90<[:bP3:b/X0b/[:0<o?c`020<c<
c0040<g=c@3;bl/0bl_;0=3@d080cLg=00D0c/k>0<c<c03Bd]80d];B0<o?c`020<k>cP040=CDe03A
dM40dM7A0=GEe@80d];B00D0g=cL0=?Cd`3Bd]80d];B0=OGe`020=?Cd`040=GEe@3Fe]H0e]KF0=CD
e080f=SH00@0emOG0=KFeP3Jf]X0f][J0`3Fe]H00`3EeMD0f=SH0=SHf0020=OGe`<0f=SH0P3EeMD0
103Ogml0e]KF0=KFeP3GemL20=KFeP030>SXj03oool0oooo0280oooo00<0lo?c0?KfmP3]kNd01@3]
kNd90>k^kP050>g]k@3_knl0m?Cd0>o_k`3^k^h00P3[jn/0103_knl0k^k^0>[ZjP3]kNd:0>k^kP04
0>g]k@3Zj^X0l_;b0?7al@80k^k^00<0kNg]0>_[j`3^k^h00`3_knl20>g]k@070?KfmP3^k^h0kno_
0?;blP3`l?00lO7a0?KfmP020>o_k`80lo?c00@0k^k^0>g]k@3_knl0l?3`0P3/k>`20>k^kP80kNg]
00D0k^k^0>g]k@3/k>`0kNg]0>k^kP020>c/k0070?7al@3_knl0jn_[0>OWi`3[jn/0lO7a0>g]k@02
0>_[j`80jNWY00P0lO7a0?;blP3]kNd0jn_[0>WYj@3Zj^X0lO7a0>c/k080jn_[00@0k>c/0?3`l03a
lO40k^k^0P3/k>`02@3alO40k>c/0>_[j`3[jn/0lO7a0>k^kP3[jn/0kno_0?7al@020>c/k00;0?;b
lP3clo<0kno_0>c/k03^k^h0l_;b0>c/k03[jn/0k>c/0>[ZjP3YjNT01P3/k>`0103[jn/0k>c/0?Cd
m03`l?020>g]k@030>k^kP3fm_H0lo?c02L0oooo000U0?ooo`030>SXj03GemL0emOG00/0emOG1@3F
e]H01@3Hf=P0eMGE0=GEe@3EeMD0e=CD0080f][J00<0d];B0=GEe@3EeMD0103De=@30=?Cd`<0d];B
00@0d=3@0=CDe03De=@0d=3@0P3?cll01@3<c<`0cLg=0<g=c@3<c<`0b/[:0080`l?300@0bl_;0<C4
a034a<@0bLW90P30`<001@36a/H0`l?30<71`@31`L40a<C400<0`L710P37alL01030`<00`l?30<?3
``33`l<30<C4a0040<G5a@3<c<`0c<c<0<O7a`80b/[:00D0bLW90<[:bP3:b/X0b/[:0<o?c`020<c<
c0040<g=c@3;bl/0bl_;0=3@d080cLg=00D0c/k>0<c<c03Bd]80d];B0<o?c`020<k>cP040=CDe03A
dM40dM7A0=GEe@80d];B00D0g=cL0=?Cd`3Bd]80d];B0=OGe`020=?Cd`040=GEe@3Fe]H0e]KF0=CD
e080f=SH00@0emOG0=KFeP3Jf]X0f][J0`3Fe]H00`3EeMD0f=SH0=SHf0020=OGe`<0f=SH0P3EeMD0
103Ogml0e]KF0=KFeP3GemL20=KFeP030>SXj03oool0oooo0280oooo00<0lo?c0?KfmP3]kNd01P3]
kNd?0>k^kP030?3`l03dm?@0kNg]0080kNg]503^k^h02@3_knl0kNg]0>_[j`3_knl0l?3`0>o_k`3e
mOD0l_;b0>c/k0020?7al@<0kno_00D0lO7a0?Gem@3_knl0m?Cd0?7al@050>k^kP060>g]k@3Zj^X0
j^[Z0?3`l03clo<0kNg]1@3/k>`20>_[j`030>c/k03[jn/0jn_[00<0jn_[00<0j>SX0>[ZjP3/k>`0
1@3/k>`0303Xj>P0k^k^0>o_k`3Zj^X0lo?c0>k^kP3/k>`0lO7a0>c/k03[jn/0j>SX0>_[j`80k>c/
0`3]kNd20>c/k0030>g]k@3/k>`0k>c/00<0k>c/00<0j>SX0>[ZjP3]kNd01`3/k>`0103[jn/0jNWY
0?;blP3_knl30>g]k@030?KfmP3clo<0oooo02H0oooo000U0?ooo`030>SXj03Fe]H0e]KF00@0e]KF
3`3GemL01@3Hf=P0fMWI0=GEe@3EeMD0e=CD00<0eMGE1@3De=@20=?Cd`80dM7A00<0d=3@0=7Ad@3A
dM400`3AdM401@3@d=00clo?0<o?c`3>c/h0cLg=0080alO700@0a/K60<W9b@39bLT0b<S80P37alL0
0`35aLD0c/k>0<K6aP040<K6aP030<?3``35aLD0aLG500<0aLG500D0c/k>0<K6aP33`l<0`l?30<O7
a`020<W9b@040<o?c`38b<P0b<S80=;BdP80c<c<00D0d];B0<k>cP3GemL0emOG0=3@d0020=;BdP@0
d=3@00<0e]KF0=7Ad@3AdM400`3AdM40103Cdm<0cLg=0<g=c@3Fe]H20=OGe`80e]KF0P3IfMT30=GE
e@<0f][J00D0e]KF0=OGe`3GemL0fMWI0=KFeP030=OGe`80e]KF00D0gmoO0=OGe`3GemL0fm_K0=WI
f@060=SHf0<0emOG0P3Bd]800`3Shn<0oooo0?ooo`0R0?ooo`030??cl`3fm_H0kNg]00L0kNg]2@3^
k^h00`3]kNd0k^k^0>g]k@020?;blP<0k^k^0`3]kNd70>k^kP040>g]k@3Zj^X0kNg]0>k^kP80kNg]
1`3^k^h01@3]kNd0jNWY0>_[j`3^k^h0kno_0080l?3`0P3]kNd01`3gmoL0lO7a0>k^kP3bl_80lo?c
0>c/k03^k^h00P3_knl20>k^kP090?3`l03dm?@0k^k^0>[ZjP3Xj>P0j^[Z0>g]k@3`l?00lo?c0080
j^[Z00H0l?3`0>o_k`3alO40jn_[0>[ZjP3`l?020>k^kP040?7al@3[jn/0jn_[0>[ZjP80jn_[00<0
kno_0?7al@3[jn/00`3[jn/02@3/k>`0jn_[0>SXj03^k^h0lo?c0>k^kP3/k>`0kno_0?;blP020>_[
j`0:0>c/k03alO40l?3`0>k^kP3bl_80kNg]0>_[j`3alO40kNg]0>WYj@<0k>c/0P3[jn/01@3`l?00
lO7a0>c/k03]kNd0k^k^00@0k>c/00<0jn_[0>g]k@3]kNd00P3]kNd00`3/k>`0lO7a0>o_k`0W0?oo
o`009@3oool00`3Xj>P0e]KF0=KFeP040=KFePl0emOG00D0e]KF0=GEe@3MgMd0gMgM0=CDe0060=GE
e@<0e=CD00@0d];B0=CDe03De=@0fMWI0`3Bd]820<o?c`040<k>cP3Bd]80d];B0=3@d0<0clo?00<0
c/k>0=3@d03@d=000`3;bl/01@3:b/X0b<S80<W9b@39bLT0aLG50080cLg=00<0b<S80<O7a`37alL0
1039bLT0103:b/X0c<c<0<c<c03;bl/20<S8b0040<k>cP3AdM40dM7A0=CDe080cLg=00D0clo?0<g=
c@3Hf=P0f=SH0<k>cP020=CDe0<0dM7A00D0clo?0=7Ad@3Cdm<0dm?C0=;BdP030=?Cd`80eMGE00<0
emOG0<o?c`3?cll00P3EeMD20=;BdP@0eMGE0P3Jf]X40=KFeP<0emOG00@0fMWI0=[JfP3Jf]X0e]KF
103GemL60=SHf080emOG00@0dm?C0=cLg03Lg=`0inOW903oool00`3clo<0m_Kf0>g]k@080>g]k@/0
k^k^0`3_knl00`3bl_80kNg]0>g]k@030>g]k@H0k^k^0P3]kNd00`3clo<0kno_0>g]k@020>_[j`04
0>c/k03Zj^X0kNg]0>g]k@80k^k^00L0kNg]0>c/k03]kNd0lo?c0?7al@3^k^h0kno_0080k^k^00H0
lO7a0?3`l03/k>`0l?3`0?Cdm03/k>`50>k^kP0;0>o_k`3`l?00k^k^0>c/k03[jn/0kNg]0>_[j`3Z
j^X0kno_0?7al@3]kNd00P3alO40103]kNd0jn_[0>SXj03`l?020>g]k@040?;blP3[jn/0jn_[0>c/
k080jNWY00@0kNg]0>k^kP3[jn/0jn_[0`3/k>`02`3[jn/0k>c/0?7al@3/k>`0jNWY0>c/k03]kNd0
k^k^0>WYj@3[jn/0k>c/0080k^k^00L0l?3`0?Cdm03]kNd0k>c/0>k^kP3]kNd0jn_[00<0k>c/00@0
lO7a0>k^kP3]kNd0k^k^0P3/k>`00`3]kNd0k>c/0>c/k0050>c/k080j^[Z00<0kno_0?[jnP3bl_80
9`3oool002D0oooo00<0j>SX0=KFeP3Fe]H0103Fe]H?0=OGe`050=KFeP3EeMD0gMgM0=gMg@3De=@0
1P3EeMD30=CDe0040=;BdP3De=@0e=CD0=WIf@<0d];B0P3?cll0103>c/h0d];B0=;BdP3@d=030<o?
c`030<k>cP3@d=00d=3@00<0bl_;00D0b/[:0<S8b039bLT0bLW90<G5a@020<g=c@030<S8b037alL0
alO700@0bLW900@0b/[:0<c<c03<c<`0bl_;0P38b<P0103>c/h0dM7A0=7Ad@3De=@20<g=c@050<o?
c`3=cLd0f=SH0=SHf03>c/h00P3De=@30=7Ad@050<o?c`3AdM40dm?C0=?Cd`3Bd]800`3Cdm<20=GE
e@030=OGe`3?cll0clo?0080eMGE0P3Bd]840=GEe@80f][J103Fe]H30=OGe`040=WIf@3Jf]X0f][J
0=KFeP@0emOG1P3Hf=P20=OGe`040=?Cd`3Lg=`0g=cL0>OWib@0oooo00<0lo?c0?Gem@3]kNd0203]
kNd;0>k^kP80kNg]0P3_knl00`3Zj^X0k>c/0>g]k@030>g]k@<0k^k^00D0k>c/0>k^kP3bl_80k^k^
0?7al@030>c/k0040>[ZjP3YjNT0j>SX0>c/k080kNg]00H0l?3`0??cl`3alO40k^k^0?7al@3_knl2
0>c/k0<0k^k^00T0jn_[0>[ZjP3^k^h0l_;b0??cl`3^k^h0jn_[0?3`l03alO400P3^k^h30>g]k@0:
0?7al@3`l?00k^k^0>o_k`3/k>`0kNg]0?3`l03alO40k>c/0>[ZjP80j>SX00P0kNg]0>o_k`3_knl0
k^k^0>_[j`3YjNT0jn_[0>[ZjP80kNg]0100j^[Z0?3`l03/k>`0j>SX0>[ZjP3YjNT0jn_[0?7al@3`
l?00kno_0>_[j`3/k>`0jn_[0>SXj03Zj^X0k>c/0P3]kNd0103/k>`0k^k^0?3`l03]kNd70>c/k004
0>o_k`3^k^h0j^[Z0>[ZjPH0k>c/00@0jn_[0>c/k03/k>`0k>c/0P3[jn/00`3^k^h0nOWi0??cl`0W
0?ooo`009@3oool00`3WinL0e]KF0=KFeP040=KFeQ40emOG0P3Fe]H0103Cdm<0e]KF0=KFeP3Fe]H5
0=GEe@050=CDe03AdM40f=SH0=SHf03Cdm<00P3De=@0103Cdm<0e=CD0=CDe03>c/h20=OGe`040=CD
e03Bd]80fMWI0=WIf@<0clo?00<0c<c<0<k>cP3>c/h0103=cLd0103?cll0cLg=0<g=c@3=cLd20<S8
b0050=?Cd`3<c<`0c<c<0<g=c@3>c/h00P3?cll0103Bd]80e=CD0=CDe03>c/h20=7Ad@050=3@d03A
dM40dM7A0=?Cd`3EeMD00P3AdM40103Fe]H0d];B0=;BdP3>c/h20=?Cd`040=OGe`3Bd]80f=SH0=SH
f0<0e]KF00@0eMGE0=WIf@3IfMT0e]KF0P3GemL20=KFeP80emOG103Fe]H20=CDe0<0e]KF103GemL0
103IfMT0emOG0=OGe`3De=@20=OGe`040=WIf@3GemL0emOG0=OGe`<0f=SH00@0fm_K0=KFeP3Fe]H0
f=SH0P3Fe]H00`3WinL0oooo0?ooo`0R0?ooo`030?;blP3emOD0k>c/00P0kNg]2@3^k^h00`3]kNd0
k^k^0>g]k@020>g]k@030>c/k03Zj^X0k>c/00@0kNg]0`3^k^h00`3/k>`0k^k^0?;blP020>g]k@04
0>k^kP3]kNd0kno_0>k^kP80j>SX00H0kno_0?7al@3^k^h0kNg]0?;blP3dm?@20>g]k@030>k^kP3/
k>`0k>c/00@0k^k^0P3`l?00103^k^h0l_;b0>k^kP3[jn/20??cl`80kNg]00@0k^k^0>g]k@3]kNd0
l?3`0P3bl_802P3alO40kNg]0>WYj@3_knl0k^k^0>_[j`3^k^h0k>c/0>k^kP3/k>`20>k^kP80jn_[
00H0inOW0>[ZjP3_knl0lO7a0>g]k@3Zj^X20?3`l00<0>g]k@3^k^h0k^k^0>k^kP3_knl0k>c/0?3`
l03^k^h0k>c/0>g]k@3^k^h0l?3`103]kNd00`3/k>`0jn_[0>g]k@030>g]k@80k>c/00P0kNg]0?3`
l03]kNd0k>c/0>_[j`3Zj^X0kNg]0>o_k`<0k>c/00X0kNg]0>o_k`3/k>`0kno_0>g]k@3/k>`0k^k^
0>o_k`3clo<0l_;b9`3oool002D0oooo00<0iNGU0=GEe@3EeMD0103Fe]H=0=OGe`80g]kN00D0f=SH
0=[JfP3GemL0emOG0=?Cd`030=GEe@<0e]KF0P3EeMD00`3Jf]X0e=CD0=CDe0020=CDe080emOG0`3C
dm<00`3@d=00emOG0=OGe`020=?Cd`80eMGE103Bd]820<g=c@040=7Ad@3@d=00d];B0=;BdP<0dM7A
00@0d=3@0<o?c`3?cll0dM7A0P3De=@01@3=cLd0dM7A0=OGe`3GemL0e=CD0080dM7A103Bd]830=CD
e0040=GEe@3Bd]80d];B0=WIf@80e=CD00D0dm?C0=CDe03De=@0e=CD0=?Cd`020=CDe0<0e]KF00@0
emOG0=cLg03Lg=`0emOG0P3Hf=P0103GemL0dm?C0=_Kf`3Kfm/30=OGe`<0f=SH1@3GemL20=KFeP04
0=SHf03Fe]H0e]KF0=?Cd`80emOG00<0f=SH0=OGe`3GemL00P3GemL20=SHf0040=WIf@3Fe]H0e]KF
0=KFeP80eMGE00<0iNGU0?ooo`3oool08P3oool0103alO40m?Cd0>c/k03/k>`70>g]k@L0k^k^00<0
kNg]0>k^kP3`l?000`3_knl01P3]kNd0k>c/0>_[j`3/k>`0jn_[0>c/k080kNg]0`3^k^h00`3`l?00
k^k^0>g]k@020>g]k@0<0?;blP3_knl0k^k^0>o_k`3Zj^X0j>SX0?3`l03alO40kNg]0>WYj@3/k>`0
lO7a1@3]kNd02P3/k>`0kNg]0>g]k@3alO40lo?c0?3`l03]kNd0kno_0>k^kP3]kNd20?7al@80kno_
0P3/k>`0103_knl0l?3`0?;blP3alO430>g]k@80k>c/00@0k^k^0?3`l03alO40l?3`0P3/k>`0203]
kNd0jn_[0>_[j`3YjNT0jn_[0?3`l03^k^h0j^[Z0P3/k>`40?7al@0:0?3`l03]kNd0k>c/0>k^kP3]
kNd0jn_[0>g]k@3clo<0mOGe0>k^kP80kNg]0P3_knl00`3[jn/0kNg]0>g]k@020>g]k@<0k>c/00<0
lO7a0>c/k03[jn/00P3[jn/03`3]kNd0lO7a0>_[j`3/k>`0jn_[0>k^kP3alO40k>c/0?7al@3^k^h0
jn_[0>k^kP3_knl0lo?c0?7al@0W0?ooo`009@3oool00`3UiND0eMGE0=GEe@040=KFePd0emOG0P3N
g]h01@3Hf=P0f][J0=OGe`3GemL0dm?C00<0eMGE0`3Fe]H20=GEe@030=[JfP3De=@0e=CD0080e=CD
0P3GemL30=?Cd`030=3@d03GemL0emOG0080dm?C0P3EeMD40=;BdP80cLg=00@0dM7A0=3@d03Bd]80
d];B0`3AdM40103@d=00clo?0<o?c`3AdM420=CDe0050<g=c@3AdM40emOG0=OGe`3De=@00P3AdM44
0=;BdP<0e=CD00@0eMGE0=;BdP3Bd]80fMWI0P3De=@01@3Cdm<0e=CD0=CDe03De=@0dm?C0080e=CD
0`3Fe]H0103GemL0g=cL0=cLg03GemL20=SHf0040=OGe`3Cdm<0fm_K0=_Kf`<0emOG0`3Hf=P50=OG
e`80e]KF00@0f=SH0=KFeP3Fe]H0dm?C0P3GemL00`3Hf=P0emOG0=OGe`020=OGe`80f=SH00@0fMWI
0=KFeP3Fe]H0e]KF0P3EeMD00`3UiND0oooo0?ooo`0R0?ooo`030?KfmP3kno/0m?Cd0080mOGe3P3f
m_H00`3gmoL0o_kn0?Win@020?_kn`060?KfmP3dm?@0l?3`0?Cdm03bl_80lo?c1@3fm_H00`3kno/0
m_Kf0?KfmP020?KfmP090?Cdm03emOD0l_;b0?7al@3clo<0l?3`0??cl`3`l?00l_;b0080m_Kf0`3e
mOD20?KfmP040??cl`3bl_80m_Kf0?Gem@<0m?Cd00<0nOWi0?knoP3fm_H00`3emOD0203jn_X0no_k
0?7al@3fm_H0oOgm0?ooo`3jn_X0mOGe0P3fm_H30?Gem@050?Cdm03bl_80l_;b0?;blP3dm?@00P3j
n_X40?Gem@030?Cdm03alO40l_;b0080mOGe0`3clo<0403bl_80moOg0?clo03fm_H0oOgm0?Shn03b
l_80lO7a0?KfmP3lo?`0moOg0?Gem@3fm_H0n_[j0?gmo@3gmoL30?KfmP@0mOGe00D0m?Cd0?3`l03c
lo<0l_;b0?7al@020?Cdm0050?Gem@3dm?@0mOGe0?Cdm03clo<0103dm?@0103clo<0l_;b0?[jnP3f
m_HW0?ooo`009@3oool0103`l?00iNGU0>GUi@3WinL@0>SXj080lO7a00D0inOW0>g]k@3Zj^X0j^[Z
0>WYj@060>SXj0L0inOW0P3Rh^840>SXj080jNWY00@0jn_[0>[ZjP3`l?00l?3`1P3Vi^H20>GUi@<0
i^KV0P3]kNd0103Vi^H0iNGU0>GUi@3Ti>@20>;RhP050>CTi03^k^h0jNWY0>WYj@3UiND01P3Vi^H4
0>OWi`<0kno_0P3[jn/30>OWi`80j>SX0P3WinL40>SXj080lO7a00<0l?3`0>_[j`3[jn/00P3YjNT2
0>SXj0030>OWi`3Xj>P0j>SX00<0inOW1@3Xj>P20?7al@<0inOW00D0i>CT0>WYj@3YjNT0kNg]0>_[
j`020>SXj0040>k^kP3Vi^H0i^KV0>WYj@80j>SX00@0inOW0>KViP3Vi^H0l?3`903oool0103clo<0
m_Kf0?7al@3bl_8?0??cl`060?Cdm03jn_X0mOGe0??cl`3gmoL0n?Sh1@3bl_850??cl`030?Cdm03c
lo<0lo?c0080lo?c00<0kno_0?7al@3bl_80103bl_801@3alO40m_Kf0?KfmP3dm?@0n?Sh0080l_;b
1P3clo<20?;blP060?Gem@3jn_X0nOWi0??cl`3bl_80lo?c0P3alO420??cl`030?Win@3kno/0m_Kf
00H0lo?c0P3bl_830?7al@040?KfmP3inOT0n_[j0?Ogm`T0l_;b0`3alO401@3dm?@0n_[j0?Win@3j
n_X0m?Cd00<0l_;b103clo<20?Cdm0D0lo?c00`0l_;b0?Cdm03inOT0l_;b0>k^kP3alO40l?3`0>o_
k`3bl_80lo?c0?Cdm03alO420?KfmP030>k^kP3bl_80l_;b00<0l_;b00<0lO7a0?KfmP3clo<09`3o
ool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3o
ool00?l0ooooT@3oool005/0oooo0T00000c0?ooo`900000O@3oool2@00003<0oooo0T00001:0?oo
o`00G03oool00d000000oooo0?ooo`0c0?ooo`03@000003oool0oooo07/0oooo00=000000?ooo`3o
ool0<`3oool00d000000oooo0?ooo`170?ooo`00?@3oool5@0000080oooo00=000000?ooo`3oool0
0P3oool00d000000oooo0?ooo`090?ooo`A000000`3oool00d000000oooo0?ooo`080?ooo`E00000
0P3oool00d000000oooo0?ooo`020?ooo`03@000003oool0oooo00X0oooo0d0000001`3ooom00000
0?oood000000oooo@000003oool0140000020?ooo`=000000P3oool2@00005X0oooo1D0000020?oo
o`03@000003oool0oooo0080oooo00=000000?ooo`3oool02@3oool4@00000<0oooo00=000000?oo
o`3oool0203oool5@0000080oooo00=000000?ooo`3oool00P3oool00d000000oooo0?ooo`0:0?oo
o`=0000000L0oooo@000003ooom000000?oood000000oooo00A000000P3oool3@0000080oooo0T00
00150?ooo`00?`3oool01d000000oooo0?ooo`3ooom000000?oood0000000P3oool00d000000oooo
@000000;0?ooo`08@000003oool0oooo@000003ooom000000?oood00000;0?ooo`07@000003oool0
oooo0?oood000000oooo@00000020?ooo`03@000003ooom0000000`0oooo00U000000?ooo`3ooom0
00000?oood000000oooo@000003oool00d0000020?ooo`06@000003oool0oooo@000003ooom00000
GP3oool01d000000oooo0?ooo`3ooom000000?oood0000000P3oool00d000000oooo@000000;0?oo
o`08@000003oool0oooo@000003ooom000000?oood00000;0?ooo`07@000003oool0oooo0?oood00
0000oooo@00000020?ooo`03@000003ooom0000000`0oooo00U000000?ooo`3ooom000000?oood00
0000oooo@000003oool00d0000020?ooo`06@000003oool0oooo@000003ooom00000A`3oool003l0
oooo00M000000?ooo`3oool0oooo@000003ooom000000080oooo00=000000?oood0000002`3oool0
24000000oooo0?oood000000oooo@000003ooom000002`3oool01d000000oooo0?ooo`3ooom00000
0?oood0000000P3oool00d000000oooo@000000<0?ooo`08@000003oool0oooo@000003ooom00000
0?oood0000030?ooo`04@000003oool0oooo@0000080oooo00=000000?oood0000000T00001L0?oo
o`03@000003oool0oooo00<0oooo00I000000?ooo`3ooom000000?oood00000;0?ooo`08@000003o
ool0oooo@000003ooom000000?oood00000;0?ooo`03@000003oool0oooo00<0oooo00I000000?oo
o`3ooom000000?oood00000<0?ooo`08@000003oool0oooo@000003ooom000000?oood0000030?oo
o`04@000003oool0oooo@0000080oooo00=000000?oood0000000T0000150?ooo`00?`3oool01d00
0000oooo0?ooo`3ooom000000?oood0000000P3oool00d000000oooo@000000;0?ooo`=0000000@0
oooo@00004000000oooo0T00000:0?ooo`07@000003oool0oooo0?oood000000oooo@00000020?oo
o`03@000003ooom0000000/0oooo0T0000020?ooo`90000000<0oooo@000003oool00P3oool2@000
00<0oooo0d000000103ooom00000@0000400001L0?ooo`04@000003oool0oooo0?ooo`9000000`3o
ool00d000000oooo@000000;0?ooo`=0000000@0oooo@00004000000oooo0T00000:0?ooo`04@000
003oool0oooo0?ooo`9000000`3oool00d000000oooo@000000;0?ooo`9000000P3oool2@0000003
0?oood000000oooo0080oooo0T0000030?ooo`=0000000@0oooo@000040000100000A@3oool003l0
oooo00M000000?ooo`3oool0oooo@000003ooom000000080oooo00=000000?oood0000002`3oool0
0d000000oooo0?ooo`0@0?ooo`07@000003oool0oooo0?oood000000oooo@00000020?ooo`03@000
003ooom0000007h0oooo00E000000?ooo`3oool0oooo@00000040?ooo`03@000003ooom0000000/0
oooo00=000000?ooo`3oool0403oool01D000000oooo0?ooo`3ooom0000000@0oooo00=000000?oo
od000000I`3oool003h0oooo0T0000040?ooo`03@000003oool0oooo0080oooo00=000000?ooo`3o
ool02@3oool2@0000140oooo0T0000040?ooo`03@000003oool0oooo0080oooo00=000000?ooo`3o
ool02`3oool00d000000oooo0?ooo`1^0?ooo`9000000`3oool3@00000<0oooo00=000000?ooo`3o
ool02@3oool2@0000140oooo0T0000030?ooo`=000000`3oool00d000000oooo0?ooo`0;0?ooo`03
@000003oool0oooo05P0oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oo
oi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oo
oi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oo
oi40oooo001T0?ooo`900000F03oool2@00006<0oooo0T00001[0?ooo`00IP3oool00d000000oooo
0?ooo`1G0?ooo`03@000003oool0oooo0680oooo00=000000?ooo`3oool0J03oool005P0oooo0d00
00030?ooo`=000000`3oool3@00000D0oooo00A000000?ooo`3oool0oooo0T0000060?ooo`03@000
003oool0oooo00L0oooo1D0000020?ooo`9000000P3oool00d000000oooo@000000;0?ooo`I00000
0P3oool00d000000oooo0?ooo`03@00000T0oooo0d0000000`3ooom000000?ooo`03@00000<0oooo
1T0000000`3ooom000000?ooo`0:0?ooo`=000000`3oool2@0000080oooo0T0000040?ooo`900000
0P3oool3@00000<0oooo0d0000020?ooo`9000000P3oool3@00000<0oooo0T0000000`3ooom00000
@00000020?ooo`03@000003oool0oooo00l0oooo0d0000001`3ooom000000?oood000000oooo@000
003oool0140000020?ooo`=000000P3oool2@0000080oooo0T00001R0?ooo`00F@3oool00d000000
oooo0?ooo`030?ooo`05@000003oool0oooo0?oood0000000P3oool00d000000oooo0?ooo`090?oo
o`03@000003oool0oooo00h0oooo00I000000?ooo`3ooom000000?oood0000020?ooo`90000000@0
oooo@000003ooom000002P3oool3@0000080oooo00I000000?ooo`3ooom000000?oood0000020?oo
o`03@000003oool0oooo00P0oooo00A000000?ooo`3ooom000000P3oool01D000000oooo0?ooo`3o
oom000000080oooo00=000000?oood0000000P3oool00d000000oooo0?ooo`0:0?ooo`05@000003o
ool0oooo0?oood0000001P3oool014000000oooo0?oood0000020?ooo`04@000003oool0oooo@000
00<0oooo00I000000?ooo`3ooom000000?oood0000020?ooo`04@000003oool0oooo@00000<0oooo
00I000000?ooo`3ooom000000?oood0000020?ooo`03@000003oool0oooo0100oooo00U000000?oo
o`3ooom000000?oood000000oooo@000003oool00d0000020?ooo`06@000003oool0oooo@000003o
oom000001P3oool00d000000oooo0?ooo`1O0?ooo`00F@3oool00d000000oooo0?ooo`030?ooo`05
@000003oool0oooo0?oood0000000P3oool00d000000oooo0?ooo`080?ooo`900000403oool00d00
0000oooo0?ooo`020?ooo`03@000003oool0oooo0090000000@0oooo@000003ooom00000303oool0
14000000oooo0?oood0000020?ooo`03@000003ooom000000080oooo00=000000?ooo`3oool0203o
ool014000000oooo0?oood0000020?ooo`05@000003oool0oooo0?oood0000000P3oool00d000000
oooo@00000020?ooo`03@000003oool0oooo00X0oooo00A000000?ooo`3oool0oooo0d0000030?oo
o`05@000003oool0oooo0?oood0000000P3oool014000000oooo0?oood0000030?ooo`06@000003o
ool0oooo@000003ooom000001@3oool01D000000oooo0?ooo`3ooom000000080oooo00=000000?oo
od0000000P3oool00d000000oooo0?ooo`0@0?ooo`08@000003oool0oooo@000003ooom000000?oo
od0000030?ooo`04@000003oool0oooo@0000080oooo00=000000?oood0000000T0000030?ooo`03
@000003oool0oooo0600oooo001I0?ooo`9000000`3oool2@00000@0oooo0d0000090?ooo`03@000
003ooom000000100oooo00=000000?ooo`3oool00`3oool2@00000040?oood00001000000?ooo`90
00002`3oool2@00000030?oood0000100000009000000`3oool3@00000X0oooo0d0000020?ooo`90
0000103oool3@00000040?oood0000100000@00000`0oooo14000000103ooom00000@00004000003
0?ooo`9000000`3oool2@00000<0oooo00=000000?ooo`3oool00T0000000`3ooom00000@0000004
@0000080oooo0T0000040?ooo`90000000<0oooo@000040000000T00000B0?ooo`9000000P3oool2
@00000030?oood000000oooo0080oooo0T0000030?ooo`=0000000@0oooo@0000400001000000`3o
ool2@0000640oooo001I0?ooo`04@000003oool0oooo@00001<0oooo00=000000?oood000000403o
ool00d000000oooo0?ooo`0R0?ooo`03@000003oool0oooo00P0oooo00=000000?ooo`3oool0303o
ool00d000000oooo0?ooo`0Q0?ooo`03@000003oool0oooo00H0oooo00=000000?ooo`3oool0WP3o
ool005P0oooo1D0000020?ooo`03@000003oool0oooo00l0oooo0T00000?0?ooo`=000008P3oool2
@00000T0oooo0T0000050?ooo`03@000003oool0oooo00D0oooo0T00000R0?ooo`9000003P3oool0
0d000000oooo0?ooo`0L0?ooo`03@000003oool0oooo07T0oooo003o0?oooi40oooo003o0?oooi40
oooo0000\
\>"],
  ImageRangeCache->{{{0, 399}, {189.438, 0}} -> {-0.157534, -0.0238147, 
  0.00580218, 0.00580218}, {{27.125, 191.25}, {185.313, 
  21.1875}} -> {-25.8602, -4.86646, 0.69477, 0.69477}, {{207.688, 371.813}, {
  185.313, 21.1875}} -> {-226.964, -7.29968, 1.04215, 1.04215}}]
}, Open  ]],

Cell[TextData[{
  StyleBox["\t",
    FontFamily->"Times New Roman",
    FontSize->10.5],
  StyleBox[
  "Because of the discretization error, the low-resolution image on the left \
in Fig. 8 includes a little bits of noise. However, observation of the images \
in Fig.8 suggests that the image governing equation makes it possible to \
reproduce the images having any resolutions.",
    TextAlignment->Left,
    TextJustification->1]
}], "Text",
  TextAlignment->Left,
  TextJustification->1,
  FontFamily->"Times New Roman"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["2.9 Illusive image generation",
  FontFamily->"Times New Roman"]], "Section"],

Cell[TextData[{
  StyleBox["\t",
    FontFamily->"Times New Roman",
    FontSize->10.5],
  StyleBox[
  "Comparison the source density image in Fig.7 with the shadowed relief \
images in Fig.5 reveals that the angled lighting images are very similar to \
those of source density. This is because an inner product operation between \
the vectors changes the vectors into the scalar quantities. \n\tLet us try to \
solve a Poisson's equation for the inner product images in Fig.5 as the \
source densities, and then we draw the images from the obtained solutions.",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell["\<\
illusion=Table[poissonSOR2D[-angle[[i]],{128,128}],
\t{i,rotation}];\
\>", "Input",
  CellLabel->"In[54]:="],

Cell[TextData[{
  StyleBox["\t",
    FontFamily->"Times New Roman",
    FontSize->10.5],
  StyleBox[
  "Figure 10 shows the images derived from the inner product image data \
\[OpenCurlyDoubleQuote]angle\[CloseCurlyDoubleQuote]. Thus, when we regard \
the inner product image data as the source density, then the solutions of the \
Poisson's equation for these input source densities produce the illusive \
images emphasizing the lighting effects. Further, the illusive images in Fig. \
9 are smooth and beautiful ones compared with these in Fig. 5. Solving the \
Poisson's equation is one of the surface integrations so that small noisy \
components are smoothed.",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell["\<\
illusionG=Table[ListDensityPlot[illusion[[i]],
\tPlotRange->All,Mesh->False,Frame->False,
\tPlotLabel->StringForm[\"`1`deg.\",(i-1)360/rotation],
\tDisplayFunction->Identity],
\t{i,rotation}];\
\>", "Input",
  CellLabel->"In[55]:="],

Cell[CellGroupData[{

Cell["\<\
Show[GraphicsArray[
\tTable[Table[illusionG[[i+j]],{j,0,2}],{i,1,rotation,3}]],
\tImageSize->{450,300},PlotLabel->\"Fig.10. Illusive images\"];\
\>", "Input",
  CellLabel->"In[56]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .65625 
%%ImageSize: 450 300 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.31746 0.015625 0.31746 [
[.5 .66875 -71 0 ]
[.5 .66875 71 12.5625 ]
[ 0 0 0 0 ]
[ 1 .65625 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .66875 -132 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Fig) show
81.000000 12.812500 moveto
(.10) show
99.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(.) show
111.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Illusive) show
165.000000 12.812500 moveto
(images) show
201.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
0 0 m
1 0 L
1 .65625 L
0 .65625 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.015625 0.321429 0.313244 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00751202 0.0192308 0.00751202 [
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(180) show
81.000000 12.812500 moveto
(deg) show
99.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(.) show
105.000000 12.812500 moveto
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
128 string
128 128 8 [128 0 0 128 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
6C6C6C6C6D6D6D6D6D6E6F707070706F70706F6F6F6F7073
6F6F706F6F6E6E6E6D6D6D6D6D6C6B6B6A6B6B6A6A6A6A6A
6A6969696969696969696969696A6A69696A6A6A6A6A6A69
69696969696969686868686767696B686868686868686767
676767676667676666666666676767686868696969696969
696A6B6868696A6B
6C6C6C6C6D6E6E6F6F707274757474747474737373727478
74737373737271706F6E6E6D6D6C6B6A6A69696969696868
696867676767676767676767676768676768686868686767
676767666666666565656463636569666464646464646363
636362626262626161616161626263646464656666666667
676868666567686A
6C6C6C6D6E6E6F707172747678787878787877777777777B
7A7677777675747371706F6E6D6C6B6A6868686868686767
676766656565656565656565656565656666666666666565
65646464636363626261616060606466636060606060605F
5E5E5E5D5D5D5D5D5C5C5C5D5D5E5F5F6060616263636464
646767656465676A
6C6D6D6E6F6F707172747577797B7C7C7C7C7B7B7B7B7B7C
807D7B7B7A7977757372706F6E6C6B6A6867676766666666
666666656464646464646363636363636363636363636363
626261616160605F5F5E5E5D5D5D5D5F62605C5D5C5C5C5B
5B5A5A59585858585757585858595A5B5B5C5C5E5F616161
6263656463646669
6C6D6E6E6F707172737576787A7C7D7F8080807F7F7F7F7F
8182807F7E7D7A787674716F6E6C6B696766656565646565
656565656463636362626262626261616161616061616060
5F5F5F5E5E5D5D5C5C5B5B5A5A5959595B5D5A5858585857
56555554545353535352525353545556565757595B5D5D5E
6060626261646769
6C6D6E6F70717273747577797A7C7E808283838383838282
8386858381807E7B787673716E6C6A686665646363626363
6364646464636262626161606060605F5F5F5F5E5E5E5D5D
5C5C5C5B5B5A5A5958585756565656555557585554545352
5251504F4F4E4E4E4E4D4D4E4E4F5050505152545658585A
5C5D606061636669
6C6D6F7071727374757678797B7D7F818385868786868686
868788878583817E7B7874716F6C6A676564636261606161
61626363646363626160605F5F5E5E5E5D5D5C5C5C5B5B5A
5959585857575655555454535352525151505253514F4F4E
4D4C4B4A4A49494948494848494A4A4B4B4C4D4F51555557
595B5D5D60636669
6C6D6E70717274757677797A7C7D7F818385878889898989
89898A8B898583817D7A76736F6D6A6765636261605F5E5F
5F606161626262616160605F5F5E5D5D5C5C5B5A5A595858
57565555545353525251504F4F4F4E4E4D4C4B4C4D4C4B49
484746454444444343434343444445464848494C4D505254
57595B5B5E626568
6D6E6F707173747577787A7B7D7E8081838587888A8A8B8B
8C8C8C8D8E8B8783807C7773706D6A67646261605F5D5C5C
5D5E5F5F606162616060605F5E5E5E5D5C5B5A5959585756
555453525251504F4F4E4D4D4C4C4B4A4A49474747484745
434241403F3F3F3E3E3E3E3E3F3F4143454546494C4E5052
5558595B5D616568
6D6E6F707273757677797A7C7D7F8082838587888A8B8C8C
8C8D8E8E8E8F8C86817E7974706C696562605E5D5D5C5B5B
5B5C5D5E5E5F6060605F5F5E5E5D5D5D5C5C5B5A5A595757
5554535251504F4E4E4D4C4B4A4949484746464544444444
43403C3C3B3B3A39393837383A3B3E40424345474A4C4E4F
5456575A5D616468
6D6E6F7172737577787A7B7D7E808183848688898A8B8C8D
8D8E8F8F8F908F8B847F7A746F6B6864625E5C5B5B5A5959
595A5B5C5D5E5E5F5F5E5E5D5D5D5C5C5C5B5A5959585756
55535251504E4D4C4B4A494848464645444342424140403F
3F403C3B393736353536373738393A3D3F404445474A4C4E
525557595D606468
6D6E6F7173747677797A7C7D7F808284858688898B8C8D8E
8F8F90909191928F89827C756E6965625F5C5A5958585857
5859595A5B5C5D5D5E5D5D5C5C5C5B5B5A5A595857565554
5352504F4D4C4B4A484746454443424141403F3E3D3D3C3B
3A3A383838373634343536363637373A3C3D424345494A4D
5153575A5D606468
6D6E707173747678797B7C7E7F8182848687898A8B8C8E8F
90919192929394918E877F796E66625F5C5A585756565656
565758595A5B5B5C5C5C5C5B5B5A5A5A5959585756555352
51504E4D4B4A48474544434241403F3E3E3C3B3A3A393837
363534333232343434343535353637393A3C41424448494C
4F5256595D606468
6D6E7072737476787A7B7D7E808283858688898B8C8D8E90
9192929394959694928D847D73685F5C5957555454545454
55565758595A5A5B5B5B5B5B5A5959585857575655545251
4F4E4D4B494846444341403F3E3D3C3B3B39383736353434
33323131313132333435343435353638393C3F414346494B
4E5155595D606468
6D6E7072737577787A7C7E7F8182848587888A8B8D8E8F91
929394959696979595918981786E60575553525151525252
535556575858595A5A5A5B5A5A595858575656555453514F
4E4C4B4947464442403E3D3C3B3A39383736353433323130
302F2F2F2F3031313234343434353537383B3E414446494B
4E5155595C606468
6D6F7072747577797B7C7E8081838586888A8B8D8E8F9092
939495969798999797958F857D73675951504E4E4E4F5051
52545556575859595A5A5A5959585857565555545352504E
4D4B4947454442403D3C3A3938373635343332312F2E2D2D
2D2C2C2C2D2F302F3032343434343436383B3D404346494B
4D5154585C606468
6D6F7173747678797B7D7E8082848587898A8C8E8F909293
94959698999A9A9A9997928981786D60534B4B4B4B4D4F50
5153545557585959595A5A59595958575555545352514F4E
4C4A48454342403E3B393836353433313131302F2E2D2B2B
2B2B2B2B2B2D2F2F3030313234353536383A3C3F4145484B
4E5155585D606468
6D6F71737577787A7C7E7F8183848687898B8D8E90919394
969798999A9B9B9C9A9A948D857C72675B4D4547494B4D4F
5153545657575959595A5959595858575554535251504F4D
4B49474442403E3C3A3836343331302F2E2E2E2D2C2B2A29
2A2A2A2A2B2B2D2D2E2F303132343536383A3C3F4144484B
4E5255595D616468
6D6F71737577797A7C7E8081838587898A8C8E8F91929495
97989A9B9C9D9E9E9D9D96908980766C61554843474A4D4F
51535456575859595A5A5A595958585756555452514F4E4C
4A484644413F3C3A38363432312F2E2D2C2B2C2B2B2A2928
29292829292A2B2B2D2F303132333436383A3C3E4144474B
4E5255595D606467
6E7071737577797B7D7F8182848688898B8D8F9192949596
989A9B9D9E9FA0A09F9E98928B837B71675B504547494C4F
51535557575859595A5A5A595958585756555452514F4E4C
4A484643403D3B39373533302F2D2C2B2A292A2A2B292A28
282727282828292A2B2D2E2F3032333537393C3E4144474B
4E5255595D606468
6E7072737577797B7D7F81838587898A8C8E909193959698
9A9B9D9E9FA1A1A2A19F9A958E867E756C61554945494D50
5254555758595A5A5A5B5B5A5959585756555453514F4D4C
4A484543403D3A373634322F2D2C2A29292829292A2A2929
2827272828272728292A2C2D2E30323436393B3E4144474B
4E5255595D606468
6E70727476787A7C7E80828486888A8B8D8F919294969899
9B9D9EA0A1A2A3A4A3A09B968F8881786F655A50474A4E50
53555758595A5B5B5B5B5B5B5A59585857565453514F4E4B
4A484543403D39363533302E2C2B29282727292928282827
252526262726262828292A2C2D2F313336383B3D4144474A
4E5255595D606468
6E70727476787A7C7E80828486888B8C8E9092949597999B
9C9EA0A2A3A4A5A6A4A29D979089837A71685E54494C4F52
5557585A5B5C5C5D5D5C5C5C5B5A59585756555352504E4C
4A484643403C393634322F2D2B2A29282727292929272726
2424242526262627272828292B2D2F3235373B3D4043474A
4E5255595D606468
6E70727576787A7C7F81838587898B8D8F91939597989A9C
9E9FA1A3A5A6A7A8A6A39F99938C847C736B61584C4F5154
57585A5C5D5E5E5E5E5E5D5D5C5B5A595857555453514F4D
4B484644403D393634312F2D2B2A28282626282929282726
242323232425252626272728292C2E313437393D4043464A
4E5255595D606468
6E70727577797B7D7F818385878A8C8E9092949698999B9D
9FA1A2A4A6A8A9AAA7A4A09A948E867E766D63594F525457
595B5D5E5F60606060605F5F5E5D5C5A595857555452504E
4C4A4745413D3A3734312F2C2B2928272525262829282625
232221212224252625262727272A2D303336393C4043464A
4E5255595D606468
6E70737577797B7D7F828486888A8D8F91939597999A9D9E
A0A2A4A6A8AAABAAA8A5A19B958F877F7870665C5155575A
5C5E5F616262636363636261605F5E5C5B5A59575553514F
4D4B4946423F3C3935322F2D2B2927252424252728282725
23222120202123242425262626292B2F3235383C3F43464A
4E5155595D606468
6E70737577797B7E80828486898B8D8F919496989A9C9EA0
A1A4A5A7A9ABADABA8A5A19B969088827B72685F55585A5D
5F61626465656667666665646362605F5D5C5A5957555351
4F4C4A4743413E3A3633302E2B2927252322232526272726
24211F1F1F2021232323232425282A2D3135383B3F42464A
4E5155595D616468
6E707375777A7C7E80838587898C8E90929496989A9D9FA1
A3A5A7A9ABADAEACAAA6A29C97918A847D736A62585C5D60
626466676869696A6A696968676563615F5E5C5B59575553
504E4C4945423F3B3835322F2B2927252422222325272827
24221F1E1E1E2021212121222427292D3033373B3F42464A
4D5155595D606468
6E707375787A7C7E818386888A8C8F919395989A9C9EA0A2
A4A6A8AAACAEAEADAAA7A29C98928C857F766D655C5F6264
66686A6B6C6D6E6E6E6E6D6C6B69686563615F5E5C5A5855
53504E4B4945413D3A36332F2B2726252422212122242628
2622201E1D1D1E1F202020202326292C3033373A3E424549
4D5155595D606468
6E717376787A7D7F818486898B8D8F929496999A9D9FA1A3
A5A8AAACAEAFAFADAAA7A39D98928E878179716960646668
6B6D6E7071727272737372706F6D6C6A676563615F5D5B58
5653504D4C48433F3C3733302C2826252322201F20232426
2523211E1D1C1D1E1F1E1F202225282B2F33363A3E424549
4D5155595D606468
6E717376787B7D7F828487898C8E91939597999B9EA0A3A5
A7A9ABADAFB0AFAEAAA7A39E99948F89837C756D65696B6E
7072737475767777787877767573716F6C6A676563605E5C
5956534F4E4A45423E3935312E2926262422201E1F212324
2422201D1C1C1D1D1E1E1E1F2125282B2F32363A3E424549
4D5155595C606468
6E717376787B7E808385878A8C8F919496989B9D9FA1A4A6
A8AAACAFB1B1B0AEAAA7A39E9B95918A857F78726C6E7173
75767879797A7B7B7C7D7D7D7B797774726F6C6A67656260
5D595552514D4845413C37322F2A27262422201D1D1F2224
2422201D1A1B1C1C1C1C1D1E2124282B2E32363A3D414549
4D5054585C606468
6E717376797B7E808386888B8D90929597999C9EA0A2A5A7
A9ABAEB0B1B1B0AEAAA7A29E9B96928B87827C7673747577
78797A7B7C7D7E7E7F80808181807E7B787673706D696764
615D595453504C4A453F3933312B28262523201D1C1D2022
2322201D1A191A1A1A1B1B1C2023262A2E3235393D414549
4C5054585C606468
6E717476797C7E818386898B8E909395989A9D9FA1A4A6A8
ABADAFB2B2B1B0ADAAA7A39F9A97928C8884807C79797979
7A7B7C7D7E7F80808182838384848482807C7975726F6B68
65615C5653524E4E48423A34322E29272623211E1C1C1E20
22221F1C19181819191A1A1C1F22262A2D3235393D414549
4C5054585C606468
6E7174777A7C7F828487898C8F919496999B9EA0A2A5A8AA
ACAEB0B2B3B1B0ADA9A5A29E9A97918D898684807D7C7C7C
7C7D7E7E7F7F808182838585868687878684807C7875716D
6965605A54544F514D463F3632312B282723211E1B1B1B1E
21221F1B191817171818181B1F2226292D3135393D414549
4D5054585C606468
6E7174777A7C7F8285888A8D909295979A9C9FA1A4A6A8AB
ADAFB1B2B3B1AFADA9A5A19E9B96918D89858482807F7E7E
7E7E7F7F80808181828485868788898A8A8987847F7B7773
6E69645D555652525049423A35332E2A2724201E1B1A1A1B
1F211F1B181615161717171A1E2225292D3135393D414548
4C5054585C606467
6E7174777A7D808385888B8E919396989B9DA0A2A5A7A9AC
AEB0B2B3B3B1AFACA8A4A09D9A95918E8A88868583818080
7F7F7F7F808080818284858688898A8B8C8D8C8B87827E79
736E676056545451524D463D37322F2B2825211E1B191919
1D201F1B181614131516171A1D2125282D3135393D414448
4C5054585C606468
6F7175777A7D818386898C8F929497999C9FA1A3A6A9ABAD
AFB1B2B4B2B0ADABA8A3A09C9994918E8C8A888785848281
8080807F8080808081838486888A8B8D8E8F8F8F8E8A857F
79736C63595354504F4D48413B34302D2825211D1B181918
1A1E1F1B171514121315171A1D2125282C3034383D414448
4C5054585C606468
6F7275787B7E8184878A8C8F9295989B9DA0A2A4A7A9ACAF
B0B2B3B3B2AFACA9A6A29F9B9793908F8E8C8B8988868583
828181808081808081828386888A8C8E8F91919191908D87
807871675C5451514D4C48433D36312F2A26221E1B191717
181B1D1B181613111213161A1D2024282C3034383C404548
4C5054585C606468
6F7275787B7E8184888B8E909396999C9EA1A3A6A8ABADB0
B1B2B4B3B1AEACA8A4A19E9A969391908F8E8D8C8A898786
858484838383828282828385878A8D8F919393949392918D
867E756B5F56504F4B4746434039332F2C28231F1A181616
16171B1A17151311111116191D2024282C3034383C404548
4C5054585C606468
6F7275787B7F8285888B8E9194979A9DA0A2A5A7A9ACAEB0
B2B3B3B2B0ACA9A7A29F9C98948F91919190908F8E8C8988
888888878787868484838385888A8D909394959696959492
8E857B7063584F4D4C4643413E3B36302C29241F1A171514
1415181816141110101114181C2024282C3034383C404548
4C5054585C606468
6F7275797C7F8285898C8F9295989B9EA1A4A6A9ABADB0B2
B2B3B2B1AEABA7A5A19E9A96939292939393939391908F8E
8F8E8D8C8C8C8B8A89888786888B8E919496979898989795
938D8276685B514949463F3E3A3836322E2A25201B171513
121215161412100E0E1215181C1F24282C3034383C404448
4C5054585C606468
6F7276797C808386898D909396999C9FA2A5A7AAADAFB1B2
B2B2B1B0ADA8A5A29F9A9794919394949596979896959391
909190908F8F8E8D8C8D8C8A898D90939698999A9A9A9997
95918A7C6E5F554A46443E3B383434332E2A26211B171412
1010121514110F0D0D1114181C1F23282C3034383C404448
4C5054585C606468
6F7276797D8083878A8D9194979A9DA1A4A6A9ABAEB0B3B4
B4B3B1AEABA7A4A09C9995929293949697999A9C9B999897
9796969796959493919091908E8E919597999A9C9C9B9A99
97938E837464574B45423E3735302E302F2B26211C171411
0E0E101313110F0D0C1014171B1F23282C3034383C404448
4C5054585C606468
6F7276797D8184888B8E9295999C9FA2A5A8AAADAFB2B4B5
B5B2B0ADA9A5A19E9A96929192939597999D9FA3A3A2A1A0
A09F9FA0A09F9E9C9B9A9B9A989796989A9B9C9D9E9D9C9A
999591897A695A4F46403E37322E292A2C2B26221D181411
0D0C0D0F110E0E0C0D1013171B1F23282C3034383C404448
4C5054585C606468
6F73767A7E8185888C8F93969A9DA0A4A7A9ACAFB1B4B5B6
B5B2AFACA7A39F9A96928D90919395989A9DA0A4A7A8A8A7
A7A7A6A6A6A6A4A3A19E9D9D9B9B9A9B9C9D9E9E9F9E9D9B
9997938C80705F5348403C38302C2625262926221E181410
0C0B0A0D0F0D0C090C1013171B1F24282C3034383D404448
4C5054585C606468
6F73777A7E8285898D9094979B9EA2A5A8ABAEB1B3B5B6B6
B5B2AEAAA6A19C97938E8D8F919395989A9D9FA2A4A6A7A7
A6A7A6A5A4A4A3A2A09F9E9D9D9D9D9D9E9FA0A0A09F9E9D
9A97948E847563574C443D39302A2622222424221E19140F
0B09080B0D0C0B080C1013171B1F24282C3034383C404549
4D5054585C606468
6F73777B7E82868A8D9195999CA0A3A7AAADB0B3B6B8B8B7
B5B2AEA9A49F9A958F898B8E909395989A9D9FA1A3A4A5A6
A6A6A5A4A4A3A2A1A09F9E9E9E9E9FA0A0A1A1A2A1A1A09E
9C999691887A68594E453D38322A241F1E1F20201D191510
0D0907080B0B0A080B1013161B1F24282C3035393D414549
4D5054585C606468
7073777B7F83878B8E92969A9EA1A5A8ACAFB2B5B7B9BAB8
B5B1ADA8A39D97928D868A8D8F9295979A9C9EA0A2A3A4A5
A5A5A4A3A3A2A1A09F9E9E9E9F9FA0A2A3A3A3A3A3A2A19F
9D9A96928A7D6E5D52484039332B241D1B1B1D1E1C18150F
0D0907070A0A09090B0F13171B2024282D3135393D414549
4D5055585C606468
7074787C8084888B8F93979B9FA3A6AAADB1B5B8BABBBAB8
B4B1ACA7A19C95908A86898C8F929497999C9E9FA1A3A4A4
A5A5A4A3A2A1A09F9E9E9E9E9FA0A1A2A3A4A5A5A4A4A3A1
9F9C98938D827262544A413A332D251D1919191A1B18150F
0B080606080A080A0B0F13171B2024292D3135393D414549
4D5155585C606468
7074787C8084888C9094989CA0A4A8ACB0B3B7BABDBDBBB8
B4AFABA59F99948E8687898C8F919497999B9D9FA1A3A4A5
A6A7A7A5A3A2A09F9E9D9E9E9FA0A2A3A5A5A6A6A6A5A4A2
A09E9A958F857665574C423C342F2720171616181A171510
0B0705040709080A0B0E12171C2025292D3135393D414549
4D5155595C606468
7074787C8185898D9195999DA1A5A9ADB1B5B9BDBFBFBCB8
B4AFA9A49E98928B8387898C8E919496999B9D9FA1A3A3A4
A7A9A9A8A4A2A1A09E9D9E9EA0A1A2A4A5A6A6A7A7A6A5A4
A29F9C9791897C6A5B4F453D353029211915151517171410
0A070403050709080C0F13181C2125292E31363A3E424649
4D5155595C606468
7074787D81858A8E92969A9EA3A7ABAFB3B7BBBFC2C0BDB9
B4AFA9A39D9790898387898C8F929496999B9D9FA1A5A7A6
A8AAABACAAA7A5A4A19E9E9EA0A1A3A4A5A6A7A8A8A7A6A5
A3A09D99948C816F6052484038302B221B13141415171411
0B070402030508080C1014181D21252A2E32363A3E42464A
4D5155595C606468
7074797D82868A8F93989CA0A4A8ADB1B5B9BDC2C4C1BDB8
B3AEA9A29C968F8884878A8C8F919496999B9D9FA0A3A5A7
A8AAABABAAA7A5A4A3A19F9FA0A2A3A4A6A6A7A8A8A8A7A7
A5A29F9B958F867465564C423B322D251F14141415171411
0C0704020205080A0C1015191D22262A2E32363A3E42464A
4E5155595D606468
7075797E82878B9094999DA1A6AAAEB3B7BBC0C4C6C2BDB9
B3ADA8A29C958D8686888B8D8F919496989A9D9EA0A2A4A6
A8A9AAABA9A7A6A4A3A1A0A0A1A2A3A4A5A6A7A8A8A8A8A7
A6A4A19D9891897A695A4F443E352F272017141314171511
0D0703010205070A0D11161A1E22262B2F33373B3F42464A
4E5255595D606468
7075797E83878C91959A9EA2A7ACB0B4B9BDC2C6C6C2BDB7
B2ADA7A19B948C8387898B8D8F919395989A9C9E9FA1A3A4
A7A9AAAAA9A7A6A4A3A2A1A1A1A2A3A4A5A6A7A8A8A8A8A7
A7A5A29F9A948C806E5E5348403831292119151414161611
0D070401020506090E12161A1F23272B2F33373B3F43464A
4E5256595D616468
7075797E83888D92969BA0A4A9ADB2B6BBBFC4C9C7C2BEB7
B3ADA7A19A938D85888A8C8E9091939597999B9D9FA0A2A4
A6A8A9A9A9A7A6A5A3A2A1A1A1A1A2A4A4A5A6A7A8A8A8A7
A6A5A4A09B958E837263554B423A332C241B171514151712
0D0703000206070B0F13171C2024282C3034383B3F43474B
4E5256595D616468
70757A7F84898D92979CA1A5AAAFB3B8BDC1C6CBC8C3BDB7
B2ACA7A29A948E8A8A8B8D8F9091939596989A9C9EA0A1A3
A6A8A9A9A9A7A6A4A3A1A1A1A1A1A2A3A4A4A5A6A7A7A7A7
A6A5A3A19D968F877666594D443C332D251D181615151712
0E0703000205070B1014181C2025292D3034383C4044474B
4F52565A5D616468
70757A7F84898E93989DA2A7ABB0B5BABFC3C8CBC8C3BCB7
B2ACA6A09A93908D8D8D8E8F909292939597999B9D9FA1A2
A5A7A9AAA9A7A5A4A2A1A0A0A1A1A1A2A2A3A4A5A5A6A6A6
A6A5A3A19E9890887B6B5D51463E352E261E191715141713
0E0703000105080C1115191D2125292D3135393C4044484B
4F52565A5D616568
70757B7F858A8F94999EA3A8ADB2B7BCC1C6CBCAC7C2BBB6
B1ABA7A0998F8F8E8E8E8F8F90919293949697999B9DA0A1
A4A7A9A9A8A6A5A4A2A0A09F9FA0A0A0A1A1A2A3A3A4A5A5
A5A4A2A09E9891887C6D5F52483F362F271F1A1816141613
0F0703000104090D11161A1E22262A2E32363A3D4144484C
4F53565A5D616568
71767B80858A90959A9FA4AAAFB3B9BEC3C8CFCCC8C2BBB6
B0AAA59E9791908F8F8F8F9090919192939495989A9C9EA0
A3A5A8A9A8A6A4A3A1A09F9E9E9E9E9F9F9F9FA0A1A1A2A3
A3A2A19F9D9892897D6F6154493F372F261F1B1916151514
0F0803000005090E12171B1F23272B2F33363A3E4145494C
5053575A5E616568
71767B81868B90969BA0A6ABB0B5BAC0C5CACFCCC8C2BBB4
AFA9A29D9693919090908F909090919191929395989A9D9F
A2A5A8AAA9A7A4A3A19F9E9E9D9D9D9D9D9D9D9D9E9E9FA0
A1A1A09E9C99928A7F716355493F372F261D1C1917151314
0D08040101050A0F13181C2024282C3033373B3E4245494C
5054575A5E616568
71767C81878C91979CA1A7ACB1B7BCC1C6CBCECAC7C1BBB4
AEA7A0999593929191909090909090909090919395989B9E
A1A4A7AAAAA8A5A3A19F9E9D9D9C9C9B9A9A9A9A9B9B9D9E
9E9F9E9D9B98928A807364574A403830271E1C1917151114
0C08050202070C1014191D2125292D3034383C3F43464A4D
5054575B5E616568
71777C82878D92989DA3A8ADB3B8BEC3C8CECDCBC6BFBAB3
ADA59E95949391919191919090908F8F8E8E8F9193969A9D
A0A4A7AAAAA9A7A4A2A09E9D9D9C9B99989797979798999B
9C9C9C9B9A96928A807566584B403830281F1D1A17161014
0D07050404090D12161A1E22262A2E3135393C4043474A4D
5154585B5E626568
71777D82888E93999EA4A9AFB4BABFC5CAD1CBCAC5BEB8B2
ABA29C969492919292929291908F8E8E8D8C8C8E9194989C
9FA4A7ABACABA8A6A3A19F9E9D9C9B989695949393949697
999A9A9A9895908A817769594C413830281F1D1B17171014
0E070504060A0F13171B1F23272B2F3236393D4044474B4E
5154585B5E626568
71777D83898E949A9FA5ABB0B6BCC1C7CCD3CCC9C2BCB6B0
A8A098979391929393939392918F8E8D8C8B8B8C8F93989B
9FA4A8ACAEADABA8A6A3A09F9E9D9C999594939291919395
9697989897948F8981776B5D4E41383029211D1C19171114
0E070605070C1115191D2125282C3033373A3E4145484B4E
5255585B5F626568
71777D83898F959BA0A6ACB2B7BDC3C8CDD0CDC9C1BBB4AF
A59E99989492929494959493919293908C8B8A8C8D91979B
A0A5A9ADB0B1AFACA8A6A19FA0A1A09C97959392908F9193
9596969695938E8880776B5F4F42393029221F1D19171114
0F090807090E12161A1E22262A2D3134383B3F4245484C4F
5255595C5F626568
72787E848A90969CA2A8ADB3B9BFC4CAD1D1CEC9C2B9B2AD
A2989997959294959697979694959795928E8D8E9092979C
A1A6ABAFB2B4B3B1ADADAAA4A5A6A4A19C99969692909093
9495969594928E8780766B5F50433A312923201D1A181214
0D0A09080C1014181C2024272B2E3235393C3F4346494C4F
5356595C5F626568
72787E848A91979DA3A9AFB5BBC0C6CBD2D3CEC8C1B8B1AB
A3989896949394979A9B9C9995969B99999292909395999E
A3A8ADB1B4B7B8B6B4B0AFAAA7ACA8A79F9E9A9B96939393
9495969593918D8780776D6152443A322A24201E1B181315
0D0A0A0A0E12161A1E2225292C3033363A3D4044474A4D50
5356595C5F626569
72787E858B91979EA4AAB0B6BCC2C8CCCDD2CFC9C1B8B0A8
A0989896949396999DA0A2A19D9C9C9A9D9A9A98999B9DA1
A5AAAFB3B6B9BCBCBAB7B3B1AEB1ACADA7A4A0A09D9A9897
9696969694918D8780786F6355483C332A26221E1A181516
0F0C0B0D1115181C2023272A2E3134383B3E4144474B4E51
54575A5D60636669
72787F858C92989FA5ABB2B8BEC4CBD1CFD0CEC7BFB8AFA6
9D9897959393979BA0A5A9A9A7A7A7A5A3A1A09F9FA0A2A4
A8ACB0B5B8BCBEBFBFBDBBB7B5B8B8B6B2ADAAA7A5A29F9D
9B99989795928E8780786F64564A3F342C2724201B191617
110E0D1013171B1E2225282C2F3236393C3F4245484B4E51
54575A5D60636669
72797F868C9399A0A6ADB3BAC0C6CDD5D5D0CDC6BEB6AFA5
9D9896949293979BA0A5AAADAFAFAFADABA8A5A2A2A3A5A8
ABAEB2B6BABDC0C1C1C0BEBDBBBBBBBBB9B7B3AFABA8A5A2
9E9C9A9896938F8881786E63574B41362C2825211B191718
120F101316191D2024272A2D3134373A3D404346494C4F52
55585A5D60636669
727980868D939AA1A8AEB5BBC2C8CFD5D9D2CDC6BEB7B0A5
9D9895949292969A9EA3A7AAACAEAEABA9A7A5A4A6A6A8AA
ADB0B3B7BABEC2C4C4C3C0BDBBBBBCBCBAB8B4B1ADAAA7A4
A19E9C9A97938F8981796F64574B41372E2826211B191718
130F1215181C1F2225292C2F3235383B3E4144474A4D5052
55585B5E60636669
727980878D949BA2A9B0B7BDC4CAD0D5DDD4CFC8C0B8B1A7
9F999593919296999CA0A4A7A9ABABACABABABA9A9A9AAAC
AEB1B4B7BABEC2C5C8C9C6C2BEBAB9B9B7B6B3B1ADABA8A6
A3A09E9C9995908A82797064594D4238312B27221C1A1717
131114181B1E2124272B2E3134373A3C3F4245484B4D5053
56595B5E61636669
727980878E959CA3AAB1B8BFC6CDD3D5DED7D1CBC3BAB3A9
A19A95939192969A9B9EA1A4A7AAACAEB0AEACABABABACAE
AFB2B4B7BABDC1C4C7CACCCAC7C2BDB9B7B4B2B0ADABA9A7
A6A3A19E9B96918B847C70665A4E4137312C28241E1B1916
1313171A1D202326292C2F3235383B3E414346494B4E5154
56595C5E61646669
737A81888F969DA4ABB2BAC1C8D0D8D8DBD8D3CDC7BDB5AC
A49E98949192969C9FA2A4A7AAACADADADADACABABACADAE
B0B2B4B7BABCBFC2C5C7C9C9C9C7C5C2C0BBB7B4B2AFAEAB
A8A5A3A09C98928D847C71665A4E4237332E2926201D1B17
14161A1D202326292C2E3134373A3C3F4245474A4C4F5254
575A5C5F61646669
737A81888F969EA5ACB4BBC3CBD3DCDFDDD9D3D0C9C1B8AF
A8A09A969292969A9EA2A6A8AAAAAAABABABABABABACADAE
B0B2B4B6B8BBBDC0C2C4C5C6C6C5C3C1C1BFBDBAB7B3B0AE
AAA7A4A19D98938E877D72665B4F433835302A28211E1E18
16191C1F2225282B2E303336383B3E404346484B4D505255
575A5D5F62646769
737A818890979EA6ADB5BDC5CDD6DFE3DFDBD4D1CBC3BBB2
AAA39C97929295999C9FA3A5A7A8A8A9A9AAAAAAABACADAE
B0B1B3B5B7B9BBBDBFC1C2C3C2C2C1C0BFBDBCB9B7B4B1AF
ABA9A6A39F99948E877F74695D50443837322B2A241F1F1A
191D1F2225282A2D303235383A3D3F424447494C4E515356
585B5D5F62646769
737A818990979FA7AEB6BEC7CFD9E3E8E2DDD6D2CCC6BEB5
ADA59E99949295989B9DA0A3A4A5A7A8A8A9A9AAAAABACAD
AFB1B2B4B6B7B9BBBCBEBFC0C0C0BFBEBDBCBAB9B7B5B2AF
ADAAA7A39F9A948E877E74695D4F433736332D2C2721201B
1D202325282A2D2F323437393C3E414346484A4D4F525456
595B5D6062646769
737A828990989FA7AFB7BFC8D1DAE4ECE5DFD8D3CEC7C0B8
B0A8A09B979495979A9C9FA1A3A4A5A6A7A8A8A9A9AAABAD
AEAFB1B2B4B6B7B9BABBBCBDBDBDBDBCBBBAB9B8B6B4B2B0
ADAAA7A4A09A958E877E74695D50433835342F2E2A24211E
212326282A2D2F323436393B3D40424447494B4E50525557
595C5E6062656769
737A82899198A0A8B0B8C0C9D2DBE5EEE9E3DDD7D0CAC3BB
B2ABA39D99959697999C9EA0A1A3A4A5A6A6A7A8A9AAABAB
ADAEB0B1B2B4B5B7B8B9BABBBBBBBBBBBAB9B8B7B6B4B2B0
AEABA8A4A09B958F887E74695D51443934332E2E2C292322
2427292B2D2F323436383B3D3F414446484A4D4F51535558
5A5C5E6063656769
737A82899198A0A8B0B8C1C9D3DCE6F1ECE6E0DAD3CCC5BD
B5ADA59F9B979798999B9D9FA0A1A3A4A5A6A6A8A8A9AAAB
ACADAEB0B1B2B3B5B6B7B8B9B9B9B9B9B9B8B7B6B4B3B1AF
ADABA8A49F9B958F887E75695D51453B35332F2F2D2C2627
282A2C2E30323436383A3C3F41434547494B4E5052545658
5A5D5F6163656769
737A82899198A0A8B0B8C1CAD3DCE6F1EFEBE4DDD6CFC7BF
B7AEA7A19D9998999A9B9D9EA0A1A2A3A4A5A6A7A8A8A9AA
ABACADAEAFB0B2B3B4B5B6B6B7B7B7B7B7B6B5B4B3B2B1AF
AEAAA8A4A09B958F877F75695D52453E38332F2E2D2C2A2A
2C2D2F31333436383A3C3E40424446494B4D4F5153555759
5B5D5F6163656769
737A82899198A0A8B0B8C1CAD3DCE7F3F4EEE8E0D9D2CAC1
BAB1A9A4A09C9A9A9B9C9D9E9FA0A2A3A3A4A5A6A7A7A8A9
AAABACADAEAFB0B1B2B3B3B4B5B5B5B5B5B5B4B3B2B1B0AF
ADAAA8A4A09B9690877F756A5D5245403A36302F2E2C2D2E
2F3032333537393B3C3E40424446484A4C4E50525456585A
5C5E60626466686A
737A82899198A0A8B0B8C0C9D2DCE6F0F7F3ECE5DDD6CDC4
BCB4ACA6A19E9C9B9C9C9D9E9FA0A1A2A3A4A5A6A6A7A7A8
A9AAAAABACADAEAFAFB0B1B2B2B3B3B3B3B3B3B2B1B0AEAD
ACAAA7A4A09B958F877E756A5D5246423C3731302F2E2F31
3233353638393B3D3E4042444648494B4D4F51535557585A
5C5E60626466686A
737A82899098A0A7AFB7C0C8D1DBE4EEF9F9F2EAE2DAD2C8
BFB6AEA8A3A09E9D9D9D9E9F9FA0A1A2A3A3A4A5A5A6A6A7
A7A8A9A9AAABACACAEAEAFAFB0B0B1B1B1B1B1B1B0AFADAC
ABA9A7A39F9B9690887F756B5F5347433F39333131313233
353637393A3C3D3F4142444647494B4D4E5052545657595B
5D5F60626466686A
737A818990989FA7AFB7BFC7D0D9E2ECF7FCF7EFE8DFD6CD
C3B9B1AAA6A2A09F9E9E9E9FA0A0A1A1A2A3A3A4A4A5A5A6
A6A7A7A8A8A9A9AAABABACADADAEAEAEAFAFAFAFAEADACAB
AAA8A5A39F9A95908880756B60544743413A363332343536
38393A3B3D3E404143444647494B4C4E5051535556585A5C
5D5F61636466686A
737A818890979FA6AEB6BEC6CED7E0EAF3FDFCF6EEE5DCD1
C7BDB3ACA7A4A2A0A0A09FA0A0A0A1A1A2A2A3A3A4A4A4A5
A5A5A6A6A6A7A7A8A9A9AAAAABABABACACACACACACABABAA
A9A7A4A29E9A958F8880766B61564A45413B373535373839
3A3B3D3E3F404243454647494A4C4E4F5152545657595B5C
5E6061636566686A
737A81888F979EA5ADB5BDC5CDD5DEE7F0FBFFFDF5EBE1D7
CBC0B7AFA9A5A3A2A1A0A0A0A0A1A1A1A1A2A2A3A3A3A4A4
A4A4A4A4A4A5A5A6A6A7A7A8A8A9A9A9AAAAAAAAAAAAA9A8
A7A5A3A09D99948F8880776C62584E49443E3937393A3B3C
3D3E3F40424344454748494B4C4E4F5052545557585A5B5D
5F6062636567686A
737A80888F969DA4ACB3BBC3CBD3DBE3ECF4FBFFFBF0E5DA
CFC4BAB2ACA7A5A4A3A2A1A1A1A1A1A1A2A2A2A2A2A3A3A3
A3A3A3A3A3A3A3A3A4A4A4A5A6A6A7A7A7A7A8A8A8A8A7A6
A6A4A29F9C98948E8880776E6459524C45403C3B3C3D3E3F
4041424344454647484A4B4C4E4F505253555658595B5C5E
5F6162646567686A
727980878E959CA3ABB2BAC1C9D0D8E0E7EEF5FAFDF5E9DE
D3C8BEB5AFAAA7A5A4A3A2A2A2A2A2A2A2A2A2A2A2A2A2A2
A1A1A1A1A1A1A1A1A1A2A2A2A3A3A4A5A5A5A5A5A5A6A5A5
A4A2A19E9B97938F8880786F655D564F4843403F40404142
43444445464748494A4B4D4E4F505253545657595A5B5D5E
606163646667696A
727980878D949BA2A9B1B8BFC6CED5DDE4EAF1F6FBF9EBE1
D7CCC2B9B2ADAAA8A6A5A4A3A3A3A3A2A2A2A2A2A1A1A1A1
A1A0A09F9F9F9E9F9F9F9FA0A0A1A1A2A2A2A2A3A3A3A2A2
A2A19F9D9A96918E89807870655E59524B46434343444445
4646474848494A4B4C4D4E4F51525354565758595B5C5E5F
606263646667696A
72797F868D949AA1A8AFB6BDC4CBD2DAE0E7EDF3F9FAF0E4
DACFC6BDB6B0ACAAA8A7A6A5A4A4A4A3A3A2A2A1A1A1A0A0
A09F9E9E9D9C9C9D9D9D9D9D9D9E9E9E9F9FA0A0A1A1A0A0
A09F9E9B9895908C8882797067615B554F4A464747474748
4849494A4B4B4C4D4E4F5051525354555758595A5C5D5E60
616263656667696A
72797F868C9399A0A7ADB4BBC2C9D0D7DDE4EBF1F9FAF5E9
DED3C9C0B9B3AFACAAA9A8A6A6A5A5A4A3A3A2A1A1A1A0A0
9F9F9E9D9C9B9A9B9B9A9A9A9A9B9C9C9C9D9D9E9E9F9F9F
9F9E9D9A97938F8B8680787369625C57514D4B4A4A4A4A4B
4B4B4C4C4D4D4E4F505152525354555758595A5B5C5E5F60
616364656668696A
72787F858B92989FA5ACB2B9C0C6CDD4DAE1E8EFF7FAF9ED
E3D9CEC5BDB7B3AFADABAAA8A8A7A6A6A5A4A3A2A1A1A0A0
9F9E9E9C9B9A999999999898989999999A9A9B9B9C9D9D9D
9D9C9B9996938F8B857F77726A645D59544F4E4E4D4D4D4D
4D4E4E4E4F4F50515252535455565758595A5B5C5D5E6061
626364656768696A
72787E848B91979DA4AAB0B7BDC4CAD1D7DEE5ECF4F9FCF4
E9E0D5CBC2BBB6B2B0AEADABAAAAA9A7A6A5A4A2A2A1A0A0
9F9F9E9D9B9A99989898989897979797989899999A9B9B9B
9A9A9A9894928D88837D76716A645E5A5653525150505050
505050515151525353545556565758595A5B5C5D5E5F6061
626365666768696A
72787E848A90969CA2A8AFB5BBC1C8CED4DBE1E8F0F8FCF9
F1E6DCD2C9C1BAB5B3B2B0AFADACABA9A8A7A5A4A3A2A3A2
A1A09F9E9D9B9A9A99999998989797989798989898999A9A
9A99989692908D87807B77716B65605B5756555453535252
5252525353535454555556575858595A5B5C5D5E5F606162
636465666768696A
71777D83898F959BA1A7ADB3B9BFC5CBD1D8DEE4EBF2F9FB
F8EEE3D8CFC8C0BBB7B5B4B2B1AFAEACABA9A8A7A5A4A4A4
A3A2A2A09F9E9D9C9C9B9B9A9A9A99999898989998979797
97969694918D8A87817B76716C66615C5A59585756555555
54545455555555565657585859595A5B5C5C5E5F60606162
636465666768696B
71777D82888E94999FA5AAB0B6BCC2C8CED4DAE0E7ECF2F6
F9F2EADFD6CFC7C1BBB9B6B5B4B3B1B0AEADABA9A8A8A7A6
A6A6A5A4A2A1A1A09F9F9F9F9D9C9C9B9B9A9A9A9A989796
96959492908D8985807B76716B66625E5C5B5A5959585757
5756565657575757585859595A5B5B5C5D5E5E5F60616263
6465666768696A6B
71777C81878D92989EA3A9AEB4BABFC5CBD1D7DCE2E8EDF2
F7F7EEE5DBD2CBC5C0BDBBBAB8B6B5B3B2B0AFADACABAAAA
AAA9A9A7A6A5A3A2A2A2A1A1A19F9F9D9C9B9A9A9A999796
959392918E8B8884807B75706B6661605F5D5C5B5B5A5959
5958585858595959595A5A5B5B5C5C5D5E5F5F6061626363
6465666768696A6B
71767C81868C91969CA1A7ACB2B7BDC2C8CDD3D8DEE3E8ED
F1F7F4EBE2D8D1CBC6C2C0BFBDBBB9B7B6B4B4B2B0AFAEAE
AEADADACABABA8A6A6A5A5A5A4A2A1A09F9C9B9B9B9A9998
979594928F8C88857F7A756E6A66636261605F5E5D5C5B5B
5B5A5A5A5A5A5A5A5B5B5B5C5C5D5D5E5F5F606162626364
6566666768696A6B
71767B80858B90959A9FA5AAAFB5BABFC4CACFD4DADFE4E8
EDF1F4EFE6DCD5CEC8C6C4C3C3C0BDBBBAB8B7B6B4B4B3B2
B2B2B1B1B0AFB0ACABAAA9A8A8A7A5A4A3A19F9E9D9C9A99
97959493908C87837F7A766F6C666564636261605F5E5D5D
5C5C5C5C5C5C5C5C5C5C5D5D5D5E5E5F6060616262636464
6566676868696A6B
71767B8085898F94999EA3A8ADB2B7BCC1C6CBD0D5DADFE4
E9EDF3F4EBE4DDD4CECAC8C8C7C6C2C0BEBDBCBBB9B8B8B6
B7B7B5B4B5B4B4B3B0B0AFAEAEADABAAA8A6A3A1A09E9C9B
999795928F8A87827C7975716E6A68666564636261605F5F
5E5E5D5D5D5D5D5D5D5E5E5E5F5F5F606061626263646465
6666676869696A6B
70757A7F84888D92979CA1A5AAAFB4B9BEC3C8CDD1D6DBE0
E4E9EEF5F3E9E0DAD4CFCCCCCCCCC7C5C2C1C1C0BDBDBCBA
BBBABBB9BABAB9B8B6B7B5B4B4B3B1AFADABA8A5A3A19F9E
9B9896938F8B86837E7975716F6D6B696766656463626160
605F5F5F5E5E5E5E5F5F5F5F606060616162626364646565
6667676869696A6B
7075797E83878C91959A9FA3A8ADB1B6BBBFC4C9CED2D7DB
E0E5EAEFF4F3E8DED8D3D0CFD0D1CDCAC9C6C6C5C3C1C1C0
BFBFC0BEBFC0C0C0BCBCBCBCBAB9B7B6B4B2AEABA8A4A1A0
9E9A96928E8984827F7A7671706E6D6B6968666565636362
616160606060606060606060616161626263636464656566
66676868696A6A6B
7074797D82868A8F94989DA1A5AAAFB3B8BCC1C5CACED3D7
DCE0E5EAEEF3F1E7DED8D4D2D3D5D3CECDCCCAC9C9C6C5C5
C4C3C4C4C3C4C6C7C6C4C1C1C1C0BEBDBBBAB6B3AFABA7A2
9E9B98928F8C8582807D787573716F6D6B6A686766656463
636262616161616161616161616262626363646465656666
67676869696A6A6B
7074787D8185898E92969A9FA3A7ACB0B4B9BDC1C6CACED3
D7DCE0E5EAF0F4F0E7DFD9D5D5D7D8D4D1D1D0CFCECCCAC9
C9C8C8C8C8C7C9CBCBCBCAC9C7C5C4C2BFBDBAB7B3AFA9A4
9F9A9793908D8885817D7A777573706E6D6B6A6867666665
646363636262626262626262626263636464646565666667
67686869696A6A6B
7074787C8084888C9094989CA1A5A9ADB1B5B9BEC2C6CACE
D3D7DCE0E5EAF0F3EEE8E2DDDAD9DCDBD7D5D5D5D4D4D1D0
CECECDCDCCCCCDCFCFD1D0CFCCC9C8C6C4C1BDB8B4B0AAA3
9F9B9793928F8A86837F7C79767472706E6C6B6A68676766
656564646363636363636363636363646465656566666767
67686869696A6B6B
6F73777B7F83878B8E92969A9EA2A6AAAEB2B6BABEC2C6CA
CED2D6DBE0E5EAEFF2EEE8E2DFDCDCDEDEDAD9D9D8D9D8D7
D5D3D1D2CFD0D0D1D1D3D5D4D1CFCCC9C5C2BEB9B4AFABA6
A29E9B9794918C8784807D7A777573716F6E6C6B69686867
666665656464646464646464646464656565666666676767
686869696A6A6B6B
6F73777A7E8285898D9094989C9FA3A7ABAEB2B6BABEC2C5
C9CDD2D6DADFE4E9EEF1EFE8E2DEDDDEE0DFDEDCDCDCDCDD
DDDBD8D8D5D4D3D4D1D0D2D2D0CECCC8C3BFBBB7B5B1ADA9
A5A29E9996938F8985827E7B79767472706F6D6C6A696968
676666666565656565646465656565656566666667676768
686969696A6A6B6B
6F73767A7D8184888B8F9296999DA0A4A7ABAFB2B6BABDC1
C5C9CCD0D4D9DDE2E6EAEFEFE9E2DEDCDEE0DEDEDEDEDEDD
DEDFDEDEDBD8D6D6D4D2D1CFCDCBC8C4C3BFBBB8B6B3B0AD
AAA5A09B9897908A86837F7C7A77757371706E6D6B6A6A69
686767676666666665656565656566666666676767676868
6869696A6A6A6B6B
6F7275797C7F8386898D9093979A9DA1A4A8ABAEB2B6B9BC
C0C3C7CBCFD3D6DBDFE3E7ECEDE9E1DDDBDCDCDCDCDBDBDB
DADAD8D8D7D5D5D4D2D0CFCDCAC9C8C4C3C0BDB9B8B5B3AF
ABA7A29E98948F8B8783807D7B78767472706F6E6C6B6A6A
696868686766666666666666666666676767676868686868
6969696A6A6A6B6B
6F7275787B7E8184888B8E9194979A9EA1A4A7AAAEB1B4B8
BBBEC2C5C9CCD0D4D8DBDFE3E6E9E7E0DCD9D8D7D7D7D7D7
D6D6D5D5D4D2D1D1CFCECDCDC9C8C7C4C3C1BFBBB9B7B3AF
ABA8A39D98938F8B8783807D7B7976747371706E6D6C6B6A
6A6969686867676767676766666667676767686868686869
69696A6A6A6B6B6B
6E7174777A7D808386898C8F9295989B9EA1A4A7AAADB0B3
B6B9BCC0C3C6C9CDD0D3D7DADDE0E4E2E0DAD6D4D4D3D2D2
D1D1D0D0D0CFCECDCCCBCBCBCBC8C6C5C4C1C0BDB9B6B2B0
ADA7A19B97928E8A8683807D7B7977757372706F6E6C6C6B
6A6A69696868686867676767676767676768686968696969
69696A6A6A6B6B6B
6E717476797C7F8184878A8C8F9295979A9DA0A3A6A9ABAE
B1B4B7BABDC0C3C6C9CCCFD2D4D7D9DADCDCDAD6D2CFCECD
CCCDCCCDCDCECECECDCBCACACBCBC8C5C4C0BDB9B8B6B3AD
A8A39E9995918C898683807D7B7977757372706F6E6D6C6B
6B6A6A696969696868686867676867676768686969696969
696A6A6A6B6B6B6B
6E717376787B7D808285888A8D8F9294979A9C9EA2A4A7AA
ACAFB2B4B7BABCBFC2C5C7CACCCED0D1D2D3D2D4D2D0CCCA
C9C8C8C8C9CACBCBCCCBCAC8C7C7C5C1BFBEBBB7B3B0ACA8
A49F9B96938F8B8885827F7D7B797775747271706E6D6C6B
6B6A6A696969686868686868686868686768686969696969
6A6A6A6A6B6B6B6B
6E707375777A7C7E818385888A8C8F919496999B9EA0A2A5
A7AAACAFB1B4B6B9BBBDC0C2C4C5C7C8C9CACACACBCCCBC9
C8C7C5C5C5C5C5C4C4C4C4C3C2C1C1BFBDB9B6B2AEAAA7A4
9F9C9894908D8A8784817F7C7A787775747271706F6E6D6C
6C6B6A6A69696969686969686968686868686969696A6A6A
6A6A6A6A6B6B6B6B
6E70727476787B7D7F818385888A8C8E90939597999B9EA0
A2A5A7A9ABADB0B2B4B6B8BABCBDBEBFC0C1C2C2C2C2C2C1
C1C1C0C0BFC0C1C1C1C0BFBFBEBCBAB8B5B2AFACA8A4A19F
9B9794918D8B888583807E7C7A787675747271706F6E6D6C
6C6B6B6A6A6A6A69696969686969696969696969696A6A6A
6A6A6A6A6B6B6B6B
6E6F71737577797B7D7F81838587898B8D8F91939597999B
9D9FA1A3A5A7A9ABADAFB1B2B4B5B6B7B8B9BABABABABAB9
B9B9B8B8B8B8B9B9B9B8B7B7B5B4B2B0ADABA8A5A29F9C9A
9794918E8B888683817F7D7B79777674737271706F6E6D6D
6C6B6B6B6A6A6A6A6A696969696969696969696A6A6A6A6A
6A6A6A6B6B6B6B6B
6D6F71737476787A7B7D7F81838486888A8C8D8F91939597
989A9C9EA0A1A3A5A6A8AAABACAEAFAFB0B1B1B2B2B2B2B1
B1B1B0B1B1B1B1B1B0B0AFAEADACAAA8A6A4A19F9C9A9795
93908D8A888583817F7D7B7A78767574727271706F6E6D6D
6D6C6B6B6A6A6A6A6A6A6A6969696969696969696A6A6A6A
6A6A6B6B6B6B6B6C
6D6F7072737577787A7B7D7E8082838586888A8B8D8E9092
939597989A9B9D9EA0A1A2A4A5A6A7A7A8A9A9AAAAAAA9A9
A9A9A9A9A9A9A9A9A9A8A7A7A6A4A3A19F9E9B9997959290
8E8C8A878583817F7D7B7A7877757473727170706F6E6D6D
6D6C6B6B6B6A6A6A6A6A6A6A6A6A6A6A6A6A6A696A6A6A6A
6A6B6B6B6B6B6B6B
6D6E70717274757778797B7C7D7F808283848687898A8C8D
8F90919394959798999A9B9D9D9E9FA0A0A1A1A2A2A2A1A2
A1A1A1A1A1A1A1A1A1A0A09F9E9D9C9A9997959391908D8B
8A88868482807F7D7B797877767473727271706F6E6E6D6D
6D6C6C6B6B6B6A6A6A6A6A6A6A6A6A6A6A6A6A6A6A6A6A6B
6B6B6A6B6B6B6B6B
6D6E6F70717374757677797A7B7C7D7E8081828385868788
8A8B8C8D8E8F909193949495969798989999999A9A9A9A9A
9A999A9999999999999898979796959392918F8D8C8A8987
858482817F7D7C7B7A7877757473737271706F6F6E6E6D6C
6C6C6C6B6B6B6B6B6B6A6A6A6A6A6A6A6A6A6A6A6A6B6B6B
6B6B6B6B6B6B6B6B
6D6E6E6F707172737475767778797A7B7C7D7E7F80818284
8585868788898A8B8C8D8E8E8F9090909191929292929292
9292929291919191919190908F8F8E8C8C8B898886858483
81807E7D7C7A7A787776757473727171706F6F6E6E6E6D6C
6C6C6C6B6B6B6B6A6B6B6A6B6A6A6A6A6B6A6A6A6A6B6B6B
6B6B6B6B6B6B6C6C
6C6D6E6F6F7071727373747576777778797A7B7B7C7D7E7F
7F80818283838485858687878888898989898A8A8A8B8B8A
8A8A8A8A8A8A8A8A89898989888887868584838381807F7E
7D7C7B7A7977777675747372727170706F6F6E6E6E6D6D6D
6C6C6C6C6B6B6B6B6B6B6B6B6B6B6B6A6B6B6A6B6B6B6B6B
6B6B6B6B6C6B6B6C
6C6D6D6E6E6F70707171727373747475767677787879797A
7A7B7C7C7D7D7E7E7F7F8080818182828282828382828383
8383828282828282828282818181807F7F7E7D7D7C7B7A79
78787777767574737372717170706F6F6F6E6E6E6D6D6D6D
6C6C6C6C6B6B6B6B6B6B6B6B6B6B6B6B6B6B6B6B6B6B6B6B
6B6B6B6C6B6B6C6C
6C6C6D6D6E6E6E6F6F6F7070717171727273737474757575
757676777777787879797979797A7A7A7B7A7A7B7B7B7B7B
7B7B7B7B7B7B7A7A7A7A7B7A797979797878787776767575
747373727272717171706F6F6E6E6E6D6D6D6D6D6D6D6D6C
6C6B6B6C6C6B6B6C6B6B6B6B6B6B6B6B6B6B6B6B6B6B6B6B
6B6B6B6B6B6B6C6C
6C6C6C6C6D6D6D6D6D6E6E6E6E6E6F6F6F6F6F7070707171
717171717171727272727272727373737373737373737473
737373737373737373737373737272727272727171717070
706F6F6F6F6F6F6F6E6E6E6D6D6D6D6C6C6C6C6C6C6C6C6C
6C6C6B6C6C6B6B6B6B6B6B6B6B6B6C6B6B6B6B6B6B6C6B6B
6C6B6B6B6B6B6C6C
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.35119 0.015625 0.64881 0.313244 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00751202 0.0192308 0.00751202 [
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(240) show
81.000000 12.812500 moveto
(deg) show
99.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(.) show
105.000000 12.812500 moveto
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
128 string
128 128 8 [128 0 0 128 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
969797979797979797989899999999999999999999999A9D
99999A9A9A9A9A9A9A9A9A9A9A9999999999999999989898
989798979797989898989898989898979798989797979797
979797979797979797979696969899969696969696969595
959595959595959594959495959595959595959494949494
9395969393949596
979797979898989999999A9B9B9B9B9B9C9C9C9C9C9C9DA0
9D9D9E9E9E9E9E9E9D9D9D9D9D9C9C9B9B9B9B9B9B9A9A9A
999999999899999999999999999999989899999899999998
989898989898989797979796969899979696969695959595
949494949394939393939393939393939392929191919191
9193939291929495
979797989899999A9A9B9C9C9D9E9E9E9E9F9F9F9F9FA0A2
A2A0A1A2A2A2A2A1A1A1A1A0A0A09F9E9D9D9D9D9C9C9B9B
9B9B9A9A9A9A9A9A9A9A9A9A9A9A9A99999999999A9A9A99
999999999998989898979797979798979796969595949494
9393939292929292919191919191919191908F8F8F8E8E8F
909191908F919395
9797989899999A9B9B9C9D9E9F9FA0A0A1A1A1A2A2A2A3A3
A6A4A4A5A6A6A6A5A5A5A4A4A3A3A2A1A0A09F9F9E9D9D9C
9C9C9B9B9B9B9B9B9B9B9B9B9B9B9A9A9A9B9B9A9B9B9B9A
9A9A9A9A9999999898989897979797979896959594949493
9392929191919090908F8F8F8F8F8F8F8E8D8C8C8C8C8D8D
8E8F8F8F8E8F9294
97979899999A9B9C9C9D9E9FA0A1A2A3A3A4A4A4A5A5A5A6
A8A9A8A9A9AAAAA9A9A8A8A7A7A6A5A4A3A2A1A0A09E9E9D
9D9D9D9C9C9C9C9D9C9C9C9C9C9C9B9B9C9C9C9B9C9C9C9B
9B9B9B9A9A9A999999989898989797969798959494949393
9292919090908F8F8E8E8D8D8D8D8D8D8C8B8989898B8B8B
8D8C8E8D8C8E9194
979898999A9B9C9D9D9E9FA0A1A2A3A4A5A6A7A7A7A8A8A9
AAACACADADAEAEAEADACACABAAA9A8A7A5A4A3A2A19F9F9E
9E9E9E9E9E9E9E9E9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D
9C9C9C9B9B9B9A9A99999998989797969696959494939393
9291908F8F8F8E8E8D8D8C8C8C8B8B8A898886868889898A
8A8A8C8B8B8E9194
9798999A9B9B9D9D9F9FA1A2A2A4A5A6A7A8A9AAAAABABAC
ADAFB0B1B2B2B2B2B1B1B0AFAEACABA9A8A6A5A3A2A0A09F
9F9F9F9F9F9F9F9F9F9E9E9E9E9E9E9E9E9E9E9E9E9E9E9E
9D9D9D9C9C9B9B9B9A9A9998989797969695959494939392
9190908F8E8E8D8C8C8B8B8A8A8A89888785838486878787
88888A898A8D9094
9798999A9B9C9E9EA0A1A2A3A4A5A6A7A9AAABACADADAEAF
B0B2B4B5B7B6B7B6B6B5B4B2B1B0AEACAAA8A6A5A3A2A1A0
A0A0A0A0A0A0A0A0A09F9F9F9F9F9F9F9F9F9F9F9F9F9F9F
9E9E9D9D9D9C9C9B9B9A9999989797969695949494939392
91908F8E8D8D8C8B8A8A8989888786858381818384848485
85868787898D9093
9798999A9C9D9E9FA1A2A3A4A5A7A8A9AAACADAEAFB0B1B2
B3B5B7B9BBBBBBBBBAB9B8B6B4B3B0AEACA9A7A6A5A3A2A1
A0A0A0A1A1A1A1A1A1A0A0A0A0A0A0A0A0A1A0A0A1A0A0A0
9F9F9E9E9D9D9C9C9B9A9998989797969695949494939392
918F8E8D8C8C8B8A8989888786848281807F7F8081818182
83858585888C8F93
97999A9B9C9E9FA0A2A3A4A6A7A8A9ABACAEAFB0B2B3B4B6
B7B9BBBCBEC0C1C1BFBEBCBAB8B5B3B0AEABA9A7A6A4A3A2
A1A1A1A1A2A2A2A2A2A1A1A1A1A1A1A1A1A1A1A1A1A1A0A0
A09F9E9E9D9D9C9B9B9A9998989797969695949493929291
90908D8C8B8B8A8988888684827F7E7D7D7C7C7D7E7E7F7F
81838285878B8F93
98999A9C9D9EA0A1A3A4A5A7A8AAABADAEAFB1B2B4B5B7B9
BABCBEC0C2C4C6C6C3C3C1BEBBB8B6B2B0ADAAA8A7A5A4A2
A2A2A2A2A2A3A3A3A3A3A2A2A2A2A2A2A3A3A3A2A2A2A1A1
A1A09F9F9E9D9D9C9B9A9999989797969694949392929190
908F8B8C8B8A89888684827F7D7B7A7A79787A7A7B7C7B7C
7F808183878B8E92
98999A9C9E9FA0A2A3A5A6A8A9ABADAEB0B1B3B5B6B8BABC
BEC0C1C4C6C8CBCAC9C7C5C3BFBBB8B4B2AEABA9A7A6A4A3
A3A3A3A3A3A3A4A4A4A4A3A3A3A3A3A4A4A4A4A3A3A3A2A2
A2A1A0A09F9E9D9C9C9A9A99989897969694949392919090
8F8D8B8B8A88878582807E7B79787676757578777879787A
7C7D8082868A8E92
98999B9D9E9FA1A3A4A6A8A9ABADAEB0B2B4B5B7B9BBBDBF
C1C3C5C7C9CCCECECFCDCAC8C3BEBAB6B3AFADAAA8A6A5A3
A3A3A3A3A4A4A4A5A5A5A4A4A5A5A5A5A5A5A5A5A4A4A3A3
A3A2A1A1A09F9E9D9C9B9A9999989796969594939291908F
8E8D8B8A888684807D7C7977757473727272757474767578
7A7B7E82868A8E92
989A9B9D9FA0A2A3A5A7A9AAACAEB0B2B4B6B8B9BBBDBFC2
C4C6C8CACDCFD1D2D3D3CFCDC8C2BCB8B4B0ADAAA8A7A5A4
A4A4A4A4A4A5A5A5A5A6A6A6A6A6A6A6A6A6A6A6A6A5A5A4
A4A3A3A2A1A09F9E9D9B9A9A999897969695949292918F8E
8D8B8A8885827E7C7978757372706F6F6F70717171727376
77797D8185898E92
989A9C9D9FA1A3A4A6A8AAACAEB0B2B3B6B8BABCBDC0C2C4
C7C9CBCDD0D2D5D6D8D8D5D1CDC7BFB9B4B1ADAAA8A7A5A4
A4A4A4A5A5A5A6A6A6A7A7A7A7A7A7A7A7A7A7A7A7A7A6A5
A5A4A3A2A1A1A09E9D9C9B9A999897969595939291908E8D
8B8987847F7C7A77757472706E6D6C6C6C6D6D6D6E6F7273
75787D8185898D92
989A9C9EA0A1A3A5A7A9ABADAFB1B3B5B7BABBBEC0C2C4C7
C9CCCED1D3D6D8D9DCDCDAD5D1CBC4BBB4B1ADAAA8A6A5A4
A4A4A5A5A6A6A6A7A7A8A8A8A8A8A8A8A8A8A8A8A8A8A7A7
A6A5A4A3A2A2A09F9E9C9B9A9998979695959392918F8D8B
8987837E7A78777371706E6D6C6B69696969696B6B6E7071
74787C8084898D92
989A9C9EA0A2A4A6A8AAACAEB1B3B5B7B9BBBDC0C2C4C7C9
CCCED1D4D6D9DBDDDFE0DED9D4CEC7BFB6B0ACA9A7A6A4A4
A4A5A5A5A6A6A7A7A8A9A9A9A9A9A9A9A9A9A9A9A9A9A9A8
A7A6A5A5A3A2A1A09E9D9B9A9A98979695949391908D8B89
86827D787674726F6D6C6B6A6968666666666668696C6E70
73787B7F84898D92
989A9C9EA0A3A5A7A9ABADB0B2B4B6B8BBBDBFC2C4C7C9CC
CFD1D4D6D9DCDFE1E2E4E1DCD8D1C9C2BAB1AAA8A5A4A4A3
A4A5A5A6A6A7A8A8A9A9AAAAAAAAABABABABABAAAAAAAAA9
A8A8A7A6A4A3A2A09F9D9C9B9A989795949391908E8C8885
817C777472706E6B6A696866656463626363646667696C6F
73777B7F84888D92
989A9D9FA1A3A5A8AAACAFB1B3B5B8BABCBFC1C4C6C9CCCE
D1D4D6D9DCDFE2E4E5E7E3DFDAD3CCC5BDB4AAA4A4A3A3A3
A4A4A5A6A7A7A8A9AAAAABABABACACACACACACACACABABAA
A9A9A8A7A5A4A3A19F9E9C9B9A9896959391908E8C88857F
7B7773716F6C6A6867666462616060606060626465676B6E
72767B7F84898D92
999B9D9FA2A4A6A8ABADB0B2B4B7B9BCBEC1C3C6C8CBCED1
D3D6D9DCDFE2E5E7E8E9E5E1DBD5CEC7BEB5ABA2A2A1A2A2
A3A4A5A6A7A8A9AAABABACACACADADADADADADADADACACAB
ABAAA9A8A6A5A3A19F9E9D9B99979593928F8E8B89837F7A
76726F6D6B6966646362615F5E5E5D5D5D5E60616366696D
72767B7F84898D92
999B9EA0A2A4A7A9ACAEB1B3B6B8BBBDC0C3C5C8CACDD0D3
D6D9DCDFE2E5E8EAECEBE7E3DDD6CFC8BFB6ACA3A0A0A1A2
A3A4A5A7A8A9AAABABACADADAEAEAEAEAEAEAEAEAEADADAC
ACABAAA9A7A5A3A19F9E9D9B98969492908D8A87837E7A76
726E6C6A68656362605F5E5C5B5B5A5A5B5C5E5F6265696D
72767A7F84888D92
999C9EA0A3A5A7AAADAFB2B4B7BABCBFC1C4C7CACCCFD2D5
D8DBDEE2E5E8EBEDEEEDE8E4DDD7D0C8C0B6ADA59D9EA0A1
A3A4A6A7A8A9ABACACADAEAEAFAFAFAFB0B0AFAFAFAFAEAD
ADACABAAA8A6A3A1A09F9D99979592908D8886827E7A7672
6E6B686764625F5E5C5B5A5958575758595A5C5E6165686D
72767A7F84888D92
999C9EA1A3A6A8ABAEB0B3B5B8BBBEC0C3C6C9CCCED1D4D7
DADEE1E4E7EBEDF0F0EEE9E4DED8D1C8BFB7AFA69B9D9FA1
A3A5A6A8A9AAACACADAEAFAFB0B0B0B0B1B1B1B1B0AFAFAE
AEADACABA9A6A3A1A19F9C989693908D8884817E7A76726F
6A676563615E5C5B595957565554545557585A5D6164686D
71767A7F84888D92
999C9EA1A3A6A9ACAEB1B4B6B9BCBFC2C5C8CBCDD0D3D6D9
DDE0E3E6EAEDF0F2F1EFEAE5DED8D1C8BFB8AFA69A9D9FA1
A3A5A6A8AAABACADAEAFB0B0B1B1B2B2B2B2B2B2B1B1B0AF
AFAEADABA9A6A3A2A19E9A9794918D88837F7C7976726E6B
6764625F5D5B595957555452515151535456595D6064686D
71767B7F84888D92
999C9FA2A4A7AAACAFB2B5B7BBBEC1C3C6C9CCCFD2D5D9DC
DFE2E5E9ECF0F2F4F2EFEBE5DFD8D0C7C0B9AFA59A9D9FA1
A3A5A7A9AAACADAEB0B0B1B2B2B2B3B3B3B3B3B3B2B2B1B0
B0AFADACA9A6A4A3A09C9995928D89847F7A7875726E6B68
64625E5C595857565452514F4E4E4F515255585C6064686C
71767B7F84888D92
999C9FA2A5A8AAADB0B3B6B9BCBFC2C5C8CBCED1D4D7DBDE
E1E4E8EBEEF2F5F5F3EFEBE5DED8CFC8C1B9AEA49A9C9FA1
A3A5A7A9ABACAEAFB0B1B2B3B3B4B4B4B4B3B4B3B3B2B2B1
B0AFAEACA9A6A5A29E9A97938E8985807A7673716E6B6865
625F5B5956555453514F4E4C4B4C4D4F5155585B5F63686C
71767B7F84888D92
999C9FA2A5A8ABAEB1B4B7BABDC0C3C6C9CCD0D3D6D9DDE0
E3E6EAEDF1F4F7F6F3F0EBE4DED7CFC8C0B7ADA49A9C9FA1
A3A6A8AAACADAFB0B1B2B3B4B4B4B5B5B4B4B4B4B4B3B2B2
B0AFAEACA9A7A4A19D9994908B86817B76726F6D6A686563
5F5C5855535251504E4D4B4949494B4D5054575B5F63686C
71767A7F84888D92
9A9DA0A3A6A9ABAFB2B5B8BBBEC1C4C8CBCED1D4D7DBDEE2
E5E8ECEFF3F6F8F6F4EFEAE3DDD6CEC7C0B6ACA3999C9EA1
A3A6A8AAACAEAFB1B2B3B4B5B5B6B6B6B5B5B5B5B4B4B3B2
B1B0AEABA9A7A39F9B96928D88827C77726E6B6866646361
5D595553514F4E4D4C4A48464647494C4F53575B5F63686C
71767A7F84888D92
9A9DA0A3A6A9ACAFB2B5B9BCBFC2C6C9CCCFD3D6D9DDE0E3
E7EAEEF1F5F8F9F7F3EFE9E2DCD4CEC7BFB5ABA2999C9EA1
A4A6A9ABADAFB0B2B3B4B5B6B6B7B7B6B6B6B6B5B5B4B3B3
B1AFADABA9A6A29D99948F8B847E78736F6B676463615F5E
5A5653504E4C4C4B494745434445484B4F52565A5F63686C
71767A7F84888D92
9A9DA0A3A7AAADB0B3B6BABDC0C4C7CACED1D4D7DBDEE2E5
E9ECF0F3F7F9F9F7F3EEE8E1DBD3CDC5BCB2A9A1989C9EA1
A4A7A9ABADAFB1B2B4B5B6B7B7B7B8B7B7B7B6B6B6B5B4B3
B1AFADAAA8A59F9B97928D88817973706C6864615F5D5C5B
5854514E4C494948464442404244474A4E51565A5F63676C
71767A7F84888D92
9A9DA0A4A7AAADB1B4B7BBBEC1C5C8CCCFD2D6D9DCE0E4E7
EBEEF2F5F9FAF9F7F2EDE6E0D9D2CBC2B9B0A8A0989B9EA1
A4A7A9ABADAFB1B2B4B5B7B7B8B8B8B8B8B7B7B6B6B5B4B3
B1AFACA9A7A39D9995908A837C75706D6965615D5B5A5958
5552504C4947474543403F3E404346494D51555A5E63676C
71767A7F84888D92
9A9DA1A4A7AAAEB1B5B8BCBFC2C6C9CDD0D4D7DBDEE2E5E9
EDF0F3F7FAFAF9F6F0EBE4DDD7D0C9BFB6AEA69E989B9FA2
A5A7AAACAEB0B1B3B4B6B7B8B9B9B9B9B8B8B8B7B6B5B4B3
B1AEABA8A6A19B97948D867E79726D6A67635F5A58565655
53514E4A46454442403E3D3C3F4345494D51555A5E63676C
71757A7F84888D92
9A9DA1A4A8ABAFB2B5B9BCC0C4C7CACED2D5D9DCDFE3E7EB
EEF2F5F9FBFAF8F4EFE9E2DBD5CDC6BBB3ABA39B999CA0A3
A6A8ABADAFB0B2B3B5B6B7B8B9B9BAB9B9B9B8B7B7B5B4B2
B1AEAAA6A39E9996918A827A766F6A6764605C5755535252
514F4D484443413F3D3C3B3B3F4245484C51555A5E63676C
71757A7F84888D92
9A9EA1A4A8ACAFB3B6BABDC1C5C8CCCFD3D6DADEE1E5E9EC
F0F3F7FAFBFAF7F3EDE7DFD9D1CBC1B7AFA79F9B9B9EA2A5
A7AAACAEAFB1B3B4B5B6B7B8B9B9BABABAB9B9B8B7B6B4B3
B0ADAAA59F9B96958F887F77736D6864625D595552504F4F
4F4E4A4642413E3C3B3A383A3E4044484C50555A5E63676C
71757A7F84888D92
9A9EA1A5A8ACB0B3B7BBBEC2C6C9CDD1D4D8DCDFE3E7EAEE
F2F5F8FBFCF9F6F1EBE4DDD6CEC7BCB3ABA29E9D9FA1A4A7
A9ABADAFB0B2B3B4B5B6B7B8B9B9BABABBBAB9B9B7B6B4B3
B0ADA9A39B9993928C857D746F6C65625F5B5753504E4C4D
4D4C4844413E3B3A3938373A3D3F43474C5055595E63676C
71757A7F83888D92
9A9EA1A5A9ACB0B4B8BBBFC3C7CBCED2D6D9DDE1E4E8ECF0
F3F7FAFBFBF8F4EFE8E1DAD2CBC2B7AFA69FA0A1A2A4A7A9
ABADAFB0B2B3B4B5B5B7B7B8B8B9BABABABBBAB9B8B7B5B3
B0ACA8A19996908E8A827A726C6964605D5955524E4C4A4A
4A4A47423F3C3938373636383B3F43474C5055595E63676C
71757A7F83888D92
9A9EA2A5A9ADB1B5B8BCC0C4C8CBCFD3D7DBDEE2E6EAEEF2
F5F8FBFBFAF7F2ECE6DED6CEC7BCB3AAA3A1A3A4A6A7A9AB
ADAFB0B1B3B4B4B5B5B6B7B7B8B8B9B9BABABABAB9B7B5B3
B0ACA6A097928F8A877F78706C67645F5B5854504D4A4847
474845403D393736353434373B3E43474B5055595E62676C
70757A7F83888D92
9A9EA2A6AAAEB2B5B9BDC1C5C9CDD0D4D8DCE0E3E7EBEFF3
F6F9FBFCF9F5F0EAE2DAD3CAC1B6AEA6A3A4A5A7A9AAACAE
AFB0B1B2B4B5B5B5B5B6B6B7B7B8B8B9B9BABABAB9B8B6B3
B0ACA69F958F8D87827E76706B65625E5A56534E4B484644
4444433F3B383633323233373A3E42464B5054595E62676C
70757A7F83888D92
9A9EA2A6AAAEB2B6BABEC2C6CACED1D5D9DDE1E5E9EDF1F5
F8FAFBFBF8F3EDE6DED6CFC5BBB1A8A5A6A7A8AAABADAFB0
B1B2B3B4B4B5B5B5B5B5B5B5B6B6B7B8B8B9B9B9B9B8B6B4
B0ABA69E958D89847F7A74706B65605D5956524D49464442
4141413D39363431303033363A3E42464B5054595D62676C
70757A7F83888D92
9A9EA2A6AAAFB2B6BBBFC3C6CACFD3D7DBDFE3E6EAEEF2F6
F9FAFBFAF6F0EAE3DAD2CABFB5ABA6A7A8A9ABADAEB0B1B2
B2B3B4B4B5B5B5B5B5B4B4B4B4B5B5B7B7B8B8B9B8B8B7B5
B1ACA69E958C85827E77736E6A645F5C5855504C47454240
3F3E3E3B3835322F2F2F32353A3D42464B4F54595D62676B
70757A7E83888D92
9B9FA2A7ABAFB3B7BBBFC4C7CCD0D4D8DCE0E4E8ECF0F4F8
FAFBFBF9F4EDE6DFD6CEC4BAB0A7A8A9AAABADAFB1B3B3B2
B3B3B4B4B5B5B5B5B4B3B2B2B2B3B4B5B6B7B8B8B8B7B6B5
B2ADA79F958B847F7B75716D68645F5B5754504B4644413E
3C3B3B3A3634312E2D2E3135393D41464B4F54585D62676B
70757A7E83888D92
9B9FA3A7ABAFB3B8BCC0C4C8CDD1D5D9DDE2E5EAEEF2F6F9
FBFBFBF7F1EAE2DBD1C8BEB4AAA6A8AAABADAFB2B3B4B3B1
B3B4B4B4B4B5B5B4B3B2B1B0B0B1B2B4B5B6B7B7B7B7B6B4
B2AEA89F968C847C79756F6C66625F5A56534F4A4642403C
3A38383835322F2C2B2E3135393C41464A4F54585D62676B
70757A7E83888D92
9B9FA3A7ACB0B4B8BDC1C5C9CED2D6DADFE3E7EBEFF3F8FA
FCFCF9F4EEE6DED6CDC3B8AEA7A8A9ABACAFB1B4B4B3B3B2
B3B4B4B4B5B5B4B3B1B1B0AFAEAFB0B2B4B5B6B7B6B6B5B3
B1AEA9A1988C847B78746E6A65605C5A56534E4A45413E3B
3836363633302D2B2A2D3034383C41454A4F53585D62666B
70757A7E83888D92
9B9FA3A7ACB0B4B9BDC1C6CACFD3D7DCE0E4E8EDF1F5F9FB
FCFBF7F2EBE2DAD1C7BCB2A8A7A8AAABADB0B2B4B4B3B2B2
B3B3B3B4B4B4B2B1B0B0AFAEADADAFB1B3B4B5B6B6B5B4B3
B1AEAAA39A8E847C76726E68655E5A5856514E4944403D3A
36343333322E2C29292C3034383C40454A4F53585D62666B
70757A7F83888D92
9B9FA3A8ACB1B5B9BEC2C7CBCFD4D8DDE1E6EAEEF3F7FAFC
FCF9F5EFE7DED5CBC1B6ABA7A8A8AAABADB0B0B3B3B1B1B1
B1B1B1B2B2B2B0AFAEACACACABACAEB0B2B4B4B5B5B5B4B2
B1AEABA59B90857D76716E68635E585654524D48443F3C38
34323130302D2B28282C3033373B40454A4E53585D62666B
70757A7E83888D92
9B9FA4A8ADB1B5BABEC3C7CCD0D5D9DEE3E7ECF0F4F8FBFD
FCF8F2EBE2DAD0C6BBB1A7A7A7A8AAABADAEAFB1B1B0B0B0
B0B0B0B1B0B0AFAEADACACACACADAEB0B2B3B4B4B5B4B3B2
B0AEABA69D92867E76716D69615D565351504B48443F3B37
32312E2E2E2B2926282B2F33363B4045494E53585D61666B
70757A7E83888D92
9B9FA4A8ADB1B6BABFC3C8CDD1D6DBDFE4E9EDF2F6FAFCFD
FBF6EFE7DFD5CBC0B6ABA5A6A7A8A9ABACADAEAFB0B0B1B1
B1B2B1B1B1B1B0AFAEADADADADAEAFB0B2B3B4B4B4B4B3B2
B0AEABA7A094887F77716C68615B55504F4D4A47433E3A36
322E2B2C2C2A2824272B2E32363B4045494E53585D61666B
70757A7E83888D92
9B9FA4A9ADB2B6BBBFC4C9CDD2D7DCE0E5EAEFF3F8FCFDFD
F9F3ECE3DAD0C6BCB1A6A5A6A6A7A9AAABADAEAFB0B0B1B2
B2B3B2B2B2B2B0AFAEADADADAEAEB0B1B2B3B3B4B4B4B3B2
B0AEABA7A1968B8078726C67615A554F4C4A4945423D3934
302C2A292A282623262A2E31363A3F44494E53585D61666B
70757A7E83888D92
9BA0A4A9ADB2B7BCC0C5CACED3D8DDE2E7EBF0F5FAFDFEFB
F7F0E8E0D6CCC1B7ADA3A4A5A5A7A8A9ABACADAFB0B1B1B2
B3B3B3B3B3B2B0AFAFAEADADAEAEAFB1B2B3B3B4B4B3B3B2
B0AEABA8A2998E8279726C66615A544E4A474543413C3933
2F2A28272726232325292D30353A3F44494E53585C61666B
70757A7E83888D92
9BA0A4A9AEB2B7BCC1C6CACFD4D9DEE3E8EDF2F7FBFDFDFA
F4EDE5DCD1C8BDB3A8A0A2A4A5A6A8A9AAACADAEB0B1B2B3
B4B4B4B3B3B2B1AFAEAEADADAEAEAFB1B2B3B3B4B4B3B3B1
B0AEABA8A39B8F847A736C66605B534D474443413F3B3731
2D2927242524212324282C30353A3F44494E53575C61666B
7075797E83888D92
9BA0A5A9AEB3B8BDC1C6CBD0D5DADFE4E9EEF3F8FDFEFCF8
F1E9E1D8CEC3B9AFA3A0A1A3A4A5A7A9AAACADAEB0B1B2B3
B4B4B5B4B3B2B0AFAEADADADADAEAFB1B2B2B3B4B4B3B3B1
B0AEACA8A39C92867C746C665F5A534D4443403D3D393631
2C2825222222202224282B30353A3F44494E53575C61666B
7075797E83888D92
9BA0A5AAAEB3B8BDC2C7CCD1D6DBE0E5EAEFF4FAFEFEFBF5
EEE6DDD4C9BFB6AB9F9FA0A2A3A5A6A8AAABADAEB0B2B3B2
B3B4B5B5B4B2B0B0AEADACACADAEAFB0B2B2B3B3B3B3B2B1
B0AEACA8A49E95887D746C655E59534B44403C3B3A383430
2B262220201F212124262A30353A3F44494E53575C61666B
70757A7E83888D92
9BA0A5AAAFB4B9BEC2C8CCD1D6DBE1E6EBF0F6FBFFFEF9F2
EBE2D9CFC5BCB2A69C9E9FA1A2A5A6A8AAABADAEAFB1B1B1
B3B4B5B5B3B1B0B0AEACACACADAEAFB0B1B2B3B3B3B3B2B1
B0AEACA8A49E978A7E746C645E57524B453C3A393737322F
2924201E1D1E202022252A2F353A3F44494E53575C61666B
70757A7E83888D91
9BA0A5AAAFB4B9BEC3C8CDD2D7DCE1E7ECF1F7FCFFFDF7F0
E7DED5CBC2B9ADA19B9D9FA1A2A4A6A8AAABACAEAFB0B1B1
B3B4B5B5B3B2B0B0AEACABACADAEAFB0B1B2B2B3B3B3B2B1
B0AEACA8A49F988B7F746B645E56514A433938353435312D
28231F1C1B1C1E1E20252A2F353A3F44494E53575C61666B
70757A7E83888D92
9BA0A5AAAFB4B9BEC4C9CED3D8DDE2E8EDF2F8FDFFFBF4ED
E3DBD2C8BFB5A99D9B9C9EA0A2A4A6A8A9ABACADAEB0B0B1
B3B4B5B5B4B2B1B0AEADACACADAEAFB0B1B2B2B3B3B2B2B1
B0AEACA8A49F998D80746C635D5550484138363332322F2B
27221D1A191B1B1D20252A2F353A3F44494E53575C61666B
70757A7E83888D92
9BA0A5AAAFB5BABFC4C9CED3D8DEE3E8EEF3F9FEFFF9F2E9
E0D7CEC5BCB1A5999B9C9EA0A2A4A6A8A9ABACADAEAFB0B1
B3B4B5B5B4B2B1B0AEACACACADAEAFB0B1B1B2B2B2B2B1B0
AFAEABA8A49F998F81756C635C554F4740383331302F2F2A
26201B171719191B20252B30353A3F44494E53585C61666B
70757A7E83888D92
9BA0A5ABB0B5BABFC4C9CFD4D9DEE4E9EFF4FAFFFDF6EFE5
DCD3CBC2B8ACA1979A9C9FA1A3A4A6A8A9ABACADAEAFB0B1
B3B4B5B5B4B2B1AFAEADACADAEAEAFB0B1B1B1B2B2B2B1B0
AFADABA8A49F989082766C635B544D463E36322F2D2D2E29
241E19161517171B20252B30353A3F44494E53585D61666B
70757A7E83888D92
9BA0A6ABB0B5BABFC5CACFD5DADFE4EAEFF5FAFFFBF4EBE1
D9D0C7BFB2A79C989B9D9FA1A3A5A6A8A9ABACADAEAFB0B1
B3B4B5B5B4B2B1AFAEADADAEAEAFAFB0B1B1B1B1B2B1B0AF
AEACAAA8A49E989083776C635B544B453D35302E2C2B2D28
231C18131315161B20252B30353A3F44494E53585D62666B
70757A7E83888D92
9CA1A6ABB0B5BBC0C5CAD0D5DAE0E5EBF0F6FBFEF9F1E7DE
D6CDC4BAAEA09A9A9C9EA0A2A4A6A7A8AAABACADAEAFB0B1
B2B4B5B5B4B2B1B0AFAEAEAEAEAFAFB0B0B1B1B1B1B0B0AF
ADACA9A7A49E979084776D635A534A433C342E2D2B2A2B27
221A16111113161B20262B30353A3F44494E53585D62676B
70757A7E83888D92
9BA1A6ABB0B6BBC0C6CBD0D6DBE0E6EBF1F6FDFCF6EEE3DB
D2C9C0B4A99C9C9C9E9FA1A3A5A7A8A9AAABABACADAEAFB0
B2B3B4B5B4B2B1B0AFAFAEAEAFB0B0B1B1B1B1B0B0AFAFAE
ADABA9A6A39E978F85796E635A524A423A332E2C2B292926
2018130F0F12161B21262B30353A3F44494E53585D62676B
70757A7F83888D92
9BA1A6ABB0B6BBC0C6CBD0D6DBE1E6ECF1F7FDF9F2EAE0D8
CFC5BBB0A49C9D9EA0A1A3A4A6A7A8A9AAABABACADAEAFB0
B1B3B4B5B5B3B2B1B0AFAFAFB0B0B1B1B1B0B0B0AFAFAEAD
ACAAA8A5A29E978F867A6E635A51494239312E2C2A282724
1E16110E0D11161B21262B30353A3F44494E53585D62676B
70757A7F83888D92
9CA1A6ABB1B6BBC1C6CBD1D6DCE1E7ECF2F7FCF6F0E7DDD4
CBC2B6ABA09E9FA0A1A3A4A6A7A8A9AAABABABACACADAEB0
B1B2B4B5B5B4B3B2B1B1B0B0B1B1B1B1B1B1B0AFAFAEADAC
ABA9A7A4A19D978F867B6F645950484139302E2B29272423
1B15100C0C11161B21262B30353A40454A4F53585D62676B
70757A7F83888D92
9CA1A6ABB1B6BCC1C7CCD1D7DCE2E7EDF3F8FAF3EDE4DBD1
C8BEB2A6A0A1A1A2A3A4A6A7A9AAAAABABABABABABACADAF
B0B1B3B5B6B5B4B3B2B2B1B1B2B2B2B2B1B1B0AFAEACACAB
A9A8A6A3A09C978F867C7064594F4840382F2D2B28262221
19130E0B0B11161C21262B30363B40454A4F54595D62676C
70757A7F83888D92
9CA1A6ACB1B6BCC1C7CCD2D7DDE2E8EEF3F9F7F1EAE0D8CF
C5B9AEA4A3A2A2A3A5A6A8A9AAABABACABABAAAAAAABACAD
AFB1B3B5B6B6B5B4B3B2B2B2B3B3B3B3B2B1B0AEACABAAA9
A8A6A5A29F9B968F867D7064594F473F372E2C2A27251E1F
17100C0A0B11161C21262C31363B40454A4F54595E62676C
71757A7F84888D92
9CA1A6ACB1B7BCC1C7CCD2D8DDE3E8EEF3FAF3EFE7DED6CC
C2B5ABA4A4A3A3A5A6A8AAABACACACACACAAA9A8A8A9ABAC
ADB0B2B5B7B7B6B5B4B3B3B3B4B5B5B4B2B1AFADABA9A9A8
A6A5A4A19E9B958F867D7164594E463E362E2B2926231B1C
150D0A090B11161C21272C31363B40454A4F54595E62676C
71757A7F84888D92
9CA1A7ACB1B7BCC2C7CDD2D8DDE3E9EEF3F9F1EDE4DCD3CA
BDB2A9A7A5A4A4A6A8AAACADAEAEAEADACAAA7A7A6A7A9AA
ACAFB2B5B7B7B7B6B5B5B4B5B5B6B6B5B3B0AEACAAA7A6A6
A5A3A2A09D9A958E867C7165594D453D352D2A282420181A
130B09080B11171C22272C31373C41464B4F54595E63676C
71767A7F84888D92
9CA1A7ACB1B7BCC2C7CDD2D8DEE3E9EFF5F7F1ECE2D9D0C7
B9AFA9A9A6A4A5A7AAACAEAFAEADAEADABA8A5A5A4A5A7A8
AAAEB1B5B7B8B7B7B6B8B6B5B5B6B7B6B2AFADABA8A5A4A4
A3A2A09F9C99948D857C7166594D443B342C2926221E1617
100908080C12171D22272D32373C41464B50555A5E63686C
71767A7F84888D92
9CA1A7ACB2B7BCC2C7CDD3D8DEE4E9EFF5F4F0EAE1D6CDC4
B8ACABA9A6A4A6A8ABAEB0AFACACAFADAAA6A4A2A2A2A4A6
A9ADB0B4B6B8B8B9B8B8B6B3B4B8B8B5B0AEABAAA7A3A2A1
A1A09F9D9B98938C847B7166594C433A322B27241F1B1415
0D0808070C12181D23282D32373C41464B50555A5F63686D
71767B7F84898D92
9CA1A7ACB2B7BDC2C8CDD3D9DEE4EAEFF3F3F0E8DFD3CAC1
B6ABABA9A6A5A6A9ACAFB0AFABABAEAAAAA3A29F9F9FA1A4
A7ACB0B3B6B8B9B9B9B7B7B4B5B9B5B5AFADA8AAA5A1A0A0
9F9E9E9C9A97928B837A7165574B4139302A26221C181213
0A0706070D13181E23282E33383D42474C50555A5F63686D
72767B7F84898D92
9CA1A7ACB2B7BDC2C8CDD3D9DFE5EBF1F2F3EEE6DDD2C8BE
B4ACACA9A6A5A6A9ACAEAFADAAABACA8A7A09F9C9C9D9FA3
A7ABAFB2B5B7B9B9B9B7B7B5B5B8B4B4ADABA7A7A29F9E9E
9D9D9C9B9995918A82797064564B40372E29241F1A151010
090605080E14191E24292E33383D42474C51565B5F64696D
72767B8084898D92
9CA1A7ACB2B7BDC2C8CED3D9DFE5EBF2F1F1EDE5DAD0C7BC
B3ADABA8A5A4A5A7A9ABACAAA9A9A7A4A29E9C9B9B9C9FA2
A6AAAEB1B4B6B8B9B8B8B6B5B4B4B1AFACA9A6A2A09E9E9D
9D9C9C9A98948F8880786E63554A40352C26221D17130F0E
080504090F141A1F252A2F34393E43484D51565B6064696E
72777B8084898D92
9CA1A7ACB2B7BDC2C8CED3D9DFE5EBF1F2F0ECE2D8CFC6BB
B2ADAAA7A4A2A4A5A7A8A9A8A7A6A4A29F9D9C9A9B9C9FA3
A6AAADB0B3B5B7B8B8B8B6B4B2B1AFADAAA7A4A1A09F9F9E
9D9C9B9996938E877F766D6154493E342A24211B14100D0D
0703050A10151B20252B30353A3F44484D52575B6065696E
72777B8084898E92
9CA1A7ACB2B7BDC2C8CED4DADFE5EBF0F6F0E9E0D6CDC5BA
B2ADA9A6A2A1A2A3A4A5A6A6A6A5A4A2A09E9C9A9B9DA0A3
A6AAACAFB2B4B6B8B8B8B6B4B1AFADABA9A7A5A3A2A1A09F
9E9D9A9895928C857E756B6053473D3228221F19120E0B0B
0503060C11161C21262B31363B3F44494E53575C60656A6E
73777C8085898E92
9CA1A7ACB1B7BCC2C8CED4DADFE6EBF0F7EEE7DDD4CBC4B9
B2ACA8A5A19FA0A1A2A3A4A5A5A5A4A19E9B9A9A9C9EA1A4
A7AAACAFB1B3B5B6B7B7B5B3B0AEACABA9A8A6A5A3A2A1A0
9F9C9A9895908B857D746A5E52463A2F27211C17100D0A09
0503070D12181D22272C31363B40454A4E53585C61656A6E
73777C8085898E92
9CA1A6ACB1B7BCC2C8CDD3DAE0E6EDEFF5ECE4DBD3CAC2B9
B2ACA7A39F9D9EA1A1A2A3A3A4A39F9D9C9A9B9C9D9FA2A5
A7AAACAEB0B2B3B5B5B5B4B2B0AEACABAAA9A7A6A5A4A2A0
9E9B9997948F89837B73685C5145382D251F1A150E0C0A07
0303090E13191E23282D32373C41464A4F54585D61666A6F
73787C8185898E92
9CA1A6ACB1B6BCC2C7CDD3D9DFE6EEF0F2E9E1D9D2C9C2B9
B2ACA6A19D9B9C9E9FA0A1A1A09E9C9C9C9C9D9E9FA1A3A6
A8AAACAEAFB1B2B3B4B4B3B1B0AEACAAAAA9A7A6A5A2A19F
9D9B9996938E88827A72665B5043362A231E18130D0A0905
01040A0F151A1F24292E33383D42474B5054595D62666B6F
74787C8185898E92
9CA1A6ABB1B6BCC1C7CDD3D9DFE6EEF0EDE6DED8D1C9C1B9
B2ABA5A09B999B9C9D9E9E9E9D9C9C9D9D9E9E9FA1A2A4A6
A8AAABADAFB0B1B2B2B2B2B1AFAEADABABA9A7A6A4A2A19F
9D9B9996928C87817970665A4E403326221C15120D090803
00060B11161B20252B2F34393E43474C51555A5E63676B70
74787D81858A8E92
9CA1A6ABB1B6BBC1C6CCD2D8DFE5EDF0EAE3DCD7D1C9C1B9
B2ABA49F9A98999A9B9C9C9D9D9D9D9E9E9FA0A1A2A4A5A7
A9AAACADAFB0B1B1B2B2B1B1AFAFADACABA9A8A7A5A3A2A0
9D9B9895918B8680786F64584B3E3123201A13110C070701
01070D12171D22272C31353A3F44484D51565A5F63676C70
74797D81858A8E92
9CA1A6ABB0B5BBC0C5CBD1D7DDE4EBEFE8E2DBD6D0C8C1B9
B2AAA39E999798999A9B9B9C9C9D9E9E9FA0A1A2A3A5A6A8
A9ABACADAEAFB0B1B1B1B1B0AFAFAEADABAAA9A7A6A4A2A0
9E9B9895908A857F776E62564A3C2E211E1812100C060500
03090E14191E23282D32373B4045494E52575B5F64686C71
75797D81868A8E92
9BA0A5ABB0B5BABFC5CAD0D6DCE2E9EEE7E1DBD5CFC8C1B9
B1AAA29D99969798999A9B9C9C9D9E9FA0A1A2A3A4A5A7A8
AAABACADAEAFB0B0B0B0B0B0B0AFAEADACAAA9A8A6A4A2A0
9E9B98948F8A847E766C6055483A2B1F1A16110F0B060200
050B10151B20252A2E33383D41464A4F53575C6064696D71
75797E82868A8E92
9BA0A5AAAFB4B9BEC4C9CFD4DAE0E6EDE7E1DAD4CEC8C0B9
B1AAA29D9996969798999A9B9C9D9EA0A1A1A3A4A5A6A8A9
AAABADADAEAFAFB0B0B0B0B0AFAFAEADACAAA9A8A6A4A2A0
9E9A97938E89837C746A5F534537291D18150F0D09050002
070D12171C21262B3034393E42474B5054585D6165696D72
767A7E82868A8E92
9BA0A5AAAFB3B8BDC3C8CDD3D8DEE4EBE6E0D9D4CEC7C0B9
B1A9A29D9996969698999A9B9D9E9FA0A1A2A3A5A6A7A8A9
ABACADADAEAFAFB0B0B0B0B0AFAEAEADACAAA9A8A6A4A2A0
9D9A97928D88827B72685D504234261C16130D0A07040004
0A0F14191E23282D31363A3F43484C5155595D62666A6E72
767A7E82868A8E92
9BA0A5A9AEB3B8BCC1C7CCD1D6DCE2E9E4DFDAD4CEC7C0B8
B1A9A29D9997969697999A9C9D9E9FA1A2A3A4A6A7A8A9AA
ABACADADAEAFAFAFB0B0B0AFAFAEADADABAAA9A7A6A3A19F
9D9996928D87807970665B4D3F32231B15100B0805030207
0C11161B20252A2E33373C4045494D52565A5E62666B6F73
777B7F83878B8F92
9BA0A4A9ADB2B7BBC0C5CACFD4D9DFE5E4E0DBD4CEC7C0B8
B1A9A29D9A97969798999B9C9D9FA0A2A3A4A5A7A8A9A9AB
ACACADAEAEAFAFAFB0B0AFAFAEAEADACABAAA9A7A5A3A19E
9C9895918C857F776E64584A3C2F201A140F08060402050A
0F14181D22272B3034393D42464A4E53575B5F63676B6F73
777B7F83878B8F93
9B9FA4A8ADB1B6BABFC4C8CDD2D7DCE0E5E0DBD4CEC7C0B8
B1A9A29E9A989797989A9B9D9E9FA1A2A3A5A6A7A8A9AAAB
ACADADAEAEAFAFAFB0AFAFAFAEADADACAAAAA8A7A4A2A09E
9B98948F8A847D766C615547392C1E19130D06040303080D
11161B1F24292D32363A3F43474C5054585C6064686C7074
787C7F83878B8F93
9B9FA3A8ACB0B5B9BDC2C6CBD0D4D9DDE2E0DBD4CEC7C0B9
B1AAA39F9B999898999B9C9E9FA0A2A3A4A5A7A8A9AAABAC
ACADAEAEAEAFAFAFAFAFAFAEAEADACABAAA9A8A6A4A19F9D
9A97938E88827B73695E514436291C17120B050303060B0F
14181D22262B2F33383C4045494D5155595D6165696D7074
787C8084878B8F93
9B9FA3A7ABAFB4B8BCC0C5C9CDD1D6DADEE0DBD4CEC8C1BA
B2AAA49F9C9A999A9A9C9D9EA0A1A3A4A5A7A8A9AAABACAC
ADAEAEAEAFAFAFAFAFAFAFAEADADACABAAA8A7A5A3A09E9C
9995918C86807970655A4E4134271A151009050304090D12
161B1F24282D31353A3E42464A4E52565A5E62666A6D7175
797C8084888B8F93
9A9EA2A6AAAEB3B7BBBFC3C7CBCFD3D6DADEDAD5CFC9C2BB
B3ACA5A09D9B9A9B9C9D9E9FA1A2A4A5A6A8A9AAABACACAD
AEAEAFAFAFAFAFAFAFAFAEAEADACABAAA9A7A6A4A29F9D9A
97948F8A847D766D62574B3E322518130F090504060B1014
191D22262A2F33373B3F44484C4F53575B5F63676A6E7276
797D8184888C8F93
9A9EA2A6AAAEB1B5B9BDC1C5C8CCD0D3D6D9D8D5D0CAC4BD
B5ADA7A29E9C9C9C9D9E9FA1A2A3A5A6A7A9AAABACADADAE
AEAFAFAFB0B0AFAFAFAFAEADACABAAA9A8A6A5A3A09E9C99
96928D88827A72695E53473B2F2216130E080505090E1217
1B2024282D3135393D4145494D5155595C6064686B6F7376
7A7D8185888C8F93
9A9EA2A5A9ADB0B4B8BCBFC3C6CACDD0D3D4D6D5D3CDC6BF
B7AFA9A3A09E9D9E9F9FA1A2A3A5A6A7A8AAABACADADAEAF
AFB0B0B0B0B0AFAFAFAFAEADACABAAA9A7A5A3A19F9D9A97
948F8B857E766E655B5044382B1E16130D0806070C10151A
1E22262B2F33373B3F43474B4F52565A5E6165696C707377
7A7E8185888C8F93
9A9EA1A5A8ACAFB3B6BABDC1C4C7CACDD0D2D3D5D6D1C9C1
B9B1ABA5A2A09FA0A0A1A2A3A5A6A7A8AAABACADAEAEAFB0
B0B0B1B1B0B0B0AFAFAEADACABAAA9A8A6A4A2A09E9B9895
928D88827A726A61574C4034261C18130C08070A0F13181C
2125292D3135393D4145494C5054575B5F6266696D717478
7B7E8285898C9093
9A9DA1A4A8ABAEB2B5B8BCBFC2C5C8CBCDCFD1D3D6D4CAC2
BBB3ADA8A4A2A1A1A2A3A4A5A6A7A9AAABACADAEAFAFB0B1
B1B1B1B1B1B0B0AFAEAEADABAAA9A8A7A5A3A19F9C9A9693
8F8A847E766E655C53483C2F241D18120C09090D12161B1F
23272C3034373B3F43474A4E5255595C6063676B6E717578
7C7F8286898C9093
9A9DA0A4A7AAADB1B4B7BABDC0C3C6C8CBCDD0D2D6D5CCC4
BDB5AFAAA6A4A3A3A3A4A5A6A7A8AAABACADAEAFB0B1B1B2
B2B2B2B2B1B0AFAFAEADACABAAA8A7A5A3A19F9D9A979390
8C87817A726A61584F43372D231D17120D0C0C11151A1E22
262A2E32363A3D4145494C5053575A5E6165686C6F727679
7C808386898D9093
9A9DA0A3A6A9ACAFB3B6B8BBBEC1C4C6C9CBCED1D5D3CFC6
BFB8B2ACA9A6A5A5A5A6A7A7A9AAACADAEAFAFB0B1B2B2B3
B3B3B3B2B1B0AFAFAEADACAAA9A7A6A4A2A09D9B9895918D
88827D766E655D544A40332C231D16130F0E1015191D2125
292D3135383C4043474A4E5155585C5F6266696D7073767A
7D8083868A8D9093
999C9FA3A6A8ABAEB1B4B7BABCBFC2C4C7C9CCCED2D1D1C8
C0BAB4AFABA8A7A7A7A7A8A9AAACADAEAFB0B1B1B2B3B3B4
B4B4B3B2B1B0AFAFAEACABAAA8A6A4A2A09E9B9895918D89
847E78716961584F463B312B231C1614111115181D202428
2C3034373B3E4245494C5053575A5D6164676B6E7174777A
7E8184878A8D9093
999C9FA2A5A8ABADB0B3B6B8BBBDC0C2C5C7C9CCCFD1D0C9
C2BCB7B2AEABA9A8A9A9AAAAACADAEB0B1B2B2B3B3B4B4B4
B4B4B4B3B1B0AFAEADABAAA9A7A5A3A09E9B9895928E8985
807A746D645C544B4238302A221D18151415191C2024282B
2F33363A3D4144484B4E5255585B5F6265686C6F7275787B
7E8184878A8D9093
999C9FA1A4A7AAACAFB2B4B7B9BBBEC0C2C5C7C9CBCDCDCA
C4BFBAB4B1AEABAAAAAAABACADAFB0B1B2B3B3B4B4B4B5B4
B4B4B4B2B1AFAEADACAAA9A7A5A3A09E9B9895928E8A8681
7B756F68605851483F362F29221D191716191D2024272B2F
3236393C4043474A4D5054575A5D606366696D707376797C
7F8285888B8E9193
999C9EA1A4A6A9ABAEB0B3B5B7BABCBEC0C3C5C7C8CACBC9
C7C2BDB7B3B1ADACABABACAEAFB1B2B3B4B4B4B4B4B4B5B4
B4B4B3B2B0AEADACAAA8A7A5A2A09D9B9895928E8B86817C
77716B645C554D453C342E28221E1C191A1D2124282B2E32
35393C3F4246494C4F5256595C5F6265686B6E7174777A7D
7F8285888B8E9194
999B9EA0A3A5A8AAADAFB1B4B6B8BABCBEC0C2C4C6C7C8C8
C9C5C0BAB6B2AFAEADAEAEB0B1B3B4B4B5B5B5B4B4B4B4B4
B4B3B2B0AFADACA9A8A7A5A3A09D9B9995928E8B88827D78
736C6660595149423A332D2824211D1B1E2225282B2F3235
383B3F4245484B4E5155585B5E616366696C6F7275787B7D
808386898B8E9194
999B9EA0A2A5A7A9ACAEB0B2B4B7B9BBBCBEC0C2C3C5C6C7
C8C7C2BEB9B5B2B1AFAFB0B1B3B4B4B5B5B5B5B4B4B4B3B3
B3B2B1AFADACAAA8A6A5A2A09E9B9A96938F8B88847E7974
6E68625C554D463F38322D2A26221E1F2326292C2F323538
3B3E4245484B4E5154575A5C5F6265686B6E707376797B7E
818486898C8E9194
999B9D9FA2A4A6A8ABADAFB1B3B5B7B9BBBCBEC0C1C2C3C5
C6C7C5C1BCB7B5B2B1B1B2B3B5B5B5B6B5B5B5B4B4B3B2B2
B1B0AFADABAAA8A5A4A2A09E9C9A9793918C88847F7A756F
69635E57504A423D3733302B27232024272A2D303336393B
3E4144474A4D505356595C5E616467696C6F7274777A7C7F
828487898C8F9194
999B9D9FA1A3A6A8AAACAEB0B2B3B5B7B9BABCBEBFC0C2C3
C4C5C7C4BFBAB8B5B2B2B3B4B6B6B6B6B5B4B4B4B3B1B1B0
AFAEACABAAA7A6A3A19F9E9C9A9794918D8884807B76716B
655F59534D47413D3835312A282224282B2E313336393C3F
4245474A4D505355585B5E606365686B6E707375787B7D80
8285878A8C8F9194
989B9D9FA1A3A5A7A9ABADAEB0B2B4B5B7B9BABCBDBEC0C1
C2C3C5C6C1BCBAB6B4B3B4B5B7B7B6B5B4B4B4B3B1B0B0AE
ADACAAA9A7A5A4A29F9D9B999794918E8985817C77726D67
615B56514C46423E3A352F2B2726292C2F3234373A3D3F42
45484A4D505255585A5D606265676A6C6F727477797C7E81
8385888A8D8F9294
989A9C9EA0A2A4A6A8AAABADAFB1B2B4B5B7B8BABBBCBEBF
C0C2C3C5C3C0BCB8B6B5B4B5B7B8B6B5B3B3B3B2AFAFAEAC
ABA9A9A5A4A3A1A09C9B989694918E8A87827D78736E6863
5E58534F4A46433F3A342F2A282B2E303336383B3E404345
484B4D505255585A5D5F626467696B6E707375787A7D7F81
8486888B8D8F9294
989A9C9EA0A2A3A5A7A9AAACAEAFB1B2B4B5B7B8B9BBBCBD
BEC0C1C2C3C3BEBAB8B6B4B5B7B8B6B4B3B1B1B0AFADACAA
A8A6A6A2A1A09F9D99989593918E8A87837F7A75706A6560
5B57534F4C49433E39332F2A2D303235373A3C3F41444649
4B4E505355585A5D5F616466686B6D70727477797B7E8082
8487898B8D909294
989A9C9D9FA1A3A4A6A8A9ABACAEAFB1B2B4B5B6B7B9BABB
BCBDBFC0C1C3C1BCB9B6B5B5B6B7B5B2B1B0AFAEADABA9A8
A5A4A2A09E9C9B9A969592908E8B87847F7C77726C67635E
5A56544F4D49413C37332E2E323437393B3E404245474A4C
4E515356585A5D5F616366686A6D6F717376787A7C7F8183
8587898C8E909294
989A9B9D9FA0A2A4A5A7A8AAABADAEAFB1B2B3B5B6B7B8B9
BABBBCBEBFC0C1BEBBB8B6B4B4B4B5B2B0AFAEACABA9A7A5
A3A19F9D9B98979694928F8E8B8784817D79746F6B67635E
5B5755504C463F3B3732323436393B3D40424446484B4D4F
525456585B5D5F616366686A6C6E70737577797B7D808284
86888A8C8E909294
989A9B9D9EA0A1A3A4A6A7A9AAABADAEAFB0B2B3B4B5B6B7
B8B9BABBBCBEBFBFBCB9B6B4B3B2B2B1AEACABAAA8A7A4A2
A09E9C9A97959392908F8D8C8884827E7B77736F6B686560
5C59544F4A443F3A363537393B3E40424446484A4C4E5153
5557595B5D5F626466686A6C6E70727476787B7D7F818385
87898B8D8F919294
98999B9C9E9FA1A2A3A5A6A8A9AAABADAEAFB0B1B2B3B4B5
B6B7B8B9BABBBCBDBCBAB6B4B2B0AFAEADAAA9A7A5A4A19F
9D9B99979392908F8D8C8C898683807D7A7774706D6A6561
5C57524C47443F3A393B3D3F40434546484A4C4E50525456
585A5C5E60626466686A6C6E70727476787A7C7E80828485
87898B8D8F919395
98999B9C9D9FA0A1A3A4A5A7A8A9AAABACADAFB0B1B2B2B3
B4B5B6B7B7B8B9B9BAB9B7B4B2AFACACABA8A6A4A2A09E9C
9B999594918F8E8E8C8B8A898583817E7C7975716E696460
5B55504A47443F3D3F4142444647494B4C4E50525355575A
5B5D5F61636567686A6C6E7072747677797B7D7F81838486
888A8C8D8F919395
98999A9C9D9E9FA1A2A3A4A6A7A8A9AAABACADAEAFB0B1B2
B2B3B4B4B5B5B6B7B7B6B6B5B2AEABA9A8A7A3A19F9D9B9A
989692918F8E8D8D8C8A8A88868583807D7975716D68635E
59544F4B46454344454647494A4C4D4F5152545557595B5D
5F6062646567696B6D6E7072747577797B7D7E8082848587
898B8C8E90919395
98999A9B9D9E9FA0A1A2A3A5A6A7A8A9AAABABACADAEAFB0
B0B1B2B2B3B3B3B4B4B4B3B4B0AFABA7A6A4A19F9E9B9A98
96959392918F8E8E8C8B8B898786837F7D78746F6B66615C
59544F4B494A494A4B4B4D4E4F515253555658595B5C5E60
62636567686A6C6D6F7172747677797B7C7E808283858688
8A8B8D8E90929395
98999A9B9C9D9E9FA0A2A3A4A5A6A7A7A8A9AAABACADADAE
AFAFB0B0B0B1B1B1B1B1B1B0AFAEABA7A4A2A09E9D9B9997
9694939291908F8F8E8C8B8A8785827E7B76736D6865615D
5954514F4F4F4F4F5051525354555658595A5C5D5F606263
656668696B6C6E707173747678797B7C7E7F818384868789
8A8C8D8F90929395
97999A9B9C9D9E9FA0A1A2A3A4A4A5A6A7A8A9A9AAABACAC
ADADAEAEAEAFAFAFAFAEAEADACABAAA6A5A29F9D9B9A9897
95949292919190908E8C8A898784807C7974716B6865615D
5A5756555555545555565758595A5B5C5D5E606162636566
68696B6C6D6F717274757778797B7D7E7F8182848687888A
8B8C8E8F91929495
9798999A9B9C9D9E9FA0A1A2A3A3A4A5A6A7A7A8A9A9AAAA
ABABACACACACADADACACABABAAA8A7A5A4A09E9D9B999896
959492929190908F8D8B8A8785837E7A7874706C68666260
5F5D5C5B5A5A5A5A5A5B5C5C5D5E5F60616263656667686A
6B6C6D6F707273757677797A7B7D7E80818284858788898B
8C8D8E9091929495
9798999A9B9C9D9E9E9FA0A1A2A2A3A4A5A5A6A6A7A8A8A9
A9AAAAAAAAAAABAAAAAAA9A9A8A7A5A4A2A09E9E9B9A9895
9493929190908F8E8D8B888684827E7B7874706C6A686765
63626160605F5F5F5F6060616262636465666768696B6C6D
6E6F717273757677787A7B7C7D7F80818284858788898A8B
8D8E8F9092939495
9798999A9B9B9C9D9E9E9FA0A1A1A2A3A3A4A5A5A6A6A7A7
A8A8A8A8A8A9A9A8A8A8A7A7A6A5A4A2A1A09E9D9B9A9795
9492919190908F8E8D8A888684827F7B787572706E6C6B6A
68676665656464646465656566676768696A6B6C6D6E6F70
71727475767778797B7C7D7E7F81828384858788898A8B8C
8D8E909192939495
979899999A9B9C9C9D9E9E9FA0A0A1A2A2A3A3A4A5A5A5A6
A6A6A6A7A7A7A7A7A6A6A5A5A4A3A2A1A09F9D9C9A999795
9493929190908F8E8C8A888684827F7D7A78767472706F6E
6D6C6B6A696969696969696A6A6B6B6C6D6E6F7071717273
75757678797A7B7C7D7E7F8081838485868688898A8B8C8D
8E8F909192939495
979898999A9A9B9C9C9D9E9E9F9FA0A0A1A2A2A2A3A3A4A4
A4A5A5A5A5A5A5A5A4A4A4A3A3A2A1A09F9D9C9B9A999796
9493929291908F8E8C8B89888683817F7D7B797775747372
71706F6E6E6D6D6D6D6E6E6E6E6F70707172737374757677
7879797A7B7C7D7E7F808182838585868788898A8B8C8D8E
8F90919292949595
97989899999A9B9B9C9C9D9D9E9E9F9FA0A0A1A1A2A2A2A3
A3A3A3A3A3A3A3A3A3A3A2A2A1A09F9E9E9D9C9B9A989796
9594939291908F8E8D8C8A8987858381807E7C7A79787776
75747473727272727272727273737474757676777878797A
7B7C7C7D7E7F8081828383848586878889898A8B8D8D8E8F
9090919293949596
97979899999A9A9B9B9C9C9D9D9D9E9E9F9FA0A0A0A0A1A1
A1A2A2A2A2A2A2A1A1A1A1A09F9F9E9D9D9C9B9A99989796
959493929291908F8E8D8B8A8987858482817F7E7D7C7A7A
7978787776767676767676777777787879797A7A7B7C7C7D
7E7F7F8081818283848586878788898A8A8B8C8C8E8E8F90
9091929393949596
9797989899999A9A9B9B9B9C9C9D9D9D9E9E9E9F9F9F9FA0
A0A0A0A0A0A0A0A0A0A09F9F9E9E9D9D9C9B9A9A99989796
95949493929191908F8E8D8B8A89878685848281807F7E7D
7D7C7C7B7B7B7A7A7A7A7B7B7B7B7C7C7D7D7D7E7E7F8080
818282838484858686878889898A8B8B8C8C8D8E8E8F9091
9192929394959596
979798989899999A9A9A9B9B9B9C9C9C9D9D9D9D9E9E9E9F
9F9F9F9F9F9F9F9E9E9E9E9D9D9D9C9C9B9A9A9998989796
9595949392929191908F8E8D8C8B8A888886858483838281
8180807F7F7F7F7E7F7F7F7F7F7F80808081818282828383
848585868687878889898A8B8B8C8C8D8D8E8E8F8F909191
9292939494959596
9797979898989999999A9A9A9A9B9B9B9C9C9C9C9C9D9D9D
9D9D9D9D9D9D9D9D9D9D9C9C9C9C9B9B9A9A999898979796
969594949393929190908F8E8E8D8C8B8A89888787868585
848484838382838283838383838384848484858585868687
8788888889898A8A8B8C8C8D8D8D8E8E8F8F909091919292
9393949495959596
9797979798989898999999999A9A9A9A9A9B9B9B9B9B9C9C
9C9C9C9C9C9C9C9C9C9B9B9B9B9B9A9A9999989897979796
9695959494939392929191908F8F8E8D8C8C8B8A8A898988
888887878787878787878787878787878888888889898A8A
8A8B8B8B8C8C8C8D8D8E8E8F8F8F90909191919192929393
9394949595959696
97979797979898989898999999999999999A9A9A9A9A9A9A
9A9A9A9A9A9A9A9A9A9A9A9A9A9999999998989897979796
9696959594949493939292929191908F8F8E8E8D8D8D8C8C
8C8B8B8B8B8B8B8B8B8B8B8B8B8B8B8B8B8B8C8C8C8C8D8D
8D8D8E8E8E8F8F8F90909090919191929292929393939494
9494959595959696
979797979797979798989898989898989898989999999999
999999999999999999999999999998989897979797979796
96969695959594949494949393939292919191919090908F
8F8F8F8F8F8F8E8F8F8F8E8F8F8F8F8F8F8F8F8F90909090
909091919191919292929292939393949394949494949595
9595959696969696
969797979797979797979797979797979797979898989898
989898989898989898989898989797979797979797969796
969696969696959595959595959594949493949493939393
939393939392929393939293939393939393939393939393
939393949494949494949494949495959595959595959595
9696969696969696
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.678571 0.015625 0.97619 0.313244 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00751202 0.0192308 0.00751202 [
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(300) show
81.000000 12.812500 moveto
(deg) show
99.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(.) show
105.000000 12.812500 moveto
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
128 string
128 128 8 [128 0 0 128 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
B0B0B0B0B0B0B0B0B0B0B0B0AFAFAFAFB0B0B0B0B0B0B1B2
B0B1B1B2B2B2B3B3B3B3B4B4B4B4B4B4B4B4B4B4B4B4B4B4
B4B4B4B4B4B4B4B4B4B4B4B4B4B4B4B3B3B4B3B3B3B3B3B4
B4B4B4B4B4B4B4B4B4B4B4B4B4B4B4B3B3B3B3B3B3B3B3B3
B3B3B3B3B3B3B3B3B2B3B2B2B2B2B2B1B1B0B0AFAFAFAEAE
AEAFAFAFAFAFAFB0
B0B0B0B1B0B0B0B0B0B0AFAFAEAEAFAFB0B0B0B1B1B2B2B2
B0B2B3B3B4B5B6B6B7B7B8B8B8B8B9B9B9B9B9B9B9B9B8B8
B7B7B8B8B8B8B8B8B8B8B8B8B8B8B7B7B7B7B7B7B7B7B7B7
B7B7B7B7B8B8B8B8B8B8B8B8B9B8B7B7B7B6B7B6B6B6B6B6
B6B6B6B5B5B6B5B5B5B5B5B5B4B4B3B3B2B1B0AEAEADADAC
ACAEAFAEAEAEAFB0
B0B0B0B0B0B0B0B0B0B0AFAFAEAEAEAFAFB0B0B1B2B2B2B1
B2B4B4B5B6B8B8B9BABBBCBCBCBDBDBEBEBDBDBDBDBCBCBB
BBBBBBBBBBBBBBBCBCBCBCBCBBBBBBBABABABABABABBBBBB
BBBBBBBBBBBBBBBBBCBCBCBCBDBCBAB7B9BABABAB9B8B9B9
B9B9B9B9B8B8B8B8B8B7B7B6B6B6B5B4B3B2B0AEADACACAC
ADADADADADAEAEAF
B0B0B0B0B0B0B0B0B0B0B0B0AFAEADAEAFB0B0B1B2B2B3B3
B2B3B5B7B8B9BBBCBEBFC0C0C1C1C2C2C2C2C2C1C1BFBFBE
BEBDBDBEBEBEBEBFBFBFBFBFBFBFBEBEBEBEBEBEBEBFBFBF
BFBFBFBFBFBFBFBFBFC0C0C0C0C0BFBDBCBCBDBCBCBCBCBB
BCBCBBBBBBBBBBBBBABAB9B9B8B8B7B6B4B2B0AEACACACAC
ADADADACACADAEAF
B0B0B0B0B1B1B1B1B1B1B1B0B0AFAFAEAEAFB0B1B1B2B3B3
B4B5B6B8BABCBEBFC1C2C4C5C6C6C6C6C6C6C6C6C4C3C2C1
C0C0BFC0C0C1C1C2C2C2C2C2C2C2C2C2C3C3C3C3C3C3C3C3
C3C3C3C3C3C3C3C3C3C3C4C3C3C3C3C2C1C0BFC0BFBFBFBF
BFBFBFBEBEBEBEBDBDBDBCBBBBBAB9B7B5B3B1AEADADADAD
ADACACABABABADAE
B0B0B0B1B1B1B1B1B2B2B2B2B1B0B0B0AFAFB0B1B2B2B3B5
B6B6B7BABCBEC0C2C5C6C8C9CACBCCCCCCCBCAC9C8C7C6C4
C3C3C2C2C2C3C4C4C4C4C5C5C5C5C5C6C6C6C6C7C8C8C8C8
C8C8C8C8C8C8C8C8C8C8C8C8C7C7C7C6C6C4C2C3C3C3C3C3
C3C3C3C2C2C1C1C1C0BFBFBEBDBCBBBAB8B5B2B0B0B0AFAF
AEACACAAA9ABADAE
B0B0B0B1B1B1B2B2B2B2B3B2B2B2B2B2B1B1B1B1B2B3B4B5
B7B8BABCBFC2C4C6C8CBCDCECFD0D0D1D0CFCECDCCCAC9C8
C7C6C5C5C5C5C6C6C6C7C7C8C8C9C9C9C9CACACBCCCCCCCC
CCCDCDCCCCCCCCCCCCCCCCCCCBCBCBCACAC9C7C6C6C7C8C8
C8C7C7C6C6C5C5C4C3C3C2C1C0BFBDBBB9B6B2B2B1B1AFAE
ADACABA9A9ABADAE
B0B0B1B1B2B2B2B3B3B3B4B4B4B4B4B4B4B4B4B3B4B5B6B7
B9BBBDBFC3C5C8CACDCFD1D3D4D5D5D4D3D2D1D0CFCECDCB
CAC9C9C8C8C8C8C8C9C9C9C9CACBCBCCCDCDCECFCFD0D0D0
D0D1D1D1D1D1D1D0D0D0D0D0CFCFCECECECDCDCCCCCCCCCC
CCCBCBCACAC9C8C7C7C6C5C4C3C1BEBBB8B4B3B3B2B1AEAD
ACABAAA9A9ABADAE
B0B0B1B1B2B2B3B4B4B4B4B5B5B5B6B6B6B6B6B6B6B7B8B9
BBBDBFC1C3C6CBCFD1D4D6D7D8D9D8D8D7D6D4D3D2D1D0CF
CECDCCCBCBCACACACACACBCBCCCCCCCDCECFD0D1D2D2D3D3
D3D4D4D4D4D4D4D4D4D3D3D2D2D1D1D1D1D1D1D1D0CFCFD0
D0CFCFCECDCDCCCBCBCAC8C7C5C1BDB8B5B4B2B1AFAEACAA
A9A9A8A8A9ABACAE
B0B1B1B2B3B3B4B4B5B5B6B6B6B7B7B8B8B9B9B9BABBBCBE
BFC1C4C6C8CACFD4D6D9DBDDDDDDDDDDDCDBD9D8D6D5D3D2
D1D0CFCECECECDCDCDCDCDCDCECECECFD0D0D1D1D2D2D3D4
D4D4D5D5D5D5D5D5D5D4D4D4D4D4D3D3D3D3D3D3D2D2D1D0
D0D2D2D1D0D0CFCFCECECCC9C4BEB9B6B3B1B0AFADABAAA9
A8A8A7A7A8AAACAE
B1B1B2B2B3B4B5B5B5B6B6B7B7B8B9BABABBBCBCBDBEC0C1
C3C6C8CACDD0D3D7DBDFE1E2E3E3E2E1E0DEDDDBD9D8D6D5
D4D3D2D1D1D0D0CFCFCFCFD0D0D1D1D2D2D3D4D4D4D5D5D6
D6D7D7D7D7D8D8D8D8D7D7D7D7D7D7D7D6D6D6D5D5D5D4D4
D2D0CED1D2D2D2D1CFCBC6C2BEBAB7B4B2AEADADABAAA8A6
A6A5A4A6A7AAACAE
B0B1B2B3B3B4B5B5B6B7B7B8B9BABBBBBCBDBEBFC0C2C3C5
C7C9CCCED1D4D7D9DEE2E5E8EAE9E8E7E5E3E1DFDDDBD9D7
D6D5D4D4D3D3D3D2D2D2D2D3D3D3D4D5D5D6D6D7D8D8D9D9
D9DADADBDBDBDBDBDBDBDBDBDBDBDADADAD9D9D9D8D8D7D7
D6D5D4D3D1CFD0CEC9C5C1BDB9B7B5B2AFACADABA9A7A5A4
A4A2A3A4A6A9ABAD
B1B1B2B3B4B5B6B6B7B8B9BABABBBCBDBEBFC1C2C3C5C7C9
CBCDCFD1D4D7DADDE0E5E9EDF0F0EEECEAE7E5E2E0DEDBDA
D8D7D7D6D6D5D5D5D4D4D4D5D6D6D7D7D8D8D9DADADBDCDD
DDDDDEDEDEDFDFDFDFDEDEDEDEDEDDDDDDDDDDDCDCDBDBDA
D9D8D7D6D5D2CDC7C3BFBBB8B5B2AFADABAAA9A7A5A4A2A2
A1A1A2A3A6A8AAAD
B1B2B3B4B4B5B6B7B8B9BABBBCBDBEBFC0C2C3C5C6C8CACC
CED0D2D5D8DBDDE0E3E8ECF0F2F5F5F2EFECE9E6E3E0DEDC
DBD9D9D8D8D7D7D7D7D7D7D8D9D9DADADBDBDCDDDDDEDFE0
E0E1E1E1E2E2E2E2E2E2E2E2E2E1E1E0E0E0E0DFDFDEDDDC
DBDAD8D5D1CBC6C1BDB9B7B4B0AEABAAA8A7A6A3A1A09F9F
9F9FA1A3A5A8ABAD
B1B2B3B4B5B6B7B8B9BABBBCBDBFC0C1C3C4C6C7C9CBCDCF
D1D3D5D8DBDEE1E4E8ECEFF2F4F6F9F8F4F0ECE8E5E2E0DE
DCDBDADADAD9D9D9D9D9DADADBDBDCDDDEDEDFDFE0E1E2E3
E3E4E4E5E5E6E6E6E6E6E5E5E5E4E4E4E3E3E2E2E2E1DFDE
DCD9D6D1CAC5C1BDB8B4B1AEACAAA8A7A5A3A09E9C9C9D9D
9C9EA0A3A5A8AAAD
B1B2B3B4B5B6B8B9BABBBCBDBFC0C2C3C5C6C7C9CBCDCFD2
D4D6D9DBDEE1E5E8EBEEF1F3F5F7F8F9F7F3EFEBE7E4E1DF
DDDDDCDBDBDBDBDBDBDBDCDCDDDEDFDFE0E1E2E2E3E4E5E6
E6E7E8E8E8E9E9E9E9E9E9E9E8E8E7E7E7E6E6E5E4E3E1DE
DCD8D3CCC4C0BCB8B4B0ACA9A8A7A4A2A09E9C9B99999A99
9B9DA0A2A4A7AAAD
B1B2B3B4B5B7B8B9BABCBEBFC0C2C3C5C6C8CACCCDD0D2D4
D7D9DCDFE2E5E8EBEEF1F4F5F7F7F7F7F9F7F2EDE9E5E2E0
DFDEDDDDDCDCDCDCDDDDDDDEDFDFE0E1E2E3E4E5E6E7E8E8
E9EAEBEBECECECECECECECECEBEBEAEAE9E8E6E5E4E2E0DD
D9D3CBC4C0BCB7B2AFACAAA7A4A19F9D9B9A989898989797
999C9FA1A4A7AAAD
B1B2B3B4B6B7B8BABBBDBFC0C2C3C5C6C8CACCCED0D2D4D6
D9DCDEE1E4E8EBEFF2F5F6F6F7F7F6F6F6F7F4EEE9E5E2E0
DFDEDDDDDDDDDDDDDEDEDFE0E1E1E2E3E4E5E6E7E8E9EAEB
EBECEDEEEFEFEFEFEEEEEEEEEEEDECEBEAE9E7E5E3E1DDD8
D2CAC3BEBBB8B3AFACAAA7A3A09D9A989795959494949496
989A9DA0A3A6A9AD
B1B2B4B5B6B8B9BBBCBEBFC1C3C4C6C8C9CBCED0D2D4D6D9
DBDEE1E4E7EAEEF1F4F7F7F7F7F6F5F4F4F2F2EEE8E4E2E0
DFDEDDDDDDDDDEDEDFE0E0E1E2E3E4E5E6E7E8E9EBEBECED
EEEFF0F0F1F1F2F1F1F1F1F0F0EFEEECEBE9E7E5E2DDD8D1
CAC4BEBBB7B3AFABA8A4A19E9B9896949392929191929495
979A9DA0A3A7AAAD
B1B2B4B6B7B9BABBBDBFC1C2C3C5C8CACBCDCFD2D4D6D9DB
DEE0E3E6EAEDF0F4F7F9F9F8F7F5F3F2F1EEEBE7E6E3E0DF
DEDDDDDDDDDEDEDFE0E1E2E2E3E4E5E6E7E9EAEBEDEDEEEF
F0F1F2F3F3F4F4F3F2F2F2F2F2F0EFEDEBE8E5E1DCD6D0C9
C4BFBAB7B3AFABA8A4A19E9B98959391908F8F8E8F909194
96999DA0A3A6A9AD
B1B3B4B6B8B9BBBCBEC0C1C3C5C7C8CBCDCFD2D4D6D8DBDD
E0E3E6E9ECF0F3F6FAFBF9F8F6F4F2F0EDEAE7E6E4E0DEDD
DCDCDCDDDDDEDFE0E1E1E2E3E5E6E7E8E9EAEBEDEEEFF0F1
F2F3F4F5F5F5F5F4F3F4F5F4F2F0EEECE9E5E1DCD5CEC8C3
BDB8B5B2AFABA7A5A29F9B989693908E8D8D8C8C8D8E9093
969A9DA0A3A6A9AD
B1B3B5B6B8B9BBBDBEC0C2C4C6C8CACCCED1D3D5D8DADDDF
E2E5E8EBEFF2F5F9FBFBFAF8F6F3F1EEEAE6E4E2DFDDDCDB
DBDBDCDDDDDEDFE0E1E2E3E4E6E7E8E9EAECEDEEEFF0F1F3
F4F5F5F6F7F6F5F5F5F6F5F2F1EFEDEBE6E0DBD5CFC9C4BF
BAB6B2AEABA8A4A19D9B9795928F8C8C8B8A8A8A8C8E9093
96999CA0A3A6A9AD
B2B3B5B6B8BABCBDBFC1C3C5C7C9CBCED0D2D4D7D9DCDEE1
E4E7EAEDF0F4F7FBFCFCFAF8F6F3F0ECE7E3E1DFDAD9D9DA
DADADBDCDCDDDFE0E1E3E4E5E6E8E9EAECEDEEEFF1F2F3F4
F5F6F7F7F7F7F6F6F8F7F5F2F0EEEAE6E0D9D4CEC9C4C0BB
B6B2AEABA6A29F9D9A9895928F8C8A89888787898B8E9093
96999DA0A3A6A9AD
B2B3B5B7B9BBBDBEC0C2C4C6C8CACDCFD1D4D6D8DBDDE0E3
E6E9ECEFF3F6F9FCFCFCF9F7F4F1EEE9E5E2DFDBD6D6D6D7
D8D8D9DADBDDDEDFE1E3E4E5E7E9EAEBECEEEFF0F1F2F3F4
F5F7F7F8F7F7F7F8F7F5F3F0EEEAE6DFD9D3CDC7C3BEB9B5
B1AEABA7A29E9C9A9794918E8B888786858587898B8E9094
96999DA0A3A6A9AD
B2B4B5B7B9BBBDBFC1C3C5C7CACCCED0D3D5D7DADDDFE2E5
E8EBEEF2F5F8FBFDFCFBF9F6F3EFEBE6E4E1DDD8D3D3D4D5
D6D6D7D9DBDCDDDFE1E2E4E6E7E9EAEBEDEEEFF0F1F3F4F4
F5F6F7F7F6F6F6F7F6F3F1EEEAE5DFDAD3CDC8C2BDB8B5B2
AEABA7A39F9C989693908D8B88868584838486888B8D9093
96999DA0A3A6AAAD
B2B4B6B8BABCBEC0C2C4C6C8CBCDCFD2D4D6D9DCDEE1E4E7
EAEDF0F3F6F9FCFEFDFBF8F5F1EEE9E5E3DFD9D4CFD0D1D2
D3D4D6D7D8DADCDEDFE1E3E5E6E8EAEBECEDEFF0F1F2F3F4
F5F5F6F6F5F5F6F5F3F0EDEAE5E0DBD5CEC8C2BDB8B4B0AE
ABA7A3A09C999694908D8B8785848282838587888A8D9093
96999DA0A3A6A9AD
B2B4B6B8BABDBFC1C3C5C7C9CCCED1D3D6D8DBDEE0E3E6E9
ECEFF2F5F8FBFEFEFDFBF8F4F0ECE7E3DFDBD5D0CCCDCECF
D0D2D3D5D6D8DADCDEDFE1E3E5E7E9EAEBEDEEEFF0F1F2F3
F4F5F5F4F4F4F3F1EFECE9E4DFDBD5CEC8C3BEB9B4B0ACA9
A6A3A09C999693908D8C898583818181838486888A8D9093
96999DA0A3A6A9AD
B2B4B7B9BBBDBFC1C3C6C8CBCDCFD2D4D7DADDDFE2E4E7EA
EDF0F3F7FAFDFFFEFCFAF6F1EEE9E4E0DDD7D2CDC8C9CACC
CDCFD0D2D4D6D7D9DBDDDFE1E3E5E7E9EAECEDEEEFF0F1F2
F3F3F3F2F2F2F1EEEAE7E3DFDBD5CEC8C3BEB9B4AFABA7A5
A29F9B999693908E8C898682807F7F80828486888A8D9093
969A9DA0A3A6A9AD
B2B4B6B9BBBDC0C2C4C6C9CBCED0D3D6D8DBDEE0E3E6E9EC
EFF2F5F8FBFEFFFEFCF8F5F0EBE6E2DED9D2CCC8C4C5C6C7
C9CBCDCFD1D2D4D6D8DADCDEE0E2E4E6E8E9EBECEDEEEFF0
F1F1F1F0EFEEECE9E6E2DFDCD7D0C9C2BDB9B5B1ACA8A4A0
9D9A979593908E8C8A86827F7E7D7E80818385878B8E9093
979A9DA0A3A6A9AD
B2B4B7B9BBBEC0C2C4C7CACCCFD1D4D7DADCDFE2E5E7EAEE
F1F3F7FAFDFFFFFDFBF7F2EDE8E3DFD9D3CCC6C2BEC0C1C3
C5C7C9CBCCCED0D2D4D6D9DBDDDFE1E3E5E6E8EAEBECEDEE
EEEDEDECEBEAE7E3E1DEDBD6CFC8C1BDBAB6B2ADA8A4A09E
9A969492908D8C8986837F7C7B7C7E7F818285878A8D9094
979A9DA0A3A6AAAD
B2B5B7BABCBEC1C3C5C8CBCDD0D2D5D8DBDDE0E3E6E9ECEF
F2F5F8FBFEFFFFFDF9F5EFEAE5E0DBD4CDC6C0BCB9BABCBE
C0C3C5C6C8CACCCED0D2D4D6D9DBDDDFE1E3E5E6E8E9EAEA
EBEBEAE8E7E5E1DEDCD9D4CEC7C0BCB8B4B1ADA9A5A19E9B
979492908D8A8885827E7C7A7A7B7D7E808285878A8D9094
979A9DA0A3A6A9AD
B3B5B7BABCBEC1C3C6C8CBCED1D3D6D9DBDEE1E4E7EAEDF0
F4F7F9FCFFFFFEFBF7F2ECE6E1DBD6CEC6BFBAB5B2B4B7BA
BCBFC1C3C5C7C9CACCCDCFD1D3D6D8DADCDFE1E3E4E5E6E6
E6E6E5E4E2DEDAD9D6D2CDC5C0BCB7B4B0ADA9A5A19E9A96
9492908E8B8886827F7C7A78797B7C7D7F8285888B8E9194
979A9DA0A3A6AAAD
B2B5B7BABCBEC1C4C6C9CCCED1D4D7DADDDFE2E5E8EBEEF2
F5F8FAFEFFFFFDF9F4F0EAE4DDD7D0C6BFB8B2ADACB0B4B8
BBBDC0C1C3C5C6C8C9CBCCCDCECFD2D4D7D9DBDDDFE0E1E2
E2E2E1DFDCD7D3D2CFCBC5BFBAB6B2AFACA8A5A19E9B9794
92908E8A8886837F7C7A7878797B7C7D7F8285888B8E9194
979A9DA0A3A6A9AC
B3B5B7BABCBFC2C4C7CACCCFD2D5D8DBDEE0E3E6E9ECF0F3
F6F9FCFEFFFEFBF7F2ECE5DFD9D2C9BFB8B0A8A5A9AFB3B7
BABDBFC1C3C5C6C7C8C9CACACBCCCCCED1D3D6D8D9DBDCDD
DEDDDCDAD6D1CDCBC8C4BFB9B4B0ADAAA7A3A09D9A979491
8F8E8B888684807D7B79767779797A7D7F8285888B8E9194
979A9DA0A3A7AAAD
B2B5B7BABDBFC2C5C8CBCDD0D3D6D9DCDEE1E4E7EAEDF1F4
F7FAFDFFFFFDF9F5F0E9E2DBD4CCC2B9B1A6A2A5ABB0B4B8
BBBDC0C2C4C5C6C7C7C7C8C8C9C9C9CACBCDD0D2D4D6D7D8
D9D8D7D4CFCCC7C3BFBBB7B3AFABA8A6A3A09D9A98959390
8E8B888683817D7B7977767777787A7D7F8285888B8E9194
979A9DA0A3A6A9AD
B2B5B8BABDC0C2C5C8CBCED1D4D7D9DCDFE2E5E8EBEFF2F5
F8FBFEFFFEFBF7F2ECE5DED7CFC6BBB3A9A4A6A9ADB1B5B9
BCBFC1C2C4C6C7C7C7C8C8C7C7C7C7C7C7C8C9CBCED0D2D3
D3D3D1CECAC5C1BEB9B5B0ABA8A5A2A19F9D9B989593918E
8B898784817E7B797776757576787A7D7F8285888B8E9194
979A9DA0A3A6AAAD
B3B5B8BBBDC0C3C6C9CBCED1D4D7DADDE0E3E6EAEDF0F4F7
FAFCFEFEFDF9F5EFE9E1DAD2C9BEB4ABA4A4A7ABAFB3B7BB
BEC1C3C4C6C7C7C8C8C7C6C6C5C5C4C4C4C4C4C6C7CACCCD
CECECCCAC5C1BDB8B2ACA9A7A5A3A19F9C9A989694918F8C
898784817E7B7A787674737476787A7D7F8285888B8E9194
979A9DA0A3A7AAAD
B2B5B8BBBDC0C3C6C9CCCFD2D5D8DADEE1E4E7EBEEF1F4F8
FBFDFEFEFCF8F3ECE5DCD5CCC2B6ACA4A2A6A9ADB1B5B9BD
C0C2C4C6C7C8C9C9C8C8C7C5C4C3C2C1C1C1C1C1C1C3C6C7
C8C8C7C4C1BEB9B4AFAAA5A1A19F9D9B9A989694918E8C8A
8884807E7C7978767372717375787A7C7F8285888B8D9194
979A9DA0A3A6A9AD
B2B5B8BBBEC1C3C6C9CCCFD2D5D8DBDEE2E5E9ECEFF2F6F9
FCFEFEFEFAF6F0E9E1D8D0C6BBB0A5A2A4A7ABAFB3B7BBBE
C1C3C5C7C8C9C9C8C8C7C6C4C2C1BFBFBEBEBEBDBDBDBEC0
C2C2C2C0BDBAB6B0ACA6A19F9D9C9A98969593908E8C8A88
85817F7B787776747271727375777A7C7F8285888B8E9194
979A9DA0A3A6A9AD
B3B6B8BBBEC1C4C6C9CCD0D2D6D9DCDFE3E6E9EDF0F4F7FA
FCFEFEFCF8F3ECE5DCD3CABEB3A7A1A4A6A9ACB0B4B8BCBE
C0C2C3C5C6C6C7C7C6C5C4C2C0BEBDBCBBBBBABABABABABB
BDBDBDBCBAB7B3AFABA5A19D999797959492908E8C8B8886
84807D7A78767472717072737577797C7F8285878A8D9093
969A9DA0A3A6AAAD
B3B6B8BBBEC1C4C7CACDD0D3D6DADDE0E3E7EAEEF1F5F8FB
FDFEFEFBF7F0E9E0D7CEC3B8ADA5A4A5A7AAADB1B5B9BCBD
BEBFBFC0C1C2C3C4C4C3C1BFBDBBBAB9B8B7B7B7B7B7B7B6
B6B8B8B8B6B4B1ADA7A4A09C9995939392908F8D8B898785
827F7C7A777573706F7071737577797C7F8284878A8D9093
96999DA0A3A6AAAD
B3B6B9BCBEC1C4C7CACDD1D4D7DADEE1E4E8EBEEF2F6F9FC
FEFFFEFAF4EDE5DCD2C8BCB1A5A1A4A5A7AAADB2B5B6B6B5
B6B9BABBBBBDBDBDBCBCBCBBB9B8B6B5B5B4B4B4B4B3B3B2
B1B1B3B3B2B1B0ACA7A4A19E9A9592908F8F8D8A89888683
817E7B79777572706E6E70727476797C7F8184878A8D9093
969A9DA0A3A6A9AD
B3B6B9BCBFC2C5C8CBCED1D4D7DBDEE1E5E8ECEFF3F7FBFE
FFFFFDF8F1EAE1D7CDC2B6AAA3A3A3A5A7A9ACAFB1B1B2B4
B6B6B6B8BABAB9B8B7B6B6B6B5B3B2B2B1B1B1B1B1B0B0AF
AEADAEAEAFAEACA9A8A5A19E9A97928F8E8C8A8A88868482
807D7A787572706F6D6E70727476797B7E8184878A8D9093
96999CA0A3A6A9AD
B3B6B9BCBFC2C5C8CBCED1D4D7DBDEE2E5E9ECF0F4F8FBFE
FFFDFAF5EEE5DCD2C7BBAFA4A1A3A3A4A6A8AAACACADADAD
AEAFB0B0B1B2B1B0B1B0AFAFAFAFAEAEAEAEAFAEAEAEADAC
ACABABACACAAAAA9A7A3A29F9C98948F8C8A898885848381
7E7B797673706F6D6C6E70727376787B7E8184878A8D9093
96999DA0A3A6A9AD
B3B6B9BCBFC2C5C8CBCED1D4D8DBDEE2E6E9EDF1F5F9FCFE
FEFCF8F2E9E0D7CCC0B5A8A2A3A3A3A3A4A4A2A2A2A1A2A3
A3A4A4A5A5A4A3A4A3A2A1A1A2A4A8AAABACACACABABABAA
AAA9A9A8A8A8A8A6A5A4A19F9D9996918D8A88868483817F
7C7A787573706E6B6B6D6F717375787B7E8083868A8D9093
96999DA0A3A6A9AD
B3B6B9BCBFC2C4C8CBCED1D4D8DBDFE2E6EAEEF2F6F9FCFE
FDFAF4EDE5DCD2C7BCB0A7A4A3A3A3A2A2A1A09E9B999999
9A9B9C9C9B9B9B9B9C9C9E9FA0A2A5A7A8A9A9A9AAA9A9A9
A8A7A7A6A6A5A4A4A4A3A2A09D9A97938E8A86848382807D
7B7A7774726F6E6B6B6D6E707274777A7D808386898C9093
96999C9FA3A6A9AD
B3B6B8BCBFC2C5C8CBCED1D4D8DCDFE3E6EAEEF2F6FAFDFD
FCF7F1EAE1D8CDC2B7ABA4A4A3A2A2A1A1A09F9E9D9C9B9B
9C9D9E9E9E9F9E9E9E9E9E9F9FA1A3A4A5A6A7A7A8A8A8A7
A7A6A6A5A5A3A2A2A1A09F9E9D9995928F8A8684827F7E7D
7B787472716E6C696A6C6E6F7174777A7D808386898C8F92
96999C9FA3A6A9AD
B3B6B9BCBFC2C5C8CBCED1D5D8DBDFE3E7EAEEF2F6FAFCFD
F9F3ECE5DCD2C8BEB4A9A5A4A3A2A1A1A0A09F9E9E9E9D9E
9E9FA0A0A0A0A09F9F9E9E9E9FA0A1A2A4A4A5A5A6A6A6A5
A5A5A4A4A2A1A2A2A1A1A09E9A9896938F8B8884807E7C7A
787573716F6D6A696A6B6D6F717476797C808385898C8F92
96999CA0A3A6A9AC
B3B6B9BBBEC1C4C8CBCED1D5D8DBDFE3E6EAEEF3F7FAFBF9
F5EFE8E0D7CEC4BAB0A8A5A3A2A1A1A0A09F9F9F9F9F9F9F
A0A1A2A2A2A2A1A0A09F9F9E9F9FA0A0A1A2A3A4A4A4A4A4
A4A4A4A3A2A1A09F9F9E9D9B999896928F8C8682807D7B78
7572716F6D6B6867686A6B6D707376797C7F8285888C8F92
96999C9FA2A6A9AD
B3B6B8BBBEC1C5C8CBCED2D5D8DCDFE3E7EAEEF3F7FAFAF7
F2EBE4DBD2C8BFB6ABA4A4A2A1A1A0A09F9F9F9F9F9FA0A1
A1A2A3A3A3A3A2A1A0A09F9F9E9E9FA0A1A1A1A2A2A2A3A2
A2A2A2A2A1A09F9E9E9D9C9A989693918D8886827F7B7976
74716F6C6A68656768696A6C6F7275797C7F8285888B8F92
95989C9FA3A6A9AD
B3B6B8BBBEC1C5C8CBCED1D5D8DCDFE2E6EAEEF2F6F8F8F4
EFE8E0D7CEC5BBB2A7A2A2A1A0A0A09F9F9F9F9FA0A0A1A1
A1A1A2A2A3A3A2A1A1A09F9E9E9E9E9F9F9FA0A0A0A1A1A1
A1A1A1A09F9F9F9F9D9C9A989593908E8B8985807C7A7774
72706E6A6865646667696A6C6F7275787B7E8185888B8E92
95989C9FA2A6A9AD
B3B6B9BCBFC2C5C8CBCED1D5D8DBDFE2E6EAEEF2F6F7F5F0
EAE3DBD2C8C0B8AFA5A2A1A0A09F9F9F9F9F9F9F9FA1A1A0
9E9FA0A1A2A1A0A1A09F9E9D9D9D9E9E9E9F9F9F9F9F9F9F
9F9F9F9F9E9D9D9B9B99989593908E8B8987817E7B787674
716E6B68666464646566686B6E7174787B7E8184888B8E91
95989C9FA2A6A9AD
B3B6B9BCBFC2C4C7CBCED1D4D8DBDFE2E6EAEEF2F5F5F1EB
E5DDD5CDC4BCB3A9A1A09F9F9E9F9F9F9F9F9F9F9F9E9C9C
9D9E9E9D9B9B9C9C9D9D9D9C9C9D9D9E9E9E9E9E9E9E9E9E
9E9E9D9C9C9B9B9998969492908E8B8887827E7C78767371
6E6B6866656464636363676A6D7174777A7E8184878B8E91
95989B9FA2A6A9AC
B2B5B8BBBEC1C4C7CACED1D4D7DBDEE2E6E9EDF1F3F2EEE8
E1D8D0C7C0B8AEA49E9E9E9E9E9E9E9E9F9F9F9F9F9E9D9C
9D9D9D9D9C9C9C9C9B9B9B9B9C9C9D9D9D9E9E9E9D9D9D9C
9C9C9C9B9A9999969492908E8C8A8885827D7B787574716E
6B6966646261605F606366696D7073777A7D8184878A8E91
95989B9FA2A5A9AC
B3B5B8BBBEC1C4C7CACDD0D4D7DADEE1E5E9ECF0F2EFE9E2
DBD3CBC3BCB3A99F9B9C9C9D9D9E9E9F9F9F9F9F9F9E9E9D
9E9E9E9E9D9D9D9C9B9A9A9B9C9C9D9D9D9D9D9D9D9C9C9B
9A9A9A9998979593918E8E8B888684817D79777472706E6B
696764615F5F5E5D5E6265696C6F73767A7D8083878A8E91
94989B9FA2A5A9AC
B3B6B8BBBEC1C4C7CACDD0D3D7DADDE1E4E8ECF0F0EBE6DF
D7CEC7BFB8AFA59C9B9B9C9D9D9E9F9F9F9F9F9F9F9F9F9F
9F9F9F9F9F9E9D9C9B9A9A9B9C9C9D9D9D9D9D9C9C9C9B9A
99989897969492908E8C89878582807C797673716F6C6B6A
6764615D5C5D5B5B5E6165686C6F7275797C8083868A8D91
94989B9FA2A5A9AC
B3B6B8BBBEC1C4C6C9CCCFD2D6D9DDE0E3E7EAEDECE7E1D8
D0C9C2BBB2A89E98999A9B9C9E9F9FA0A0A0A0A0A0A09F9F
9FA0A09F9E9D9C9C9B9A9B9C9C9D9D9E9E9D9D9D9C9B9A9A
999796959492908E8A88878582807C7875716F6D6B6A6967
65625F5C5A5857595D6064676A6E7175787C7F83868A8D91
94979B9EA2A5A9AC
B2B5B8BBBEC0C3C6C9CCCFD2D5D8DCDFE3E6E9EBE8E3DBD3
CCC5BDB4AAA0969397999B9D9E9FA0A0A1A1A1A1A0A0A09F
9F9F9F9F9E9D9C9C9B9B9C9C9D9E9E9E9E9E9E9D9D9B9A99
9897959492908E8B888684817E7C7975726E6B6A69686865
635F5C58575656595C6063666A6D7174787B7F8286898D90
94979B9EA2A5A9AC
B3B5B8BBBDC0C3C6C9CCCFD2D5D8DBDEE2E5E9EAE5DFD7CF
C7C0B8AFA497919497999C9D9FA0A1A2A2A2A2A2A1A0A09F
9F9F9F9F9E9D9D9D9D9D9D9E9E9F9FA0A09F9F9E9D9B9A99
97969492918F8C898582807E7C7975726F6B686867676663
615C5956545455585C5F6266696D7074777B7F8286898D90
94979A9EA2A5A9AC
B2B5B8BABDC0C2C5C8CBCED1D4D7DADDE0E4E9E8E2DBD2CB
C3BBB2A89D949495989B9D9EA0A2A3A3A3A3A3A3A2A1A1A0
A09F9F9F9F9E9E9E9E9F9FA0A0A1A1A1A1A1A09F9E9C9B99
98969492908E8B898582807D7A7773706C68666666656461
5E595553525254585B5E6265696C7073777A7E8185898C90
93979A9EA2A5A9AC
B2B5B7BABDBFC2C5C8CACDD0D3D6D9DCE0E3E5E2DCD6CDC6
BEB6ADA3989395979A9C9EA0A2A4A4A5A5A5A4A4A3A2A1A0
A0A0A09F9F9F9F9FA0A0A1A2A3A3A4A4A4A3A2A1A09E9C9A
98969492908D8B8885827F7C7975726E6B6765656462605E
5A5553514F5154575A5E6165686C6F73767A7E8185888C8F
93969A9EA1A5A9AC
B2B5B7BABDBFC2C4C7CACDCFD2D5D8DBDEE1E3DED8D0CAC3
BBB2A89D949396999B9EA0A2A4A5A6A7A8A7A6A6A4A3A2A1
A09F9F9FA0A0A0A1A2A2A3A4A5A5A6A6A6A5A5A3A19F9D9B
989694918F8C898784817E7B7774706D6A65646362615F5C
5853504E4D4F5356595D6064676B6F7276797D8184888C8F
93969A9EA1A5A9AC
B2B5B7B9BCBFC1C4C7C9CCCFD2D4D7DBDEE2E2DBD5CDC5BE
B7AEA4999497999B9DA0A2A4A6A8A9AAAAA9A8A7A5A3A2A1
A09F9F9FA0A0A1A2A3A4A5A6A7A8A9A9A9A9A7A5A3A19E9B
999694918F8C898683817D7A76726F6B6764636260605D5A
55504C4A4B4E5155585C5F63676A6E7275797D8084888B8F
93969A9DA1A5A9AC
B2B4B7B9BCBEC1C3C6C8CBCED1D4D7D9DCE0DDD6D1CAC3BC
B4AAA19A999A9B9D9FA1A4A6A9AAABACACABA9A8A5A3A2A0
9F9E9E9FA0A1A2A3A4A5A5A7A8AAACACACABAAA7A5A29F9C
9A9794918F8C898683807C7975716D69666261605F5D5956
514D4947484C5054575B5F62666A6E7175797C8084878B8F
92969A9DA1A5A8AC
B2B4B7B9BBBEC0C2C5C8CACDD0D3D6D8DBDEDAD5CEC7C1B9
B1A69D999C9C9D9FA1A4A6A9ABADAEAEADADAAA8A5A3A19F
9E9D9D9E9FA0A1A2A4A5A7A8AAACADAEAEAEACAAA7A3A09D
9A9794928F8C8986827E7B7774706C6864615F5E5D5A5452
4D494645474B4F52565A5E6266696D7174787C8083878B8E
92969A9DA1A5A8AC
B2B4B6B8BBBDBFC2C4C7C9CCCFD1D4D7D9DAD6D3CDC6BEB7
ADA49E9E9E9D9EA0A2A5A8ABADAFB0B0AFADAAA7A4A19F9D
9C9B9C9C9D9FA0A2A3A5A7A9ABACAEB0B0AEACA9A7A3A09D
9A9794928F8C8986827D7975726E6A66625F5D5C59554F4E
4A45444445494D5155595D6165686C7074787C7F83878A8E
9296999DA1A5A8AC
B2B4B6B8BABDBFC1C4C6C8CBCDD0D3D6DADAD4D1CBC4BCB4
AAA19D9F9E9E9FA1A3A6AAADADABABADAEABA7A5A39F9C9A
9999999A9B9C9DA0A2A7A9A9A8A9ACAEACABA9A8A5A29F9C
989694918F8C8985817D7875716C68645F5C5A5854514C4A
4540404144484C5054585C6064686C7074777B7F83878A8E
9296999DA1A5A8AC
B2B4B6B8BABCBEC0C2C5C7CACDCFD2D5D7D5D2CDC8C1B9B2
AAA3A09F9E9D9FA1A3A6A9AAA7A6A8A8A6A4A29F9C9A9997
9696979898999B9D9FA0A1A1A2A7A9A7A5A5A3A2A19E9C99
969492908E8B8884807C79756F6965615D595754504C4847
413E3E3E42474B4F53575B5F63676B6F73777B7F82868A8E
9295999DA1A5A8AC
B2B3B5B7B9BBBDBFC2C4C6C9CBCED1D3D3D2D1CCC6BEB7AF
A7A1A2A19F9E9EA0A2A4A5A6A5A4A49F9F9C9A9896949291
92939494959597989A9B9B9DA1A3A1A2A09F9C9D9B979695
9392908F8D8A87837F7A76716B67635E595654504B484443
3E3C3B3C41454A4E52565B5F63676B6F73767A7E82868A8E
9295999DA1A5A8AC
B2B3B5B7B9BBBDBFC1C3C5C8CACDD0D5D6D3CEC9C2BBB5AE
A7A3A3A19E9D9C9D9D9D9D9B9B9E9E9B968F8E8C8B8A8B8C
8E8F90919192929394959798999C9B99959595938F8E8F8F
8F8F8E8C8B8986827D78736D67625F5B56524F4C48433F3E
3A39383B4044494D51565A5E62666A6E72767A7E82868A8E
9295999DA1A4A8AC
B1B3B5B6B8BABCBEC0C2C4C6C9CBCED2D3D1CEC8C0BAB4AE
A8A4A3A09D9B9A9997959290908F8D8A8886848282848688
8A8C8D8E8E8E8E8E8F8F9091928F8B898988888684858789
8A8A8B8A8886837F7A76706B65605C57524E4B47433F3B3A
3736363A3E43484C5155595D62666A6E72767A7E8286898D
9195999DA1A4A8AC
B1B3B4B6B7B9BBBDBEC0C3C5C7CACCCDCED0CDC6BFB9B3AC
A7A5A3A09D9A989693908C888583817F7D7D7E7E7F818385
88898A8B8B8B8C8C8C8C8B8A888784817E7C7B7C7E808285
868888878583807C78746F69635D57534E4A47433E3B3837
343233383D42474B5054595D6165696E72767A7E8285898D
9195999DA1A4A8AC
B1B3B4B5B7B8BABBBDBFC1C3C6C8CACCCFCEC9C2BCB5B0AB
A7A4A29F9B989694928F8B8885838281807F7E7C7C7E8183
8587898989898888888A8A898784807E7C7B7C7D7F818384
8686858483807D7975716C66605B554F4A47433F3B383534
313033383D41464B4F54585C6165696D7175797D8185898D
9195999DA1A4A8AC
B1B2B3B5B6B7B9BABCBDBFC1C4C6C9CBCDC8C3BDB7B1ADA8
A5A3A09D99969492918E8C898786837F7B7875767A7D8083
858687888887868583828283838382807F7F7F8081828384
84838281807D7A76736F69635D57504945413F3B38353432
2F2F32373C41454A4F53585C6065696D7175797D8185898D
9195999DA0A4A8AC
B1B2B3B4B5B6B7B9BABCBEC0C2C4C9CAC9C3BDB6B2AEAAA6
A3A19E9A969391908F8E8C8A88837C76737375777A7D8083
8586878787868584817E7B79797B7E808182828283838382
807F7E7D7C7A77736F6B655F59544E47413E3B3734323131
2D2D32363B40454A4E53575C6064696D7175797D8185898D
9195999DA0A4A8AC
B1B2B2B3B4B5B6B7B9BABBBDBFC2C6C8C7BEB7B1ADA9A6A3
A09D9A9793908E8B888786847F7A76767677787A7D7F8183
8586868686868583817F7C7A77767576787B7D7E7E7D7C7C
7C7C7C7B797673706D68625E58524A423D3A3633302F2E2C
292C31363B4044494E52575B6064686D7175797D8185898D
9195999DA0A4A8AC
B1B1B2B3B3B4B5B6B7B8B9BABCBEC0C1BEB8B1ADA9A5A29F
9C9A9693908D8C8A8784807D7B7A79797A7A7C7D7F818384
868687878787868483807E7C7A7979797877767778797A7A
7A7A7A797774706D6965605B544C443C3935312F2D2B2A27
262B30353A3F44494D52575B5F64686C7175797D8185898D
9195999DA0A4A8AC
B0B1B1B2B2B3B4B4B5B5B6B7B9BABCBDB9B3ADAAA6A29F9C
999793918D8B8A888684817F7D7C7C7D7D7D7F8081838485
87878888888786858482817F7D7C7C7B7B7A7A7A7A7A7A7A
7A79787674726F6B66615C564F47403834312D2C2A282723
242A2F34393F43484D52565B5F64686C7075797D8185898D
9195999DA0A4A8AC
B0B0B1B1B1B2B2B2B3B3B4B4B5B6B6B6B2AEABA8A39F9C99
9794908E8B89888785848281807F7F7F7F80818283858687
888889898989888786858382807F7E7E7D7C7C7B7B7A7A79
79787675736F6D69656159524C453D35312D292826242320
23292E34393E43484D52565B5F64686C7075797D8185898D
9195999DA0A4A8AC
B0B0B0B0B0B1B1B1B1B1B1B1B1B1B1B1AEABA8A5A19D9A97
93908C8A8887878684838282818181818283848586878889
898A8B8B8B8A898987868584838281807F7E7D7C7C7B7A79
79787674716E6B68635D5650494139322E29262422201E1D
22282E33393E43484D51565B5F64686C7075797D8185898D
9195999DA0A4A8AC
B0B0B0AFAFAFAFAFAFAFAEAEAEADADADA9A6A39F9D9A9793
908D8A878685858484838383828283838485868788898A8B
8B8C8C8C8C8B8B8A898887868583828281807F7E7D7B7A79
787675726F6C6965605A544E453D352E2B2824201D1B191C
22282E33393E43484D51565B5F64686C7075797D8185898D
9195999DA0A4A8AC
B0AFAFAFAEAEAEADADACACABAAAAA9A8A4A19E9C9A979491
8D8A8785848483838383848484848585868788898A8B8C8C
8D8E8E8E8D8D8C8C8B8A89888685848381807F7E7D7C7A79
787673716E6B67635D5751494139302A2824201C1816151B
22282E33393E43484D51565B5F64686C7175797D8185898D
9195999DA1A4A8AC
AFAFAFAEADADACACABAAA9A8A7A6A4A49F9C9B999794918E
8C89858382828282838384848585868788888A8B8C8D8E8E
8F8F8F8F8F8F8E8D8C8C8B8A88878685838281807E7C7A79
777472706D6965615A544E453C332B2623211C191714151C
22282E33393E43484D52565B5F64686D7175797D8185898D
9195999DA1A4A8AC
AFAFAEADADACABAAA9A8A7A5A4A2A09C999A989694918E8C
888583818080818182838485868788898A8B8C8D8E8F8F90
919191919190908F8F8E8D8B8A898786848382807E7C7A78
7673716E6B66625D57514940372F26221F1C18151413171D
23292E34393E43484D52575B6064686D7175797D8185898D
9195999DA1A4A8AC
AFAEADACACABAAA9A7A6A5A3A19F9C99989693928F8D8B89
868381807F7F80818284858687888A8B8B8C8D8E8F909192
929393939392929191908E8D8C8A8987858482817F7D7A78
7573706C6864605B544D443B332B221E1B1814121113181E
23292F34393F44494E52575C6064696D71757A7E82868A8D
9195999DA1A5A8AC
AFAEADACABAAA8A7A6A4A2A19E9C9996938F8E8C8A898785
8482807F7E7E7F818284858788898B8C8D8E8F9192929394
94959595959494939391908F8E8C8B89878683817F7D7A78
75726E6B66615C564F473E362D261E1A1713100F0F13191F
242A2F353A3F44494E53575C6065696D72767A7E82868A8E
9295999DA1A5A8AC
AFAEADABAAA9A7A6A4A3A19E9C9996938E8C898786848382
817F7E7D7D7E7F8183858688898B8C8E8F90929394959596
979797979797969695949391908E8C8B898784827F7D7A77
74716D69645F59524A42393028211B17130F0D0D0F141A1F
252B30353B40454A4F53585C61656A6E72767A7E82868A8E
9296999DA1A5A8AC
AFADACABA9A8A6A5A3A19F9D9A9794908C8883818080807F
7E7D7D7D7D7E7F81838587898B8C8E8F9192949596979798
99999999999999989796959392908E8C8A888583807D7A77
74706C67625C554D453C342C241D1613100D0B0C0F151B20
262B31363B41464A4F54595D61666A6E72777B7F83868A8E
92969A9DA1A5A8AC
AEADACAAA9A7A5A4A2A09E9B9895928E89827C7B7B7C7D7D
7D7C7C7C7D7F80828486888A8C8E8F91939495969798999A
9B9B9C9C9C9C9B9A999897959492908E8C898683807D7A76
736F6A655F5850483F372E271F150F0E0C0A0A0B10161C21
272C32373C41464B5055595E62666B6F73777B7F83878B8F
92969A9DA1A5A9AC
AEADABAAA8A6A5A3A19F9C9A9794918D88837D797A7C7D7C
7C7B7C7C7D7F80838587898B8D8F9192949697989A9B9C9C
9D9E9E9E9E9E9D9C9C9B99979593918F8C8A8783807D7976
716C67625B534B433A322920170E0B0B0907080B11171D22
282D33383D42474C51555A5E63676B6F74787C7F83878B8F
93969A9EA1A5A9AC
AEADABA9A8A6A4A2A09E9B999693908C8884807D7C7C7D7C
7B7B7B7B7D7E818385888A8C8E9092949697999A9C9D9E9F
A0A1A1A1A1A0A09F9E9D9B99979593908D8A8784817D7974
6F6B655E564E453D342C23190E0909080504060B12181E24
292F34393E43484D52565B5F64686C7074787C8084888B8F
93979A9EA1A5A9AC
AEACABA9A7A5A3A19F9D9A9895928F8C8885817F7E7D7C7A
7A7A7A7B7D7F818386888B8D8F91939597999B9C9E9FA0A1
A2A3A3A4A3A3A2A1A09E9C9B989694918E8B8884807D7873
6E686159514940362E261C110B0906040203060C13191F25
2A30353B4045494E53575C6064696D7175797D8184888C90
93979A9EA2A5A9AC
AEACABA9A7A5A3A19F9C9A9794928E8B888582807F7D7A7B
7A797A7B7D7F828486898B8D90929497999B9D9EA0A1A2A3
A4A5A6A6A6A5A4A3A2A09E9C9A9896938F8C8884807B7671
6B645D554D443B33291E140D080503010003070D141A2126
2C31373C41464B4F54585D61656A6E7276797D8185898C90
94979B9EA2A5A9AC
AEACAAA8A7A5A2A09E9C999794918E8B888582807E7B7A79
78797A7B7D7F828487898C8E909395989A9C9EA0A1A3A4A5
A6A7A8A8A7A7A6A4A3A2A09E9C9A9793908C88847F7A746E
675F5850483F362C231A0F090604010000020810161C2228
2E33383D42474C51555A5E62666B6F72767A7E8286898D90
94989B9FA2A6A9AC
AEACAAA8A6A4A2A09E9B999694918E8B8885827F7C787876
7576787A7C7E818486898C8E919396989B9DA0A2A3A5A6A7
A8A8A9A8A8A7A7A6A5A3A19F9D9A97938F8B87827C77716A
635B534B41382F261D140D090502000001050B12181E242A
30353A3F44494E52575B5F64686C7073777B7F83868A8D91
94989B9FA2A6A9AC
AEACAAA8A6A4A2A09D9B999693918E8B8885817E7A777471
727375787B7E818386888B8E909396999C9EA1A2A4A5A7A8
A8A8A9A8A8A8A7A6A4A2A19E9C9996928E8A857F7A736C66
5F564E453B322B231A120D090402000103070E141B21272C
32373C41464A4F54585C6065696D7174787C8083878A8E91
95989C9FA2A6A9AD
AEACAAA8A6A4A2A09D9B999693918E8B8885817E7A74706E
6E717375787C80838587898C8F93979A9C9FA1A3A4A4A5A6
A7A7A7A7A6A5A4A3A2A09E9C9996928F8B86817C766F6860
58504840372F271F18100A0603010103060B11171D23292F
34393E43484C5155595E62666A6E7275797D8084888B8F92
95999C9FA3A6A9AD
AEACAAA8A6A4A2A09D9B989693918E8B8885817E7A756F6A
6A6D7174777A7D7F8285888C8F9396999C9E9FA0A1A3A3A3
A4A4A4A3A2A1A09F9D9A999693908C8985817C76716C655C
554C443B332C241A130E0A0603020404080E141A20262C31
363B4045494E52575B5F63676B6F73777A7E8285888C8F93
96999CA0A3A6A9AD
AEACAAA8A6A4A2A09D9B989693918E8B8885827E7A76726E
6D6D6E707476787D8085888B8F929597999B9D9E9FA0A0A0
A0A09F9E9D9C9A989694918E8C8986837E7A75706B655E57
4F473F372F271F18110C0805050605060C12181D23292E33
383D42474C5054595D6165696D7074787B7F8286898D9093
969A9DA0A3A6AAAD
AEACAAA8A6A4A29F9D9B989693918E8B8885827F7B777470
6C6B6D707376797C7F8285898D9093959798999A9B9C9C9B
9B9A999897969492908E8B888582817D7A75706B655E5852
4A423B332B231B140E0A09090908070A10161B21272C3136
3B4045494E52565B5F63666A6E7275797C8083878A8D9194
979A9DA0A4A7AAAD
AEACAAA8A6A4A29F9D9B999694918E8C8986837F7C797572
6F6B6B6E717377797C7F83868A8E90929394949596969695
959493918F8E8D8B898783817F7D7B7673706A645E574F48
413A332B241D15110E0D0E0D0A08080E14191F242A2F3439
3E42474C5054585C6064686C7073777A7E8184888B8E9194
989B9EA1A4A7AAAD
AEACAAA8A6A4A2A09D9B999694928F8C898784807D7A7774
716F6E6E7174777A7C7E8184878A8C8E8F8F90909090908F
8D8D8A8888858282807E7D7A7875726F6B65605B554E4842
3B342C241E18151310100E0A09080C12181D23282D32373C
41454A4E52565B5F62666A6E7175787B7F8285898C8F9295
989B9EA1A4A7AAAD
AEACAAA8A6A4A2A09E9B999794928F8D8A8784817E7B7875
73706D6E6E6F7276797C7E8183868889898A8A8A8A898987
868483827F7D7B79777573706E6B67645F5C58534C46403A
322B26211D19161615110C09070910161C21262B31353A3F
43484C5155595D6165686C6F73767A7D8083878A8D909396
999C9FA2A4A7AAAD
AEACAAA8A6A4A2A09E9C9A979593908E8B888583807D7A77
74716F6B6A6F717375797B7D7F8182838384848383828280
7F7D7B77757372706C6B686563605D5956524D48443E3731
2B26221E1A181816130F0C09080E141A20252A2F34393E42
474B4F53585C5F63676A6E7175787B7E8285888B8E919497
999C9FA2A5A8AAAD
AEACAAA8A6A4A2A09E9C9A989693918E8C898684817E7B78
7673706D69696E72747677797A7C7D7C7C7C7C7B7B7B7978
7673716E6C69666463605C5A5855514D4A46423E39342F2A
2522201E1D1D1A15100D0A090E13191E24292E33383C4146
4A4E52565A5E6265696C7073767A7D808386898C8F929597
9A9DA0A2A5A8AAAD
AEACAAA8A7A5A3A19F9D9B989694928F8D8A8885827F7D7A
7774716E6B69696C7072747676767676767576757473726F
6D6B6865635F5C58555453504D4945423D3935312D292725
23201F1F1E1B16120E0A080B12181E23282D32373C404549
4D5155595D6164686B6E7275787B7E8184888B8D90939598
9B9EA0A3A5A8ABAD
AEACAAA9A7A5A3A19F9D9B99979592908E8B898683817E7B
787673706D696666696D707272706F6F6F6E6D6C6B6A6867
64615F5D5955524E4B484644423E3B3835312D2A27262523
2323221F1C16110E0C090A11171D23282D32373C4044484D
5155595C6063676A6E7174777A7D808386898C8E91949699
9C9EA1A3A6A8ABAD
AEACABA9A7A5A3A1A09E9C9A989593918F8C8A878582807D
7A7774716E6A6664646668696A6A686666666463605F5D5C
5A5855534F4C4946423E3C3C393634312E2B292726262626
2524221D17110F0C080B12181E23282D32373C4044484D50
54585C5F63666A6D707376797C7F8285888A8D909295979A
9C9FA1A4A6A9ABAD
AEACABA9A7A6A4A2A09E9C9A98969492908D8B898684817F
7C797673706C686460616263646463605E5D5D5A58555251
504F4C4A4644413E3B383533302E2E2C2B29292829292724
221F1914100F0C090C12181E24292E33383C4145494C5054
585C5F6366696C6F7376797B7E818486898C8E919396989B
9D9FA2A4A7A9ABAE
AEADABA9A8A6A4A2A19F9D9B99979593918F8C8A88858380
7E7B7875716E6A66615C5C5F61615E5C595654524F4C4946
4443413F3D3B3A3A3939363431302F2F2F2F2E2C2A262320
1C1813100E0D0A0C141A1F252A2F34383D4145494D515559
5C5F6366696C6F7275787B7E808386888B8D90929597999C
9EA0A2A5A7A9ABAE
AEADABAAA8A6A5A3A1A09E9C9A98969492908E8C89878582
7F7D7A7773706C6864605B5A5B5B5B5A56534F4C49464342
3E3A363534353637363637363535363432302E2A27221E1A
1512100F0B0A0F151B21262B3035393E42464A4E5255595C
606366696C6F7275787B7D808285878A8C8F919396989A9D
9FA1A3A5A7A9ACAE
AEADABAAA8A7A5A4A2A09F9D9B99979593918F8D8B898684
817F7C7976726F6B67635F595456585756534F4B49474542
3F3E3D3C3B3A3939393A3A3A39383633312E2A27221C1814
13110F0C0E14191E23282D32363B3F43474B4F53565A5D60
6366696C6F7275787A7D80828587898C8E90929597999B9D
A0A2A4A6A8AAACAE
AEADACAAA9A7A6A4A3A19F9E9C9A98979593918F8D8B8886
84817E7B7875726E6B67625E595452535352514F4D4A4745
4342403F3E3E3E3E3E3D3C3B3A3936332F2926211D1A1716
14101013181D22262B3034393D4145494D5054585B5E6164
676A6D707375787B7D80828587898B8E90929496989A9C9E
A0A2A4A6A8AAACAE
AFADACAAA9A8A6A5A3A2A09F9D9B9A98969492908F8D8A88
8683817E7B7976726F6B67635E59534F4F5151504E4C4B49
484645444342434342403E3B3837332E2A26221E1C1B1915
14161A1E22272B2F33383C4044484B4F5256595D60636669
6C6E717376797B7E80838587898C8E90919396989A9C9E9F
A1A3A5A7A9AAACAE
AFADACABA9A8A7A5A4A3A1A09E9D9B9998969492908E8C8A
888683817E7C7976726F6B67635F5B56524E4C4E50504F4E
4B49484745444341403E3D3A35322E2B292725211E1B1A1C
1F2225282C3034383C4043474B4E5255595C5F6265686B6D
707275777A7C7E818385888A8C8E9092949698999B9D9FA0
A2A4A6A8A9ABACAE
AFADACABAAA9A7A6A5A3A2A19F9E9C9B9998969493918F8D
8B888684817F7C797673706C6965615D595654514E4F504F
4E4E4C4A49474542403E3C39373532312E2A262425262729
2B2D3033373A3D4144484B4F5255585B5E6164676A6D6F72
7477797C7E80838586888A8C8E90929496989A9B9D9EA0A2
A3A5A6A8A9ABADAE
AFAEACABAAA9A8A7A5A4A3A2A09F9E9C9B9998969493918F
8D8B89878582807D7A7774716E6B6764615E5C595754514F
4E4E4D4D4C4B4A494844413F3D3A3632302F2F3031323334
36383B3D404346494C505356595C5E6164676A6C6F717476
787B7D7F82848687898B8D8F9192949698999B9D9E9FA1A3
A4A6A7A8AAABADAE
AFAEADACABAAA8A7A6A5A4A3A1A09F9E9C9B999897959391
908E8C8A888683817E7C797673706E6B686563605E5C5958
5655545352514F4C4A484543413F3E3D3C3B3B3B3C3D3E40
424446484A4C4F5254575A5D606265676A6D70727476797B
7D7F81838587898B8C8E9092939597989A9B9C9EA0A1A2A4
A5A6A8A9ABACADAF
AFAEADACABAAA9A8A7A6A5A4A3A2A09F9E9D9B9A98979694
92918F8D8B89878583807E7B797674716F6C6A6866646260
5F5E5C5B5A59575553514F4E4C4B4948474747474748494B
4C4E50525456585B5D606264676A6C6E70737577797B7D7F
81838587898A8C8E8F9193949697999A9C9D9E9FA1A2A4A5
A6A7A8AAABACAEAF
AFAEADACACABAAA9A8A7A6A5A4A3A2A19F9E9D9C9B999897
959492908F8D8B89878583807E7C79777573726F6E6C6A68
6766656362615F5E5C5B5958565554535352525253545455
57585A5C5D5F626465686A6C6E70727577797A7C7E808284
8688898B8C8E909192949597999A9B9C9E9FA0A2A3A4A5A6
A7A8A9AAACADADAF
AFAEAEADACABAAAAA9A8A7A6A5A4A3A2A1A09F9E9D9C9B99
9897959492918F8D8B8A88868482807E7D7B797775737271
706E6D6C6B6A686765646362615F5E5E5D5D5D5D5E5E5F60
6162646566686A6C6E7071747678797B7D7F808283858789
8A8C8D8F909293949697989A9B9C9D9FA0A1A2A3A4A5A6A7
A8A9AAABACADAEAF
AFAFAEADACACABAAAAA9A8A7A6A6A5A4A3A2A1A09F9E9D9C
9B9A989796949391908E8D8B898886848381807E7C7B7A79
77767675737271706F6D6C6B6A6A69686868686868696A6B
6B6C6D6E7072737476787A7C7D7E808283858688898A8C8D
8F90929395969798999A9C9D9E9FA0A1A2A2A3A4A5A6A7A8
A9AAABACADADAEAF
AFAFAEAEADACACABAAAAA9A8A8A7A6A6A5A4A3A2A1A0A09F
9E9D9C9B99989796949392908F8D8C8B8988868584838281
807F7E7D7C7B7A7978777776757473737272727273737475
75767778797A7B7D7E80818384858788898B8C8E8F909193
9495969798999A9B9C9D9E9FA0A1A2A3A3A4A5A6A7A8A8A9
AAABABACADAEAFAF
AFAFAEAEADADACACABABAAAAA9A8A8A7A7A6A5A4A4A3A2A2
A1A09F9E9D9C9B9A9998969594939291908F8D8C8B8A8988
88878686858483828181807F7F7E7E7D7D7D7C7D7D7E7E7E
7F808182828385868788898A8B8D8E8F9091929394959797
98999B9B9C9D9E9FA0A1A2A2A3A4A4A5A6A7A7A8A8A9AAAA
ABABACADAEAEAEAF
AFAFAFAEAEADADADACACABABAAAAA9A9A8A8A7A7A6A6A5A5
A4A3A2A2A1A09F9E9D9C9B9B9A9998979695949392919190
908F8F8E8D8D8C8B8B8A8989888888878787878787878889
898A8A8B8B8C8D8E8F9091929293949596979898999A9B9C
9D9E9E9FA0A1A2A3A3A4A4A5A5A6A7A7A8A9A9A9AAAAABAB
ACACADADAEAEAFB0
B0AFAFAFAEAEAEADADADACACACABABABAAAAA9A9A8A8A8A7
A7A6A6A5A5A4A3A3A2A1A1A09F9E9E9D9C9B9B9A9A999998
989797979695959494949393929292919191919192929293
9393939494959697979898999A9B9B9C9C9D9D9E9FA0A0A1
A2A2A2A3A4A5A5A6A6A7A7A8A8A8A9A9AAAAABABABACACAC
ADADADAEAEAEAFB0
B0AFAFAFAFAFAEAEAEAEAEADADADADACACACABABABAAAAAA
AAAAA9A9A8A8A7A7A6A6A6A5A5A5A4A4A3A3A2A2A1A1A1A0
A0A09F9F9F9E9E9E9D9D9D9C9C9C9C9C9B9B9B9C9C9C9C9C
9D9D9D9E9E9E9E9F9FA0A0A1A2A2A2A3A3A4A4A4A4A5A5A6
A6A7A7A8A8A8A8A9A9AAAAAAABABABACACACACADADADADAE
AEAEAFAFAFAFB0B0
B0B0B0AFAFAFAFAFAFAFAFAFAEAEAEAEAEAEADADADADADAD
ADADACACACACACACABABABABABAAAAAAA9A9A9A8A8A8A8A8
A8A8A7A7A7A7A7A7A6A6A6A6A6A6A6A6A5A5A6A6A6A6A6A6
A6A6A7A7A7A7A7A7A7A8A8A8A9A9A9A9AAAAAAAAAAAAABAB
ABABACACACACACADADADADADADADADAEAEAEAEAEAEAEAEAE
AFAFAFAFAFB0B0B0
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.343006 0.321429 0.640625 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00751202 0.0192308 0.00751202 [
[.5 1.0125 -17 0 ]
[.5 1.0125 17 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
69.000000 12.812500 moveto
(deg) show
87.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(.) show
93.000000 12.812500 moveto
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
128 string
128 128 8 [128 0 0 128 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
93939393929292929291908F8F8F8F908F8F909090908F8C
90908F909091919192929292929394949594949595959595
959696969696969696969696969595969695959595959596
969696969696969797979798989694979797979797979898
989898989998989999999999989898979797969696969696
9695949797969594
9393939392919190908F8D8B8A8B8B8B8B8B8C8C8C8D8B87
8B8C8C8C8C8D8E8F90919192929394959596969696969797
969798989898989898989898989897989897979797979898
989898999999999A9A9A9B9C9C9A96999B9B9B9B9B9B9C9C
9C9C9D9D9D9D9D9E9E9E9E9E9D9D9C9B9B9B9A9999999998
989797999A989795
939393929191908F8E8D8B89878787878787888888888884
85898888898A8B8C8E8F9091929394959797979797979898
9898999A9A9A9A9A9A9A9A9A9A9A9A9A9999999999999A9A
9A9B9B9B9C9C9C9D9D9E9E9F9F9F9B999C9F9F9F9F9F9FA0
A1A1A1A2A2A2A2A2A3A3A3A2A2A1A0A09F9F9E9D9C9C9B9B
9B98989A9B9A9895
9392929190908F8E8D8B8A88868483838383848484848483
7F8284848586888A8C8D8F90919394959798989899999999
9999999A9B9B9B9B9B9B9C9C9C9C9C9C9C9C9C9C9C9C9C9C
9D9D9E9E9E9F9FA0A0A1A1A2A2A2A2A09D9FA3A2A3A3A3A4
A4A5A5A6A7A7A7A7A8A8A7A7A7A6A5A4A4A3A3A1A09E9E9E
9D9C9A9B9C9B9996
93929191908F8E8D8C8A8987858382807F7F7F8080808080
7E7D7F8081828587898B8E909193949698999A9A9A9B9A9A
9A9A9A9A9B9C9C9C9D9D9D9D9D9D9E9E9E9E9E9F9E9E9F9F
A0A0A0A1A1A2A2A3A3A4A4A5A5A6A6A6A4A2A5A7A7A7A7A8
A9AAAAABABACACACACADADACACABAAA9A9A8A8A6A4A2A2A1
9F9F9D9D9E9B9896
939291908F8E8D8C8B8A88868583817F7D7C7C7C7C7C7D7D
7C797A7C7E7F818487898C8E91939597999A9B9C9C9D9C9C
9C9B9B9B9B9C9D9D9D9E9E9F9F9F9FA0A0A0A0A1A1A1A2A2
A3A3A3A4A4A5A5A6A7A7A8A9A9A9A9AAAAA8A7AAABABACAD
ADAEAFB0B0B1B1B1B1B2B2B1B1B0AFAFAFAEADABA9A7A7A5
A3A29F9F9E9C9996
9392908F8E8D8C8B8A8987868482807E7C7A797879797979
797877787A7C7E8184878B8E909395989A9B9C9D9E9F9E9E
9E9D9C9C9B9C9C9D9E9F9FA0A0A1A1A1A2A2A3A3A3A4A4A5
A6A6A7A7A8A8A9AAAAABABACACADADAEAEAFADACAEB0B0B1
B2B3B4B5B5B6B6B6B7B6B7B7B6B5B5B4B4B3B2B0AEAAAAA8
A6A4A2A29F9C9996
9392918F8E8D8B8A898886858382807E7C7A787776767676
76767574767A7C7E8285898C909295989A9C9D9E9FA0A1A0
A09F9E9E9D9D9D9E9E9F9FA0A0A1A2A2A3A3A4A5A5A6A7A7
A8A9AAAAABACACADADAEAFB0B0B0B1B1B2B3B4B3B2B3B4B6
B7B8B9BABBBBBBBCBCBCBCBCBBBBBAB9B7B7B6B3B2AFADAB
A8A6A4A4A19D9A97
9291908F8E8C8B8A8887858482817F7E7C7A787775757474
737373727174787C7F83888C8F9295989B9D9E9FA0A2A3A3
A2A1A0A09F9E9D9E9F9F9FA0A1A1A1A2A3A4A5A6A6A7A8A9
AAABACADADAEAFB0B0B1B2B2B3B3B4B5B5B6B8B8B8B7B8BA
BCBDBEBFC0C0C0C1C1C1C1C1C0C0BEBCBABAB9B6B3B1AFAD
AAA7A6A4A29E9A97
9291908F8D8C8A898886858382807F7D7C7A787775747373
73727171717073797E81868B8F93969A9D9FA1A2A2A3A4A4
A4A3A2A1A1A09F9F9FA0A0A1A1A2A2A2A3A3A4A5A5A6A8A8
AAABACADAEAFB0B1B1B2B3B4B5B6B6B7B8B9B9BABBBBBBBB
BCBFC3C3C4C4C5C6C6C7C8C7C5C4C1BFBDBCBAB8B5B3B1B0
ABA9A8A5A29E9B97
9291908E8D8C8A8887858482817F7E7C7B79777675747372
72717070706F70747B80858B9094979B9DA1A3A4A4A5A6A6
A6A5A4A3A2A1A1A0A0A1A1A2A2A2A3A3A3A4A5A6A6A7A8A9
AAACADAEAFB1B2B3B4B5B6B7B7B9B9BABBBCBDBDBEBFBFC0
C0BFC3C4C6C8C9CACAC9C8C8C7C6C5C2C0BFBBBAB8B5B3B1
ADAAA8A6A29F9B97
9291908E8C8B898886858382807F7D7B7A79777674737271
70706F6F6E6E6D70767D838A91969A9DA0A3A5A6A7A7A7A8
A7A6A6A5A4A3A2A2A1A2A2A3A3A3A4A4A5A5A6A7A8A9AAAB
ACADAFB0B2B3B4B5B7B8B9BABBBCBDBEBEBFC0C1C2C2C3C4
C5C5C7C7C7C8C9CBCBCAC9C9C9C8C8C5C3C2BDBCBAB6B5B2
AEACA8A5A29F9B97
92918F8E8C8B898786848381807E7D7B7978767574737170
6F6E6E6D6D6C6B6E7178808691999DA0A3A5A7A8A9A9A9A9
A9A8A7A6A5A4A4A3A3A3A3A4A4A5A5A5A6A6A7A8A9AAACAD
AEAFB1B2B4B5B7B8BABBBCBDBEBFC0C1C1C3C4C5C5C6C7C8
C9CACBCCCDCDCBCBCBCBCACACAC9C8C6C5C3BEBDBBB7B6B3
B0ADA9A6A29F9B97
92918F8D8C8B8987858482817F7D7C7A797776747372716F
6E6D6D6C6B6A696B6D727B828C97A0A3A6A8AAABABABABAB
AAA9A8A7A6A5A5A4A4A4A4A4A5A6A6A7A7A8A8A9AAABADAE
B0B1B2B4B6B7B9BBBCBEBFC0C1C2C3C4C4C6C7C8C9CACBCB
CCCDCECECECECDCCCBCACBCBCACAC9C7C6C3C0BEBCB9B6B4
B1AEAAA6A29F9B97
92918F8D8C8A8887858381807E7D7B7A787775747271706E
6D6C6B6A6969686A6A6E767E87919FA8AAACADAEAEADADAD
ACAAA9A8A7A7A6A5A5A5A4A5A5A6A7A7A8A9A9AAABACAEB0
B1B3B4B6B8B9BBBDBFC1C2C3C4C5C6C7C8C9CACBCCCDCECF
CFD0D0D0D0CFCECECDCBCBCBCBCACAC8C7C4C1BEBBB9B6B4
B1AEAAA6A39F9B97
92908F8D8B8A88868483817F7E7C7A797775747271706F6D
6C6B6A6968676668686A707A828C98A6AEAFB1B1B1B0AFAE
ADABAAA9A8A7A6A6A5A5A5A6A6A7A7A8A9AAAAABACADAFB1
B2B4B6B8BABBBDBFC2C3C5C6C7C8C9CACBCCCDCED0D1D2D2
D2D3D3D3D2D0CFD0CFCDCBCBCBCBCBC9C7C4C2BFBCB9B6B4
B2AEABA7A39F9B97
92908E8C8B8987868482817F7D7B7A7876757371706F6D6C
6B6A69676665656566686D767E87929FACB4B4B4B4B2B0AF
AEACABAAA8A7A6A6A6A5A5A6A6A6A7A8AAAAABACADAEB0B1
B3B5B7BABCBDBFC1C4C6C7C9CACBCCCECECECFD0D1D2D4D4
D4D4D4D4D4D2D0D0CFCFCECDCBCACAC9C7C5C3C0BEBAB7B4
B1AEAAA7A29F9B97
92908E8C8A8887858381807E7C7B7978767472716F6E6C6B
696867666564646365656B727A838D98A4B2BAB8B6B4B2B0
AEACABA9A8A8A6A6A6A5A6A6A6A7A7A8AAABACADAEAFB0B2
B4B6B8BBBDBFC1C3C5C7C9CBCCCECFD0D1D1D1D2D3D4D5D6
D5D5D5D5D4D4D2D2D1D0CFCECDCBCAC9C7C5C3C0BEBBB7B4
B1ADAAA6A29E9B97
92908E8C8A88868583817F7E7C7A7876757371706E6D6B6A
68676564636261616262696F767F89939EAAB7BCB8B5B2B0
AEACABA9A8A7A6A6A5A5A5A6A6A7A7A8A9AAABADAEB0B1B3
B5B7B9BBBEC0C3C5C7C9CBCDCED0D1D2D3D4D3D4D4D5D6D7
D6D6D7D6D6D5D4D4D2D0CFCECDCCCBC9C7C5C3C1BEBBB8B4
B1ADAAA6A29F9B98
918F8E8C8A88868482807E7D7B7977767472706E6D6B6A69
6765646261605F5F6061676D747C848E98A4AFBAB8B6B3B0
AEACAAA8A8A7A6A6A5A5A5A6A6A7A7A8A9AAABADAEB0B1B3
B5B7B9BCBFC2C4C6C8CACCCFD0D2D3D4D5D6D5D5D4D6D5D7
D7D8D8D7D7D7D6D5D4D2D1D0CFCDCCCAC8C6C3C1BEBBB8B4
B1ADAAA6A29F9B97
918F8D8C8A88868482807E7C7A78767573716F6E6C6A6967
65646261605E5E5D5E60656A7179818A939EAAB6BAB6B2AF
ADABAAA8A7A6A5A5A5A4A4A5A6A6A7A8A9AAABACAEB0B2B3
B5B7BABCBFC2C5C8C9CBCDD0D2D3D5D6D6D7D6D6D5D5D6D6
D7D8D8D7D7D8D8D7D6D5D3D2D1CFCDCBC9C6C4C1BEBBB8B4
B1ADAAA6A29F9B97
918F8D8B89878583817F7D7B7977757472706E6D6B696766
6462615F5E5D5C5B5C5F646970777E87909AA5AFB8B5B1AF
ACAAA8A7A6A5A4A4A4A4A4A4A5A6A7A7A8A9ABACAEB0B1B4
B5B7BABCBFC2C6C9CACCCFD1D3D4D6D7D8D8D6D6D7D7D7D8
DADAD9D9D8D9D9D7D7D6D5D3D2D0CECCC9C7C4C2BEBBB8B5
B1ADAAA6A29F9B97
918F8D8B89878583817F7D7B79777473716F6D6B6A686664
63615F5D5C5B5A595B5D62686F767C858E97A1ABB6B3B0AD
AAA8A7A5A4A3A3A2A2A3A3A3A4A5A6A7A8A9AAACADAFB1B3
B5B7B9BCBFC3C6C9CBCDD0D2D4D5D6D7D8D8D6D6D6D8D8D9
DBDBDBDAD9D9D9D8D8D7D7D6D4D2D0CDCAC8C4C2BFBCB8B5
B1ADAAA6A29F9B97
918F8D8A89878583807E7C7A78767472706E6C6A68676563
61605E5C5A595857595C60666C737B838C949EA7B3B0AEAB
A8A7A5A3A2A1A1A1A1A1A2A2A3A4A5A6A7A8AAABACAEB0B2
B4B7B9BBBFC2C6C9CBCED0D2D4D5D7D7D9D9D7D6D6D7D8D9
DBDCDCDCDBDADAD9D9D8D8D7D6D3D1CECBC8C6C2BFBCB9B5
B1ADAAA6A29F9B97
918F8D8A88868482807E7C7A787573716F6D6B6967666462
605E5D5B59575655585B5F656B71798189929CA6B0ADABA8
A6A4A2A1A09F9F9F9F9FA0A0A1A2A3A5A6A7A8AAABADAFB1
B3B5B8BABEC2C5C8CBCED0D3D4D6D7D8DADAD9D7D6D7D9DA
DCDDDEDEDDDBDAD9DAD9D8D8D8D5D2CFCCC9C6C3BFBCB9B5
B1ADAAA6A29F9B97
918F8C8A88868482807D7B79777572706E6C6A6866656261
5F5D5B5957555455575A5E646A707880878F99A3AEAAA8A5
A3A1A09E9D9D9C9C9C9C9D9E9FA0A1A3A4A5A6A8AAACAEB0
B2B4B6B9BDC0C3C6CACDD0D2D4D6D8DADBDBDAD8D7D7D8DA
DCDDDEDFDFDEDCDBDBDAD9D9D9D6D4D0CDCAC7C3C0BCB9B5
B1AEAAA6A29F9B97
918F8C8A888684817F7D7B79767472706E6B69676563615F
5E5B5A5856545254575A5E64696F777D848D97A0AAA7A5A2
A09E9D9B9A9A999899999A9B9C9D9FA0A2A3A5A6A8AAACAE
B0B3B5B8BCBEC1C5C9CCCFD1D4D6D8DADCDDDCDAD9D8D8D9
DBDEE0E0E0DFDEDCDCDCDCDBDAD7D5D2CECAC7C4C0BDB9B5
B1AEAAA6A29E9B97
918F8C8A888583817F7C7A787673716F6D6B69676562605E
5C5A58565452515355595D63686E757B828C959DA7A3A29F
9D9B99989796969595969697989A9C9EA0A1A3A4A6A8AAAC
AFB1B3B6BABDC0C4C7CACDD0D4D6D8DADBDDDDDCDAD8D7D8
DBDDE0E1E1E1DFDEDEDEDEDDDBD8D6D2CFCCC8C4C0BDB9B5
B2AEAAA6A29F9B97
918F8C8A878583817E7C79777573706E6C6A676563615F5D
5B5957555351515255585D63676D737A8089929AA3A09D9B
9997959493929191919192939496979A9C9EA0A1A3A5A7AA
ACAFB1B4B6BABEC2C5C9CCD0D4D8D9DADBDDDEDEDDDBD9D7
D9DDDFE1E2E2E1E0DFDFDFDFDCD9D6D3CFCCC8C5C1BDBAB6
B2AEAAA6A29F9B97
918E8C89878582807E7B79767472706D6B69666562605E5C
5A5755535150505255585C62676D71787E868E969F9B9997
9492918F8E8D8D8D8C8C8D8F90929395989A9C9EA0A2A4A7
A9ACAFB2B3B7BCC0C3C8CCCFD3D7D9DADCDDDFE0DFDCDBD9
DADCDEE1E2E3E2E1E0E1E0DFDDDAD7D4D0CCC9C5C1BDBAB6
B2AEAAA6A29F9B97
918E8C89878482807D7B787673716E6C6A686664615F5C5A
58565452504F505155585C61666B70767C838A929A969491
8F8D8C8B8A898888878788898A8C8E909395989A9C9FA1A3
A6A9ACB0B1B5BABDC1C6CACED1D6D9D9DBDDDFE1E0DEDCDB
DBDDDFE2E3E3E2E2E1E1E1E0DEDAD7D4D0CDC9C5C1BDBAB6
B2AEAAA6A39F9B97
918E8C898784817F7C7A787573706E6B69676462605E5B59
575553504E4E4F5155585C61646A6E757A80878D93918E8C
8A89878686858484838282828486888B8D909395989A9D9F
A2A6AAADAEB2B7BABEC3C8CDD0D5D8D9DBDDDFE2E2E0DDDB
DBDDDFE2E5E4E3E3E3E3E2E1DEDBD7D4D1CDC9C5C2BEBAB6
B2AFABA7A39F9B97
918E8C898684817F7C797774726F6D6A686663615F5D5A58
5654514F4E4E4F5155585D6164696D74787D83898C8B8A88
8786858483828181807F7F7E7E7F818487898C8F9296989B
9EA2A6ABACAFB3B5BAC0C6CCCED4D7D9DADCDFE2E3E2DFDD
DCDDDFE2E5E6E5E5E5E4E4E3DFDCD9D5D1CDCAC6C2BEBAB6
B3AFABA7A39F9B97
918E8B898683817E7C797674716F6C6A676562605E5B5957
5452504D4D4E4F5255585C6065686D73777B7F8386868686
8584838281807F7F7E7D7C7C7B7B7B7D7F83868A8D909497
9A9EA3A9ACADB1B1B7BDC5CBCDD1D6D8D9DCDEE1E3E3E1DF
DDDDE0E3E6E7E7E6E6E5E5E3E0DDD9D5D2CDCAC6C2BEBAB6
B3AFABA7A39F9B97
918E8B888583807D7B787673706E6B696664615F5D5A5755
53514F4D4C4E4F52565A5D6165686E7276797B7F82838383
8382818180807F7E7D7C7A7A79797878797B7F83878A8E92
969A9FA5ABABB0AEB2B9C0C9CDCED4D7D8DCDEE1E4E4E4E1
DEDDE0E4E6E7E8E8E7E7E7E4E0DDD9D6D2CECAC6C2BEBAB6
B2AFABA7A39F9B97
918E8B888583807D7A7775726F6D6A686563605E5B595754
52504E4D4C4E5052565A5E6164696E72767A7B7D7F808181
818180807F7F7E7E7D7B7A79787776757576787B8084888C
91969BA2AAA9ADADAFB6BDC5CACCD1D5D8DBDFE1E4E5E5E4
E0DEE0E4E7E9EAE9E8E8E8E5E1DDDAD6D2CECAC6C2BEBAB7
B3AFABA7A39F9B98
918E8B8885827F7C7A7774716E6C696764625F5D5A585653
514F4D4C4C4E5053575B5F62656A6E717577797A7C7E7F7F
808080807F7F7F7E7D7B7A797776757473727374787D8186
8C91989FA9ABABAEADB2B9C2C8CDD0D4D7DADEE1E4E6E6E6
E2DFE0E4E7E9EBECEAE9E8E5E2DEDAD7D2CECAC6C2BEBBB7
B3AFABA7A39F9B97
908E8A8885827E7C797673706D6B686663605E5C59565452
504E4D4B4D4F5254575C5F63666B6E71737577787A7B7D7E
7F7F7F807F7F7F7F7E7C7B79777574727170707071757A80
868C939CA6ACABAFB0B2B7BEC4CBCFD2D7DADEE2E4E7E6E7
E5E1E0E4E8EAEBEDECEAE8E5E2DEDAD7D3CFCBC7C2BEBBB7
B3AFABA7A39F9B97
908D8A8784817E7B787573706D6A6764625F5D5B58565350
4F4D4C4C4D505356595D6064686C6F707173747677797A7C
7D7E7E7F7F7E7F7F7E7D7C7977757371706E6E6E6E6F7278
7F878E98A3ABAEAEB2B3B7BCC2C9CED0D5D9DDE1E4E6E8E8
E7E4E2E4E7E9ECEEEDECE9E5E2DFDBD7D3CFCBC7C3BFBAB7
B3AFABA7A39F9B97
908D8A8784817E7B7774716F6C696663615E5C595754524F
4E4D4B4C4E5153575B5E6165696C6E6F7071727375767879
7A7B7B7C7C7C7D7D7D7D7C7A787572706E6C6C6B6C6D6E72
79818A94A0A9AFB0B4B8B9BCBFC6CCD0D3D7DCE0E5E7E9E9
E9E8E4E5E8EAECEEEEEEE9E6E2DFDBD7D3CFCBC7C3BFBAB7
B3AFABA7A39F9B97
908D8A8784807D7A7774716E6B6865625F5D5A585653514F
4D4C4C4D4F5356585D6063676B706E6E6E6F6F7071737677
777777787878797B7B7C7C7A7775726F6C6B6A69696A6B6D
717A848F9CA7B0B2B3B9BCBEC1C4C9CFD3D6DBE0E5E8EAEB
EBEAE7E7E9EBEEEFEFEEEBE7E3DFDBD7D3CFCBC7C3BFBAB7
B3AFABA7A39F9B97
908D8A8683807D7A7673706D6A6764615E5B595654524F4D
4D4C4D4E5154585A5E6165696C6D6D6C6C6C6C6C6E6F7071
7071727373737475767778797774716E6B6968676767686A
6C727D8997A4AEB6B6B9C0C1C5C7C9CDD1D5DADFE4E8EAEC
EDEDEAE9EBEDEFF1F1EDEAE7E3E0DBD7D3CFCBC7C3BFBBB7
B3AFABA7A39F9B97
908D8986837F7C7976726F6C696663605D5A585552504E4D
4D4D4E4F52575A5D6065686B6E6C6B6B6A696867696A6C6E
6F6E6F6F707071727372737576726F6C6967666565656668
6A6E758391A0AAB5B9BBC1C4C7CBCBCCD1D5D9DEE4E8EBED
EFEFEDEAEBEEF0F2F2EEEBE7E3E0DCD7D3CFCBC7C3BFBBB7
B3AFABA7A39F9B97
908D8986827F7C7875726E6B6865625E5B595654514F4C4B
4B4C4E5154585B5F63666A6D6D6C6B696866656364666768
68696968696A6B6C6E6F6E6F71716E6A6866656363646566
686C717C8B9BA8B4BABDC1C8CACFD1CFD0D4D9DEE3E8EBEE
F1F1EFECECEEF0F2F3EFEBE8E4E0DCD7D3CFCBC7C3BFBBB7
B3AFABA7A39F9B97
908D8986827E7B7774716D6A6663605D5A575552504D4B4A
4A4D4F52565A5E6165696D6E6D6C6A686662605C5C5D5E5F
5F60605F5F60616364656465676869676564636261626365
666A6E768596A5B0B9BFC1C8CDD1D6D5D3D4D9DDE2E7EBEE
F2F3F2F0EEF1F1F3F2EFECE8E4E0DCD7D3CFCBC7C3BFBBB7
B3AFABA7A39F9B97
908C8985817E7A7773706C6965625F5B585653504E4B4A49
4A4D5053585C6065696D726F6E6C6A6765625F5B58575758
5858595959595B5C5E616262646465646362616160616264
66686C737F8FA0ACB7BFC3C7CFD3D9DAD9D6D9DDE1E7EBEF
F3F4F5F2F0F2F3F6F3EFECE8E4E0DBD7D3CFCBC7C2BFBBB7
B3AFABA7A39F9B97
908C8885817D7A76726F6B6864615D5A5754514E4C4A4949
4A4D5155595E63686C7172706E6C6A676562605D5B595858
5958595A5B5B5C5D5F6061626262626261605F5F5F606162
65686B717B8A9CA8B3BBC2C6CFD5D9DDDDDBDBDDE1E6EBF0
F4F6F7F4F2F3F4F7F3EFECE8E4E0DBD7D3CFCBC7C3BFBAB6
B2AFABA7A39F9B97
908C8884817D7975726E6A66635F5C5855524F4C49474748
4A4D51565B60656A707674716F6C6A676562605E5C5B5A59
59595A5B5B5C5D5E5F6061616161605F5F5E5E5D5E5E5F61
6366696E778597A6B1BAC2C7CDD5DBE0E1E0DFDFE2E6EAEF
F2F6F8F7F4F4F5F7F4EFECE9E4E0DBD7D3CFCAC6C2BEBAB6
B2AFABA7A39F9B97
8F8C8884807C7874716D6965615E5A5753504D4A48464547
4A4E52575C62686D72797572706D6A686563615F5D5C5B5A
5A5A5B5C5C5D5E5F6061616160605F5D5C5C5C5C5C5D5E60
6265696D758291A2ADB7BFC6CCD4DBE2E4E4E2E1E3E7EAF0
F2F6F8F8F5F5F6F6F4F0ECE8E4DFDBD7D2CECAC6C2BEBAB6
B2AFAAA7A39F9B97
8F8B87837F7B7774706C6864605C5955524E4A4745444547
4B4E53585E636A6F75797673706D6B68666361605E5C5B5B
5A5A5B5C5D5E5F6061616161605F5E5D5C5B5A5A5B5B5C5E
6063676C727D8D9DABB5BEC5CCD2DAE2E6E6E6E5E4E7EAF0
F4F7F9F9F7F5F7F5F4F0ECE8E4DFDBD6D2CECAC6C2BEBAB6
B2AEAAA7A39F9B97
8F8B87837F7B77736F6B67635F5B57534F4C484542424447
4B50545A60666B7179787673706E6B68666462605E5C5B5A
5958585A5C5D5F6061626161605F5D5C5A5A5959595A5B5D
5F61656A707A899AA8B3BDC3CBD0D8DFE8E9E9E7E5E8EAEF
F4F8FAFBF8F6F7F5F4F1EDE8E3DFDAD6D2CECAC6C2BEBAB6
B2AEAAA6A39F9B97
8F8B87837E7A76726E6A66625E5A56524E4A464240404347
4B50565B61676D747C787673716E6B69666462605E5C5C5B
585656575B5D5E5F616261615F5E5D5B5A59595858595A5B
5D6063686E768395A4B0BAC2CACFD6DEE6EAEAEAE8E8EBEF
F5F8FBFCFAF8F6F7F3F0ECE7E3DEDAD6D1CEC9C5C1BDB9B6
B2AEAAA6A39F9B97
8F8B87827E7A75716D6965615C5854504C4844403D3F4246
4B50565C62686F767C787673706D6B69666462605E5A5859
5755545355585A5B5E6161615F5E5C5B5A5958575758595A
5C5F62666B737E909FADB7BFC7CFD4DDE4ECEBEBEAE8EBEE
F4F8FBFDFCFAF7F7F3EFEBE7E2DEDAD5D1CDC9C5C1BDB9B5
B2AEAAA6A39F9B97
8F8B86827D7975706C67635F5B57524E4A46423D3B3E4247
4C51565D636970777B787573706E6B69666462605F5C5A58
5755545455585A5B5C5E60605F5D5C5B5959585757575858
5A5D60646A70798B9AA9B3BDC4CDD2DAE0EBEBEBEAE8EBEE
F3F8FBFDFDFAF7F5F3EFEAE6E2DDD9D5D1CDC9C5C1BDB9B5
B1AEAAA6A29F9B97
8F8A86817D78746F6B66625E5955514C48443F3B393D4246
4C52575D636A727979777472706E6B69676562615F5D5B59
575655545658595B5C5E5F5F5E5D5C5B5A59585757575758
595B5E62676E768596A5B0BBC1CAD0D8DFE8EBECEBE8EAEE
F2F8FCFEFDFAF8F5F2EEE9E5E1DDD9D4D0CCC8C4C0BDB9B5
B1ADAAA6A29F9B97
8F8A86817C78736E6A65615D58534F4B46423D39393D4248
4D52585E646B737C78767472706E6C6A67656361605E5C5B
585655555658595B5C5D5E5E5E5D5C5B5A59585757575758
585A5D60656B737F91A1ACB7BFC7CED6DEE6EAEBEBE9E9EE
F2F8FBFEFDFAF9F6F1EDE9E5E0DCD8D4D0CCC8C4C0BCB9B5
B1ADA9A6A29E9B97
8F8A86817C77726D69645F5B56524D4944403B36383D4148
4C52585E656C727A777573716F6E6C6A68666462605F5D5B
595756565658595A5C5D5E5E5E5E5D5B5B5A595857575758
595A5B5F646A717C8D9CAAB4BDC5CCD3DBE4E8EAEBEAE8ED
F2F8FCFFFDF9F8F4F0ECE8E3DFDBD7D3CFCBC7C4C0BCB8B4
B1ADA9A6A29E9B97
8F8A85807B76726D68635E5A55504C47423E3934373C4248
4D53585D656B7175757472706F6E6C6A69676563615F5E5C
595756565658595B5C5E5E5E5E5E5D5C5B5B5A5958585858
595A5C5E626970788999A6B2BBC3CCD2DAE2E7E9EAEAE8ED
F1F8FCFFFDFAF8F4EFEBE7E3DFDAD6D2CFCBC7C3BFBBB8B4
B0ADA9A5A29E9B97
8F8A85807B76716C67625D58544F4A45403C3734373C4348
4D53595F656C6F72727271706F6D6D6C6A68666462605E5D
5A58565556585A5B5D5E5F5F5E5E5E5D5D5C5B5A5A595959
595A5C5E61676F778494A2AEB9C1CAD1D9E1E6E8EAEBE8EC
F1F8FCFFFEFAF7F3EEEAE6E2DEDAD6D2CECAC6C3BFBBB7B4
B0ADA9A5A29E9A97
8F8A84807A75706B66615C57524D48433E393435383D4449
4E54585F66707071717170706F6E6D6C6B69686664625F5E
5B58565657595A5B5D5F5F60605F5F5F5E5E5D5C5C5B5A5A
5A5B5D5F61676E778392A0ADB7C0C9D0D8E0E5E7E9EBE9EC
F0F8FCFFFEFBF6F2EEE9E5E1DDD9D5D1CDC9C5C2BEBBB7B3
B0ACA9A5A29E9A97
8E89847F7A756F6A65605B55504C46413C373033373D4449
4F555A61686E6F707070706F6F6E6E6D6C6B6A676563615F
5C5A575657595B5C5E5F6061616161606060605F5E5E5D5C
5C5D5E6062676D7682909EABB6C0C8D0D9E0E4E6E9EAEAEB
F0F7FCFFFFFAF6F1EDE8E4E0DCD8D4D0CCC9C5C1BEBAB6B3
AFACA8A5A19E9A97
8E89847E79746F69645F59544F4A453F3A353033373D444B
50565D62696C6E6F6F6F706F6F6F6E6E6E6D6C6A67656260
5D5A575556585B5C5E60616162626262626262626161605F
5E5E5F6163666D75808E9CAAB6C0C8D0D9E2E3E6E8EAECEB
F2F7FBFEFEFAF5F0ECE7E3DFDBD7D3CFCCC8C4C1BDBAB6B3
AFABA8A5A19E9A97
8E89837E78736E68635E58534E48433E39343135383E444B
51585F666A6C6D6E6E6F6F6F6F6F6F6F6F6F6E6C6A676461
5E5B585555575A5C5E606162626363646565656564646261
6160616264676D757F8C9BA8B5BFC7CFD8E1E3E6E8EAEEEB
F3F7FAFDFDF8F3EFEBE6E2DEDAD6D2CFCBC7C3C0BCB9B5B2
AFABA8A4A19E9A97
8E88837D78726D67625C57524C47413C373132343940454C
525A616A6B6C6E6E6E6E6E6F6F6F70707171706E6C696562
5F5B58555556585B5D5F6162626364666768686868676664
6363636465696D757F8A99A7B4BFC7CFD7E0E2E5E8E9EFEB
F2F8FAFBFBF6F2EDE9E5E1DDD9D5D1CECAC6C3BFBCB8B5B2
AEABA7A4A19D9A97
8E88827D77716C66615B56504B45403A352E34353A41474D
545D63696B6D6E6D6D6D6D6E6F707171727373716E6B6763
605B5854535457595C5E606162636467696A6B6C6C6B6968
66656565676A6F757E8896A6B3BEC7CFD7E0E2E4E8E8EFEB
F1F8FAFBF9F5F0ECE8E4E0DCD8D4D0CDC9C6C2BFBBB8B4B1
AEABA7A4A19D9A97
8E88827C76716B65605A544F49433E38332C33363D43494F
575F67686C6E6D6C6C6C6C6D6E70717273747473706C6764
605B575351525457595C5F60616263666A6B6C6D6E6E6C6A
69686767686B70767E8894A2B1BEC7CFD6DEE2E3E6E8EEEB
F1F8F9FAF8F3EEEAE6E2DEDAD7D3CFCCC8C5C1BEBAB7B4B1
ADAAA7A4A09D9A97
8E88827C76706A645F59534D48423C37322F32363E444B50
5A6166676B6D6D6B6B6A6B6C6E6D6C6F73747573726E6864
5F5A56524F4E505357595E605F5E5F63686A6C6D6F706E6C
6A6969696A6C71777F8894A0B0BDC6CFD6DDE0E2E6E8EEEB
F0F6F7F8F6F1EDE9E5E1DDD9D5D2CECBC7C4C0BDBAB7B3B0
ADAAA6A3A09D9A97
8D87817B756F69635D57524C46403B352E2E31363D464D52
5D6766686A6D6B6A696868696B6A686A6D7172716F6D6863
5E5954504D4B4C4E5252555B5A595B5E636669696D6F6F6C
6B6A696A6B6D71787F8994A0AFBCC5CED6DCDFE2E5E7EDEB
F2F5F6F7F3EFEBE7E3DFDBD8D4D1CDCAC6C3C0BCB9B6B3B0
ACA9A6A3A09D9A97
8D87817B756E68625C56504A443F39342D2C31373E474E54
5C6767696B6C6B68656463666A696466666D6D6F6C6A6661
5C57524E4B4847494B4F50555853575860616564696C6C6C
6B6A696A6C6E72787F88929EADBBC5CDD5DBDFE1E4E7ECEA
F2F5F5F5F1EDE9E5E1DDDAD6D3CFCCC9C5C2BFBBB8B5B2AF
ACA9A6A3A09D9A96
8D87817A746E68615B554F49433D3733322D30363E474F57
5F6767696B6C6966625F5D5E62636365626565676664625E
5A55504C4946434345484C4E514E5352585B5F5F62656768
696969696B6E72787F87909CAAB7C3CCD5D9DDE1E5E7EAE9
F0F3F4F2EEEAE7E3DFDCD8D5D1CECBC7C4C1BEBBB8B4B1AE
ABA8A5A29F9C9996
8D87807A736D67605A544D47413B342E302F313840475059
6267686A6C6C68645F5A56565858585A5C5E5F60605F5D5B
57534F4A47434140404244484A4747494D5255585A5D6062
646667686A6D71787F87909BA9B5C0CBD3D8DBDFE4E6E9E8
EEF1F2EFECE8E4E1DDDAD7D3D0CDC9C6C3C0BDBAB7B4B1AE
ABA8A5A29F9C9996
8D868079736C665F59524C453F39322A2A2F32394149505A
6267696B6D6C68645F5A55525050505254575A5D5D5C5A57
54514D4945423F3E3E3F41424444444446484C5054575A5D
61636567696C70777E87919CA8B4BEC9D3D7DADEE4E6E8E7
EDF0EFECE9E6E2DFDBD8D5D2CECBC8C5C2BFBCB9B6B3B0AD
AAA7A5A29F9C9996
8D867F79726C655E57514A443D37302A262D323941484F5A
62676A6B6D6D6965615C58555351515456585A5B59595755
524F4C4845413D3B3B3C3F424444434345474B4E5255585B
5E616365686C70767E86909BA8B4BEC8D1D7D9DEE4E6E8E7
ECF0EDEAE7E3E0DDDAD6D3D0CDCAC7C4C1BEBBB8B5B2AFAD
AAA7A4A19F9C9996
8D867F78726B645D564F48423B352F2A222B30373F474E58
60666A6C6E6D6966635F5B58565454535454545656565553
514E4B4845413D3A3736393D4145464648494C4E52545759
5C5F6163666A6F757D868F9BA6B2BDC7CED4D8DDE3E5E8E8
ECEEEBE7E4E1DEDBD8D4D1CECBC8C5C3C0BDBAB7B4B2AFAC
A9A6A4A19E9C9996
8D867F78716A635C554E474039322C2A21282E343C454C56
5E656A6C6E6D696564615E5B585553514F51535454545351
504D4B4845423E3B38353335383D4246484B4D4F52545658
595C5E6164696E747B838F99A5B1BEC8CED3D7DBE1E4E6E9
ECECE8E5E2DFDCD9D6D3D0CDCAC7C4C1BEBCB9B6B4B1AEAB
A9A6A3A19E9B9996
8C857E777069625B544D453E372F272724272C3238424A53
5B61676B6E6D6963605D5B58555352525252535454535251
4F4D4B484543403D3A38363636383A3D3F44484B4D505154
575A5C5F63676D727B838E99A5B1BDC8CCD1D6D9DFE2E4E8
EBE9E5E2DFDCD9D6D3D1CECBC8C5C3C0BDBAB8B5B3B0ADAB
A8A5A3A09E9B9996
8C857E777069615A534B443C342C232022262C2F363E4750
575F65696D6D6965615D5957555555545454545454535251
4F4D4B494744423F3D3B3A39393A3C3E3E404245484C4F51
55585B5E62676C7178828D99A4B0BCC7CACFD5D7DEE1E1E7
E9E6E3E0DDDAD7D4D1CFCCC9C7C4C1BFBCB9B7B4B2AFADAA
A8A5A2A09D9B9896
8C857E776F686159524A423A3229201C20242B2E343C444D
555C63686D6D6A6663605C5A585757565655555554535251
4F4E4C4A48464442403E3D3C3D3D3E3F40424346484B4E50
5456595C60666B7178808B96A2AFBBC7C8CDD4D5DBE0E0E5
E6E2E0DDDAD7D5D2CFCDCAC7C5C2C0BDBBB8B6B3B1AEACA9
A7A4A2A09D9B9896
8C857E766F6860585149413830261C171D22292D3339414A
525A61666B6D6A6764625F5C5B5A58575756565555545352
504E4D4B494846444341403F3F3F404142434546484A4D50
5255585C60656B7178818B96A2B0BCC8C9CCD2D3D8DEDFE4
E2DFDCDAD7D5D2D0CDCBC8C6C3C1BEBCB9B7B5B2B0ADABA9
A6A4A29F9D9B9896
8C857D766F676058504840372E251B131A20272C31383F47
4F575F64686B6A686563605E5C5B5A595857575656555452
51504E4D4B494846454443424242424344454647494B4D4F
5255585B5F656A7178818B96A2AFBCC7CACBD0D1D5DBDEE1
DEDCD9D7D5D2D0CDCBC9C6C4C2BFBDBBB8B6B4B1AFADAAA8
A6A3A19F9D9A9896
8C857D766E675F574F473F362D241A11161C22282F353C44
4D545C62666A69686663615F5E5C5B5A5959585756555454
52514F4E4D4B4A48474645444444444445464748494B4D4F
5154575B5F646A7077818B96A2AEBBC6CBCCD1D1D3D6DCDD
DBD8D6D4D2D0CDCBC9C7C4C2C0BEBBB9B7B5B2B0AEACAAA7
A5A3A19F9C9A9896
8C857D766E675F574F473E362C23190E13191F252C333A42
4A525A6064686867666462605F5E5C5B5A59595757565554
5352514F4E4D4C4A4948474646464646464748494B4C4E50
5254575B60646A7077818A96A2AEBAC4CACCD0D0D2D3D9D8
D7D5D3D1CFCDCBC9C7C5C3C0BEBCBAB8B6B4B1AFADABA9A7
A5A2A09E9C9A9896
8C857D766E675F574F473E352C23190E10141B2229303840
4851585E62666766656462615F5E5D5C5B5A595857575655
54535251504F4D4C4B4A49494848484848494A4B4C4D4E50
5155575B5F646A7078808A96A2ADBAC1C7CCD0D1D2D3D5D5
D3D2D0CECCCBC9C7C5C3C1BFBDBBB9B6B4B2B0AEACAAA8A6
A4A2A09E9C9A9896
8C857D766E675F574F473E352C23180C0B11171F262D353E
454E565B5F63656564636261605F5D5C5C5B5A5958585756
5554535251504F4E4D4C4C4B4A4A4A4A4A4A4B4C4D4E4F50
5255575B5F64696F78808A95A2ADBABFC5C9CFD0D1D3D2D1
D0CFCDCCCAC8C6C4C3C1BFBDBBB9B7B5B3B1AFADABA9A7A5
A3A19F9D9B999795
8C857D766E675F574F473F362D23190F080C131A2229323B
434B53595E61636463636261605F5E5D5C5B5A5959585857
5655555453525150504F4E4D4D4C4C4C4C4C4C4D4E4F5152
5355585B5F646A7078818A95A2ADB9BDC3C8CECFD0D1D0CE
CDCCCAC9C7C6C4C2C1BFBDBBB9B7B6B4B2B0AEACAAA8A7A5
A3A19F9D9B999795
8C857D766F675F5850483F372E241B1106060D151D252D37
404951575C5F616262626160605F5E5D5C5C5B5A5A595958
5857565655545353515150504F4F4E4E4E4E4E4E4F505253
5456585C6064696F77808A94A0ACB8BCC0C6CCCECECECDCC
CAC9C8C6C5C3C2C0BEBDBBB9B8B6B4B2B1AFADABA9A8A6A4
A2A09F9D9B999795
8C857E766F676058504840382F261D130803081017202932
3C464E55595D5F60616161605F5F5E5E5D5C5C5B5B5A5A59
595858575756565554545352525151515050505051525354
55575A5C60656A6F777F8A949FABB8BCBEC5C9CCCDCBCAC9
C7C6C5C4C2C1BFBEBCBBB9B8B6B4B3B1AFAEACAAA9A7A5A3
A2A09E9C9B999795
8C857E776F6860595149413931281F150C020309111A232E
38424C53585B5D5F5F5F605F5F5F5E5E5D5D5C5C5B5B5B5A
5A5A59595958585756565555545454535353535353545455
56585B5D61656A70777F89949EA9B5BABEC4C8CACAC8C7C6
C5C4C2C1C0BFBDBCBAB9B8B6B5B3B1B0AEADABA9A8A6A4A3
A19F9E9C9A999795
8C857E777068615A524A423A322A21180F0400020A141E28
343F4850565A5C5D5E5F5F5F5F5E5E5E5E5D5D5C5C5C5B5B
5B5B5B5B5B5A5A5959585857575656565555555555555657
585A5C5F62666B70777F88939DA7B1B6BBC1C6C8C6C5C4C3
C2C1C0BFBDBCBBBAB8B7B6B4B3B1B0AFADABAAA8A7A5A4A2
A09F9D9C9A989795
8C857F777069625B534C443C342C241C130B0400040F1A25
303B454D53585A5B5C5D5E5E5E5E5E5E5D5D5D5D5D5C5C5C
5C5C5C5C5C5C5C5C5B5B5B5A595958585858575757575859
595B5D6063676B71777F88919BA6ADB3BABFC3C4C3C2C1C0
BFBEBDBCBBBAB9B8B7B5B4B3B1B0AFADACAAA9A7A6A4A3A1
A09E9D9B9A989795
8D867F78716A635C544D453E362F271F18110A05020A1621
2C37414A5055585A5B5C5D5D5D5D5D5D5D5D5D5D5D5D5D5D
5E5E5E5E5E5E5E5E5E5D5D5D5C5C5B5A5A5A5A5A5A595A5A
5B5D5E6164686C70777F87909AA2A9B0B7BCBFC0BFBFBEBD
BCBBBBBAB9B8B7B6B5B4B2B1B0AFADACABA9A8A6A5A4A2A1
9F9E9C9B99989695
8D867F78726B645D564E474039312A221B150E090406141E
28333D464D525557595A5B5C5C5C5C5D5D5D5D5D5E5E5E5E
5E5F5F60606061606060605F5F5E5E5D5D5D5D5C5C5C5D5D
5D5E606265696E71767F878F9AA1A6ADB4B9BCBCBCBBBBBA
B9B9B8B7B7B6B5B4B3B2B1B0AEADACABA9A8A7A6A4A3A1A0
9F9D9C9B99989695
8D868079726B655E575049423B342D251F18120C06050F1B
25303942494F53555758595A5B5B5B5C5C5D5D5E5E5E5F5F
5F60616162636362626262626261616160605F5F5E5E5F5F
5F606164676A6F73777D868F989EA4AAB0B5B9B8B8B8B8B7
B7B6B6B5B4B4B3B2B1B0AFAEADACABAAA8A7A6A5A3A2A19F
9E9D9C9A99989695
8D868079736C665F58524B443D362F28221B140E06050A16
212C363F464C505355565759595A5A5B5C5C5D5E5E5E5F5F
606061626364656464656565656463636362626161606060
60616265686C7074797F878C969DA3A8AEB2B4B5B5B5B5B4
B4B4B3B3B2B2B1B0AFAEADADACABAAA8A7A6A5A4A3A1A09F
9E9C9B9A99979695
8D87807A746D67605A534D463F39322B251E171008050612
1C26313A42484C5052545557575859595A5B5C5D5E5E5F5F
606161636465666666666767676666666565646463626262
62636466696C70747A80888D959BA2A6ABB0B1B1B2B2B2B2
B2B1B1B1B0B0AFAEADADACABAAA9A8A7A6A5A4A3A2A19F9E
9D9C9B9A98979695
8D87817B746E68625B554F48423B352E28211A130B06030B
161F2A343D44494D4F51525455555658595A5B5D5D5E5F5F
606061626465666767676767686868686767666665646464
656565676B6D72777C82898E959BA1A5A9ACADAEAFAFAFAF
AFAFAFAEAEAEADACACABAAA9A9A8A7A6A5A4A3A2A1A09F9E
9D9C9A9998979695
8D87817B756F69635D57504A443E37312B241E170F070306
0E19232D363E454A4C4D4F505253545657585A5B5C5D5C5D
5E5F60616264656566666667676868676867676767666565
656667696D6F72787F84888E949A9FA4A8A9AAABACACADAD
ADADADACACACABABAAAAA9A8A7A7A6A5A4A3A2A1A09F9E9D
9C9B9A9998979695
8E88827C76706A645E58524C46403A342E27211B140D0604
07111C2730373F44484A4B4D4E505153545657585A5B5B5B
5C5D5D5F6061626363646465656566666767676667686868
6869696B6E7275787E84898E93999EA3A5A6A7A8A9AAAAAA
ABABABAAAAAAAAA9A9A8A7A7A6A6A5A4A3A3A1A09F9F9E9D
9C9B9A9998979694
8E88827D77716B66605A554F49433D37312B251F18130D09
060D15202930383E4446494A4B4C4E4F5152545657575859
59595A5B5D5E5E5F60606060626363646465656565676869
696A6B6D6F72767A7F84898E94999DA1A3A4A5A6A6A7A8A8
A8A9A9A9A8A8A8A8A7A7A6A6A5A4A4A3A2A1A1A09F9E9D9C
9B9A999897969594
8E88837E78726D67615C56514B45403A342E28231D17120D
0808111A242D343A3F42444547494A4C4D4F505253545555
55565658595A5C5D5D5D5E5E5E6060626364656565666869
6A6C6D6E7174777B7F848A8F94999E9FA0A2A3A4A4A5A6A6
A6A7A7A7A7A6A6A6A6A5A5A4A4A3A3A2A1A0A09F9E9D9C9C
9B9A999897969594
8E89837E79736E69635E58534D48423D37322C27211C1712
0E080B141D272E34393D3F4042444648494B4B4D4F505151
5152525354545759595A5A5A5B5D5E5F6063646464656667
686A6B6D7073777A80858A9195999C9D9E9FA0A1A2A3A4A4
A4A5A5A5A5A5A5A5A4A4A4A3A3A2A2A1A0A09F9E9D9D9C9B
9A99999897969594
8E89847F7A746F6A65605A55504A45403B35302B25201B17
120E0B1019232A3137393B3C3C3F4244454748494B4B4C4D
4D4D4E4E4F504F535455565757585A5B5C5E606162636566
686A6B6C6F73787C8085899093999A9B9C9D9E9FA0A1A2A2
A3A3A3A3A3A3A3A3A3A3A2A2A2A1A1A09F9F9E9D9D9C9B9B
9A99989797969594
8E89847F7A76706B66615C57524D48433E39342F2A25201B
16120C0B141B222B3135373738393D3F4142434446474749
48484A4B4A4B4B4C4F4F50515152545557595C5E5F616364
66686A6D7075787D83868A8E919597999A9B9C9D9E9FA0A0
A1A1A2A2A2A2A2A2A2A1A1A1A0A0A09F9F9E9D9D9C9B9B9A
9999989796969594
8F8A85807B77726D68635E5A55504B46413C37322E29241F
1B16110A0C161F252B3033333333383A3D3E3E3F42424345
444544464545464749484A4B4B4C4E505254575A5C5E6061
6467696C7074797C81868A8E9092949698999A9B9C9D9E9F
9FA0A0A0A1A1A1A1A0A0A0A09F9F9F9E9E9D9D9C9B9B9A9A
9998989796969594
8F8A86817C78736E6A65605C57524E4944403B36312D2824
1F1A15100B0C1721272C2F302F2E32353639393A3C3E3E3F
40403F41403F3F3F43434343454648494B4D5154575B5E5F
6165696D71767B7D8085898E8F9192949697999A9A9C9C9D
9E9E9F9F9F9F9F9F9F9F9F9F9E9E9E9D9D9C9C9B9B9A9A99
9998979796959594
8F8B86827D7975706B67625E5A55504C47433E3A35312C28
231F1A15110C0E1821272B2D2C2A2C313233353636393A3A
3B3C3B3B3C3B3938393B3E3E3E3F41424445494C5054585D
6164676D70737A7D7F82878A8C8E909294959798999A9B9C
9C9D9D9E9E9E9E9E9E9E9E9E9E9D9D9D9C9C9B9B9A9A9999
9898979696959594
8F8B87827E7A76716D6965605C58534F4B46423E3935312C
28231F1A150F0B0F1820262A2A28272B2E2E2F3031333536
363737373738363434343536383A3B3D404245484C50565B
6065686C6F72777A7E8285888A8C8F91929495979899999A
9B9C9C9C9D9D9D9D9D9D9D9D9D9D9C9C9B9B9B9A9A999998
9897979696959594
8F8B87837F7B77736F6B67635E5A56524E4A46413D393531
2C28231F1A150F0C11171D2225262324282A2A2A2B2B2E2F
3131323233333230302E2F30333637393B3E42474B4F555C
6064686C6D7075797C808386898B8D8F9193949597989899
9A9A9B9B9C9C9C9C9C9C9C9C9C9C9C9B9B9A9A9A99999898
9897979696959494
908C8884807C7874716D6965615D5955514D4945413D3935
312D29241F1A15100D11171D202323212125262627262728
2A2C2E2D302F2F2E2E2C2A2B2E3033363A3D41464B505459
5D6164686B6E73787B7F8285888A8C8E9091939496979798
99999A9A9B9B9B9B9B9B9B9B9B9B9B9A9A9A999999989898
9797969695959494
908C8885817D7A76726F6B6763605C5854514D4945413D3A
36322D2925201B16110E10171D2122211F20212323232322
222427272A2B2C2B2E2F2D2D2F3133373C4044484A4E5256
5A5D6166696C70767A7D818486898B8D8F90929395969697
989999999A9A9A9A9A9B9B9A9A9A9A9A9A99999998989897
9796969695959494
908C8985827E7B7774706D6966625F5B5854504D4945423E
3A36332F2B26221D19151010161D2123211F212121212122
21202121242729292B2D2E303234373B3C404447494C4F52
555A5F6467686F75797C808385888A8C8E8F919294959596
97989898999999999A9A9A9A9A9A99999999989898989797
9796969595959494
908D8A8683807C7976726F6C6865625E5B5754514D494643
3F3C3834302C2924201C181312161E222423232323242424
25252727282A2A2B2D2F30323536373B3C3F4246474A4C50
54585D61676B7074787C7F828487898B8D8F909193949595
969797979899999999999999999999989898989797979797
9696969595959494
908D8A8784817E7B7774716E6B6865615E5B5855514E4B47
44413D3A36332F2B2724201C1916181F2326272828282828
29292A2A2B2D2E2E303132323637383B3C3E404446484C50
54575C62676C7074787C7F828486898B8C8E8F9192939495
959696979798989898989899999998989898979797979796
9696959595949494
918E8B8885827F7C797673706D6A6764615E5B5855524F4C
4946433F3C3936322F2C2825221F1B1D1F25292B2B2C2D2D
2E2E2F2F2F303132333434343437393A3B3E3F4246494D4F
52585E64686D7175797C7F828486888A8C8D8F9091939394
959596969797979798989898989898989897979697969696
9696959595949494
918E8B898683807E7B787573706D6A6865625F5C59565451
4E4B4845423F3C393633302D2B282625232325292D303132
3332333232313131323435353434373A3B3F424647494C52
575C61666A6E7376797C7F828486888A8C8D8F9091929394
949595969696969797979798989798989897979696969696
9695959594949494
918E8C898784827F7D7A777572706D6B686563615D5B5855
53504D4B484543403D3A383533312F2E2D2C2D2B2D2F3335
36373737363534343334353738383A3E404144484C4F5357
5B6064696C7074777A7D80828486888A8B8D8E8F91929394
949595969696979797979797979797979897979696969696
9595959594949494
918F8C8A888583817E7C7A777573706E6B696664615F5D5A
585553504E4B494644423F3D3B3A38373635353534333436
37383A3A3A3A3A3B3B3B3B3C3D3E3E404246494D5155585B
6063676B6F7275787B7E80838587888A8B8D8E8F90919293
939495959696969697969697969797979797969696959595
9595959594949494
918F8D8B89878482807E7C7A777573716F6C6A686664615F
5D5A585654524F4D4B494745434241403F3E3D3D3D3D3D3E
3E3E3F3F403F3E3E3E3F4040414345474A4D5053575B5E60
64686B6E7274777A7C7F81838587898A8B8D8E8F90919293
939494959595959696969697969696969696969696959595
9595959594949494
91908E8C8A88868482807E7C7A78767472706E6C6A686664
62605E5C5A58565452504E4D4B4A49484746454545454546
4646474747474646464748484A4B4D4F5254575A5D606365
686B6E717477797C7E8082848688898B8C8D8E8F90919292
939494949595959595969696969696969696969595959595
9595959494949494
92908E8C8B8987858482807E7C7B7977757372706E6C6A68
676563615F5E5C5A59575554535150504F4E4E4D4D4D4D4E
4E4E4F4E4E4E4E4E4F4F505152535557595B5E606365686A
6C6F7275777A7C7E8082848587898A8B8D8D8E8F90919292
929394949595959595959596969696969696969695959595
9595949494949493
92908F8D8C8A8887858482817F7D7C7A7977757472716F6D
6C6A6867656462615F5E5D5B5A5958585756565555555656
565656565656565656575858595B5C5E60616466686A6D6F
717375787A7C7E8082848587888A8B8C8D8E8F8F90919292
929394949495959595959595959595959595959695959595
9594949494949494
92918F8E8D8B8A888786848382807F7D7C7B797876757372
706F6E6C6B6A6867666564626261605F5F5E5E5D5D5D5E5D
5E5E5E5E5E5E5E5E5E5F5F606162636566686A6C6E6F7274
7577797B7D7F808284868788898B8C8D8D8E8F9091919292
929393949494959595959595959595959595959595959594
9494959494949494
9291908F8E8C8B8A89888685848382817F7E7D7C7A797877
7574737271706F6E6C6B6B6A696867676666666565656565
65666566666666666667676868696A6C6D6E707273757678
7A7B7D7E808283848587888A8B8C8C8D8E8F909091919293
939393949494949494959595959595959595959595949494
9494949494949494
929191908F8E8D8C8B8A898887868584838281807F7E7D7B
7A7A79787776757473727171706F6F6F6E6E6D6D6D6D6D6D
6D6D6D6D6E6E6E6E6E6E6F6F7070717373747677797A7B7C
7E7F81828385858788898A8B8C8D8E8E8F90909191919293
939393949494949594949594959595959495959595949494
9494949494949393
93929190908F8E8D8C8C8B8A898888878685848483828180
807F7E7D7C7C7B7A7A797878777776767676757575747475
757575757575757576767676777778797A7B7C7C7E7F8081
82838485868888898A8B8C8D8D8E8F8F9090919191929292
939393939494949494949494949494959494959494949494
9494949493949493
9392929191908F8F8E8E8D8C8C8B8B8A8989888787868685
858483838282818180807F7F7E7E7D7D7D7D7D7C7D7D7C7C
7C7C7D7D7D7D7D7D7D7D7D7E7E7E7F808081828283848586
87878888898A8B8C8C8D8E8E8F8F90909091919192929292
939393939494949494949494949494949494949494949494
9494949394949393
939392929191919090908F8F8E8E8E8D8D8C8C8B8B8A8A8A
8A8989888888878786868686868585858485858484848484
848484848484858585858485868686868787878889898A8A
8B8C8C8D8D8D8E8E8E8F9090919191929292929292929293
939494939394949394949494949494949494949494949494
9494949494949393
939393939292929292919191919190909090908F8F8F8E8E
8E8E8E8E8E8E8D8D8D8D8D8D8D8C8C8C8C8C8C8C8C8C8B8C
8C8C8C8C8C8C8C8C8C8C8C8C8C8D8D8D8D8D8D8E8E8E8F8F
8F9090909090909091919192929292939393939393939393
939394939394949494949494949493949494949494939494
9394949494949393
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.35119 0.343006 0.64881 0.640625 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00751202 0.0192308 0.00751202 [
[.5 1.0125 -20 0 ]
[.5 1.0125 20 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(60) show
75.000000 12.812500 moveto
(deg) show
93.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(.) show
99.000000 12.812500 moveto
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
128 string
128 128 8 [128 0 0 128 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
696868686868686868676766666666666666666666666562
666665656565656565656565656666666666666666676767
676867686868676767676767676767686867676868686868
686868686868686868686969696766696969696969696A6A
6A6A6A6A6A6A6A6A6B6A6B6A6A6A6A6A6A6A6A6B6B6B6B6B
6C6A696C6C6B6A69
68686868676767666666656464646464636363636363625F
626261616161616162626262626363646464646464656565
666666666766666666666666666666676766666766666667
67676767676767686868686969676668696969696A6A6A6A
6B6B6B6B6C6B6C6C6C6C6C6C6C6C6C6C6C6D6D6E6E6E6E6E
6E6C6C6D6E6D6B6A
686868676766666565646363626161616160606060605F5D
5D5F5E5D5D5D5D5E5E5E5E5F5F5F60616262626263636464
646465656565656565656565656565666666666665656566
666666666667676767686868686867686869696A6A6B6B6B
6C6C6C6D6D6D6D6D6E6E6E6E6E6E6E6E6E6F707070717170
6F6E6E6F706E6C6A
68686767666665646463626160605F5F5E5E5E5D5D5D5C5C
595B5B5A5959595A5A5A5B5B5C5C5D5E5F5F606061626263
636364646464646464646464646465656564646564646465
6565656566666667676767686868686867696A6A6B6B6B6C
6C6D6D6E6E6E6F6F6F707070707070707172737373737272
7170707071706D6B
6868676666656463636261605F5E5D5C5C5B5B5B5A5A5A59
57565756565555565657575858595A5B5C5D5E5F5F616162
626262636363636263636363636364646363636463636364
6464646565656666666767676768686968676A6B6B6B6C6C
6D6D6E6F6F6F707071717272727272727374767676747474
7273717273716E6B
68676766656463626261605F5E5D5C5B5A59585858575756
555353525251515152535354555657585A5B5C5D5E606061
616161616161616162626262626262626262626262626262
6363636464646565666666676768686969696A6B6B6C6C6C
6D6E6F707070717172727373737474757677797977767675
7575737474716E6B
686766656464626260605E5D5D5B5A595857565555545453
52504F4E4D4D4D4D4E4E4F505153545657595A5C5D5F5F60
606060606060606060616161616161616161616161616161
62626263636464646565666767686869696A6A6B6B6C6C6D
6E6F6F70717172737374747575757677787A7C7B79787878
7777757675726F6B
68676665646361615F5E5D5C5B5A59585655545352525150
4F4D4B4A48494849494A4B4D4E4F51535557595A5C5D5E5F
5F5F5F5F5F5F5F5F5F606060606060606060606060606060
61616262626363646465666667686869696A6B6B6B6C6C6D
6E6F707172727374757576767778797A7C7E7E7C7B7B7B7A
7A79787876726F6C
68676665636261605E5D5C5B5A58575655535251504F4E4D
4C4A484644444444454647494B4C4F51535658595A5C5D5E
5F5F5F5E5E5E5E5E5E5F5F5F5F5F5F5F5F5E5F5F5E5F5F5F
60606161626263636465666767686869696A6B6B6B6C6C6D
6E7071727373747576767778797B7D7E7F80807F7E7E7E7D
7C7A7A7A7773706C
686665646361605F5D5C5B59585756545351504F4D4C4B49
48464443413F3E3E40414345474A4C4F51545658595B5C5D
5E5E5E5E5D5D5D5D5D5E5E5E5E5E5E5E5E5E5E5E5E5E5F5F
5F606161626263646465666767686869696A6B6B6C6D6D6E
6F6F7273747475767777797B7D8081828283838281818080
7E7C7D7A7874706C
6766656362615F5E5C5B5A585755545251504E4D4B4A4846
4543413F3D3B39393C3C3E414447494D4F525557585A5B5D
5D5D5D5D5D5C5C5C5C5C5D5D5D5D5D5D5C5C5C5D5D5D5E5E
5E5F6060616262636465666667686869696B6B6C6D6D6E6F
6F70747374757677797B7D80828485858687858584838483
807F7E7C7874716D
6766656361605F5D5C5A5957565452514F4E4C4A49474543
413F3E3B3937343536383A3C4044474B4D51545658595B5C
5C5C5C5C5C5C5B5B5B5B5C5C5C5C5C5B5B5B5B5C5C5C5D5D
5D5E5F5F606162636365656667676869696B6B6C6D6E6F6F
707274747577787A7D7F8184868789898A8A878887868785
83827F7D7975716D
6766646261605E5C5B5957565452514F4D4B4A4846444240
3E3C3A3836333131303235373C4145494C50525557595A5C
5C5C5C5C5B5B5B5A5A5A5B5B5A5A5A5A5A5A5A5A5B5B5C5C
5C5D5E5E5F6061626364656666676869696A6B6C6D6E6F70
7172747577797B7F828386888A8B8C8D8D8D8A8B8B898A87
8584817D7975716D
67656462605F5D5C5A58565553514F4D4B4947464442403D
3B39373532302E2D2C2C3032373D43474B4F525557585A5B
5B5B5B5B5B5A5A5A5A5959595959595959595959595A5A5B
5B5C5C5D5E5F60616264656566676869696A6B6D6D6E7071
727475777A7D818386878A8C8D8F9090908F8E8E8E8D8C89
8886827E7A76716D
67656362605E5C5B59575553514F4D4C49474543423F3D3B
383634322F2D2A2927272A2E323840464B4E525557585A5B
5B5B5B5A5A5A59595958585858585858585858585858595A
5A5B5C5D5E5E5F6162636465666768696A6A6C6D6E6F7172
7476787B808385888A8B8D8F919293939392929291908D8C
8A87827E7A76726D
676563615F5E5C5A58565452504E4C4A484544413F3D3B38
3633312E2C2927262323252A2E343B444B4E525557595A5B
5B5B5A5A5959595858575757575757575757575757575858
595A5B5C5D5D5F6061636465666768696A6A6C6D6E707274
76787C818587888C8E8F9192939496969696969494918F8E
8B87837F7B76726D
676563615F5D5B59575553514E4C4A484644423F3D3B3836
33312E2B29262422201F21262B313840494F535658595B5B
5B5A5A5A5959585857565656565656565656565656565657
58595A5A5C5D5E5F61626465656768696A6B6C6E6F727476
797D8287898B8D909293949596979999999999979693918F
8C8784807B76726D
676563615F5C5A585654524F4D4B49474442403D3B383633
302E2B292623201E1D1B1E23272E363D454E55575A5B5B5C
5B5A5A595958575756565555555554545454545555555556
575758595B5C5D5F606263646567686A6B6C6E6F7173777A
7E83888B8D8F9194959697999A9B9C9D9C9C9B9998969390
8C8884807B77726D
676562605E5C5A575553504E4C4A474543403E3B39363331
2E2B292623201D1B1A181C20252C333A424B555B5B5C5C5C
5B5B5A595858575655555454545353535353535353545455
565657585A5B5C5E606163646567696A6C6E6F7173777A80
84888C8E9093959798999B9D9E9F9F9F9F9F9D9B9A989491
8D8984807B76726D
666462605D5B595754524F4D4B484643413E3C393734312E
2C292623201D1A1817161A1E242A3138414A545D5D5E5D5D
5C5B5A595857565554545353535252525252525252535354
54555657595A5C5E6061626466686A6C6D707174767C8085
898D90929496999B9C9D9EA0A1A1A2A2A2A19F9E9C999692
8D8984807B76726D
6664615F5D5B585653514E4C494744423F3C3A3735322F2C
292623201D1A17151314181C222930374049535C5F5F5E5D
5C5B5A585756555454535252515151515151515151525253
53545556585A5C5E6061626467696B6D6F7275787C818589
8D919395979A9C9D9FA0A1A3A4A4A5A5A4A3A1A09D9A9692
8D8985807B77726D
6663615F5C5A585552504D4B484543403E3B383533302D2A
2724211D1A1714121112171B22282F373F49525A62615F5E
5C5B59585756545353525151505050504F4F505050505152
5253545557595C5E5F606266686A6D6F7277797D8185898D
919497989B9DA0A1A3A4A5A6A7A8A8A7A6A5A3A19E9A9792
8D8985807B77726D
6663615E5C595754514F4C4A4744413F3C393633312E2B28
25211E1B1814120F0F11161B21272E37404850596462605E
5C5A595756555353525150504F4F4F4F4E4E4E4E4F505051
5152535456595C5E5E606367696C6F72777B7E8185898D90
95989A9C9EA1A3A4A6A6A8A9AAABABAAA8A7A5A29E9B9792
8E8985807B77726D
6663615E5C595653514E4B494643403D3A3734322F2C2926
221F1C1915120F0D0E10151A21272E37404750596562605E
5C5A59575554535251504F4F4E4E4D4D4D4D4D4D4E4E4F50
5051525456595C5D5E6165686B6E72777C808386898D9194
989B9DA0A2A4A6A6A8AAABADAEAEAEACABA9A6A29F9B9792
8E8984807B77726D
6663605D5B585553504D4A4844413E3C393633302D2A2623
201D1A16130F0D0B0D10141A20272F383F46505A6562605E
5C5A5856555352514F4F4E4D4D4D4C4C4C4C4C4C4D4D4E4F
4F50525356595B5C5F63666A6D72767B8085878A8D919497
9B9DA1A3A6A7A8A9ABADAEB0B1B1B0AEADAAA7A39F9B9793
8E8984807B77726D
6663605D5A5755524F4C494643403D3A3734312E2B282421
1E1B1714110D0A0A0C10141A212730373E46515B6563605E
5C5A5856545351504F4E4D4C4C4B4B4B4B4C4B4C4C4D4D4E
4F50515356595A5D6165686C71767A7F85898C8E9194979A
9DA0A4A6A9AAABACAEB0B1B3B4B3B2B0AEAAA7A4A09C9793
8E8984807B77726D
6663605D5A5754514E4B4845423F3C3936332F2C2926221F
1C1915120E0B08090C0F141B212830373F48525B6563605E
5C5957555352504F4E4D4C4B4B4B4A4A4B4B4B4B4B4C4D4D
4F50515356585B5E62666B6F74797E84898D909295979A9C
A0A3A7AAACADAEAFB1B2B4B6B6B6B4B2AFABA8A4A09C9793
8E8985807B77726D
65625F5C595654504D4A4744413E3B3734312E2B2824211D
1A1713100C0907090B10151C222931383F49535C6663615E
5C5957555351504E4D4C4B4A4A4949494A4A4A4A4B4B4C4D
4E4F515456585C6064696D72777D83888D919497999B9C9E
A2A6AAACAEB0B1B2B3B5B7B9B9B8B6B3B0ACA8A4A09C9793
8E8985807B77726D
65625F5C595653504D4A4643403D393633302C2926221F1C
1815110E0A0706080C10161D232B3138404A545D6663615E
5B59565452504F4D4C4B4A49494848494949494A4A4B4C4C
4E50525456595D62666B70747B81878C9094989B9C9EA0A1
A5A9ACAFB1B3B3B4B6B8BABCBBBAB7B4B0ADA9A5A09C9793
8E8985807B77726D
65625F5C5855524F4C4945423F3B3835312E2B2824211D1A
16130F0C080606080C11171E242C323A434D565E6763615E
5B58565452504E4D4B4A49484848474848484949494A4B4C
4E505255575A6064686D72777E868C8F93979B9EA0A2A3A4
A7ABAEB1B3B6B6B7B9BBBDBFBDBBB8B5B1AEA9A5A09C9893
8E8985807B77726D
65625F5B5855524E4B4844413E3A3733302D2926231F1B18
14110D0A060506080D12191F262D343D464F575F6764615E
5B58565452504E4D4B4A48484747474747484849494A4B4C
4E505356585C62666A6F757C838A8F92969A9EA2A4A5A6A7
AAADAFB3B6B8B8BABCBFC0C1BFBCB9B6B2AEAAA5A19C9893
8E8985807B77726D
65625E5B5855514E4A4743403D3936322F2B2824211D1A16
120F0C08050506090F141B22282F3640495159616764605D
5A585553514F4E4C4B4948474646464647474748494A4B4C
4E515457595E64686B727981868D9295989CA0A5A7A9A9AA
ACAEB1B5B9BABBBDBFC1C2C3C0BCBAB6B2AEAAA5A19C9893
8E8A85807B77726D
65625E5B5754504D4A46433F3B3835312D2A2623201C1814
110D0A060405070B10161D242A3239444C545C6466635F5C
59575452504F4D4C4A4948474646454646464748484A4B4D
4E5155595C6166696E757D85899095989B9FA3A8AAACADAD
AEB0B2B7BBBCBEC0C2C3C4C4C0BDBAB7B3AEAAA5A19C9893
8E8A85807B77726D
65615E5B5753504C4945423E3A3733302C2925211E1A1613
0F0C08050405080C121820262E343E485058606464615D5A
58555351504E4C4B4A494847464645454546464748494B4C
4F52555A6064696A707780888C92979B9DA2A6AAADAFB0B0
B0B1B5B9BDBEC1C3C4C5C7C5C1BFBBB7B3AFAAA5A19C9893
8E8A85807B77726D
65615E5A57534F4C4844413D3936322E2B2723201C181511
0D0A07040306090E141B22293138434C545D6162605E5B58
565452504F4D4C4B4A494847464645454445464648494B4C
4F52565C64666C6D737A828B90939A9DA0A4A8ACAFB1B3B2
B2B3B7BBBEC1C4C5C6C7C8C5C2C0BCB8B3AFAAA6A19C9893
8E8A85807C77726D
65615E5A56534F4B4744403C3834312D2926221E1B17130F
0C08050404070B10171E252D343D485059605F5E5D5B5856
5452504F4D4C4B4A4A484847474645454544454647484A4C
4F53575E66696F71757D858D93969B9FA2A6AAADB1B3B5B5
B5B5B8BDC0C3C6C7C8C9C9C7C4C0BCB8B3AFAAA6A19C9893
8E8A85807C77726D
65615D5A56524E4A47433F3B3734302C2824211D1915110D
0A07040405080D131921293138434C555C5E5C5B59585654
52504F4E4C4B4B4A4A494848474746464545454546484A4C
4F53595F686D70757880878F93989BA0A4A7ABAFB2B5B7B8
B8B7BABFC2C6C8C9CACBCBC8C4C1BCB8B4AFAAA6A19D9893
8F8A85807C77726D
65615D5955514D4A46423E3A36322F2B27231F1C1814100C
09060403060A0F151D252C353E4951595C5B5A5856555351
504F4E4D4B4A4A4A4A49494848474746464545454647494C
4F5359606A7072787D81898F949A9DA1A5A9ACB1B4B7B9BB
BBBBBCC0C4C7C9CCCDCDCCC8C5C1BDB9B4AFABA6A19D9893
8F8A85807C77726D
65615D5955514D4945413D3935312E2A26221E1A16120E0A
07050404070C12192129303A444E575A595857555452504F
4E4D4C4B4B4A4A4A4A4A4A4A49494847474646464647494B
4F5459616A72767B80858B8F949A9FA2A6A9ADB2B6B9BBBD
BEBEBEC2C6C9CBCECFCFCCC9C5C1BDB9B4AFABA6A29D9893
8F8A85807C77726D
65615D5955504D4944403C3935302C2824201C1915110D09
06050405090F151C252D35404A54595857565452514F4E4D
4D4C4B4B4A4A4A4A4A4B4B4B4B4A4A48484747464747484A
4E5359616A737A7D81888C91959BA0A3A7AAAFB3B8BABDBF
C0C1C1C4C7CACDD0D0D0CDCAC5C2BDB9B4B0ABA6A29D9894
8F8A85817C77726D
64605D5854504C4844403B38332F2B27231F1B17130F0B07
050404060B12192029313B454F585756555452504E4C4C4D
4C4C4B4B4A4A4A4A4B4C4D4D4D4C4B4A494847474748494A
4D5258606A747B80848A8E92979BA0A4A8ABAFB4B9BBBEC1
C3C4C4C5C9CBCED1D2D1CECAC6C2BEB9B4B0ABA7A29D9894
8F8A85817C77726D
64605C5854504C47433F3B37322E2A26221D1A15110D0906
040404080E151D242E37414B555957555452504D4C4B4C4E
4C4B4B4B4B4A4A4B4C4D4E4F4F4E4D4B4A4948484848494B
4D51576069737B83868A9093999DA0A5A9ACB0B5B9BDBFC3
C5C7C7C7CACDD0D3D4D1CECAC6C3BEB9B5B0ABA7A29D9894
8F8A85817C77726D
64605C58534F4B47423E3A36312D2925201C1814100C0705
0303060B11192129323C47515857565453504E4B4B4C4C4D
4C4B4B4B4A4A4B4C4E4E4F5051504F4D4B4A494849494A4C
4E51565E67737B84878B91959A9FA3A5A9ACB1B5BABEC1C4
C7C9C9C9CCCFD2D4D5D2CFCBC7C3BEBAB5B0ACA7A29D9994
8F8A85817C77726D
64605C58534F4B46423E3935302C28231F1B17120E0A0604
0304080D141D252E38434D5758575554524F4D4B4B4C4D4D
4C4C4C4B4B4B4D4E4F4F50515252504E4C4B4A49494A4B4C
4E51555C65717B83898D91979AA1A5A7A9AEB1B6BBBFC2C5
C9CBCCCCCDD1D3D6D6D3CFCBC7C3BFBAB5B0ACA7A29D9994
8F8A85807C77726D
64605C57534E4A46413D3834302B27221E1915110C080503
03060A1018212A343E49545857575554524F4F4C4C4E4E4E
4E4E4E4D4D4D4F50515353535453514F4D4B4B4A4A4A4B4D
4E51545A646F7A82898E91979CA1A7A9ABADB2B7BBC0C3C7
CBCDCECFCFD2D4D7D7D3CFCCC8C4BFBAB5B1ACA7A29D9994
8F8A85817C77726D
64605B57524E4A45413C38332F2A26211C18130F0B070402
03070D141D252F39444E5858585755545251504E4E4F4F4F
4F4F4F4E4F4F5051525353535352514F4D4C4B4B4A4B4C4D
4F515459626D7981898E92969EA2A9ACAEAFB4B7BBC0C4C8
CDCED1D1D1D4D6D9D7D4D0CCC9C4BFBAB6B1ACA7A29E9994
8F8A85817C77726D
64605B57524E4945403C37322E2924201B16120D09050302
04091018202A343F49545A5958575654535251504F4F4E4E
4E4D4E4E4E4E4F50515252525251504F4D4C4B4B4B4B4C4D
4F5154585F6B7780888E93979EA4AAAFB0B2B5B8BCC1C5C9
CDD1D4D3D3D5D7DBD8D4D1CDC9C4BFBAB6B1ACA7A29E9994
8F8A85817C77726D
64605B56524D4944403B36322D28231F1A15100C07030202
060C131C252F39434E595A5959585655545251504F4F4E4D
4D4C4D4D4D4D4F505152525251514F4E4D4C4C4B4B4B4C4D
4F5154585E69747F878D93989EA5AAB0B3B5B6BABDC2C6CB
CFD3D5D6D5D7D9DCD9D5D1CEC9C5C0BBB6B1ACA7A29E9994
8F8A85817C77726D
645F5B56524D48433F3A35312C27221D18140F0A05020104
080F171F29333E48525C5B5A5A585756545352504F4E4E4D
4C4C4C4C4C4D4F50505152525151504E4D4C4C4B4B4C4C4D
4F5154575D66717D868D93999EA5ABB1B5B8BABCBEC3C6CC
D0D5D7D8D8D9DCDCDAD6D2CFCAC5C0BBB6B1ACA7A39E9994
8F8A85817C77726D
645F5B56514D48433E3935302B26211C17120D0804020205
0B121A232E37424C575F5D5B5A595756555352514F4E4D4C
4B4B4B4C4C4D4E50515152525151504E4D4C4C4B4B4C4C4E
4F5154575C64707B858C93999FA4ACB2B8BBBCBEC0C4C8CE
D2D6D8DBDADBDEDCDBD7D3CFCAC5C0BBB6B1ACA8A39E9994
8F8A86817C77726D
645F5A56514C47423E39342F2A25201B16110C0702010307
0E161E27313C46505C5F5E5C5B5A5856555352514F4E4D4C
4B4B4A4B4C4D4F50515252525251504E4D4D4C4B4B4C4C4E
4F5153575C636D79838B9399A0A5ACB2BBBCBFC2C2C6C9CE
D3D7DADDDDDDDFDDDBD7D4CFCAC5C0BBB6B1ACA8A39E9994
8F8A86817C77726D
645F5A55514C47423D38332E29241F1A15100B050101040A
1119222B3640495460605F5D5C5A5957555452514F4D4C4D
4C4B4A4A4B4D4F4F515253535251504F4D4D4C4C4C4C4D4E
4F5153575B616A77828B939AA1A6ACB4BBBFC3C4C5C7CBCF
D4D9DDDFDFE0DEDEDBD9D5CFCAC5C0BBB6B1ACA8A39E9994
8F8A85817C77726D
645F5A55504B46413D37332E29241E19140F09040001060D
141D26303A434D596361605E5D5A595755545251504E4E4E
4C4B4A4A4C4E4F4F515353535251504F4E4D4C4C4C4C4D4E
4F5153575B616875818B939BA1A8ADB4BAC3C5C6C8C8CDD0
D6DBDFE1E2E1DFDFDDDAD5D0CAC5C0BBB6B1ACA8A39E9994
8F8A85817C77726E
645F5A55504B46413C37322D28231E18130E08030002080F
18212A343D46525E6462605E5D5B595755545351504F4E4E
4C4B4A4A4C4D4F4F515354535251504F4E4D4D4C4C4C4D4E
4F5153575B606774808B949BA1A9AEB5BCC6C7CACBCACED2
D7DCE0E3E4E3E1E1DFDAD5D0CAC5C0BBB6B1ACA8A39E9994
8F8A85817C77726D
645F5A55504B46413B36312C27221D17120D070200040B12
1C242D37404A56626463615F5D5B595756545352514F4F4E
4C4B4A4A4B4D4E4F515253535251504F4E4D4D4C4C4D4D4E
4F5153575B6066727F8B939CA2AAAFB7BEC7C9CCCDCDD0D4
D8DDE2E5E6E4E4E2DFDAD5D0CAC5C0BBB6B1ACA8A39E9994
8F8A85817C77726D
645F5A55504A45403B36312C27211C17110C060100060D16
1F28313A434E5A666463615F5D5B59575654535251504F4E
4C4B4A4A4B4D4E4F515353535251504F4E4E4D4D4D4D4E4F
505154575B6066707E8A939CA3AAB0B8BFC7CCCECFD0D0D5
D9DFE4E8E8E6E6E4DFDAD4CFCAC5C0BBB6B1ACA7A39E9994
8F8A85817C77726D
645F5A544F4A45403B36302B26211B16100B05000209101A
232C343D47535E686563605E5C5B59575654535251504F4E
4C4B4A4A4B4D4E50515253525151504F4E4E4E4D4D4D4E4F
505254575B60676F7D89939CA4ABB2B9C1C9CDD0D2D2D1D6
DBE1E6E9EAE8E8E4DFDAD4CFCAC5C0BBB6B1ACA7A29E9994
8F8A85817C77726D
645F59544F4A45403A35302A25201B15100A0500040B141E
262F38404D5863676462605E5C5A59575654535251504F4E
4C4B4A4A4B4D4E50515252515150504F4E4E4E4E4D4E4F50
515355575B61676F7C88939CA4ABB4BAC2CACFD1D3D4D2D7
DCE3E7ECECEAE9E4DFDAD4CFCAC5C0BBB6B1ACA7A29D9994
8F8A85817C77726D
635E59544F4A443F3A352F2A251F1A140F090401060E1821
29323B45515F656563615F5D5B5958575554535251504F4E
4D4B4A4A4B4D4E4F505151515150504F4F4E4E4E4E4F4F50
525356585B61686F7B88929CA5ACB5BCC3CBD1D2D4D5D4D8
DDE5E9EEEEECE9E4DFD9D4CFCAC5C0BBB6B1ACA7A29D9894
8F8A85817C77726D
645E59544F49443F39342F29241F19140E09020309111C24
2D363F4B5663636361605E5C5A585756555454535251504F
4D4C4B4A4B4D4E4F50505151504F4F4E4E4E4E4F4F505051
525456595C6168707A86919CA5ADB5BDC5CCD1D3D4D6D6D9
DFE7ECF0F0EDE9E4DED9D4CFCAC5C0BBB6B1ACA7A29D9894
8F8A85807C77726D
645E59544F49443F39342F29241E19130E0802060D151F27
303A444F5B6362615F5E5C5B59585756555454535251504F
4E4C4B4A4A4C4D4E4F5050504F4F4E4E4E4F4F4F50505152
5355575A5D6168707985919CA5AEB6BDC6CED1D3D5D7D8DB
E1E9EEF1F2EEE9E4DED9D4CFCAC5C0BBB6B1ACA7A29D9894
8F8A85807C77726D
635E59544E49443E39342E29231E18130D0803090F18222B
343D49545F61605F5E5C5B5958575655545454535352514F
4E4D4B4A4A4B4C4D4E4E4F4F4E4E4E4E4E4E4F5050515253
5456585B5E6268707984909BA6AFB7BEC6CFD1D4D6D8DBDC
E4EAEFF3F3EEE9E4DED9D4CFCAC5BFBAB5B0ACA7A29D9894
8F8A85807C77726D
635E59544E49433E38332E28231D18120C07050C121B242E
37414D595F5E5E5D5C5B5958565555545454545454535250
4F4E4C4A494A4B4C4D4D4E4E4D4D4D4D4E4E4F5051535354
5657595C5F63687079838F9BA6B0B7BFC7D0D2D4D7D9DDDE
E6ECF1F4F4EEE9E3DED9D4CFC9C4BFBAB5B0ABA6A29D9893
8F8A85807C77726D
635E59534E49433E38332D28221D17110C06080E151F2730
3A46515B5C5D5D5C5A595756555454535454555555545352
504E4C4A49494A4B4C4D4D4D4C4C4C4C4D4E4F5153545556
57595A5D6064697079828F9BA6B0B8C0C8D1D3D5D8DAE1E0
E8EFF3F5F4EEE9E3DED9D3CEC9C4BFBAB5B0ABA6A19D9893
8E8A85807B77726D
635E59534E48433E38332D27221C17110C050C1018212933
3D4A545B5B5C5C5A59575554535353535355565757565453
524F4D4A4848494A4B4C4C4C4B4A4A4B4D4E505254565657
595A5B5E61646A7079828E9BA6B1B9C1C9D1D4D6D9DCE4E3
EAF2F5F6F4EEE9E3DED8D3CEC9C4BFBAB5B0ABA6A19D9893
8E8A85807B77726D
635E58534E48433D38322D27221C16110C060E121B232C35
424D56585A5B5B5957555352515151525355585859585655
53504D4A484848494A4A4B4A4A49494A4C4F515355585959
5A5C5D5F62656A7179838E9AA6B2BAC2CAD2D5D7DBDFE7E5
ECF4F6F7F4EEE8E3DDD8D3CEC8C3BEB9B4B0ABA6A19C9893
8E8985807B77726D
635E58534E48433D38322D27211C16100A080E131D262F38
46505656595B5A58555351505152515254575A5A5B5A5857
55514E4A484748484947494A4A4948494D505254575A5B5B
5C5D5F6063666B727A838E99A6B2BBC4CBD3D6D9DDE1E9E8
EFF6F7F7F3EDE8E2DDD8D2CDC8C3BEB9B4AFAAA5A19C9793
8E8985807B77726D
635E58534D48433D38322C27211B16100A0B0F151E29323B
47535456595B595754514F505353505255595B5D5D5D5B59
56524F4B494747464747494C4B47474A4F515455585C5D5E
5E5F606264676C737B848E99A6B3BCC5CDD4D8DBE0E4EBEA
F2F7F7F8F3EDE7E2DCD7D2CDC8C3BEB9B4AFAAA5A09C9792
8E8984807B76726D
635E58534D48423D37322C26211B15100C0C0F17202C353E
49545456595A595653504F5054545155555C5D6060605E5B
58534F4C494746464648484B4A464A4A505257555A5E5F5F
6061616365686D747C858E9AA8B4BEC6CFD5D9DDE3E7EDEC
F5F8F9F8F2ECE7E1DCD7D1CCC7C2BDB8B3AFAAA5A09C9792
8D8984807B76726D
635E58534D48423D37322C26201A140E0D0C1119222D3741
4B535356595A59565351505255545357585F60636362605C
5854504D4A4846464648484A4A474B4B525458585D606161
62626364666A6E757D868F9BA9B4BFC8D1D6DBE0E5EAEFEF
F6F9FAF7F1EBE6E1DBD6D1CCC7C2BDB8B3AEA9A4A09B9692
8D89847F7B76726D
635E58534D48423D37312C26201A140D0E0E121A252F3843
4C5254575A5B5A58565453555656585B5D6163646463605D
5955514E4B4947464747494A4B4B4E505356595D5F616162
62636365676B70777F87919CAAB5BFCAD3D9DDE2E8ECF0F1
F7FAFBF6F0EBE5E0DAD5D0CBC6C1BCB7B2AEA9A49F9B9691
8D88847F7B76726D
635E58534D48423D37312C26201A140E0D0F131D27303944
4D5255585B5D5B5A5857565758595B5D606263656463605C
5955524F4C4A48474747494B4D4E505255585B5E5F606061
62636466696C71788089929EABB6C1CBD5DBDEE4EBEFF2F2
F8FCFAF5EFEAE4DFDAD4CFCAC5C0BBB7B2ADA8A49F9A9691
8D88847F7B76716D
635E58534D48423D37312B25201A140F090F161F29323A45
4D5256595D5E5D5C5B5A5959595A5B5D5F61636564625F5C
595553504D4B49474747494B4E50525456585A5C5D5E5F60
616265676A6D737A818A949FACB8C2CDD7DDE0E6EDF1F4F4
FAFCF9F3EEE9E3DED9D4CEC9C4C0BBB6B1ACA8A39F9A9591
8C88837F7A76716D
635E58534E48433D37312B252019140F081118222B343B46
4D53575A5E605F5E5D5C5B5A5A5A5B5E6164656563615E5B
585553504E4C4A4948484A4C4F5153545657595A5C5D5E5F
606365676A6F747A828B95A1ADB9C5D0D8DEE3E8EFF2F5F6
FAFCF8F2EDE7E2DDD8D3CEC9C4BFBAB5B1ACA7A39E9A9591
8C88837F7A76716D
635E59534E48433D37322C251F1912100A131B242C353D46
4D53585C6062615E5E5D5C5C5B5C60626365646362605D5A
585553514F4D4C4A4A4A4B4D4F515354555658595A5B5D5F
616466686B70767C848C97A3AEBAC7D2DAE0E5EAF1F3F5F8
FCFCF6F1ECE6E1DCD7D2CDC8C3BEB9B5B0ABA7A29E999590
8C87837E7A76716D
635E59534E49433D38322C262019110F0D161E262D363D46
4D53595E62646361605F5E5E5F61636363636261605E5C59
57555351504E4D4C4B4B4C4E4F515355555658595A5D5E60
626466696C71777D858D99A4AFBCC9D5DCE1E7ECF2F5F6FA
FEFBF5F0EAE5E0DBD6D1CCC7C2BDB8B4AFABA6A29D999490
8B87837E7A76716D
635E59544E49433E38322C262019110F121921272E363E46
4D545A5F646664636261616162636362626161605E5D5B59
57555452504F4E4D4D4D4D4E50515254545658595B5D5E60
626466696D73787E868F99A5B1BFCCD9DDE3EAEDF2F6F7FC
FFF9F4EEE9E4DFDAD4D0CBC6C1BCB8B3AEAAA5A19C98948F
8B87827E7A75716D
635E59544E49443E39332D27201A120F151C23282E363E46
4D545B6065676665646363626262626161605F5E5D5B5A58
56555352504F4E4E4D4D4E4E50505253545657585A5C5D5F
6264676A6E74797F87909BA7B4C1CEDCDFE5ECEEF3F8F8FE
FEF8F2EDE8E2DDD8D3CECAC5C0BBB7B2AEA9A5A09C98938F
8B86827E7A75716D
635E59544F4A443F3A342E28221B1410171D24292F373E46
4D555C61666867666564646363626161605F5E5D5C5A5957
5654535251504F4E4E4E4E4F5050515254555658595B5D5F
6164676A6F757A8088919DA9B5C3D1DEE1E7EDEFF3F9FAFF
FCF6F1EBE6E1DCD7D2CDC8C4BFBAB6B1ADA8A4A09B97938E
8A86827E7975716D
645F5A544F4A45403A352F29231D1611181E242A30373E46
4E555D626669686766656463636261605F5E5D5C5B5A5857
5554535251504F4F4F4F4F4F4F50515253555657595B5D5F
6164676B70757B8189939FAAB7C5D4E0E5E9EEF0F4F9FDFF
FAF4EFEAE4DFDAD5D1CCC7C2BEB9B5B0ACA8A39F9B96928E
8A86817D7975716D
645F5A55504B46413B36302B251F1912181E252B31373F46
4E555D6266696968676665646362615F5E5E5C5B5A595756
555452525150504F4F4F4F4F5050515253555657595B5D5F
6165686C71767C838B95A0ACBAC8D6E2E7EAF0F2F6FAFFFD
F8F2EDE8E3DED9D4CFCBC6C1BDB8B4AFABA7A29E9A96928D
8985817D7975716D
645F5A55504C47423C37322C27211B14191F262B31383F46
4E565D6266696969676665646261605F5E5D5C5A59585756
545352525150504F4F4F4F4F5051515253555657595B5D5F
6265686D72777D848D97A2AFBDCBD9E3E9ECF2F5F8FBFFFB
F5F0EBE6E1DCD7D2CEC9C5C0BCB7B3AEAAA6A29D9995918D
8985817D7975716D
645F5A56514C47433E38332E29231D161B20252B31383F47
4E565D6266686969686665636261605E5D5C5B5958575655
54535252515050504F4F4F505051525254555658595C5E60
6266696D72787F868F99A4B2C0CDDCE4EAEFF4F7FAFCFDF8
F3EEE9E4DFDAD5D1CCC8C3BFBAB6B2ADA9A5A19D9994908C
8884807C7874706D
645F5B56524D48443F3A35302B26201A1B1F242B31383F47
4E565D62656869686766646362605F5D5C5B5A5857565654
53535251515050504F4F505051515253545556585A5C5E61
63676A6E737A8088919BA7B5C3D0DFE5EBF0F7F9FBFDFAF5
F0EBE7E2DDD8D4CFCBC6C2BDB9B5B1ACA8A4A09C9894908C
8884807C7874706C
64605B57524E4945403B37322D28231F1A1F242B31383F47
4E565D61656768686765646261605E5D5C5A595857565554
53525251515050504F50505051525253555557585B5D5F61
64676B70757B8289939EAAB8C6D3E1E6ECF2F9FBFCFCF7F2
EEE9E4E0DBD6D2CDC9C5C0BCB8B3AFABA7A39F9B97938F8B
8783807C7874706C
64605C57534F4A46423D39342F2B26221D1F242B31383F46
4E555C606466676766646361605F5D5C5B5A585756555453
53525151515050505050505151525354555657595B5E6062
65686C71777D848C96A1AEBBC9D6E3E8EDF4FAFCFCF9F4F0
EBE7E2DDD9D4D0CCC7C3BFBAB6B2AEAAA6A29E9A96928F8B
87837F7B7874706C
64605C5854504B47433F3A36322E2925211F242B31373E45
4D555B6063656665656362615F5E5C5B5A58575655545353
525151515050505050505051525253545557585A5C5F6163
666A6E73797F868F9AA5B1BECBD8E5EAEFF6FAFCFBF6F2ED
E9E4E0DBD7D2CECAC5C1BDB9B5B1ADA9A5A19D9995928E8A
86837F7B7774706C
65615D5955514C4844403C3834302C292521252A30363D44
4C535A5F62646564636261605E5D5B5A5957565554535352
515150505050505050505151525354555658595B5D606265
686B70757B8289929DA8B4C1CDDAE7ECF0F6FAFBF9F4EFEB
E6E2DDD9D5D0CCC8C4C0BBB7B3B0ACA8A4A09C9895918D89
86827E7B7773706C
65615D5955514E4A46423E3A37332F2C2926272A2F353B42
4A52585D616363636261605E5D5C5A595856555453525251
515050504F4F5050505051525354555657595A5C5F616366
696D72777D858D96A1ACB8C4D0DDE9ECF1F7FAFAF6F1EDE8
E4DFDBD7D2CECAC6C2BEBAB6B2AEAAA6A39F9B9794908C89
85827E7A7773706C
65615D5A56524F4B4743403C3935322F2C2B292A2C323940
4850565C5F61626160605E5D5C5A59585755545352525150
504F4F4F4F4F50505050515253545556585A5C5E60626568
6B70747A8189919AA4AFBBC7D4E1E9ECF2F7F9F8F3EFEAE5
E1DDD9D4D0CCC8C4C0BCB8B4B0ADA9A5A19E9A96938F8C88
85817E7A7773706C
65615E5A5753504C4945423E3B3835322F2D2C2A292E363E
464E545A5D5F605F5F5E5D5C5A595857555453525151504F
4F4F4E4E4F4F4F505051525354555657595B5D5F6164676A
6D72777D858D959EA8B3BFCBD9E3E7ECF3F7F8F5F0ECE7E3
DEDAD6D2CECAC6C2BEBAB6B3AFABA8A4A09D9996928E8B87
84817D7A76736F6C
65625E5B5754514D4A4743403D3A373432302E2C292B353D
444C52575B5D5E5E5D5C5B5A595856555453525150504F4E
4E4E4E4E4E4F4F5051515254555657585A5C5E606365696C
70757B8189919AA3ACB7C3D0DBE2E7EDF3F6F6F2EDE9E4E0
DCD8D3CFCBC8C4C0BCB8B5B1ADAAA6A39F9C9894918E8A87
83807D7976736F6C
65625F5B5855524E4B4845423F3C393734322F2D292A333B
424A5055595B5C5C5C5B5A5958575554535251504F4E4E4D
4D4D4D4D4E4F5050515253545557585A5C5E606265686C6F
73787E858D959EA7B0BCC8D2DCE2E8EDF2F3F3EEEAE5E1DD
D9D5D1CDC9C5C2BEBAB6B3AFACA8A5A19E9A9793908D8986
837F7C7976726F6C
65625F5C595653504C494744413E3B393634312E2A2C3039
40474D5356595A5A5A595858565553525150504F4E4D4D4C
4C4C4C4D4E4F5050515253555658595B5D5F6264676A6E72
777D8289919AA2ABB5BFCCD3DCE2E9ECF0F1EFEAE6E2DEDA
D6D2CECAC7C3BFBCB8B5B1AEAAA7A3A09D9996928F8C8985
827F7C7975726F6C
6663605C595754514E4B484543403D3B383633312D2E2E37
3F454B50545758585858575655535251504F4E4E4D4C4C4B
4B4B4C4D4E4F50505153545557595B5D5F6164676A6E7276
7B81878E969EA7B0B9C4CED4DCE3E9EBEEEEEAE7E2DFDBD7
D3CFCBC8C4C1BDBAB6B3AFACA8A5A29E9B9894918E8B8885
817E7B7875726F6C
6663605D5A5754524F4C494744423F3D3A383633302E2F36
3D43484D51545657565655555352514F4E4D4D4C4C4B4B4B
4B4B4B4C4E4F505152545556585A5C5F6164676A6D71767A
7F858B929BA3ABB4BDC7CFD5DDE2E7EAEBEAE6E3DFDBD7D4
D0CCC9C5C2BEBBB7B4B1ADAAA7A4A09D9A9793908D8A8784
817E7B7875726F6C
6663605E5B585553504D4B484644413F3D3A383634323235
3B40454B4E5154555555545352504F4E4D4C4C4B4B4B4A4B
4B4B4B4D4E505152535556585A5C5F6164676A6D7175797E
848A90979FA7AEB7C0C9D0D6DDE2E6E8E9E6E2DFDBD8D4D0
CDC9C6C3BFBCB8B5B2AFABA8A5A29F9C9996928F8C898683
807D7A7774716E6C
6663615E5B595654514F4C4A484543413F3C3A3837353436
383D42484C4E525354545351504E4D4C4B4B4B4B4B4B4A4B
4B4B4C4D4F5152535557585A5D5F6264676A6D7174797E83
888E949BA3AAB2BAC3CBD1D7DDE1E3E6E5E2DEDBD7D4D1CD
CAC6C3C0BDB9B6B3B0ADA9A6A3A09D9A9794918E8B888582
807D7A7774716E6B
6664615F5C5A575552504E4B49474543413F3D3B39383737
363A3F45494D50515251514F4E4C4B4B4A4A4A4B4B4B4B4B
4B4C4D4F5052535657585A5C5F6264666A6D7174777D8287
8C93999FA6AEB6BDC5CCD2D7DBDEE2E4E1DDDAD7D4D0CDCA
C7C4C0BDBAB7B4B1AEAAA7A4A19E9C999693908D8A878482
7F7C797674716E6B
6664615F5D5A585653514F4D4B48464443413F3D3C3A3938
37383D41464A4D4E50504F4E4C4B4B4A4A4A4A4B4B4B4C4C
4C4D4E5052535557595A5D5F616465696C7074777B81868B
91979DA3AAB2B9C0C7CDD2D5D9DDE1E0DCD9D6D3D0CDCAC7
C4C1BDBAB7B4B1AEABA8A5A3A09D9A9794918F8C89868481
7E7B797673716E6B
666462605D5B59575452504E4C4A48464443413F3E3D3C3A
39383A3E43484A4D4E4E4D4C4A4A4A494A4A4A4B4B4C4D4D
4E4F50525455575A5B5D5F616365686C6E73777B80858A90
969CA1A8AFB5BDC2C8CCCFD4D8DCDFDBD8D5D2CFCCC9C6C4
C1BEBBB8B5B2AFACA9A6A3A19E9B989693908D8B88858380
7D7B787673706E6B
666462605E5C59575553514F4D4C4A4846454341403F3D3C
3B3A383B4045474A4D4D4C4B494949494A4B4B4B4C4E4E4F
505153545558595C5E60616365686B6E72777B7F84898E94
9AA0A6ACB2B8BEC2C7CACED5D7DDDBD7D4D1CECCC9C6C3C0
BDBAB8B5B2AFACAAA7A4A19F9C9A9794918F8C8A8784827F
7D7A787573706E6B
676462605E5C5A58565452514F4D4B4A4846454342413F3E
3D3C3A393E4345494B4C4B4A4848494A4B4B4B4C4E4F4F51
52535556585A5B5D60626466686B6E71767A7E83888D9298
9EA4A9AEB3B9BDC1C5CAD0D4D8D9D6D3D0CDCBC8C5C2C0BD
BAB7B5B2AFADAAA7A5A29F9D9A989593908D8B888683817E
7C7A777572706D6B
676563615F5D5B5957555452504E4D4B4A48474544434140
3F3D3C3A3C3F4347494A4B4A4847494A4C4C4C4D50505153
5456565A5B5C5E5F636467696B6E7175787D82878C91979C
A1A7ACB0B5B9BCC0C5CBD0D5D7D4D1CFCCC9C7C4C1BFBCBA
B7B4B2AFADAAA7A5A2A09D9B989694918F8C8A878582807E
7B79777472706D6B
676563615F5D5C5A5856555351504E4D4B4A484746444342
413F3E3D3C3C414547494B4A4847494B4C4E4E4F50525355
5759595D5E5F606266676A6C6E7175787C80858A8F959A9F
A4A8ACB0B3B6BCC1C6CCD0D5D2CFCDCAC8C5C3C0BEBBB9B6
B4B1AFACAAA7A5A2A09E9B999794928F8D8B888684817F7D
7B787674726F6D6B
67656362605E5C5B595756545351504E4D4B4A4948464544
4342403F3E3C3E4346494A4A49484A4D4E4F505152545657
5A5B5D5F61636465696A6D6F7174787B8083888D93989CA1
A5A9ABB0B2B6BEC3C8CCD1D1CDCBC8C6C4C1BFBDBAB8B5B3
B1AEACA9A7A5A2A09E9C99979592908E8C89878583807E7C
7A787673716F6D6B
67656462605F5D5B5A585755545251504E4D4C4A49484746
45444341403F3E414447494B4B4B4A4D4F5051535456585A
5C5E6062646768696B6D707174787B7E82868B9094989CA1
A4A8AAAFB3B9C0C4C8CDCDCBC9C6C4C2BFBDBBB9B7B4B2B0
ADABA9A7A4A2A09E9C99979593918F8C8A888684827F7D7B
79777573716F6D6B
67656462615F5E5C5B59585655545251504F4D4C4B4A4948
47464544434140404346494B4C4D4D4E5153545557585B5D
5F616365686A6C6D6F707273777B7D8184888C9094979A9F
A3A6ABB0B5BBC0C5C9CAC8C6C4C1BFBDBBB9B7B5B3B1AEAC
AAA8A6A4A2A09D9B99979593918F8D8B89878482807E7C7A
78767472706E6D6B
6766646361605E5D5C5A59575655545251504F4E4D4C4B4A
49484746454443424345494B4D4F5051525556585A5B5E60
626466686C6D6F7072737376797C7F8285888B8F92959A9E
A3A8ADB3B8BBC0C5C6C4C2C0BFBCBAB9B7B5B3B1AFADABA9
A7A5A3A19F9D9B99979593918F8D8B89878583817F7D7B7A
78767472706E6C6A
6766646362605F5E5C5B5A58575655545352504F4E4D4D4C
4B4A4948484746464546484B4D5053535457595B5D5F6163
64666A6B6E707171737475767A7C7E8183868A8E91969B9F
A4AAAFB5B8BBC0C2C0BEBDBBB9B8B6B4B3B1AFADACAAA8A5
A4A2A09E9C9A98979593918F8D8B8988868482807E7C7B79
77757372706E6C6A
676665636261605E5D5C5B595857565554535251504F4E4D
4D4C4B4B4A4A49484849494A4D51545657585C5E60626465
67696D6E7071727273757577797A7C7F82868A8E92979CA1
A6ABB0B4B9BABCBBBAB9B8B6B5B3B2B0AEADABAAA8A6A4A2
A09F9D9B9A98969492918F8D8B8A88868482817F7D7B7A78
767473716F6E6C6A
676665646261605F5E5D5C5A59585756555454535251504F
4F4E4D4D4C4C4C4B4B4B4C4B4F505458595B5E6061646567
696A6C6D6E7071717374747678797C8082878B9094999EA3
A6ABB0B4B6B5B6B5B4B4B2B1B0AEADACAAA9A7A6A4A3A19F
9D9C9A9897959392908E8D8B8988868483817F7D7C7A7977
757472716F6D6C6A
67666564636261605F5D5C5B5A5958585756555453525251
50504F4F4F4E4E4E4E4E4E4F505154585B5D5F6162646668
696B6C6D6E6F707071737475787A7D8184898C92979A9EA2
A6ABAEB0B0B0B0B0AFAEADACABAAA9A7A6A5A3A2A09F9D9C
9A9997969493918F8E8C8B898786848381807E7C7B797876
757372706F6D6C6A
68666564636261605F5E5D5C5B5B5A595857565655545353
525251515150505050515152535455595A5D606264656768
6A6B6D6D6E6E6F6F71737576787B7F83868B8E94979A9EA2
A5A8A9AAAAAAABAAAAA9A8A7A6A5A4A3A2A19F9E9D9C9A99
9796949392908E8D8B8A888786848281807E7D7B79787775
747371706E6D6B6A
6867666564636261605F5E5D5C5C5B5A5958585756565555
5454535353535252535354545557585A5B5F616264666769
6A6B6D6D6E6F6F70727475787A7C8185878B8F9397999D9F
A0A2A3A4A5A5A5A5A5A4A3A3A2A1A09F9E9D9C9A99989795
949392908F8D8C8A898886858482817F7E7D7B7A78777674
7372716F6E6D6B6A
686766656463626161605F5E5D5D5C5B5A5A595958575756
56555555555554555555565657585A5B5D5F61616465676A
6B6C6D6E6F6F7071727477797B7D8184878B8F939597989A
9C9D9E9F9FA0A0A0A09F9F9E9D9D9C9B9A99989796949392
91908E8D8C8A89888785848382807F7E7D7B7A7877767574
7271706F6D6C6B6A
68676665646463626161605F5E5E5D5C5C5B5A5A59595858
575757575756565757575858595A5B5D5E5F61626465686A
6B6D6E6E6F6F7071727577797B7D8084878A8D8F91939495
9798999A9A9B9B9B9B9A9A9A99989897969594939291908F
8E8D8B8A8988878684838281807E7D7C7B7A787776757473
72716F6E6D6C6B6A
6867666665646363626161605F5F5E5D5D5C5C5B5A5A5A59
595959585858585859595A5A5B5C5D5E5F6062636566686A
6B6C6D6E6F6F7071737577797B7D80828587898B8D8F9091
929394959696969696969695959494939291908F8E8E8D8C
8A8A8987868584838281807F7E7C7B7A7979777675747372
71706F6E6D6C6B6A
68676766656564636362616160605F5F5E5D5D5D5C5C5B5B
5B5A5A5A5A5A5A5A5B5B5B5C5C5D5E5F6062636465666869
6B6C6D6D6E6F707173747677797C7E80828486888A8B8C8D
8E8F9091919292929291919191908F8F8E8D8C8C8B8A8988
8786868584838281807F7E7D7C7A7A797877767574737271
706F6E6D6D6B6A6A
686767666665646463636262616160605F5F5E5E5D5D5D5C
5C5C5C5C5C5C5C5C5C5C5D5D5E5F60616162636465676869
6A6B6C6D6E6F707172737576787A7C7E7F81838586878889
8A8B8B8C8D8D8D8D8D8D8D8D8C8C8B8B8A89898887878685
8483838281807F7E7D7C7C7B7A7978777676757472727170
6F6F6E6D6C6B6A69
6868676666656564646363626262616160605F5F5F5F5E5E
5E5D5D5D5D5D5D5E5E5E5E5F606061626263646566676869
6A6B6C6D6D6E6F707172747576787A7B7D7E808182838585
868787888989898989898988888887878686858584838382
8180807F7E7E7D7C7B7A797878777675757473737171706F
6F6E6D6C6C6B6A69
68686767666665656464646363626262616161606060605F
5F5F5F5F5F5F5F5F5F5F6060616162626364656566676869
6A6B6B6C6D6E6E6F70717274757678797A7B7D7E7F808182
828383848484858585858484848483838282828181807F7F
7E7D7D7C7B7B7A7979787776767574747373727171706F6E
6E6D6D6C6B6A6A69
686867676766666565656464646363636262626261616160
606060606060606161616162626263636465656667676869
6A6A6B6C6D6D6E6E6F7071727374757777797A7B7C7C7D7E
7E7F7F80808080818080808080807F7F7F7E7E7D7D7D7C7C
7B7A7A7979787877767675747473737272717170706F6E6E
6D6D6C6B6B6A6A69
686868676767666666656565656464646363636363626262
626262626262626262626363636364646565666767686869
696A6B6B6C6C6D6E6F6F7071717273747576777878797A7A
7B7B7B7C7C7D7C7D7C7C7C7C7C7C7B7B7B7B7A7A7A797978
7877777776767575747373727272717170706F6F6E6E6D6D
6C6C6B6B6A6A6A69
686868686767676766666666656565656564646464646363
636363636363636363646464646465656666676768686869
696A6A6B6B6C6C6D6D6E6E6F707071727373747575767677
777778787878787878787878787878787777777776767575
75747474737373727271717070706F6F6E6E6E6E6D6D6C6C
6C6B6B6A6A6A6969
686868686867676767676666666666666665656565656565
656565656565656565656565656666666667676768686869
69696A6A6B6B6B6C6C6D6D6D6E6E6F707071717272727373
737474747474747474747474747474747474737373737272
72727171717070706F6F6F6F6E6E6E6D6D6D6D6C6C6C6B6B
6B6B6A6A6A6A6969
686868686868686867676767676767676767676666666666
666666666666666666666666666667676768686868686869
6969696A6A6A6B6B6B6B6B6C6C6C6D6D6E6E6E6E6F6F6F70
70707070707071707070717070707070707070706F6F6F6F
6F6F6E6E6E6E6E6D6D6D6D6D6C6C6C6B6C6B6B6B6B6B6A6A
6A6A6A6969696969
696868686868686868686868686868686868686767676767
676767676767676767676767676868686868686868696869
6969696969696A6A6A6A6A6A6A6A6B6B6B6C6B6B6C6C6C6C
6C6C6C6C6C6D6D6C6C6C6D6C6C6C6C6C6C6C6C6C6C6C6C6C
6C6C6C6B6B6B6B6B6B6B6B6B6B6B6A6A6A6A6A6A6A6A6A6A
6969696969696969
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.678571 0.343006 0.97619 0.640625 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00751202 0.0192308 0.00751202 [
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(120) show
81.000000 12.812500 moveto
(deg) show
99.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(.) show
105.000000 12.812500 moveto
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
128 string
128 128 8 [128 0 0 128 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
4F4F4F4F4F4F4F4F4F4F4F4F505050504F4F4F4F4F4F4E4D
4F4E4E4D4D4D4C4C4C4C4B4B4B4B4B4B4B4B4B4B4B4B4B4B
4B4B4B4B4B4B4B4B4B4B4B4B4B4B4B4C4C4B4C4C4C4C4C4B
4B4B4B4B4B4B4B4B4B4B4B4B4B4B4B4C4C4C4C4C4C4C4C4C
4C4C4C4C4C4C4C4C4D4C4D4D4D4D4D4E4E4F4F5050505151
515050505050504F
4F4F4F4E4F4F4F4F4F4F5050515150504F4F4F4E4E4D4D4D
4F4D4C4C4B4A494948484747474746464646464646464747
484847474747474747474747474748484848484848484848
484848484747474747474747464748484849484949494949
4949494A4A494A4A4A4A4A4A4B4B4C4C4D4E4F5151525253
535150515151504F
4F4F4F4F4F4F4F4F4F4F505051515150504F4F4E4D4D4D4E
4D4B4B4A4947474645444343434242414142424242434344
444444444444444343434343444444454545454545444444
444444444444444443434343424345484645454546474646
46464646474747474748484949494A4B4C4D4F5152535353
5252525252515150
4F4F4F4F4F4F4F4F4F4F4F4F50515251504F4F4E4D4D4C4C
4D4C4A484746444341403F3F3E3E3D3D3D3D3D3E3E404041
414242414141414040404040404041414141414141404040
4040404040404040403F3F3F3F3F40424343424343434344
434344444444444445454646474748494B4D4F5153535353
5252525353525150
4F4F4F4F4E4E4E4E4E4E4E4F4F50505151504F4E4E4D4C4C
4B4A4947454341403E3D3B3A39393939393939393B3C3D3E
3F3F403F3F3E3E3D3D3D3D3D3D3D3D3D3C3C3C3C3C3C3C3C
3C3C3C3C3C3C3C3C3C3C3B3C3C3C3C3D3E3F403F40404040
404040414141414242424344444546484A4C4E5152525252
5253535454545251
4F4F4F4E4E4E4E4E4D4D4D4D4E4F4F4F50504F4E4D4D4C4A
4949484543413F3D3A39373635343333333435363738393B
3C3C3D3D3D3C3B3B3B3B3A3A3A3A3A393939393837373737
37373737373737373737373738383839393B3D3C3C3C3C3C
3C3C3C3D3D3E3E3E3F40404142434445474A4D4F4F4F5050
5153535556545251
4F4F4F4E4E4E4D4D4D4D4C4D4D4D4D4D4E4E4E4E4D4C4B4A
48474543403D3B3937343231302F2F2E2F30313233353637
38393A3A3A3A393939383837373636363635353433333333
333232333333333333333333343434353536383939383737
37383839393A3A3B3C3C3D3E3F40424446494D4D4E4E5051
5253545656545251
4F4F4E4E4D4D4D4C4C4C4B4B4B4B4B4B4B4B4B4C4B4A4948
464442403C3A373532302E2C2B2A2A2B2C2D2E2F30313234
3536363737373737363636363534343332323130302F2F2F
2F2E2E2E2E2E2E2F2F2F2F2F303031313132323333333333
333434353536373838393A3B3C3E4144474B4C4C4D4E5152
5354555656545251
4F4F4E4E4D4D4C4B4B4B4B4A4A4A49494949494949484746
4442403E3C3934302E2B29282726272728292B2C2D2E2F30
3132333434353535353534343333333231302F2E2D2D2C2C
2C2B2B2B2B2B2B2B2B2C2C2D2D2E2E2E2E2E2E2E2F30302F
2F30303132323334343537383A3E42474A4B4D4E50515355
5656575756545351
4F4E4E4D4C4C4B4B4A4A4949494848474746464645444341
403E3B393735302B292624222222222223242627292A2C2D
2E2F30313131323232323232313131302F2F2E2E2D2D2C2B
2B2B2A2A2A2A2A2A2A2B2B2B2B2B2C2C2C2C2C2C2D2D2E2F
2F2D2D2E2F2F3030313133363B4146494C4E4F5052545556
5757585857555351
4E4E4D4D4C4B4A4A4A494948484746454544434342413F3E
3C393735322F2C2824201E1D1C1C1D1E1F2122242627292A
2B2C2D2E2E2F2F303030302F2F2E2E2D2D2C2B2B2B2A2A29
292828282827272727282828282828282929292A2A2A2B2B
2D2F312E2D2D2D2E3034393D4145484B4D51525254555759
595A5B5958555351
4F4E4D4C4C4B4A4A4948484746454444434241403F3D3C3A
383633312E2B2826211D1A17151617181A1C1E2022242628
292A2B2B2C2C2C2D2D2D2D2C2C2C2B2A2A29292827272626
262525242424242424242424242425252526262627272828
292A2B2C2E302F31363A3E4246484A4D5053525456585A5B
5B5D5C5B59565452
4E4E4D4C4B4A4949484746454544434241403E3D3C3A3836
3432302E2B2825221F1A16120F0F111315181A1D1F212425
27282829292A2A2A2B2B2B2A292928282727262525242322
222221212120202020212121212122222222222323242425
262728292A2D32383C4044474A4D5052545556585A5B5D5D
5E5E5D5C59575552
4E4D4C4B4B4A494847464544434241403F3D3C3A39373533
312F2D2A2724221F1C17130F0D0A0A0D101316191C1F2123
24262627272828282828282726262525242423222221201F
1F1E1E1E1D1D1D1D1D1D1D1D1D1E1E1F1F1F1F2020212223
2425272A2E34393E4246484B4F5154555758595C5E5F6060
60605E5C5A575452
4E4D4C4B4A4948474645444342403F3E3C3B393836343230
2E2C2A2724211E1B1713100D0B0906070B0F13171A1D1F21
23242525252626262626252524242322212120201F1E1D1C
1C1B1B1A1A19191919191A1A1A1B1B1B1C1C1D1D1D1E2021
2326292E353A3E42474B4E51535557585A5C5F6163636262
63615F5C5A575552
4E4D4C4B4A49474645444342403F3D3C3A3938363432302D
2B292624211E1A1714110E0C0A080706080C1014181B1E20
222223242424242424242323222120201F1E1D1D1C1B1A19
191817171716161616161616171718181819191A1B1C1E21
23272C333B3F43474B4F535657585B5D5F61636466666566
64625F5D5B585552
4E4D4C4B4A484746454341403F3D3C3A39373533322F2D2B
282623201D1A1714110E0B0A0808080806080D12161A1D1F
20212222232323232222222120201F1E1D1C1B1A19181717
161514141313131313131313141415151617191A1B1D1F22
262C343B3F43484D505355585B5E60626465676767676868
6663605E5B585552
4E4D4C4B494847454442403F3D3C3A39373533312F2D2B29
2623211E1B1714100D0A09090808090909080B11161A1D1F
20212222222222222121201F1E1E1D1C1B1A191817161514
141312111010101011111111111213141516181A1C1E2227
2D353C4144474C505355585C5F626567686A6A6B6B6B6B69
6765625F5C595652
4E4D4B4A494746444341403E3C3B39373634312F2D2B2926
24211E1B1815110E0B08080808090A0B0B0D0D11171B1D1F
2021222222222121201F1F1E1D1C1B1A1918171614141312
11100F0F0E0E0D0E0E0E0E0F0F1011131416181A1D22272E
353B4144484C5054575B5E616467696B6C6D6D6E6E6D6B6A
6865625F5C585552
4E4D4B494846454442403E3D3C3A37353432302D2B292624
211F1C1915120F0B08060607080A0C0D0E111418191C1F20
21222222222121201F1E1D1D1C1B1A191816151412121110
0F0E0D0C0C0B0B0C0D0D0D0D0D0F101214171A1E23292F36
3B4045484C5054575B5E6164676A6C6E6F707071706F6E6B
6966625F5C595652
4E4C4B4947464443413F3E3C3A38373432302D2B29272422
1F1C1916130F0C0905040607090B0D0F121518191B1F2122
232323222221201F1E1E1D1C1A1918171615141211100F0E
0D0C0B0A0A0A0A0B0C0B0A0B0D0F1113161A1E232A31373C
42474A4D5054585A5D606467696C6F717272737372716F6C
6965625F5C595652
4E4C4A4947464442413F3D3B39373533312E2C2A27252220
1D1A1714100D0A0604040507090C0E1115191B1D20222324
242423222221201F1E1D1C1B1918171615131211100F0E0C
0B0A0A0908090A0A0A090A0D0E101214191F242A30363B40
45494D5154575B5E6264686A6D7073737475757573716F6C
6966635F5C595652
4D4C4A4947454342403E3C3A383634312F2D2B282623211E
1B1815120F0B080403030507090C0F13181C1E2025262625
252524232322201F1E1C1B1A19171615131211100E0D0C0B
0A0908080808090907080A0D0F1115191F262B31363B3F44
494D5154595D606265676A6D707375767778787674716F6C
6966625F5C595652
4D4C4A48464442413F3D3B39373532302E2B292724221F1C
191613100C090603030306080B0E11161A1D202429292928
27272625242221201E1C1B1A181615141311100F0E0D0C0B
0A08080708080807080A0C0F11151920262C32383C41464A
4E5154585D616365686B6E71747778797A7A787674716F6B
6966625F5C595652
4D4B4A48464442403E3C3A383533312F2C2A282522201D1A
1714110D0A070402030406090C1014191B1E22272C2C2B2A
29292826242322201E1D1B19181615141211100F0E0C0B0B
0A09080809090908090C0E11151A20252C32373D42474A4D
5154585C606367696C6F727477797A7B7C7B797774726F6C
6966625F5C595552
4D4B49474543413F3D3B39373432302D2B292623211E1B18
15120F0C090603010204070A0E11161A1C20262B302F2E2D
2C2B292827252321201E1C1A191715141312100F0E0D0C0B
0A0A09090A0A090A0C0F12151A1F242A31373D42474B4F51
54585C5F6366696B6F7274787A7B7D7D7C7A787775726F6C
6966625F5C595652
4D4B49474542403E3C3A383633312E2C292724211F1C1916
13100D0A070401010204070B0F13181C20242A2F33323130
2F2D2C2A2927252321201E1C1A181615141211100F0E0D0C
0B0A0A0B0B0B0C0E1013161B20242A31373C41464B4F5356
595C5F6366696C6F7273767A7C7E7E7E7C7B797775726F6C
6966625F5C595652
4D4B48464442403E3C39373432302D2B282522201D1B1815
120F0C08050200010305090E11161B1F22282D3237363533
32302F2D2B2928262422201E1C1A181615131211100F0E0D
0C0C0C0D0D0D0E1115181C20242A31373C41464B5054585A
5D606466696C6F717376797D7F80807F7D7B797775726F6C
6965625F5C595652
4D4B494644423F3D3B393634312F2C292724211F1C191613
100D0A070401000103070A0F14191D21262D33373B3A3938
363432302E2D2B29272523211F1D1B19171614131211100F
0E0E0E0F10111316191D2023282F363D42464A4E53575B5F
6265686A6C6F717375797D808182817F7E7C7A7874716F6C
6865625F5C595652
4D4B484644413F3D3B383533302E2B282523201D1A181511
0E0C08050200000204080D12171C20262C33393D413F3E3C
3A38363433312F2D2B29262422201E1C1A19171514131211
111212131415181C1E21242930373E4245494D52575B5F61
65696B6D6F727376797C8083848381807E7D7A7875726F6B
6865625F5C595552
4D4A484543413E3C3A3734322F2D2A2724221F1C19161310
0D0A070401000002060A10151A1F242B32393F4346454341
3F3C3A39373533312F2D2B29262422201E1C1A1917161515
14141517181A1E2123262B31383F43474B4E52565A5E6164
686B6D6F7275777A7D818385858482817F7D7A7875726F6B
6865625F5C595652
4C4A484543413E3C393734312E2C292624211E1B1815120F
0B08060300000104080D13191E2429313940454A4D4B4845
43403E3C3A3836353332302E2C29272523201E1C1B1A1919
19191A1B1D212526292D323A3F43484B4F52565A5E616569
6B6D6F717477797D8083858786848382807D7A7774716E6B
6865625F5C595552
4D4A484543413E3B393633312E2B282522201D1A1714110D
0A070501000002060B0F151B22282F3940474D52534F4B47
44423F3E3C3A39373634333231302D2B28262422201F1E1D
1D1D1E2023282C2D30343A4045494D5053575A5E6164686B
6D6F717577797C808385878786848382807D7A7774716E6B
6865625F5C595653
4C4A484543403D3B383533302D2A2724211F1C1916130F0C
09060301000104080D131A20262D3640474F575A56504C48
4542403E3C3A393837363535343333312E2C292726242322
21222325292E3234373B40464B4F5255585C5F6265686B6E
70717477797B7F828486898886868582807D7A7774716E6B
6865625F5C585552
4D4A484542403D3A3734322F2C292623211E1B1815120E0B
080502000002060A0F161D242B333D464E595D5A544F4B47
44423F3D3B3A3938383837373636363534322F2D2B292827
2627282B3033383C4044484C505457595C5F6265676A6C6F
717477797C7E82848688898888878582807D7A7774716E6B
6865625F5C595652
4D4A4745423F3D3A3734312E2B282623201D1A1714100D0A
070401000104080D131A21283039444C565B5956524E4A46
43403E3D3B393838383737383838383838373634312F2D2C
2C2C2E31353A3E41464A4F54575A5D5E606264676A6C6E71
7476787B7E81848688898A8A89878582807D7A7774716E6B
6865625F5C595552
4C4A4744423F3C393634312E2B2825221F1C1915120F0B08
0503010102060A10161E252D36414B545B5B5854504C4844
413E3C3B39383837373839393A3A3B3B3B3B3B3938353332
313133353A3E42474D5356585A5C5E60636567696B6E7073
76787B7E81848587898B8C8B89878582807D7A7774716E6B
6865625F5C585552
4D4A4744423F3C393633302D2A2725211E1B1814110E0B07
0402010103070C131A232A333D49535B5D5956524E4A4642
3F3D3B39383736363737383A3B3C3D3E3E3E3E3E3E3C3938
3737383B3E41464B50555A5E5E6062646567696B6E717375
777B7F81838687898C8D8E8C8A878583807D7A7774726E6B
6865625F5C595652
4D4A4744413E3C393633302D2A2724211D1A1613100D0906
0301010105090F161E272F39444F5A5D5B5854504C484441
3E3C3A38373636373738393B3D3E4040414141424242413F
3D3D3D3F4245494F53595E6062636567696A6C6F71737577
7A7E80848788898B8D8E8D8C8A888583807D7A7774716E6B
6865625F5C595652
4C494744413E3B3936332F2D292623201C1916120F0B0805
03010103070C131A232C35414C585E5B5956534F4B474341
3F3D3C3A39393838393A3B3D3F4142434444454545454544
4242424345484C50545A5E626668686A6B6D6F7173747779
7B7F828587898B8D8E8F8D8C8A888683807D7A7875726F6C
6965625F5C595552
4C494744413E3B3835322F2C2925221F1C1815110E0A0704
02010104080F161F28313C47525A5B5A5855524E4A464342
4140403F3E3D3C3B3B3C3E40424445464748484848484849
49474747494B4E52585B5F63666A6C6C6D6F70727476787A
7D808385888A8C8F908F8E8C8A888683807D7B7875726F6C
6966625F5C595552
4C494643413E3B3835322E2B2825211E1B1714110D090603
010001050B121A232D37434E5A5E5B5A5855524D4A49494A
4946454444424242434343444647494A4A4B4B4B4B4C4C4D
4E4E4C4C4D4E4F53585B5E61656A6D6F707072757677797C
7E818486888A8D8F91918F8D8B898683807E7B7875726F6C
6965625F5C595652
4C494643403D3A3734312E2B2824211E1A1713100C080401
000002070E151E28323D49555C5C5C5A585653504E4E4D4B
4949494745454647484949494A4C4D4D4E4E4E4E4E4F4F50
5152515150515356575A5E6165686D707173757577797B7D
7F8285878A8D8F9092918F8D8B898684817E7B7875726F6C
6966635F5C595652
4C494643403D3A3734312E2B2824211D1A16130F0B070401
0002050A111A232D3844505B5E5C5C5B5957555353525252
51504F4F4E4D4E4F4E4F5050505051515151505151515253
5354545353555556585C5D6063676B70737576777A7B7C7E
818486898C8F909293918F8D8C898784817E7B7875726F6C
6966625F5C595652
4C494643403D3A3734312E2B2724211D1916120E0A060301
0103070D161F28333F4A575D5C5C5C5C5B5B5D5D5D5E5D5C
5C5B5B5A5A5B5C5B5C5D5E5E5D5B57555453535354545455
55565657575757595A5B5E606266696E727577797B7C7E80
8385878A8C8F91949492908E8C8A8784817F7C7975726F6C
6966625F5C595652
4C494643403D3B3734312E2B2724201D1915110D09060301
02050B121A232D38434F585B5C5C5C5D5D5E5F6164666666
6564636364646464636361605F5D5A585756565655565656
57585859595A5B5B5B5C5D5F6265686C7175797B7C7D7F82
8485888B8D9091949492918F8D8B8885827F7C7976736F6C
696663605C595652
4C494743403D3A3734312E2B2723201C1915110D09050202
03080E151E27323D48545B5B5C5D5D5E5E5F606162636464
636261616160616161616160605E5C5B5A59585857575758
5859595A5A5C5D5D5E5F606162666A6D7075797B7D808182
84878B8D8E919396959391908E8B8885827F7C797673706D
696663605C595652
4C494643403D3A3734312E2A2724201C1815110D09050302
060C131A232D37414B565A5B5C5D5E5E5F5F606161616261
61605F5F5F5F5F6060616161605F5E5D5B5B5A5A5959595A
5A5A5B5B5D5E5D5D5E5E5F616567696C7074777B7F818385
878A8C8E90929596959492908E8B8986837F7C7A7673706D
6966635F5C595653
4C494644413E3B3734312E2A2724201C1915110C08050406
0A10171F28313B454F575A5C5D5E5E5F5F60606060606060
5F5E5D5D5D5D5E5F5F60606160605F5F5E5D5C5B5B5B5B5B
5B5B5B5C5D5E5F60606162646667696D7073797D7F828487
8A8D8E9092949798979594928F8C898683807D7A7773706D
696663605D595652
4C494744413E3A3734312D2A2723201C1815110C08050508
0D141B242D374049545B5B5D5E5E5F5F6060606060605F5E
5E5D5C5C5C5C5D5E5F5F60606161605F5E5E5E5D5D5D5C5D
5D5D5D5D5E5F60616162636567696C6E7277797D80848689
8B8E909395979A9897969593908D8A8683807D7A7774706D
6A6763605C595652
4C494744413E3A3734312E2A2723201D1915110D0907070B
10171F28313A444D585D5D5E5F5F5F60606060605F5F5E5E
5E5E5D5D5C5C5D5E5E5F60616161616060605F5F5F5E5E5E
5E5E5E5F60606060626365676A6C6F7174767A7F8385888B
8D8F9195979A9B9998969593908D8A8784817E7A7774716D
6A6763605D595652
4C494643403D3A3734312E2A2724201D1915110D09080A0F
151C242D373F47505A5D5E5F5F60606060606060605E5E5F
61605F5E5D5E5F5E5F606162626261616160606060606060
60606060616262646466676A6C6F717476787E818487898B
8E919497999B9B9B9A999794918E8B8784817E7B7774716E
6A6763605D595652
4C494643403D3B3834312E2B2724201D1915110D0A0A0E14
1A222A323B434C565E5F6060616060606060606060616363
626161626464636362626263636262616161616161616161
616162636364646667696B6D6F717477787D818387898C8E
919497999A9B9B9C9C9C9895928E8B8885817E7B7874716E
6A6764605D595653
4D4A4744413E3B3835312E2B2824211D1916120E0C0D1117
1E272F383F47515B61616161616161616060606060616263
626262626363636364646464636362626261616162626263
63636364656666696B6D6F717375777A7D8284878A8B8E91
9496999B9D9E9FA09F9C9996928F8C8885827E7B7875716E
6A6764605D5A5653
4C4A4744413E3B3835322F2B2825211E1A16130F0D10161D
242C343C434C566064636362626161606060606060616162
616161616262626364656564636362626262626262636364
6565656667686A6C6E71717477797B7E8286888B8D8F9194
96989B9EA0A0A1A2A19D9A9693908C8985827F7C7875716E
6B6764605D5A5653
4C494744413E3B3835322F2C2825221E1B17130F0F141920
2831384047505A6364646362626160606060606060606060
606060606061626364656564636362626262626363636465
66676768696B6D6F717376787A7D7F8386898C8E90939495
989B9EA2A3A2A4A4A19E9A9793908D8A86837F7C7975726E
6B6764605D5A5653
4C494744413E3B393633302D2926221F1C18151213181E27
2F363D444D576167666564636160605F5F5F5F5F5F5F6060
605F5F606162636364656463636262616162626263646565
6668696A6B6D6F717577787A7D7F83878A8E909294959698
9A9DA0A3A5A7A8A6A29F9B9895918E8A8783807C7975726E
6B6864615D5A5653
4D4A4744413F3C393633302D2A2723201C191614171C242C
333A424B555F696C6866646261605F5F5E5E5E5E5F5F5F60
606060606162636364646363626161616161616262646566
67686A6B6D6F717477797B7E8183868A8D9194959697979A
9CA0A3A7A8A9A9A6A39F9C9995928E8B8784807D7976726F
6B6864615D5A5653
4C4A4744423F3C393633302D2A2724211D1A16151A202830
383F47505B686E6B68666362605F5E5D5D5D5D5D5E5F5F60
6060606061626262626262616160605F5F60606162646566
68696B6D6E7073767A7D7F8183868A8D909497979898999C
9EA3A6A9ABABAAA7A3A09D9996928F8B8884807D7976726F
6B6865615D5A5653
4D4A4745423F3D3A3734312E2B2825221F1B16171D242D34
3C444D57626B6B6A676462615F5D5C5C5C5C5C5C5D5E5E5F
5F606060606161616160605F5F5E5E5E5E5E5F6061636466
67696B6D6F7174767A7D7F8285888C8F93979999999A9B9E
A1A6AAACADADABA7A4A19D9A96938F8C8885817E7A76736F
6C6865615D5A5653
4D4A484542403D3A3735322F2C2926231F1C1A1D23293239
4149525C676C6A686563615F5D5B5B5A5A5A5B5B5C5D5E5F
5F5F5F60606060605F5F5E5D5C5C5B5B5B5C5D5E5F616365
67696B6D6F7274777A7D8083868A8D9194989A9A9B9D9FA1
A5AAACAEB0AEABA8A5A19E9A9793908C8985817E7A777370
6C6965615E5A5653
4D4A484542403D3B383532302D2A2724211E1C21272F353C
444D57626B6C696664615F5D5B5A5958575859595B5C5D5E
5F6060605F5F5F5E5D5D5C5B5A5A5959595A5A5C5E606264
67696B6E707376787B7E8184888B8F92959A9B9C9D9EA0A3
A7ACAFB1B2B0ACA9A6A29F9B9894908D8986827E7B777370
6C6965615E5A5653
4D4A484643403E3B383633302D2B2824211D1D242A323A41
48515B666B686664625F5D5B59575655555657585A5C5D5E
5F6060605F5F5E5D5C5B5A59585756565656585A5C5E6164
66696B6E707376797C7E8285898D9094989B9C9D9F9FA2A5
AAAFB3B5B4B1AEAAA7A3A09C9895918D8A86827F7B777470
6C6965625E5A5653
4D4B484643413E3C393734312E2B2826231F22292E353C43
4B555E6566656462605E5B5956555453535456575A5C5D5F
606161605F5E5D5C5B5A5A5857555353535455585A5D6063
65686B6E707376797C7F83868A8E9296999D9E9FA0A2A6A9
AEB2B6B8B7B3AFABA8A4A09D9995918E8A86837F7B787470
6D6965625E5A5753
4D4B484644413F3D3A3735322F2C29272421252A31383E46
4E596266636362605E5B595654525151525255575A5C5E60
61626261605F5E5D5B5A58575553525151515355585C5F62
65686B6D707376797D8184888B8F93979B9EA0A1A2A5ABAD
B2B6B9BAB8B4B0ADA9A5A19D9996928E8B87837F7C787471
6D6965625E5A5753
4D4B49474442403D3B383633302E2B282625292C32394148
525B61616162615F5D5A575452504F4F505255585B5E6062
6364636362605F5D5C5A58565453514F4F515356585C5F62
65686B6D707376797D82868A8D9195999DA0A2A3A6AAB0B1
B5BABBBBBAB6B2AEAAA6A29E9A97938F8B8783807C787571
6D6966625E5A5753
4D4B49474542403E3B393734322F2C2925252B2E343B434B
555E62606161605E5C595552525454525154585A5C606365
666666656463625F5D58565657565351535456575A5D6063
67696B6E7073767A7E82878A8E93979BA0A3A5A7ABAEB3B5
BABFBFBEBBB7B3AFABA7A39F9B97938F8B8884807C787571
6D6966625E5A5753
4D4B49474543413F3D3A383532302D2A282A2D32373E464D
555C5F606162605E5C59565558595757595B5D6063656668
6969686767666462605F5E5E5D5856585A5A5C5D5E616366
696B6D6F7174777B7F83868A90969A9EA2A6A8ABAFB3B7B8
BEC1C1C1BDB8B4B0ACA8A4A09C9894908C8884807D797571
6D6A66625E5A5753
4D4C4A48464442403D3B393634312E2C2C2D2E3339414850
585E5D5E6061615F5D5B5A595A5B5B6060636567696B6D6E
6D6C6B6B6A6A6867656464625E5C5E5D5F6063626468696A
6C6D6F707275787C8085898E94989CA1A6A9ABAFB4B7BBBC
C1C3C4C3BEBAB5B1ADA9A4A09C9894908C8985817D797571
6D6A66625E5A5753
4D4C4A48464442403E3C3A3735322F2A292C31363D444A51
585C5C5E6162636262626264646161646970717374757473
71706F6E6E6D6D6C6B6A6867666364666A6A6A6C70717070
707071737476797D82878C92989DA0A4A9ADB0B3B7BCC0C1
C5C6C7C4BFBBB6B2AEA9A5A19D9995918D8985817D797571
6D6A66625E5B5753
4E4C4A49474543413F3D3B393634312D2C2E31373F454B51
575B5C5F62646566686A6D6F6F70727577797B7D7D7B7977
757372717171717170706F6E6D707476767777797B7A7876
7575747577797C8085898F949A9FA3A8ADB1B4B8BCC0C4C5
C8C9C9C5C1BCB7B3AEAAA6A29D9995918D8985817D797672
6E6A66625E5B5753
4E4C4B4948464442413F3C3A38353332312F323940464C53
585A5C5F626567696C6F73777A7C7E8082828181807E7C7A
77767574747473737373747577787B7E81838483817F7D7A
797777787A7C7F83878B90969CA2A8ACB1B5B8BCC1C4C7C8
CBCDCCC7C2BDB8B4AFABA6A29E9A96918D8985817D7A7672
6E6A66625E5B5753
4E4C4B4A4847454442403E3C393735333031363D434A4F54
585B5D606467696B6D7074777A7C7D7E7F80818383817E7C
7A7876767676777777757576787B7F8183848382807E7C7B
79797A7B7C7F82868A8E93999FA4AAB0B5B8BCC0C4C7CACB
CECFCCC7C2BEB9B4B0ABA7A39E9A96928E8A86827E7A7672
6E6A66625E5B5753
4E4D4C4A494846454342403E3B39363432373C42484E5257
5A5C5F6266696B6D6E71737678797C8084878A8985827F7C
7A7978777778797A7C7D7D7C7C7C7D7F8080807F7E7D7C7B
7B7C7D7E7F8285898C90969CA2A8AFB6BABEC0C4C7CACBCD
D0D0CDC8C3BEBAB5B0ACA7A39F9A96928E8A86827E7A7672
6E6A66625F5B5753
4E4D4C4B4A4948464543413F3D3B3635363C42494D515559
5C5E6165696C6E6F70717375777C83898C8C8A8885827F7C
7A79787878797A7B7E8184868684817F7E7D7D7D7C7C7C7D
7F8081828385888C90949AA0A6ABB1B8BEC1C4C8CBCDCECE
D2D2CDC9C4BFBAB5B1ACA8A39F9B96928E8A86827E7A7672
6E6A66625F5B5753
4E4D4D4C4B4A494846454442403D39373841484E5256595C
5F6265686C6F71747778797B808589898988878582807E7C
7A79797979797A7C7E80838588898A898784828181828383
8383838486898C8F92979DA1A7ADB5BDC2C5C9CCCFD0D1D3
D6D3CEC9C4BFBBB6B1ADA8A49F9B97928E8A86827E7A7672
6E6A66625F5B5753
4E4E4D4C4C4B4A494847464543413F3E41474E52565A5D60
6365696C6F727375787B7F828485868685858382807E7C7B
797978787878797B7C7F8183858686868788898887868585
85858586888B8F92969A9FA4ABB3BBC3C6CACED0D2D4D5D8
D9D4CFCAC5C0BBB6B2ADA8A4A09B97938E8A86827E7A7672
6E6A66625F5B5753
4F4E4E4D4D4C4B4B4A4A494846454342464C5255595D6063
66686C6E72747577797B7E80828383828282807F7E7C7B7A
787877777778797A7B7D7E80828383848485858585858585
858687898B8D9094999EA3A9B0B8BFC7CBCED2D3D5D7D8DC
DBD5D0CBC6C0BCB7B2ADA9A4A09B97938F8A86827E7A7672
6E6A66625F5B5753
4F4F4E4E4E4D4D4D4C4C4B4B4A4949494D5154575C606366
686B6F71747677787A7B7D7E7F808080807F7E7D7C7A7978
7777767676767778797A7C7D7F8081818283838484858586
8687898A8C9092969A9EA6ADB3BAC2CACED2D6D7D9DBDCDF
DCD6D1CBC6C1BCB7B2ADA9A4A09B97938F8A86827E7A7672
6E6A66625F5B5753
4F4F4F4F4F4E4E4E4E4E4E4E4E4E4E4E5154575A5E626568
6C6F7375777878797B7C7D7D7E7E7E7E7D7C7B7A79787776
767574747475767678797A7B7C7D7E7F8081828383848586
8687898B8E9194979CA2A9AFB6BEC6CDD1D6D9DBDDDFE1E2
DDD7D1CCC6C1BCB7B2AEA9A4A09B97938F8A86827E7A7672
6E6A66625F5B5753
4F4F4F5050505050505051515152525256595C606265686C
6F727578797A7A7B7B7C7C7C7D7D7C7C7B7A797877767574
7473737373747475767778797A7C7D7D7E7F808182848586
87898A8D9093969A9FA5ABB1BAC2CAD1D4D7DBDFE2E4E6E3
DDD7D1CCC6C1BCB7B2AEA9A4A09B97938F8A86827E7A7672
6E6A66625F5B5753
4F5050505151515252535354555556575B5E616365686B6E
7275787A7B7B7C7C7C7C7B7B7B7B7A7A7978777675747373
727171717272737374757677797A7B7C7E7F808182838586
87898C8E9194989CA2A8AEB6BEC6CFD5D7DBDFE3E7E9EAE4
DDD7D1CCC6C1BCB7B2AEA9A4A09B97938E8A86827E7A7672
6E6A66625E5B5753
50505051525253535455565758595B5B60636466686B6E71
73767A7C7D7D7D7D7C7C7B7B7A7A79787777757473727171
7070707070707172737374757778797A7C7D7E7F81838586
888B8D8F92969A9EA5ABB1BAC3CCD4D9DCDEE3E6E8EBEAE3
DDD7D1CCC6C1BCB7B2ADA9A4A09B97928E8A86827E7A7672
6E6A66625E5B5753
50505152525354555657585A5B5D5F63666567696B6E7173
777A7C7E7F7F7E7E7D7C7B7A79787776757473727170706F
6E6E6E6E6E6F6F7070717274757678797B7C7D7F81838587
898C8E9194999DA2A8AEB6BFC8D0D9DDE0E3E7EAEBECE8E2
DCD6D1CBC6C1BCB7B2ADA8A49F9B97928E8A86827E7A7672
6E6A66625E5B5753
505152535354555658595A5C5E60636667696C6D70727476
797C7E7F80807F7E7D7B7A797877757474737271706F6E6D
6D6C6C6C6C6D6D6E6E6F7172737576787A7B7D7E80828587
8A8C8F93979B9FA4ABB2BBC4CCD4DDE1E4E7EBEDEEECE7E1
DCD6D0CBC6C0BBB6B1ADA8A39F9B96928E8A85817D797572
6E6A66625E5A5753
5051525354555758595B5D5E616366696C7071737576787A
7B7D7F808181807E7D7B7A78777674737271706E6D6D6C6B
6B6A6A6A6A6B6B6C6C6E6F707173747678797C7E80828587
8A8D9194999EA3A9B0B8C1C9D2D9E1E5E8ECEFF0F0ECE6E0
DBD5D0CAC5C0BBB6B1ACA8A39F9A96928D8985817D797571
6D6A66625E5A5753
50515254555658595B5C5E616366696C71737678797B7C7D
7E8081828281807E7C7A797776747371706F6D6C6B6A6A69
68686868686869696A6B6C6E6F71737476787B7D80828588
8B8E92969BA0A6ADB5BDC6CFD7DEE4E8ECF0F2F2F0EBE5E0
DAD4CFCAC4BFBAB5B0ACA7A39E9A95918D8985817D797571
6D6966625E5A5753
505253545657595A5C5E606265686B6F73777C7E7F7F7F80
818282828281807E7C7A7876747371706E6D6B6A69686867
666666666666666768696A6C6D6F717375777A7C7F828588
8B8F93989DA3AAB2BAC3CBD3DBE2E9ECEFF2F4F3F0EAE4DF
D9D4CEC9C4BEB9B5B0ABA6A29E9995918D8884807C797571
6D6965625E5A5753
5152535556585A5B5D5F6164676A6D71767D838484838282
8283838382807F7D7B7977757371706E6C6B6A6968676665
64646363636364656667686A6B6D6F717376797C7F828589
8C90959AA0A7AFB7C0C8D1D8E0EAF0F1F3F5F5F4EFE9E3DE
D8D3CDC8C3BEB9B4AFAAA6A19D9994908C8884807C787470
6D6965625E5A5653
5152545557595A5C5E606365686B6E72777C828685838283
8384838382807F7C7A78767472706E6D6B69686765646363
6261616161616263636466686A6C6E707375787C7F828689
8E93989DA4ACB4BCC5CDD6DFE8F1F4F4F6F8F7F4EEE8E2DD
D7D2CCC7C2BDB8B3AEAAA5A19C9894908B8783807C787470
6C6965615E5A5653
5152545657595B5D5F616466696C6F73777B7F8283838283
8484848482817E7C7A777573716F6D6B6968666563626160
5F5E5E5E5E5F5F6061626466686A6C6F7275787B7E82868B
90949AA1A9B1BAC2CBD3DCE6F1F6F6F7FAFBF9F4EDE7E1DB
D6D0CBC6C1BCB7B2ADA9A4A09B97938F8B87837F7B777470
6C6865615E5A5653
51535456585A5C5E606265676A6D7073777A7E8081828385
8585858482807E7C79777472706E6C6A6866646361605F5E
5D5C5C5B5C5C5D5E5F61636467696B6E7174777B7F82878C
91979EA6AEB6BFC9D1D9E3EEF4F6F9FBFDFCF9F3ECE6E0DA
D5CFCAC4BFBAB6B1ACA8A39F9B96928E8A86827E7B77736F
6C6865615D5A5653
51535456585A5C5E606365686B6D7174777A7D7F80828584
8586858482807D7B797674726F6D6B68666462615F5E5D5C
5B5A5959595A5B5C5D5F61636567696C7073777B7F84898E
949BA2AAB2BBC4CCD6E1EBF2F7FAFCFEFFFCF8F2EBE5DED9
D3CEC8C3BEB9B4B0ABA7A29E9A95918D8986827E7A76736F
6B6864615D5A5653
51535557585A5D5F616366686B6E7174777A7D7F81848586
8786858482807D7B787673716F6C6A676563615F5E5C5B5A
595857575858595B5C5D5F616365686C6F73777B80858B91
98A0A7AFB7C0C9D3DCE5F0F6F9FBFEFFFFFDF7EFE9E3DDD7
D1CCC7C2BDB8B3AEAAA5A19D9994908D8985817D7976726F
6B6764605D595653
51535557595B5D5F616466696B6E7174777A7D8083878789
8A89878583817E7B797673716E6C696764625F5D5C5A5958
57575657575858595A5C5E606265686C7074787D83888E95
9CA4ACB4BEC7D0D9E2EBF2F6FAFDFFFFFEFAF4EDE7E1DBD5
CFCAC5C0BBB6B1ADA8A4A09B97938F8C8884807C7975726E
6B6764605D595653
51535557595B5D5F626466696C6E7174777A7E8185888B8E
8D8C8A8784817E7C797774716F6C696663615E5D5B5A5857
57575657575758595B5D5E616366696D71757A80858C9399
A0A9B1BAC4CDD4DCE5EDF2F6FBFDFFFEFCF8F1EBE4DED8D3
CDC8C3BEB9B5B0ABA7A39F9A96928E8B87837F7C7875716E
6A6763605D595652
51535557595B5D5F626466696C6E7174777A7E81858B8F91
918E8C8A87837F7C7A787673706C686563605E5C5B5B5A59
58585858595A5B5C5D5F616366696D7074797E838990979F
A7AFB7BFC8D0D8E0E7EFF5F9FCFEFEFCF9F4EEE8E2DCD6D0
CBC6C1BCB7B3AEAAA6A19D9995918D8A86827F7B7774706D
6A6663605C595652
51535557595B5D5F626467696C6E7174777A7E81858A9095
95928E8B888582807D7A7773706C69666361605F5E5C5C5C
5B5B5B5C5D5E5F60626566696C6F73767A7E83898E939AA3
AAB3BBC4CCD3DBE5ECF1F5F9FCFDFBFBF7F1EBE5DFD9D3CE
C9C4BFBAB6B1ADA8A4A09C9894908C8885817D7A7773706C
6966635F5C595652
51535557595B5D5F626467696C6E7174777A7D8185898D91
9292918F8B8987827F7A7774706D6A6866646261605F5F5F
5F5F606162636567696B6E717376797C81858A8F949AA1A8
B0B8C0C8D0D8E0E7EEF3F7FAFAF9FAF9F3EDE7E2DCD6D1CC
C7C2BDB8B3AFABA6A29E9A96928F8B8784807D7976726F6C
6965625F5C595552
51535557595B5D60626467696C6E7174777A7D8084888B8F
9394928F8C898683807D7A76726F6C6A6867666564636364
6465666768696B6D6F7174777A7D7E82858A8F949AA1A7AD
B5BDC4CCD4DCE4EBF1F5F6F6F6F7F8F5EFE9E4DED8D3CEC9
C4BFBAB6B1ADA9A4A09C9995918D8A86837F7C7875726E6B
6865625F5B585552
51535557595B5D60626466696B6E717376797C8083868A8D
909494918E8C888683807C7975716F6D6C6B6B6A6969696A
6A6B6C6E7071727476787C7E808284898C8F959BA1A8B0B7
BEC5CCD4DBE2EAEEF1F2F1F2F5F7F7F1EBE6E0DBD5D0CBC6
C1BDB8B3AFABA7A39F9B97938F8C8885817E7B7774716E6B
6764615E5B585552
51535557595B5D5F626466696B6D707376787B7F8285888B
8E9091918E8B888583817E7B7875737170706F6F6F6F6F70
72727577777A7D7D7F818285878A8D90949A9FA4AAB1B7BD
C4CBD3DBE1E7EAECEFEFF1F5F6F7F3EDE7E2DCD7D2CDC8C3
BEBAB5B1ADA9A4A09D9995918E8A8784807D7A7673706D6A
6764615E5B585552
51535557595B5D5F616466686B6D707275787B7E8184878A
8C8F929191908D898683817E7C7977767675757575767678
797B7C7D80828486888A8C8F9194989BA0A3A7ACB3B9BFC5
CDD4D9DEE2E6E9E9EAEEF3F6F8F6EFE9E3DED9D4CECAC5C0
BCB7B3AEAAA6A29E9A9793908C8985827F7C7875726F6C69
6663605D5B585552
51535557595B5D5F616365686A6C6F7174777A7C7F828588
8B8E909495908E8C8A868482807E7D7C7C7B7B7C7C7D7D7F
808284888A8C8D8F9394979A9C9FA2A6A9ADB2B7BBC1C8CE
D4D9DDE1E5E7E7E9ECF0F3F6F7F1EBE5DFDAD5D0CBC6C1BD
B8B4B0ACA7A3A09C9895918E8A8784817D7A7774716E6B68
6663605D5A575552
51535557595B5D5F61636567696C6E717376797B7E818487
898C8F929696918D8B898886858382838383838484848687
898C8E919396999B9C9FA3A5A7AAAEB2B5B9BDC1C6CBD0D5
DADDDFE1E2E2E5EAEFF2F5F6F1ECE6E1DBD6D1CCC7C3BEB9
B5B1ADA9A5A19D9A96938F8C8985827F7C797673706D6A68
65625F5D5A575552
51535557585A5C5E60626467696B6D707275777A7D808285
888B8E91949696938F8D8B8989898989898A898A8B8C8D90
9294979A9CA0A3A7AAABACAFB2B6BABDC2C6CACED2D6D8DA
DCDFE0E0E1E4E9EDF1F5F7F4EDE7E1DCD7D2CDC8C3BFBAB6
B2AEAAA6A29E9B9794918D8A8784817E7B7774726F6C6A67
64615F5C5A575452
51535556585A5C5E60626466686A6D6F717476797C7E8184
87898C8F9296999996928F8D8D8F90909091929394959798
9B9EA0A2A6AAADB1B4B7B9BBBDC1C4C7CACED2D5D8D9DADC
DCDCDDE0E3E9EEF1F3F6F5EEE8E2DCD7D2CDC8C3BFBBB7B2
AEAAA6A39F9C9895918E8B8885827F7C797673716E6B6966
63615E5C59575452
51535456585A5C5E5F616365676A6C6E707375787A7D7F82
85888B8E9195999B9B9997969595979999999B9C9FA0A2A3
A5A7AAACB0B3B6B9BDC1C3C3C6C9CBCED1D4D6D8D9D9D9D9
DADBDDE2E8EEF0F3F7F4EDE7E1DCD7D2CDC8C3BFBBB7B2AF
ABA7A3A09C9995928F8C898683807D7A7775726F6D6A6865
63605E5B59565452
5153545658595B5D5F61636567696B6D6F727476797B7E80
8386898C8F93979B9F9E9D9C9B9B9C9FA1A2A2A5A7AAADAE
AFB0B3B5B9BBBEC1C4C7CACCCFD1D1D3D4D6D6D7D6D6D8DB
DDE0E6EBEFF0F3F6F3EDE7E1DBD6D1CCC7C3BEBAB6B3AFAB
A7A3A09C999693908C898684817E7B797673716E6C696764
62605D5B58565451
5152545657595B5D5E60626466686A6C6E707375777A7C7F
8184878A8E9195999EA3A3A09E9EA1A3A6A9ABADB0B3B6B9
BBBCBEC0C2C4C5C5C6C6C9CBCECFD0D0D0D0D1D3D5D9DCDF
E3E7ECEFF1F2F5F3EBE5E0DAD5D0CBC7C2BEBAB6B2AEAAA6
A3A09C999693908D8A8784817F7C797774726F6D6A686663
615F5D5A58565451
5152545557595A5C5E5F61636567696B6D6F717376787A7D
808285888C8F93979B9FA4A5A4A4A4A5A9ACB0B3B6B9BCBD
C1C5C9CACBCAC9C8C9C9C8C9CACAC9CBCDCFD1D5D8DDE1E5
EAEDEFF0F4F5F0EAE4DED9D4CFCAC6C1BDB9B5B1ADAAA6A3
9F9C999693908D8A8784827F7D7A787573706E6C69676562
605E5C5A58565351
5152545557585A5B5D5F60626466686A6C6E70727476797B
7E808386898D9094989CA0A6ABA9A7A8A9ACB0B4B6B8BABD
C0C1C2C3C4C5C6C6C6C5C5C5C6C7C9CCCED1D5D8DDE3E7EB
ECEEF0F3F1EBE6E1DCD7D2CDC9C4C0BCB8B4B0ACA9A5A29F
9C999693908D8A8785827F7D7A787673716F6D6A68666462
5F5D5B5957555351
515253555658595B5C5E6061636567686A6C6E7072747779
7B7E8184878A8D9194989DA1A6ABADACACADAEB0B2B5B8BA
BCBDBFC0C1C1C1C1C1C2C3C4C5C6C9CCD0D6D9DEE2E5E8E9
EBEFEFECE7E2DDD9D4CFCBC6C2BEBAB6B2AFABA7A4A19E9B
9895928F8C8A8784827F7D7A787674716F6D6B6967656361
5F5D5B5957555351
505253555657595A5C5D5F6062646567696B6D6F70727577
797C7E818486898D9094989CA1A6ACB0B0AEAEAFB1B3B4B6
B7B9BABBBCBDBCBCBDBFC1C4C7C8CCD1D5D9DDE1E3E4E6EA
EBE9E5E1DDD8D4D0CCC7C3BFBBB7B4B0ADA9A6A29F9C9996
93918E8C898684817F7C7A787673716F6E6C696765636160
5E5C5A5856555351
505253545657585A5B5C5E5F6162646667696B6D6F717375
77797C7E818386898D9094989CA0A4A9ADB1B3B1AFAFB0B1
B4B6B7B8BABBBCBEBFC1C2C5CACDD1D4D6D8DADEE1E4E5E3
E0DDDAD7D3CFCBC7C3BFBCB8B4B1ADAAA6A3A09D9A979492
8F8D8A888583817E7C7A777573716F6D6B6967666462605F
5D5B595756545351
50525354555658595A5C5D5E606163646667696B6C6E7072
7477797B7E808386898C8F93969A9EA2A6A9ABAEB1B0AFB0
B1B1B3B5B6B8BABDBFC1C3C6C8CACDCED1D5D9DBDAD9D8D6
D4D2CFCCC8C5C2BEBBB7B4B0ADAAA7A4A19E9B989592908D
8B888683817F7C7A79777573716F6D6B6967656462615F5D
5C5A595756545251
50515354555657585A5B5C5D5F606163646667696B6C6E70
727476787A7D7F8285888B8E9194989B9EA1A3A6A8ABAEB0
B1B1B2B2B3B4B5B6B7BBBEC0C2C5C9CDCFD0D0CFCECDCCCB
C9C7C4C2BFBCB9B6B3AFACA9A6A3A19E9B989593908E8B89
878482807D7B7978767472706E6D6B696766646261605E5C
5B59585755545251
5051525354555758595A5B5C5E5F606163646667686A6C6E
6F71737577797C7E818386898C8F9194979A9C9FA1A3A6A7
A9AAABACADAEB0B3B5B7BABCBEC0C1C2C3C4C4C4C3C2C1BF
BDBBB9B7B5B3B0ADABA8A5A29F9D9A9895928F8D8B898684
82807E7C7A78767473716F6D6C6A6867656463615F5E5D5B
5A59575654535250
505152535455565758595A5B5C5D5F60616264656768696B
6D6E70727476787A7C7F818486898B8E90939597999B9D9F
A0A1A3A4A5A6A8AAACAEB0B1B3B4B6B7B8B8B8B8B8B7B6B4
B3B1AFADABA9A7A4A29F9D9B989593918F8C8A8886848280
7E7C7A7876757371706E6C6B69686665636261605E5D5B5A
5958575554535150
50515253535455565758595A5B5C5D5E6061626364666768
6A6B6D6F70727476787A7C7F818386888A8C8D9091939597
98999A9C9D9EA0A1A3A4A6A7A9AAABACACADADADACABABAA
A8A7A5A3A2A09D9B9A979593918F8D8A88868583817F7D7B
7977767473716F6E6D6B6A686665646361605F5D5C5B5A59
5857565553525250
5051515253545555565758595A5B5C5D5E5F606162636466
67686A6B6D6E7072747577797B7D7F81828486888A8C8D8E
8F919293949597989A9B9C9D9EA0A1A1A2A2A2A2A1A1A09F
9E9D9B9A99979593918F8E8B8987868482807F7D7C7A7876
757372706F6D6C6B69686765646362605F5E5D5C5B5A5958
5756555453525150
50505152535354555556575859595A5B5C5D5E5F60616263
64656768696B6C6E6F7172747677797B7C7E7F8183848586
8889898A8C8D8E8F90929394959596979797979797969594
949392918F8D8C8B8987858382817F7D7C7A797776757372
706F6D6C6A6968676665636261605F5E5D5D5C5B5A595857
5655545352525150
505051515253535455555657575859595A5B5C5D5E5F5F60
61626364666768696B6C6D6F707273747677797A7B7C7D7E
7F80818283848586878888898A8B8C8C8D8D8D8D8C8C8B8A
8A89888786858482817F7E7C7B7A787776747371706F6E6C
6B6A696867666564636261605F5E5D5C5C5B5A5958575756
5554545352515050
5050515152525353545455555657575858595A5B5B5C5D5D
5E5F6061626364656667696A6B6C6D6E6F70727374757677
777879797A7B7C7D7E7E7F80808181828282838282818181
807F7E7D7D7C7A7978777675747271706F6E6D6C6B6A6868
67666464636261605F5E5D5D5C5B5B5A5958585757565555
5454535251515150
505050515152525253535454555556565757585859595A5A
5B5C5D5D5E5F60616263646465666768696A6B6C6D6E6E6F
6F7070717272737474757676777777787878787878787776
7675757474737271706F6E6D6D6C6B6A6968676766656463
626161605F5E5D5C5C5B5B5A5A5958585756565655555454
535352525151504F
4F5050505151515252525353535454545555565657575758
5859595A5A5B5C5C5D5E5E5F606161626364646565666667
67686868696A6A6B6B6B6C6C6D6D6D6E6E6E6E6E6D6D6D6C
6C6C6C6B6B6A6968686767666564646363626261605F5F5E
5D5D5D5C5B5A5A5959585857575756565555545454535353
525252515151504F
4F5050505050515151515152525252535353545454555555
55555656575758585959595A5A5A5B5B5C5C5D5D5E5E5E5F
5F5F60606061616162626263636363636464646363636363
6262626161616160605F5F5E5D5D5D5C5C5B5B5B5B5A5A59
595858575757575656555555545454535353535252525251
5151505050504F4F
4F4F4F505050505050505050515151515151525252525252
525253535353535354545454545555555656565757575757
575758585858585859595959595959595A5A595959595959
595958585858585858575757565656565555555555555454
545453535353535252525252525252515151515151515151
50505050504F4F4F
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[56]:=",
  ImageSize->{450, 295.313},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007200019b000`400?l00000o`00003oo`3oooo3
0?ooo`00o`3oooo30?ooo`00o`3oooo30?ooo`00o`3oooo30?ooo`00o`3oooo30?ooo`00o`3oooo3
0?ooo`00o`3oooo30?ooo`00o`3oooo30?ooo`00o`3oooo30?ooo`00o`3oooo30?ooo`00803oool3
06a/K0D0KFe]00<0Kfm_071`L01`L700101`L70306m_K`06071`L01cLg<0Kfm_06m_K`1`L700Kfm_
0`1^KVh406e]K@0506a/K01[Jf/0Jf][06YZJP1[Jf/01@1ZJVX:06UYJ@80JVYZ0P1YJFT506YZJPL0
JFUY0`1XJ6P206MWI`0306][J`1XJ6P0J6QX00@0J6QX1@1WIfL00`1VIVH0IfMW06MWI`0406IVIP<0
IfMW0P1XJ6P606UYJ@0606YZJP1[Jf/0J6QX06UYJ@1ZJVX0Jf][7P3oool00`2FUYH0UiNG09NGU`05
09NGU`0309RHV02IVIT0VIVI00L0VIVI00@0VYZJ09fMW@2IVIT0VIVI2@2JVYX709VIV@<0V9RH00@0
UiNG09RHV02GUiL0UiNG202HV9P209NGU`0309RHV02GUiL0UiNG00/0UiNG0`2FUYH00`2IVIT0UYJF
09JFUP0409JFUPT0UIFE0P2DU9@709FEU@@0U9BD00L0Ti>C09FEU@2FUYH0Ti>C09BDU02EUID0UYJF
01h0oooo2P2`/;030:n_[`D0/;2`00<0/K6a0;:b/P2`/;000P2a/K420;:b/P@0/k>c602d];@20;>c
/`030;Bd]02c/k<0/k>c0080/k>c3@2d];@?0;>c/`H0/[:b00<0/K6a0;2`/02`/;000P2_[jl30:j^
[PD0[jn_00<0/;2`0?ooo`3oool0803oool00200oooo0`1/K6`00`1]KFd0KVi^06i^KP0206m_K`03
079bLP1dM7@0MGEe00@0M7Ad0`1cLg<00`1dM7@0N7Qh07AdM00307=cL`05079bLP1aLG40L71`06m_
K`1^KVh00P1]KFd0101/K6`0Jf][06YZJP1ZJVX406UYJ@0306QXJ01YJFT0J6QX00X0IfMW00<0J6QX
06MWI`1WIfL0101XJ6P406MWI`@0IVIV0P1UIFD01@1TI6@0Hf=S06=SH`1YJFT0IVIV00D0I6AT101S
Hf<4069RHP@0HF5Q0P1RHV80101SHf<0I6AT06ATI01UIFD306IVIP80IfMW0P1XJ6P0101VIVH0IfMW
06QXJ01ZJVXN0?ooo`<0UiNG0`2HV9P209VIV@0309ZJVP2KVi/0Vi^K0080Vi^K1@2LW9`0102MWId0
X:2P09fMW@2MWId509jNWP@0WIfM0P2LW9`509^KV`80VYZJ102IVIT00`2HV9P0VIVI09VIV@0609VI
V@80V9RH00<0VIVI09RHV02IVIT00P2IVIT709RHV0<0UiNG0P2FUYH00`2IVIT0UiNG09JFUP0309JF
UP<0UIFE0`2DU9@00`2CTi<0U9BD09>CT`0809>CT`80TY:B1@2ATI4209>CT`80TY:B00<0U9BD09FE
U@3oool07@3oool20;2`/0030;6a/@2`/;00/;2`00<0/;2`0P2_[jl20:j^[P040:n_[`2`/;00/;2`
0;2`/080/K6a0P2b/[801@2`/;00/[:b0;>c/`2c/k<0]KFe0080][Jf0P2g]kL30;Rh^0L0^KVi00<0
^;Rh0;Ng]`2g]kL02P2h^;P<0;Ng]`L0^;Rh00H0^KVi0;Ng]`2g]kL0]kNg0;Jf]P2g]kL60;Jf]P80
]KFe00<0][Jf0;Fe]@2e]KD00`2e]KD20;Bd]0040;>c/`2b/[80/K6a0;2`/080[Zj^00D0[Jf]0:b/
[02/[:`0[Zj^0:n_[`020:j^[P030:n_[`2`/;00oooo0240oooo000P0?ooo`80K6a/00P0KFe]06i^
KP1^KVh0Kfm_071`L01aLG40M7Ad07IfMPD0N7Qh101gMgL00`1kNg/0NWYj07IfMP0207MgM`0:07Ee
M@1dM7@0Lg=c075aL@1`L700KVi^06e]K@1/K6`0Jf][06YZJPD0J6QX0`1WIfL00`1VIVH0IFEU06EU
I@0906EUI@D0IVIV0`1UIFD206ATI0<0Hf=S00<0HV9R065QH@1QHF400P1PH6000`1TI6@0IVIV06=S
H`05061PH00305mOG`1NGUh0GUiN00D0GEeM0P1LG5`205eMG@0705iNGP1OGel0H61P061PH01QHF40
HV9R06=SH`0306ATI080IfMW0P1UIFD00`1WIfL0JVYZ0?ooo`0M0?ooo`80UiNG0P2HV9P209VIV@80
VYZJ0P2LW9`0102MWId0WYjN09jNWP2NWYh409nOW`050:2PX02RXZ80XZ:R0:2PX02QXJ400`2RXZ83
0:6QX@<0X:2P00<0WinO09jNWP2MWId00P2MWId209bLW0<0Vi^K2`2JVYX409VIV@<0VYZJ1@2IVIT3
09RHV0@0UiNG00<0V9RH09NGU`2GUiL00P2FUYH0102EUID0U9BD09BDU02DU9@209>CT`D0TY:B1`2A
TI401`2@T900Shn?08n?S`2?Shl0SXj>08n?S`2@T9000P2ATI40102@T900TI6A09>CT`2EUIDN0?oo
o`P0/;2`0P2_[jl30:j^[P040:n_[`2`/;00/;2`0;6a/@80/[:b00D0/K6a0;:b/P2d];@0];Bd0;Fe
]@020;Rh^0030;Vi^@2j^[X0^k^k0080_;bl0P2m_Kd20;jn_P<0_Kfm0P2l_;`60;^k^`D0_;bl0P2k
^k/50;Zj^PT0^k^k102l_;`0102m_Kd0^[Zj0;Ng]`2i^KT30;Zj^P030;Rh^02i^KT0^KVi00<0^KVi
1@2h^;P02P2g]kL0][Jf0;Jf]P2f][H0]KFe0;>c/`2b/[80/;2`0:j^[P2][Jd20:b/[0@0[Jf]0P2^
[Zh00`2_[jl0oooo0?ooo`0P0?ooo`00803oool03@1/K6`0KFe]06i^KP1_Kfl0L71`075aL@1bLW80
Lg=c07IfMP1hN7P0NWYj07alO01mOGd00`20P80407moO`0?0861P@22PX80P82007moO`1mOGd0NWYj
07QhN01fMWH0M7Ad06m_K`1^KVh0K6a/06][J`1YJFT0IfMW00<0IFEU00<0I6AT06EUI@1UIFD00`1U
IFD00`1TI6@0Hf=S06=SH`05069RHP@0HF5Q00<0H61P065QH@1QHF400P1PH60205mOG`80GUiN0P1M
GEd00`1LG5`0Fe]K05]KF`0205YJFP80FEUI00<0Fe]K05eMG@1JFUX00`1HF5P00`1GEeL0EUIF05EE
E@0205ADE0@0De=C00H0DU9B05=CD`1CDe<0E5AD05EEE@1FEUH205MGE`0405UIF@1KFe/0GEeM05iN
GP80H61P0P1RHV800`1TI6@0IfMW06UYJ@0N0?ooo`80UiNG0P2IVIT02P2JVYX0Vi^K09bLW02LW9`0
WYjN09nOW`2PX:00XJ6Q0::RXP2SXj<30:BTY080YJFU00D0YZJV0:RXZ02YZJT0Z:RX0:VYZ@020:ZZ
ZP80ZJVY00P0Z:RX0:NWY`2WYjL0YZJV0:FUY@2TY:@0Xj>S0:6QX@80X:2P0P2NWYh309fMW@<0W9bL
00<0WIfM09bLW02LW9`00`2LW9`209^KV`80W9bL00@0Vi^K09bLW02LW9`0W9bL0`2KVi/309ZJVP80
VIVI102HV9P01@2GUiL0UYJF09NGU`2HV9P0UIFE0080U9BD0P2CTi<209:BTP<0T92@0P2?Shl00`2>
SXh0SHf=08f=S@0308f=S@0308b<S02;Rh/0RHV90080RHV90P2;Rh/01`2=SHd0S8b<08j>SP2=SHd0
SXj>096AT@2DU9@07P3oool30;2`/0H0/K6a0P2`/;020:n_[`030:j^[P2_[jl0/;2`0080/K6a0P2c
/k<02P2d];@0]KFe0;Jf]P2h^;P0_;bl0;jn_P2o_kl0`L710<;2`P35aLD70<K6aP030<C4a033`l<0
`/;20080`<3000@0_kno0<30`030`<00`L712032`/8?0<?3``090<C4a033`l<0`l?30<?3``32`/80
`L710<30`02o_kl0`<3000D0_kno102n_[h20;fm_@090;bl_02k^k/0^k^k0;Zj^P2i^KT0]KFe0;>c
/`2a/K40[Zj^00@0[Jf]0P2/[:`20:^[Z`030:f][@2^[Zh0oooo0240oooo000P0?ooo`0>06a/K01]
KFd0Kfm_071`L01aLG40LW9b07=cL`1dM7@0MgMg07UiN@1jNWX0O7al07inOP22PX8408>3P`80PX:2
0100Ph>308J6QP25QHD0Ph>30820P01nOWh0Ng]k07QhN01fMWH0LG5a06i^KP1/K6`0JVYZ06QXJ01V
IVH0I6AT0P1SHf<00`1RHV80Hf=S06=SH`0406ATI0<0HV9R0P1QHF43061PH0<0GemO0`1NGUh205eM
G@80G5aL0P1KFe/205YJFP80F5QH00@0EeMG05IFEP1FEUH0EUIF0P1EEED01@1GEeL0F5QH05EEE@1D
E5@0De=C0080DU9B00<0DE5A04m?C`1?Cdl0101>CTh0101=CDd0CTi>04i>CP1?Cdl2051@D008055A
D@1BDU80E5AD05IFEP1HF5P0FUYJ05aLG01MGEd2061PH00306=SH`1VIVH0JFUY01h0oooo00H0UiNG
09RHV02IVIT0VYZJ09^KV`2LW9`209fMW@0709nOW`2PX:00XJ6Q0::RXP2SXj<0YJFU0:JVYP030:NW
Y`030:RXZ02YZJT0ZZZZ0080[:b/00l0[Jf]0:j^[P2^[Zh0[Zj^0:f][@2/[:`0Zj^[0:ZZZP2YZJT0
Z:RX0:NWY`2UYJD0Xj>S0::RXP2QXJ400P2OWil709jNWPh0WIfM0P2LW9`309^KV`0409ZJVP2IVIT0
VIVI09VIV@80V9RH00H0UiNG09JFUP2FUYH0UYJF09FEU@2DU9@309>CT`0309:BTP2ATI40Shn?0080
Shn?0P2>SXh0102=SHd0S8b<08b<S02<S8`208^;R`0608V9R@28R8P0QXJ608J6QP28R8P0RHV90`2:
RXX01@2<S8`0Rh^;08j>SP2ATI40U9BD01h0oooo0P2`/;050;6a/@<0/[:b00<0/K6a0;2`/02`/;00
0P2_[jl01@2`/;00/K6a0;:b/P2c/k<0]KFe0080][Jf00X0]kNg0;Zj^P2n_[h0`<300<;2`P35aLD0
a/K60<W9b@3:b/X0bl_;0`3<c<`01@3:b/X0bLW90<S8b037alL0a/K60080`l?30`32`/840<C4a0@0
aLG50`36a/H00`37alL0b<S80<S8b00<0<S8b080alO70P36a/H00`34a<@0`/;20<?3``050<?3``80
`/;20`31`L402@30`<00_kno0;jn_P2m_Kd0_;bl0;^k^`2h^;P0]KFe0;:b/P020;2`/080[jn_00L0
[Zj^0:b/[02/[:`0ZZZZ0:^[Z`2][Jd0[Zj^0280oooo000P0?ooo`0A06a/K01]KFd0L71`075aL@1b
LW80Lg=c07AdM01eMGD0N7Qh07UiN@1kNg/0OGem07moO`23Ph<0QHF508J6QP27QhL01026QXH04P27
QhL0R8R808N7Q`23Ph<0PH6107inOP1kNg/0N7Qh075aL@1_Kfl0K6a/06YZJP1WIfL0IFEU06=SH`1R
HV80HF5Q061PH080HF5Q00L0HV9R06=SH`1SHf<0I6AT06=SH`1RHV80HF5Q0080H61P00@0GemO05iN
GP1NGUh0GUiN0P1MGEd205aLG080Fe]K00@0FUYJ05UIF@1HF5P0F5QH0P1GEeL0101FEUH0EEEE05AD
E01DE5@205=CD`06059BDP1ADE40DE5A051@D01BDU80De=C0P1?Cdl00`1>CTh0CDe=04a<C00204Y:
BP<0BDU90`18B4P03019BDT0BTY:04Y:BP1;Bd/0C4a<04e=C@1?Cdl0DE5A05EEE@1GEeL0FEUI05]K
F`80GEeM00<0Hf=S06IVIP1YJFT07P3oool00`2GUiL0V9RH09ZJVP0209^KV`80WIfM00T0WinO0:6Q
X@2RXZ80XZ:R0:BTY02UYJD0YjNW0:RXZ02YZJT00P2ZZZX01P2[Zj/0[:b/0:f][@2_[jl0/;2`0;6a
/@<0/[:b0P2a/K402@2_[jl0[Zj^0:b/[02[Zj/0ZJVY0:RXZ02UYJD0Xj>S0::RXP020:2PX0P0WinO
3@2NWYh209fMW@80W9bL0P2KVi/209ZJVP0409VIV@2HV9P0V9RH09NGU`80UYJF0P2EUID01`2DU9@0
Ti>C09>CT`2BTY80TI6A092@T02?Shl00P2>SXh0102=SHd0S8b<08b<S02;Rh/308Z:RP0608V9R@27
QhL0QHF508>3P`24Q8@0QXJ60P27QhL208R8R00508Z:RP29RHT0SHf=092@T02DU9@07P3oool20;2`
/0<0/K6a0`2b/[800`2c/k<0/[:b0;:b/P020;:b/P@0/K6a00h0/[:b0;Bd]02e]KD0]kNg0;Rh^02j
^[X0_;bl0<;2`P34a<@0a/K60<S8b03;bl/0c/k>0<o?c`80d=3@00T0dM7A0=3@d03>c/h0cLg=0<c<
c03:b/X0bLW90<O7a`36a/H00`35aLD30<K6aP80alO700<0b<S80<W9b@39bLT00P39bLT00`3:b/X0
bl_;0<c<c0040<c<c0030<g=c@3<c<`0c<c<00H0c<c<0P3;bl/20<[:bP040<W9b@37alL0a/K60<O7
a`<0b<S800<0alO70<K6aP36a/H00P35aLD02@34a<@0`l?30<;2`P31`L40`<300;no_`2m_Kd0^KVi
0;Jf]P020;:b/P0:0;6a/@2_[jl0[Zj^0:f][@2/[:`0Zj^[0:VYZ@2[Zj/0[Jf]0:j^[R80oooo000P
0?ooo`0A06a/K01]KFd0L71`075aL@1bLW80M7Ad07EeM@1fMWH0NGUi07YjNP1lO7`0OGem07moO`23
Ph<0QHF508N7Q`28R8P01@29RHT0502:RXX0Rh^;08F5Q@23Ph<0PH6107emO@1jNWX0Lg=c06m_K`1]
KFd0JVYZ06MWI`1UIFD0HV9R065QH@1PH600GemO05iNGP1OGel0H61P0P1QHF42069RHP80HF5Q0P1P
H600101OGel0GUiN05eMG@1MGEd205aLG080FUYJ00@0FEUI05QHF01HF5P0EeMG0P1EEED01P1DE5@0
De=C05=CD`1BDU80DE5A051@D080Cdm?0P1>CTh00`1=CDd0C4a<04];B`0204a<C00504];B`19BDT0
B4Q804M7A`15ADD00`14A4@404=3@`80A4A400X0ADE504Q8B018B4P0BDU904a<C01=CDd0DU9B05AD
E01GEeL0FEUI0P1KFe/00`1RHV80IFEU06QXJ00N0?ooo`0509NGU`2HV9P0VYZJ09^KV`2LW9`00P2N
WYh04`2PX:00XZ:R0:>SX`2TY:@0YJFU0:JVYP2YZJT0ZZZZ0:^[Z`2/[:`0[Jf]0:j^[P2_[jl0/;2`
0;:b/P2d];@0]KFe0;Jf]P2g]kL00P2f][H0302e]KD0/[:b0;6a/@2`/;00[Zj^0:b/[02ZZZX0YZJV
0:FUY@2SXj<0XZ:R0:6QX@P0X:2P3@2OWil0102NWYh0WIfM09fMW@2MWId209bLW00609^KV`2JVYX0
VIVI09VIV@2HV9P0UiNG0P2FUYH00`2EUID0U9BD09BDU00209>CT`0409:BTP2ATI40T92@08j>SP80
SHf=00<0S8b<08^;R`2:RXX00P29RHT01028R8P0QhN708J6QP23Ph<20861P@0308>3P`24Q8@0Q8B4
0080QHF500H0QXJ608N7Q`27QhL0SHf=092@T02CTi<N0?ooo`80/;2`00@0/K6a0;:b/P2b/[80/[:b
0P2c/k<80;Bd]00?0;>c/`2d];@0][Jf0;Ng]`2i^KT0^k^k0;fm_@2o_kl0aLG50<S8b03:b/X0cLg=
0<o?c`3Cdm<0e=CD0080eMGE00P0e=CD0=?Cd`3AdM40d=3@0<o?c`3>c/h0cLg=0<[:bP80bLW91038
b<P40<W9b@80bl_;00<0c<c<0<g=c@3=cLd00P3?cll40=3@d0D0dM7A103@d=00103?cll0c/k>0<k>
cP3>c/h20<g=c@D0c<c<00D0bl_;0<[:bP3:b/X0bLW90<S8b0020<O7a`070<G5a@34a<@0`l?30<71
`@2n_[h0^;Rh0;Bd]0020;>c/`0:0;:b/P2^[Zh0[Jf]0:b/[02[Zj/0ZZZZ0:VYZ@2[Zj/0[Jf]0:j^
[R80oooo000P0?ooo`0B06e]K@1^KVh0L71`075aL@1cLg<0M7Ad07EeM@1gMgL0NWYj07]kN`1mOGd0
OWin0820P023Ph<0QHF508N7Q`28R8P0RXZ:0P2;Rh/308b<S00C08f=S@2;Rh/0QhN708>3P`20P800
O7al07=cL`1`L700KFe]06YZJP1WIfL0I6AT065QH@1PH600GemO05eMG@1LG5`0GEeM05iNGP0205mO
G`03061PH01RHV80HF5Q00<0H61P00H0GemO05iNGP1NGUh0GEeM05aLG01KFe/205UIF@0505QHF01G
EeL0EUIF05EEE@1CDe<00P1BDU80101ADE40D51@04m?C`1>CTh204e=C@0504a<C01;Bd/0BTY:04Y:
BP19BDT00P17AdL01P18B4P0AdM704E5A@13@d<0@T920410@0<0?clo100n?Sh203lo?`0?0451@@15
ADD0ADE504I6AP19BDT0C4a<051@D01BDU80EEEE05QHF01IFET0Fe]K065QH@1UIFD0J6QX01h0oooo
01P0UiNG09RHV02JVYX0W9bL09fMW@2NWYh0WinO0:6QX@2SXj<0Y:BT0:FUY@2WYjL0Z:RX0:ZZZP2/
[:`0[Jf]0:j^[P2_[jl0/K6a0;:b/P2c/k<0]KFe0;Ng]`2i^KT30;^k^`0=0;Zj^P2i^KT0][Jf0;Bd
]02c/k<0/;2`0:j^[P2/[:`0YjNW0:JVYP2UYJD0Xj>S0::RXP030:2PX0D0XJ6Q1`2PX:000`2QXJ40
X:2P0:6QX@030:2PX00309nOW`2NWYh0WYjN0080WIfM00@0W9bL09^KV`2JVYX0VIVI0P2HV9P0102G
UiL0UYJF09JFUP2EUID209BDU080Ti>C00@0TY:B096AT@2?Shl0SHf=0P2<S8`02@2;Rh/0RXZ:08V9
R@28R8P0QhN708J6QP24Q8@0PX:20820P00207moO`050820P021PH40PH6108:2PP23Ph<00`25QHD0
0`2<S8`0Shn?09>CT`0N0?ooo`80/;2`00@0/K6a0;:b/P2b/[80/k>c0`2d];@30;Fe]@H0][Jf00h0
^;Rh0;Vi^@2k^k/0_Kfm0;no_`31`L40a/K60<_;b`3?cll0dM7A0=CDe03GemL0f=SH0=WIf@80f=SH
00T0emOG0=CDe03Cdm<0d];B0=7Ad@3@d=00c/k>0<g=c@3<c<`00P3;bl/40<[:bP80bl_;0P3<c<`0
103=cLd0c/k>0<o?c`3AdM420=;BdP<0dm?C1P3De=@20=?Cd`80d];B1P3AdM420<o?c`80d=3@00D0
clo?0<k>cP3=cLd0cLg=0<c<c0020<_;b`0<0<S8b037alL0aLG50<71`@2m_Kd0]KFe0;Bd]02b/[80
/K6a0:n_[`2/[:`0ZZZZ0P2YZJT20:RXZ0030:^[Z`2/[:`0[Zj^0280oooo000P0?ooo`0C06e]K@1^
KVh0LG5a079bLP1cLg<0MGEe07MgM`1hN7P0Ng]k07emO@1nOWh0P8200861P@24Q8@0QXJ608R8R029
RHT0RXZ:08b<S00208f=S@0?08j>SP2?Shl0Shn?092@T02?Shl0Rh^;08B4Q01oOgl0M7Ad06m_K`1[
Jf/0J6QX06ATI01RHV80G5aL0080Fe]K00P0FUYJ05UIF@1IFET0FUYJ05]KF`1LG5`0GEeM05iNGP80
GemO0P1NGUh205eMG@<0G5aL00l0Fe]K05UIF@1IFET0F5QH05MGE`1FEUH0EEEE059BDP1ADE40D51@
04i>CP1=CDd0Bd];04Y:BP19BDT00P18B4P01016ATH0ADE504A4A013@d<20492@P80@4100P0o?cl0
1@10@400>c/k03Ti>@0g=cL0=SHf0080=CDe0P0g=cL04@0h>3P0>CTi03Xj>P0o?cl0@41004A4A015
ADD0AdM704a<C01>CTh0DU9B05EEE@1GEeL0FEUI061PH01TI6@0J6QX01h0oooo01T0V9RH09VIV@2L
W9`0WIfM09jNWP2PX:00XJ6Q0:>SX`2UYJD0YjNW0:RXZ02ZZZX0Zj^[0:j^[P2_[jl0/K6a0;:b/P2d
];@0]kNg0;Vi^@2j^[X0_;bl0;jn_P30`<00a<C40080a/K60P33`l<02`2n_[h0^k^k0;Rh^02f][H0
/[:b0;2`/02ZZZX0Z:RX0:NWY`2UYJD0Y:BT00D0XZ:R102SXj<50::RXP80Xj>S0`2RXZ830:6QX@80
WinO00D0WYjN09fMW@2MWId0Vi^K09ZJVP0209VIV@0409RHV02GUiL0UYJF09JFUP80U9BD00<0Ti>C
09:BTP2ATI400P2@T9003P2?Shl0S8b<08^;R`2:RXX0RHV908R8R026QXH0PX:207moO`1mOGd0Ng]k
07YjNP1iNGT0N7Qh0P1jNWX207]kN`0807alO01oOgl0P8200861P@23Ph<0Rh^;08j>SP2BTY8N0?oo
o`80/K6a00<0/[:b0;>c/`2d];@00`2e]KD01`2f][H0]kNg0;Ng]`2h^;P0^KVi0;Zj^P2k^k/00P2l
_;`03@2m_Kd0`<300<71`@33`l<0a/K60<S8b03:b/X0d=3@0=?Cd`3GemL0fm_K0=oOg`3Rh^800P3S
hn<02`3Rh^80hN7Q0>3Ph03MgMd0fm_K0=WIf@3Hf=P0e]KF0=CDe03Cdm<0d];B0080dM7A00<0d=3@
0<o?c`3?cll00P3?cll00`3@d=00dM7A0=7Ad@020=;BdP030=?Cd`3De=@0e=CD0080eMGE0P3Fe]H3
0=OGe`<0f=SH1P3GemL30=KFeP80eMGE0P3De=@00`3Bd]80d=3@0=7Ad@030=;BdP090=7Ad@3?cll0
a/K60<;2`P2n_[h0^[Zj0;Ng]`2b/[80[Zj^0080[Jf]00X0Zj^[0:RXZ02VYZH0YZJV0:FUY@2TY:@0
YZJV0:ZZZP2/[:`0[Zj^8P3oool00200oooo01@0KFe]06i^KP1aLG40Lg=c07AdM01fMWH0MgMg07Ui
N@1lO7`0OGem07moO`20P800PX:208F5Q@26QXH0R8R808V9R@2;Rh/0SHf=08j>SP80Shn?0P2@T900
3@2ATI40TY:B08n?S`29RHT0PX:207EeM@1^KVh0JFUY06EUI@1RHV80GemO05YJFP1IFET0101HF5P2
05UIF@0505YJFP1KFe/0GEeM05eMG@1NGUh00P1MGEd205aLG080Fe]K0P1JFUX04@1HF5P0EeMG05IF
EP1EEED0E5AD05=CD`1@D500Cdm?04e=C@1<C4`0Bd];04Q8B017AdL0ATI604E5A@14A4@0@T920080
@D5100H0@41003lo?`0n?Sh0?Cdm03`l?00k>c/203Xj>P80>3Ph00@0=cLg03Hf=P0d=3@0=3@d0`0f
=SH203Lg=`0>03`l?00m?Cd0@T9204=3@`15ADD0BTY:04e=C@1ADE40De=C05MGE`1JFUX0H61P06AT
I01XJ6PN0?ooo`0X09RHV02IVIT0W9bL09jNWP2OWil0X:2P0::RXP2SXj<0YZJV0:RXZ02YZJT0Zj^[
0:f][@2`/;00/K6a0;>c/`2e]KD0][Jf0;Zj^P2l_;`0_[jn0<30`031`L40a<C40<S8b03;bl/0b/[:
0<W9b@37alL0`l?30;no_`2k^k/0^;Rh0;Bd]02b/[80Zj^[0:VYZ@2WYjL0YZJV0:BTY0D0Xj>S102T
Y:@40:>SX`<0Y:BT0`2SXj<30::RXP80X:2P00@0WinO09jNWP2MWId0W9bL0P2JVYX00`2IVIT0V9RH
09NGU`0209JFUP80U9BD0140Ti>C096AT@2@T900T92@08n?S`2=SHd0Rh^;08Z:RP28R8P0QhN708F5
Q@22PX80OWin07]kN`1iNGT0N7Qh07IfMP0207EeM@0<07QhN01gMgL0N7Qh07QhN01jNWX0O7al07em
O@20P800PX:208Z:RP2>SXh0TY:B7P3oool01@2`/;00/K6a0;>c/`2c/k<0];Bd0080]KFe02<0][Jf
0;Ng]`2h^;P0^KVi0;Zj^P2k^k/0_;bl0;fm_@2n_[h0_kno0<30`033`l<0aLG50<O7a`39bLT0c<c<
0<k>cP3De=@0emOG0=WIf@3Ng]h0h^;R0>SXj03Zj^X0jNWY0>SXj03WinL0iNGU0>7Qh@3Ogml0gMgM
0=_Kf`3IfMT0e]KF0=GEe@020=CDe080dm?C103Bd]820=?Cd`050=CDe03EeMD0eMGE0=KFeP3GemL0
0P3Hf=P30=WIf@030=[JfP3Kfm/0fm_K00L0fm_K0`3Jf]X30=WIf@0F0=SHf03GemL0emOG0=KFeP3E
eMD0dm?C0=7Ad@3?cll0d=3@0<k>cP39bLT0`L710;fm_@2i^KT0]kNg0;Fe]@2_[jl0[:b/0:f][@2[
Zj/0ZJVY0:FUY@80Y:BT00H0XZ:R0:>SX`2TY:@0ZJVY0:^[Z`2][JdR0?ooo`00803oool05@1]KFd0
KVi^075aL@1cLg<0M7Ad07IfMP1hN7P0NGUi07alO01nOWh0Ogmo0861P@22PX80QXJ608N7Q`29RHT0
RXZ:08^;R`2>SXh0Shn?092@T002096AT@0>09:BTP2CTi<0U9BD096AT@2>SXh0QhN707UiN@1^KVh0
IVIV069RHP1OGel0G5aL05QHF01GEeL405IFEP0505MGE`1HF5P0FEUI05YJFP1KFe/0101LG5`0101K
Fe/0FUYJ05YJFP1JFUX205UIF@0A05MGE`1FEUH0EEEE05=CD`1BDU80DE5A04i>CP1=CDd0Bd];04Y:
BP18B4P0ADE504A4A013@d<0@T920451@@0o?cl00P0n?Sh02@0l?3`0>c/k03Xj>P0i>CT0>3Ph03Lg
=`0f=SH0=CDe03<c<`02038b<P<0=3@d0`0e=CD0400f=SH0=cLg03Xj>P0l?3`0@D510492@P14A4@0
BDU904a<C01?Cdl0DU9B05IFEP1IFET0H61P06ATI01XJ6PN0?ooo`0I09RHV02IVIT0WIfM09jNWP2O
Wil0XJ6Q0:>SX`2TY:@0Z:RX0:VYZ@2[Zj/0[Jf]0:j^[P2b/[80];Bd0;Fe]@2g]kL0^KVi0;fm_@2o
_kl0`L710<?3``35aLD0alO70<c<c0020<k>cP0=0<o?c`3=cLd0b<S80<?3``2n_[h0^[Zj0;Jf]P2c
/k<0[Jf]0:ZZZP2XZ:P0YZJV0:FUY@040:>SX`80Y:BT0`2UYJD20:BTY0H0YJFU0P2TY:@30:>SX`80
XJ6Q00H0X:2P09nOW`2NWYh0W9bL09^KV`2JVYX209VIV@0F09NGU`2FUYH0UYJF09FEU@2DU9@0Ti>C
096AT@2@T900Shn?08j>SP2=SHd0RXZ:08R8R026QXH0Q8B40820P01mOGd0NGUi07MgM`1eMGD0M7Ad
07=cL`80LW9b00`0MGEe07AdM01dM7@0MGEe07QhN01jNWX0Ng]k07inOP22PX80RXZ:08j>SP2BTY8N
0?ooo`80/K6a00<0/k>c0;Bd]02e]KD00P2f][H05`2g]kL0^KVi0;Zj^P2j^[X0^k^k0;bl_02n_[h0
_kno0<71`@32`/80`l?30<O7a`39bLT0bl_;0<g=c@3?cll0dM7A0=OGe`3Jf]X0gMgM0>3Ph03UiND0
kNg]0080l?3`00T0k^k^0>c/k03Zj^X0iNGU0>;RhP3Ph>00g]kN0=_Kf`3Hf=P00P3GemL20=KFeP80
eMGE0`3De=@0103EeMD0e]KF0=OGe`3GemL20=SHf080f][J00@0fm_K0=cLg03MgMd0gMgM0`3Ng]h3
0=oOg`@0g]kN1@3MgMd05P3Lg=`0fm_K0=_Kf`3Jf]X0fMWI0=SHf03Fe]H0eMGE0=;BdP3=cLd0alO7
0<?3``2k^k/0^;Rh0;Fe]@2b/[80[jn_0:^[Z`2ZZZX0ZJVY0:NWY`2UYJD20::RXP80XJ6Q00D0XZ:R
0:>SX`2XZ:P0ZZZZ0:f][@0R0?ooo`00803oool05@1]KFd0KVi^079bLP1cLg<0M7Ad07IfMP1hN7P0
NWYj07emO@1nOWh0P82008:2PP23Ph<0QXJ608R8R029RHT0Rh^;08b<S02>SXh0T92@096AT@0209:B
TP0=09>CT`2EUID0UYJF09BDU02BTY80SHf=07emO@1cLg<0J6QX05mOG`1LG5`0FEUI05EEE@0405AD
E00605EEE@1FEUH0EeMG05QHF01IFET0FUYJ1@1KFe/205UIF@80F5QH0180EeMG05IFEP1EEED0E5AD
059BDP1ADE40Cdm?04e=C@1;Bd/0BDU904Q8B016ATH0@d=30451@@10@400?clo03hn?P0l?3`203/k
>`0403Ti>@0h>3P0=cLg03De=@80=3@d00<0<c<c038b<P0a<C400P0a<C400`0b<S80<c<c03@d=002
03@d=080=CDe00l0=SHf03Ti>@0l?3`0?clo0451@@13@d<0BDU904];B`1>CTh0DE5A05EEE@1IFET0
H61P06ATI01XJ6P07P3oool06`2HV9P0VYZJ09fMW@2OWil0X:2P0::RXP2SXj<0YJFU0:VYZ@2ZZZX0
[:b/0:j^[P2`/;00];Bd0;Jf]P2h^;P0^KVi0;^k^`2o_kl0`/;20<C4a036a/H0b<S80<[:bP3?cll0
dM7A0=;BdP020=?Cd`0;0<g=c@38b<P0`/;20;bl_02h^;P0];Bd0:f][@2ZZZX0Z:RX0:NWY`2UYJD0
1@2TY:@30:FUY@X0YZJV0P2UYJD20:BTY0070:>SX`2RXZ80XJ6Q0:2PX02OWil0WIfM09^KV`0209ZJ
VP0F09VIV@2GUiL0UYJF09JFUP2EUID0U9BD09:BTP2ATI40Shn?08j>SP2=SHd0Rh^;08R8R025QHD0
PX:207inOP1lO7`0NGUi07EeM@1cLg<0LW9b071`L080Kfm_00d0L71`075aL@1aLG40LG5a07=cL`1f
MWH0MgMg07UiN@1mOGd0PH6108V9R@2>SXh0TY:B01h0oooo01l0/K6a0;:b/P2d];@0];Bd0;Fe]@2f
][H0]kNg0;Rh^02j^[X0^k^k0;bl_02m_Kd0_[jn0<30`032`/80`l?30<G5a@36a/H0b/[:0<c<c03>
c/h0d=3@0=;BdP3EeMD0fm_K0=gMg@3Ph>00hn?S0>SXj03`l?00l_;b0080mOGe00P0l_;b0>o_k`3Y
jNT0i^KV0>?Sh`3Ph>00g]kN0=_Kf`80fMWI0P3Hf=P50=OGe`040=SHf03IfMT0f][J0=[JfP80fm_K
0P3MgMd0103Ng]h0gmoO0>3Ph03Ph>020>7Qh@P0h^;R00<0hN7Q0>3Ph03Ph>000P3Ph>005P3Ogml0
g]kN0=gMg@3Lg=`0fm_K0=[JfP3EeMD0dM7A0<_;b`36a/H0`L710;fm_@2g]kL0];Bd0;2`/02^[Zh0
Zj^[0:RXZ02WYjL0YZJV0:>SX`2QXJ4409nOW`050:6QX@2SXj<0Z:RX0:^[Z`2][Jd08P3oool00200
oooo01X0KFe]06i^KP1bLW80Lg=c07EeM@1gMgL0N7Qh07YjNP1nOWh0Ogmo0861P@22PX80Q8B408N7
Q`28R8P0RXZ:08^;R`2=SHd0Shn?096AT@2BTY80Ti>C09BDU02EUID0UYJF09NGU`80UIFE00P0TI6A
0861P@1hN7P0KVi^061PH01GEeL0EEEE059BDP80DE5A0P1BDU801P1CDe<0EEEE05IFEP1GEeL0F5QH
05UIF@<0FUYJ00<0Fe]K05YJFP1IFET00P1HF5P06P1GEeL0EUIF05EEE@1DE5@0De=C055AD@1?Cdl0
CTi>04];B`19BDT0AdM704I6AP14A4@0@41003hn?P0m?Cd0?3`l03/k>`0i>CT0>3Ph03Lg=`0f=SH0
=CDe03@d=00b<S80<C4a0P0`<30302l_;`04030`<00a<C40<C4a038b<P<0=3@d0P0e=CD03P0h>3P0
>c/k03hn?P11@D40A4A404U9B@1;Bd/0CTi>055AD@1EEED0FEUI061PH01TI6@0J6QX7P3oool06`2H
V9P0VYZJ09fMW@2OWil0XJ6Q0:>SX`2TY:@0YZJV0:ZZZP2/[:`0[Zj^0;2`/02b/[80][Jf0;Rh^02j
^[X0_;bl0;fm_@32`/80a<C40<O7a`39bLT0bl_;0<g=c@3Bd]80eMGE0=KFeP020=SHf00;0=7Ad@3=
cLd0alO70;no_`2i^KT0];Bd0:f][@2ZZZX0Z:RX0:NWY`2UYJD00`2TY:@20:FUY@<0YZJV2`2WYjL0
1@2VYZH0YJFU0:FUY@2SXj<0XZ:R0080XJ6Q00P0X:2P09fMW@2LW9`0Vi^K09ZJVP2IVIT0UiNG09JF
UP80UIFE0140Ti>C09:BTP2@T900SXj>08f=S@2;Rh/0RHV908B4Q01oOgl0O7al07YjNP1gMgL0MGEe
079bLP1`L700KVi^06e]K@0206a/K0<0KFe]00X0KVi^079bLP1cLg<0MGEe07QhN01mOGd0PH6108V9
R@2=SHd0TY:B7P3oool0:P2a/K40/[:b0;Bd]02e]KD0][Jf0;Ng]`2h^;P0^KVi0;^k^`2l_;`0_Kfm
0;no_`30`<00`l?30<C4a036a/H0alO70<W9b@3=cLd0clo?0=7Ad@3Cdm<0eMGE0=SHf03Ng]h0hN7Q
0>CTi03Xj>P0k>c/0?;blP3dm?@0m_Kf0?Win@3hn?P0m?Cd0>c/k03Xj>P0iNGU0>;RhP3Ph>00g=cL
0=_Kf`<0f][J103IfMT20=[JfP030=_Kf`3Lg=`0gMgM0080g]kN00@0gmoO0>3Ph03QhN40h^;R0P3S
hn<00`3Ti>@0iNGU0>GUi@040>KViP<0iNGU0P3Ti>@20>?Sh`80h^;R01D0hN7Q0=oOg`3Ng]h0g=cL
0=WIf@3AdM40b/[:0<G5a@31`L40_Kfm0;Rh^02a/K40[Zj^0:b/[02ZZZX0Z:RX0:FUY@2SXj<0X:2P
09jNWP2LW9`00P2MWId01`2LW9`0WYjN0:2PX02SXj<0Z:RX0:ZZZP2][Jd08P3oool00200oooo01P0
KFe]06m_K`1cLg<0M7Ad07IfMP1hN7P0NGUi07]kN`1nOWh0P82008:2PP24Q8@0QHF508V9R@2:RXX0
S8b<08j>SP2?Shl0TY:B09>CT`2DU9@0UIFE09JFUP2HV9P309ZJVP0809VIV@2GUiL0RHV90861P@1h
N7P0KFe]061PH01CDe<304];B`0704e=C@1?Cdl0DE5A05=CD`1DE5@0EEEE05MGE`0305UIF@80FUYJ
0P1IFET05@1HF5P0EeMG05EEE@1EEED0De=C059BDP1ADE40Cdm?04i>CP1<C4`0B4Q804E5A@13@d<0
@T920410@00k>c/0>CTi03Ph>00f=SH0=CDe03<c<`03034a<@03030`<00_;bl0;Bd]00H0:b/[00L0
;Bd]02l_;`0_;bl0<30`034a<@0b<S80=3@d0080=CDe00h0>3Ph03Xj>P0l?3`0?clo0451@@18B4P0
Bd];04i>CP1ADE40EEEE05QHF01PH600I6AT06QXJ1h0oooo02L0V9RH09ZJVP2NWYh0X:2P0::RXP2T
Y:@0YZJV0:RXZ02/[:`0[Zj^0;6a/@2c/k<0]KFe0;Vi^@2k^k/0_Kfm0<30`032`/80alO70<W9b@3<
c<`0c/k>0=7Ad@3De=@0fMWI0=_Kf`3MgMd0gmoO0>3Ph03IfMT0e=CD0<k>cP37alL0_kno0;Jf]P2/
[:`0ZJVY0:NWY`2VYZH00P2TY:@30:FUY@040:JVYP2WYjL0YjNW0:RXZ0`0ZJVY00X0Z:RX0:NWY`2U
YJD0YJFU0:>SX`2RXZ80XJ6Q09jNWP2MWId0Vi^K0P2JVYX05@2GUiL0UYJF09FEU@2DU9@0Ti>C096A
T@2=SHd0Rh^;08V9R@26QXH0PX:207QhN01fMWH0M7Ad079bLP1_Kfl0KFe]06][J`1ZJVX0JFUY06QX
J00406IVIP0;06QXJ01YJFT0KVi^071`L01cLg<0N7Qh07]kN`1oOgl0RHV908f=S@2BTY807P3oool0
7P2a/K40/[:b0;Bd]02e]KD0]kNg0;Rh^02i^KT0^[Zj0;jn_P2o_kl0`<300<;2`P33`l<0a/K60<S8
b03:b/X0c<c<0<g=c@3Bd]80e=CD0=OGe`3IfMT0g=cL0=oOg`3UiND0j>SX0>_[j`3^k^h0lO7a0?Ge
m@@0moOg00P0nOWi0?;blP3]kNd0jNWY0>GUi@3Rh^80gmoO0=kNgP80gMgM0`3Lg=`30=gMg@090=kN
gP3Ogml0h>3P0>7Qh@3Rh^80hn?S0>GUi@3Vi^H0inOW0080j>SX00<0jNWY0>_[j`3[jn/01`3/k>`0
6@3[jn/0j^[Z0>[ZjP3YjNT0j>SX0>KViP3UiND0h^;R0>3Ph03MgMd0fMWI0=?Cd`34a<@0`<300;bl
_02g]kL0/[:b0:n_[`2ZZZX0YjNW0:BTY02QXJ40WinO09^KV`2JVYX00`2HV9P209NGU`0709VIV@2L
W9`0WinO0:6QX@2WYjL0ZZZZ0:f][@0R0?ooo`00803oool0601]KFd0Kfm_07=cL`1eMGD0MgMg07Qh
N01jNWX0O7al07moO`21PH40Ph>308B4Q026QXH0RHV908^;R`2=SHd0SXj>092@T02CTi<0U9BD09JF
UP2GUiL0V9RH09VIV@80Vi^K01<0W9bL09ZJVP2JVYX0SHf=08F5Q@1lO7`0LW9b06MWI`1KFe/0ADE5
04M7A`19BDT0Bd];04e=C@1ADE40De=C05ADE01FEUH0EeMG00<0FEUI00<0FUYJ05UIF@1IFET00P1H
F5P05@1GEeL0EEEE05ADE01BDU80DE5A051@D01?Cdl0CDe=04];B`17AdL0A4A40492@P10@400?Shn
03Xj>P0h>3P0=SHf03@d=00c<c<0<30`02l_;`0302h^;P0402d];@0[:b/0:RXZ02TY:@<0:RXZ0P0[
:b/202d];@0D02h^;P0`<300<C4a038b<P0d=3@0=CDe03Ph>00j>SX0?3`l03lo?`11@D40B4Q804];
B`1>CTh0DU9B05EEE@1IFET0HF5Q06ATI01XJ6PN0?ooo`0V09RHV02JVYX0WYjN0:2PX02SXj<0YJFU
0:NWY`2YZJT0[Jf]0;2`/02b/[80];Bd0;Jf]P2k^k/0_Kfm0;no_`32`/80a<C40<W9b@3<c<`0clo?
0=7Ad@3De=@0e]KF0=cLg03Ogml0hN7Q0>;RhP3Ti>@0g=cL0=SHf03AdM40bLW90<;2`P2j^[X0ZZZZ
0:RXZ02UYJD30:BTY080YJFU0P2VYZH20:RXZ080ZJVY0`2ZZZX40:^[Z`@0ZZZZ0240ZJVY0:RXZ02W
YjL0YZJV0:BTY02SXj<0XZ:R09nOW`2MWId0W9bL09^KV`2JVYX0UiNG09FEU@2DU9@0Ti>C096AT@2@
T900S8b<08R8R025QHD0PH6107alO01dM7@0LW9b071`L01^KVh0Jf][06YZJP1XJ6P0IVIV06EUI@1T
I6@00`1SHf<0301TI6@0IVIV06MWI`1/K6`0Kfm_07=cL`1gMgL0Ng]k07moO`28R8P0SHf=09:BTQh0
oooo01h0/K6a0;:b/P2d];@0][Jf0;Ng]`2h^;P0^[Zj0;^k^`2o_kl0`<300<;2`P33`l<0aLG50<S8
b03:b/X0c<c<0<k>cP3@d=00e=CD0=KFeP3IfMT0g=cL0=kNgP3QhN40j>SX0>_[j`3_knl0l_;b0?Ge
m@3fm_H20?Ogm`<0m_Kf00L0m?Cd0>k^kP3YjNT0iNGU0>;RhP3Ogml0g]kN00D0gMgM0P3Ng]h02`3O
gml0h>3P0>7Qh@3Rh^80hn?S0>CTi03UiND0inOW0>SXj03YjNT0j^[Z0080jn_[00<0kNg]0>k^kP3_
knl00P3_knl50>k^kP0G0>c/k03[jn/0j^[Z0>WYj@3WinL0iNGU0>7Qh@3MgMd0f=SH0=;BdP3:b/X0
_[jn0;^k^`2h^;P0/k>c0:n_[`2/[:`0YjNW0:>SX`2PX:00WIfM09ZJVP2GUiL00P2EUID309BDU008
09JFUP2HV9P0VYZJ09fMW@2PX:00YZJV0:VYZ@2][JdR0?ooo`00803oool06@1]KFd0Kfm_07=cL`1e
MGD0MgMg07UiN@1jNWX0O7al0820P021PH40Ph>308F5Q@27QhL0RXZ:08b<S02>SXh0Shn?096AT@2D
U9@0UIFE09NGU`2HV9P0VYZJ09^KV`2MWId00P2NWYh209fMW@0@092@T029RHT0P82007IfMP1/K6`0
HF5Q04Q8B013@d<0AdM704Y:BP1=CDd0DE5A05=CD`1DE5@0EUIF05MGE`80FEUI0`1JFUX07`1IFET0
F5QH05QHF01GEeL0EUIF05EEE@1BDU80DE5A04m?C`1>CTh0C4a<04Y:BP16ATH0A4A40451@@0o?cl0
?3`l03Ph>00f=SH0=3@d038b<P0a<C40;Rh^02d];@0/;2`0:b/[02`/;00[:b/0:RXZ02TY:@0X:2P0
100Y:BT05`0Z:RX0:b/[02/[:`0];Bd0<30`034a<@0b<S80<c<c03@d=00h>3P0>SXj03`l?00n?Sh0
@D5104M7A`1;Bd/0CTi>059BDP1EEED0FEUI061PH01TI6@0IfMW01h0oooo02@0V9RH09ZJVP2OWil0
XJ6Q0:>SX`2UYJD0Z:RX0:ZZZP2_[jl0/K6a0;>c/`2e]KD0^;Rh0;bl_02o_kl0`L710<C4a036a/H0
c<c<0<k>cP3AdM40e=CD0=KFeP3IfMT0gmoO0>;RhP3Ti>@0iNGU0>OWi`3Ogml0f][J0=?Cd`3<c<`0
aLG50;fm_@2ZZZX20:BTY080Xj>S0P2TY:@01@2UYJD0YZJV0:NWY`2XZ:P0ZJVY0080ZZZZ0P2[Zj/7
0:b/[080Zj^[0200ZZZZ0:VYZ@2XZ:P0YjNW0:FUY@2TY:@0Xj>S09nOW`2NWYh0W9bL09^KV`2JVYX0
UYJF09FEU@2CTi<0TI6A092@T02>SXh0R8R808F5Q@1oOgl0Ng]k07MgM`1aLG40Kfm_06a/K01ZJVX0
J6QX06MWI`1TI6@0HV9R065QH@@0H61P00`0HV9R06ATI01UIFD0Jf][06i^KP1bLW80MWIf07]kN`1o
Ogl0RHV908f=S@2BTY8N0?ooo`0L0;6a/@2b/[80]KFe0;Jf]P2h^;P0^KVi0;^k^`2l_;`0_kno0<71
`@33`l<0a<C40<K6aP39bLT0bl_;0<k>cP3@d=00d];B0=KFeP3IfMT0fm_K0=kNgP3QhN40i>CT0>[Z
jP3^k^h0lO7a0?Cdm0<0moOg00/0m_Kf0?Gem@3dm?@0m?Cd0?;blP3^k^h0j>SX0>CTi03Rh^80gmoO
0=kNgP030=gMg@80g]kN00X0gmoO0>3Ph03Ph>00hN7Q0>?Sh`3Ti>@0iNGU0>KViP3WinL0jNWY0P3[
jn/00`3/k>`0kNg]0>k^kP020?3`l080lO7a00@0l_;b0?7al@3alO40lO7a0P3`l?005`3^k^h0k>c/
0>_[j`3YjNT0inOW0>GUi@3MgMd0f=SH0=7Ad@3:b/X0a<C40;^k^`2g]kL0/k>c0:n_[`2[Zj/0Z:RX
0:6QX@2NWYh0Vi^K09RHV02FUYH0Ti>C0080TY:B0P2ATI402@2DU9@0UIFE09NGU`2JVYX0WIfM0:2P
X02WYjL0ZZZZ0:f][@0R0?ooo`00803oool06@1^KVh0L71`07=cL`1eMGD0MgMg07UiN@1kNg/0OGem
0861P@22PX80Q8B408J6QP28R8P0Rh^;08f=S@2?Shl0TI6A09:BTP2EUID0UYJF09RHV02JVYX0Vi^K
09fMW@2OWil00P2PX:00402OWil0WYjN09:BTP2;Rh/0Ph>307]kN`1aLG40IfMW051@D015ADD0AdM7
04U9B@1<C4`0DE5A05=CD`1EEED205MGE`80FEUI0`1JFUX06P1IFET0F5QH05QHF01GEeL0EUIF05EE
E@1BDU80DE5A04m?C`1>CTh0C4a<04Y:BP16ATH0@d=30410@00m?Cd0>c/k03Lg=`0e=CD0<c<c030`
<00_;bl0;2`/02/[:`0Z:RX0:BTY0P0Z:RX01@0Y:BT0:RXZ02PX:00X:2P09bLW00<0:2PX01H0:BTY
02XZ:P0[:b/0;Rh^02l_;`0`<300<S8b03<c<`0g=cL0>CTi03`l?00n?Sh0@D5104M7A`1;Bd/0CTi>
059BDP1EEED0FEUI061PH01TI6@0J6QX7P3oool0902IVIT0Vi^K09nOW`2RXZ80Y:BT0:JVYP2XZ:P0
Zj^[0;2`/02b/[80];Bd0;Ng]`2i^KT0_[jn0<71`@33`l<0a/K60<S8b03>c/h0dM7A0=?Cd`3Fe]H0
fMWI0=cLg03Rh^80iNGU0>OWi`3Xj>P0jNWY0>7Qh@3Kfm/0eMGE0<k>cP37alL0_[jn0:^[Z`80XZ:R
00T0XJ6Q0::RXP2SXj<0Y:BT0:FUY@2VYZH0YjNW0:VYZ@2ZZZX00P2[Zj/20:b/[0L0[Jf]0P2/[:`2
0:^[Z`0M0:VYZ@2XZ:P0YZJV0:FUY@2SXj<0WinO09jNWP2MWId0Vi^K09VIV@2EUID0Ti>C09:BTP2?
Shl0SXj>08^;R`23Ph<0Ogmo07YjNP1fMWH0LW9b06e]K@1[Jf/0JFUY06IVIP1TI6@0Hf=S065QH@1O
Gel00P1NGUh205eMG@0=05iNGP1PH600HF5Q06=SH`1YJFT0KFe]079bLP1fMWH0Ng]k07moO`29RHT0
SHf=09:BTP0N0?ooo`0Y0;6a/@2b/[80][Jf0;Ng]`2i^KT0^[Zj0;^k^`2m_Kd0`L710<;2`P33`l<0
aLG50<S8b03;bl/0cLg=0<o?c`3Bd]80e=CD0=WIf@3Kfm/0g]kN0>3Ph03Shn<0i^KV0>g]k@3`l?00
m?Cd0?Ogm`3inOT0n?Sh0?Ogm`3emOD0lo?c0?;blP3alO40jn_[0>OWi`3Vi^H0hn?S0>3Ph03Ng]h0
103MgMd0103Ng]h0gmoO0>3Ph03QhN420>;RhP060>CTi03UiND0i^KV0>OWi`3YjNT0jn_[0P3]kNd0
103^k^h0kno_0?3`l03bl_820??cl`80m?Cd1@3bl_805`3_knl0kNg]0>_[j`3Xj>P0iNGU0>7Qh@3F
e]H0d=3@0<W9b@34a<@0_kno0;Ng]`2c/k<0[jn_0:^[Z`2XZ:P0Y:BT09jNWP2KVi/0V9RH09FEU@2C
Ti<0T92@0080Shn?00/0SXj>08n?S`2ATI40U9BD09JFUP2IVIT0WIfM0:2PX02VYZH0ZJVY0:f][@0R
0?ooo`00803oool0601^KVh0L71`07=cL`1eMGD0MgMg07UiN@1kNg/0OGem0861P@23Ph<0QHF508N7
Q`29RHT0S8b<08j>SP2@T900TI6A09>CT`2FUYH0V9RH09ZJVP2KVi/0WIfM09jNWP80XJ6Q01<0XZ:R
0:6QX@2OWil0UIFE08j>SP26QXH0OWin07EeM@1/K6`0EEEE04U9B@15ADD0BDU904e=C@1BDU80E5AD
05EEE@1GEeL0F5QH00<0FUYJ0P1KFe/05`1JFUX0FEUI05QHF01GEeL0EUIF05EEE@1CDe<0DE5A04m?
C`1=CDd0C4a<04Y:BP15ADD0@d=30410@00m?Cd0>SXj03Hf=P0d=3@0<S8b02l_;`0];Bd0:RXZ0080
:BTY00@0:2PX02TY:@0Y:BT0:RXZ0P0Y:BT0100X:2P09bLW02PX:00X:2P202LW9`0E02PX:00Y:BT0
;2`/02d];@0^;Rh0<30`038b<P0f=SH0>CTi03/k>`0n?Sh0@D5104M7A`1;Bd/0CTi>059BDP1EEED0
FEUI061PH01TI6@0J6QX01h0oooo02D0VIVI09^KV`2PX:00XZ:R0:BTY02WYjL0ZJVY0:b/[02a/K40
/k>c0;Jf]P2h^;P0^k^k0<30`033`l<0aLG50<S8b03:b/X0d=3@0=?Cd`3Fe]H0fMWI0=cLg03Ogml0
iNGU0>SXj03Zj^X0k>c/0>_[j`3Shn<0gMgM0=KFeP3?cll0b<S80;no_`2/[:`0Xj>S0080X:2P00L0
XJ6Q0:>SX`2TY:@0YJFU0:NWY`2XZ:P0ZZZZ0080Zj^[00<0[:b/0:f][@2][Jd01`2^[Zh20:f][@80
[:b/01d0ZZZZ0:VYZ@2WYjL0YJFU0:>SX`2OWil0WYjN09fMW@2KVi/0V9RH09BDU02BTY80T92@08f=
S@2:RXX0QhN707inOP1jNWX0MWIf079bLP1^KVh0JVYZ06QXJ01UIFD0Hf=S069RHP1PH600GUiN05aL
G00205]KF`0?05YJFP1KFe/0G5aL05iNGP1OGel0HV9R06UYJ@1]KFd0LW9b07IfMP1jNWX0Ogmo08R8
R02=SHd0TY:B01h0oooo02P0/K6a0;>c/`2f][H0^;Rh0;Vi^@2k^k/0_;bl0;jn_P31`L40`l?30<G5
a@37alL0b<S80<g=c@3?cll0d];B0=CDe03Fe]H0fm_K0=gMg@3Ph>00hn?S0>KViP3YjNT0l?3`0??c
l`3fm_H0n_[j0?_kn`3hn?P0m_Kf0?Cdm03bl_80l?3`0>g]k@3WinL0i^KV0>CTi03Ph>00g]kN0`3L
g=`20=gMg@0B0=oOg`3Ph>00hN7Q0>7Qh@3Rh^80hn?S0>KViP3WinL0j>SX0>WYj@3Zj^X0kNg]0>k^
kP3_knl0l?3`0?7al@3bl_80m?Cd103emOD06`3clo<0m?Cd0?Gem@3dm?@0l_;b0>k^kP3/k>`0jNWY
0>GUi@3QhN40g=cL0<k>cP38b<P0`l?30;fm_@2h^;P0/[:b0:n_[`2[Zj/0YjNW0:FUY@2RXZ80Vi^K
09RHV02FUYH0Ti>C092@T00208f=S@80S8b<00X0SHf=092@T02CTi<0UYJF09ZJVP2MWId0X:2P0:JV
YP2YZJT0[Jf]8P3oool00200oooo02h0KVi^071`L01dM7@0MWIf07QhN01jNWX0O7al07inOP22PX80
Q8B408J6QP28R8P0Rh^;08j>SP2@T900TY:B09BDU02EUID0VIVI09^KV`2LW9`0WYjN0:2PX02RXZ80
Y:BT0:FUY@2VYZH0Y:BT0::RXP2GUiL0T92@08V9R@23Ph<0NWYj075aL@1NGUh0E5AD04U9B@1<C4`0
Cdm?05EEE@1GEeL0F5QH05YJFP1KFe/0G5aL0P1MGEd305aLG00G05YJFP1IFET0F5QH05MGE`1FEUH0
De=C059BDP1@D500CTi>04a<C01:BTX0ATI604=3@`10@400?3`l03Ti>@0d=3@0<S8b02l_;`0];Bd0
:b/[02TY:@0X:2P00P0W9bL202TY:@809bLW00@09RHV02@T900T92@09BDU0`0V9RH202LW9`0C02PX
:00Y:BT0:b/[02d];@0_;bl0=CDe03Lg=`0k>c/0?Cdm0410@017AdL0BTY:04i>CP1BDU80EEEE05UI
F@1PH600I6AT06QXJ00N0?ooo`0J09VIV@2LW9`0XJ6Q0:>SX`2VYZH0Z:RX0:^[Z`2^[Zh0/k>c0;Fe
]@2h^;P0^k^k0;jn_P33`l<0a/K60<W9b@3<c<`0c/k>0=CDe03GemL0f][J0=kNgP3QhN40i>CT0>_[
j`3]kNd20?3`l00A0>k^kP3Ti>@0g]kN0=SHf03AdM40b<S80;no_`2_[jl0YZJV09^KV`2MWId0WinO
0:>SX`2UYJD0YZJV0:RXZ02YZJT00P2/[:`0102][Jd0[Zj^0:n_[`2_[jl30;2`/0<0/K6a00<0/;2`
0:n_[`2_[jl00P2^[Zh07P2/[:`0Zj^[0:VYZ@2VYZH0Xj>S0:6QX@2OWil0W9bL09RHV02FUYH0T92@
08f=S@28R8P0Q8B40861P@1nOWh0MWIf079bLP1_Kfl0JVYZ06MWI`1SHf<0HF5Q05iNGP1LG5`0Fe]K
05UIF@1GEeL0EUIF05EEE@80E5AD00h0EeMG05QHF01JFUX0GEeM065QH@1XJ6P0KFe]075aL@1fMWH0
NWYj07moO`28R8P0SHf=09:BTQh0oooo01/0/[:b0;>c/`2f][H0^;Rh0;Zj^P2l_;`0_Kfm0;no_`33
`l<0aLG50<O7a`39bLT0bl_;0=3@d03Bd]80e=CD0=OGe`3IfMT0g]kN0>7Qh@3Ti>@0inOW0>[ZjP3]
kNd0m?Cd0?Ogm`3kno/00P3lo?`02@3hn?P0m_Kf0??cl`3`l?00k>c/0>OWi`3QhN40gmoO0=[JfP02
0=WIf@80f][J01@0fm_K0=cLg03Lg=`0gmoO0>3Ph03QhN40hn?S0>CTi03UiND0j>SX0>WYj@3Zj^X0
k>c/0>g]k@3_knl0lO7a0?;blP3clo<0m?Cd0?Gem@@0moOg01d0m_Kf0?Shn03gmoL0mOGe0?;blP3`
l?00j^[Z0>KViP3Ph>00fMWI0=CDe03>c/h0a<C40<30`02k^k/0][Jf0;:b/P2[Zj/0YZJV0::RXP2O
Wil0WIfM09ZJVP2EUID0TY:B08n?S`2<S8`0RXZ:08R8R00208N7Q`0;08V9R@2;Rh/0T92@09>CT`2F
UYH0VIVI09fMW@2PX:00YZJV0:VYZ@2][Jd08P3oool00200oooo02d0KVi^071`L01eMGD0MWIf07Qh
N01jNWX0O7al07moO`23Ph<0QHF508N7Q`29RHT0Rh^;08n?S`2ATI40Ti>C09FEU@2GUiL0VYZJ09bL
W02NWYh0WinO0:6QX@2SXj<0YZJV0:NWY`2XZ:P0YZJV0:>SX`2IVIT0Ti>C08b<S024Q8@0O7al07=c
L`1QHF40F5QH04a<C01?Cdl0DE5A05MGE`1HF5P0FUYJ05aLG01MGEd0101NGUh205eMG@0E05]KF`1J
FUX0FEUI05QHF01GEeL0E5AD05=CD`1ADE40Cdm?04e=C@1;Bd/0ATI604A4A010@400?Cdm03Ti>@0d
=3@0<C4a02l_;`0];Bd0:b/[0080:2PX0P0V9RH01P0X:2P0:BTY02PX:00W9bL09RHV02@T90808b<S
00<092@T02DU9@0U9BD00P0V9RH04`0W9bL0:2PX02TY:@0/;2`0;Rh^03@d=00g=cL0>CTi03dm?@10
@400ATI604Y:BP1>CTh0DU9B05EEE@1IFET0H61P06ATI01XJ6P07P3oool0<@2IVIT0W9bL0:6QX@2S
Xj<0YZJV0:VYZ@2/[:`0[Zj^0;Bd]02f][H0^KVi0;bl_02o_kl0aLG50<S8b03;bl/0cLg=0=3@d03F
e]H0fMWI0=gMg@3Ph>00hn?S0>KViP3]kNd0l?3`0?;blP3alO40kno_0>GUi@3Ng]h0f=SH0=7Ad@38
b<P0_kno0:n_[`2VYZH0VYZJ09fMW@2OWil0Xj>S0:FUY@2VYZH0Z:RX0:ZZZP2/[:`0[Jf]0:j^[P2_
[jl00P2`/;000`2a/K40/[:b0;:b/P030;:b/P80/K6a01/0/;2`0:n_[`2_[jl0[Jf]0:^[Z`2YZJT0
YZJV0:>SX`2QXJ40WYjN09ZJVP2GUiL0U9BD08f=S@28R8P0Ph>307moO`1lO7`0NGUi079bLP1^KVh0
Jf][06MWI`1TI6@0GemO05eMG@1KFe/00P1IFET00`1GEeL0E5AD059BDP03055AD@0>05ADE01FEUH0
FEUI05eMG@1PH600J6QX06e]K@1aLG40MWIf07]kN`1oOgl0R8R808f=S@2BTY8N0?ooo`0J0;:b/P2c
/k<0]kNg0;Vi^@2k^k/0_Kfm0;jn_P30`<00a<C40<K6aP38b<P0b/[:0<g=c@3AdM40e=CD0=KFeP3H
f=P0fm_K0>3Ph03Shn<0i^KV0>WYj@3/k>`0kno_0?KfmP3inOT30?clo0080?Ogm`3dm?@0lO7a0>k^
kP3YjNT0iNGU0=oOg`3Kfm/30=KFeP80f=SH01H0fMWI0=[JfP3Kfm/0g]kN0=oOg`3QhN40hn?S0>CT
i03UiND0jNWY0>[ZjP3[jn/0k>c/0>k^kP3`l?00lO7a0?;blP3clo<0m?Cd0?Gem@3gmoL0n?Sh103g
moL06P3emOD0lo?c0?3`l03^k^h0i^KV0=oOg`3IfMT0dm?C0<g=c@37alL0_[jn0;Vi^@2e]KD0/K6a
0:j^[P2WYjL0XZ:R09jNWP2LW9`0VYZJ09NGU`2ATI40SXj>08^;R`28R8P0QhN70P25QHD03027QhL0
RHV908^;R`2@T900U9BD09JFUP2IVIT0WIfM0:2PX02VYZH0ZJVY0:f][B80oooo000P0?ooo`0]06i^
KP1`L700MGEe07MgM`1iNGT0Ng]k07emO@1oOgl0Ph>308F5Q@27QhL0RXZ:08b<S02@T900TY:B09BD
U02FUYH0V9RH09^KV`2MWId0WinO0:6QX@2RXZ80Y:BT0:RXZ02YZJT0ZZZZ0:NWY`2TY:@0VYZJ09BD
U02>SXh0QXJ607inOP1fMWH0Hf=S05UIF@1?Cdl0DU9B05ADE01IFET0Fe]K05eMG@1NGUh0GemO00@0
H61P0P1OGel05`1MGEd0G5aL05YJFP1IFET0F5QH05EEE@1DE5@0DU9B051@D01>CTh0C4a<04M7A`15
ADD0@D5103dm?@0j>SX0=3@d034a<@0_;bl0;2`/02/[:`0X:2P09bLW00809BDU00d09RHV02PX:00X
:2P09RHV02DU9@0S8b<08R8R024Q8@0R8R8092@T02DU9@0V9RH09BDU00<09bLW0100:RXZ02d];@0c
<c<0=SHf03Ti>@0l?3`0@41004I6AP1:BTX0CTi>059BDP1EEED0FEUI061PH01TI6@0J6QX7P3oool0
;`2IVIT0W9bL0::RXP2TY:@0YjNW0:ZZZP2/[:`0[jn_0;Fe]@2g]kL0^k^k0;jn_P31`L40a/K60<W9
b@3<c<`0clo?0=;BdP3IfMT0g=cL0=oOg`3Rh^80iNGU0>WYj@3`l?00l_;b0?Cdm03bl_80kno_0>GU
i@3Ogml0f=SH0=3@d037alL0`<300:n_[`2UYJD0VYZJ09fMW@2OWil0Xj>S0:FUY@2WYjL0ZJVY0:ZZ
ZP2][Jd0[Zj^0080/;2`00<0/K6a0;:b/P2b/[801@2c/k<20;:b/P0P0;6a/@2`/;00/;2`0:f][@2/
[:`0ZJVY0:JVYP2TY:@0X:2P09bLW02IVIT0UIFE09:BTP29RHT0Q8B407moO`1jNWX0N7Qh07EeM@1^
KVh0Jf][06QXJ01TI6@0HV9R05aLG01IFET0F5QH05MGE`1FEUH0E5AD055AD@1?Cdl204i>CP0?04m?
C`1BDU80EEEE05QHF01LG5`0H61P06QXJ01/K6`0LG5a07IfMP1kNg/0Ogmo08R8R02=SHd0TY:B01h0
oooo02D0/[:b0;Bd]02g]kL0^KVi0;^k^`2m_Kd0_kno0<71`@35aLD0alO70<[:bP3<c<`0c/k>0=?C
d`3EeMD0emOG0=[JfP3MgMd0h^;R0>GUi@3Xj>P0jn_[0>k^kP3bl_80n?Sh0?_kn`3moOd0o?cl0?_k
n`3fm_H0lo?c0>o_k`3[jn/0i^KV0>CTi03MgMd0f=SH0080dm?C01@0e=CD0=KFeP3Fe]H0emOG0=WI
f@3Kfm/0gMgM0=oOg`3QhN40h^;R0>CTi03Vi^H0jNWY0>[ZjP3[jn/0kNg]0>k^kP3`l?00lO7a0??c
l`80m?Cd00<0mOGe0?Ogm`3gmoL0103fm_H0:03clo<0lO7a0>k^kP3Zj^X0gmoO0=[JfP3Cdm<0cLg=
0<S8b032`/80^;Rh0;Fe]@2b/[80[Zj^0:^[Z`2SXj<0WinO09bLW02HV9P0UYJF09>CT`2=SHd0Rh^;
08R8R026QXH0QHF508>3P`24Q8@0QXJ608R8R02;Rh/0T92@09>CT`2FUYH0VIVI09fMW@2PX:00YZJV
0:ZZZP2][JdR0?ooo`00803oool0;@1^KVh0L71`07EeM@1gMgL0NGUi07]kN`1mOGd0Ogmo08B4Q026
QXH0R8R808Z:RP2=SHd0TI6A09>CT`2EUID0UiNG09VIV@2MWId0WYjN0:2PX02RXZ80Y:BT0:JVYP2Z
ZZX0Zj^[0:ZZZP2XZ:P0YJFU09^KV`2EUID0Shn?08N7Q`1oOgl0N7Qh06IVIP1LG5`0DE5A05EEE@1G
EeL0G5aL05iNGP1OGel0HF5Q069RHP0406=SH`0I069RHP1QHF40GemO05iNGP1LG5`0Fe]K05YJFP1G
EeL0EEEE05=CD`1ADE40Cdm?04e=C@19BDT0ATI60492@P0o?cl0?3`l03De=@0b<S80;bl_02d];@0[
:b/09bLW02DU9@0202@T900702DU9@0W9bL0:2PX02LW9`0U9BD08b<S028R8P02020P8004024Q8@0S
8b<092@T02@T90<09RHV0100:BTY02/[:`0b<S80=CDe03Ph>00l?3`0?clo04I6AP1:BTX0CTi>055A
D@1EEED0FEUI061PH01TI6@0J6QX7P3oool06@2IVIT0W9bL0::RXP2UYJD0Z:RX0:ZZZP2][Jd0/;2`
0;Jf]P2i^KT0_;bl0;no_`32`/80b<S80<_;b`3>c/h0dM7A0=CDe03Kfm/0g]kN0>7Qh@3Ti>@0j>SX
0>_[j`3bl_800P3emOD0603clo<0kno_0>GUi@3Ng]h0f=SH0<o?c`38b<P0`L710:j^[P2TY:@0VYZJ
09bLW02OWil0Xj>S0:FUY@2WYjL0ZJVY0:^[Z`2^[Zh0[jn_0;2`/02a/K40/[:b0;>c/`@0];Bd0`2c
/k<20;:b/P0`0;6a/@2`/;00[Zj^0:b/[02YZJT0YZJV0:FUY@2NWYh0VYZJ09NGU`2CTi<0SXj>08F5
Q@20P800NWYj07IfMP1cLg<0LG5a06][J`1XJ6P0IFEU069RHP1OGel0FEUI05IFEP1EEED0E5AD05=C
D`1ADE40CTi>04a<C01;Bd/0C4a<04e=C@1ADE40EEEE05QHF01KFe/0GemO06QXJ01/K6`0LG5a07If
MP1kNg/0Ogmo08R8R02=SHd0TY:B7P3oool0?P2b/[80];Bd0;Rh^02j^[X0_;bl0;jn_P30`<00`/;2
0<K6aP38b<P0bl_;0<g=c@3?cll0e=CD0=KFeP3IfMT0g=cL0=kNgP3Ti>@0inOW0>[ZjP3]kNd0l?3`
0??cl`3inOT0o?cl0?knoP3moOd0no_k0?Gem@3alO40k^k^0>WYj@3UiND0hn?S0=WIf@3De=@0clo?
0=3@d03AdM40dm?C0=CDe03Fe]H0emOG0=SHf03Lg=`0g]kN0=oOg`3QhN40hn?S0>GUi@3Xj>P0j^[Z
0>_[j`3/k>`0kNg]0?3`l03alO40l_;b0??cl`3dm?@0mOGe0P3fm_H20?Gem@0Z0?KfmP3clo<0l?3`
0>g]k@3Zj^X0iNGU0=_Kf`3EeMD0c/k>0<S8b032`/80_Kfm0;Bd]02`/;00[Zj^0:^[Z`2WYjL0X:2P
09bLW02IVIT0UYJF09BDU02@T900Rh^;08N7Q`25QHD0Q8B408:2PP23Ph<0QHF508N7Q`28R8P0RXZ:
092@T02CTi<0UYJF09VIV@2MWId0X:2P0:JVYP2YZJT0[Jf]8P3oool00200oooo02l0KVi^071`L01e
MGD0MgMg07UiN@1kNg/0OWin0820P024Q8@0QXJ608V9R@2;Rh/0SHf=096AT@2DU9@0UYJF09RHV02J
VYX0WYjN0:2PX02QXJ40Y:BT0:FUY@2WYjL0Zj^[0:f][@2[Zj/0Z:RX0:FUY@2KVi/0UYJF092@T028
R8P0PX:207]kN`1XJ6P0GemO05EEE@1HF5P0FUYJ05mOG`1QHF40HV9R06ATI01UIFD0IVIV06MWI`02
06IVIP0M06EUI@1TI6@0HV9R061PH01OGel0GEeM05aLG01IFET0EeMG05EEE@1CDe<0DE5A04m?C`1:
BTX0AdM704=3@`11@D40?Shn03Hf=P0c<c<0<30`02h^;P0[:b/09bLW02DU9@0S8b<08R8R02<S8`0U
9BD00P0W9bL00`0V9RH092@T024Q8@0201lO7`03020P800Q8B408b<S00808b<S018092@T02DU9@0X
:2P0:RXZ034a<@0e=CD0>3Ph03/k>`0o?cl0ATI604Y:BP1>CTh0DE5A05EEE@1IFET0HF5Q06ATI01X
J6PN0?ooo`0b09VIV@2LW9`0XZ:R0:FUY@2XZ:P0Zj^[0:j^[P2a/K40]kNg0;Zj^P2m_Kd0`<300<?3
``39bLT0c<c<0=3@d03Cdm<0e]KF0=gMg@3Ph>00hn?S0>KViP3Zj^X0kNg]0?Cdm03gmoL0m_Kf0??c
l`3`l?00i>CT0=kNgP3GemL0clo?0<S8b030`<00[Jf]0:BTY02JVYX0W9bL09nOW`2SXj<0YZJV0:RX
Z02ZZZX0[:b/0:n_[`2`/;00/K6a0;:b/P2c/k<20;Bd]080]KFe102d];@0802c/k<0/[:b0;:b/P2`
/;00[Zj^0:b/[02YZJT0YjNW0:BTY02MWId0VIVI09BDU02@T900Rh^;0861P@1kNg/0MWIf079bLP1_
Kfl0KFe]06QXJ01UIFD0Hf=S05mOG`1LG5`0EEEE05=CD`1BDU80DE5A051@D01>CTh0Bd];0`19BDT0
3`1;Bd/0D51@05ADE01GEeL0Fe]K05mOG`1XJ6P0K6a/075aL@1fMWH0NWYj07moO`28R8P0SHf=09:B
TP0N0?ooo`0I0;:b/P2d];@0^;Rh0;Zj^P2m_Kd0_kno0<71`@33`l<0alO70<W9b@3<c<`0c/k>0=7A
d@3Fe]H0f=SH0=_Kf`3Ng]h0h>3P0>KViP3YjNT0k>c/0>o_k`3bl_80mOGe0?_kn`020?knoP0T0?gm
o@3kno/0m?Cd0?3`l03/k>`0inOW0>?Sh`3Ogml0eMGE0=3@d03<c<`0cLg=0<k>cP3@d=00d];B0=?C
d`3EeMD0e]KF0=[JfP3Lg=`0g]kN0=oOg`3QhN40hn?S0>OWi`3YjNT0j^[Z0>_[j`3]kNd0kno_0?3`
l03alO40l_;b0??cl`3dm?@0mOGe0`3dm?@06P3clo<0kno_0>c/k03YjNT0i>CT0=oOg`3EeMD0c/k>
0<S8b033`l<0_[jn0;Vi^@2`/;00[:b/0:VYZ@2VYZH0Xj>S09bLW02IVIT0UYJF09>CT`2@T900SHf=
08V9R@25QHD0Ph>30P21PH403P23Ph<0Q8B408J6QP28R8P0RXZ:092@T02CTi<0UYJF09VIV@2MWId0
X:2P0:JVYP2YZJT0[Jf]8P3oool00200oooo01P0KVi^071`L01eMGD0N7Qh07YjNP1lO7`0OWin0861
P@26QXH0R8R808Z:RP2<S8`0Shn?09>CT`2EUID0V9RH09ZJVP2LW9`0X:2P0::RXP2TY:@0YZJV0:RX
Z02ZZZX20:j^[P0C0:f][@2ZZZX0YjNW09bLW02HV9P0TY:B08b<S025QHD0Ogmo06e]K@1UIFD0G5aL
05mOG`1RHV80IVIV06QXJ01ZJVX0Jf][06a/K00406i^KP0K06e]K@1/K6`0JFUY06QXJ01UIFD0Hf=S
065QH@1NGUh0G5aL05YJFP1HF5P0EEEE05=CD`1>CTh0Bd];04U9B@15ADD0@D5103Xj>P0f=SH0<c<c
02l_;`0[:b/09RHV02DU9@0T92@08R8R00808B4Q00H092@T02HV9P0X:2P09RHV028R8P0N7Qh201dM
7@0301hN7P0O7al0820P0080820P01408b<S02HV9P0Y:BT0<30`03<c<`0g=cL0>SXj03hn?P15ADD0
BDU904e=C@1ADE40EEEE05UIF@1PH600I6AT06QXJ00N0?ooo`0c09ZJVP2MWId0Xj>S0:JVYP2YZJT0
[:b/0:n_[`2b/[80^KVi0;bl_02o_kl0`/;20<K6aP3<c<`0clo?0=?Cd`3Fe]H0fMWI0>3Ph03Shn<0
inOW0>[ZjP3^k^h0lO7a0?Shn03inOT0moOg0??cl`3_knl0h^;R0=cLg03De=@0c/k>0<O7a`2o_kl0
Zj^[0::RXP2IVIT0W9bL09jNWP2TY:@0YZJV0:VYZ@2[Zj/0[Jf]0;2`/02b/[80/k>c0;Bd]02e]KD0
][Jf0080]kNg0`2f][H20;Fe]@0K0;Bd]02c/k<0/k>c0;6a/@2][Jd0Zj^[0:VYZ@2VYZH0XZ:R09VI
V@2DU9@0Shn?08^;R`24Q8@0N7Qh07=cL`1_Kfl0Jf][06MWI`1TI6@0HF5Q05mOG`1NGUh0FUYJ05IF
EP1@D500CTi>0080C4a<01D0Bd];04U9B@15ADD0@d=304A4A015ADD0B4Q804m?C`1BDU80EUIF05YJ
FP1OGel0J6QX06a/K01aLG40MWIf07YjNP1oOgl0R8R808f=S@2BTY807P3oool0?@2b/[80];Bd0;Vi
^@2k^k/0_Kfm0<30`032`/80a<C40<W9b@3;bl/0c/k>0=3@d03Cdm<0f=SH0=_Kf`3Ng]h0h>3P0>?S
h`3YjNT0k>c/0>o_k`3bl_80mOGe0?Shn03no_h0oooo0?knoP3lo?`0n?Sh0?3`l03[jn/0i^KV0>;R
hP3Ng]h0fMWI0<c<c038b<P0a<C40<G5a@36a/H0bLW90<_;b`3=cLd0clo?0=7Ad@3De=@0e]KF0=SH
f03Jf]X0g=cL0=kNgP3Rh^80i>CT0>KViP3Xj>P0jNWY0>c/k03]kNd0k^k^0>o_k`3`l?000P3alO40
;@3`l?00kno_0>k^kP3/k>`0i^KV0>;RhP3Ogml0g=cL0=OGe`39bLT0`/;20;fm_@2i^KT0]KFe0;6a
/@2XZ:P0Y:BT0:2PX02MWId0VYZJ09FEU@2CTi<0T92@08j>SP2<S8`0RXZ:08:2PP1oOgl0OWin07em
O@1nOWh0PH6108>3P`25QHD0QhN708^;R`2@T900Ti>C09NGU`2JVYX0WIfM0:2PX02VYZH0ZJVY0:f]
[@0R0?ooo`00803oool0601^KVh0LG5a07IfMP1hN7P0NWYj07emO@1oOgl0PH6108J6QP29RHT0Rh^;
08f=S@2?Shl0U9BD09JFUP2IVIT0VYZJ09fMW@2QXJ40Xj>S0:FUY@2XZ:P0ZZZZ0:b/[080[jn_01<0
[Jf]0:ZZZP2WYjL0WIfM09RHV02BTY80SXj>08N7Q`21PH40LG5a06UYJ@1PH600I6AT06IVIP1[Jf/0
KFe]06i^KP1`L700LG5a0080LW9b0P1cLg<09`1bLW80L71`06e]K@1/K6`0JVYZ06MWI`1UIFD0HF5Q
05mOG`1MGEd0Fe]K05QHF01FEUH0D51@04e=C@1<C4`0B4Q804=3@`0l?3`0=cLg03<c<`0`<300;2`/
02HV9P0U9BD08b<S028R8P0P82007alO02<S8`0T92@09RHV02DU9@0S8b<07QhN01dM7@0L71`07AdM
01hN7P0201lO7`0B020P800R8R809BDU02PX:00_;bl0<c<c03Hf=P0j>SX0?Shn04E5A@19BDT0CDe=
055AD@1EEED0FEUI061PH01TI6@0J6QX7P3oool0602JVYX0WIfM0:>SX`2WYjL0ZZZZ0:f][@2`/;00
/k>c0;Zj^P2m_Kd0`<300<C4a037alL0c/k>0=7Ad@3De=@0emOG0=_Kf`3Rh^80iNGU0>WYj@3/k>`0
l?3`0??cl`80nOWi01P0moOg0??cl`3^k^h0hN7Q0=_Kf`3Cdm<0cLg=0<G5a@2l_;`0ZJVY0:6QX@2H
V9P0W9bL09jNWP2TY:@0YjNW0:VYZ@2[Zj/0[Jf]0;6a/@2b/[80];Bd0;Fe]@2f][H20;Ng]`040;Rh
^02g]kL0]kNg0;Ng]`80][Jf01/0]KFe0;Bd]02c/k<0/K6a0:f][@2ZZZX0Z:RX0:FUY@2OWil0UiNG
09:BTP2=SHd0R8R80861P@1cLg<0L71`06a/K01XJ6P0I6AT065QH@1MGEd0G5aL05]KF`1HF5P0E5AD
04i>CP1<C4`00P19BDT05@18B4P0ATI60492@P10@400@T9204A4A017AdL0CTi>055AD@1FEUH0FUYJ
05mOG`1WIfL0K6a/075aL@1fMWH0NWYj07moO`28R8P0SHf=09:BTP0N0?ooo`0H0;:b/P2d];@0^KVi
0;^k^`2n_[h0`<300<;2`P34a<@0b/[:0<c<c03?cll0dM7A0=CDe03Jf]X0g=cL0=oOg`3Rh^80iNGU
0>[ZjP3^k^h0lO7a0??cl`3gmoL0n_[j0P3oool08P3moOd0no_k0?Ogm`3]kNd0j>SX0>?Sh`3Ogml0
fMWI0=?Cd`36a/H0`/;20;jn_P30`<00`L710<G5a@37alL0bLW90<_;b`3<c<`0d=3@0=;BdP3De=@0
e]KF0=WIf@3Kfm/0gmoO0>7Qh@3Shn<0iNGU0>KViP3Zj^X0jn_[0>c/k03]kNd20>k^kP0^0>g]k@3/
k>`0jn_[0>[ZjP3WinL0hN7Q0=kNgP3Kfm/0e]KF0<o?c`31`L40_Kfm0;Zj^P2f][H0/[:b0:f][@2T
Y:@0X:2P09jNWP2JVYX0UYJF09:BTP2@T900SHf=08b<S029RHT0QXJ607moO`1lO7`0Ng]k07alO01n
OWh0PH6108:2PP25QHD0QhN708Z:RP2@T900U9BD09NGU`2JVYX0WIfM0:2PX02VYZH0ZZZZ0:f][B80
oooo000P0?ooo`0]06i^KP1aLG40MWIf07QhN01kNg/0OGem07moO`22PX80QhN708V9R@2<S8`0SXj>
096AT@2EUID0UiNG09VIV@2KVi/0WYjN0:>SX`2UYJD0YjNW0:VYZ@2[Zj/0[Jf]0;2`/02_[jl0[Zj^
0:ZZZP2WYjL0WYjN09VIV@2DU9@0Shn?08V9R@23Ph<0MGEe06e]K@1UIFD0JFUY06][J`1`L700LW9b
07=cL`1dM7@0MGEe0080MgMg0P1hN7P05`1gMgL0MWIf07=cL`1aLG40Kfm_06a/K01ZJVX0IFEU06=S
H`1PH600GUiN05aLG01IFET0De=C04m?C`1>CTh0BTY:04E5A@0n?Sh0>CTi03De=@0a<C40;Rh^0080
9RHV00H092@T028R8P0P82007QhN024Q8@0S8b<202@T9004028R8P0M7Ad071`L01`L70807AdM0P0N
7Qh04P0O7al08B4Q02DU9@0X:2P0;bl_038b<P0f=SH0>SXj03hn?P15ADD0BDU904e=C@1ADE40EEEE
05UIF@1PH600I6AT06QXJ1h0oooo0340VYZJ09fMW@2TY:@0YjNW0:ZZZP2][Jd0/K6a0;Bd]02k^k/0
_[jn0<71`@35aLD0b<S80<o?c`3Bd]80e]KF0=WIf@3Lg=`0i>CT0>OWi`3[jn/0k^k^0?;blP3emOD0
n_[j0?Win@3gmoL0l_;b0>g]k@3Ph>00fMWI0=;BdP3;bl/0`/;20;Vi^@2XZ:P0X:2P09RHV02KVi/0
WYjN0:BTY02WYjL0ZJVY0:^[Z`2][Jd0/K6a0;:b/P2d];@0]KFe0080]kNg102h^;P07P2g]kL0][Jf
0;Jf]P2e]KD0];Bd0;>c/`2a/K40[:b/0:VYZ@2WYjL0Xj>S09fMW@2EUID0T92@08Z:RP23Ph<0O7al
071`L01]KFd0JFUY06EUI@1QHF40GEeM05YJFP1IFET0F5QH05EEE@1BDU80C4a<04U9B@80AdM701D0
ADE504=3@`0o?cl0?Shn0410@013@d<0ATI604e=C@1ADE40EEEE05YJFP1NGUh0IfMW06a/K01aLG40
MWIf07YjNP1oOgl0R8R808f=S@2BTY807P3oool0602b/[80]KFe0;Zj^P2l_;`0_[jn0<71`@33`l<0
aLG50<_;b`3=cLd0d=3@0=;BdP3EeMD0fm_K0=gMg@3Ph>00hn?S0>KViP3/k>`0kno_0?;blP3emOD0
n?Sh0?_kn`80oooo0240oOgm0?Win@3emOD0j^[Z0>GUi@3Ph>00fm_K0=CDe03=cLd0`<300;bl_02i
^KT0^[Zj0;bl_030`<00`l?30<G5a@36a/H0b<S80<c<c03>c/h0d=3@0=;BdP3De=@0e]KF0=_Kf`3M
gMd0gmoO0>7Qh@3Shn<0i^KV0>SXj03YjNT00P3Zj^X07@3[jn/0j^[Z0>SXj03WinL0iNGU0>7Qh@3L
g=`0fMWI0=CDe03>c/h0alO70;bl_02h^;P0];Bd0;6a/@2][Jd0ZJVY0:6QX@2NWYh0Vi^K09NGU`2D
U9@0T92@08f=S@2:RXX0R8R808F5Q@22PX80O7al0080NWYj0100Ng]k07emO@20P800PX:208F5Q@27
QhL0RXZ:092@T02DU9@0UiNG09ZJVP2MWId0X:2P0:JVYP2YZJT0[Jf]8P3oool00200oooo02/0KVi^
075aL@1fMWH0N7Qh07]kN`1nOWh0P82008>3P`27QhL0RXZ:08b<S02?Shl0TI6A09JFUP2HV9P0Vi^K
09fMW@2OWil0Y:BT0:JVYP2XZ:P0ZZZZ0:b/[02_[jl0/K6a0;2`/02^[Zh0ZZZZ0:NWY`2NWYh0Vi^K
09FEU@2ATI40RXZ:08F5Q@1hN7P0LW9b06a/K01^KVh0LG5a07EeM@1fMWH0N7Qh0080NGUi0P1kNg/0
8@1lO7`0OGem07emO@1mOGd0NGUi07MgM`1dM7@0LW9b06m_K`1ZJVX0IfMW06EUI@1RHV80H61P05eM
G@1EEED0DU9B055AD@1=CDd0B4Q80451@@0l?3`0=cLg038b<P0_;bl09bLW02HV9P0T92@08R8R020P
800M7Ad07alO028R8P0202@T9004028R8P0M7Ad06QXJ01/K6`<071`L01<07AdM01hN7P0Q8B4092@T
02PX:00^;Rh0<S8b03Hf=P0j>SX0?Cdm04E5A@19BDT0CDe=051@D01DE5@0F5QH061PH01TI6@0J6QX
01h0oooo03<0VYZJ09fMW@2TY:@0YjNW0:ZZZP2^[Zh0/K6a0;Fe]@2l_;`0_kno0<;2`P36a/H0bLW9
0=3@d03De=@0emOG0=_Kf`3Ng]h0iNGU0>WYj@3]kNd0l?3`0??cl`3gmoL0n_[j0?Win@3fm_H0l?3`
0>_[j`3MgMd0emOG0=3@d039bLT0_kno0;Jf]P2VYZH0WYjN09RHV02KVi/0WinO0:FUY@2WYjL0ZZZZ
0:b/[02^[Zh0/K6a0;>c/`2d];@0][Jf0;Ng]`2h^;P00`2i^KT20;Rh^00F0;Ng]`2f][H0]KFe0;Bd
]02c/k<0/K6a0:^[Z`2XZ:P0YZJV0:6QX@2KVi/0U9BD08f=S@26QXH0OWin07UiN@1]KFd0JVYZ06MW
I`1SHf<0GemO05YJFP80EUIF01`0EEEE05=CD`1ADE40BTY:04I6AP15ADD0A4A40492@P10@400?Cdm
03`l?00o?cl0@d=304E5A@1=CDd0DE5A05EEE@1JFUX0GUiN06MWI`1/K6`0LG5a07EeM@1jNWX0Ogmo
08R8R02=SHd0TY:B7P3oool0>`2c/k<0]KFe0;Zj^P2l_;`0_[jn0<71`@33`l<0a/K60<_;b`3>c/h0
dM7A0=?Cd`3Fe]H0fm_K0=kNgP3QhN40i>CT0>OWi`3]kNd0l?3`0?Cdm03gmoL0nOWi0?clo03oool0
o_kn0?_kn`3gmoL0l_;b0>KViP3QhN40fm_K0=KFeP3>c/h0a/K60;Zj^P2e]KD0/[:b0;Bd]02g]kL0
_;bl0;no_`31`L40`l?30<G5a@39bLT0b/[:0<c<c03=cLd0clo?0=7Ad@3Fe]H0f=SH0=[JfP3Lg=`0
gmoO0>?Sh`3Ti>@0iNGU00<0i^KV02h0iNGU0>CTi03Rh^80g]kN0=[JfP3Fe]H0d];B0<g=c@35aLD0
`<300;Ng]`2d];@0/;2`0:f][@2YZJT0YJFU09jNWP2JVYX0UYJF09BDU02BTY80SXj>08^;R`28R8P0
QXJ608:2PP1oOgl0NWYj07QhN01iNGT0Ng]k07alO01oOgl0PX:208F5Q@28R8P0Rh^;096AT@2DU9@0
UiNG09ZJVP2MWId0X:2P0:JVYP2ZZZX0[Jf]8P3oool00200oooo02d0KVi^075aL@1fMWH0NGUi07]k
N`1nOWh0P82008>3P`28R8P0Rh^;08f=S@2@T900TY:B09NGU`2IVIT0W9bL09jNWP2PX:00YJFU0:NW
Y`2YZJT0Zj^[0:j^[P2`/;00/K6a0;2`/02^[Zh0ZZZZ0:NWY`2NWYh0Vi^K09JFUP2BTY80Rh^;08N7
Q`1lO7`0MWIf07=cL`1dM7@0MGEe07QhN01iNGT0NWYj07]kN`1lO7`00P1nOWh07P1oOgl0P8200820
P021PH40P82007inOP1kNg/0N7Qh07IfMP1`L700KFe]06UYJ@1WIfL0I6AT065QH@1IFET0E5AD05=C
D`1@D500C4a<04E5A@0o?cl0>CTi03<c<`0a<C40:2PX02HV9P0U9BD08b<S020P80807AdM00L0820P
028R8P0S8b<08R8R01dM7@0J6QX06ATI00<06QXJ01<06a/K01`L700P82008b<S02HV9P0^;Rh0<S8b
03De=@0i>CT0?Cdm04E5A@19BDT0C4a<051@D01DE5@0F5QH061PH01TI6@0J6QX01h0oooo03D0VYZJ
09fMW@2TY:@0Z:RX0:^[Z`2_[jl0/[:b0;Fe]@2l_;`0`<300<C4a037alL0b/[:0=;BdP3EeMD0fMWI
0=cLg03Ogml0inOW0>_[j`3^k^h0l_;b0?Gem@3inOT0n_[j0?Shn03dm?@0kno_0>WYj@3Kfm/0eMGE
0<g=c@36a/H0^k^k0;>c/`2SXj<0Vi^K09VIV@2LW9`0X:2P0:JVYP2XZ:P0Zj^[0:f][@2_[jl0/[:b
0;>c/`2e]KD0][Jf0;Ng]`2h^;P0^KVi0;Zj^P030;Vi^@80]kNg01D0]KFe0;Bd]02b/[80/K6a0:ZZ
ZP2VYZH0Xj>S09jNWP2IVIT0TI6A08Z:RP22PX80NWYj07IfMP1ZJVX0IfMW06ATI01PH600G5aL05MG
E`1CDe<00P1BDU80201ADE40Cdm?04Q8B014A4@0@d=30451@@0o?cl0?Cdm0P0k>c/04@0o?cl0@T92
04E5A@1<C4`0DE5A05EEE@1JFUX0GUiN06MWI`1/K6`0LG5a07EeM@1jNWX0Ogmo08R8R02=SHd0TY:B
01h0oooo03`0/[:b0;Fe]@2j^[X0_;bl0;jn_P31`L40a<C40<K6aP3<c<`0c/k>0=7Ad@3De=@0emOG
0=gMg@3Ogml0h^;R0>GUi@3Xj>P0k^k^0?;blP3emOD0n?Sh0?[jnP3no_h0oooo0?gmo@3inOT0m?Cd
0?3`l03Ti>@0gMgM0=OGe`3@d=00a/K60;no_`2b/[80[Jf]0:b/[02`/;00];Bd0;^k^`2m_Kd0`<30
0<71`@33`l<0a/K60<S8b039bLT0bl_;0<c<c03=cLd0clo?0=;BdP3De=@0emOG0=WIf@3MgMd0gmoO
0>3Ph03QhN420>;RhP0K0>7Qh@3Ogml0g=cL0=OGe`3Cdm<0clo?0<_;b`35aLD0_kno0;Zj^P2b/[80
[jn_0:b/[02XZ:P0YJFU0:6QX@2KVi/0UiNG09BDU02BTY80T92@08Z:RP28R8P0QXJ608>3P`1oOgl0
O7al0080N7Qh0140NGUi07]kN`1lO7`0Ogmo08:2PP25QHD0R8R808^;R`2ATI40U9BD09NGU`2JVYX0
WIfM0:2PX02VYZH0ZJVY0:b/[00R0?ooo`00803oool09@1^KVh0LG5a07IfMP1iNGT0O7al07inOP21
PH40Ph>308V9R@2;Rh/0SXj>092@T02CTi<0V9RH09ZJVP2MWId0WinO0:6QX@2VYZH0Z:RX0:^[Z`2]
[Jd0[jn_0;:b/P2a/K40/;2`0:f][@2ZZZX0YjNW09nOW`2JVYX0UiNG09:BTP2<S8`0R8R80820P01l
O7`00`1iNGT01@1jNWX0Ng]k07alO01mOGd0OWin0080P82000@0PH6108:2PP23Ph<0Ph>30P24Q8@0
7022PX80P82007alO01eMGD0LW9b06m_K`1[Jf/0J6QX06EUI@1LG5`0EUIF05=CD`1BDU80CTi>04Q8
B012@T80>SXj03@d=00b<S80:BTY02LW9`0V9RH08b<S024Q8@0N7Qh071`L01hN7P0P8202028R8P04
01`L700I6AT061PH01PH60806ATI01<06QXJ01`L700O7al08R8R02HV9P0];Bd0<S8b03De=@0i>CT0
?Cdm04E5A@19BDT0C4a<051@D01DE5@0F5QH061PH01TI6@0J6QX01h0oooo01L0VYZJ09jNWP2TY:@0
Z:RX0:b/[02_[jl0/k>c0;Jf]P2m_Kd0`L710<G5a@38b<P0c<c<0=?Cd`3Fe]H0f][J0=kNgP3QhN40
jNWY0>c/k03`l?00lo?c0?Ogm`020?[jnP0;0?Ogm`3clo<0kNg]0>OWi`3IfMT0dM7A0<_;b`31`L40
]kNg0:n_[`2OWil00P2KVi/03P2NWYh0XZ:R0:NWY`2ZZZX0[:b/0:j^[P2_[jl0/k>c0;Bd]02e]KD0
][Jf0;Ng]`2h^;P0^KVi0`2j^[X0602i^KT0^;Rh0;Ng]`2f][H0];Bd0;>c/`2`/;00ZZZZ0:FUY@2O
Wil0Vi^K09JFUP2?Shl0R8R807moO`1gMgL0Lg=c06QXJ01TI6@0HV9R05eMG@1IFET0EEEE051@D0<0
Cdm?01X0CTi>04I6AP12@T80@D5103hn?P0l?3`0>c/k03Ph>00j>SX0?Shn0410@014A4@0C4a<051@
D01EEED0FUYJ05iNGP1WIfL0K6a/075aL@1eMGD0NWYj07moO`28R8P0SHf=09:BTQh0oooo01L0/k>c
0;Fe]@2j^[X0_;bl0;no_`32`/80a<C40<O7a`3<c<`0clo?0=;BdP3EeMD0f=SH0=kNgP3Ph>00hn?S
0>KViP3YjNT0l?3`0??cl`3fm_H0nOWi0?clo0020?knoP0H0?_kn`3gmoL0l_;b0>c/k03Ogml0fMWI
0=;BdP39bLT0_kno0;Rh^02XZ:P0YJFU0:VYZ@2_[jl0/k>c0;Zj^P2m_Kd0_kno0<71`@33`l<0a/K6
0<O7a`38b<P0bLW90P3:b/X20<c<c00V0<k>cP3AdM40dm?C0=SHf03IfMT0fm_K0=cLg03MgMd0g]kN
0=cLg03Jf]X0e]KF0=7Ad@3=cLd0b<S80<C4a02o_kl0^KVi0;Bd]02][Jd0ZZZZ0:NWY`2SXj<0X:2P
09fMW@2GUiL0U9BD096AT@2?Shl0SXj>08R8R026QXH0Q8B40820P01mOGd0Ng]k07IfMP1gMgL207Ui
N@0?07YjNP1oOgl0PX:208F5Q@28R8P0Rh^;096AT@2DU9@0UiNG09ZJVP2MWId0X:2P0:NWY`2ZZZX0
[Jf]0280oooo000P0?ooo`0W06i^KP1aLG40MgMg07YjNP1lO7`0Ogmo08:2PP25QHD0RXZ:08f=S@2@
T900TY:B09FEU@2JVYX0W9bL09nOW`2QXJ40Y:BT0:RXZ02[Zj/0[Jf]0:n_[`2a/K40/[:b0;6a/@2_
[jl0[Jf]0:VYZ@2UYJD0WYjN09^KV`2FUYH0TI6A08f=S@29RHT0Q8B408:2PP20P800Ogmo00<0OWin
0P1oOgl02@20P800PH610861P@22PX80Q8B408F5Q@26QXH0R8R808V9R@0208Z:RP0G08V9R@24Q8@0
Ogmo07]kN`1gMgL0Lg=c06i^KP1TI6@0GEeM05EEE@1FEUH0DU9B051@D019BDT0@T9203Xj>P0e=CD0
;Rh^02XZ:P0W9bL092@T020P800N7Qh00P0J6QX0200K6a/07alO024Q8@0K6a/061PH01HF5P0E5AD0
5QHF0P0G5aL04P0J6QX07QhN028R8P0U9BD0;Bd]034a<@0e=CD0>CTi03dm?@15ADD0B4Q804a<C01@
D500E5AD05QHF01PH600I6AT06MWIah0oooo02h0VYZJ09jNWP2UYJD0ZJVY0:b/[02`/;00];Bd0;Rh
^02o_kl0`l?30<O7a`3;bl/0c/k>0=KFeP3IfMT0gMgM0>7Qh@3Ti>@0k>c/0?3`l03clo<0moOg0?[j
nP3kno/0n?Sh0?Cdm03_knl0j>SX0>7Qh@3Bd]80bl_;0<;2`P2g]kL0[jn_0:JVYP2PX:00XJ6Q0::R
XP2TY:@0YjNW0:^[Z`2][Jd0[jn_0;2`/02b/[80];Bd0P2e]KD20;Ng]`030;Rh^02i^KT0^[Zj0080
^[Zj01P0^k^k0;Vi^@2h^;P0]kNg0;Fe]@2c/k<0/;2`0:RXZ02QXJ40VIVI09JFUP2@T900RXZ:08:2
PP1jNWX0LW9b06a/K01TI6@0H61P05eMG@1IFET0EEEE059BDP1<C4`404Y:BP0I0492@P0o?cl0?3`l
03Ti>@0h>3P0=cLg03Hf=P0h>3P0>c/k03lo?`13@d<0C4a<051@D01EEED0FEUI05iNGP1WIfL0K6a/
075aL@1eMGD0NWYj07moO`28R8P0SHf=09:BTP0N0?ooo`0]0;:b/P2e]KD0^[Zj0;fm_@30`<00`/;2
0<G5a@38b<P0c/k>0=7Ad@3De=@0emOG0=WIf@3Ogml0h^;R0>GUi@3Xj>P0jn_[0?;blP3emOD0n?Sh
0?_kn`3no_h0oooo0?_kn`3gmoL0l_;b0>c/k03UiND0emOG0<o?c`36a/H0^k^k0;>c/`2YZJT0YZJV
0:VYZ@2][Jd0/K6a0;Fe]@2l_;`0_kno0<71`@32`/80a<C400<0alO70P38b<P50<O7a`050<S8b03;
bl/0c/k>0=3@d03Bd]800P3Cdm<06`3AdM40c/k>0<[:bP35aLD0`L710;Vi^@2e]KD0/;2`0:^[Z`2X
Z:P0XZ:R0:6QX@2OWil0WIfM09^KV`2HV9P0Ti>C096AT@2>SXh0Rh^;08V9R@24Q8@0PH6107inOP1k
Ng/0NGUi07MgM`0207EeM@0A07IfMP1hN7P0NWYj07moO`22PX80QHF508R8R02;Rh/0TI6A09BDU02G
UiL0VYZJ09fMW@2PX:00YZJV0:ZZZP2][Jd08P3oool00200oooo02P0KVi^075aL@1gMgL0NWYj07em
O@20P800Ph>308F5Q@2;Rh/0SXj>096AT@2CTi<0UYJF09^KV`2MWId0X:2P0::RXP2UYJD0ZJVY0:b/
[02^[Zh0/;2`0;:b/P2c/k<0/K6a0:n_[`2/[:`0Z:RX0:BTY02MWId0VYZJ09FEU@2ATI40SXj>08Z:
RP26QXH0QHF508>3P`21PH40P820101oOgl20820P00C0861P@22PX80Q8B408F5Q@26QXH0RHV908Z:
RP2;Rh/0S8b<08f=S@2;Rh/0QhN708:2PP1nOWh0NGUi07=cL`1WIfL0H61P05IFEP0205ADE00;059B
DP1=CDd0ATI603dm?@0g=cL0;bl_02/[:`0X:2P09BDU024Q8@0N7Qh00`0I6AT06`0M7Ad0820P01/K
6`0H61P05QHF01@D500C4a<05ADE01LG5`0J6QX07AdM024Q8@0U9BD0;Bd]034a<@0e=CD0>CTi03dm
?@14A4@0B4Q804a<C01@D500E5AD05QHF01PH600I6AT06QXJ00N0?ooo`0F09ZJVP2NWYh0YJFU0:VY
Z@2][Jd0/K6a0;Fe]@2h^;P0`<300<C4a038b<P0bl_;0<o?c`3GemL0fm_K0=kNgP3Rh^80i^KV0>k^
kP3bl_80mOGe0?Shn080no_k00X0moOg0?;blP3/k>`0i^KV0=kNgP3>c/h0alO70;bl_02c/k<0ZZZZ
0P2SXj<02P2TY:@0YZJV0:NWY`2YZJT0[Jf]0:n_[`2`/;00/K6a0;>c/`2d];@20;Fe]@040;Jf]P2g
]kL0]kNg0;Rh^080^KVi0`2j^[X05`2i^KT0]kNg0;Fe]@2c/k<0/;2`0:JVYP2PX:00UiNG09:BTP2?
Shl0QhN707moO`1hN7P0L71`06a/K01TI6@0GemO05]KF`1HF5P0E5AD051@D01:BTX0B4Q80080AdM7
01X0B4Q80410@00m?Cd0>CTi03Lg=`0f=SH0=CDe03@d=00g=cL0>c/k03hn?P13@d<0Bd];051@D01E
EED0FEUI05iNGP1WIfL0K6a/071`L01eMGD0NWYj07moO`28R8P0SHf=09:BTQh0oooo01H0/k>c0;Fe
]@2k^k/0_Kfm0<30`033`l<0a/K60<W9b@3>c/h0dM7A0=CDe03GemL0f][J0>3Ph03Shn<0i^KV0>[Z
jP3]kNd0m?Cd0?Ogm`3jn_X0o?cl0P3no_h05P3inOT0mOGe0>o_k`3YjNT0hN7Q0=;BdP39bLT0_[jn
0;Bd]02[Zj/0Y:BT0:NWY`2[Zj/0[jn_0;>c/`2g]kL0_[jn0<71`@33`l<0a<C40<K6aP37alL20<S8
b0040<O7a`36a/H0a/K60<G5a@@0a<C403@0a/K60<O7a`3:b/X0c<c<0<g=c@3>c/h0c<c<0<[:bP35
aLD0`L710;fm_@2b/[80[:b/0:VYZ@2WYjL0YJFU0:6QX@2OWil0W9bL09ZJVP2HV9P0UYJF096AT@2?
Shl0S8b<08V9R@27QhL0PH6107inOP1kNg/0NWYj07QhN01fMWH0Lg=c07AdM01fMWH0N7Qh07YjNP1o
Ogl0PX:208F5Q@28R8P0Rh^;096AT@2DU9@0UiNG09ZJVP2MWId0X:2P0:NWY`2ZZZX0[Jf]8P3oool0
0200oooo02P0Kfm_075aL@1gMgL0NWYj07emO@21PH40Ph>308J6QP2<S8`0Shn?09:BTP2DU9@0UiNG
09bLW02OWil0XJ6Q0:>SX`2VYZH0Zj^[0:f][@2_[jl0/K6a0;:b/P2d];@0/;2`0:f][@2[Zj/0Z:RX
0:>SX`2LW9`0VIVI09BDU02ATI40SXj>08b<S028R8P0QhN708F5Q@24Q8@0PX:20`20P800301oOgl0
P8200820P020P800PH6108>3P`24Q8@0QXJ608Z:RP2;Rh/0SHf=08j>SP80Shn?03<0SXj>08Z:RP25
QHD0Ogmo07UiN@1/K6`0Hf=S05UIF@1CDe<0E5AD04m?C`1=CDd0B4Q80451@@0k>c/0<30`02d];@0X
:2P09BDU024Q8@0M7Ad061PH01TI6@0H61P06QXJ01hN7P0K6a/05aLG01DE5@0D51@04Q8B01<C4`0G
5aL06QXJ01dM7@0Q8B409BDU02`/;00`<300=3@d03Ph>00m?Cd0A4A404Q8B01<C4`0D51@05ADE01H
F5P0H61P06ATI01XJ6P07P3oool0;@2JVYX0WYjN0:JVYP2ZZZX0[Zj^0;:b/P2e]KD0^KVi0<71`@35
aLD0bLW90<g=c@3@d=00f=SH0=cLg03Ph>00hn?S0>OWi`3_knl0lo?c0?KfmP3inOT0no_k0?clo03e
mOD0l?3`0>[ZjP3Rh^80f][J0<[:bP31`L40][Jf0:j^[P2VYZH0Xj>S0:FUY@2WYjL0ZJVY0:ZZZP2/
[:`0[jn_0;2`/02a/K40/[:b0;Bd]0030;Fe]@80][Jf00<0]kNg0;Rh^02h^;P00P2i^KT20;Zj^P0G
0;Vi^@2h^;P0][Jf0;>c/`2`/;00YZJV09nOW`2EUID0Shn?08f=S@22PX80OWin07IfMP1`L700Jf][
069RHP1NGUh0FUYJ05IFEP1CDe<0CTi>04Q8B016ATH00`14A4@06@0o?cl0>c/k03Ph>00f=SH0<c<c
038b<P0c<c<0=cLg03Xj>P0n?Sh0@T9204];B`1@D500E5AD05UIF@1NGUh0IfMW06a/K01`L700MGEe
07YjNP1oOgl0R8R808f=S@2BTY807P3oool05P2b/[80]KFe0;^k^`2m_Kd0`<300<?3``36a/H0bLW9
0<o?c`3Bd]80eMGE0=SHf03Jf]X0hN7Q0>CTi03WinL0jn_[0>k^kP3dm?@0n?Sh0?_kn`3moOd20?kn
oP0E0?Shn03clo<0k>c/0>GUi@3Lg=`0c<c<0<;2`P2f][H0[:b/0:BTY02RXZ80ZJVY0:f][@2a/K40
]KFe0;Vi^@30`<00`/;20<C4a036a/H0alO70080bLW90P38b<P01037alL0aLG50<?3``32`/850<71
`@0<0<?3``36a/H0alO70<S8b037alL0a<C40<71`@2n_[h0^KVi0:n_[`2ZZZX0YJFU0P2QXJ40902M
WId0Vi^K09ZJVP2HV9P0UYJF09BDU02>SXh0S8b<08Z:RP28R8P0Q8B407inOP1lO7`0NGUi07QhN01f
MWH0Lg=c075aL@1cLg<0MGEe07QhN01jNWX0Ogmo08:2PP25QHD0R8R808^;R`2ATI40U9BD09NGU`2J
VYX0WIfM0:2PX02VYZH0ZJVY0:f][B80oooo000P0?ooo`0F06m_K`1bLW80N7Qh07]kN`1nOWh0PH61
08B4Q027QhL0S8b<08n?S`2BTY80UIFE09RHV02MWId0X:2P0::RXP2TY:@0YjNW0:b/[02_[jl0/;2`
0;:b/P80/k>c0140[jn_0:b/[02YZJT0YZJV0::RXP2KVi/0UiNG09>CT`2@T900Shn?08j>SP2;Rh/0
RHV908R8R026QXH0QHF508:2PP020861P@@0P82000P0PH6108:2PP23Ph<0QXJ608Z:RP2<S8`0SXj>
08n?S`<0TI6A01D0T92@08f=S@27QhL0P820075aL@1WIfL0G5aL05ADE01ADE40CDe=04a<C018B4P0
@d=303dm?@0a<C40;bl_02XZ:P0V9RH08R8R01hN7P0I6AT00P0G5aL06`0H61P06a/K01/K6`0H61P0
5QHF01<C4`0A4A404Q8B01HF5P0J6QX07AdM020P800T92@0;2`/030`<00d=3@0>3Ph03`l?015ADD0
B4Q804a<C01@D500E5AD05QHF01PH600I6AT06QXJ00N0?ooo`0F09ZJVP2NWYh0YZJV0:ZZZP2^[Zh0
/[:b0;Jf]P2j^[X0`/;20<K6aP3:b/X0c/k>0=7Ad@3IfMT0gMgM0>7Qh@3UiND0jNWY0?7al@3emOD0
n?Sh0?[jnP80no_k01<0lo?c0>g]k@3Vi^H0g]kN0=KFeP35aLD0^k^k0;6a/@2XZ:P0YJFU0:JVYP2X
Z:P0ZZZZ0:^[Z`2][Jd0[jn_0;6a/@2b/[80/k>c0080];Bd1P2e]KD0102f][H0]kNg0;Rh^02h^;P3
0;Vi^@0G0;Rh^02f][H0];Bd0;2`/02VYZH0WYjN09FEU@2=SHd0RHV907moO`1jNWX0M7Ad071`L01[
Jf/0H61P05eMG@1IFET0EUIF059BDP1=CDd0ATI604A4A012@T800P11@D406@0m?Cd0>CTi03Hf=P0d
=3@0<C4a030`<00c<c<0=SHf03Xj>P0n?Sh0@T9204];B`1@D500E5AD05UIF@1MGEd0IfMW06a/K01`
L700MGEe07YjNP1oOgl0R8R808f=S@2BTY807P3oool05@2b/[80]KFe0;^k^`2n_[h0`L710<?3``36
a/H0bLW90<o?c`3Bd]80eMGE0=SHf03Kfm/0h^;R0>GUi@3YjNT0k>c/0>o_k`3fm_H0nOWi0?clo003
0?knoP0F0?KfmP3`l?00jNWY0>7Qh@3Hf=P0a/K60;^k^`2`/;00YJFU0::RXP2TY:@0Zj^[0:n_[`2c
/k<0]kNg0;^k^`31`L40`l?30<G5a@37alL0b<S80<W9b@80b<S800@0alO70<K6aP34a<@0`L710P2o
_kl20;jn_P<0_Kfm01d0_[jn0<30`032`/80`/;20<30`02m_Kd0^[Zj0;Jf]P2/[:`0YZJV0:6QX@2O
Wil0WIfM09ZJVP2HV9P0UYJF09FEU@2CTi<0T92@08b<S02:RXX0R8R808F5Q@21PH40Ng]k07QhN01g
MgL0MWIf07AdM002079bLP0B07=cL`1eMGD0MgMg07YjNP1oOgl0PX:208F5Q@28R8P0Rh^;096AT@2D
U9@0UiNG09ZJVP2MWId0X:2P0:JVYP2YZJT0[Jf]8P3oool00200oooo02T0Kfm_079bLP1hN7P0Ng]k
07inOP21PH40Q8B408R8R02>SXh0T92@09>CT`2FUYH0VIVI09jNWP2QXJ40Xj>S0:JVYP2XZ:P0[Jf]
0;2`/02a/K40/[:b0;Bd]02c/k<0[Zj^0:b/[02XZ:P0Y:BT0:6QX@2JVYX0UYJF09>CT`2ATI40T92@
08n?S`2=SHd0S8b<08Z:RP29RHT0QhN708F5Q@0208B4Q080Ph>31022PX807P23Ph<0QHF508Z:RP2=
SHd0Shn?096AT@2CTi<0U9BD09>CT`2BTY80TI6A08f=S@26QXH0MGEe06][J`1OGel0EUIF051@D01;
Bd/0AdM704I6AP13@d<0@41003<c<`0_;bl0;2`/02PX:00S8b<07alO01PH60<05QHF00D05aLG01XJ
6P0G5aL05ADE01<C4`02014A4@0C01HF5P0I6AT07AdM020P800T92@0;2`/030`<00d=3@0>3Ph03`l
?015ADD0B4Q804a<C01@D500E5AD05QHF01PH600I6AT06QXJ00N0?ooo`0Z09ZJVP2NWYh0YZJV0:ZZ
ZP2_[jl0/[:b0;Jf]P2k^k/0`l?30<K6aP3:b/X0clo?0=?Cd`3Kfm/0gmoO0>?Sh`3Vi^H0j^[Z0?;b
lP3fm_H0nOWi0?[jnP3kno/0n_[j0?3`l03Zj^X0hn?S0=[JfP3Bd]80_kno0;Fe]@2[Zj/0YZJV0:NW
Y`2XZ:P0Zj^[0:f][@2^[Zh0/;2`0;6a/@2b/[80/k>c0P2d];@40;Fe]@<0];Bd0P2e]KD20;Ng]`0P
0;Rh^02i^KT0^;Rh0;Rh^02g]kL0]KFe0;6a/@2VYZH0WYjN09FEU@2<S8`0QHF507inOP1gMgL0Lg=c
06i^KP1ZJVX0GemO05aLG01HF5P0EEEE051@D01<C4`0ADE50492@P10@400?clo03hn?P0k>c/0>3Ph
03De=@0b<S8202l_;`0C038b<P0e=CD0>SXj03dm?@12@T80Bd];04m?C`1DE5@0FEUI05eMG@1WIfL0
Jf][071`L01eMGD0NWYj07inOP28R8P0SHf=09:BTP0N0?ooo`0E0;>c/`2f][H0^k^k0;jn_P31`L40
a<C40<K6aP39bLT0d=3@0=;BdP3Fe]H0fMWI0=cLg03Shn<0i^KV0>WYj@3]kNd0l?3`0?Ogm`3jn_X0
o?cl0080o_kn01H0o?cl0??cl`3/k>`0iNGU0=cLg03Cdm<0_[jn0;>c/`2WYjL0XJ6Q0:BTY02VYZH0
[:b/0;2`/02d];@0^;Rh0;bl_030`<00`/;20<?3``35aLD0a/K60P37alL01`36a/H0aLG50<C4a032
`/80_[jn0;fm_@2l_;`00P2k^k/40;Zj^P0`0;^k^`2m_Kd0_Kfm0;bl_02j^[X0]kNg0;>c/`2[Zj/0
YJFU0:6QX@2MWId0VIVI09NGU`2EUID0U9BD09:BTP2@T900SXj>08^;R`28R8P0QXJ608B4Q020P800
NWYj07QhN01fMWH0M7Ad079bLP1aLG40LW9b07=cL`1eMGD0MgMg07UiN@1oOgl0PX:208F5Q@27QhL0
RXZ:092@T02CTi<0UYJF09ZJVP2MWId0X:2P0:JVYP2ZZZX0[Jf]8P3oool00200oooo01<0Kfm_079b
LP1iNGT0O7al07moO`22PX80QHF508V9R@2?Shl0TY:B09FEU@2HV9P0Vi^K0:6QX@2TY:@0YZJV0:VY
Z@2[Zj/0/;2`0080/[:b00X0/k>c0;:b/P2a/K40Zj^[0:NWY`2UYJD0XJ6Q09jNWP2FUYH0Ti>C0P2B
TY8409>CT`06096AT@2@T900Shn?08n?S`2>SXh0SHf=0P2<S8`02`2;Rh/0RXZ:08V9R@28R8P0QhN7
08J6QP2;Rh/0SXj>096AT@2DU9@0UYJF00<0V9RH01H0UiNG09FEU@2CTi<0PX:207IfMP1XJ6P0Fe]K
055AD@19BDT0ATI603lo?`0n?Sh0>SXj03Hf=P0b<S80;Rh^02XZ:P0U9BD0820P01LG5`0E5AD04a<C
0P0B4Q80100F5QH051@D018B4P0@410200h>3P0C01DE5@0H61P071`L01lO7`0T92@0;2`/030`<00d
=3@0>3Ph03`l?014A4@0B4Q804a<C01@D500E5AD05QHF01PH600I6AT06QXJ00N0?ooo`0D09^KV`2O
Wil0YjNW0:^[Z`2_[jl0/k>c0;Rh^02l_;`0a<C40<S8b03=cLd0dM7A0=GEe@3MgMd0h^;R0>GUi@3Z
j^X0k^k^0?KfmP3inOT30?_kn`0@0?Ogm`3Zj^X0h^;R0=_Kf`3AdM40b<S80;Bd]02ZZZX0YZJV0:RX
Z02ZZZX0Zj^[0:n_[`2b/[80/k>c0;Bd]080/k>c102d];@02`2e]KD0];Bd0;>c/`2b/[80/K6a0;2`
/02a/K40/[:b0;Bd]02e]KD0][Jf00<0]kNg01L0][Jf0;Bd]02b/[80Z:RX09nOW`2FUYH0S8b<08B4
Q01iNGT0MGEe06m_K`1/K6`0IVIV05mOG`1JFUX0EUIF05=CD`1?Cdl0BTY:0492@P10@400?3`l03Xj
>P0203Ph>00H03De=@0b<S80;bl_02`/;00[:b/0<C4a03De=@0i>CT0?3`l0451@@1:BTX0Cdm?05AD
E01HF5P0GEeM06MWI`1[Jf/0L71`07EeM@1jNWX0OWin08R8R02=SHd0TY:B7P3oool09P2c/k<0][Jf
0;bl_02n_[h0`L710<C4a037alL0b/[:0=7Ad@3De=@0emOG0=[JfP3Ng]h0i>CT0>SXj03[jn/0k^k^
0?;blP3inOT0o?cl0?knoP3oool0o_kn0?[jnP3]kNd0iNGU0=cLg03Bd]80b<S80;6a/@2UYJD0XJ6Q
0:BTY02UYJD0YjNW0:f][@2b/[80]KFe0`2f][H0102i^KT0^[Zj0;^k^`2k^k/20;fm_@<0_;bl00<0
^k^k0;Rh^02f][H00P2e]KD30;Bd]080/k>c00h0/[:b0;6a/@2c/k<0/k>c0;:b/P2a/K40/;2`0:NW
Y`2TY:@0XJ6Q09jNWP2JVYX0TY:B092@T080Shn?0200SHf=08Z:RP28R8P0QXJ608>3P`21PH40OWin
07UiN@1gMgL0MGEe079bLP1`L700KVi^071`L01bLW80M7Ad07IfMP1iNGT0Ogmo0861P@24Q8@0QhN7
08Z:RP2@T900Ti>C09JFUP2JVYX0WIfM0:2PX02VYZH0ZJVY0:f][B80oooo000P0?ooo`0C06m_K`1b
LW80NGUi07alO020P800Ph>308J6QP29RHT0T92@09>CT`2FUYH0VIVI09bLW02RXZ80YJFU0:NWY`2Z
ZZX0[Jf]0;6a/@030;:b/P0:0;6a/@2`/;00Z:RX0:FUY@2RXZ80WinO09ZJVP2DU9@0TI6A09>CT`80
U9BD00P0UIFE09NGU`2HV9P0UYJF09FEU@2CTi<0T92@096AT@80T92@00`0Shn?08j>SP2=SHd0S8b<
08f=S@2<S8`0RXZ:08f=S@2@T900Ti>C09JFUP2HV9P309ZJVP0F09VIV@2GUiL0UIFE08Z:RP1lO7`0
KVi^05mOG`1EEED0ATI604A4A00n?Sh0>c/k03Ph>00d=3@0<c<c02h^;P0Z:RX09RHV024Q8@0G5aL0
51@D018B4P80410@00@05ADE01@D500A4A403`l?0P0=3@d04`0D51@061PH01`L700O7al08b<S02`/
;00`<300=3@d03Ph>00l?3`0A4A404Q8B01<C4`0D51@05ADE01HF5P0H61P06ATI01XJ6P07P3oool0
502KVi/0WinO0:NWY`2/[:`0/;2`0;Bd]02h^;P0_Kfm0<G5a@39bLT0c/k>0=;BdP3Fe]H0gmoO0>?S
h`3WinL0jn_[0>o_k`3hn?P0n_[j0P3lo?`03P3inOT0m?Cd0>KViP3Ng]h0e]KF0<g=c@33`l<0[Zj^
0:NWY`2XZ:P0ZJVY0:^[Z`2/[:`0/K6a0P2d];@30;>c/`<0];Bd00<0]KFe0;Bd]02c/k<00P2a/K40
202`/;00[jn_0:n_[`2`/;00/[:b0;Bd]02e]KD0]kNg0P2f][H05`2e]KD0/k>c0;6a/@2YZJT0XJ6Q
09RHV02<S8`0Q8B407QhN01dM7@0KVi^06YZJP1UIFD0G5aL05YJFP1FEUH0De=C04i>CP1:BTX0@D51
03hn?P0k>c/0>3Ph0080=SHf01P0<c<c030`<00];Bd0:b/[02XZ:P0`<300=3@d03Ph>00l?3`0@D51
04Y:BP1?Cdl0De=C05QHF01MGEd0IVIV06][J`1`L700MGEe07YjNP1nOWh0R8R808f=S@2BTY8N0?oo
o`0D0;>c/`2f][H0_;bl0;no_`32`/80aLG50<S8b03;bl/0dM7A0=CDe03GemL0fm_K0=kNgP3UiND0
j>SX0>c/k03_knl0lo?c0?_kn`3no_h20?ooo`080?gmo@3hn?P0j^[Z0>7Qh@3GemL0cLg=0<;2`P2Z
ZZX30:>SX`040:FUY@2WYjL0[:b/0:n_[`80/K6a00T0/[:b0;Jf]P2f][H0][Jf0;Rh^02j^[X0^KVi
0;Rh^02g]kL00`2f][H00`2c/k<0/[:b0;:b/P040;6a/@80/;2`0100[jn_0:j^[P2^[Zh0[Zj^0:n_
[`2^[Zh0[:b/0:RXZ02UYJD0XJ6Q09jNWP2JVYX0TY:B08n?S`2>SXh0S8b<0P2:RXX07P26QXH0Q8B4
08:2PP20P800OGem07QhN01eMGD0LW9b071`L01_Kfl0KFe]071`L01bLW80M7Ad07IfMP1iNGT0OWin
0861P@24Q8@0QhN708Z:RP2@T900Ti>C09JFUP2IVIT0W9bL0:2PX02VYZH0ZJVY0:f][B80oooo000P
0?ooo`0C06m_K`1bLW80NGUi07emO@20P800Ph>308N7Q`2:RXX0TI6A09BDU02GUiL0VYZJ09fMW@2T
Y:@0YZJV0:VYZ@2[Zj/0[Zj^0;>c/`020;Bd]0080;>c/`2a/K40[Zj^0:NWY`2TY:@0X:2P09bLW02I
VIT209:BTP0:09>CT`2DU9@0UYJF09NGU`2JVYX0W9bL09^KV`2IVIT0V9RH09NGU`80UYJF00d0UiNG
09JFUP2DU9@0Ti>C096AT@2@T900TI6A092@T02>SXh0TI6A09FEU@2GUiL0VIVI0080W9bL01L0Vi^K
09ZJVP2IVIT0UiNG08j>SP23Ph<0M7Ad06ATI01GEeL0ADE50492@P0n?Sh0=cLg03De=@0^;Rh0<30`
02l_;`0[:b/09RHV024Q8@0G5aL051@D014A4@0200h>3P804a<C01L04A4A00l?3`0=3@d030`<01@D
500G5aL06a/K01lO7`0S8b<0;2`/030`<00d=3@0>3Ph03`l?014A4@0B4Q804a<C01@D500E5AD05QH
F01PH600I6AT06QXJ00N0?ooo`0T09^KV`2OWil0YjNW0:b/[02`/;00];Bd0;Vi^@2m_Kd0a/K60<[:
bP3?cll0dm?C0=OGe`3Ph>00i>CT0>SXj03]kNd0lO7a0?Win@3kno/0o?cl0?_kn`3gmoL0l_;b0>;R
hP3Jf]X0dM7A0<O7a`2l_;`0Z:RX0:NWY`2XZ:P0ZZZZ0:^[Z`2][Jd0/[:b0P2d];@00`2c/k<0/[:b
0;>c/`020;>c/`80];Bd00/0/[:b0;6a/@2`/;00/;2`0:n_[`2^[Zh0[Jf]0:n_[`2a/K40/k>c0;Bd
]0020;Jf]P0M0;Fe]@2d];@0/k>c0;6a/@2ZZZX0Xj>S09ZJVP2>SXh0Q8B407IfMP1bLW80KVi^06QX
J01UIFD0FUYJ05QHF01FEUH0DE5A04i>CP19BDT0@41003dm?@0j>SX0=SHf03@d=00c<c<0<S8b02h^
;P0/;2`00P0Y:BT04`0`<300=3@d03Ph>00l?3`0@41004Y:BP1?Cdl0De=C05QHF01MGEd0IVIV06][
J`1`L700MGEe07YjNP1oOgl0R8R808f=S@2BTY807P3oool07`2c/k<0][Jf0;bl_02o_kl0`/;20<G5
a@38b<P0bl_;0=7Ad@3De=@0emOG0=_Kf`3Ng]h0iNGU0>WYj@3/k>`0l?3`0?Cdm03kno/0o_kn0?oo
o`3moOd0n_[j0?Gem@3UiND0g=cL0=;BdP37alL0^k^k0:BTY02QXJ400P2SXj<00`2TY:@0YZJV0:ZZ
ZP020:b/[080[Jf]00@0[Zj^0:n_[`2`/;00/;2`0P2a/K400`2`/;00/K6a0;2`/0030:n_[`L0[Zj^
00@0[Jf]0:b/[02/[:`0Zj^[0P2/[:`20:ZZZP0Y0:NWY`2SXj<0XZ:R09nOW`2LW9`0U9BD08n?S`2<
S8`0RXZ:08V9R@28R8P0Q8B408>3P`21PH40OWin07]kN`1fMWH0Lg=c071`L01_Kfl0KFe]06a/K01`
L700LW9b07=cL`1fMWH0N7Qh07inOP21PH40Q8B408N7Q`2:RXX0T92@09>CT`2FUYH0VIVI09fMW@2P
X:00YZJV0:VYZ@2][Jd08P3oool00200oooo01<0Kfm_079bLP1iNGT0OGem0861P@24Q8@0R8R808^;
R`2BTY80UIFE09VIV@2LW9`0WinO0:FUY@2XZ:P0ZZZZ0:f][@2_[jl0];Bd0080]KFe00l0/[:b0;2`
/02][Jd0YJFU0:6QX@2NWYh0VYZJ09JFUP2ATI40TY:B09>CT`2EUID0UiNG09VIV@2OWil00P2SXj<0
0`2RXZ80XJ6Q0:2PX00209nOW`80X:2P02P0WYjN09bLW02KVi/0VYZJ09^KV`2JVYX0UiNG09JFUP2H
V9P0VYZJ09^KV`2MWId0WYjN09fMW@2LW9`0VYZJ09VIV@2ATI40RHV907YjNP1YJFT0FUYJ04I6AP10
@400?Shn03Lg=`0b<S80:BTY02XZ:P0/;2`0:b/[02HV9P0R8R8061PH01@D500A4A403@d=00`<300?
3`l04A4A0P0>3Ph05@0<30`03@d=01<C4`0G5aL06a/K01lO7`0S8b<0;2`/030`<00d=3@0>3Ph03`l
?014A4@0B4Q804a<C01@D500E5AD05QHF01PH600I6AT06QXJ00N0?ooo`0C09^KV`2OWil0Z:RX0:b/
[02a/K40]KFe0;Vi^@2n_[h0alO70<_;b`3?cll0e=CD0=SHf03QhN40i^KV0>[ZjP3^k^h0lo?c0?[j
nP020?clo0090?Win@3emOD0kno_0=kNgP3EeMD0bl_;0<71`@2f][H0YjNW0080Z:RX00@0ZZZZ0:^[
Z`2][Jd0/;2`0P2c/k<50;6a/@80/[:b00<0/;2`0:n_[`2^[Zh0102/[:`0102^[Zh0/;2`0;:b/P2d
];@30;Fe]@0H0;Bd]02b/[80/K6a0:^[Z`2UYJD0Vi^K092@T025QHD0MWIf075aL@1^KVh0J6QX06=S
H`1HF5P0EUIF05ADE01BDU80CDe=04Q8B00o?cl0?3`l03Ph>00d=3@0<S8b0P0`<3005`0];Bd0:b/[
02PX:00X:2P0<30`03<c<`0g=cL0>c/k0410@01:BTX0CTi>05=CD`1HF5P0GEeM06IVIP1[Jf/0L71`
07EeM@1jNWX0OWin08R8R02=SHd0TY:B01h0oooo01<0/k>c0;Jf]P2l_;`0_kno0<;2`P35aLD0b<S8
0<_;b`3AdM40e=CD0=SHf03Kfm/0g]kN0>KViP3YjNT0kNg]0?7al@3emOD0o?cl0080o_kn00T0o?cl
0?Shn03bl_80h>3P0=OGe`3<c<`0`<300;Fe]@2RXZ80102SXj<01`2TY:@0XZ:R0::RXP2RXZ80XJ6Q
0::RXP2SXj<00P2TY:@20:FUY@040:>SX`2TY:@0Xj>S0::RXP80XJ6Q00@0Y:BT0:RXZ02ZZZX0Zj^[
0P2/[:`30:^[Z`80ZZZZ00<0ZJVY0:RXZ02XZ:P00P2XZ:P0502UYJD0Y:BT0:6QX@2OWil0WIfM09JF
UP2ATI40SHf=08Z:RP28R8P0QXJ608>3P`21PH40Ogmo07alO01jNWX0MGEe07=cL`1`L700KVi^0P1[
Jf/04`1_Kfl0LG5a07=cL`1eMGD0N7Qh07inOP20P800Ph>308J6QP2:RXX0T92@09>CT`2FUYH0VIVI
09fMW@2PX:00YZJV0:VYZ@2][Jd08P3oool00200oooo02H0Kfm_07=cL`1jNWX0OWin0861P@25QHD0
R8R808b<S02CTi<0UYJF09ZJVP2MWId0X:2P0:NWY`2YZJT0[:b/0:n_[`2a/K40]KFe0;Jf]P2e]KD0
/[:b0:n_[`2/[:`0Xj>S09nOW`2JVYX0UYJF09:BTP2@T900TI6A09>CT`2EUID0V9RH09ZJVP2PX:00
Y:BT0:NWY`80Z:RX0P2WYjL30:JVYP040:BTY02SXj<0XJ6Q09jNWP80WIfM03T0Vi^K09ZJVP2KVi/0
W9bL09fMW@2NWYh0WinO09jNWP2MWId0Vi^K09VIV@2CTi<0S8b<0820P01`L700GemO04Q8B010@400
?3`l03Ph>00`<3009RHV02DU9@0V9RH0:BTY02HV9P0R8R8061PH01@D500@410030`<00/;2`0=3@d0
3`l?00d=3@0<30`02@T900`<300C4a<05aLG01/K6`0O7al092@T02`/;00`<300=3@d03Ph>00m?Cd0
A4A404Q8B01<C4`0D51@05ADE01HF5P0H61P06ATI01XJ6P07P3oool07@2KVi/0WinO0:RXZ02][Jd0
/K6a0;Fe]@2j^[X0_[jn0<O7a`3<c<`0d=3@0=GEe@3IfMT0hn?S0>OWi`3/k>`0l?3`0?Cdm03kno/0
oOgm0?clo03hn?P0l_;b0>_[j`3Jf]X0d=3@0<K6aP2k^k/0/K6a0080YjNW00D0Z:RX0:ZZZP2[Zj/0
[Jf]0:n_[`020;6a/@D0/;2`00D0/K6a0;2`/02_[jl0[Zj^0:f][@030:b/[00P0:f][@2^[Zh0/;2`
0;:b/P2c/k<0];Bd0;Fe]@2d];@0/k>c0;:b/P2`/;00Zj^[0:JVYP2MWId0TY:B08J6QP1fMWH0LG5a
06e]K@1YJFT0HF5Q05IFEP1CDe<0DE5A051@D01;Bd/0B4Q803lo?`0k>c/0=cLg038b<P0a<C4202h^
;P0G02/[:`0Y:BT09RHV02PX:00_;bl0<c<c03Hf=P0k>c/0@41004U9B@1>CTh0De=C05QHF01MGEd0
IVIV06][J`1`L700MGEe07YjNP1nOWh0R8R808f=S@2BTY807P3oool07P2c/k<0][Jf0;bl_02o_kl0
`/;20<C4a038b<P0bl_;0=7Ad@3De=@0f=SH0=_Kf`3Ogml0i^KV0>[ZjP3^k^h0l_;b0?KfmP3lo?`0
o_kn0?gmo@3jn_X0m?Cd0>g]k@3Lg=`0d];B0<O7a`2l_;`0/;2`0:BTY0<0Xj>S0P2RXZ800`2PX:00
WYjN09^KV`0209VIV@0409ZJVP2KVi/0W9bL09bLW0<0Vi^K0P2LW9`01P2NWYh0WinO0::RXP2UYJD0
YjNW0:RXZ080ZJVY00H0ZZZZ0:VYZ@2YZJT0ZJVY0:RXZ02WYjL20:JVYP0F0:FUY@2TY:@0Y:BT0:>S
X`2RXZ80X:2P09fMW@2GUiL0Ti>C08j>SP2:RXX0QXJ608B4Q022PX80P82007emO@1kNg/0NWYj07Ad
M01bLW80Kfm_06i^KP80Jf][01<0KVi^071`L01bLW80M7Ad07MgM`1mOGd0P82008>3P`26QXH0RHV9
092@T02CTi<0UYJF09VIV@2LW9`0WinO0:JVYP2YZJT0[Jf]0280oooo000P0?ooo`0X06m_K`1cLg<0
Ng]k07inOP22PX80QXJ608Z:RP2=SHd0UIFE09VIV@2LW9`0X:2P0:>SX`2ZZZX0[Jf]0;2`/02c/k<0
][Jf0;Rh^02g]kL0]KFe0;:b/P2^[Zh0ZJVY09nOW`2JVYX0UIFE08n?S`29RHT0SXj>092@T02CTi<0
UIFE09RHV02JVYX0WinO0:6QX@2SXj<0Y:BT0:FUY@80YZJV00L0YJFU0:BTY02TY:@0XZ:R0:6QX@2P
X:00WinO00<0WYjN00D0WinO0:2PX02PX:00XJ6Q0::RXP020:6QX@0A0:2PX02NWYh0W9bL09JFUP2A
TI40R8R807YjNP1XJ6P0CTi>04E5A@0m?Cd0>3Ph038b<P0T92@07alO01hN7P0O7al00P0P82001P0I
6AT05ADE010@400=3@d02@T900P820802`/;01H02PX:00P8200;2`/04a<C01HF5P0K6a/07alO02@T
900/;2`0<30`03De=@0i>CT0?Cdm04E5A@19BDT0CDe=051@D01DE5@0F5QH061PH01TI6@0J6QX7P3o
ool04P2KVi/0WinO0:VYZ@2][Jd0/[:b0;Jf]P2k^k/0_kno0<W9b@3=cLd0d];B0=OGe`3Lg=`0iNGU
0>[ZjP3_knl0lo?c0?Shn080oOgm00P0nOWi0??cl`3/k>`0hn?S0=3@d036a/H0_;bl0;6a/@<0YZJV
00H0YjNW0:VYZ@2ZZZX0Zj^[0:j^[P2_[jl20;2`/0030;6a/@2b/[80/k>c00<0/[:b00<0/;2`0:n_
[`2^[Zh00`2][Jd01@2^[Zh0/;2`0;6a/@2b/[80/k>c00<0];Bd0340/k>c0;:b/P2`/;00Zj^[0:NW
Y`2QXJ40UYJF08^;R`1hN7P0LW9b06a/K01WIfL0HF5Q05EEE@1?Cdl0C4a<04Y:BP19BDT0ADE503dm
?@0i>CT0=3@d030`<00/;2`0:BTY02XZ:P0X:2P09RHV02<S8`0V9RH0;Rh^034a<@0f=SH0>SXj03lo
?`19BDT0CTi>05=CD`1HF5P0GEeM06IVIP1[Jf/0L71`07EeM@1jNWX0OWin08R8R02=SHd0TY:B01h0
oooo0200/k>c0;Jf]P2l_;`0_kno0<;2`P35aLD0b<S80<_;b`3AdM40eMGE0=SHf03Kfm/0gmoO0>OW
i`3Zj^X0k^k^0?;blP3fm_H0o?cl0?gmo@3inOT0lo?c0>c/k03UiND0d];B0<S8b02n_[h0];Bd0:VY
Z@2TY:@0Xj>S0::RXP80XJ6Q00<0X:2P09nOW`2NWYh00P2NWYh00`2MWId0WYjN09nOW`040:2PX080
WinO0`2NWYh00`2PX:00XJ6Q0::RXP020:BTY0040:FUY@2VYZH0YZJV0:JVYP80YJFU0P2TY:@00`2R
XZ80XJ6Q0::RXP020:6QX@0W0:2PX02NWYh0VYZJ09JFUP2CTi<0Shn?08^;R`28R8P0Q8B407inOP1l
O7`0NWYj07QhN01eMGD0LG5a06m_K`1]KFd0JVYZ06UYJ@1ZJVX0KFe]06m_K`1aLG40M7Ad07IfMP1l
O7`0P82008>3P`25QHD0RHV908n?S`2BTY80UYJF09VIV@2LW9`0X:2P0:JVYP2YZJT0[:b/0280oooo
000P0?ooo`0X071`L01cLg<0Ng]k07moO`23Ph<0QhN708^;R`2>SXh0UYJF09ZJVP2NWYh0XJ6Q0:FU
Y@2/[:`0[jn_0;:b/P2e]KD0]kNg0;Zj^P2h^;P0]KFe0;6a/@2][Jd0Z:RX09fMW@2GUiL0TY:B08f=
S@26QXH0SHf=08n?S`2BTY80UIFE09NGU`2JVYX0WYjN0:2PX02RXZ80Xj>S0:BTY080YJFU00H0Y:BT
0:>SX`2SXj<0XJ6Q0:2PX02OWil309jNWP0309nOW`2PX:00XZ:R00@0Xj>S0100XZ:R0:6QX@2OWil0
WIfM09JFUP2BTY80RXZ:07emO@1^KVh0DU9B04Q8B010@400>CTi03<c<`0T92@07AdM0P0K6a/0200M
7Ad07QhN01PH600E5AD03`l?00d=3@092@T01`L70P0:2PX200T92@0D00/;2`0C4a<05aLG01/K6`0P
820092@T02d];@0a<C40=CDe03Ti>@0m?Cd0ADE504U9B@1=CDd0D51@05EEE@1HF5P0H61P06ATI01X
J6PN0?ooo`0M09^KV`2PX:00ZJVY0:f][@2b/[80]kNg0;bl_030`<00b/[:0<k>cP3Cdm<0f=SH0=gM
g@3WinL0jn_[0?3`l03emOD0n_[j0?knoP3kno/0moOg0?3`l03Xj>P0h>3P0<c<c031`L40]kNg0:f]
[@2SXj<00P2UYJD01`2WYjL0Z:RX0:VYZ@2[Zj/0[Jf]0:n_[`2`/;000P2a/K450;>c/`040;2`/02_
[jl0[jn_0:j^[P80[Jf]00D0[Zj^0:n_[`2a/K40/[:b0;>c/`020;Bd]080/k>c01L0/[:b0;2`/02[
Zj/0Z:RX0::RXP2IVIT0SXj>07UiN@1bLW80K6a/06IVIP1QHF40E5AD04i>CP1:BTX0AdM704E5A@13
@d<0?3`l03Ti>@0c<c<0;bl_02XZ:P0202LW9`0G02HV9P0S8b<08b<S02DU9@0];Bd0<30`03De=@0j
>SX0?clo04U9B@1>CTh0De=C05QHF01LG5`0IVIV06][J`1`L700MGEe07YjNP1nOWh0R8R808f=S@2B
TY807P3oool07`2c/k<0][Jf0;^k^`2n_[h0`L710<C4a038b<P0bl_;0=7Ad@3EeMD0f=SH0=_Kf`3O
gml0i^KV0>[ZjP3^k^h0lo?c0?Ogm`3kno/0nOWi0?Gem@3_knl0j>SX0>3Ph03>c/h0a<C40;Zj^P2`
/;00Z:RX0:>SX`2RXZ800P2QXJ420:2PX0D0WinO00<0X:2P0:6QX@2RXZ800P2RXZ800`2QXJ40X:2P
0:2PX00209nOW`0609jNWP2OWil0X:2P0:2PX02QXJ40XZ:R1`2TY:@0;@2SXj<0XZ:R0:6QX@2PX:00
WinO09jNWP2MWId0Vi^K09VIV@2FUYH0TY:B08n?S`2<S8`0QXJ608:2PP1mOGd0Ng]k07QhN01eMGD0
LW9b06m_K`1]KFd0Jf][06QXJ01WIfL0J6QX06][J`1]KFd0L71`07=cL`1fMWH0O7al07moO`22PX80
QHF508R8R02?Shl0TY:B09JFUP2IVIT0W9bL09nOW`2VYZH0ZJVY0:f][@0R0?ooo`00803oool04@1`
L700M7Ad07alO020P800Q8B408R8R02;Rh/0Shn?09NGU`2KVi/0WinO0:>SX`2VYZH0[Jf]0;6a/@2e
]KD0^;Rh0080^[Zj01D0^;Rh0;Bd]02a/K40[:b/0:NWY`2LW9`0UIFE092@T02:RXX0QXJ608b<S02?
Shl0TY:B09BDU02GUiL0VIVI09jNWP2OWil0XJ6Q0:>SX`2TY:@00P2UYJD01@2TY:@0Xj>S0::RXP2P
X:00WinO00@0WYjN00H0X:2P0:6QX@2RXZ80Xj>S0:BTY02UYJD20:BTY00?0:>SX`2QXJ40WinO09RH
V02CTi<0SHf=08:2PP1bLW80E5AD04Y:BP11@D40>SXj03<c<`0U9BD07AdM00<06ATI01l06QXJ01PH
600E5AD03`l?00/;2`0820P01PH600P8200:2PX020P800X:2P0;2`/04a<C01LG5`0K6a/0820P02@T
900];Bd0<C4a03De=@0i>CT0?Cdm04E5A@19BDT0CDe=055AD@1EEED0F5QH061PH01TI6@0J6QX01h0
oooo02P0Vi^K0:2PX02YZJT0[Zj^0;:b/P2g]kL0_;bl0<71`@3:b/X0clo?0=CDe03IfMT0g]kN0>SX
j03]kNd0l_;b0?Ogm`3kno/0oOgm0?[jnP3dm?@0kNg]0>GUi@3Lg=`0b<S80;fm_@2c/k<0Z:RX0:2P
X02TY:@0YJFU0:JVYP2XZ:P0ZJVY0:ZZZP2][Jd0[Zj^0;2`/02a/K40/[:b0`2d];@20;>c/`040;6a
/@2_[jl0[Zj^0:j^[P80[Jf]00D0[Zj^0:n_[`2a/K40/[:b0;>c/`020;Bd]080/k>c0300/K6a0;2`
/02[Zj/0Z:RX0:>SX`2KVi/0Shn?07YjNP1cLg<0K6a/06IVIP1PH600De=C04e=C@17AdL0A4A404=3
@`11@D40>c/k03Lg=`0a<C40;Bd]02TY:@0T92@09BDU02@T900Q8B408b<S02@T900/;2`0<30`03De
=@0j>SX0?clo04U9B@1>CTh0De=C05MGE`1LG5`0IVIV06][J`1`L700MGEe07UiN@1nOWh0R8R808f=
S@2BTY8N0?ooo`0N0;>c/`2f][H0^k^k0;jn_P31`L40aLG50<S8b03;bl/0d];B0=GEe@3Hf=P0g=cL
0=oOg`3WinL0j^[Z0>k^kP3clo<0moOg0?[jnP3gmoL0l_;b0>_[j`3Ti>@0fm_K0<S8b02o_kl0][Jf
0:^[Z`2TY:@0XZ:R0P2QXJ420:2PX0D0WinO00<0X:2P0:6QX@2RXZ800`2SXj<0102RXZ80XJ6Q0:2P
X02PX:0209nOW`0309jNWP2OWil0X:2P0080XJ6Q0`2RXZ800`2SXj<0XZ:R0::RXP020::RXP0/0:6Q
X@2PX:00WinO09jNWP2MWId0W9bL09ZJVP2HV9P0Ti>C096AT@2=SHd0R8R808J6QP22PX80Ng]k07Ui
N@1fMWH0M7Ad075aL@1/K6`0JVYZ06QXJ01UIFD0IfMW06QXJ01ZJVX0K6a/06m_K`1bLW80MGEe07al
O01oOgl0PX:208F5Q@28R8P0Shn?09:BTP2EUID0V9RH09bLW02OWil0YZJV0:VYZ@2][JdR0?ooo`00
803oool0:@1`L700M7Ad07alO020P800Q8B408R8R02<S8`0T92@09RHV02LW9`0X:2P0:BTY02XZ:P0
/;2`0;>c/`2g]kL0^[Zj0;fm_@2k^k/0^;Rh0;Bd]02_[jl0Zj^[0:FUY@2IVIT0U9BD08j>SP26QXH0
QhN708b<S02?Shl0TI6A09BDU02GUiL0VIVI09fMW@2OWil0XJ6Q0:>SX`2TY:@0YZJV0080YjNW00H0
YJFU0:>SX`2PX:00WinO09jNWP2MWId209jNWP030:2PX02RXZ80Xj>S0080YJFU0P2VYZH04@2UYJD0
Y:BT0::RXP2PX:00VYZJ09FEU@2?Shl0QHF507IfMP1GEeL0C4a<0492@P0l?3`0=3@d02LW9`0P8200
5aLG00805QHF01l061PH01LG5`0E5AD0410@00/;2`071`L010@400L71`092@T020P800X:2P0;2`/0
4Q8B01LG5`0L71`0820P02DU9@0];Bd0<C4a03De=@0i>CT0?Cdm04E5A@19BDT0CDe=055AD@1EEED0
FEUI061PH01TI6@0J6QX01h0oooo02P0Vi^K0:2PX02YZJT0[Zj^0;>c/`2h^;P0_Kfm0<71`@3;bl/0
d=3@0=GEe@3Jf]X0gmoO0>WYj@3^k^h0lo?c0?Shn03moOd0o?cl0?Shn03alO40jNWY0>7Qh@3Hf=P0
`l?30;Vi^@2_[jl0Xj>S0:2PX02SXj<0Y:BT0:FUY@2WYjL0ZJVY0:ZZZP2][Jd0[Zj^0;2`/02a/K40
/[:b0P2d];@01P2e]KD0];Bd0;>c/`2`/;00[jn_0:j^[P<0[Jf]00<0[Zj^0:n_[`2a/K400P2b/[82
0;Bd]080/k>c01L0/K6a0;2`/02/[:`0Z:RX0:>SX`2LW9`0TY:B07alO01dM7@0K6a/06IVIP1OGel0
De=C04e=C@14A4@0@d=30410@00m?Cd0>CTi03Hf=P0a<C40;2`/02PX:003028R8P0F020P800R8R80
92@T02/[:`0`<300=CDe03Xj>P0o?cl0BDU904i>CP1CDe<0EeMG05aLG01VIVH0Jf][071`L01eMGD0
NGUi07inOP28R8P0SHf=09:BTQh0oooo01h0/k>c0;Jf]P2k^k/0_[jn0<71`@35aLD0b<S80<_;b`3A
dM40eMGE0=SHf03Lg=`0gmoO0>KViP3Zj^X0k^k^0?;blP3fm_H0n?Sh0?Cdm03_knl0j>SX0>3Ph03G
emL0aLG50;^k^`2b/[80YjNW0::RXP2QXJ430:2PX0@0WinO0P2PX:030:6QX@80XZ:R00H0Xj>S0::R
XP2QXJ40XJ6Q0:2PX02OWil309jNWP<0WinO0P2PX:050:6QX@0]0:2PX02OWil0WinO09nOW`2MWId0
W9bL09ZJVP2HV9P0UIFE092@T02>SXh0Rh^;08V9R@25QHD0P82007YjNP1gMgL0M7Ad079bLP1`L700
JVYZ06QXJ01UIFD0I6AT06IVIP1WIfL0JVYZ06a/K01_Kfl0LW9b07EeM@1kNg/0OWin0861P@25QHD0
R8R808j>SP2BTY80UIFE09RHV02LW9`0WinO0:JVYP2YZJT0[Jf]0280oooo000P0?ooo`0V071`L01d
M7@0O7al0861P@25QHD0RHV908f=S@2ATI40VIVI09fMW@2QXJ40YJFU0:VYZ@2a/K40]KFe0;Vi^@2m
_Kd0_kno0;bl_02h^;P0];Bd0:n_[`2YZJT0Y:BT09RHV02BTY80Rh^;08>3P`27QhL0S8b<08j>SP2A
TI40U9BD09JFUP2IVIT0WIfM09nOW`2QXJ420:>SX`090:NWY`2YZJT0ZJVY0:RXZ02TY:@0XJ6Q0:2P
X02NWYh0WIfM0080WYjN00D0XJ6Q0::RXP2TY:@0YJFU0:JVYP020:NWY`0A0:JVYP2UYJD0Y:BT0::R
XP2LW9`0UiNG096AT@29RHT0O7al05]KF`1?Cdl0ADE503dm?@0e=CD0:BTY024Q8@0I6AT00`0E5AD0
7P0G5aL051@D010@400:2PX01`L700<30`051@D01`L700T92@0820P030`<01<C4`0H61P071`L024Q
8@0U9BD0;Rh^034a<@0f=SH0>SXj03hn?P16ATH0BDU904e=C@1ADE40EEEE05UIF@1PH600I6AT06QX
J1h0oooo01/0Vi^K0:2PX02ZZZX0[Zj^0;>c/`2h^;P0_Kfm0<;2`P3<c<`0dM7A0=KFeP3Kfm/0h>3P
0>[ZjP3_knl0m?Cd0?[jnP3no_h0no_k0?Gem@3^k^h0i^KV0=gMg@3De=@0_kno0;Jf]P2[Zj/00P2O
Wil02P2RXZ80Xj>S0:FUY@2VYZH0Z:RX0:ZZZP2][Jd0[Zj^0;2`/02b/[820;>c/`040;Bd]02e]KD0
]KFe0;Bd]080/;2`00L0[Zj^0:f][@2/[:`0[:b/0:j^[P2_[jl0/;2`0080/[:b0`2c/k<0602b/[80
/K6a0;2`/02/[:`0Z:RX0:BTY02NWYh0UIFE07emO@1dM7@0K6a/06EUI@1NGUh0De=C04];B`14A4@0
@41003`l?00k>c/0>3Ph03@d=00`<300:b/[02HV9P80820P01L07alO024Q8@0Q8B4092@T02XZ:P0`
<300=CDe03Xj>P0o?cl0BDU904i>CP1CDe<0EeMG05aLG01VIVH0Jf][071`L01eMGD0NWYj07inOP28
R8P0SHf=09:BTP0N0?ooo`0M0;>c/`2f][H0_;bl0;no_`32`/80aLG50<S8b03;bl/0dM7A0=GEe@3H
f=P0fm_K0=oOg`3Vi^H0j^[Z0>k^kP3bl_80m_Kf0?Gem@3`l?00j^[Z0>?Sh`3Kfm/0d];B0<30`02h
^;P0[jn_0:FUY@2RXZ800P2PX:0709nOW`80XJ6Q00X0WYjN09nOW`2PX:00XJ6Q0::RXP2PX:00XJ6Q
0:2PX02OWil0WYjN0P2MWId309jNWPT0WinO01D0WYjN09fMW@2MWId0Vi^K09VIV@2HV9P0UIFE09>C
T`2>SXh0Rh^;08V9R@27QhL0PH6107inOP1hN7P0MWIf07AdM01aLG40KVi^06QXJ01VIVH00`1TI6@0
501UIFD0J6QX06][J`1^KVh0LG5a07AdM01kNg/0OWin0861P@24Q8@0R8R808j>SP2ATI40UIFE09RH
V02LW9`0WinO0:JVYP2YZJT0[Jf]8P3oool00200oooo02X0L71`07AdM01mOGd0PX:208J6QP2:RXX0
Shn?09>CT`2LW9`0X:2P0:BTY02XZ:P0[Jf]0;Fe]@2i^KT0_Kfm0<;2`P34a<@0_Kfm0;Rh^02c/k<0
[Zj^0:VYZ@2RXZ80UYJF08n?S`28R8P0Q8B408N7Q`2<S8`0Shn?096AT@2DU9@0UYJF09VIV@2MWId0
WinO0:2PX02SXj<0YJFU0:RXZ02ZZZX20:^[Z`050:ZZZP2UYJD0Y:BT0:>SX`2QXJ400P2OWil00`2R
XZ80Xj>S0:BTY0020:JVYP<0Z:RX0P2WYjL03P2UYJD0WinO09^KV`2EUID0Shn?08J6QP1UIFD0EUIF
04a<C012@T80>c/k02d];@0U9BD07alO0`0D51@01@0G5aL051@D014A4@0<30`01`L700800P8201L0
1@D500P8200:2PX030`<01DE5@0I6AT07AdM028R8P0V9RH0;Rh^038b<P0f=SH0>SXj03hn?P16ATH0
BTY:04i>CP1ADE40EEEE05UIF@1PH600I6AT06QXJ00N0?ooo`0Z09^KV`2PX:00ZZZZ0:n_[`2d];@0
^KVi0;jn_P33`l<0cLg=0=;BdP3GemL0g=cL0>7Qh@3/k>`0lO7a0?Ogm`3lo?`0oooo0?Ogm`3`l?00
inOW0=kNgP3EeMD0bl_;0;Vi^@2][Jd0XJ6Q09^KV`2MWId0XJ6Q0::RXP2TY:@0YZJV0:RXZ02ZZZX0
[:b/0:j^[P2_[jl0/;2`0;6a/@2c/k<0];Bd0P2e]KD0302c/k<0/;2`0;2`/02^[Zh0[:b/0:^[Z`2/
[:`0[Zj^0:n_[`2`/;00/K6a0;:b/P<0/k>c0180/[:b0;6a/@2`/;00[:b/0:RXZ02TY:@0WinO09RH
V01oOgl0M7Ad06][J`1TI6@0GUiN055AD@1:BTX0@d=303Ti>@0h>3P203De=@07034a<@0];Bd0:2PX
02<S8`0L71`06a/K01`L700201hN7P0D020P800Z:RX0;bl_03De=@0j>SX0?clo04U9B@1>CTh0De=C
05MGE`1LG5`0IVIV06][J`1`L700MGEe07YjNP1nOWh0R8R808f=S@2BTY8N0?ooo`0K0;:b/P2e]KD0
^k^k0;jn_P31`L40a<C40<O7a`3:b/X0dM7A0=CDe03GemL0fm_K0=kNgP3Vi^H0jNWY0>g]k@3alO40
lo?c0>k^kP3Xj>P0hN7Q0=SHf03@d=00alO70;Rh^02^[Zh0Y:BT00L0WYjN102OWil00`2NWYh0WIfM
09fMW@0309fMW@<0W9bL102KVi/0102LW9`0WIfM09fMW@2MWId209jNWP<0WIfM0`2LW9`0;@2KVi/0
VYZJ09VIV@2IVIT0U9BD09:BTP2@T900SXj>08b<S028R8P0QHF508:2PP1mOGd0Ng]k07QhN01dM7@0
LG5a06i^KP1[Jf/0JFUY06ATI01RHV80HF5Q061PH01OGel0H61P06IVIP1YJFT0KFe]071`L01cLg<0
NWYj07emO@21PH40Q8B408N7Q`2>SXh0TI6A09FEU@2HV9P0Vi^K09nOW`2UYJD0ZJVY0:b/[00R0?oo
o`00803oool06P1`L700MGEe07inOP22PX80QhN708^;R`2@T900U9BD09fMW@2QXJ40YZJV0:ZZZP2^
[Zh0]kNg0;^k^`30`<00a<C40<K6aP2m_Kd0^KVi0;>c/`2][Jd0Z:RX0::RXP2EUID0SHf=0P26QXH0
5@28R8P0SHf=08n?S`2ATI40U9BD09JFUP2HV9P0WIfM09jNWP2PX:00XZ:R0:BTY02XZ:P0ZJVY0:ZZ
ZP2[Zj/0ZJVY0:JVYP2TY:@0Xj>S0:6QX@020:2PX0050::RXP2SXj<0Y:BT0:FUY@2VYZH0102XZ:P0
<02WYjL0YZJV0:6QX@2MWId0V9RH096AT@29RHT0JFUY05YJFP1?Cdl0A4A403hn?P0_;bl09bLW020P
800G5aL051@D01<C4`0G5aL05ADE014A4@0=3@d01`L700410@020P801@D500L71`0:2PX03@d=01HF
5P0J6QX07QhN028R8P0V9RH0;bl_03<c<`0g=cL0>c/k03lo?`16ATH0BTY:04i>CP1BDU80EEEE05UI
F@1PH600I6AT06QXJ1h0oooo02H0Vi^K0:2PX02ZZZX0[jn_0;Bd]02i^KT0_[jn0<C4a03>c/h0dm?C
0=SHf03MgMd0h^;R0>g]k@3bl_80n?Sh0?gmo@3oool0m?Cd0>g]k@3Shn<0fm_K0=;BdP38b<P0]KFe
0:VYZ@2MWId0Vi^K09bLW02PX:00XZ:R0:BTY02VYZH0Z:RX0:VYZ@2/[:`0[Jf]0:j^[P80/;2`00T0
/k>c0;Bd]02e]KD0]KFe0;Bd]02a/K40/;2`0:j^[P2][Jd00P2/[:`01@2^[Zh0[jn_0;2`/02a/K40
/[:b0080/k>c0P2b/[806@2a/K40/;2`0:b/[02XZ:P0Y:BT09nOW`2IVIT0P82007AdM01/K6`0Hf=S
05eMG@1@D500B4Q80451@@0h>3P0=SHf03<c<`0b<S80;bl_02/[:`0W9bL08R8R01XJ6P0I6AT00P0K
6a/05@0M7Ad0820P02XZ:P0_;bl0=CDe03Xj>P0o?cl0BDU904i>CP1CDe<0EeMG05aLG01VIVH0Jf][
071`L01eMGD0NWYj07inOP28R8P0SHf=09:BTP0N0?ooo`0M0;>c/`2e]KD0^k^k0;jn_P31`L40a<C4
0<O7a`3:b/X0d=3@0=CDe03GemL0f][J0=kNgP3UiND0jNWY0>c/k03`l?00l_;b0>WYj@3Rh^80fm_K
0=?Cd`3;bl/0`l?30;>c/`2YZJT0WinO09^KV`2LW9`00P2MWId209jNWPD0WinO1P2NWYh209fMW@06
09bLW02KVi/0VYZJ09ZJVP2KVi/0W9bL1P2MWId209bLW00809^KV`2JVYX0VYZJ09VIV@2HV9P0UiNG
09FEU@2ATI4208j>SP0>08^;R`28R8P0Q8B40861P@1mOGd0NGUi07MgM`1dM7@0L71`06i^KP1[Jf/0
JFUY06MWI`1QHF4205mOG`0F05iNGP1MGEd0GUiN06EUI@1YJFT0K6a/06m_K`1cLg<0NWYj07emO@20
P800Ph>308N7Q`2>SXh0TI6A09BDU02HV9P0Vi^K09nOW`2UYJD0ZJVY0:b/[280oooo000P0?ooo`0@
071`L01eMGD0OWin08>3P`27QhL0S8b<096AT@2EUID0WYjN0::RXP2WYjL0[:b/0;2`/02i^KT0_Kfm
0<;2`P80a/K601P0_Kfm0;Ng]`2b/[80[Jf]0:NWY`2QXJ40U9BD08b<S023Ph<0QhN708V9R@2=SHd0
Shn?096AT@2CTi<0UIFE09RHV02LW9`0WYjN09nOW`2QXJ40Xj>S0:NWY`2YZJT20:ZZZP050:VYZ@2V
YZH0Y:BT0:>SX`2RXZ800P2QXJ401@2RXZ80Xj>S0:BTY02UYJD0YZJV00@0Z:RX0P2WYjL0402RXZ80
WinO09ZJVP2DU9@0S8b<06i^KP1NGUh0De=C04Q8B010@400<C4a02TY:@0Q8B406ATI01DE5@0D51@2
01HF5P0L014A4@0=3@d01`L700410@020P801@D500H61P092@T03Ph>01HF5P0J6QX07alO02<S8`0W
9bL0;bl_03<c<`0g=cL0>c/k03lo?`16ATH0BTY:04i>CP1BDU80EUIF05UIF@1QHF40I6AT06QXJ1h0
oooo02X0Vi^K0:2PX02ZZZX0[jn_0;Fe]@2j^[X0_kno0<C4a03>c/h0dm?C0=SHf03Ng]h0hn?S0>k^
kP3clo<0nOWi0?knoP3oool0l_;b0>WYj@3Ph>00emOG0<k>cP35aLD0/K6a0:FUY@2IVIT0Vi^K09bL
W02PX:00XZ:R0:BTY02VYZH0Z:RX0:VYZ@2/[:`0[Jf]0:j^[P2_[jl0/;2`0;>c/`2d];@20;Fe]@04
0;Bd]02a/K40/;2`0:j^[P<0[:b/00<0[Zj^0:n_[`2`/;000P2a/K430;:b/P0C0;6a/@2`/;00[jn_
0:^[Z`2XZ:P0Y:BT09nOW`2IVIT0PH6107EeM@1/K6`0Hf=S05aLG01?Cdl0AdM70410@00h>3P0<c<c
034a<@0202l_;`0302XZ:P0V9RH0820P00805aLG0P0I6AT05@0K6a/0820P02/[:`0`<300=CDe03Xj
>P0o?cl0BDU904i>CP1CDe<0F5QH05aLG01VIVH0Jf][071`L01eMGD0NWYj07inOP28R8P0SHf=09:B
TP0N0?ooo`0@0;>c/`2f][H0^k^k0;jn_P31`L40a<C40<O7a`3:b/X0d=3@0=?Cd`3GemL0f][J0=gM
g@3Ti>@0j>SX0>c/k080l?3`00T0i^KV0=oOg`3GemL0c/k>0<O7a`2o_kl0[jn_0:FUY@2LW9`00P2K
Vi/209fMW@0309jNWP2OWil0WinO00/0WinO00<0WIfM09bLW02KVi/00P2JVYX00`2KVi/0W9bL09fM
W@0309fMW@<0W9bL01/0Vi^K09ZJVP2IVIT0V9RH09NGU`2FUYH0U9BD09:BTP2>SXh0S8b<08V9R@27
QhL0QHF50820P01lO7`0NGUi07IfMP1cLg<0LG5a06a/K01[Jf/0JVYZ06MWI`1TI6@0GEeM05aLG01M
GEd00P1KFe/0501NGUh0IFEU06QXJ01/K6`0Kfm_079bLP1iNGT0O7al0820P023Ph<0QXJ608f=S@2A
TI40U9BD09RHV02KVi/0WinO0:FUY@2YZJT0[:b/8P3oool00200oooo02X0L71`07EeM@1nOWh0Ph>3
08R8R02=SHd0TY:B09JFUP2PX:00Y:BT0:VYZ@2][Jd0/[:b0;^k^`2o_kl0a<C40<W9b@37alL0_[jn
0;Ng]`2c/k<0[Jf]0:NWY`2QXJ40Ti>C08f=S@25QHD0R8R808Z:RP2>SXh0T92@096AT@2CTi<0UIFE
09NGU`2KVi/0WIfM09nOW`2PX:00XZ:R0:JVYP2XZ:P30:VYZ@040:JVYP2UYJD0Xj>S0::RXP<0XJ6Q
00D0XZ:R0:BTY02TY:@0YJFU0:NWY`030:RXZ00A0:NWY`2VYZH0Y:BT0:2PX02KVi/0UIFE08j>SP1b
LW80Hf=S05EEE@1;Bd/0@T9203<c<`0/;2`092@T01/K6`0G5aL00P0E5AD07@0G5aL04Q8B00d=3@07
1`L0000000820P061PH01`L700/;2`0?3`l05aLG01`L700P820092@T02PX:00`<300=3@d03Ph>00k
>c/0?clo04M7A`1;Bd/0CTi>059BDP1FEUH0FEUI065QH@1TI6@0J6QX01h0oooo02X0Vi^K0:2PX02[
Zj/0/;2`0;Fe]@2j^[X0_kno0<C4a03?cll0e=CD0=WIf@3Ng]h0i>CT0>o_k`3dm?@0n_[j0?ooo`3m
oOd0kno_0>GUi@3Lg=`0dm?C0<_;b`32`/80[:b/0:6QX@2GUiL0VYZJ09bLW02QXJ40Xj>S0:BTY02V
YZH0Z:RX0:VYZ@2/[:`0[Jf]0:j^[P2_[jl0/;2`0;>c/`2d];@20;Fe]@0:0;Bd]02a/K40[jn_0:j^
[P2][Jd0[:b/0:f][@2^[Zh0[jn_0;2`/080/K6a0`2b/[806P2a/K40/;2`0:n_[`2[Zj/0Z:RX0:BT
Y02OWil0V9RH08:2PP1fMWH0K6a/06=SH`1KFe/0CDe=04I6AP0n?Sh0=SHf038b<P0_;bl0;Bd]02h^
;P0Y:BT092@T01hN7P0F5QH05ADE0P0G5aL05@0K6a/0820P02/[:`0`<300=CDe03Xj>P0o?cl0BDU9
04i>CP1CDe<0F5QH05eMG@1VIVH0Jf][071`L01eMGD0NWYj07inOP28R8P0SHf=09:BTP0N0?ooo`0O
0;>c/`2f][H0^k^k0;jn_P31`L40a<C40<K6aP39bLT0clo?0=;BdP3Fe]H0fMWI0=gMg@3Shn<0inOW
0>[ZjP3]kNd0k>c/0>7Qh@3Hf=P0d=3@0<W9b@32`/80^k^k0:RXZ02NWYh0V9RH09VIV@2JVYX0W9bL
09jNWP0209nOW`H0X:2P0P2OWil20:2PX00809nOW`2NWYh0W9bL09bLW02KVi/0VYZJ09^KV`2LW9`2
09fMW@80WYjN0P2MWId0<`2LW9`0Vi^K09ZJVP2JVYX0VIVI09JFUP2EUID0U9BD09:BTP2@T900RXZ:
08R8R027QhL0QHF508:2PP1lO7`0N7Qh07EeM@1aLG40Kfm_06e]K@1ZJVX0JFUY06MWI`1UIFD0HV9R
05aLG01JFUX0F5QH05MGE`1IFET0GEeM06ATI01WIfL0JVYZ06i^KP1aLG40N7Qh07alO01oOgl0Ph>3
08J6QP2=SHd0TI6A09BDU02GUiL0Vi^K09jNWP2UYJD0ZJVY0:b/[00R0?ooo`00803oool06P1`L700
MGEe07moO`24Q8@0RHV908f=S@2BTY80UiNG0:6QX@2UYJD0ZZZZ0:n_[`2c/k<0_Kfm0<71`@36a/H0
bl_;0<S8b02m_Kd0]kNg0;:b/P2/[:`0YjNW0::RXP2DU9@0SXj>0P2:RXX03P2;Rh/0Shn?092@T02A
TI40Ti>C09FEU@2FUYH0VYZJ09bLW02NWYh0X:2P0:6QX@2VYZH0Z:RX0`2YZJT00`2VYZH0Y:BT0:>S
X`040:6QX@050::RXP2SXj<0Y:BT0:BTY02VYZH0102WYjL0;`2VYZH0Xj>S0:6QX@2MWId0UYJF08n?
S`1fMWH0IVIV05UIF@1=CDd0A4A403<c<`0];Bd09BDU01dM7@0H61P05QHF01DE5@0G5aL04Q8B00h>
3P071`L0000000820P051@D01`L700/;2`0@410061PH01`L700P82009BDU02TY:@0`<300=3@d03Ph
>00l?3`0@41004M7A`1;Bd/0Cdm?059BDP1FEUH0FUYJ065QH@1TI6@0J6QX01h0oooo02X0Vi^K0:2P
X02[Zj/0/;2`0;Fe]@2j^[X0_kno0<G5a@3?cll0eMGE0=[JfP3Ogml0i>CT0>o_k`3emOD0n_[j0?oo
o`3kno/0jn_[0>7Qh@3IfMT0d=3@0<O7a`2o_kl0YjNW09bLW02HV9P0Vi^K09fMW@2QXJ40Xj>S0:FU
Y@2VYZH0Z:RX0:VYZ@2/[:`0[Jf]0:j^[P2_[jl0/;2`0;>c/`2d];@20;Fe]@040;Bd]02a/K40[jn_
0:j^[P80[Jf]00@0[Zj^0:n_[`2_[jl0/;2`0`2a/K406P2b/[80/K6a0;2`/02_[jl0[Zj^0:ZZZP2X
Z:P0Y:BT09jNWP2HV9P0Ph>307MgM`1/K6`0Hf=S05]KF`1;Bd/0ADE503dm?@0e=CD0<30`02h^;P0[
:b/0;Bd]02PX:00S8b<071`L0P0C4a<05`0E5AD05QHF01/K6`0P8200:b/[030`<00e=CD0>SXj03lo
?`19BDT0CTi>05=CD`1HF5P0GEeM06IVIP1[Jf/0L71`07EeM@1jNWX0OWin08R8R02=SHd0TY:B01h0
oooo0200/[:b0;Fe]@2k^k/0_[jn0<30`033`l<0a/K60<W9b@3?cll0d];B0=GEe@3Hf=P0g=cL0>?S
h`3Vi^H0jNWY0>_[j`3Xj>P0fm_K0=?Cd`3<c<`0aLG50;fm_@2d];@0X:2P09JFUP2CTi<0UiNG09VI
V@2MWId0WYjN09nOW`80X:2P0`2QXJ430:2PX0@0WinO00<0WYjN09bLW02LW9`00P2KVi/209bLW0D0
WYjN0P2MWId0502KVi/0VYZJ09VIV@2HV9P0UIFE09BDU02BTY80T92@08j>SP28R8P0QXJ608B4Q021
PH40OWin07UiN@1eMGD0LW9b06i^KP1[Jf/0JVYZ0P1XJ6P01@1UIFD0Hf=S05mOG`1HF5P0EeMG0080
EUIF01D0FEUI05aLG01SHf<0IVIV06YZJP1]KFd0LG5a07QhN01kNg/0Ogmo08:2PP26QXH0SHf=092@
T02DU9@0UiNG09^KV`2NWYh0YJFU0:VYZ@2/[:`08P3oool00200oooo01P0L71`07EeM@1oOgl0QHF5
08Z:RP2?Shl0U9BD09VIV@2SXj<0Z:RX0:f][@2b/[80]kNg0<71`@36a/H0bl_;0<[:bP37alL0^k^k
0;Jf]P2a/K40Zj^[0:NWY`2PX:0208n?S`<0SXj>00d0Shn?092@T02ATI40TY:B09>CT`2DU9@0UiNG
09VIV@2KVi/0WIfM0:2PX02TY:@0YjNW0080ZJVY00@0Z:RX0:FUY@2TY:@0XZ:R0P2PX:00102OWil0
X:2P0:2PX02PX:020:6QX@80Xj>S0380Y:BT0:FUY@2UYJD0YJFU0::RXP2PX:00WYjN09RHV02ATI40
O7al06e]K@1OGel0DU9B04Q8B00f=SH0;bl_02LW9`0O7al06QXJ01PH600D51@05QHF01<C4`0?3`l0
1`L7000000010@4010@400T92@0=3@d04A4A01XJ6P0N7Qh08R8R02HV9P0Z:RX0<S8b03Hf=P0j>SX0
?Cdm0451@@18B4P0C4a<04m?C`1CDe<0EUIF05YJFP1QHF40IFEU06QXJ1h0oooo01P0Vi^K0:6QX@2[
Zj/0/;2`0;Jf]P2k^k/0`<300<K6aP3@d=00e]KF0=_Kf`3Ph>00i^KV0?7al@3fm_H0oOgm0?clo03f
m_H0hn?S0=_Kf`3Bd]80bLW90<30`02d];@309bLW00D09jNWP2OWil0Xj>S0:FUY@2WYjL0Z:RX0:VY
Z@2ZZZX0Zj^[0:b/[02][Jd0[Zj^0:n_[`2b/[80/k>c0;Bd]02e]KD0];Bd0;6a/@2`/;020:n_[`80
[Zj^0P2`/;030;6a/@80/;2`0P2_[jl04P2^[Zh0[Jf]0:VYZ@2VYZH0Xj>S09jNWP2GUiL0QHF507Ui
N@1^KVh0Hf=S05YJFP1:BTX0@T9203Xj>P0c<c<0;Rh^02`/;080:BTY00<09RHV020P800H61P00P0?
3`l05`0B4Q805QHF01/K6`0Q8B40:b/[030`<00e=CD0>SXj03lo?`19BDT0CTi>05=CD`1HF5P0GEeM
06MWI`1[Jf/0L71`07EeM@1jNWX0Ogmo08R8R02=SHd0TY:B01h0oooo01P0/[:b0;Fe]@2j^[X0_Kfm
0<30`032`/80aLG50<S8b03>c/h0dM7A0=CDe03GemL0f][J0>3Ph03Ti>@0jNWY0>SXj03Rh^80d];B
0<_;b`33`l<0^k^k0;:b/P2XZ:P209BDU00609FEU@2HV9P0Vi^K09jNWP2PX:00XZ:R1@2SXj<0102R
XZ80XJ6Q0:6QX@2PX:0409nOW`<0WYjN0P2OWil00`2PX:00XJ6Q0:6QX@030:6QX@0D09nOW`2NWYh0
W9bL09^KV`2IVIT0V9RH09BDU02BTY80T92@08j>SP2;Rh/0QHF508:2PP20P800OGem07YjNP1cLg<0
L71`06a/K01XJ6P206IVIP0606EUI@1TI6@0HF5Q05iNGP1IFET0De=C0P1BDU805P1DE5@0F5QH05]K
F`1RHV80IFEU06UYJ@1/K6`0L71`07MgM`1jNWX0OWin0861P@25QHD0S8b<092@T02CTi<0UiNG09ZJ
VP2NWYh0YJFU0:VYZ@2/[:`R0?ooo`00803oool06P1aLG40MWIf0820P025QHD0RXZ:092@T02EUID0
VYZJ0:BTY02ZZZX0[jn_0;>c/`2i^KT0`l?30<S8b03?cll0c<c<0<S8b02k^k/0][Jf0;2`/02ZZZX0
YJFU09jNWP2ATI40T92@0`2?Shl2092@T080TI6A0140TY:B09>CT`2EUID0V9RH09ZJVP2LW9`0WYjN
0:>SX`2UYJD0Z:RX0:VYZ@2XZ:P0Y:BT0:>SX`2QXJ40X:2P09nOW`0309jNWP<0WinO00@0X:2P0:6Q
X@2QXJ40XZ:R0P2SXj<0402QXJ40WinO09fMW@2HV9P0TY:B07emO@1_Kfl0HF5Q05ADE019BDT0=cLg
02l_;`0V9RH07alO01/K6`0I6AT201DE5@0301@D500?3`l020P80080000001L01@D500T92@0>3Ph0
4Q8B01/K6`0O7al08b<S02LW9`0[:b/0<c<c03Hf=P0j>SX0?Shn0451@@19BDT0C4a<051@D01CDe<0
EeMG05YJFP1QHF40IFEU06QXJ00N0?ooo`0[09^KV`2QXJ40Zj^[0;2`/02f][H0^k^k0<30`036a/H0
d=3@0=KFeP3Kfm/0hN7Q0>KViP3alO40moOg0?gmo@3inOT0l_;b0>3Ph03Hf=P0clo?0<G5a@2k^k/0
/;2`09bLW02MWId0WYjN0:2PX02QXJ40Y:BT0:JVYP2WYjL0Z:RX0:VYZ@2ZZZX0Zj^[0:b/[02][Jd0
[Zj^0:n_[`2a/K40/k>c0;Bd]0020;Fe]@030;:b/P2a/K40/;2`00<0[jn_00@0/;2`0;6a/@2a/K40
/K6a0P2`/;020:n_[`0a0:j^[P2][Jd0[:b/0:RXZ02UYJD0XZ:R09jNWP2GUiL0QXJ607YjNP1^KVh0
Hf=S05YJFP19BDT0@T9203Ti>@0a<C40;Rh^02`/;00X:2P09bLW02@T900N7Qh05QHF00h>3P0=3@d0
4A4A01HF5P0K6a/08B4Q02/[:`0`<300=CDe03Xj>P0o?cl0BDU904i>CP1CDe<0F5QH05eMG@1WIfL0
Jf][071`L01eMGD0NWYj07moO`28R8P0SHf=09:BTP0N0?ooo`0O0;:b/P2e]KD0^[Zj0;fm_@2o_kl0
`/;20<G5a@38b<P0cLg=0=3@d03Cdm<0e]KF0=WIf@3Ph>00hn?S0>GUi@3Rh^80g=cL0<g=c@36a/H0
_[jn0;Jf]P2][Jd0Xj>S09>CT`2EUID0UiNG09ZJVP2LW9`0X:2P0::RXP020:BTY080YJFU0P2TY:@0
0`2SXj<0XZ:R0:6QX@030:2PX0@0WinO0P2PX:000`2QXJ40XZ:R0:>SX`030:BTY00E0:>SX`2QXJ40
X:2P09jNWP2LW9`0VYZJ09RHV02DU9@0TY:B092@T02=SHd0Rh^;08F5Q@22PX80Ogmo07alO01iNGT0
LW9b06i^KP1[Jf/0IfMW0080IFEU01h0HV9R061PH01NGUh0FUYJ05EEE@1ADE40Cdm?055AD@1DE5@0
EeMG05YJFP1QHF40IFEU06QXJ01/K6`0Kfm_07IfMP1jNWX0OWin0861P@25QHD0S8b<08n?S`2CTi<0
UYJF09ZJVP2NWYh0YJFU0:VYZ@2/[:`R0?ooo`00803oool06P1aLG40MWIf0861P@26QXH0Rh^;092@
T02FUYH0Vi^K0:JVYP2[Zj/0/;2`0;Fe]@2j^[X0aLG50<[:bP3?cll0c<c<0<S8b02k^k/0];Bd0:n_
[`2YZJT0XZ:R09fMW@2CTi<0TI6A1P2@T903096AT@0>09>CT`2EUID0V9RH09ZJVP2MWId0XZ:R0:FU
Y@2XZ:P0ZZZZ0:VYZ@2TY:@0Xj>S0:6QX@2OWil209jNWPH0WIfM0P2NWYh0602OWil0X:2P0:6QX@2P
X:00WYjN09bLW02IVIT0TY:B07moO`1aLG40Hf=S05EEE@19BDT0=cLg02l_;`0V9RH07AdM01`L700I
6AT05ADE01<C4`0D51@03@d=00P820800@4101L01@D500X:2P0?3`l04a<C01`L700P820092@T02PX
:00/;2`0<c<c03Lg=`0k>c/0?Shn0492@P19BDT0C4a<051@D01DE5@0EeMG05YJFP1QHF40IFEU06QX
J00N0?ooo`0R09bLW02QXJ40Zj^[0;6a/@2f][H0^k^k0<71`@36a/H0dM7A0=KFeP3Lg=`0hN7Q0>OW
i`3bl_80moOg0?clo03fm_H0l?3`0=gMg@3De=@0bl_;0<;2`P2f][H0Zj^[09jNWP2OWil0X:2P0:6Q
X@2SXj<0YZJV0:NWY`2XZ:P0ZJVY0:ZZZP80Zj^[0P2/[:`01@2][Jd0[Zj^0;6a/@2b/[80];Bd0080
]KFe00@0/k>c0;:b/P2a/K40/K6a0P2`/;050;6a/@80[jn_01T0[Zj^0:f][@2/[:`0Zj^[0:NWY`2T
Y:@0XJ6Q09fMW@2GUiL0QXJ607]kN`1_Kfl0I6AT05UIF@18B4P0@D5103Ti>@0`<300;Rh^02/[:`0W
9bL092@T02<S8`0K6a/05ADE008030`<01L04A4A01HF5P0K6a/08B4Q02/[:`0`<300=CDe03Xj>P10
@400BTY:04m?C`1CDe<0F5QH05eMG@1WIfL0Jf][071`L01eMGD0NWYj07moO`28R8P0SHf=09:BTP0N
0?ooo`0S0;:b/P2e]KD0^[Zj0;fm_@2o_kl0`/;20<C4a037alL0cLg=0<o?c`3Bd]80eMGE0=SHf03N
g]h0hN7Q0>?Sh`3Ng]h0f=SH0<[:bP33`l<0^k^k0;:b/P2XZ:P0WIfM09>CT`2FUYH0VIVI09^KV`2N
WYh0XZ:R0:BTY02UYJD0YZJV0:NWY`2XZ:P00P2VYZH0102TY:@0Xj>S0::RXP2PX:0309nOW`80X:2P
00H0XJ6Q0::RXP2RXZ80Xj>S0:BTY02UYJD30:JVYP0e0:FUY@2SXj<0XJ6Q09nOW`2MWId0Vi^K09RH
V02DU9@0TI6A08n?S`2<S8`0RHV908B4Q021PH40OWin07]kN`1gMgL0L71`06e]K@1ZJVX0IFEU06AT
I01SHf<0HF5Q05mOG`1LG5`0F5QH05=CD`1>CTh0CDe=04m?C`1CDe<0EUIF05UIF@1PH600I6AT06MW
I`1[Jf/0Kfm_07IfMP1iNGT0OGem0861P@24Q8@0S8b<08n?S`2CTi<0UYJF09ZJVP2NWYh0YJFU0:VY
Z@2/[:`08P3oool00200oooo01X0LG5a07IfMP21PH40QhN708b<S02ATI40UiNG09bLW02WYjL0[:b/
0;6a/@2g]kL0_;bl0<K6aP3;bl/0c/k>0<[:bP37alL0^k^k0;Bd]02^[Zh0YjNW0:2PX02IVIT0Ti>C
09:BTP80TI6A1`2@T900202ATI40Ti>C09FEU@2HV9P0Vi^K0:6QX@2TY:@0YjNW0P2ZZZX01P2UYJD0
Xj>S0:6QX@2OWil0WYjN09fMW@80W9bL00@0Vi^K09ZJVP2JVYX0VYZJ0P2KVi/0602MWId0WYjN09jN
WP2NWYh0WIfM09^KV`2HV9P0TY:B0820P01cLg<0I6AT05MGE`1:BTX0>3Ph030`<00W9bL07QhN01`L
700I6AT05ADE014A4@0D51@030`<00P820800P8201L01`L700`<300@410051@D01dM7@0Q8B409BDU
02TY:@0];Bd0=3@d03Ph>00l?3`0?clo04=3@`1:BTX0CDe=051@D01DE5@0EeMG05]KF`1QHF40IFEU
06QXJ00N0?ooo`0H09bLW02QXJ40Zj^[0;6a/@2f][H0_;bl0<71`@37alL0dM7A0=OGe`3Lg=`0h^;R
0>OWi`3clo<0n?Sh0?[jnP3clo<0kNg]0=_Kf`3AdM40b<S80;jn_P2b/[80YZJV0P2QXJ401@2RXZ80
Xj>S0:BTY02WYjL0ZJVY0080ZZZZ1@2[Zj/02@2/[:`0[Jf]0;2`/02a/K40/k>c0;Fe]@2f][H0];Bd
0;>c/`020;:b/P80/K6a0`2b/[820;6a/@0K0:n_[`2^[Zh0[:b/0:b/[02[Zj/0ZJVY0:JVYP2SXj<0
X:2P09bLW02GUiL0QXJ607alO01`L700I6AT05UIF@18B4P0@41003Ph>00_;bl0;Bd]02/[:`0V9RH0
8R8R024Q8@0I6AT04a<C00802`/;01L04A4A01HF5P0L71`08B4Q02/[:`0`<300=SHf03/k>`10@400
BTY:04m?C`1DE5@0FEUI05eMG@1WIfL0K6a/071`L01eMGD0NWYj07moO`28R8P0SHf=09:BTP0N0?oo
o`0>0;:b/P2e]KD0^KVi0;bl_02o_kl0`L710<C4a037alL0c<c<0<o?c`3Bd]80e=CD0=OGe`3Ng]h2
0>;RhP0A0=_Kf`3EeMD0aLG50;jn_P2g]kL0[Zj^0:BTY02IVIT0UiNG09VIV@2KVi/0WIfM0:2PX02T
Y:@0YZJV0:RXZ02YZJT00P2ZZZX01P2XZ:P0YjNW0:FUY@2SXj<0XZ:R0:2PX0<0WinO00P0X:2P0:6Q
X@2RXZ80Xj>S0:BTY02UYJD0YZJV0:RXZ0@0ZJVY03@0YJFU0:>SX`2QXJ40WYjN09^KV`2IVIT0U9BD
096AT@2?Shl0S8b<08V9R@23Ph<0PH6107emO@1jNWX0MWIf06m_K`1[Jf/0IfMW06ATI01SHf<0HV9R
061PH01MGEd0FUYJ05EEE@1@D500BTY:04];B`1>CTh0DE5A05EEE@1HF5P0GemO06=SH`1WIfL0JVYZ
06i^KP1eMGD0NGUi07emO@20P800Q8B408^;R`2?Shl0Ti>C09JFUP2JVYX0WIfM0:FUY@2YZJT0[:b/
8P3oool00200oooo01T0LG5a07MgM`22PX80QhN708f=S@2BTY80V9RH09fMW@2XZ:P0[Jf]0;>c/`2h
^;P0_[jn0<S8b03>c/h0cLg=0<_;b`36a/H0^[Zj0;>c/`2][Jd0YJFU09jNWP2EUID0Ti>C00@0TI6A
0`2@T90208n?S`0908j>SP2?Shl0TI6A09>CT`2FUYH0VYZJ0:2PX02TY:@0YjNW0080ZZZZ00X0YjNW
0:BTY02RXZ80X:2P09jNWP2MWId0W9bL09^KV`2IVIT0V9RH0`2GUiL00`2HV9P0VIVI09^KV`0209bL
W00D09^KV`2JVYX0UYJF09:BTP20P800MGEe06IVIP1HF5P0Bd];03Ph>00`<300:2PX01lO7`0M7Ad0
6QXJ01HF5P0@410051@D00d=3@071`L200@4100G00T92@0=3@d04Q8B01HF5P0N7Qh08R8R02HV9P0Z
:RX0;Rh^03De=@0i>CT0?3`l0410@013@d<0BTY:04e=C@1ADE40E5AD05QHF01KFe/0HV9R06EUI@1X
J6P07P3oool0602LW9`0XJ6Q0:b/[02a/K40][Jf0;bl_031`L40alO70=;BdP3GemL0gMgM0>;RhP3X
j>P0lo?c0?Win@3gmoL0lO7a0>[ZjP3Hf=P0clo?0<G5a@2i^KT0[Zj^0:BTY080XZ:R00D0Xj>S0:FU
Y@2VYZH0ZJVY0:ZZZP020:^[Z`030:b/[02[Zj/0ZZZZ0080ZZZZ00X0Zj^[0:b/[02_[jl0/K6a0;>c
/`2e]KD0][Jf0;Fe]@2d];@0/k>c0`2b/[830;>c/`0f0;:b/P2a/K40[Zj^0:b/[02[Zj/0ZZZZ0:VY
Z@2XZ:P0YJFU0::RXP2OWil0Vi^K09JFUP26QXH0OGem071`L01TI6@0FEUI04M7A`0o?cl0=cLg02h^
;P0/;2`0:RXZ02DU9@0N7Qh07alO01LG5`0@41002PX:00/;2`0A4A405QHF01`L700Q8B40;2`/034a
<@0f=SH0>c/k0410@01:BTX0Cdm?05ADE01IFET0GUiN06MWI`1/K6`0LG5a07EeM@1jNWX0Ogmo08R8
R02=SHd0TY:B7P3oool05`2b/[80];Bd0;Vi^@2l_;`0_[jn0<71`@33`l<0a/K60<_;b`3>c/h0dM7A
0=CDe03GemL0g=cL0>3Ph03MgMd0e]KF0=7Ad@33`l<0_;bl0;Bd]02ZZZX0XJ6Q0080VYZJ00P0Vi^K
09fMW@2OWil0XJ6Q0:JVYP2YZJT0ZZZZ0:^[Z`80[:b/00H0ZJVY0:RXZ02UYJD0Xj>S0::RXP2OWil2
09jNWP0509nOW`2PX:00XZ:R0:>SX`2TY:@00P2UYJD00`2WYjL0ZZZZ0:b/[0020:b/[00e0:^[Z`2W
YjL0YJFU0::RXP2OWil0W9bL09ZJVP2DU9@0TI6A08n?S`2<S8`0RHV908>3P`20P800O7al07UiN@1e
MGD0KFe]06UYJ@1VIVH0HV9R065QH@1PH600GEeM05UIF@1FEUH0DE5A04e=C@17AdL0B4Q804a<C01@
D500E5AD05MGE`1OGel0HV9R06IVIP1ZJVX0KVi^07EeM@1iNGT0O7al0820P024Q8@0Rh^;08n?S`2B
TY80UYJF09ZJVP2MWId0YJFU0:RXZ02/[:`08P3oool00200oooo01X0LG5a07MgM`23Ph<0RHV908j>
SP2DU9@0VYZJ09nOW`2[Zj/0/;2`0;Jf]P2l_;`0`L710<c<c03Cdm<0c<c<0<W9b@32`/80][Jf0;2`
/02XZ:P0X:2P09RHV02GUiL0TI6A09:BTP<0Ti>C01`0TY:B096AT@2?Shl0SXj>08f=S@2<S8`0Rh^;
08b<S02?Shl0Ti>C09RHV02OWil0Y:BT0:RXZ02/[:`0[Zj^0:^[Z`2XZ:P0YZJV0:>SX`2PX:00WinO
09fMW@2LW9`0VIVI09FEU@2DU9@0TY:B0P2ATI400`2CTi<0UIFE09JFUP0209RHV00/09NGU`2DU9@0
Shn?0861P@1gMgL0Jf][05eMG@1>CTh0>3Ph030`<00Y:BT08B4Q01dM7@0L71`05aLG014A4@0D51@0
3Ph>00L71`051@D01`L700`<300A4A405ADE01TI6@0Q8B409BDU02PX:00/;2`0<30`03Lg=`0j>SX0
?Shn0451@@15ADD0Bd];04i>CP1BDU80EEEE05QHF01KFe/0HV9R06EUI@1XJ6PN0?ooo`0H09bLW02Q
XJ40[:b/0;6a/@2g]kL0_;bl0<;2`P37alL0d];B0=SHf03MgMd0hn?S0>WYj@3clo<0nOWi0?7al@3]
kNd0i>CT0=?Cd`3:b/X0_Kfm0;:b/P2YZJT0YjNW0P2TY:@0102VYZH0Z:RX0:ZZZP2][Jd30:j^[P0;
0:f][@2/[:`0YjNW0:NWY`2VYZH0YjNW0:VYZ@2/[:`0[jn_0;:b/P2e]KD00P2g]kL01@2f][H0]KFe
0;Fe]@2d];@0]KFe0080][Jf00H0]KFe0;>c/`2`/;00[:b/0:ZZZP2WYjL20:JVYP0_0:FUY@2RXZ80
X:2P09fMW@2JVYX0UIFE08J6QP1lO7`0LG5a06EUI@1IFET0ADE503dm?@0e=CD0;Bd]02XZ:P0X:2P0
820P01PH600J6QX04a<C00/;2`0820P02`/;014A4@0G5aL071`L028R8P0/;2`0<C4a03Lg=`0l?3`0
@D5104];B`1?Cdl0E5AD05UIF@1NGUh0IfMW06a/K01aLG40MWIf07YjNP1oOgl0R8R808f=S@2BTY80
7P3oool05P2b/[80];Bd0;Rh^02k^k/0_Kfm0;no_`32`/80a<C40<W9b@3<c<`0clo?0=7Ad@3De=@0
fMWI0=[JfP3Fe]H0dm?C0<g=c@2n_[h0]kNg0:f][@2TY:@209jNWP0809fMW@2NWYh0X:2P0::RXP2U
YJD0Zj^[0:f][@2_[jl20;2`/0080:n_[`2ZZZX0YjNW0:BTY02QXJ40WinO09bLW02KVi/209bLW009
09fMW@2PX:00XZ:R0:>SX`2UYJD0YjNW0:VYZ@2/[:`0[Zj^0080/;2`03D0[Zj^0:VYZ@2WYjL0Xj>S
0:2PX02MWId0VYZJ09BDU02BTY80Shn?08b<S029RHT0PX:207emO@1iNGT0MGEe079bLP1ZJVX0IVIV
069RHP1OGel0GEeM05aLG01EEED0Cdm?04i>CP1:BTX0ADE504A4A015ADD0BDU904e=C@1ADE40EEEE
05eMG@1QHF40IFEU06QXJ01/K6`0M7Ad07QhN01lO7`0Ogmo08>3P`2:RXX0SXj>09:BTP2FUYH0VIVI
09fMW@2UYJD0Z:RX0:b/[00R0?ooo`00803oool0601aLG40MgMg08>3P`29RHT0Shn?09FEU@2KVi/0
X:2P0:b/[02b/[80]kNg0;fm_@33`l<0cLg=0=3@d03=cLd0bLW90<71`@2d];@0[jn_0:FUY@2NWYh0
VIVI09RHV080TY:B0P2DU9@08P2EUID0Ti>C096AT@2BTY80Ti>C092@T02<S8`0RXZ:08b<S02=SHd0
TI6A09NGU`2PX:00YJFU0:VYZ@2][Jd0/;2`0:n_[`2/[:`0Z:RX0:JVYP2QXJ40WinO0:6QX@2PX:00
W9bL09NGU`2EUID0TY:B092@T02?Shl0TI6A09>CT`2EUID209JFUP0/09FEU@2CTi<0SXj>0820P01g
MgL0Jf][05mOG`1?Cdl0>CTi030`<00Y:BT08R8R01lO7`0M7Ad05aLG014A4@0D51@03`l?00T92@07
1`L02@T900h>3P0B4Q805QHF01XJ6P0R8R809RHV02XZ:P0];Bd0<C4a03Ph>00k>c/0?clo0492@P15
ADD0C4a<04m?C`1BDU80EEEE05UIF@1LG5`0HV9R06EUI@1XJ6PN0?ooo`0F09bLW02QXJ40[:b/0;6a
/@2g]kL0_;bl0<;2`P37alL0d];B0=SHf03Ng]h0hn?S0>WYj@3emOD0moOg0?7al@3/k>`0h^;R0=3@
d037alL0^KVi0:n_[`80ZJVY00/0Y:BT0:FUY@2WYjL0ZZZZ0:b/[02_[jl0[Zj^0:f][@2^[Zh0[Jf]
0:^[Z`020:FUY@070:BTY02UYJD0YjNW0:ZZZP2^[Zh0/K6a0;Fe]@030;Ng]`0<0;Jf]P2h^;P0][Jf
0;Fe]@2f][H0]kNg0;Jf]P2b/[80[jn_0:^[Z`2XZ:P0YJFU0P2TY:@0;`2SXj<0X:2P09nOW`2LW9`0
VIVI09BDU025QHD0O7al075aL@1VIVH0FEUI04A4A00k>c/0=3@d02`/;00Y:BT09RHV01hN7P0F5QH0
5aLG010@40092@T020P800`<300B4Q805aLG01dM7@0R8R80;Bd]038b<P0g=cL0?3`l0451@@1;Bd/0
D51@05EEE@1JFUX0GUiN06QXJ01/K6`0LG5a07IfMP1jNWX0Ogmo08R8R02=SHd0TY:B01h0oooo00d0
/[:b0;Bd]02h^;P0^[Zj0;fm_@2o_kl0`L710<C4a038b<P0bl_;0<g=c@3@d=00dm?C0080f][J00h0
e=CD0=7Ad@3;bl/0_;bl0;Bd]02ZZZX0XJ6Q09fMW@2OWil0WYjN09nOW`2QXJ40Xj>S0:JVYP80[Jf]
0P2[Zj/01`2][Jd0[Zj^0:NWY`2UYJD0Xj>S09nOW`2LW9`00`2IVIT01P2JVYX0Vi^K09fMW@2PX:00
XZ:R0:NWY`<0ZJVY03P0[:b/0:j^[P2/[:`0Zj^[0:RXZ02UYJD0XZ:R09nOW`2LW9`0V9RH09BDU02A
TI40Shn?08b<S029RHT0PH6107emO@1hN7P0MGEe075aL@1XJ6P0I6AT05mOG`1LG5`0FUYJ05QHF01A
DE40C4a<04Y:BP15ADD0@4100451@@14A4@0B4Q804a<C01@D500E5AD05aLG01PH600I6AT06QXJ01/
K6`0M7Ad07MgM`1kNg/0Ogmo08>3P`2:RXX0SXj>09:BTP2FUYH0VIVI09fMW@2UYJD0Z:RX0:b/[280
oooo000P0?ooo`0=079bLP1hN7P0Q8B408Z:RP2@T900UYJF09bLW02RXZ80[Jf]0;>c/`2i^KT0_kno
0<C4a0020=7Ad@0P0<k>cP39bLT0`/;20;:b/P2][Jd0XZ:R09RHV02IVIT0UiNG09:BTP2DU9@0UIFE
09JFUP2GUiL0UYJF09BDU02EUID0UiNG09FEU@2BTY80SHf=08j>SP2@T900TY:B09NGU`2QXJ40YZJV
0:^[Z`2_[jl0/[:b0;>c/`2a/K420:f][@090:ZZZP2TY:@0YZJV0:BTY02QXJ40W9bL09VIV@2FUYH0
TY:B0080T92@0300Ti>C09BDU02FUYH0UIFE09BDU02BTY80SXj>0820P01fMWH0Jf][05mOG`1@D500
>SXj034a<@0Y:BT08b<S020P800M7Ad061PH018B4P0D51@03@d=00X:2P0820P030`<010@400D51@0
61PH01`L700T92@09bLW02/[:`0^;Rh0<S8b03Ti>@0l?3`0?clo04=3@`16ATH0C4a<04m?C`1CDe<0
EUIF05UIF@1LG5`0HV9R06EUI@1XJ6PN0?ooo`0N09bLW02QXJ40[:b/0;:b/P2g]kL0_;bl0<;2`P37
alL0dm?C0=SHf03Ng]h0i>CT0>WYj@3emOD0m?Cd0?3`l03Zj^X0hN7Q0<g=c@34a<@0^;Rh0:b/[02[
Zj/0ZJVY0:BTY02VYZH0Z:RX0:^[Z`2^[Zh0[jn_0P2/[:`0102_[jl0[Jf]0:ZZZP2TY:@30::RXP08
0:BTY02YZJT0[Jf]0;2`/02d];@0][Jf0;Rh^02i^KT20;Rh^00;0;Jf]P2c/k<0^;Rh0;Rh^02e]KD0
/;2`0:j^[P2ZZZX0YjNW0:>SX`2RXZ800P2QXJ40;P2OWil0WIfM09^KV`2HV9P0Ti>C08B4Q01kNg/0
LG5a06IVIP1IFET0@d=303Xj>P0b<S80:b/[02LW9`0T92@06a/K01@D500E5AD03@d=00P820071`L0
30`<018B4P0H61P07AdM02<S8`0];Bd0<S8b03Lg=`0l?3`0@D5104];B`1@D500EEEE05YJFP1OGel0
J6QX06e]K@1aLG40MWIf07]kN`1oOgl0RHV908f=S@2BTY8N0?ooo`0P0;:b/P2d];@0^;Rh0;Zj^P2l
_;`0_[jn0<30`032`/80alO70<[:bP3=cLd0clo?0=;BdP3GemL0eMGE0=;BdP3=cLd0b<S80;Vi^@2b
/[80ZZZZ0:>SX`2PX:00WinO09fMW@2OWil0XJ6Q0:>SX`2VYZH0ZZZZ0:NWY`2VYZH20:RXZ0060:JV
YP2RXZ80WinO09bLW02JVYX0VIVI0P2FUYH01`2GUiL0V9RH09RHV02KVi/0WIfM09nOW`2PX:000P2Q
XJ400`2WYjL0ZJVY0:NWY`020:FUY@0J0::RXP2QXJ40WYjN09bLW02IVIT0UYJF09:BTP2@T900SXj>
08^;R`28R8P0P82007alO01iNGT0MGEe06m_K`1UIFD0HF5Q05eMG@1IFET0EeMG05ADE01<C4`0B4Q8
04M7A`11@D4203hn?P0H0492@P17AdL0Bd];04m?C`1CDe<0Fe]K05mOG`1SHf<0IfMW06][J`1cLg<0
MgMg07]kN`1oOgl0PX:208Z:RP2>SXh0TY:B09FEU@2IVIT0WIfM0:FUY@2XZ:P0[:b/8P3oool00200
oooo01D0LW9b07QhN024Q8@0RXZ:096AT@2GUiL0WIfM0:>SX`2_[jl0]KFe0;^k^`30`<00a/K60=;B
dP3Cdm<0c/k>0<S8b031`L40/K6a0:^[Z`2SXj<00P2HV9P02P2FUYH0Ti>C09BDU02GUiL0VYZJ09^K
V`2IVIT0UIFE09JFUP2KVi/209VIV@0G09:BTP2@T900Ti>C09FEU@2IVIT0Xj>S0:RXZ02][Jd0/K6a
0;Bd]02h^;P0][Jf0;Bd]02`/;00[jn_0:ZZZP2/[:`0Z:RX0:NWY`2OWil0WYjN09^KV`2FUYH00`2C
Ti<05@2DU9@0UYJF09FEU@2CTi<0TI6A08f=S@20P800MgMg06e]K@1QHF40DU9B03Xj>P0b<S80:RXZ
02@T900P82007QhN01PH600C4a<05ADE00d=3@0200X:2P0H00h>3P0B4Q805QHF01XJ6P0N7Qh09BDU
02TY:@0/;2`0<30`03<c<`0j>SX0?Cdm0410@014A4@0AdM704e=C@1@D500De=C05IFEP1IFET0G5aL
069RHP1UIFD0JFUY7P3oool03@2LW9`0XJ6Q0:b/[02b/[80]kNg0;fm_@32`/80b<S80=?Cd`3IfMT0
g]kN0>CTi03Zj^X00P3clo<01P3`l?00j>SX0=oOg`3:b/X0`L710;Jf]P80Zj^[00D0ZJVY0:FUY@2V
YZH0ZJVY0:b/[0020:n_[`80Zj^[00@0[Zj^0:ZZZP2ZZZX0XZ:R0`2OWil01P2QXJ40YjNW0:b/[02`
/;00/k>c0;Jf]P<0^KVi0P2g]kL02@2d];@0^KVi0;Fe]@2e]KD0[jn_0:f][@2ZZZX0YJFU0:6QX@02
0:2PX00E09nOW`2NWYh0W9bL09ZJVP2GUiL0TY:B08>3P`1jNWX0LG5a06EUI@1GEeL0@D5103Ti>@0`
<300:RXZ02HV9P0R8R8061PH018B4P0C4a<02PX:00801`L701P03@d=01<C4`0H61P07QhN02<S8`0^
;Rh0<c<c03Ph>00m?Cd0@T9204a<C01@D500EEEE05YJFP1OGel0J6QX06e]K@1bLW80MWIf07]kN`1o
Ogl0RHV908f=S@2BTY8N0?ooo`0H0;:b/P2c/k<0]kNg0;Vi^@2k^k/0_Kfm0;no_`32`/80a/K60<W9
b@3;bl/0c/k>0=7Ad@3Cdm<0d];B0=7Ad@3<c<`0a/K60;Ng]`2_[jl0YjNW0:6QX@2RXZ80XJ6Q0P2N
WYh01@2PX:00XZ:R0:BTY02VYZH0YJFU0080Y:BT0P2OWil0102JVYX0V9RH09JFUP2DU9@209:BTP07
09>CT`2DU9@0U9BD09FEU@2GUiL0V9RH09ZJVP0209^KV`0P09fMW@2SXj<0XJ6Q0::RXP2PX:00WinO
09fMW@2KVi/0UiNG09JFUP2EUID0Ti>C092@T02?Shl0SHf=08Z:RP27QhL0Ogmo07YjNP1fMWH0LG5a
06][J`1SHf<0GUiN05UIF@1FEUH0E5AD051@D018B4P0A4A404=3@`0n?Sh203`l?00H0451@@15ADD0
BTY:04i>CP1BDU80Fe]K05mOG`1SHf<0IfMW06][J`1cLg<0MWIf07YjNP1nOWh0PX:208Z:RP2>SXh0
TY:B09FEU@2IVIT0WIfM0:FUY@2XZ:P0[:b/8P3oool00200oooo01D0LW9b07QhN025QHD0Rh^;096A
T@2GUiL0WYjN0:BTY02`/;00][Jf0;bl_032`/80b<S80<g=c@3Bd]80clo?0<W9b@31`L40/;2`0:RX
Z02PX:000P2HV9P0202FUYH0Ti>C09JFUP2IVIT0WIfM0:2PX02QXJ40WIfM0P2LW9`0302JVYX0WIfM
09ZJVP2HV9P0VIVI09^KV`2MWId0YJFU0:ZZZP2_[jl0/k>c0;Jf]P80_;bl00<0^[Zj0;Ng]`2c/k<0
0P2a/K402@2/[:`0[Jf]0:NWY`2TY:@0X:2P09fMW@2JVYX0V9RH09NGU`0309JFUP0/09BDU02ATI40
SHf=0820P01hN7P0Kfm_06=SH`1EEED0?3`l03<c<`0Z:RX09RHV028R8P0N7Qh061PH01DE5@0F5QH0
3`l?00`<300=3@d04A4A01DE5@0H61P071`L020P800W9bL0:RXZ02h^;P0a<C40=3@d03/k>`0n?Sh0
@D5104A4A017AdL0CTi>055AD@1DE5@0EeMG05YJFP1MGEd0Hf=S06IVIP1YJFTN0?ooo`0E09bLW02Q
XJ40[:b/0;:b/P2g]kL0_Kfm0<;2`P38b<P0dm?C0=WIf@3Ogml0iNGU0>_[j`3bl_80lo?c0>k^kP3V
i^H0gMgM0<S8b02n_[h0];Bd0080[:b/00d0ZJVY0:FUY@2VYZH0ZJVY0:b/[02^[Zh0[Jf]0:ZZZP2[
Zj/0[:b/0:RXZ02WYjL0WinO0080W9bL00L0WIfM09nOW`2WYjL0Zj^[0:n_[`2b/[80]KFe00<0^KVi
0P2g]kL02@2e]KD0^;Rh0;Bd]02d];@0[Jf]0:^[Z`2WYjL0XZ:R09nOW`0209jNWP0B09fMW@2LW9`0
Vi^K09VIV@2EUID0TI6A08:2PP1iNGT0L71`06ATI01FEUH0@41003Lg=`0^;Rh0:BTY02@T900O7al0
5ADE0P0@41006`092@T01PH600P8200>3Ph051@D01TI6@0N7Qh092@T02h^;P0c<c<0>3Ph03dm?@12
@T80C4a<055AD@1FEUH0Fe]K05mOG`1YJFT0KFe]079bLP1fMWH0Ng]k0820P029RHT0SHf=09:BTP0N
0?ooo`0E0;:b/P2c/k<0]kNg0;Vi^@2k^k/0_Kfm0;no_`31`L40aLG50<S8b03:b/X0cLg=0=3@d03F
e]H0dm?C0<k>cP39bLT0`/;20;Fe]@2^[Zh0YjNW0080Xj>S00<0XJ6Q09fMW@2LW9`00`2MWId209^K
V`80WYjN00X0Vi^K09JFUP2>SXh0S8b<08^;R`2:RXX0Rh^;08j>SP2?Shl0T92@0P2ATI402@2BTY80
Ti>C09BDU02EUID0UiNG09RHV02LW9`0Vi^K09VIV@0209FEU@0309>CT`2?Shl0SXj>00<0Shn?02h0
SXj>08b<S02;Rh/0RHV908J6QP1mOGd0N7Qh07=cL`1]KFd0IfMW05mOG`1KFe/0EUIF059BDP1?Cdl0
C4a<04=3@`0o?cl0?Shn03Xj>P0i>CT0>c/k0410@014A4@0BDU904e=C@1ADE40FUYJ05iNGP1RHV80
IVIV06YZJP1bLW80MWIf07YjNP1nOWh0PX:208Z:RP2>SXh0TY:B09FEU@2IVIT0WIfM0:BTY02XZ:P0
[:b/8P3oool00200oooo01h0LW9b07UiN@26QXH0S8b<09>CT`2IVIT0X:2P0:JVYP2c/k<0^[Zj0<30
`036a/H0cLg=0=GEe@3@d=00cLg=0<K6aP2n_[h0[jn_0:FUY@2MWId0V9RH09JFUP2DU9@0Ti>C09NG
U`2KVi/0X:2P0:FUY@2][Jd30:n_[`030:f][@2[Zj/0YJFU0080XZ:R00P0Xj>S0:FUY@2[Zj/0[Zj^
0;:b/P2f][H0^[Zj0<30`080`L7100<0`<300;jn_P2m_Kd00`2k^k/0=P2i^KT0]kNg0:n_[`2[Zj/0
Z:RX0:FUY@2RXZ80WYjN09ZJVP2HV9P0UYJF09>CT`2?Shl0PH6107QhN01^KVh0Hf=S05MGE`11@D40
=SHf02`/;00X:2P09BDU024Q8@0I6AT05aLG01PH600B4Q803`l?01<C4`0F5QH06ATI01dM7@0P8200
92@T02XZ:P0];Bd0<C4a03@d=00g=cL0?Cdm0410@013@d<0ATI604U9B@1?Cdl0DU9B05EEE@1HF5P0
FUYJ05eMG@1SHf<0IVIV06UYJAh0oooo01`0W9bL0:6QX@2/[:`0/[:b0;Ng]`2m_Kd0`/;20<S8b03C
dm<0fMWI0=oOg`3UiND0jn_[0?;blP3`l?00k>c/0>;RhP3Hf=P0a/K60;^k^`2b/[80[Jf]0:ZZZP2W
YjL0XZ:R0:BTY02UYJD0YjNW0P2XZ:P0402WYjL0YZJV0:BTY02RXZ80WinO09bLW02JVYX0Vi^K09bL
W02OWil0YZJV0:ZZZP2][Jd0/;2`0;>c/`2g]kL30;Rh^0090;Jf]P2d];@0/K6a0:n_[`2][Jd0ZZZZ
0:NWY`2QXJ40X:2P0080WinO01<0WYjN09fMW@2KVi/0VIVI09JFUP2CTi<0SXj>07moO`1fMWH0KFe]
065QH@1DE5@0?Shn03@d=00Z:RX092@T024Q8@0K6a/0410@00803@d=01/01`L700<30`0:2PX0410@
01DE5@0K6a/0820P02DU9@0`<300=CDe03Xj>P0o?cl0A4A404e=C@1BDU80EeMG05]KF`1PH600JFUY
06i^KP1bLW80MgMg07]kN`20P800RHV908j>SP2BTY807P3oool08`2a/K40/k>c0;Jf]P2g]kL0^KVi
0;^k^`2m_Kd0_[jn0<?3``35aLD0alO70<[:bP3<c<`0c/k>0=3@d03=cLd0a/K60;no_`2c/k<0[:b/
0:NWY`2UYJD0Xj>S0:2PX02JVYX0V9RH09JFUP2CTi<0T92@08R8R025QHD0Ph>30861P@1oOgl0OGem
0080OWin00H0Ogmo0861P@23Ph<0R8R808V9R@2:RXX208^;R`@0S8b<00H0Rh^;08Z:RP27QhL0Q8B4
0861P@1nOWh207alO00c07inOP20P800PX:208F5Q@26QXH0R8R808N7Q`25QHD0Ph>30820P01hN7P0
M7Ad06m_K`1YJFT0Hf=S05MGE`1CDe<0CTi>04Y:BP17AdL0@d=303/k>`0h>3P0=cLg03@d=00b<S80
>3Ph03dm?@12@T80AdM704];B`1@D500FEUI05eMG@1QHF40IFEU06UYJ@1bLW80MWIf07YjNP1nOWh0
PX:208V9R@2=SHd0TI6A09FEU@2IVIT0WIfM0:BTY02XZ:P0[:b/0280oooo000P0?ooo`0O079bLP1i
NGT0QXJ608f=S@2CTi<0VYZJ0:6QX@2XZ:P0]KFe0;^k^`32`/80b<S80<o?c`3IfMT0d];B0<g=c@36
a/H0_[jn0;2`/02UYJD0WIfM09RHV02EUID0U9BD09:BTP2FUYH0VYZJ09jNWP2SXj<0ZZZZ0:b/[002
0:j^[P040:^[Z`2YZJT0YJFU0:BTY080YZJV00L0Z:RX0:f][@2`/;00/k>c0;Ng]`2j^[X0`/;20080
a<C400@0`l?30<30`02m_Kd0^k^k0P2l_;`0=P2j^[X0^;Rh0;6a/@2][Jd0ZZZZ0:NWY`2TY:@0XJ6Q
09bLW02JVYX0UiNG09>CT`2?Shl0PH6107UiN@1_Kfl0I6AT05MGE`11@D40=cLg02h^;P0X:2P09RHV
024Q8@0I6AT05aLG01PH600C4a<03`l?01DE5@0H61P071`L01lO7`0R8R809BDU02`/;00_;bl0<S8b
03De=@0h>3P0?Shn0451@@14A4@0AdM704Y:BP1@D500DU9B05EEE@1HF5P0Fe]K05iNGP1SHf<0IVIV
06UYJAh0oooo01d0W9bL0:6QX@2/[:`0/[:b0;Ng]`2m_Kd0`/;20<S8b03De=@0f][J0=oOg`3UiND0
jn_[0?KfmP3`l?00jNWY0>3Ph03Fe]H0aLG50;Zj^P2b/[80[Jf]0:VYZ@2VYZH0XJ6Q0::RXP2SXj<0
Y:BT0:FUY@020:JVYP0?0:FUY@2TY:@0XZ:R0:2PX02LW9`0VYZJ09^KV`2MWId0X:2P0:JVYP2ZZZX0
[:b/0:n_[`2b/[80][Jf00<0^;Rh01h0][Jf0;Bd]02_[jl0[Jf]0:^[Z`2YZJT0YjNW0:>SX`2RXZ80
XJ6Q0:2PX02OWil0WYjN09ZJVP2HV9P0UIFE09:BTP2<S8`0OWin07EeM@1[Jf/0H61P05=CD`0m?Cd0
<S8b02PX:00R8R807alO01TI6@0>3Ph200/;2`0K00D51@030`<030`<014A4@0F5QH071`L024Q8@0V
9RH0<C4a03Hf=P0k>c/0?clo04A4A01>CTh0De=C05MGE`1LG5`0H61P06YZJP1^KVh0Lg=c07MgM`1l
O7`0P82008V9R@2>SXh0TY:B01h0oooo02@0/K6a0;>c/`2e]KD0]kNg0;Rh^02j^[X0^k^k0;fm_@31
`L40`l?30<K6aP38b<P0b/[:0<o?c`3>c/h0bLW90<;2`P2l_;`0/;2`0:^[Z`2WYjL0Y:BT0::RXP2O
Wil0V9RH09JFUP2DU9@0TY:B08n?S`28R8P0QHF508>3P`22PX80PH610820P01nOWh207alO00407in
OP21PH40QHF508N7Q`<0RHV90`28R8P208Z:RP0j08V9R@24Q8@0P82007inOP1lO7`0Ng]k07emO@1o
Ogl0PH6108>3P`24Q8@0QXJ608F5Q@24Q8@0Ph>30820P01mOGd0MGEe075aL@1/K6`0IVIV061PH01E
EED0Cdm?04Y:BP17AdL0@d=303lo?`0h>3P0=CDe03@d=00a<C40<30`03Ph>00m?Cd0@D5104I6AP1;
Bd/0Cdm?05QHF01LG5`0HF5Q06EUI@1YJFT0LG5a07EeM@1iNGT0OGem0861P@29RHT0SHf=096AT@2E
UID0VIVI09fMW@2TY:@0Z:RX0:b/[280oooo000P0?ooo`0O079bLP1iNGT0QhN708f=S@2DU9@0Vi^K
0::RXP2YZJT0]kNg0;fm_@34a<@0b/[:0=3@d03MgMd0e=CD0<o?c`38b<P0`<300;6a/@2WYjL0WinO
09VIV@2EUID0Ti>C09:BTP2FUYH0VIVI09bLW02PX:00YjNW0:VYZ@020:^[Z`030:b/[02[Zj/0Zj^[
00<0ZJVY00d0ZZZZ0:j^[P2a/K40];Bd0;Ng]`2j^[X0`/;20<G5a@38b<P0bLW90<K6aP32`/80^[Zj
0080^KVi01T0]kNg0;Jf]P2a/K40[Jf]0:^[Z`2XZ:P0YZJV0:>SX`2NWYh0W9bL09VIV@2EUID0T92@
08:2PP1iNGT0L71`06ATI01IFET0@T9203Ph>00a<C40:b/[02LW9`0R8R806QXJ00805aLG01/04a<C
014A4@0H61P06a/K01hN7P0Q8B4092@T02LW9`0^;Rh0<C4a03@d=00g=cL0>SXj03lo?`12@T80ADE5
04Q8B01;Bd/0D51@05=CD`1FEUH0FEUI05]KF`1NGUh0Hf=S06IVIP1YJFT07P3oool07@2LW9`0XJ6Q
0:b/[02a/K40]kNg0;bl_032`/80b<S80=CDe03Jf]X0gmoO0>KViP3[jn/0moOg0>k^kP3WinL0gMgM
0=CDe034a<@0^KVi0;:b/P2/[:`0Z:RX0:FUY@2OWil0X:2P0:6QX@2RXZ80Xj>S00<0YJFU00<0Y:BT
0:6QX@2NWYh00P2JVYX02P2LW9`0WYjN0:6QX@2WYjL0ZZZZ0:b/[02_[jl0/K6a0;Fe]@2f][H20;Ng
]`0k0;Fe]@2c/k<0[Zj^0:b/[02[Zj/0ZJVY0:RXZ02UYJD0Xj>S0::RXP2QXJ40X:2P09nOW`2JVYX0
V9RH09FEU@2@T900Rh^;07emO@1dM7@0JVYZ05iNGP1BDU80>SXj02l_;`0W9bL08B4Q01`L700G5aL0
3@d=00X:2P092@T01@D500<30`0=3@d04Q8B01PH600M7Ad08R8R02LW9`0a<C40=SHf03/k>`10@400
ADE504i>CP1CDe<0F5QH05aLG01QHF40JVYZ06i^KP1cLg<0MgMg07alO020P800RHV908j>SP2BTY80
7P3oool0:`2a/K40/[:b0;Fe]@2f][H0]kNg0;Vi^@2j^[X0_;bl0;no_`31`L40a<C40<K6aP39bLT0
cLg=0<S8b033`l<0_Kfm0;Ng]`2][Jd0Z:RX0:FUY@2SXj<0X:2P09fMW@2FUYH0U9BD09:BTP2ATI40
SXj>08V9R@27QhL0QXJ608>3P`1oOgl0Ng]k07EeM@1fMWH0NWYj07emO@20P800QHF508J6QP27QhL0
0P28R8P00`26QXH0QHF508>3P`0208:2PP80Ph>300P0PX:20820P01oOgl0Ogmo0820P021PH40PX:2
08>3P`80Q8B401<0PX:20861P@20P800OGem07YjNP1cLg<0Kfm_06UYJ@1SHf<0GEeM051@D019BDT0
ADE50451@@0o?cl0>c/k03De=@0d=3@0<S8b0080;bl_01T0=cLg03`l?011@D40ADE504Y:BP1?Cdl0
F5QH05aLG01PH600IFEU06UYJ@1aLG40MGEe07UiN@1mOGd0PH6108V9R@2=SHd0TI6A09FEU@2IVIT0
WIfM0:BTY02XZ:P0[:b/0280oooo000P0?ooo`0T079bLP1iNGT0QhN708j>SP2EUID0W9bL0:>SX`2Z
ZZX0^;Rh0;no_`36a/H0cLg=0=?Cd`3Ng]h0emOG0=7Ad@3;bl/0`l?30;>c/`2YZJT0XJ6Q09ZJVP2E
UID0Ti>C09:BTP2FUYH0VYZJ09^KV`2NWYh0Y:BT0:NWY`2ZZZX0[:b/0:j^[P2`/;00[:b/0`2[Zj/0
:P2/[:`0[jn_0;:b/P2d];@0]kNg0;Zj^P31`L40a<C40<O7a`3:b/X0c<c<0<[:bP32`/80_Kfm0;Vi
^@2g]kL0];Bd0;2`/02][Jd0Zj^[0:VYZ@2WYjL0YZJV0:6QX@2NWYh0Vi^K09JFUP2ATI40Q8B407al
O01`L700IVIV05YJFP11@D40=cLg034a<@0/;2`0:2PX02@T900K6a/06ATI01HF5P804a<C01T06QXJ
01dM7@0P82008b<S02HV9P0Y:BT0;bl_038b<P0e=CD0>3Ph03/k>`11@D40@d=304I6AP19BDT0Bd];
055AD@1DE5@0EUIF05UIF@1LG5`0GUiN06ATI01VIVH0JFUY01h0oooo01X0W9bL0:6QX@2/[:`0/K6a
0;Ng]`2l_;`0`/;20<S8b03Cdm<0f][J0>3Ph03Vi^H0kNg]0?Gem@3/k>`0i>CT0=_Kf`3Cdm<0`/;2
0;Vi^@2b/[80[:b/0:NWY`2SXj<0WIfM09jNWP80XJ6Q0180XZ:R0:>SX`2TY:@0Xj>S09nOW`2MWId0
W9bL09^KV`2LW9`0WIfM09nOW`2RXZ80YjNW0:ZZZP2/[:`0[Zj^0;2`/02c/k<30;Fe]@0P0;Bd]02b
/[80[Zj^0:b/[02[Zj/0ZZZZ0:VYZ@2VYZH0YJFU0:BTY02RXZ80X:2P09jNWP2IVIT0UiNG09BDU02?
Shl0RHV907]kN`1cLg<0J6QX05aLG01ADE40>3Ph02d];@0U9BD07alO01XJ6P0E5AD030`<00X:2P07
1`L200<30`0I00h>3P0C4a<06ATI01hN7P0S8b<0:2PX038b<P0g=cL0?3`l0451@@16ATH0Cdm?05AD
E01HF5P0GEeM065QH@1ZJVX0Kfm_07=cL`1hN7P0O7al0861P@29RHT0SXj>09:BTP0N0?ooo`0<0;6a
/@2b/[80];Bd0;Fe]@2f][H0]kNg0;Vi^@2j^[X0_[jn0<30`032`/80a<C40P39bLT07033`l<0_Kfm
0;Jf]P2b/[80ZZZZ0:JVYP2SXj<0XJ6Q09jNWP2JVYX0Ti>C096AT@2@T900Shn?08j>SP2:RXX0R8R8
08>3P`1lO7`0MWIf07=cL`1eMGD0MgMg07YjNP1mOGd0P82008F5Q@26QXH308N7Q`0:08F5Q@24Q8@0
PH6107inOP1kNg/0NGUi07]kN`1nOWh0P8200861P@80PX:20`23Ph<04`22PX80P82007inOP1mOGd0
O7al07YjNP1gMgL0Kfm_06][J`1UIFD0GemO05UIF@1>CTh0AdM70451@@0n?Sh0>c/k03Lg=`0b<S80
0P0a<C4202d];@0I03Hf=P0k>c/0@41004E5A@1:BTX0CTi>05MGE`1LG5`0H61P06ATI01YJFT0LG5a
07EeM@1iNGT0OGem0861P@29RHT0SHf=096AT@2EUID0VIVI09fMW@2TY:@0Z:RX0:b/[00R0?ooo`00
803oool0801cLg<0NWYj08R8R02?Shl0UYJF09fMW@2TY:@0Zj^[0;Zj^P31`L40b<S80=3@d03Hf=P0
fm_K0=SHf03Cdm<0cLg=0<O7a`2e]KD0[:b/0:BTY02NWYh0V9RH09BDU02BTY80UYJF09bLW02OWil0
XZ:R0:NWY`2ZZZX0[:b/0`2][Jd03P2/[:`0Zj^[0:^[Z`2/[:`0[Jf]0;2`/02b/[80];Bd0;Ng]`2j
^[X0_kno0<;2`P35aLD0alO70P39bLT0>@37alL0aLG50<;2`P30`<00^k^k0;Bd]02b/[80[jn_0:j^
[P2[Zj/0Z:RX0:>SX`2PX:00W9bL09RHV02BTY80Q8B407alO01aLG40IVIV05YJFP12@T80=cLg03<c
<`0^;Rh0:BTY02HV9P0M7Ad06a/K01LG5`0D51@05QHF01dM7@0P82008b<S02HV9P0Y:BT0;2`/034a
<@0d=3@0=cLg03Xj>P0l?3`0@T9204E5A@17AdL0BTY:04a<C01BDU80E5AD05MGE`1JFUX0G5aL05mO
G`1TI6@0IVIV06UYJ@0N0?ooo`0P09bLW02QXJ40[:b/0;6a/@2f][H0_;bl0<;2`P37alL0dm?C0=WI
f@3Ogml0i^KV0>k^kP3bl_80jNWY0>7Qh@3IfMT0d];B0<;2`P2i^KT0/[:b0:b/[02VYZH0XJ6Q09^K
V`2LW9`0WYjN09nOW`2PX:00XJ6Q0:2PX02NWYh309bLW00<09fMW@2NWYh0WinO0:6QX@2SXj<0Z:RX
0:ZZZP2/[:`0[Zj^0:n_[`2b/[80/k>c0P2d];@0102c/k<0/K6a0:j^[P2/[:`20:ZZZP0e0:VYZ@2V
YZH0YJFU0::RXP2QXJ40WinO09fMW@2IVIT0UYJF09>CT`2>SXh0R8R807YjNP1bLW80IVIV05]KF`1@
D500=SHf02XZ:P0S8b<07QhN01PH600C4a<02PX:00T92@051@D00@4100@4100?3`l05ADE01XJ6P0O
7al092@T02TY:@0c<c<0>3Ph03dm?@12@T80AdM7051@D01DE5@0FEUI05eMG@1RHV80Jf][06m_K`1d
M7@0N7Qh07alO021PH40RHV908j>SP2BTY807P3oool0802a/K40/[:b0;>c/`2d];@0]KFe0;Jf]P2g
]kL0^KVi0;^k^`2m_Kd0_kno0<;2`P36a/H0alO70;jn_P2g]kL0/K6a0:f][@2VYZH0Xj>S0:2PX02M
WId0VYZJ09NGU`2@T900SXj>08^;R`28R8P0QhN708B4Q01oOgl0NWYj0`1fMWH01P1hN7P0NWYj07em
O@1oOgl0PH6108F5Q@@0QXJ600/0QHF508>3P`21PH40Ogmo07alO01jNWX0MWIf07EeM@1fMWH0N7Qh
07]kN`0207inOP0307emO@1lO7`0O7al0080O7al02d0Ng]k07UiN@1fMWH0Lg=c06e]K@1XJ6P0HV9R
05iNGP1HF5P0BTY:0492@P0m?Cd0>SXj03Hf=P0c<c<0;bl_02h^;P0/;2`0:BTY02`/;00f=SH0>c/k
0410@014A4@0BDU904i>CP1GEeL0Fe]K061PH01TI6@0J6QX075aL@1eMGD0NGUi07emO@21PH40RHV9
08f=S@2ATI40UIFE09VIV@2MWId0Y:BT0:RXZ02/[:`08P3oool00200oooo00`0Lg=c07YjNP28R8P0
T92@09NGU`2NWYh0YZJV0:f][@2m_Kd0aLG50<g=c@3Fe]H20=oOg`0A0=_Kf`3De=@0dM7A0<_;b`2k
^k/0/[:b0:ZZZP2SXj<0W9bL09NGU`2BTY80UIFE09VIV@2LW9`0WinO0:FUY@2WYjL00P2XZ:P20:VY
Z@80ZZZZ02T0Zj^[0:b/[02][Jd0/;2`0;6a/@2c/k<0]KFe0;Ng]`2k^k/0_Kfm0;no_`31`L40`/;2
0<?3``32`/80`L710<30`02o_kl0_Kfm0;Vi^@2g]kL0];Bd0;6a/@2_[jl0Zj^[0:JVYP2SXj<0WinO
09VIV@2DU9@0QhN707moO`1dM7@0JFUY05eMG@14A4@0>3Ph03Lg=`0b<S80:b/[02XZ:P0201lO7`0L
01XJ6P0I6AT07AdM028R8P0U9BD0:2PX02XZ:P0];Bd0<30`03De=@0h>3P0>SXj03dm?@0o?cl0A4A4
04M7A`19BDT0C4a<04i>CP1CDe<0EUIF05QHF01KFe/0GEeM05mOG`1TI6@0IfMW06UYJAh0oooo01d0
W9bL0:6QX@2[Zj/0/K6a0;Jf]P2k^k/0`L710<K6aP3Bd]80f=SH0=oOg`3UiND0kNg]0>[ZjP3Shn<0
g=cL0=OGe`3AdM40`L710;Vi^@2b/[80Zj^[0:BTY02OWil0V9RH09VIV@2JVYX0Vi^K09bLW00409fM
W@80WYjN00X0X:2P0:6QX@2RXZ80Y:BT0:FUY@2YZJT0ZZZZ0:b/[02][Jd0[jn_0P2a/K420;:b/P80
/K6a01/0[jn_0:f][@2/[:`0Zj^[0:VYZ@2WYjL0YJFU0:>SX`2RXZ80X:2P09fMW@2HV9P0UIFE096A
T@2;Rh/0QXJ607QhN01_Kfl0I6AT05QHF01;Bd/0<C4a02<S8`0P82006QXJ01<C4`0A4A400P071`L2
00410@0J00L71`0B4Q805aLG01dM7@0R8R809bLW02`/;00e=CD0>SXj03lo?`14A4@0B4Q8055AD@1F
EUH0FUYJ05mOG`1SHf<0K6a/071`L01dM7@0NGUi07emO@21PH40RXZ:08j>SP2BTY8N0?ooo`050;2`
/02a/K40/[:b0;:b/P2c/k<00P2d];@0602e]KD0][Jf0;Ng]`2i^KT0^[Zj0;bl_02i^KT0/k>c0:f]
[@2ZZZX0YZJV09nOW`2LW9`0VIVI09NGU`2CTi<0TI6A08^;R`2:RXX0R8R808J6QP24Q8@0Ogmo07em
O@80O7al0P1mOGd01@1oOgl0P8200861P@23Ph<0Q8B40080QhN70`28R8P01P26QXH0QHF508B4Q022
PX80PH6107moO`80O7al0P1kNg/707YjNP0^07QhN01fMWH0M7Ad079bLP1_Kfl0IVIV065QH@1LG5`0
EUIF04m?C`10@400>3Ph03@d=00a<C40;Bd]02`/;00X:2P09bLW02<S8`0T92@0:RXZ03@d=00i>CT0
?clo04=3@`18B4P0CDe=05IFEP1KFe/0GemO06ATI01XJ6P0L71`07EeM@1iNGT0OGem0861P@29RHT0
SHf=096AT@2EUID0VIVI09fMW@2TY:@0Z:RX0:b/[280oooo000P0?ooo`0Q07=cL`1jNWX0RHV9092@
T02GUiL0WinO0:NWY`2^[Zh0_[jn0<O7a`3?cll0fMWI0>?Sh`3Rh^80gMgM0=KFeP3Bd]80c<c<0;jn
_P2e]KD0[Jf]0:FUY@2NWYh0VIVI09:BTP2EUID0V9RH09^KV`2MWId0Xj>S0:BTY02UYJD0YjNW0080
Z:RX00l0ZJVY0:ZZZP2ZZZX0Zj^[0:b/[02_[jl0/K6a0;:b/P2d];@0][Jf0;Vi^@2k^k/0_;bl0;jn
_P2o_kl00P30`<00>02o_kl0_[jn0;fm_@2l_;`0^KVi0;Ng]`2e]KD0/[:b0:n_[`2][Jd0YjNW0:>S
X`2OWil0VYZJ09BDU027QhL0OWin07AdM01YJFT0GEeM04=3@`0g=cL0=SHf03<c<`0];Bd0;2`/024Q
8@0P82006a/K01dM7@0P82009BDU02PX:00Z:RX0;Bd]02l_;`0b<S80=cLg03Ti>@0l?3`0?Shn0451
@@16ATH0B4Q804Y:BP1=CDd0Cdm?05ADE01FEUH0FEUI05]KF`1MGEd0H61P06ATI01WIfL0JFUY7P3o
ool07@2LW9`0XJ6Q0:^[Z`2`/;00]KFe0;^k^`30`<00aLG50=7Ad@3GemL0gMgM0>CTi03[jn/0j>SX
0>;RhP3Kfm/0e]KF0=3@d031`L40^KVi0;:b/P2ZZZX0Xj>S09jNWP2GUiL0V9RH09VIV@2JVYX0Vi^K
0080W9bL00l0WIfM09jNWP2NWYh0WinO0:6QX@2RXZ80Xj>S0:FUY@2VYZH0ZJVY0:^[Z`2/[:`0[Jf]
0:j^[P2`/;00102a/K40>P2`/;00[jn_0:j^[P2][Jd0Zj^[0:ZZZP2WYjL0YZJV0:BTY02RXZ80X:2P
09jNWP2HV9P0UIFE092@T02:RXX0QHF507MgM`1^KVh0HV9R05IFEP1:BTX0;Rh^024Q8@0N7Qh061PH
018B4P0@41001PH600D51@0000000`<300T92@0D51@06ATI01hN7P0S8b<0:2PX02d];@0g=cL0>c/k
0410@015ADD0BDU9059BDP1GEeL0Fe]K05mOG`1TI6@0K6a/075aL@1eMGD0NGUi07emO@21PH40RXZ:
08j>SP2BTY8N0?ooo`80/;2`0P2a/K430;:b/P040;>c/`2d];@0];Bd0;Fe]@80][Jf0180/[:b0:j^
[P2[Zj/0Z:RX0:>SX`2LW9`0VIVI09NGU`2DU9@0T92@08j>SP29RHT0R8R808N7Q`25QHD0Q8B40861
P@20P80407moO`050861P@22PX80Ph>308F5Q@26QXH00P28R8P308V9R@0708R8R027QhL0QXJ608F5
Q@23Ph<0PX:207moO`0207inOP0407emO@1lO7`0Ng]k07]kN`80NWYj0P1iNGT0;P1fMWH0MGEe07=c
L`1_Kfl0KFe]06EUI@1QHF40FEUI059BDP1<C4`0?Cdm03De=@0a<C40;Bd]02TY:@0X:2P092@T02<S
8`0P82008b<S02TY:@0d=3@0>CTi03hn?P13@d<0B4Q804e=C@1FEUH0Fe]K05mOG`1TI6@0J6QX071`
L01eMGD0NGUi07emO@21PH40RHV908f=S@2ATI40UIFE09VIV@2MWId0Y:BT0:RXZ02/[:`R0?ooo`00
803oool0901cLg<0NWYj08V9R@2@T900V9RH09nOW`2WYjL0[jn_0;no_`38b<P0dM7A0=[JfP3Ti>@0
iNGU0=oOg`3Hf=P0dm?C0<k>cP30`<00^;Rh0;2`/02XZ:P0X:2P09^KV`2DU9@0UIFE09NGU`2JVYX0
W9bL0:6QX@2SXj<0Y:BT0:FUY@2VYZH0YjNW0:RXZ080ZJVY00`0ZZZZ0:^[Z`2^[Zh0[jn_0;6a/@2b
/[80];Bd0;Ng]`2i^KT0^[Zj0;^k^`2l_;`30;fm_@0g0;bl_02k^k/0^[Zj0;Rh^02f][H0];Bd0;:b
/P2`/;00[Jf]0:NWY`2TY:@0X:2P09ZJVP2EUID0QhN707inOP1dM7@0JFUY05eMG@13@d<0>3Ph03De
=@0d=3@0;bl_02h^;P0T92@08B4Q01hN7P0Q8B408b<S02PX:00Z:RX0;Bd]02l_;`0b<S80=3@d03Ti
>@0k>c/0?Cdm0410@012@T80AdM704U9B@1;Bd/0CTi>051@D01EEED0EeMG05UIF@1LG5`0GUiN061P
H01UIFD0IfMW06UYJ@0N0?ooo`0M09^KV`2PX:00Zj^[0;2`/02e]KD0^[Zj0;no_`35aLD0d=3@0=KF
eP3Lg=`0h^;R0>WYj@3WinL0hN7Q0=_Kf`3EeMD0clo?0<71`@2i^KT0/K6a0:ZZZP2RXZ80WIfM09JF
UP2GUiL0V9RH09VIV@2JVYX00P2LW9`03P2MWId0WYjN09nOW`2PX:00XZ:R0:>SX`2TY:@0YJFU0:NW
Y`2ZZZX0Zj^[0:b/[02][Jd0[Zj^1P2`/;00>@2_[jl0[Zj^0:f][@2/[:`0ZZZZ0:RXZ02VYZH0Y:BT
0::RXP2PX:00WYjN09RHV02DU9@0Shn?08Z:RP24Q8@0MWIf06a/K01PH600EEEE04Q8B00[:b/07alO
01XJ6P0F5QH04A4A00l?3`061PH00P82000000051@D02`/;01DE5@0K6a/0820P02DU9@0Z:RX0;Rh^
03Ph>00m?Cd0@D5104I6AP1:BTX0De=C05MGE`1LG5`0H61P06ATI01]KFd0LG5a07EeM@1iNGT0OWin
08:2PP2:RXX0SXj>09:BTP0N0?ooo`@0/;2`2@2a/K402`2^[Zh0Zj^[0:RXZ02UYJD0XJ6Q09ZJVP2G
UiL0Ti>C092@T02<S8`0RXZ:0080QhN700@0QXJ608B4Q023Ph<0PX:21021PH402022PX80Q8B408F5
Q@26QXH0QhN708R8R029RHT0RXZ:0`2;Rh/208V9R@0908N7Q`26QXH0QHF508B4Q022PX80PH610820
P01oOgl0OWin0080O7al0380Ng]k07YjNP1iNGT0NGUi07IfMP1dM7@0LG5a06i^KP1[Jf/0Hf=S05eM
G@1FEUH0D51@04U9B@0i>CT0<S8b02h^;P0Y:BT09RHV02@T900P82007QhN01dM7@0R8R80:2PX03<c
<`0i>CT0?Shn04=3@`18B4P0CDe=05IFEP1KFe/0GemO06ATI01XJ6P0L71`07EeM@1iNGT0OGem0861
P@29RHT0SHf=096AT@2EUID0VIVI09fMW@2TY:@0Z:RX0:b/[280oooo000P0?ooo`0b07=cL`1jNWX0
RHV9096AT@2HV9P0X:2P0:RXZ02`/;00`<300<W9b@3Bd]80fm_K0>GUi@3YjNT0hn?S0=gMg@3GemL0
d=3@0<?3``2k^k/0/[:b0:^[Z`2SXj<0WIfM09FEU@2FUYH0UiNG09VIV@2LW9`0X:2P0:6QX@2SXj<0
Y:BT0:FUY@2VYZH0YjNW0:RXZ02YZJT0ZZZZ0:^[Z`2][Jd0[Zj^0;2`/02a/K40/[:b0;Fe]@2g]kL0
^;Rh0;Vi^@2j^[X40;^k^`0F0;Zj^P2i^KT0]kNg0;Jf]P2d];@0/[:b0;2`/02^[Zh0Z:RX0:BTY02P
X:00Vi^K09FEU@28R8P0OWin07AdM01YJFT0GEeM04A4A00i>CT0=3@d03<c<`80;Rh^01h0:BTY02<S
8`0R8R8092@T02LW9`0[:b/0;Bd]02l_;`0b<S80=3@d03Hf=P0k>c/0?Cdm03lo?`11@D40A4A404Q8
B01:BTX0CDe=04m?C`1ADE40EEEE05QHF01JFUX0G5aL05iNGP1PH600IFEU06MWI`1YJFTN0?ooo`0H
09^KV`2PX:00ZZZZ0:n_[`2d];@0^KVi0;jn_P34a<@0clo?0=CDe03Jf]X0h>3P0>KViP3WinL0hN7Q
0=[JfP3De=@0c/k>0<30`02i^KT0/K6a0:ZZZP2RXZ80WIfM0P2FUYH0402GUiL0V9RH09VIV@2KVi/0
W9bL09fMW@2NWYh0X:2P0:6QX@2SXj<0Y:BT0:FUY@2VYZH0Z:RX0:ZZZP2[Zj/20:f][@030:j^[P2_
[jl0/;2`00@0/;2`03T0[jn_0:j^[P2][Jd0[:b/0:ZZZP2XZ:P0YZJV0:BTY02RXZ80X:2P09jNWP2G
UiL0Ti>C08j>SP29RHT0Ph>307AdM01ZJVX0GemO05=CD`15ADD0:BTY01dM7@0H61P05ADE00l?3`0=
3@d01@D5000000020P801`L700d=3@0G5aL071`L024Q8@0V9RH0:b/[030`<00i>CT0?Shn0492@P17
AdL0Bd];05ADE01HF5P0GEeM065QH@1UIFD0KFe]079bLP1fMWH0NWYj07inOP22PX80RXZ:08j>SP2B
TY807P3oool20;2`/0H0[jn_0`2^[Zh20:f][@0;0:VYZ@2VYZH0Xj>S09nOW`2MWId0UiNG09>CT`2@
T900SHf=08Z:RP27QhL00P25QHD208B4Q080Ph>30P22PX8208>3P`0708B4Q026QXH0QhN708R8R029
RHT0RXZ:08^;R`0408b<S00708^;R`2:RXX0RHV908R8R027QhL0QXJ608>3P`0208:2PP0f0861P@20
P800OWin07emO@1kNg/0NWYj07UiN@1hN7P0MGEe079bLP1_Kfl0K6a/06UYJ@1PH600FUYJ05ADE01>
CTh0ADE503De=@0^;Rh0:b/[02PX:00T92@0820P01/K6`0I6AT071`L028R8P0X:2P0<c<c03Ti>@0n
?Sh0@d=304Q8B01=CDd0EUIF05]KF`1OGel0I6AT06QXJ01`L700MGEe07UiN@1mOGd0PH6108V9R@2=
SHd0TI6A09FEU@2IVIT0WIfM0:BTY02XZ:P0[:b/8P3oool00200oooo01P0Lg=c07YjNP29RHT0TI6A
09RHV02PX:00Z:RX0;2`/031`L40bLW90=?Cd`3Lg=`0i^KV0>c/k03Vi^H0h>3P0=[JfP3Cdm<0aLG5
0;fm_@2e]KD0[Jf]0:FUY@2OWil209NGU`0:09RHV02IVIT0Vi^K09nOW`2PX:00XJ6Q0:>SX`2TY:@0
YJFU0:JVYP80Z:RX00`0ZJVY0:ZZZP2/[:`0[Jf]0:j^[P2`/;00/K6a0;>c/`2e]KD0][Jf0;Ng]`2h
^;P50;Vi^@0E0;Rh^02f][H0];Bd0;>c/`2a/K40[jn_0:f][@2XZ:P0Y:BT09nOW`2KVi/0UIFE08R8
R01nOWh0MGEe06UYJ@1MGEd0ADE503/k>`0e=CD0<c<c0080;bl_01h0;2`/02HV9P0W9bL0:2PX02XZ
:P0^;Rh0<30`038b<P0d=3@0=SHf03Ph>00l?3`0?clo0451@@13@d<0ADE504U9B@1;Bd/0CTi>051@
D01BDU80EUIF05QHF01JFUX0GEeM05mOG`1QHF40IFEU06MWI`1YJFTN0?ooo`0H09^KV`2PX:00ZZZZ
0:n_[`2c/k<0^;Rh0;fm_@33`l<0cLg=0=?Cd`3Hf=P0g]kN0>CTi03Vi^H0h>3P0=WIf@3De=@0c/k>
0<30`02i^KT0/K6a0:VYZ@2RXZ80WIfM0`2FUYH03`2HV9P0VIVI09^KV`2MWId0WYjN09nOW`2PX:00
XJ6Q0:>SX`2UYJD0YZJV0:NWY`2XZ:P0Zj^[0:b/[0020:f][@030:j^[P2_[jl0/;2`00@0/;2`0P2^
[Zh0=`2][Jd0[:b/0:ZZZP2XZ:P0YZJV0:BTY02RXZ80X:2P09fMW@2GUiL0TY:B08f=S@28R8P0PX:2
079bLP1XJ6P0GEeM051@D012@T809RHV01`L700F5QH04a<C00d=3@0:2PX010@40000000410@02PX:
00l?3`0I6AT07QhN02<S8`0X:2P0;Bd]034a<@0j>SX0?clo04=3@`18B4P0C4a<05EEE@1IFET0GEeM
069RHP1VIVH0KVi^079bLP1fMWH0NWYj07inOP22PX80RXZ:08j>SP2BTY807P3oool00`2`/;00[jn_
0:n_[`030:j^[P80[Jf]0140[:b/0:^[Z`2ZZZX0ZZZZ0:VYZ@2TY:@0XJ6Q09jNWP2LW9`0VYZJ09BD
U02ATI40SHf=08Z:RP27QhL0QHF508B4Q00408>3P`<0Q8B40P25QHD01`26QXH0R8R808V9R@2:RXX0
Rh^;08b<S02=SHd00`2>SXh0@02=SHd0S8b<08b<S02;Rh/0RXZ:08V9R@28R8P0QHF508B4Q023Ph<0
PH610820P01nOWh0OGem07alO01jNWX0NGUi07QhN01cLg<0LG5a06i^KP1[Jf/0IfMW05eMG@1GEeL0
DE5A04U9B@11@D40<30`02XZ:P0X:2P092@T020P800L71`05QHF01DE5@0K6a/08R8R02PX:00c<c<0
>CTi03hn?P13@d<0B4Q804e=C@1FEUH0Fe]K05mOG`1TI6@0J6QX075aL@1eMGD0NGUi07emO@21PH40
RHV908f=S@2ATI40UIFE09VIV@2MWId0Y:BT0:RXZ02/[:`R0?ooo`00803oool06@1cLg<0NWYj08V9
R@2ATI40V9RH0:2PX02XZ:P0/;2`0<71`@3:b/X0dm?C0=cLg03WinL0m?Cd0>k^kP3Xj>P0h>3P0=WI
f@3:b/X0`L710;Zj^P2a/K40ZJVY0:BTY02LW9`00P2JVYX01P2KVi/0W9bL09jNWP2OWil0X:2P0::R
XP80Xj>S00d0YJFU0:JVYP2WYjL0YjNW0:RXZ02ZZZX0Zj^[0:b/[02][Jd0[Zj^0;2`/02a/K40/[:b
0080/k>c00<0];Bd0;Fe]@2e]KD00`2e]KD0=02c/k<0/[:b0;6a/@2`/;00[jn_0:f][@2XZ:P0Y:BT
0:2PX02KVi/0UYJF08N7Q`1oOgl0MGEe06YZJP1MGEd0ADE50410@00j>SX0=SHf030`<00_;bl0;2`/
02d];@0^;Rh0;bl_030`<00c<c<0=CDe03Lg=`0i>CT0>c/k03`l?010@400@T9204A4A016ATH0B4Q8
04a<C01>CTh0D51@059BDP1DE5@0F5QH05YJFP1LG5`0GUiN061PH01RHV80IVIV06QXJ01ZJVXN0?oo
o`0V09^KV`2PX:00ZJVY0:f][@2b/[80]kNg0;^k^`30`<00b/[:0<o?c`3De=@0fMWI0=oOg`3Ti>@0
h>3P0=_Kf`3De=@0c/k>0<30`02h^;P0/K6a0:VYZ@2RXZ80WIfM09NGU`2FUYH0UiNG09RHV02IVIT0
W9bL09fMW@2OWil0X:2P0::RXP2SXj<0YJFU0:NWY`2XZ:P20:VYZ@80[:b/00<0[Jf]0:j^[P2^[Zh0
0P2_[jl20;2`/080[jn_03T0[Zj^0:f][@2/[:`0Zj^[0:ZZZP2WYjL0YJFU0:>SX`2QXJ40WYjN09bL
W02EUID0TI6A08b<S025QHD0Ogmo06i^KP1TI6@0F5QH04Y:BP0l?3`0820P01XJ6P0D51@03`l?00P8
20061PH00P8200D51@0:2PX03`l?01@D500M7Ad08R8R02LW9`0[:b/0<30`03@d=00m?Cd0@T9204I6
AP1:BTX0CTi>05MGE`1KFe/0GemO06=SH`1WIfL0Kfm_07=cL`1gMgL0Ng]k07moO`23Ph<0Rh^;08n?
S`2CTi<07P3oool20:n_[`80[Jf]01D0[:b/0:^[Z`2ZZZX0ZJVY0:NWY`2UYJD0Y:BT0::RXP2PX:00
VIVI09ZJVP2HV9P0UYJF09BDU02>SXh0S8b<08R8R025QHD0Ph>30861P@20P8000P21PH402`22PX80
Ph>308F5Q@26QXH0QhN708R8R029RHT0RXZ:08b<S02=SHd0SXj>0080Shn?1@2ATI40?`2@T900Shn?
08n?S`2>SXh0SHf=08^;R`29RHT0QhN708J6QP24Q8@0Ph>30820P01nOWh0O7al07YjNP1hN7P0MWIf
075aL@1^KVh0Jf][06IVIP1RHV80EeMG055AD@19BDT0@41003Lg=`0V9RH08R8R01lO7`0L71`061PH
01DE5@0C4a<05aLG01dM7@0S8b<0:BTY03@d=00i>CT0?Shn04=3@`18B4P0CDe=05MGE`1KFe/0H61P
06ATI01XJ6P0LG5a07EeM@1iNGT0OGem0861P@29RHT0SHf=096AT@2EUID0VIVI09fMW@2TY:@0Z:RX
0:b/[00R0?ooo`00803oool06`1cLg<0NWYj08V9R@2ATI40V9RH0:2PX02XZ:P0/;2`0<30`039bLT0
d];B0=cLg03Vi^H0moOg0??cl`3/k>`0iNGU0=gMg@3=cLd0a<C40;bl_02d];@0[:b/0:JVYP2NWYh0
W9bL09^KV`0209bLW00709jNWP2OWil0X:2P0:6QX@2RXZ80Xj>S0:FUY@020:JVYP80YjNW00H0ZJVY
0:ZZZP2ZZZX0Zj^[0:b/[02^[Zh20:n_[`030;2`/02a/K40/[:b00D0/k>c03@0/[:b0;6a/@2`/;00
[Zj^0:f][@2/[:`0YjNW0:BTY02PX:00Vi^K09FEU@27QhL0OWin07EeM@1ZJVX0GEeM04I6AP12@T80
?3`l03Lg=`0a<C40<30`02h^;P0_;bl0<C4a038b<P0c<c<0=SHf03Ph>00i>CT0>c/k03dm?@0n?Sh0
@T9204A4A016ATH0B4Q804U9B@1=CDd0Cdm?055AD@1CDe<0EEEE05QHF01JFUX0G5aL05iNGP1PH600
HV9R06IVIP1XJ6P0JVYZ7P3oool06@2KVi/0WinO0:RXZ02][Jd0/K6a0;Jf]P2j^[X0_kno0<S8b03=
cLd0d];B0=OGe`3Lg=`0iNGU0>3Ph03Kfm/0e=CD0<k>cP30`<00^;Rh0;6a/@2YZJT0XZ:R09jNWP2H
V9P00P2GUiL03P2HV9P0VYZJ09fMW@2NWYh0WinO0:6QX@2RXZ80Xj>S0:JVYP2WYjL0Z:RX0:VYZ@2Z
ZZX0[:b/0P2][Jd20:j^[P80[jn_00@0/;2`0:n_[`2_[jl0[jn_0P2][Jd0=`2/[:`0ZZZZ0:ZZZP2W
YjL0Y:BT0::RXP2PX:00WYjN09^KV`2DU9@0Shn?08Z:RP24Q8@0OGem06a/K01QHF40EEEE04M7A`0i
>CT07QhN01TI6@0C4a<03@d=00H61P0410@00`<300P8200=3@d04A4A01HF5P0O7al092@T02TY:@0]
;Bd0<S8b03Hf=P0o?cl0@d=304M7A`1<C4`0D51@05QHF01LG5`0H61P06ATI01XJ6P0L71`07AdM01h
N7P0O7al07moO`23Ph<0Rh^;08n?S`2CTi<07P3oool08@2_[jl0[Zj^0:b/[02/[:`0Zj^[0:ZZZP2Y
ZJT0YjNW0:FUY@2SXj<0XJ6Q09nOW`2LW9`0V9RH09JFUP2CTi<0TY:B08n?S`2;Rh/0RHV908J6QP23
Ph<0PH610820P01oOgl0P8200861P@22PX80Q8B408J6QP27QhL0R8R808Z:RP0208^;R`0608f=S@2>
SXh0Shn?092@T02ATI40TY:B102CTi<0?`2BTY80TI6A096AT@2@T900SXj>08f=S@2:RXX0RHV908N7
Q`25QHD0Q8B40861P@1oOgl0OGem07YjNP1hN7P0MGEe071`L01/K6`0J6QX06ATI01PH600E5AD04e=
C@14A4@0>c/k03<c<`0R8R807QhN01/K6`0H61P051@D018B4P0C4a<061PH01hN7P0S8b<0:BTY03@d
=00i>CT0?clo04A4A019BDT0CTi>05MGE`1LG5`0H61P06ATI01YJFT0LG5a07EeM@1jNWX0OWin08:2
PP2:RXX0SHf=096AT@2EUID0VIVI09fMW@2UYJD0Z:RX0:b/[00R0?ooo`00803oool03@1cLg<0NWYj
08V9R@2@T900V9RH0:2PX02WYjL0[jn_0<30`038b<P0dM7A0=_Kf`3Ti>@00P3inOT02`3bl_80j^[Z
0>;RhP3Bd]80b<S80;no_`2f][H0[Zj^0:RXZ02PX:00WYjN00<0WIfM0P2OWil01@2PX:00XJ6Q0::R
XP2SXj<0Y:BT0080YJFU0P2VYZH01@2WYjL0Z:RX0:VYZ@2YZJT0ZZZZ0080[:b/0P2^[Zh20:n_[`03
0;2`/02a/K40/K6a00<0/K6a01@0/;2`0:n_[`2][Jd0[:b/0:^[Z`2WYjL0Xj>S09nOW`2KVi/0UYJF
08R8R01oOgl0MGEe06][J`1OGel0AdM704=3@`0o?cl0>CTi03<c<`80<C4a01d0<S8b03<c<`0e=CD0
=SHf03Ti>@0j>SX0?3`l03dm?@0o?cl0@D5104A4A016ATH0AdM704U9B@1;Bd/0CTi>051@D01BDU80
E5AD05IFEP1IFET0Fe]K05eMG@1OGel0H61P069RHP1VIVH0J6QX06YZJP0N0?ooo`0I09^KV`2OWil0
Z:RX0:b/[02`/;00]KFe0;Vi^@2m_Kd0a/K60<_;b`3@d=00e=CD0=WIf@3Rh^80h>3P0=_Kf`3De=@0
c/k>0<30`02i^KT0/K6a0:ZZZP2SXj<0WinO09VIV@0209RHV00?09VIV@2KVi/0WYjN09nOW`2PX:00
XZ:R0:>SX`2TY:@0YjNW0:RXZ02YZJT0ZZZZ0:^[Z`2/[:`0[Jf]00<0[Zj^1@2_[jl0>P2^[Zh0[Jf]
0:b/[02[Zj/0ZZZZ0:VYZ@2VYZH0Y:BT0:6QX@2OWil0WIfM09ZJVP2CTi<0SXj>08R8R022PX80Ng]k
06UYJ@1NGUh0DE5A04A4A00f=SH071`L01LG5`0B4Q802`/;00D51@030`<01PH600/;2`0?3`l051@D
01PH600R8R809RHV02/[:`0_;bl0<c<c03Ph>010@400ADE504U9B@1=CDd0DE5A05UIF@1MGEd0HF5Q
06EUI@1YJFT0L71`07AdM01hN7P0O7al0820P024Q8@0Rh^;08n?S`2CTi<N0?ooo`0U0:n_[`2^[Zh0
[:b/0:^[Z`2ZZZX0Z:RX0:NWY`2VYZH0XZ:R0:6QX@2NWYh0W9bL09VIV@2CTi<0Shn?08j>SP2<S8`0
RXZ:08N7Q`25QHD0Q8B408:2PP20P800Ogmo07inOP1oOgl0PH6108:2PP24Q8@0QhN708R8R029RHT0
Rh^;08b<S02=SHd0Shn?096AT@0209:BTP0309>CT`2DU9@0UIFE00<0UIFE03l0U9BD09>CT`2CTi<0
TI6A092@T02?Shl0S8b<08^;R`29RHT0QhN708J6QP21PH40Ogmo07emO@1jNWX0N7Qh07EeM@1^KVh0
Jf][06IVIP1QHF40G5aL04m?C`17AdL0?Shn03Hf=P0];Bd07QhN01XJ6P0G5aL04a<C010@400?3`l0
4a<C01TI6@0O7al092@T02XZ:P0e=CD0>SXj03lo?`14A4@0BDU904i>CP1GEeL0G5aL061PH01UIFD0
JFUY079bLP1fMWH0NWYj07inOP22PX80RXZ:08j>SP2BTY80UIFE09VIV@2MWId0YJFU0:RXZ02/[:`0
8P3oool00200oooo01/0Lg=c07YjNP29RHT0T92@09RHV02OWil0YjNW0:n_[`2o_kl0alO70=3@d03I
fMT0h^;R0?Ogm`3lo?`0moOg0>o_k`3Xj>P0e]KF0<g=c@33`l<0^KVi0;6a/@2ZZZX0XZ:R0:2PX02O
Wil00P2NWYh00`2OWil0X:2P0:2PX0020:6QX@040::RXP2SXj<0Y:BT0:BTY080YJFU00<0YZJV0:NW
Y`2WYjL00P2XZ:P01P2YZJT0ZZZZ0:^[Z`2[Zj/0[:b/0:f][@<0[Zj^0`2_[jl0<`2^[Zh0[Jf]0:b/
[02[Zj/0ZZZZ0:FUY@2SXj<0WinO09ZJVP2EUID0R8R80820P01eMGD0Jf][061PH017AdL0@d=30451
@@0j>SX0=SHf03<c<`0d=3@0=CDe03Hf=P0h>3P0>CTi03/k>`0m?Cd0?Shn0410@011@D40@d=304I6
AP17AdL0BDU904];B`1<C4`0D51@055AD@1CDe<0EEEE05IFEP1JFUX0G5aL05eMG@1OGel0HF5Q06=S
H`1VIVH0J6QX06YZJP0N0?ooo`0J09^KV`2OWil0YjNW0:^[Z`2_[jl0];Bd0;Rh^02l_;`0aLG50<W9
b@3=cLd0dM7A0=KFeP3Ng]h0h>3P0=_Kf`3De=@0c/k>0<71`@2j^[X0/[:b0:ZZZP2TY:@0WinO09ZJ
VP2IVIT209ZJVP0=09bLW02NWYh0X:2P0:6QX@2SXj<0Y:BT0:FUY@2XZ:P0ZJVY0:ZZZP2[Zj/0[:b/
0:f][@030:j^[PH0[jn_03X0[Zj^0:f][@2/[:`0Zj^[0:ZZZP2XZ:P0YJFU0:>SX`2PX:00WYjN09bL
W02IVIT0TI6A08b<S026QXH0P82007UiN@1UIFD0FUYJ04i>CP11@D40=3@d01XJ6P0E5AD0410@00T9
2@051@D00`<300T92@0=3@d04Q8B01HF5P0K6a/092@T02PX:00];Bd0<C4a03De=@0j>SX0@T9204I6
AP1:BTX0CTi>059BDP1JFUX0GUiN069RHP1VIVH0JVYZ075aL@1eMGD0NGUi07alO020P800Q8B408^;
R`2?Shl0Ti>C7P3oool09P2_[jl0[Zj^0:^[Z`2ZZZX0ZJVY0:NWY`2VYZH0Y:BT0:6QX@2NWYh0W9bL
09VIV@2FUYH0SXj>08b<S029RHT0QhN708J6QP23Ph<0PX:20861P@1oOgl0OWin07emO@1nOWh0Ogmo
0861P@23Ph<0QHF508R8R029RHT0Rh^;08b<S02>SXh0Shn?09:BTP2CTi<0U9BD0P2EUID509NGU`80
UYJF01d0UIFE09BDU02CTi<0TI6A08j>SP2<S8`0Rh^;08V9R@27QhL0PX:207moO`1mOGd0NWYj07Mg
M`1dM7@0KFe]06UYJ@1TI6@0GemO05UIF@1:BTX0@T9203Ti>@0`<300:2PX01/K6`0G5aL04a<C00l?
3`0200d=3@0N01@D500J6QX07alO02DU9@0[:b/0=CDe03/k>`10@400ADE504Y:BP1?Cdl0F5QH05aL
G01QHF40IFEU06YZJP1bLW80MWIf07YjNP1nOWh0PX:208Z:RP2>SXh0TY:B09JFUP2IVIT0WIfM0:FU
Y@2XZ:P0[:b/8P3oool00200oooo01X0Lg=c07YjNP28R8P0T92@09NGU`2OWil0YZJV0:j^[P2n_[h0
a/K60<k>cP3GemL0h>3P0??cl`3moOd0o?cl0?KfmP3^k^h0g=cL0=7Ad@37alL0_Kfm0;>c/`2/[:`0
Y:BT0::RXPH0X:2P0P2QXJ400`2RXZ80Xj>S0:>SX`030:BTY080YJFU0`2VYZH0102WYjL0Z:RX0:VY
Z@2YZJT20:ZZZP80Zj^[1@2/[:`20:^[Z`0`0:ZZZP2YZJT0Y:BT0::RXP2NWYh0VYZJ09FEU@28R8P0
P82007IfMP1[Jf/0HF5Q04Y:BP15ADD0@D5103/k>`0g=cL0=CDe03Lg=`0h>3P0>CTi03Xj>P0k>c/0
?Shn03lo?`10@400@T9204=3@`15ADD0AdM704U9B@1:BTX0C4a<04i>CP1ADE40DU9B05ADE01FEUH0
EeMG05]KF`1LG5`0GUiN061PH01QHF40Hf=S06IVIP1XJ6P0JVYZ7P3oool09P2JVYX0WYjN0:JVYP2Z
ZZX0[Zj^0;>c/`2g]kL0^k^k0<?3``37alL0bl_;0<o?c`3Cdm<0f][J0=kNgP3Jf]X0eMGE0<o?c`32
`/80^k^k0;>c/`2/[:`0YJFU0:2PX02KVi/0VYZJ09^KV`2LW9`0WIfM09nOW`2QXJ40XZ:R0:BTY02U
YJD0YZJV0:VYZ@2ZZZX0Zj^[0P2/[:`20:j^[PL0[jn_0P2^[Zh0>@2/[:`0Zj^[0:ZZZP2YZJT0YjNW
0:BTY02RXZ80WinO09fMW@2JVYX0UiNG08n?S`2:RXX0Q8B407emO@1fMWH0HV9R05MGE`1;Bd/0?Shn
038b<P0H61P04a<C00l?3`092@T01@D500@4100;2`/0410@01@D500I6AT07AdM02HV9P0Z:RX0;bl_
03<c<`0g=cL0>c/k04A4A018B4P0C4a<04m?C`1CDe<0Fe]K05mOG`1SHf<0IfMW06YZJP1bLW80MWIf
07UiN@1mOGd0PH6108B4Q02<S8`0Shn?09>CT`0N0?ooo`0A0:n_[`2][Jd0Zj^[0:VYZ@2XZ:P0YZJV
0:FUY@2SXj<0WinO09fMW@2JVYX0UiNG09BDU02<S8`0R8R808>3P`21PH400P20P8000`1oOgl0OWin
07emO@0207emO@0>07inOP1oOgl0PH6108>3P`25QHD0RHV908^;R`2<S8`0SXj>08n?S`2ATI40U9BD
09FEU@2FUYH209NGU`H0VIVI03h0V9RH09NGU`2FUYH0UIFE09>CT`2@T900SXj>08b<S02:RXX0R8R8
08>3P`20P800OGem07YjNP1gMgL0M7Ad06a/K01WIfL0HV9R05aLG01EEED0ADE503`l?00d=3@0;2`/
02@T900F5QH04a<C010@400=3@d02`/;00`<300E5AD06a/K020P800V9RH0:b/[03Hf=P0k>c/0@D51
04I6AP1:BTX0Cdm?05UIF@1MGEd0HF5Q06IVIP1ZJVX0LW9b07MgM`1kNg/0Ogmo08>3P`2:RXX0SXj>
09:BTP2FUYH0VYZJ09fMW@2UYJD0Z:RX0:b/[280oooo000P0?ooo`0M07=cL`1jNWX0R8R808n?S`2F
UYH0WIfM0:BTY02/[:`0^k^k0<?3``3;bl/0dm?C0=_Kf`3/k>`0m?Cd0?_kn`3oool0no_k0>GUi@3J
f]X0clo?0<C4a02j^[X0/[:b0:NWY`2UYJD0Y:BT0:>SX`2RXZ801@2QXJ440::RXPT0Xj>S0`2TY:@0
0`2UYJD0YZJV0:NWY`030:NWY`<0Z:RX0340YjNW0:JVYP2VYZH0XZ:R09nOW`2LW9`0V9RH09BDU028
R8P0P82007MgM`1^KVh0I6AT059BDP1<C4`0ADE50410@00l?3`0>c/k03dm?@0n?Sh0?clo0410@011
@D40@d=304A4A015ADD0ATI604M7A`18B4P0Bd];04a<C01>CTh0Cdm?051@D01CDe<0EEEE05IFEP1H
F5P0FEUI05aLG01NGUh0GemO065QH@1RHV80I6AT06MWI`1XJ6P0JVYZ01h0oooo01/0VYZJ09jNWP2U
YJD0ZJVY0:f][@2`/;00];Bd0;Rh^02o_kl0`l?30<K6aP3:b/X0cLg=0=?Cd`3De=@0e]KF0=GEe@3C
dm<0a/K60;no_`2g]kL0[jn_0:VYZ@2SXj<0WYjN09fMW@2NWYh00P2OWil0202RXZ80Xj>S0:FUY@2V
YZH0YjNW0:RXZ02[Zj/0[:b/0P2][Jd00`2^[Zh0[jn_0;2`/0030;2`/0@0[jn_03/0[Zj^0:f][@2[
Zj/0ZZZZ0:VYZ@2WYjL0YJFU0:6QX@2OWil0WIfM09ZJVP2GUiL0U9BD08^;R`25QHD0OWin07IfMP1^
KVh0Fe]K051@D014A4@0>3Ph02/[:`0F5QH04a<C00d=3@0820P01PH600L71`0@41005ADE01XJ6P0N
7Qh08R8R02/[:`0_;bl0<c<c03Lg=`0k>c/0?clo04M7A`1;Bd/0Cdm?059BDP1FEUH0GUiN065QH@1U
IFD0JFUY06a/K01cLg<0MgMg07YjNP1nOWh0PH6108F5Q@2<S8`0Shn?09>CT`0N0?ooo`0C0:j^[P2]
[Jd0ZZZZ0:RXZ02VYZH0YJFU0:>SX`2QXJ40W9bL09ZJVP2GUiL0U9BD096AT@28R8P0Ph>307emO@1i
NGT0NWYj07emO@0207alO00D07]kN`1lO7`0O7al07moO`20P800Ph>308F5Q@27QhL0Rh^;08f=S@2?
Shl0TI6A09:BTP2DU9@0UiNG09RHV02JVYX0Vi^K09bLW02MWId409jNWP0K09fMW@2LW9`0W9bL09^K
V`2IVIT0UiNG09>CT`2ATI40Shn?08b<S02:RXX0Ph>30820P01mOGd0NGUi07IfMP1aLG40IfMW069R
HP1KFe/0De=C04];B`0j>SX0<S8b02TY:@0P82005aLG00802`/;02802@T900L71`0820P02`/;01LG
5`0M7Ad08R8R02PX:00];Bd0>3Ph03dm?@12@T80AdM704a<C01ADE40FUYJ05iNGP1SHf<0IfMW06][
J`1dM7@0N7Qh07alO01oOgl0Ph>308^;R`2?Shl0Ti>C09JFUP2JVYX0WYjN0:FUY@2YZJT0[:b/8P3o
ool00200oooo01d0LW9b07UiN@27QhL0SXj>09FEU@2LW9`0Xj>S0:^[Z`2j^[X0`L710<W9b@3@d=00
f=SH0>OWi`3^k^h0mOGe0?[jnP3moOd0jNWY0=kNgP3Cdm<0b<S80;jn_P2e]KD0ZZZZ0:NWY`2UYJD0
Y:BT0:>SX`0;0::RXPP0XJ6Q0`2RXZ800`2SXj<0Y:BT0:FUY@040:FUY@0b0:JVYP2UYJD0YJFU0:BT
Y02QXJ40WYjN09^KV`2GUiL0Ti>C08R8R020P800N7Qh06m_K`1UIFD0EUIF04m?C`18B4P0@d=30410
@00o?cl0@4100451@@12@T80@d=304A4A015ADD0ATI604M7A`18B4P0BDU904Y:BP1=CDd0CTi>04m?
C`1@D500DU9B05ADE01FEUH0EeMG05UIF@1JFUX0GEeM05iNGP1PH600HF5Q06=SH`1TI6@0IfMW06UY
J@1ZJVXN0?ooo`0J09ZJVP2NWYh0YJFU0:RXZ02/[:`0[jn_0;>c/`2f][H0_Kfm0<71`@34a<@0alO7
0<[:bP3@d=00d];B0=?Cd`3EeMD0e]KF0<W9b@31`L40^KVi0;6a/@2[Zj/0YJFU0:2PX02OWil20:2P
X0090:6QX@2SXj<0YJFU0:JVYP2WYjL0Z:RX0:ZZZP2/[:`0[Jf]0080[Zj^00<0[jn_0;2`/02`/;00
0P2a/K420;2`/080[jn_03`0[Zj^0:f][@2/[:`0ZZZZ0:VYZ@2XZ:P0YZJV0:BTY02PX:00WYjN09^K
V`2HV9P0UIFE09:BTP28R8P0PX:207YjNP1bLW80JVYZ05MGE`1<C4`0@41003@d=00V9RH061PH01<C
4`0<30`020P800L71`0:2PX04a<C01PH600L71`08B4Q02DU9@0];Bd0<C4a03De=@0i>CT0?Cdm0451
@@19BDT0C4a<051@D01DE5@0EeMG05mOG`1RHV80IVIV06UYJ@1]KFd0M7Ad07QhN01kNg/0OWin08:2
PP25QHD0S8b<092@T02CTi<N0?ooo`0D0:j^[P2][Jd0ZJVY0:RXZ02VYZH0Y:BT0::RXP2PX:00Vi^K
09VIV@2FUYH0Ti>C092@T028R8P0Q8B40820P01mOGd0O7al07emO@1lO7`407]kN`0A07inOP21PH40
Ph>308F5Q@28R8P0S8b<08j>SP2@T900TY:B09BDU02FUYH0VIVI09ZJVP2LW9`0WIfM09jNWP2PX:00
102QXJ40?`2PX:00WinO09jNWP2MWId0Vi^K09VIV@2EUID0Ti>C092@T02=SHd0RXZ:08B4Q021PH40
OGem07UiN@1dM7@0Kfm_06EUI@1NGUh0EUIF04i>CP15ADD0=3@d02`/;00S8b<06ATI00h>3P092@T0
20P800D51@0410@01PH600/;2`0H61P07QhN02@T900Y:BT0;bl_03Ti>@0n?Sh0@d=304Q8B01=CDd0
DU9B05]KF`1OGel0I6AT06QXJ01/K6`0M7Ad07QhN01lO7`0P82008B4Q02;Rh/0Shn?09>CT`2GUiL0
VYZJ09jNWP2UYJD0ZJVY0:b/[00R0?ooo`00803oool07@1bLW80NGUi08N7Q`2=SHd0U9BD09^KV`2R
XZ80ZJVY0;Rh^02o_kl0a/K60<k>cP3EeMD0i>CT0>[ZjP3alO40m_Kf0?_kn`3[jn/0hN7Q0=OGe`3<
c<`0`/;20;Vi^@2][Jd0ZZZZ0:RXZ02VYZH0YJFU00@0Xj>S102RXZ840:6QX@80X:2P0P2OWil00`2N
WYh0WinO09nOW`0209nOW`030:2PX02QXJ40XJ6Q00<0XZ:R0`2SXj<30::RXP0>09nOW`2MWId0VYZJ
09JFUP2ATI40RHV90820P01hN7P0L71`06EUI@1IFET0DU9B04];B`16ATH204=3@`80A4A400<0ADE5
04I6AP16ATH00P18B4P05`19BDT0BTY:04];B`1<C4`0CTi>04m?C`1ADE40DU9B05=CD`1FEUH0EeMG
05QHF01IFET0Fe]K05iNGP1OGel0H61P069RHP1SHf<0I6AT06MWI`1YJFT0JVYZ01h0oooo01T0VYZJ
09fMW@2TY:@0Z:RX0:^[Z`2^[Zh0/[:b0;Fe]@2l_;`0_kno0<;2`P35aLD0b<S80<g=c@3?cll0dM7A
0=?Cd`3Fe]H0b/[:0<;2`P2k^k/0/k>c0:f][@2XZ:P0XZ:R0080XJ6Q00X0XZ:R0:>SX`2UYJD0YZJV
0:NWY`2YZJT0ZZZZ0:^[Z`2][Jd0[Zj^0P2_[jl00`2`/;00/K6a0;6a/@030;6a/@0N0;2`/02_[jl0
[Zj^0:j^[P2][Jd0Zj^[0:VYZ@2XZ:P0YjNW0:FUY@2SXj<0WinO09bLW02JVYX0UYJF09>CT`2?Shl0
Q8B407inOP1fMWH0KVi^06EUI@1CDe<0B4Q803`l?00_;bl092@T01PH600B4Q8030`<0P092@T07`0=
3@d05QHF01/K6`0O7al08b<S02LW9`0`<300=3@d03Lg=`0k>c/0?clo04=3@`1:BTX0CTi>059BDP1E
EED0FEUI061PH01SHf<0IfMW06][J`1^KVh0MGEe07QhN01lO7`0Ogmo08:2PP26QXH0S8b<092@T02C
Ti<07P3oool04`2^[Zh0[:b/0:VYZ@2WYjL0YJFU0:>SX`2QXJ40WinO09ZJVP2HV9P0UIFE09:BTP2?
Shl0R8R808F5Q@21PH40Ogmo07inOP1lO7`0101jNWX04P1kNg/0Ogmo0861P@23Ph<0QXJ608R8R02=
SHd0Shn?096AT@2CTi<0UIFE09NGU`2KVi/0W9bL09jNWP2OWil0X:2P0::RXP80Xj>S0440Y:BT0:>S
X`2RXZ80XJ6Q0:2PX02NWYh0W9bL09^KV`2FUYH0U9BD096AT@2>SXh0Rh^;08B4Q020P800OGem07Qh
N01cLg<0KVi^065QH@1IFET0DE5A04U9B@10@400;Rh^02HV9P0L71`04A4A00/;2`061PH010@40082
0P030`<01PH600`<300I6AT07alO02DU9@0Z:RX0<30`03/k>`10@400ADE504U9B@1>CTh0De=C05aL
G01PH600I6AT06UYJ@1]KFd0MGEe07UiN@1mOGd0PH6108B4Q02<S8`0T92@09>CT`2GUiL0VYZJ09jN
WP2UYJD0ZJVY0:b/[00R0?ooo`00803oool07P1bLW80NGUi08J6QP2=SHd0U9BD09ZJVP2QXJ40Z:RX
0;Jf]P2m_Kd0a<C40<_;b`3Bd]80h>3P0>OWi`3]kNd0lo?c0?Win@3`l?00i>CT0=[JfP3?cll0a/K6
0;fm_@2`/;00[:b/0:ZZZP2XZ:P0YjNW0:FUY@<0Y:BT0P2SXj<0102RXZ80XJ6Q0:6QX@2QXJ420:2P
X00509nOW`2NWYh0WYjN09fMW@2LW9`01@2MWId309jNWP80WinO00<0X:2P0:6QX@2QXJ400`2PX:00
3`2NWYh0Vi^K09RHV02EUID0T92@08R8R022PX80NGUi071`L01WIfL0Fe]K05EEE@1?Cdl0BTY:04I6
AP0304M7A`80B4Q801X0BDU904Y:BP1;Bd/0Bd];04a<C01=CDd0CTi>051@D01ADE40DU9B05=CD`1D
E5@0EeMG05QHF01IFET0FUYJ05aLG01NGUh0H61P065QH@1RHV80Hf=S06EUI@1WIfL0JFUY06YZJQh0
oooo01T0VYZJ09fMW@2TY:@0YjNW0:ZZZP2][Jd0/K6a0;Bd]02j^[X0_Kfm0<30`033`l<0a/K60<_;
b`3=cLd0d=3@0=;BdP3Fe]H0c<c<0<C4a02m_Kd0]KFe0:n_[`2ZZZX0Y:BT00<0Xj>S00X0Y:BT0:JV
YP2WYjL0Z:RX0:ZZZP2[Zj/0[:b/0:j^[P2_[jl0/;2`0P2a/K440;:b/P0O0;6a/@2_[jl0[jn_0:j^
[P2][Jd0[:b/0:^[Z`2XZ:P0YjNW0:FUY@2SXj<0XJ6Q09fMW@2JVYX0UiNG09>CT`2@T900S8b<0861
P@1jNWX0LW9b06YZJP1QHF40Cdm?04=3@`0g=cL0;Bd]02<S8`0G5aL04Q8B00d=3@0200`<300O014A
4@0J6QX07QhN028R8P0V9RH0:RXZ038b<P0f=SH0>SXj03dm?@11@D40ADE504a<C01@D500De=C05MG
E`1JFUX0HF5Q06EUI@1XJ6P0K6a/06m_K`1fMWH0NGUi07alO020P800Ph>308J6QP2=SHd0T92@09>C
T`0N0?ooo`0Z0:j^[P2/[:`0ZJVY0:NWY`2UYJD0Xj>S0:6QX@2OWil0VYZJ09NGU`2DU9@0TY:B08j>
SP28R8P0QHF508:2PP20P800Ogmo07YjNP1kNg/0NWYj07UiN@1jNWX0Ng]k07moO`22PX80Q8B408J6
QP29RHT0SHf=092@T02BTY80U9BD09NGU`2IVIT0WIfM09jNWP2PX:00XJ6Q0::RXP2TY:@0YJFU0`2V
YZH0?`2TY:@0Xj>S0::RXP2PX:00WYjN09bLW02HV9P0UYJF09>CT`2?Shl0S8b<08B4Q020P800Ng]k
07IfMP1aLG40Jf][05eMG@1EEED0CDe=04A4A00k>c/0:BTY01hN7P0D51@03@d=00P820030`<00@41
000000030`<01`L700d=3@0J6QX08B4Q02HV9P0/;2`0<C4a03`l?011@D40ATI604];B`1?Cdl0E5AD
05eMG@1QHF40IFEU06YZJP1^KVh0MWIf07UiN@1mOGd0PH6108F5Q@2<S8`0T92@09BDU02GUiL0Vi^K
09jNWP2UYJD0ZJVY0:b/[00R0?ooo`00803oool07@1bLW80NGUi08J6QP2<S8`0Ti>C09VIV@2PX:00
YjNW0;Bd]02k^k/0`/;20<W9b@3@d=00gMgM0>CTi03[jn/0lO7a0?Win@3emOD0jNWY0=kNgP3Cdm<0
bLW90<30`02c/k<0[jn_0:b/[02ZZZX0ZJVY0080YZJV0P2UYJD00`2TY:@0Xj>S0::RXP030:6QX@07
0:2PX02OWil0WinO09jNWP2MWId0W9bL09ZJVP0209^KV`<0VYZJ00D0Vi^K09bLW02LW9`0W9bL09fM
W@0209jNWP@0WinO00l0WIfM09ZJVP2GUiL0Ti>C08n?S`26QXH0P82007QhN01cLg<0JFUY05aLG01G
EeL0DE5A04e=C@1;Bd/00`1:BTX304];B`0604a<C01=CDd0CDe=04i>CP1?Cdl0D51@0P1BDU804@1C
De<0E5AD05EEE@1HF5P0FEUI05YJFP1KFe/0G5aL05mOG`1PH600HF5Q06=SH`1TI6@0IFEU06QXJ01Y
JFT0JVYZ01h0oooo01T0VYZJ09fMW@2SXj<0YZJV0:VYZ@2/[:`0[jn_0;>c/`2h^;P0^k^k0;jn_P31
`L40a<C40<W9b@3;bl/0c/k>0=7Ad@3EeMD0clo?0<K6aP2o_kl0^;Rh0;:b/P2/[:`0YZJV00<0YJFU
00X0YZJV0:NWY`2YZJT0ZZZZ0:b/[02][Jd0[Zj^0:n_[`2`/;00/K6a0P2b/[830;>c/`110;:b/P2a
/K40[jn_0:n_[`2^[Zh0[Jf]0:b/[02ZZZX0YjNW0:JVYP2TY:@0XZ:R0:2PX02KVi/0V9RH09FEU@2A
TI40SHf=08R8R01mOGd0MWIf06i^KP1UIFD0GEeM04Y:BP10@400<c<c02`/;00S8b<05QHF01<C4`0?
3`l03Ph>010@400E5AD07AdM024Q8@0U9BD0:BTY02d];@0e=CD0>3Ph03`l?010@400@d=304M7A`1>
CTh0DE5A05EEE@1HF5P0G5aL069RHP1VIVH0JFUY06e]K@1`L700MWIf07YjNP1mOGd0P82008>3P`26
QXH0SHf=092@T02CTi<07P3oool0:P2^[Zh0[:b/0:RXZ02WYjL0YJFU0::RXP2PX:00WYjN09VIV@2G
UiL0U9BD096AT@2>SXh0R8R808F5Q@22PX80P82007inOP1jNWX0NGUi07QhN01iNGT0NWYj07]kN`1o
Ogl0PX:208B4Q027QhL0RHV908j>SP2@T900Ti>C09FEU@2HV9P0VYZJ09jNWP2PX:00XJ6Q0:>SX`2T
Y:@0YZJV0:NWY`80Z:RX01d0YjNW0:JVYP2TY:@0Xj>S0::RXP2PX:00WYjN09ZJVP2GUiL0Ti>C092@
T02<S8`0Q8B407moO`1jNWX0M7Ad06i^KP1WIfL0F5QH051@D018B4P0?clo03Hf=P0S8b<06QXJ00l?
3`092@T01PH600410@020000000Q00820P0820P0410@01`L700R8R80:2PX02h^;P0c<c<0?Cdm0492
@P17AdL0C4a<055AD@1EEED0GUiN069RHP1VIVH0Jf][06m_K`1fMWH0NWYj07inOP22PX80QXJ608f=
S@2@T900U9BD09RHV02KVi/0WinO0:JVYP2YZJT0[:b/0280oooo000P0?ooo`0N079bLP1hN7P0Q8B4
08^;R`2ATI40UiNG09fMW@2TY:@0/;2`0;Ng]`2m_Kd0a<C40<[:bP3GemL0g]kN0>GUi@3/k>`0m?Cd
0?clo03dm?@0jNWY0>3Ph03EeMD0bl_;0;^k^`2f][H0/[:b0;2`/02^[Zh0Zj^[0P2ZZZX0102YZJT0
YjNW0:JVYP2TY:@20::RXP080:6QX@2PX:00WinO09nOW`2NWYh0WIfM09^KV`2IVIT509RHV0<0UiNG
0P2HV9P00`2IVIT0VYZJ09^KV`0209^KV`80VYZJ00l0V9RH09BDU02BTY80SHf=08>3P`1mOGd0MWIf
075aL@1ZJVX0GUiN05YJFP1FEUH0De=C059BDP1ADE401@1@D503055AD@04059BDP1CDe<0De=C05EE
E@80EUIF0100EeMG05QHF01JFUX0Fe]K05aLG01MGEd0GUiN061PH01QHF40HV9R06=SH`1UIFD0IVIV
06QXJ01YJFT0JVYZ7P3oool06`2IVIT0W9bL0::RXP2UYJD0Z:RX0:^[Z`2][Jd0/;2`0;Jf]P2h^;P0
^k^k0;fm_@30`<00aLG50<O7a`39bLT0c<c<0<o?c`3@d=00bLW90<;2`P2l_;`0]kNg0;:b/P2[Zj/0
ZJVY0:RXZ0020:VYZ@070:ZZZP2/[:`0[Jf]0:j^[P2`/;00/K6a0;:b/P020;>c/`D0];Bd0440/k>c
0;6a/@2_[jl0[Zj^0:f][@2[Zj/0ZZZZ0:VYZ@2UYJD0Xj>S0:2PX02NWYh0Vi^K09FEU@2BTY80SXj>
08V9R@25QHD0P82007AdM01]KFd0I6AT05aLG01DE5@0@T9203Ph>00`<300:RXZ028R8P0H61P05ADE
01@D500E5AD06ATI01`L700T92@0:2PX02/[:`0_;bl0<c<c03Xj>P0m?Cd0@D5104A4A018B4P0Bd];
059BDP1EEED0F5QH05]KF`1OGel0IFEU06QXJ01/K6`0Kfm_079bLP1hN7P0Ng]k07inOP21PH40Q8B4
08N7Q`2=SHd0T92@09>CT`0N0?ooo`0X0:j^[P2/[:`0Z:RX0:JVYP2TY:@0XZ:R0:2PX02MWId0VIVI
09JFUP2CTi<0TI6A08j>SP28R8P0QHF50861P@1nOWh0NWYj07AdM01aLG40LW9b07=cL`1eMGD0N7Qh
07inOP21PH40Ph>308J6QP28R8P0SXj>092@T02CTi<0UYJF09VIV@2LW9`0XJ6Q0::RXP2TY:@0YJFU
0:NWY`80Z:RX0480ZJVY0:RXZ02XZ:P0YjNW0:JVYP2TY:@0XZ:R0:6QX@2NWYh0VIVI09JFUP2BTY80
SXj>08Z:RP1oOgl0NWYj07=cL`1/K6`0IVIV05mOG`1>CTh0ADE503/k>`0b<S80:b/[01XJ6P0B4Q80
3@d=00T92@0410@0000000410@030`<01`L700h>3P0D51@08B4Q02LW9`0/;2`0<S8b03Lg=`11@D40
ATI604Y:BP1?Cdl0E5AD05QHF01PH600IFEU06UYJ@1]KFd0LG5a07QhN01lO7`0P82008>3P`27QhL0
SXj>096AT@2EUID0V9RH09bLW02OWil0YZJV0:VYZ@2][JdR0?ooo`00803oool0;@1bLW80N7Qh08B4
Q02:RXX0T92@09JFUP2LW9`0XZ:R0:n_[`2e]KD0^k^k0<71`@38b<P0e=CD0=_Kf`3QhN40j>SX0?3`
l03lo?`0nOWi0?7al@3Vi^H0g=cL0=;BdP31`L40^[Zj0;Fe]@2c/k<0/[:b0:n_[`2][Jd0[:b/0:^[
Z`2YZJT0Z:RX0:FUY@2TY:@0Xj>S0::RXP2SXj<0XJ6Q0:2PX02OWil0WYjN09fMW@0209ZJVP<0VIVI
00D0V9RH09NGU`2GUiL0V9RH09NGU`0309RHV00E09VIV@2JVYX0VYZJ09ZJVP2HV9P0UYJF09:BTP2@
T900SHf=0820P01kNg/0MgMg075aL@1[Jf/0H61P05]KF`1GEeL0EUIF05EEE@1DE5@0De=C00@0DU9B
0`1CDe<205ADE00305EEE@1FEUH0EeMG0080F5QH00l0FEUI05]KF`1LG5`0GEeM05iNGP1OGel0HF5Q
069RHP1SHf<0I6AT06EUI@1VIVH0J6QX06UYJ@1ZJVX07P3oool06P2IVIT0W9bL0:6QX@2TY:@0YjNW
0:ZZZP2/[:`0[jn_0;Bd]02g]kL0^KVi0;^k^`2n_[h0`/;20<G5a@37alL0bLW90<_;b`3=cLd0b/[:
0<C4a02o_kl0^[Zj0;Bd]02^[Zh0Zj^[0`2ZZZX01`2/[:`0[Jf]0:n_[`2`/;00/K6a0;:b/P2c/k<0
0`2d];@0A@2e]KD0];Bd0;Bd]02d];@0/[:b0;6a/@2^[Zh0[Jf]0:b/[02ZZZX0ZJVY0:NWY`2SXj<0
X:2P09jNWP2KVi/0V9RH09:BTP2>SXh0RXZ:08J6QP21PH40Ng]k06m_K`1XJ6P0H61P05QHF01ADE40
?clo03Hf=P0_;bl0:BTY028R8P0I6AT05aLG01HF5P0I6AT07AdM020P800W9bL0:b/[02l_;`0b<S80
=SHf03`l?010@400@d=304M7A`1:BTX0CDe=05ADE01GEeL0FUYJ05eMG@1PH600IVIV06UYJ@1]KFd0
L71`07=cL`1iNGT0O7al07moO`22PX80QHF508R8R02>SXh0TI6A09>CT`0N0?ooo`0C0:j^[P2/[:`0
Z:RX0:JVYP2TY:@0XZ:R0:2PX02MWId0VIVI09JFUP2CTi<0TI6A08j>SP28R8P0QHF50861P@1nOWh0
NWYj071`L00206i^KP0@075aL@1cLg<0MGEe07alO020P800Ph>308F5Q@27QhL0S8b<08n?S`2CTi<0
UiNG09ZJVP2LW9`0XJ6Q0:>SX`80Y:BT00<0YJFU0:NWY`2WYjL00P2WYjL0@02VYZH0Y:BT0:>SX`2R
XZ80X:2P09jNWP2LW9`0UYJF09:BTP2?Shl0Rh^;08J6QP1lO7`0MWIf06m_K`1XJ6P0H61P05QHF018
B4P0@41003Lg=`0_;bl09bLW01PH600@41002PX:00H61P030`<00@4100<30`061PH02`/;014A4@0G
5aL08b<S02TY:@0_;bl0=3@d03Ti>@13@d<0B4Q804a<C01ADE40EEEE05UIF@1RHV80IVIV06YZJP1^
KVh0LW9b07UiN@1mOGd0P82008B4Q028R8P0Shn?09:BTP2EUID0VIVI09bLW02OWil0YZJV0:VYZ@2]
[JdR0?ooo`00803oool09P1aLG40MgMg08>3P`29RHT0Shn?09FEU@2KVi/0XJ6Q0:f][@2c/k<0^KVi
0;no_`35aLD0dM7A0=SHf03Ng]h0i>CT0>_[j`3inOT0no_k0?Shn03^k^h0hn?S0=SHf038b<P0`<30
0;^k^`2g]kL0]KFe0;:b/P2a/K40[jn_0:j^[P2/[:`0Zj^[0:RXZ02WYjL0YJFU0P2TY:@01P2SXj<0
XZ:R0::RXP2PX:00WinO09fMW@80W9bL0P2KVi/209ZJVP80VIVI0P2HV9P00`2IVIT0V9RH09NGU`03
09NGU`0@09JFUP2DU9@0TI6A08f=S@2:RXX0PH6107]kN`1fMWH0LG5a06a/K01QHF40G5aL05YJFP1I
FET0F5QH05MGE`<0EEEE0P1DE5@405EEE@80EUIF0P1HF5P205UIF@0?05YJFP1LG5`0G5aL05iNGP1O
Gel0H61P065QH@1RHV80Hf=S06ATI01UIFD0IVIV06QXJ01YJFT0Jf][01h0oooo01/0VIVI09bLW02Q
XJ40Y:BT0:JVYP2YZJT0Zj^[0:j^[P2c/k<0]KFe0;Ng]`2j^[X0_;bl0<30`033`l<0aLG50<O7a`38
b<P0bl_;0<W9b@37alL0`/;20;fm_@2g]kL0/K6a0:f][@2/[:`00P2[Zj/01@2^[Zh0[jn_0;6a/@2b
/[80/k>c00D0];Bd04D0]KFe0;Bd]02d];@0/k>c0;:b/P2`/;00[Jf]0:b/[02ZZZX0Z:RX0:NWY`2U
YJD0X:2P09fMW@2KVi/0V9RH09FEU@2>SXh0Rh^;08J6QP21PH40O7al07MgM`1[Jf/0I6AT05aLG01E
EED0CDe=03`l?00d=3@0;Rh^02PX:00R8R8071`L01TI6@0J6QX07AdM024Q8@0T92@0:b/[02h^;P0b
<S80=CDe03Ti>@0o?cl0@T9204I6AP19BDT0C4a<04m?C`1FEUH0FEUI05aLG01OGel0HV9R06QXJ01[
Jf/0KVi^075aL@1dM7@0NWYj07emO@1oOgl0PX:208F5Q@28R8P0SXj>096AT@2DU9@07P3oool04`2^
[Zh0[:b/0:RXZ02VYZH0Y:BT0::RXP2PX:00WIfM09RHV02FUYH0Ti>C096AT@2>SXh0R8R808F5Q@21
PH40OWin07YjNP1_Kfl00P1ZJVX04@1]KFd0LG5a07AdM01jNWX0OGem07moO`22PX80QHF508b<S02?
Shl0Ti>C09JFUP2IVIT0W9bL09nOW`2PX:00XJ6Q0080Xj>S0`2TY:@07@2SXj<0XZ:R0:2PX02OWil0
WIfM09ZJVP2IVIT0UYJF092@T02<S8`0RHV908F5Q@21PH40MWIf075aL@1/K6`0IFEU05aLG01EEED0
A4A403/k>`0c<c<0;2`/02@T900C4a<03Ph>00X:2P061PH00`<3008010@4028020P800h>3P0D51@0
6QXJ02HV9P0/;2`0<C4a03Hf=P0k>c/0ADE504U9B@1>CTh0DU9B05MGE`1KFe/0Hf=S06MWI`1[Jf/0
Kfm_07=cL`1jNWX0OWin08:2PP25QHD0R8R808n?S`2CTi<0UYJF09VIV@2LW9`0X:2P0:JVYP2YZJT0
[Jf]8P3oool00200oooo02D0LG5a07MgM`22PX80R8R808j>SP2DU9@0VIVI09nOW`2ZZZX0/;2`0;Jf
]P2l_;`0`/;20<k>cP3De=@0f][J0>3Ph03WinL0l_;b0?KfmP3inOT0l_;b0>[ZjP3Ogml0clo?0<O7
a`31`L40^k^k0;Vi^@2e]KD0];Bd0;>c/`2a/K40/;2`0:j^[P2[Zj/0ZJVY0080Z:RX00P0YjNW0:JV
YP2VYZH0YJFU0:BTY02RXZ80XJ6Q0:2PX0@0WinO0P2LW9`209^KV`<0VYZJ01D0V9RH09NGU`2FUYH0
UYJF09BDU02BTY80T92@08f=S@29RHT0P82007]kN`1fMWH0LG5a06][J`1RHV80GUiN05aLG01KFe/0
FUYJ05UIF@1HF5P00`1GEeL205IFEP@0EeMG00@0F5QH05UIF@1IFET0FUYJ0P1KFe/03P1MGEd0GUiN
05iNGP1OGel0H61P069RHP1SHf<0I6AT06EUI@1VIVH0IfMW06UYJ@1ZJVX0Jf][7P3oool04P2IVIT0
Vi^K0:2PX02SXj<0YJFU0:RXZ02ZZZX0[Jf]0;6a/@2d];@0][Jf0;Rh^02j^[X0_[jn0<30`032`/80
a<C40<K6aP80b<S800`0bLW90<G5a@30`<00^[Zj0;:b/P2_[jl0[Zj^0:f][@2^[Zh0/;2`0;6a/@2c
/k<20;Bd]080]KFe1@2d];@0@`2c/k<0/[:b0;2`/02_[jl0[:b/0:VYZ@2XZ:P0YjNW0:FUY@2SXj<0
WIfM09^KV`2IVIT0UIFE09:BTP2;Rh/0R8R808:2PP1mOGd0N7Qh07=cL`1VIVH0H61P05UIF@1ADE40
BDU903Xj>P0c<c<0;Bd]02PX:00T92@07AdM01/K6`0N7Qh08R8R02DU9@0X:2P0;bl_038b<P0e=CD0
>3Ph03/k>`12@T80ADE504Q8B01;Bd/0CTi>055AD@1HF5P0Fe]K05iNGP1QHF40Hf=S06UYJ@1/K6`0
Kfm_079bLP1eMGD0Ng]k07emO@20P800Ph>308J6QP29RHT0SXj>096AT@2DU9@07P3oool0502^[Zh0
[:b/0:RXZ02VYZH0Y:BT0::RXP2PX:00WIfM09RHV02FUYH0Ti>C096AT@2>SXh0R8R808F5Q@22PX80
OWin07YjNP1bLW80KVi^0P1]KFd0401^KVh0L71`07IfMP1hN7P0OGem0820P025QHD0Rh^;08n?S`2B
TY80UIFE09NGU`2IVIT0WIfM09jNWP2OWil40:2PX00L09nOW`2NWYh0WIfM09ZJVP2HV9P0UYJF09BD
U02ATI40SXj>08V9R@26QXH0Ph>307inOP1jNWX0L71`06][J`1UIFD0GUiN05MGE`1?Cdl0?clo03Lg
=`0_;bl09bLW01lO7`0A4A4030`<00P820<01@D502<01PH600`<300B4Q8061PH01dM7@0Y:BT0;Rh^
03<c<`0h>3P0?Cdm04M7A`1<C4`0D51@05ADE01IFET0GEeM06EUI@1YJFT0KFe]071`L01dM7@0Ng]k
07moO`22PX80QXJ608V9R@2@T900Ti>C09JFUP2JVYX0WIfM0:2PX02VYZH0ZZZZ0:f][@0R0?ooo`00
803oool0501aLG40MgMg0861P@27QhL0SHf=09:BTP2HV9P0WYjN0:VYZ@2^[Zh0];Bd0;Zj^P2o_kl0
bl_;0=7Ad@3GemL0g=cL0>;RhP3]kNd0l_;b0P3gmoL04@3^k^h0iNGU0=;BdP3;bl/0aLG50<30`02m
_Kd0^[Zj0;Rh^02f][H0]KFe0;>c/`2b/[80[jn_0:f][@2/[:`0Zj^[0080ZZZZ0P2YZJT00`2WYjL0
YZJV0:>SX`030::RXP80XJ6Q0P2OWil00`2MWId0W9bL09^KV`0209ZJVP0E09VIV@2GUiL0UYJF09FE
U@2BTY80TI6A08j>SP2;Rh/0R8R80820P01kNg/0MGEe071`L01[Jf/0HF5Q061PH01OGel0GEeM05aL
G01KFe/0FUYJ00<0FEUI0`1HF5P405UIF@0305YJFP1KFe/0Fe]K0080G5aL00D0GUiN05mOG`1OGel0
H61P065QH@0206=SH`0706ATI01UIFD0IVIV06MWI`1YJFT0JVYZ06][J`0N0?ooo`0K09VIV@2KVi/0
X:2P0::RXP2UYJD0YjNW0:VYZ@2/[:`0/;2`0;:b/P2d];@0]kNg0;Vi^@2l_;`0_[jn0<30`032`/80
`l?30<K6aP37alL0b<S80<O7a`32`/80_[jn0;Fe]@2b/[80/K6a0080[jn_00@0/K6a0;>c/`2d];@0
];Bd0`2e]KD30;Bd]080/k>c04<0/[:b0;6a/@2_[jl0[Jf]0:ZZZP2XZ:P0YZJV0:FUY@2RXZ80X:2P
09^KV`2JVYX0UYJF09>CT`2?Shl0R8R808B4Q01nOWh0NGUi07AdM01^KVh0HV9R05aLG01EEED0CDe=
04I6AP0h>3P0<S8b02d];@0Z:RX09RHV01hN7P0O7al08b<S02HV9P0Y:BT0;2`/038b<P0e=CD0>3Ph
03/k>`0n?Sh0ADE504Q8B01;Bd/0CTi>055AD@1DE5@0FUYJ05aLG01OGel0HV9R06EUI@1[Jf/0KVi^
071`L01cLg<0MWIf07]kN`1nOWh0PH6108B4Q026QXH0RHV908j>SP2ATI40U9BD01h0oooo02H0[Zj^
0:b/[02XZ:P0YZJV0:BTY02RXZ80WinO09fMW@2HV9P0UYJF09>CT`2ATI40SXj>08R8R025QHD0PX:2
07moO`1kNg/0M7Ad071`L01/K6`0Jf][06e]K@1`L700MWIf07UiN@1lO7`0Ogmo08:2PP29RHT0SHf=
092@T02CTi<0UIFE09NGU`2IVIT0VYZJ09^KV`80W9bL01d0Vi^K09ZJVP2IVIT0V9RH09NGU`2DU9@0
TY:B092@T02>SXh0Rh^;08R8R022PX80PH6107emO@1jNWX0MGEe06][J`1UIFD0GUiN05QHF01BDU80
BTY:03/k>`0c<c<0:b/[02<S8`0K6a/03Ph>00X:2P0300T92@0T00L71`0:2PX0410@01HF5P0K6a/0
8B4Q02`/;00a<C40=SHf03/k>`10@400BDU904i>CP1BDU80EUIF05]KF`1OGel0IVIV06YZJP1^KVh0
LW9b07EeM@1lO7`0P82008>3P`27QhL0RXZ:096AT@2DU9@0UiNG09ZJVP2MWId0X:2P0:NWY`2ZZZX0
[Jf]8P3oool00200oooo02L0LG5a07IfMP21PH40QXJ608b<S02ATI40UYJF09bLW02WYjL0[:b/0;:b
/P2g]kL0_Kfm0<S8b03=cLd0dm?C0=SHf03Ng]h0j>SX0>g]k@3alO40moOg0?Cdm03[jn/0f=SH0=7A
d@3;bl/0a/K60<;2`P2o_kl0_Kfm0;^k^`2i^KT0]kNg0;Jf]P2d];@0/[:b0;2`/02_[jl00P2^[Zh2
0:f][@030:b/[02[Zj/0Z:RX0080YZJV0`2UYJD01@2RXZ80XJ6Q0:2PX02OWil0W9bL0080Vi^K01D0
VYZJ09VIV@2HV9P0UiNG09BDU02BTY80Shn?08b<S028R8P0Ogmo07YjNP1eMGD0KVi^06YZJP1SHf<0
HV9R065QH@1PH600GemO05iNGP1LG5`00`1KFe/605YJFP80Fe]K0P1LG5`205eMG@80GemO00H0H61P
065QH@1RHV80Hf=S06ATI01UIFD206IVIP0406MWI`1YJFT0JVYZ06][Jah0oooo01/0VIVI09^KV`2O
Wil0XZ:R0:BTY02VYZH0Z:RX0:^[Z`2_[jl0/K6a0;>c/`2e]KD0]kNg0;^k^`2l_;`0_[jn0<30`031
`L40`l?30<G5a@36a/H0alO70<G5a@31`L40]kNg0;Fe]@2b/[800P2a/K401@2c/k<0]KFe0;Fe]@2e
]KD0][Jf0080]KFe0P2d];@0AP2c/k<0/[:b0;6a/@2`/;00[jn_0:f][@2[Zj/0Z:RX0:FUY@2TY:@0
XZ:R0:2PX02NWYh0VYZJ09NGU`2CTi<0TI6A08b<S024Q8@0Ogmo07YjNP1eMGD0Kfm_06UYJ@1NGUh0
EeMG051@D01:BTX0@T9203Lg=`0c<c<0<30`02/[:`0W9bL0820P02@T900W9bL0:RXZ02d];@0`<300
=SHf03Ti>@0k>c/0?Shn0451@@17AdL0BTY:04e=C@1@D500De=C05IFEP1LG5`0GUiN065QH@1TI6@0
IfMW06a/K01_Kfl0LW9b07AdM01gMgL0O7al07moO`22PX80Q8B408N7Q`29RHT0Shn?096AT@2DU9@N
0?ooo`0E0:j^[P2/[:`0Z:RX0:JVYP2TY:@0XZ:R09nOW`2MWId0VIVI09JFUP2DU9@0TI6A08j>SP29
RHT0QXJ608>3P`1oOgl0O7al07EeM@1bLW80Kfm_0080Jf][00h0KVi^07=cL`1gMgL0NGUi07alO01o
Ogl0QXJ608Z:RP2>SXh0T92@09:BTP2CTi<0U9BD09FEU@<0UYJF04@0UIFE09BDU02CTi<0TI6A08n?
S`2=SHd0Rh^;08V9R@27QhL0Ph>30861P@1mOGd0Ng]k07IfMP1cLg<0L71`06ATI01NGUh0EeMG04m?
C`18B4P0@D5103<c<`0[:b/092@T01dM7@0E5AD03Ph>00d=3@0>3Ph03@d=00X:2P0820P03Ph>01@D
500I6AT07alO02@T900_;bl0=3@d03Ti>@0n?Sh0@T9204a<C01@D500E5AD05QHF01LG5`0H61P06QX
J01/K6`0L71`07=cL`1gMgL0OWin0861P@24Q8@0R8R808^;R`2ATI40U9BD09RHV02KVi/0WYjN0:6Q
X@2WYjL0ZZZZ0:f][B80oooo000P0?ooo`0V075aL@1fMWH0P82008F5Q@29RHT0Shn?09BDU02IVIT0
Xj>S0:RXZ02][Jd0/[:b0;Ng]`31`L40a/K60<_;b`3@d=00eMGE0=oOg`3Ti>@0jNWY0>g]k@3clo<0
m?Cd0>CTi03MgMd0e=CD0<k>cP3:b/X0b<S80<O7a`36a/H0`/;20<30`02n_[h0_;bl0;^k^`2i^KT2
0;Rh^080]kNg00D0]KFe0;Bd]02e]KD0];Bd0;>c/`020;2`/00N0:n_[`2^[Zh0[Jf]0:^[Z`2ZZZX0
Z:RX0:JVYP2QXJ40X:2P09jNWP2LW9`0Vi^K09VIV@2EUID0TY:B08n?S`2:RXX0QhN707alO01iNGT0
MGEe075aL@1^KVh0J6QX06IVIP1UIFD0I6AT06=SH`1RHV80H61P0P1OGel205iNGPH0GEeM0P1NGUh3
05mOG`07061PH01QHF40HV9R069RHP1SHf<0I6AT06EUI@0206IVIP0506MWI`1XJ6P0JFUY06YZJP1[
Jf/07P3oool07P2HV9P0Vi^K09nOW`2QXJ40Xj>S0:FUY@2WYjL0ZJVY0:f][@2^[Zh0/;2`0;:b/P2d
];@0]kNg0;Vi^@2j^[X0_;bl0;fm_@30`<00`L710<;2`P33`l<0aLG50<K6aP2l_;`0^[Zj0;Jf]P2d
];@0/k>c0;Fe]@80]kNg00H0][Jf0;Fe]@2d];@0];Bd0;>c/`2a/K420;2`/0140:f][@2/[:`0ZZZZ
0:VYZ@2WYjL0Y:BT0::RXP2OWil0WIfM09^KV`2IVIT0U9BD096AT@2>SXh0RHV908F5Q@1lO7`0MgMg
079bLP1]KFd0IfMW065QH@1FEUH0DE5A04a<C016ATH0@T9203Xj>P0e=CD0;bl_02/[:`0W9bL0:BTY
02`/;00_;bl0<S8b03@d=00g=cL0?Cdm03lo?`12@T80ADE504Q8B01=CDd0D51@059BDP1EEED0F5QH
05YJFP1PH600HV9R06EUI@1WIfL0JVYZ06m_K`1bLW80M7Ad07MgM`1iNGT0OWin0861P@23Ph<0QHF5
08R8R02:RXX0Shn?09:BTP2DU9@N0?ooo`0Q0:j^[P2/[:`0Z:RX0:JVYP2TY:@0XZ:R0:2PX02NWYh0
VIVI09NGU`2DU9@0TY:B08n?S`2:RXX0QhN708B4Q021PH40OWin07QhN01eMGD0Lg=c071`L01]KFd0
KVi^06m_K`1bLW80MWIf07UiN@1lO7`0PH6108>3P`26QXH0R8R80080RHV90`2:RXX208V9R@1408J6
QP24Q8@0Ph>308:2PP1oOgl0Ng]k07UiN@1gMgL0MGEe07=cL`1`L700Jf][06MWI`1TI6@0GemO05aL
G01CDe<0C4a<04I6AP10@400>SXj038b<P0V9RH08B4Q01dM7@0I6AT05QHF01DE5@0A4A4030`<00T9
2@071`L0410@01HF5P0L71`08B4Q02HV9P0[:b/0=CDe03Xj>P0o?cl0@d=304Q8B01ADE40EEEE05UI
F@1MGEd0HF5Q06EUI@1/K6`0Kfm_07=cL`1fMWH0NWYj0820P023Ph<0QhN708Z:RP2=SHd0Ti>C09JF
UP2IVIT0W9bL09nOW`2RXZ80YjNW0:ZZZP2][JdR0?ooo`00803oool07@1`L700MGEe07moO`24Q8@0
R8R808f=S@2BTY80UiNG0:6QX@2UYJD0ZZZZ0:n_[`2d];@0_[jn0<?3``38b<P0cLg=0=7Ad@3Kfm/0
h>3P0>CTi03YjNT0k^k^0?Gem@3YjNT0h>3P0=[JfP3De=@0clo?00<0c<c<00D0alO70<G5a@32`/80
`L710<30`0020;fm_@0Y0;bl_02k^k/0^[Zj0;^k^`2i^KT0^[Zj0;Vi^@2h^;P0][Jf0;Ng]`2e]KD0
];Bd0;>c/`2a/K40[jn_0:f][@2[Zj/0YJFU0:>SX`2QXJ40WinO09jNWP2KVi/0UYJF09>CT`2?Shl0
Rh^;08J6QP1nOWh0NGUi07EeM@1aLG40Kfm_06][J`1YJFT0IfMW06IVIP1UIFD0I6AT069RHP1QHF40
0P1PH60205mOG`@0GUiN0`1OGel3061PH005065QH@1RHV80HV9R06=SH`1TI6@00P1UIFD01`1VIVH0
IfMW06MWI`1XJ6P0JFUY06YZJP1[Jf/07P3oool0702HV9P0VYZJ09jNWP2PX:00XZ:R0:BTY02VYZH0
Z:RX0:^[Z`2][Jd0[jn_0;6a/@2b/[80]KFe0;Ng]`2h^;P0^[Zj0;^k^`2n_[h0_kno0<30`032`/80
`l?30<G5a@30`<00_;bl0;Rh^02f][H20;Fe]@040;Ng]`2h^;P0][Jf0;Fe]@80/k>c00D0/[:b0:n_
[`2_[jl0[Zj^0:^[Z`020:VYZ@110:FUY@2TY:@0XJ6Q0:2PX02LW9`0Vi^K09RHV02FUYH0TI6A08j>
SP2:RXX0QhN708:2PP1hN7P0Lg=c06i^KP1XJ6P0Hf=S05iNGP1CDe<0Cdm?04Y:BP16ATH0@d=303Xj
>P0d=3@0;bl_02XZ:P0X:2P0;Rh^030`<00c<c<0=SHf03Ph>00k>c/0@41004=3@`15ADD0B4Q804];
B`1@D500DU9B05EEE@1HF5P0FUYJ05eMG@1RHV80I6AT06MWI`1YJFT0Jf][071`L01cLg<0MGEe07Qh
N01jNWX0Ogmo0861P@24Q8@0QXJ608R8R02;Rh/0Shn?09:BTP2DU9@07P3oool08@2^[Zh0[:b/0:RX
Z02VYZH0Y:BT0::RXP2PX:00WYjN09ZJVP2GUiL0UIFE09>CT`2@T900Rh^;08R8R025QHD0Ph>30820
P01jNWX0MgMg07AdM01aLG40Kfm_06][J`1_Kfl0LG5a07=cL`1eMGD0NGUi07emO@1oOgl0PH6108:2
PP0208>3P`0308B4Q023Ph<0Ph>30080PX:201T0Ogmo07emO@1kNg/0MgMg07EeM@1bLW80L71`06a/
K01[Jf/0J6QX06EUI@1PH600GEeM05UIF@1FEUH0DU9B04Q8B014A4@0?Shn03Lg=`0a<C40:b/[028R
8P0N7Qh06QXJ008061PH02T04a<C00l?3`0<30`02@T900P8200D51@06QXJ020P800U9BD0:RXZ02l_
;`0i>CT0?Shn0492@P17AdL0Bd];05=CD`1HF5P0G5aL05mOG`1SHf<0IfMW06i^KP1aLG40MGEe07Qh
N01kNg/0PX:208F5Q@28R8P0Rh^;08j>SP2DU9@0UiNG09VIV@2LW9`0WinO0::RXP2XZ:P0ZZZZ0:f]
[@0R0?ooo`00803oool09P1`L700MGEe07inOP23Ph<0QhN708b<S02ATI40UIFE09nOW`2SXj<0Z:RX
0:f][@2a/K40^k^k0;no_`34a<@0bLW90<k>cP3GemL0fm_K0>3Ph03UiND0j^[Z0>o_k`3clo<0j>SX
0=kNgP3Hf=P0dm?C0<o?c`3@d=00dM7A0<g=c@3:b/X0bLW90<K6aP35aLD0`l?30P31`L420;no_`03
0<30`02n_[h0_kno0080`<30102l_;`06`2i^KT0]kNg0;Jf]P2d];@0/[:b0:^[Z`2XZ:P0Y:BT0:6Q
X@2PX:00WYjN09JFUP2BTY80SXj>08V9R@24Q8@0Ogmo07YjNP1fMWH0LG5a071`L01]KFd0Jf][06UY
J@1XJ6P0IVIV06EUI@0206=SH`03069RHP1QHF40HF5Q00P0H61P0`1QHF400`1RHV80Hf=S06=SH`02
06ATI00406EUI@1VIVH0IVIV06MWI`80J6QX0P1ZJVX00`1[Jf/0oooo0?ooo`0L0?ooo`0Y09RHV02J
VYX0WYjN0:2PX02RXZ80Xj>S0:FUY@2WYjL0ZZZZ0:b/[02^[Zh0[jn_0;6a/@2d];@0]KFe0;Ng]`2h
^;P0^KVi0;bl_02m_Kd0_[jn0<30`031`L40`/;20<?3``2n_[h0^[Zj0;Rh^02f][H0]KFe0;Ng]`2h
^;P0][Jf0;Bd]02c/k<0/K6a0;2`/02_[jl0[Jf]0:b/[02XZ:P00P2VYZH0@@2RXZ80XJ6Q09nOW`2M
WId0VIVI09RHV02EUID0Ti>C08j>SP2:RXX0QhN708>3P`1oOgl0MGEe071`L01ZJVX0IFEU061PH01K
Fe/0De=C04m?C`1<C4`0BDU904=3@`0i>CT0<c<c02l_;`0Z:RX0;Bd]038b<P0e=CD0=cLg03Xj>P0l
?3`0?clo04A4A016ATH0BDU904];B`1>CTh0De=C05EEE@1HF5P0FUYJ05eMG@1OGel0I6AT06IVIP1X
J6P0Jf][06e]K@1bLW80M7Ad07MgM`1iNGT0Ng]k0820P022PX80Q8B408N7Q`29RHT0Rh^;092@T02B
TY80U9BD01h0oooo0240[Zj^0:b/[02XZ:P0YZJV0:BTY02RXZ80X:2P09jNWP2JVYX0V9RH09JFUP2C
Ti<0TI6A08b<S029RHT0QXJ608B4Q021PH40Ng]k07QhN01fMWH0Lg=c071`L01]KFd0JFUY06i^KP1b
LW80M7Ad07IfMP1iNGT0NWYj07alO01mOGd00`1lO7`307]kN`0I07UiN@1fMWH0Lg=c075aL@1^KVh0
K6a/06IVIP1TI6@0Hf=S061PH01LG5`0FUYJ05EEE@1ADE40CDe=04Y:BP16ATH0?Shn03Ti>@0d=3@0
;bl_02XZ:P0U9BD0820P01hN7P0201dM7@0Z01XJ6P0@41003@d=00X:2P092@T03Ph>01TI6@0N7Qh0
92@T02TY:@0^;Rh0<c<c03`l?011@D40ATI604Y:BP1>CTh0EUIF05YJFP1NGUh0HV9R06EUI@1YJFT0
L71`07=cL`1fMWH0NWYj07emO@23Ph<0QXJ608V9R@2<S8`0Shn?09FEU@2GUiL0VYZJ09fMW@2PX:00
XZ:R0:RXZ02ZZZX0[Jf]8P3oool00200oooo02@0L71`07AdM01mOGd0PX:208J6QP2:RXX0Shn?09BD
U02MWId0XJ6Q0:FUY@2ZZZX0[jn_0;Rh^02l_;`0`L710<G5a@3:b/X0dm?C0=OGe`3Lg=`0h>3P0>GU
i@3Zj^X0lo?c0?7al@3WinL0g]kN0=SHf03Bd]80dm?C0=GEe@3Cdm<0c/k>0<g=c@3:b/X20<W9b@04
0<K6aP35aLD0a<C40<?3``80a<C400D0`l?30<K6aP37alL0a/K60<C4a0020<71`@0M0<30`02n_[h0
_Kfm0;^k^`2j^[X0/k>c0:n_[`2[Zj/0YjNW0::RXP2NWYh0V9RH09:BTP2?Shl0S8b<08F5Q@20P800
OGem07QhN01eMGD0Lg=c06m_K`1]KFd0Jf][06YZJP1XJ6P0IfMW06EUI@1TI6@00P1SHf<00`1RHV80
HF5Q065QH@07065QH@80HV9R0P1SHf<206ATI00306EUI@1VIVH0IVIV0080IfMW00D0J6QX06UYJ@1Z
JVX0JVYZ06][J`0N0?ooo`1509RHV02JVYX0WIfM09nOW`2QXJ40Xj>S0:BTY02VYZH0ZJVY0:^[Z`2/
[:`0[Zj^0:n_[`2b/[80];Bd0;Fe]@2f][H0]kNg0;Zj^P2k^k/0_;bl0;fm_@2o_kl0`<300<?3``31
`L40_;bl0;Vi^@2f][H0]KFe0;Jf]P2g]kL0]KFe0;:b/P2a/K40[jn_0:j^[P2][Jd0Zj^[0:VYZ@2U
YJD0Y:BT0::RXP2PX:00WYjN09^KV`2JVYX0UYJF09FEU@2BTY80T92@08^;R`27QhL0Q8B407moO`1l
O7`0LW9b06a/K01WIfL0Hf=S05iNGP1JFUX0E5AD04m?C`1=CDd0BDU90451@@0g=cL0<c<c0080;Rh^
02D0<S8b03Lg=`0i>CT0>c/k03hn?P10@400@T9204M7A`1:BTX0C4a<04i>CP1ADE40EUIF05QHF01J
FUX0GEeM05mOG`1QHF40IVIV06QXJ01ZJVX0KFe]06m_K`1cLg<0MWIf07QhN01jNWX0O7al0861P@23
Ph<0QHF508N7Q`29RHT0S8b<092@T02BTY80U9BD01h0oooo01P0[Zj^0:b/[02XZ:P0YjNW0:FUY@2S
Xj<0XJ6Q09nOW`2KVi/0V9RH09JFUP2DU9@0TY:B08f=S@2:RXX0R8R808F5Q@22PX80OGem07YjNP1g
MgL0M7Ad075aL@1^KVh206UYJ@0306a/K01`L700LW9b00L0MWIf01X0MGEe07AdM01cLg<0LW9b06e]
K@1[Jf/0J6QX06EUI@1SHf<0G5aL05QHF01EEED0E5AD05=CD`1@D500BDU904E5A@12@T80?Cdm03Ti
>@0a<C40;Bd]02TY:@0W9bL09BDU02<S8`807alO02`07QhN01/K6`0F5QH03Ph>00X:2P0820P02`/;
018B4P0N7Qh08b<S02PX:00];Bd0<S8b03Lg=`10@400ADE504U9B@1=CDd0DE5A05UIF@1MGEd0HF5Q
06ATI01XJ6P0Jf][079bLP1eMGD0N7Qh07]kN`1nOWh0Q8B408R8R02;Rh/0SHf=092@T02EUID0V9RH
09^KV`2NWYh0X:2P0:>SX`2XZ:P0Zj^[0:f][B80oooo000P0?ooo`0M071`L01dM7@0OGem0861P@25
QHD0RHV908j>SP2BTY80VYZJ09nOW`2SXj<0YjNW0:b/[02d];@0^KVi0;fm_@31`L40a/K60<k>cP3C
dm<0emOG0=cLg03Ph>00iNGU0?3`l03dm?@0l?3`0>OWi`3Ogml00P3EeMD02P3GemL0f=SH0=CDe03A
dM40d=3@0<o?c`3>c/h0c<c<0<[:bP39bLT40<S8b00Q0<W9b@3;bl/0bl_;0<_;b`3:b/X0bLW90<G5
a@34a<@0`/;20;no_`2m_Kd0]kNg0;>c/`2_[jl0ZJVY0:BTY02OWil0UiNG09>CT`2@T900SHf=08R8
R021PH40OGem07YjNP1gMgL0MGEe071`L01^KVh0KFe]06][J`1ZJVX0J6QX0080IVIV00@0IFEU06AT
I01SHf<0Hf=S2@1RHV80101SHf<0I6AT06ATI01TI6@206EUI@0306IVIP1WIfL0IfMW0080J6QX00@0
JFUY06YZJP1ZJVX0Jf][7P3oool07@2HV9P0VYZJ09fMW@2OWil0X:2P0::RXP2TY:@0YJFU0:RXZ02Z
ZZX0Zj^[0:f][@2^[Zh0/K6a0;:b/P2c/k<0]KFe0;Jf]P2h^;P0^KVi0;Zj^P2k^k/0_;bl0;jn_P30
`<00`L710;jn_P2k^k/0^;Rh00<0];Bd02@0]KFe0;:b/P2`/;00[Zj^0:b/[02[Zj/0ZJVY0:NWY`2S
Xj<0XJ6Q09nOW`2MWId0Vi^K09NGU`2FUYH0U9BD09:BTP2?Shl0SXj>08N7Q`24Q8@0PH6107emO@1i
NGT0Kfm_06][J`1WIfL0Hf=S05iNGP1KFe/0EEEE051@D01<C4`0ATI603lo?`0g=cL2038b<P0V03@d
=00f=SH0>c/k03dm?@10@400@T9204A4A016ATH0Bd];04e=C@1?Cdl0DU9B05ADE01HF5P0Fe]K05eM
G@1OGel0HF5Q06=SH`1XJ6P0JVYZ06a/K01^KVh0L71`07EeM@1gMgL0NGUi07]kN`1mOGd0PX:208B4
Q026QXH0R8R808Z:RP2<S8`0T92@09:BTP2DU9@N0?ooo`0I0:j^[P2/[:`0ZJVY0:NWY`2UYJD0Xj>S
0:6QX@2OWil0Vi^K09VIV@2GUiL0UIFE09:BTP2>SXh0Rh^;08V9R@26QXH0Ph>307inOP1kNg/0N7Qh
07IfMP1cLg<0L71`06UYJ@0206IVIP0506UYJ@1]KFd0LW9b079bLP1`L7000`1_Kfl06@1]KFd0K6a/
06][J`1ZJVX0J6QX06ATI01QHF40GemO05eMG@1IFET0DU9B04i>CP1;Bd/0B4Q804I6AP14A4@0?Shn
03/k>`0h>3P0=CDe034a<@0Z:RX09bLW02HV9P0U9BD00P0S8b<0;P0R8R807alO01`L700F5QH04A4A
00`<30092@T02PX:014A4@0G5aL08b<S02PX:00];Bd0<S8b03Lg=`0l?3`0A4A404Q8B01=CDd0DE5A
05EEE@1LG5`0H61P06=SH`1WIfL0JVYZ06i^KP1dM7@0MgMg07YjNP1mOGd0P82008J6QP29RHT0S8b<
08j>SP2ATI40UYJF09VIV@2LW9`0WYjN0:6QX@2SXj<0Z:RX0:^[Z`2][JdR0?ooo`00803oool07`1_
Kfl0Lg=c07]kN`1oOgl0Ph>308N7Q`2;Rh/0SXj>09JFUP2JVYX0WYjN0::RXP2VYZH0[Zj^0;:b/P2f
][H0^[Zj0;jn_P36a/H0b/[:0<k>cP3Bd]80e]KF0=_Kf`3UiND0j^[Z0>o_k`3bl_80k^k^0>;RhP3O
gml00P3Lg=`20=kNgP80fMWI00T0f=SH0=WIf@3Hf=P0eMGE0=?Cd`3AdM40d];B0<o?c`3@d=000P3A
dM407P3Cdm<0eMGE0=CDe03?cll0c<c<0<W9b@35aLD0`/;20;Vi^@2d];@0[jn_0:^[Z`2VYZH0XZ:R
09^KV`2GUiL0U9BD096AT@2<S8`0Q8B40820P01mOGd0NWYj07MgM`1cLg<0LG5a06m_K`1^KVh0K6a/
06][J`80J6QX00@0IfMW06IVIP1VIVH0IFEU2P1TI6@206EUI@<0IVIV0P1WIfL206QXJ080JFUY00<0
JVYZ06][J`1[Jf/07P3oool0<02HV9P0VIVI09bLW02NWYh0WinO0:6QX@2RXZ80Xj>S0:JVYP2XZ:P0
ZJVY0:ZZZP2[Zj/0[Zj^0:n_[`2`/;00/K6a0;:b/P2d];@0]KFe0;Jf]P2g]kL0^;Rh0;Vi^@2k^k/0
_;bl0;fm_@2l_;`0^[Zj0;Bd]02b/[80/;2`0:n_[`2^[Zh0[Jf]0:VYZ@2WYjL0YJFU0:BTY02QXJ40
WIfM09^KV`2IVIT0UiNG09>CT`2@T900Shn?08f=S@80S8b<03X0RHV908>3P`20P800OGem07YjNP1g
MgL0L71`06e]K@1ZJVX0IFEU065QH@1LG5`0DU9B04a<C017AdL0A4A403lo?`0i>CT0>c/k03dm?@0o
?cl0@41004E5A@16ATH0B4Q804Y:BP1<C4`0CTi>059BDP1DE5@0EUIF05QHF01JFUX0GUiN061PH01R
HV80I6AT06IVIP1XJ6P0K6a/06i^KP1`L700LW9b07AdM01hN7P0NWYj07alO01nOWh0P82008B4Q025
QHD0QhN708V9R@2;Rh/0SHf=096AT@2CTi<0UIFE7P3oool07P2^[Zh0[:b/0:VYZ@2WYjL0YZJV0:BT
Y02RXZ80X:2P09bLW02JVYX0V9RH09JFUP2DU9@0T92@08f=S@2;Rh/0RHV908J6QP21PH40Ogmo07al
O01iNGT0MWIf07=cL`1/K6`0J6QX06ATI01PH600HF5Q06=SH`80I6AT01<0Hf=S061PH01NGUh0GEeM
05YJFP1HF5P0EEEE059BDP1@D500Cdm?04a<C01:BTX0ATI60451@@0n?Sh0>c/k03Ph>00e=CD0<c<c
0080;Rh^00@0;2`/02/[:`0Y:BT0:2PX0P0Y:BT01`0W9bL092@T028R8P0I6AT051@D010@400?3`l0
0P0<30`0:00B4Q8061PH01hN7P0T92@0;Rh^03<c<`0h>3P0?3`l0451@@15ADD0C4a<051@D01DE5@0
F5QH05aLG01SHf<0IVIV06UYJ@1/K6`0Kfm_07=cL`1iNGT0Ng]k07inOP21PH40Q8B408V9R@2<S8`0
SXj>096AT@2CTi<0V9RH09^KV`2MWId0WinO0::RXP2TY:@0ZJVY0:^[Z`2^[ZhR0?ooo`00803oool0
901_Kfl0Lg=c07YjNP1nOWh0PX:208F5Q@29RHT0SHf=09BDU02HV9P0W9bL09nOW`2SXj<0Zj^[0:j^
[P2b/[80][Jf0;Zj^P32`/80aLG50<W9b@3=cLd0d];B0=KFeP3Ogml0i>CT0>WYj@3^k^h0lO7a0>SX
j03Rh^80g]kN0=gMg@3Ng]h0h>3P0=kNgP@0g=cL00T0gMgM0=_Kf`3Hf=P0f=SH0=GEe@3Cdm<0e=CD
0=7Ad@3@d=000P3Bd]806`3>c/h0c<c<0<S8b033`l<0_kno0;Ng]`2e]KD0/K6a0:f][@2YZJT0YJFU
09jNWP2IVIT0UYJF09>CT`2?Shl0QHF508:2PP1nOWh0Ng]k07UiN@1dM7@0LW9b071`L01_Kfl0KFe]
06a/K00206UYJ@0406QXJ01WIfL0IVIV06IVIPD0IFEU00<0I6AT06EUI@1UIFD00`1UIFD306IVIP80
IfMW0P1XJ6P306UYJ@0306YZJP1[Jf/0Jf][01h0oooo01T0V9RH09VIV@2LW9`0WIfM09nOW`2PX:00
XJ6Q0:>SX`2UYJD0YjNW0:RXZ02YZJT0ZZZZ0:b/[02][Jd0[jn_0;2`/02a/K40/[:b0;>c/`2d];@0
]KFe0;Jf]P2g]kL0^;Rh0080^KVi00D0^[Zj0;Vi^@2d];@0/[:b0:n_[`020:b/[00;0:^[Z`2VYZH0
Y:BT0::RXP2PX:00WYjN09^KV`2IVIT0UIFE09BDU02ATI400P2>SXh04`2<S8`0Rh^;08Z:RP29RHT0
Ph>30861P@1nOWh0O7al07UiN@1aLG40KVi^06UYJ@1TI6@0H61P05]KF`1@D500BTY:04M7A`14A4@0
0P0o?cl0:011@D40@T9204A4A016ATH0BDU904];B`1<C4`0CTi>051@D01BDU80EEEE05MGE`1JFUX0
Fe]K05eMG@1QHF40Hf=S06EUI@1WIfL0J6QX06YZJP1^KVh0L71`079bLP1dM7@0MWIf07UiN@1kNg/0
OGem07moO`21PH40Q8B408J6QP28R8P0RXZ:08b<S02=SHd0TI6A09>CT`2EUIDN0?ooo`0N0:j^[P2]
[Jd0ZJVY0:RXZ02VYZH0Y:BT0::RXP2QXJ40WIfM09^KV`2IVIT0UiNG09FEU@2ATI40Shn?08b<S02:
RXX0R8R808>3P`20P800OWin07]kN`1hN7P0MGEe06i^KP1ZJVX0IVIV065QH@1LG5`0GemO0P1QHF40
3@1NGUh0G5aL05UIF@1DE5@0DU9B04m?C`1<C4`0BDU904A4A013@d<0@D5103lo?`0m?Cd00P0j>SX2
03Ti>@0303Hf=P0d=3@0<30`00@0;bl_03@0;2`/02XZ:P0V9RH08b<S020P800L71`04a<C010@400>
3Ph03@d=00X:2P0D51@06QXJ01lO7`0U9BD0:RXZ03@d=00h>3P0?Cdm0451@@15ADD0BDU9055AD@1E
EED0FEUI05aLG01OGel0IVIV06UYJ@1/K6`0Kfm_079bLP1eMGD0Ng]k07inOP20P800Ph>308J6QP2;
Rh/0SHf=092@T02BTY80UIFE09VIV@2LW9`0WYjN0:2PX02RXZ80YJFU0:VYZ@2[Zj/0[Zj^8P3oool0
0200oooo0280Kfm_07=cL`1jNWX0OGem0861P@24Q8@0R8R808^;R`2BTY80UYJF09VIV@2MWId0X:2P
0:NWY`2[Zj/0[jn_0;:b/P2f][H0_Kfm0<71`@35aLD0bLW90<c<c03@d=00fMWI0=gMg@3Rh^80i^KV
0>[ZjP3_knl0jNWY0>;RhP3Ng]h0g=cL1`3Ng]h0103Ogml0g]kN0=kNgP3Kfm/20=KFeP0O0=CDe03B
d]80dM7A0<o?c`3;bl/0b<S80<C4a033`l<0_kno0;Rh^02f][H0/k>c0;2`/02][Jd0ZZZZ0:2PX02K
Vi/0V9RH09NGU`2@T900QXJ608>3P`1oOgl0O7al07YjNP1eMGD0Lg=c075aL@1`L700KVi^06e]K@02
06YZJP0406UYJ@1XJ6P0IfMW06MWI`@0IVIV1@1UIFD306IVIP<0IfMW0`1XJ6P206UYJ@80JVYZ0P1[
Jf/N0?ooo`0C09RHV02IVIT0W9bL09fMW@2NWYh0WinO0:6QX@2RXZ80Y:BT0:JVYP2WYjL0Z:RX0:VY
Z@2[Zj/0[:b/0:f][@2^[Zh0[jn_0;6a/@020;:b/P050;>c/`2d];@0];Bd0;Fe]@2f][H00P2g]kL0
4@2f][H0]KFe0;:b/P2^[Zh0Zj^[0:VYZ@2XZ:P0Xj>S0:6QX@2OWil0WIfM09^KV`2HV9P0UYJF09:B
TP2ATI40Shn?0080SHf=03d0S8b<08Z:RP2:RXX0R8R808F5Q@23Ph<0P82007emO@1iNGT0LG5a06e]
K@1XJ6P0Hf=S05iNGP1IFET0Cdm?04];B`16ATH0ADE504=3@`15ADD0ATI604M7A`19BDT0BTY:04e=
C@1?Cdl0DE5A059BDP1DE5@0EEEE05UIF@1KFe/0GEeM05mOG`1PH600I6AT06EUI@1WIfL0JFUY06][
J`1]KFd0L71`079bLP1dM7@0MGEe07MgM`1kNg/0OGem07inOP20P800PX:208F5Q@27QhL0RHV908^;
R`2<S8`0SXj>096AT@2CTi<0UIFE01h0oooo01h0[Zj^0:f][@2ZZZX0Z:RX0:JVYP2UYJD0Xj>S0:6Q
X@2NWYh0W9bL09ZJVP2HV9P0UYJF09:BTP2@T900SXj>08b<S029RHT0QHF508:2PP1oOgl0OGem07Yj
NP1gMgL0L71`06a/K01XJ6P0I6AT061PH01JFUX305]KF`0>05YJFP1FEUH0Cdm?04a<C019BDT0ATI6
04=3@`0n?Sh0>SXj03Hf=P0e=CD0=3@d03Hf=P0g=cL203Hf=P0k03Lg=`0f=SH0=CDe03Hf=P0d=3@0
<S8b030`<00Z:RX09bLW028R8P0N7Qh06QXJ01DE5@0@41003`l?00/;2`0:2PX03`l?01/K6`0Q8B40
9RHV02/[:`0`<300>CTi03hn?P12@T80ATI604Y:BP1>CTh0EEEE05UIF@1LG5`0H61P06=SH`1YJFT0
K6a/06m_K`1bLW80MGEe07QhN01mOGd0P82008:2PP25QHD0QhN708b<S02?Shl0TI6A09>CT`2FUYH0
VYZJ09fMW@2OWil0XJ6Q0:>SX`2UYJD0ZJVY0:b/[02^[Zh08P3oool00200oooo02<0Kfm_079bLP1i
NGT0O7al07moO`23Ph<0QXJ608V9R@2@T900Ti>C09NGU`2JVYX0WIfM0:BTY02XZ:P0Zj^[0:j^[P2b
/[80^KVi0;bl_030`<00`l?30<O7a`3;bl/0dm?C0=KFeP3Kfm/0gmoO0>?Sh`3/k>`0kNg]0>WYj@3Q
hN40gMgM0=_Kf`030=cLg080fm_K0P3Jf]X20=SHf00S0=OGe`3EeMD0e=CD0=;BdP3@d=00clo?0<g=
c@39bLT0b<S80<C4a033`l<0`<300;Vi^@2h^;P0]KFe0;>c/`2_[jl0Zj^[0::RXP2NWYh0V9RH09BD
U02?Shl0QhN708>3P`20P800OGem07]kN`1fMWH0M7Ad079bLP1`L700Kfm_06i^KP1[Jf/00P1ZJVX0
101YJFT0J6QX06QXJ01WIfL906IVIP<0IfMW101XJ6P306UYJ@80JVYZ0P1[Jf/N0?ooo`0>09RHV02I
VIT0Vi^K09fMW@2NWYh0WinO0:2PX02QXJ40Xj>S0:FUY@2VYZH0YjNW0:RXZ02ZZZX20:^[Z`030:b/
[02][Jd0[jn_0080/;2`00<0/K6a0;:b/P2b/[800P2c/k<40;Bd]00?0;2`/02_[jl0Zj^[0:NWY`2V
YZH0XJ6Q09nOW`2NWYh0Vi^K09ZJVP2FUYH0UIFE09>CT`2BTY80TI6A0080SXj>01@0S8b<08^;R`2;
Rh/0RHV908J6QP23Ph<0Ogmo07emO@1hN7P0Kfm_06][J`1VIVH0HF5Q05aLG01IFET0Cdm?04];B`19
BDT0BTY:04U9B@80Bd];02L0CDe=04i>CP1?Cdl0DU9B05=CD`1EEED0EUIF05QHF01IFET0G5aL05iN
GP1PH600HV9R06=SH`1WIfL0J6QX06YZJP1/K6`0KFe]06m_K`1bLW80M7Ad07IfMP1gMgL0NGUi07al
O01nOWh0P82008:2PP23Ph<0QXJ608R8R02:RXX0Rh^;08f=S@2>SXh0TY:B09>CT`2EUID07P3oool0
;@2^[Zh0[Jf]0:ZZZP2XZ:P0YjNW0:FUY@2TY:@0XZ:R09nOW`2MWId0Vi^K09VIV@2GUiL0Ti>C096A
T@2?Shl0SHf=08^;R`26QXH0Q8B40861P@1oOgl0O7al07UiN@1bLW80Kfm_06][J`1WIfL0Hf=S05UI
F@1DE5@0EUIF05QHF01GEeL0EUIF04m?C`1;Bd/0BDU904M7A`15ADD0?clo03hn?P0m?Cd0?3`l03/k
>`0303Ti>@<0>SXj03T0>3Ph03Hf=P0c<c<0<C4a02h^;P0W9bL08R8R01`L700H61P051@D01<C4`0?
3`l030`<00h>3P0D51@06ATI02<S8`0X:2P0;Bd]038b<P0f=SH0?clo04=3@`17AdL0Bd];04m?C`1C
De<0FUYJ05eMG@1PH600Hf=S06IVIP1/K6`0Kfm_079bLP1eMGD0N7Qh07YjNP20P800PX:208F5Q@27
QhL0RHV908j>SP2@T900TY:B09FEU@2GUiL0Vi^K09fMW@2PX:00XZ:R0:BTY02VYZH0ZZZZ0:b/[02^
[Zh08P3oool00200oooo02@0Kfm_079bLP1hN7P0Ng]k07inOP21PH40Q8B408R8R02>SXh0TI6A09BD
U02GUiL0VYZJ0:6QX@2TY:@0YjNW0:ZZZP2^[Zh0];Bd0;Rh^02k^k/0_[jn0<;2`P35aLD0c<c<0=3@
d03De=@0f=SH0=_Kf`3Shn<0i^KV0>WYj@3WinL0h>3P0=cLg03Hf=P40=OGe`80e]KF0P3EeMD01@3D
e=@0dM7A0=7Ad@3?cll0c/k>0080cLg=01d0b<S80<O7a`34a<@0`l?30<71`@2k^k/0^KVi0;Ng]`2c
/k<0[jn_0:^[Z`2SXj<0WIfM09RHV02CTi<0Shn?08N7Q`23Ph<0P82007emO@1kNg/0MWIf07AdM01c
Lg<0LG5a071`L01^KVh0K6a/06][J`0206YZJP0306UYJ@1XJ6P0J6QX00D0IfMW0`1VIVH306MWI`@0
J6QX0`1YJFT206YZJP<0Jf][7P3oool0502HV9P0VIVI09^KV`2LW9`0WIfM09jNWP2OWil0X:2P0:>S
X`2TY:@0YJFU0:JVYP2WYjL0Z:RX0:VYZ@2ZZZX0Zj^[0:b/[02][Jd0[Zj^0P2_[jl20;2`/0D0/K6a
0100/;2`0:n_[`2^[Zh0Zj^[0:NWY`2TY:@0X:2P09jNWP2MWId0Vi^K09VIV@2FUYH0U9BD09>CT`2B
TY80TI6A0P2?Shl0402>SXh0S8b<08^;R`2:RXX0QHF508:2PP1nOWh0Ng]k07IfMP1]KFd0J6QX06EU
I@1QHF40GEeM05UIF@1ADE4404m?C`0Y051@D01ADE40DU9B05=CD`1DE5@0EUIF05QHF01IFET0FUYJ
05aLG01MGEd0H61P069RHP1SHf<0IFEU06IVIP1YJFT0Jf][06a/K01^KVh0L71`075aL@1dM7@0MWIf
07QhN01iNGT0Ng]k07inOP1oOgl0PH6108>3P`24Q8@0QhN708V9R@2:RXX0S8b<08f=S@2?Shl0TY:B
09>CT`2EUID07P3oool08@2^[Zh0[Jf]0:ZZZP2YZJT0YjNW0:JVYP2TY:@0Xj>S09nOW`2NWYh0W9bL
09ZJVP2HV9P0UIFE09>CT`2ATI40Shn?08f=S@28R8P0QXJ608B4Q021PH40OWin07]kN`1eMGD0LW9b
06i^KP1[Jf/0IfMW05iNGP1IFET0E5AD059BDP0205=CD`09055AD@1?Cdl0CDe=04Y:BP17AdL0@d=3
0492@P10@400?clo00@0?Shn03`0?Cdm03`l?00k>c/0>CTi03Hf=P0c<c<0;bl_02TY:@0Q8B407AdM
01XJ6P0G5aL05QHF01@D500@41004a<C01PH600M7Ad08R8R02/[:`0`<300=3@d03Ti>@0m?Cd0ADE5
04U9B@1=CDd0D51@05ADE01HF5P0GUiN065QH@1TI6@0IfMW06YZJP1`L700Lg=c07EeM@1hN7P0Ng]k
07emO@22PX80QHF508N7Q`29RHT0Rh^;092@T02BTY80U9BD09JFUP2HV9P0W9bL09jNWP2PX:00XZ:R
0:BTY02VYZH0ZZZZ0:b/[02^[ZhR0?ooo`00803oool0:`1^KVh0LG5a07IfMP1iNGT0O7al07moO`21
PH40Q8B408Z:RP2<S8`0Shn?09:BTP2EUID0VYZJ09fMW@2PX:00Xj>S0:JVYP2[Zj/0[Zj^0;6a/@2d
];@0]kNg0;Zj^P30`<00`l?30<K6aP39bLT0c<c<0=;BdP3De=@0emOG0=WIf@3Jf]X0g=cL0=[JfP3F
e]H0d];B0<o?c`3>c/h0c<c<0<g=c@3<c<`00P3=cLd20<k>cP0Q0<g=c@3;bl/0b/[:0<[:bP3;bl/0
b<S80<G5a@34a<@0`<300;Vi^@2h^;P0][Jf0;>c/`2][Jd0Z:RX09jNWP2IVIT0UIFE096AT@2<S8`0
QXJ608>3P`20P800OGem07]kN`1gMgL0MGEe07=cL`1bLW80L71`06m_K`1]KFd0K6a/0080Jf][00<0
JVYZ06UYJ@1YJFT00P1YJFT306QXJ080IfMW00<0J6QX06MWI`1WIfL00P1XJ6P506UYJ@<0JVYZ0`1[
Jf/N0?ooo`0:09NGU`2HV9P0VYZJ09^KV`2LW9`0WIfM09jNWP2OWil0XJ6Q0::RXP80Xj>S00H0Y:BT
0:JVYP2WYjL0YjNW0:RXZ02YZJT20:ZZZP80Zj^[0`2/[:`20:f][@80[:b/00d0Zj^[0:ZZZP2XZ:P0
YjNW0:FUY@2TY:@0WYjN09fMW@2KVi/0VIVI09RHV02EUID0U9BD0080TY:B01@0TI6A092@T02?Shl0
SHf=08^;R`2:RXX0QhN708>3P`1nOWh0NWYj07QhN01dM7@0K6a/06QXJ01VIVH0HV9R061PH01OGel0
G5aL05]KF`@0FUYJ02P0Fe]K05aLG01LG5`0GEeM05mOG`1PH600HF5Q069RHP1SHf<0IFEU06MWI`1X
J6P0JVYZ06][J`1/K6`0Kfm_071`L01bLW80Lg=c07EeM@1fMWH0NGUi07YjNP1kNg/0OGem07inOP21
PH40PX:208B4Q025QHD0QhN708V9R@2;Rh/0S8b<08f=S@2>SXh0T92@09:BTP2DU9@0UIFE7P3oool0
9@2_[jl0[Jf]0:^[Z`2YZJT0Z:RX0:NWY`2UYJD0Y:BT0:6QX@2PX:00WYjN09fMW@2KVi/0V9RH09JF
UP2DU9@0TY:B092@T02<S8`0RXZ:08R8R026QXH0Ph>30861P@1lO7`0NGUi07IfMP1bLW80Kfm_06MW
I`1SHf<0GemO05]KF`1FEUH0DU9B04a<C01>CTh00P1@D500A@1?Cdl0Bd];04U9B@18B4P0AdM704E5
A@13@d<0@D510410@00n?Sh0?Cdm03Xj>P0b<S80;Rh^02/[:`0Y:BT09bLW024Q8@0N7Qh06a/K01XJ
6P0L71`07alO02DU9@0X:2P0;2`/030`<00d=3@0?3`l0410@013@d<0AdM704];B`1BDU80EEEE05UI
F@1LG5`0GemO069RHP1XJ6P0Jf][06e]K@1`L700LW9b07MgM`1jNWX0O7al07inOP21PH40Ph>308R8
R02:RXX0S8b<08j>SP2@T900U9BD09JFUP2HV9P0VIVI09^KV`2OWil0X:2P0::RXP2TY:@0YZJV0:RX
Z02[Zj/0[:b/0:j^[P0R0?ooo`00803oool08P1^KVh0LG5a07IfMP1hN7P0Ng]k07emO@20P800PX:2
08R8R02:RXX0SHf=08n?S`2BTY80UiNG09ZJVP2LW9`0WYjN0::RXP2WYjL0ZZZZ0:b/[02_[jl0/[:b
0;Bd]02j^[X0_;bl0;no_`32`/80aLG50<[:bP3<c<`0c/k>0=3@d03AdM420=;BdP050=CDe03Bd]80
d=3@0<c<c039bLT00`38b<P09039bLT0bl_;0<_;b`3<c<`0bl_;0<[:bP38b<P0alO70<G5a@31`L40
_kno0;jn_P2g]kL0/k>c0;2`/02/[:`0Z:RX0:BTY02KVi/0UYJF09>CT`2?Shl0Rh^;08F5Q@22PX80
Ogmo07emO@1kNg/0MgMg07EeM@1dM7@0LW9b075aL@1`L700KFe]06a/K080Jf][00@0JVYZ06UYJ@1Y
JFT0JFUY201XJ6P00`1WIfL0J6QX06QXJ00406UYJ@@0JVYZ0`1[Jf/N0?ooo`0609NGU`2HV9P0VYZJ
09^KV`2LW9`0WIfM0P2NWYh01@2PX:00XJ6Q0::RXP2RXZ80Xj>S0080YJFU0P2VYZH0102WYjL0Z:RX
0:VYZ@2YZJT40:ZZZP0:0:^[Z`2ZZZX0ZZZZ0:ZZZP2YZJT0Z:RX0:NWY`2UYJD0Y:BT0::RXP80WYjN
01X0Vi^K09ZJVP2HV9P0U9BD09>CT`2BTY80TI6A092@T02?Shl0SXj>08f=S@2;Rh/0R8R808J6QP22
PX80OWin07]kN`1hN7P0M7Ad06a/K01ZJVX0J6QX06MWI`1UIFD0Hf=S065QH@80H61P0`1OGel2061P
H00V065QH@1RHV80Hf=S06ATI01UIFD0IVIV06MWI`1XJ6P0Jf][06a/K01]KFd0KVi^06m_K`1bLW80
Lg=c07EeM@1fMWH0MgMg07QhN01kNg/0O7al07emO@1oOgl0P82008:2PP24Q8@0QHF508N7Q`28R8P0
RXZ:08^;R`2=SHd0SXj>08n?S`2@T900Ti>C09BDU02EUIDN0?ooo`0X0:n_[`2][Jd0Zj^[0:ZZZP2Y
ZJT0YjNW0:JVYP2UYJD0XZ:R0:6QX@2OWil0WYjN09bLW02IVIT0V9RH09JFUP2DU9@0Ti>C08n?S`2=
SHd0Rh^;08R8R026QXH0Q8B407moO`1lO7`0NGUi07IfMP1cLg<0K6a/06UYJ@1UIFD0HF5Q05eMG@1I
FET0E5AD055AD@1>CTh0Cdm?051@D080CTi>0480C4a<04Y:BP19BDT0ADE50492@P10@400?Shn03`l
?00i>CT0=CDe038b<P0a<C40;Rh^02XZ:P0T92@09BDU02HV9P0W9bL0:BTY02/[:`0`<300<c<c03Lg
=`0j>SX0?Cdm04A4A018B4P0Bd];04m?C`1BDU80F5QH05]KF`1NGUh0HF5Q06ATI01WIfL0KFe]06m_
K`1bLW80M7Ad07MgM`1lO7`0OWin0820P023Ph<0QHF508J6QP2:RXX0S8b<08j>SP2@T900TY:B09JF
UP2HV9P0VYZJ09^KV`2MWId0X:2P0::RXP2SXj<0YJFU0:JVYP2XZ:P0Zj^[0:f][@2^[ZhR0?ooo`00
803oool08`1^KVh0L71`07EeM@1gMgL0NWYj07alO01nOWh0PH6108F5Q@28R8P0RXZ:08b<S02?Shl0
U9BD09JFUP2IVIT0Vi^K09jNWP2RXZ80YJFU0:NWY`2ZZZX0[:b/0:n_[`2d];@0][Jf0;Vi^@2k^k/0
_Kfm0<;2`P34a<@0aLG50<O7a`38b<P0bLW90080b/[:00D0bl_;0<c<c03;bl/0b<S80<O7a`040<G5
a@@0a<C401h0`l?30<71`@31`L40_kno0;fm_@2i^KT0/[:b0:j^[P2ZZZX0YjNW0:BTY02OWil0V9RH
09BDU02@T900SHf=08Z:RP24Q8@0PH6107moO`1lO7`0NWYj07MgM`1eMGD0M7Ad079bLP1aLG40L71`
06i^KP1]KFd206a/K00306][J`1ZJVX0JFUY00<0JFUY00@0J6QX06UYJ@1XJ6P0JFUY101XJ6P306UY
J@H0JVYZ0`1[Jf/N0?ooo`0309NGU`2HV9P0VYZJ0080Vi^K00D0W9bL09fMW@2NWYh0WinO0:2PX002
0:6QX@030::RXP2SXj<0Y:BT0080YJFU00<0YZJV0:NWY`2WYjL0102XZ:P20:VYZ@<0Z:RX00d0YjNW
0:JVYP2UYJD0Y:BT0::RXP2QXJ40WYjN09fMW@2KVi/0VYZJ09NGU`2DU9@0TY:B0080TI6A01<0T92@
08n?S`2>SXh0SHf=08Z:RP28R8P0QXJ608:2PP1oOgl0Ng]k07QhN01eMGD0L71`06i^KP1/K6`0Jf][
06YZJP1XJ6P0IVIV0080IFEU0`1TI6@306EUI@0U06IVIP1WIfL0J6QX06UYJ@1ZJVX0Jf][06a/K01^
KVh0Kfm_071`L01aLG40LW9b07EeM@1fMWH0MgMg07QhN01iNGT0Ng]k07emO@1nOWh0Ogmo0861P@22
PX80Q8B408F5Q@27QhL0R8R808V9R@2;Rh/0S8b<08f=S@2>SXh0T92@096AT@2CTi<0U9BD09FEU@0N
0?ooo`0X0:n_[`2^[Zh0Zj^[0:ZZZP2YZJT0Z:RX0:NWY`2UYJD0Xj>S0::RXP2PX:00WinO09jNWP2K
Vi/0VIVI09RHV02FUYH0U9BD096AT@2?Shl0SHf=08^;R`29RHT0QhN708:2PP20P800OGem07YjNP1g
MgL0LG5a06i^KP1[Jf/0IfMW06ATI01QHF40G5aL05UIF@1GEeL0E5AD055AD@80CTi>0P1=CDd0@01<
C4`0BTY:04U9B@18B4P0A4A40451@@0o?cl0>SXj03Hf=P0b<S80<30`02l_;`0`<300<C4a038b<P0c
<c<0=3@d03Hf=P0k>c/0?Cdm0410@013@d<0ATI604a<C01@D500De=C05IFEP1IFET0GUiN065QH@1T
I6@0IfMW06YZJP1/K6`0LG5a07AdM01fMWH0N7Qh07]kN`1oOgl0PX:208B4Q026QXH0QhN708V9R@2=
SHd0Shn?096AT@2BTY80U9BD09RHV02IVIT0Vi^K09fMW@2NWYh0XJ6Q0:>SX`2TY:@0YZJV0:NWY`2X
Z:P0Zj^[0:f][@2^[ZhR0?ooo`00803oool08`1^KVh0L71`07AdM01fMWH0N7Qh07]kN`1mOGd0Ogmo
08>3P`25QHD0R8R808Z:RP2<S8`0T92@09>CT`2EUID0UiNG09VIV@2NWYh0X:2P0::RXP2UYJD0YjNW
0:VYZ@2][Jd0/;2`0;:b/P2d];@0][Jf0;Zj^P2l_;`0_Kfm0;jn_P2o_kl0`<3000D0`/;20P31`L42
0<30`0050;no_`31`L40`L710<71`@30`<000P2o_kl07@2l_;`0^[Zj0;Rh^02e]KD0/[:b0:b/[02X
Z:P0Y:BT0:6QX@2OWil0Vi^K09BDU02ATI40SHf=08^;R`28R8P0Ph>30820P01nOWh0O7al07YjNP1f
MWH0MGEe07AdM01bLW80LG5a071`L01^KVh0KFe]0080K6a/00<0Jf][06YZJP1ZJVX00P1ZJVX306UY
J@0306QXJ01YJFT0JFUY00H0JFUY1P1ZJVX306][Jah0oooo00D0UiNG09RHV02IVIT0VYZJ09^KV`02
09bLW00309fMW@2NWYh0WinO0080X:2P00D0XJ6Q0::RXP2SXj<0Xj>S0:BTY0020:FUY@@0YZJV102W
YjL20:JVYP0S0:FUY@2TY:@0Xj>S0::RXP2QXJ40X:2P09fMW@2LW9`0VYZJ09VIV@2GUiL0U9BD09>C
T`2BTY80TI6A092@T02?Shl0SXj>08b<S02:RXX0R8R808J6QP22PX80Ogmo07emO@1jNWX0N7Qh07Ad
M01bLW80L71`06m_K`1^KVh0KFe]06][J`1ZJVX01P1YJFT206YZJP0906][J`1/K6`0KFe]06i^KP1_
Kfl0L71`075aL@1bLW80Lg=c0080MGEe00/0N7Qh07UiN@1jNWX0Ng]k07alO01mOGd0Ogmo0820P021
PH40Ph>308B4Q00208J6QP0<08R8R029RHT0RXZ:08b<S02=SHd0SXj>08n?S`2@T900TI6A09>CT`2D
U9@0UIFE7P3oool0=`2_[jl0[Zj^0:b/[02[Zj/0ZZZZ0:RXZ02WYjL0YZJV0:BTY02SXj<0XJ6Q0:2P
X02OWil0W9bL09^KV`2IVIT0V9RH09NGU`2CTi<0TI6A092@T02>SXh0S8b<08Z:RP26QXH0Ph>30861
P@1nOWh0O7al07IfMP1cLg<0L71`06i^KP1[Jf/0J6QX06=SH`1PH600GUiN05aLG01IFET0EUIF05EE
E@1DE5@0De=C059BDP1?Cdl0C4a<04Y:BP18B4P0ADE504=3@`0o?cl0?Shn03dm?@0l?3`00P0k>c/0
<`0l?3`0?Cdm03hn?P10@400@T9204I6AP18B4P0BTY:04a<C01?Cdl0E5AD05MGE`1JFUX0GEeM061P
H01UIFD0IfMW06YZJP1]KFd0L71`079bLP1fMWH0NGUi07]kN`1mOGd0Ogmo08>3P`25QHD0QhN708V9
R@2;Rh/0S8b<092@T02BTY80Ti>C09FEU@2GUiL0VYZJ09^KV`2LW9`0WYjN0:2PX02RXZ80Y:BT0:FU
Y@2VYZH0Z:RX0:VYZ@2/[:`0[Jf]0:n_[`0R0?ooo`00803oool08`1^KVh0Kfm_07=cL`1eMGD0MgMg
07UiN@1kNg/0OGem0861P@23Ph<0QHF508N7Q`29RHT0SHf=08n?S`2ATI40Ti>C09FEU@2IVIT0Vi^K
09fMW@2OWil0XJ6Q0:>SX`2WYjL0ZJVY0:^[Z`2][Jd0[jn_0;:b/P2d];@0]KFe0;Jf]P2g]kL0^;Rh
00D0^[Zj0P2i^KT30;Rh^0<0^KVi01l0^;Rh0;Ng]`2g]kL0];Bd0;:b/P2`/;00[Jf]0:^[Z`2UYJD0
XZ:R09nOW`2LW9`0VYZJ09NGU`2ATI40SXj>08^;R`28R8P0QXJ60861P@1oOgl0OGem07]kN`1iNGT0
MWIf07AdM01cLg<0LW9b075aL@1`L700KVi^0080KFe]00<0K6a/06][J`1[Jf/01@1ZJVX806UYJ@L0
JVYZ101[Jf/N0?ooo`0309NGU`2HV9P0VIVI0080VYZJ00<0Vi^K09bLW02LW9`00P2NWYh209nOW`03
0:2PX02QXJ40XZ:R0080XZ:R00@0Xj>S0:BTY02TY:@0Y:BT1P2UYJD20:BTY080Xj>S00/0XZ:R0:6Q
X@2PX:00WinO09bLW02KVi/0VYZJ09VIV@2GUiL0U9BD09>CT`0209:BTP0C096AT@2?Shl0SXj>08b<
S02;Rh/0RHV908R8R023Ph<0PH6107moO`1mOGd0Ng]k07MgM`1eMGD0M7Ad07=cL`1bLW80LG5a06m_
K`0206i^KP<0KFe]101^KVh2071`L00B075aL@1bLW80Lg=c07=cL`1eMGD0MWIf07MgM`1hN7P0NGUi
07YjNP1kNg/0O7al07emO@1nOWh0Ogmo0861P@22PX80Ph>30P25QHD03027QhL0R8R808V9R@2:RXX0
Rh^;08f=S@2>SXh0Shn?092@T02ATI40TY:B09BDU080UIFE7P3oool0=P2_[jl0[Zj^0:b/[02[Zj/0
ZZZZ0:VYZ@2XZ:P0YjNW0:FUY@2TY:@0Xj>S0::RXP2PX:00WYjN09fMW@2KVi/0VYZJ09RHV02FUYH0
U9BD09:BTP2ATI40Shn?08f=S@29RHT0QhN708F5Q@23Ph<0P82007]kN`1iNGT0MWIf07AdM01aLG40
Kfm_06YZJP1XJ6P0IVIV06ATI01RHV80GemO05iNGP1LG5`0Fe]K05YJFP1GEeL0EEEE05=CD`1ADE40
Cdm?04i>CP1;Bd/0BDU904Q8B0@0AdM70380B4Q804U9B@1;Bd/0C4a<051@D01BDU80E5AD05IFEP1H
F5P0GEeM061PH01RHV80I6AT06MWI`1/K6`0KVi^071`L01cLg<0MGEe07MgM`1kNg/0OGem07moO`21
PH40Ph>308N7Q`29RHT0RXZ:08b<S02>SXh0Shn?09>CT`2DU9@0UYJF09NGU`2IVIT0W9bL09fMW@2N
WYh0WinO0:6QX@2TY:@0YJFU0:JVYP2WYjL0Z:RX0:ZZZP2/[:`0[Zj^0:n_[b80oooo000P0?ooo`0P
06e]K@1_Kfl0LW9b07=cL`1eMGD0MgMg07QhN01jNWX0OGem07inOP20P800PX:208>3P`26QXH0R8R8
08Z:RP2;Rh/0SHf=092@T02BTY80Ti>C09FEU@2GUiL0V9RH09^KV`2MWId0WYjN0:2PX02QXJ40Y:BT
0:FUY@2VYZH20:NWY`030:RXZ02YZJT0ZZZZ0080ZZZZ2@2YZJT0702XZ:P0YjNW0:NWY`2TY:@0Xj>S
0:6QX@2OWil0WYjN09VIV@2GUiL0UIFE09:BTP2@T900SXj>08Z:RP27QhL0QHF508>3P`21PH40OGem
07]kN`1jNWX0N7Qh07MgM`1dM7@0Lg=c079bLP1aLG42071`L00506i^KP1]KFd0KFe]06e]K@1/K6`0
0P1[Jf/<06YZJP0306UYJ@1ZJVX0JVYZ0080JVYZ1P1[Jf/N0?ooo`80UiNG0P2IVIT209ZJVP80Vi^K
00D0W9bL09fMW@2MWId0WIfM09jNWP0209nOW`<0X:2P0`2QXJ450::RXP<0XJ6Q00@0X:2P09nOW`2O
Wil0WYjN0P2MWId0202KVi/0VYZJ09VIV@2HV9P0UiNG09FEU@2DU9@0Ti>C0P2BTY803P2@T900Shn?
08j>SP2=SHd0Rh^;08Z:RP27QhL0QHF508B4Q022PX80PH6107inOP1mOGd0O7al0P1jNWX00`1iNGT0
N7Qh07MgM`0607IfMP80MgMg0P1hN7P207UiN@80NWYj0P1lO7`0101mOGd0OWin07moO`20P8020861
P@0408:2PP23Ph<0Q8B408J6QP80QhN700@0R8R808V9R@2:RXX0Rh^;0P2<S8`02P2>SXh0Shn?092@
T02@T900TI6A09:BTP2CTi<0U9BD09FEU@2FUYHN0?ooo`050:n_[`2^[Zh0[Jf]0:b/[02[Zj/00P2Z
ZZX0;@2YZJT0YjNW0:JVYP2UYJD0Y:BT0:>SX`2QXJ40X:2P09nOW`2NWYh0WIfM09^KV`2IVIT0V9RH
09NGU`2EUID0U9BD096AT@2?Shl0SHf=08^;R`2:RXX0QXJ608B4Q022PX80P82007inOP1mOGd0NGUi
07MgM`1eMGD0Lg=c079bLP1`L700KVi^06e]K@1/K6`0Jf][06QXJ01WIfL0IFEU06ATI01SHf<0HV9R
05mOG`0205iNGP<0GEeM0P1NGUh0<@1OGel0H61P065QH@1TI6@0IFEU06IVIP1XJ6P0JVYZ06i^KP1`
L700LG5a07AdM01fMWH0NGUi07]kN`1mOGd0Ogmo0820P022PX80QHF508N7Q`29RHT0RXZ:08b<S02?
Shl0T92@09:BTP2CTi<0U9BD09JFUP2HV9P0VYZJ09^KV`2LW9`0WIfM0:2PX02QXJ40XZ:R0:>SX`2T
Y:@0YZJV0:NWY`2XZ:P0ZJVY0:ZZZP2[Zj/0[Jf]0:j^[P2_[jl08P3oool00200oooo01d0KFe]06i^
KP1aLG40LW9b07AdM01eMGD0MgMg07QhN01kNg/0O7al07emO@1oOgl0P82008>3P`24Q8@0QXJ608N7
Q`29RHT0S8b<08f=S@2?Shl0T92@096AT@2CTi<0UIFE09NGU`2HV9P0VIVI09ZJVP0209fMW@0509jN
WP2OWil0X:2P0:2PX02QXJ400`2RXZ890:6QX@80X:2P01L0WinO09fMW@2LW9`0VYZJ09VIV@2GUiL0
Ti>C096AT@2@T900SHf=08^;R`2:RXX0QXJ608B4Q022PX80P82007moO`1kNg/0NGUi07QhN01gMgL0
MWIf07=cL`02079bLP04075aL@1`L700Kfm_06i^KP<0KFe]00@0K6a/06][J`1[Jf/0Jf][3P1ZJVX3
06][J`0306YZJP1[Jf/0Jf][0080Jf][7P3oool209NGU`0309RHV02IVIT0VIVI0080VYZJ0P2KVi/2
09bLW080WIfM0`2NWYh309nOW`X0X:2P00<0WinO09jNWP2NWYh00P2MWId01`2LW9`0VYZJ09ZJVP2I
VIT0V9RH09NGU`2EUID00P2DU9@04@2CTi<0TY:B096AT@2@T900Shn?08j>SP2=SHd0Rh^;08V9R@27
QhL0QXJ608F5Q@24Q8@0PH610820P01oOgl0OWin0080OGem00@0O7al07]kN`1kNg/0Ng]k0`1jNWX3
07]kN`80O7al0`1mOGd01`1nOWh0Ogmo0820P020P800PH6108:2PP23Ph<00P24Q8@01025QHD0QXJ6
08J6QP28R8P208V9R@0508Z:RP2;Rh/0S8b<08b<S02=SHd00P2>SXh00`2@T900TI6A096AT@0209:B
TP0409>CT`2EUID0UIFE09JFUQh0oooo0P2_[jl0102][Jd0[:b/0:b/[02[Zj/20:ZZZP0Q0:RXZ02W
YjL0YZJV0:JVYP2UYJD0Xj>S0::RXP2QXJ40X:2P09nOW`2MWId0W9bL09^KV`2JVYX0V9RH09NGU`2D
U9@0Ti>C096AT@2@T900SXj>08^;R`29RHT0R8R808J6QP24Q8@0Ph>30820P01nOWh0O7al07]kN`1j
NWX0MgMg0080MWIf00X0MGEe07=cL`1aLG40L71`06m_K`1]KFd0K6a/06][J`1ZJVX0JFUY1@1XJ6P0
901YJFT0JVYZ06][J`1[Jf/0KFe]06i^KP1`L700LW9b07=cL`1fMWH0N7Qh07YjNP1lO7`0OGem0820
P022PX80Ph>308F5Q@26QXH0R8R808Z:RP2<S8`0SHf=08n?S`2@T900Ti>C09FEU@2FUYH0UiNG09RH
V02IVIT0W9bL09fMW@2NWYh0WinO0:2PX080XZ:R00`0Xj>S0:BTY02UYJD0YjNW0:RXZ02YZJT0ZZZZ
0:^[Z`2/[:`0[Jf]0:j^[P2_[jlR0?ooo`00803oool0801]KFd0KVi^071`L01aLG40Lg=c07AdM01e
MGD0MWIf07UiN@1jNWX0Ng]k07alO01mOGd0P8200861P@22PX80Ph>308F5Q@27QhL0R8R808Z:RP2;
Rh/0S8b<08f=S@2?Shl0T92@096AT@2CTi<0U9BD09FEU@2FUYH0UiNG0P2HV9P209VIV@D0VYZJ00<0
VIVI09ZJVP2IVIT0102IVIT209RHV00J09NGU`2FUYH0UIFE09>CT`2BTY80TI6A08f=S@2<S8`0RXZ:
08V9R@27QhL0QHF508:2PP21PH40Ogmo07emO@1lO7`0NWYj07QhN01gMgL0MGEe07AdM01cLg<0LW9b
075aL@1`L70206m_K`0306i^KP1]KFd0K6a/0080K6a/1P1[Jf/:06YZJPT0Jf][7P3oool209NGU`80
V9RH0P2IVIT209ZJVP<0Vi^K0P2LW9`409fMW@80WYjN1`2OWil309jNWP<0WIfM0P2LW9`00`2KVi/0
VYZJ09VIV@0209RHV00609NGU`2EUID0UIFE09BDU02CTi<0TY:B0P2ATI401P2@T900Shn?08j>SP2=
SHd0Rh^;08Z:RP80R8R800D0QXJ608B4Q023Ph<0Ph>308:2PP020861P@030820P01oOgl0Ogmo00L0
Ogmo0`20P8020861P@80PX:20P23Ph<01024Q8@0QHF508J6QP26QXH208N7Q`0308R8R029RHT0RXZ:
0080Rh^;0P2<S8`00`2=SHd0SXj>08j>SP0208n?S`80TI6A0P2BTY801@2CTi<0U9BD09FEU@2EUID0
UYJF01h0oooo0P2_[jl01`2^[Zh0[Jf]0:b/[02/[:`0Zj^[0:ZZZP2YZJT00P2XZ:P09@2WYjL0YZJV
0:FUY@2TY:@0Xj>S0::RXP2QXJ40X:2P09nOW`2NWYh0WIfM09bLW02KVi/0V9RH09NGU`2FUYH0U9BD
09>CT`2@T900Shn?08f=S@2<S8`0Rh^;08V9R@26QXH0QHF508B4Q023Ph<0PX:20820P01oOgl0OWin
07emO@1lO7`0NWYj07UiN@1hN7P00P1gMgL0101fMWH0M7Ad07=cL`1cLg<3079bLP80Lg=c02/0M7Ad
07EeM@1eMGD0MgMg07QhN01iNGT0NWYj07]kN`1nOWh0P8200861P@23Ph<0Q8B408N7Q`28R8P0RHV9
08^;R`2<S8`0SXj>092@T02ATI40Ti>C09BDU02EUID0UiNG09RHV02IVIT0VYZJ09^KV`2LW9`0WYjN
09nOW`2PX:00XJ6Q0::RXP2SXj<0Y:BT0:FUY@2VYZH0YjNW0:RXZ02YZJT0ZZZZ0080Zj^[00@0[:b/
0:j^[P2_[jl0[jn_8P3oool00200oooo01@0KFe]06i^KP1_Kfl0L71`075aL@1bLW80Lg=c07AdM01f
MWH0MgMg07QhN01iNGT0NWYj07alO01mOGd0OWin07moO`20P800PX:208B4Q080QHF500T0QXJ608N7
Q`29RHT0RXZ:08^;R`2<S8`0SHf=08j>SP2?Shl00`2@T9000`2ATI40TY:B09:BTP0709:BTPD0TI6A
0P2@T9003P2?Shl0SXj>08b<S02<S8`0Rh^;08R8R026QXH0QHF508B4Q023Ph<0PH6107inOP1mOGd0
O7al0P1jNWX01@1gMgL0MWIf07EeM@1dM7@0Lg=c0080LG5a00<0L71`06m_K`1_Kfl00P1^KVh0101]
KFd0K6a/06a/K01/K6`406][J`0406YZJP1[Jf/0JVYZ06][J`<0JVYZ00<0Jf][06YZJP1ZJVX00P1Z
JVX706][J`80K6a/7P3oool209NGU`<0V9RH0`2IVIT309ZJVP80Vi^K1@2LW9`;09fMW@<0W9bL0P2K
Vi/0102JVYX0VIVI09RHV02HV9P209NGU`0709JFUP2EUID0U9BD09BDU02CTi<0TY:B096AT@02092@
T00708n?S`2>SXh0SHf=08b<S02;Rh/0RXZ:08V9R@0208N7Q`0308J6QP25QHD0QHF50080Q8B40P23
Ph<00`22PX80Ph>308>3P`0408>3P`@0Q8B40P25QHD208J6QP80QhN70P28R8P208V9R@80RXZ:00<0
Rh^;08b<S02=SHd00P2=SHd00`2>SXh0Shn?08n?S`02092@T003096AT@2BTY80TY:B0080Ti>C0P2D
U9@209FEU@0309JFUP3oool0oooo01`0oooo0P2_[jl00`2^[Zh0[Jf]0:f][@020:b/[0040:^[Z`2Z
ZZX0ZZZZ0:VYZ@80Z:RX00<0YjNW0:JVYP2UYJD00P2TY:@20::RXP0F0:6QX@2PX:00WinO09jNWP2L
W9`0Vi^K09ZJVP2IVIT0V9RH09FEU@2DU9@0Ti>C09:BTP2ATI40T92@08f=S@2<S8`0Rh^;08Z:RP29
RHT0R8R808N7Q`80QXJ600<0QHF508>3P`22PX800P21PH401020P800Ogmo07inOP1nOWh507emO@<0
OWin0180Ogmo0861P@22PX80PX:208>3P`25QHD0QhN708R8R029RHT0RXZ:08^;R`2>SXh0Shn?092@
T02ATI40TY:B09>CT`2EUID209NGU`0809RHV02IVIT0Vi^K09bLW02MWId0WYjN09nOW`2PX:020::R
XP040:>SX`2TY:@0Y:BT0:JVYP80YjNW0P2XZ:P20:ZZZP80Zj^[00D0[:b/0:f][@2^[Zh0[Zj^0:n_
[`0R0?ooo`00803oool02`1/K6`0KFe]06m_K`1_Kfl0L71`075aL@1bLW80Lg=c07AdM01eMGD0MWIf
0080MgMg00H0NGUi07YjNP1kNg/0Ng]k07alO01nOWh207moO`050820P021PH40PX:208>3P`24Q8@0
0P25QHD01026QXH0QhN708R8R028R8P308V9R@<0RXZ:0P2;Rh/708Z:RP@0RHV900h0R8R808N7Q`26
QXH0QHF508B4Q023Ph<0PH610820P01oOgl0OWin07emO@1kNg/0NWYj07UiN@80MgMg00<0MGEe07Ad
M01cLg<00P1bLW82071`L080Kfm_0P1^KVh306e]K@<0K6a/301[Jf/00`1ZJVX0Jf][06][J`0806][
J`0306a/K03oool0oooo01`0oooo0`2GUiL409RHV0<0VIVI102JVYX409^KV`X0W9bL102KVi/209ZJ
VP0309VIV@2HV9P0V9RH00<0UiNG00<0UYJF09FEU@2EUID00P2DU9@00`2CTi<0TY:B09:BTP02096A
T@04092@T02?Shl0SXj>08f=S@80S8b<0P2:RXX208V9R@80R8R83027QhL408R8R00408V9R@2:RXX0
RXZ:08Z:RP80Rh^;0`2<S8`208f=S@0508j>SP2?Shl0Shn?08n?S`2@T900102ATI40102BTY80Ti>C
09>CT`2CTi<209BDU080UIFE0P2FUYHN0?ooo`80[jn_0P2^[Zh30:f][@030:b/[02[Zj/0Zj^[0080
ZZZZ00<0ZJVY0:RXZ02XZ:P00P2WYjL01@2VYZH0YJFU0:FUY@2TY:@0Xj>S0080XZ:R00h0X:2P09nO
W`2NWYh0WIfM09bLW02KVi/0VYZJ09VIV@2HV9P0UiNG09JFUP2DU9@0Ti>C09:BTP80TI6A00H0T92@
08n?S`2?Shl0SXj>08f=S@2<S8`208^;R`0308Z:RP29RHT0RHV90080R8R81P27QhL01028R8P0RHV9
08V9R@2:RXX208^;R`0508b<S02=SHd0Shn?092@T02ATI400P2BTY80102DU9@0UIFE09JFUP2GUiL2
09RHV00909ZJVP2KVi/0W9bL09fMW@2NWYh0WinO0:2PX02QXJ40XZ:R0080Xj>S00H0Y:BT0:FUY@2U
YJD0YZJV0:NWY`2XZ:P30:VYZ@030:ZZZP2[Zj/0Zj^[0080[:b/0P2][Jd00`2^[Zh0[jn_0;2`/00R
0?ooo`00803oool206a/K00406e]K@1^KVh0KVi^06i^KP80Kfm_0P1`L703075aL@03079bLP1cLg<0
Lg=c0080M7Ad0`1eMGD207IfMP80MgMg0P1hN7P407UiN@<0NWYj00<0Ng]k07YjNP1kNg/0201kNg/4
07YjNP0307]kN`1jNWX0NGUi0080NGUi0P1hN7P00`1gMgL0MWIf07IfMP0207EeM@0307AdM01cLg<0
LW9b0080LW9b0P1aLG400`1`L700Kfm_06m_K`0206i^KPL0KFe]0P1/K6`00`1[Jf/0K6a/06a/K002
06][J`0306a/K01[Jf/0Jf][0100Jf][0P1/K6`N0?ooo`L0UiNG2@2HV9P@09VIV@<0V9RH1@2GUiL3
09JFUP80UIFE1@2DU9@209>CT`80TY:B0`2ATI43092@T0H0Shn?00@0SXj>08n?S`2?Shl0SXj>202?
Shl5092@T0@0TI6A102BTY8409>CT`@0U9BD1@2EUID409JFUQh0oooo00<0/;2`0:n_[`2_[jl00P2_
[jl40:j^[P@0[Jf]0P2/[:`30:^[Z`@0ZZZZ0P2YZJT00`2XZ:P0YjNW0:NWY`020:JVYP<0YJFU0P2T
Y:@00`2SXj<0XZ:R0::RXP030:6QX@80X:2P0`2OWil209jNWP<0WIfM102LW9`209^KV`D0W9bL0P2M
WId409jNWP0409nOW`2PX:00X:2P0:6QX@80XZ:R0P2SXj<30:BTY080YJFU0P2VYZH00`2WYjL0Z:RX
0:RXZ0020:RXZ080ZJVY0P2ZZZX30:^[Z`<0[:b/0`2][Jd30:j^[P<0[jn_0P2`/;0R0?ooo`00803o
ool306a/K0D0KFe]101^KVh406m_K`80L71`1`1aLG46079bLPP0Lg=c00<0M7Ad07=cL`1cLg<02@1c
Lg<5079bLP<0LG5a0`1`L70506m_K`<0KVi^0`1]KFd<06a/K0P0Jf][00<0K6a/06][J`1[Jf/01@1[
Jf/00`1/K6`0Jf][06][J`0206][J`80K6a/7P3oool00`2FUYH0UiNG09NGU`0=09NGU`l0V9RH1`2G
UiL00`2FUYH0UiNG09JFUP0409JFUPL0UIFE0`2DU9@00`2CTi<0U9BD09>CT`0709>CT`80TY:B0P2C
Ti<00`2BTY80Ti>C09>CT`0;09>CT`X0U9BD202EUID709JFUQh0oooo0P2`/;080:n_[`D0[Zj^1`2]
[Jd50:b/[0@0Zj^[0`2ZZZX20:VYZ@H0Z:RX1@2WYjL70:JVYP80YJFU1P2VYZH60:NWY`<0Z:RX0`2Y
ZJT50:ZZZP@0Zj^[102/[:`70:f][@L0[Zj^102_[jl30;2`/280oooo003o0?oool<0oooo003o0?oo
ol<0oooo003o0?oool<0oooo003o0?oool<0oooo003o0?oool<0oooo001O0?ooo`900000R03oool2
@00008P0oooo0T00001=0?ooo`00H@3oool00d000000oooo0?ooo`270?ooo`03@000003oool0oooo
08L0oooo00=000000?ooo`3oool0BP3oool00440oooo1D0000020?ooo`03@000003oool0oooo0080
oooo00=000000?ooo`3oool01@3oool3@0000080oooo0T0000030?ooo`=000001@3oool00d000000
oooo0?ooo`1R0?ooo`=000000`3oool3@0000080oooo00=000000?ooo`3oool01@3oool3@0000080
oooo0T0000030?ooo`=000001@3oool00d000000oooo0?ooo`1R0?ooo`900000103oool00d000000
oooo0?ooo`020?ooo`03@000003oool0oooo00D0oooo0d0000020?ooo`9000000`3oool3@00000D0
oooo00=000000?ooo`3oool0A03oool004<0oooo00M000000?ooo`3oool0oooo@000003ooom00000
0080oooo00=000000?oood0000001@3oool01T000000oooo0?oood000000oooo@00000@0oooo00A0
00000?ooo`3ooom00000JP3oool00d000000oooo0?ooo`040?ooo`06@000003oool0oooo@000003o
oom000001@3oool01T000000oooo0?oood000000oooo@00000@0oooo00A000000?ooo`3ooom00000
K03oool01T000000oooo0?oood000000oooo@0000080oooo00=000000?oood0000001@3oool01T00
0000oooo0?oood000000oooo@00000@0oooo00A000000?ooo`3ooom00000C03oool004<0oooo00M0
00000?ooo`3oool0oooo@000003ooom000000080oooo00=000000?oood0000001@3oool01D000000
oooo0?oood000000oooo00=000000P3oool014000000oooo0?oood00001[0?ooo`04@000003oool0
oooo0?ooo`A0000000@0oooo@000003ooom000001@3oool01D000000oooo0?oood000000oooo00=0
00000P3oool014000000oooo0?oood00001[0?ooo`07@000003oool0oooo0?oood000000oooo@000
00020?ooo`03@000003ooom0000000D0oooo00E000000?ooo`3ooom000000?ooo`03@0000080oooo
00A000000?ooo`3ooom00000C03oool004<0oooo00=000000?ooo`3oool00P3oool01d000000oooo
0?ooo`3ooom000000?oood0000001P3oool3@00000040?oood0000100000@00000<0oooo0d00001[
0?ooo`07@000003oool0oooo0?oood000000oooo@00000020?ooo`03@000003ooom0000000H0oooo
0d000000103ooom00000@000040000030?ooo`=00000K03oool01T000000oooo0?oood000000oooo
@0000080oooo00=000000?oood0000001P3oool3@00000040?oood0000100000@00000<0oooo0d00
001<0?ooo`00@`3oool01d000000oooo0?ooo`3ooom000000?oood0000000P3oool00d000000oooo
@00000080?ooo`03@000003oool0oooo0780oooo00=000000?oood0000000`3oool2@0000080oooo
00=000000?oood000000203oool00d000000oooo0?ooo`1b0?ooo`03@000003ooom000000080oooo
00=000000?oood0000000P3oool00d000000oooo@00000080?ooo`03@000003oool0oooo05@0oooo
00120?ooo`900000103oool00d000000oooo0?ooo`020?ooo`03@000003oool0oooo00H0oooo0T00
001e0?ooo`03@000003oool0oooo00<0oooo00E000000?ooo`3oool0oooo@00000080?ooo`900000
M@3oool00d000000oooo0?ooo`020?ooo`03@000003oool0oooo0080oooo00=000000?ooo`3oool0
1P3oool2@00005H0oooo003o0?oool<0oooo003o0?oool<0oooo003o0?oool<0oooo003o0?oool<0
oooo003o0?oool<0oooo003o0?oool<0oooo003o0?oool<0oooo003o0?oool<0oooo003o0?oool<0
oooo003o0?oool<0oooo003o0?oool<0oooo003o0?oool<0oooo003o0?oool<0oooo003o0?oool<0
oooo003o0?oool<0oooo003o0?oool<0oooo003o0?oool<0oooo003o0?oool<0oooo000P0?ooo`<0
Ti>C1@2BTY800`2@T900Shn?08n?S`0408n?S`<0T92@00H0Shn?08b<S02@T900T92@08n?S`2@T903
096AT@@0TY:B00D0Ti>C09BDU02DU9@0UIFE09BDU00509FEU@X0UYJF0P2EUID209JFUPD0UIFE1`2F
UYH309NGU`80V9RH00<0U9BD09NGU`2GUiL0102GUiL509RHV00309VIV@2HV9P0V9RH00@0VIVI0`2H
V9P209NGU`H0UYJF00H0UIFE09BDU02GUiL0UYJF09FEU@2DU9@N0?ooo`0306UYJ@1XJ6P0J6QX00D0
J6QX00<0IfMW06IVIP1VIVH01`1VIVH0101UIFD0HV9R06IVIP1VIVH906EUI@L0IVIV0`1WIfL0101X
J6P0IfMW06QXJ01XJ6P806MWI`80J6QX00<0IfMW06QXJ01XJ6P02`1XJ6P306UYJ@0306IVIP1YJFT0
JFUY00@0JFUY2@1ZJVX206][J`L0JVYZ101[Jf/01`1/K6`0JVYZ06UYJ@1/K6`0Jf][06YZJP1YJFT0
7P3oool:04m?C`<0D51@1@1?Cdl00`1>CTh0CDe=04m?C`0204i>CP80CDe=101<C4`H04];B`80C4a<
00<0Bd];04a<C01<C4`00P1<C4`=04];B`l0C4a<1P1=CDd00`1>CTh0Cdm?04m?C`02051@D0<0DE5A
1@1@D5000`1?Cdl0oooo0?ooo`0P0?ooo`00803oool309>CT`0309:BTP2ATI40TI6A0080T92@00<0
SHf=08^;R`2:RXX0102;Rh/308b<S00308^;R`27QhL0Rh^;00<0S8b<00D0SHf=08j>SP2?Shl0T92@
096AT@0209:BTP0409>CT`2DU9@0UIFE09FEU@@0UYJF00<0UiNG09JFUP2GUiL02P2HV9P00`2GUiL0
V9RH09RHV00409NGU`@0V9RH102IVIT209ZJVP0509^KV`2LW9`0W9bL09JFUP2IVIT01@2KVi/409bL
W0@0WIfM102NWYh209fMW@0409bLW02KVi/0Vi^K09ZJVP<0VIVI0P2HV9P209NGU`0409VIV@2HV9P0
UiNG09FEUAh0oooo0`1XJ6P306MWI`80IVIV00<0IFEU06ATI01TI6@00P1TI6@506=SH`04069RHP1O
Gel0HV9R069RHPD0HF5Q101RHV8206=SH`D0I6AT0P1UIFD406IVIP0306MWI`1VIVH0IVIV00H0IVIV
0P1WIfL00`1VIVH0IfMW06IVIP0206IVIPL0IfMW0`1XJ6P206UYJ@0306IVIP1XJ6P0JFUY00<0JFUY
0`1ZJVX306][J`0306a/K01[Jf/0K6a/00P0K6a/0P1]KFd506i^KP80K6a/0P1]KFd00`1[Jf/0JVYZ
0?ooo`0M0?ooo`80Cdm?00<0CTi>04m?C`1?Cdl00`1?Cdl2051@D080DE5A00@0D51@04m?C`1?Cdl0
Cdm?0P1>CTh204e=C@0504m?C`1=CDd0C4a<04a<C01:BTX00P19BDT204Q8B0<0AdM71`16ATH00`17
AdL0B4Q804Q8B00:04M7A``0B4Q81`17AdL01P16ATH0B4Q804Q8B018B4P0BDU904Q8B0H0BDU90P1:
BTX00`19BDT0BTY:04Y:BP0304Y:BP80Bd];00@0C4a<04e=C@1>CTh0Cdm?0P1ADE401@1BDU80De=C
05=CD`1ADE40D51@0080DE5A00<0D51@04m?C`3oool08@3oool00200oooo0P2CTi<0202BTY80TI6A
096AT@2@T900Shn?08j>SP2;Rh/0RHV91@27QhL408R8R00308B4Q025QHD0RHV90080R8R800X0RXZ:
08^;R`2<S8`0SXj>08n?S`2ATI40TY:B09>CT`2DU9@0UIFE1@2GUiL309RHV00309VIV@2JVYX0VYZJ
00T0VYZJ1@2IVIT309ZJVP80Vi^K0`2LW9`00`2MWId0WYjN09jNWP0209nOW`0309^KV`2IVIT0W9bL
00D0WinO00<0X:2P0:6QX@2QXJ401@2RXZ820:>SX`80XZ:R00L0XJ6Q0:2PX02OWil0WinO09jNWP2M
WId0W9bL00<0Vi^K0P2HV9P209ZJVP0309RHV02EUID0oooo01d0oooo0P1XJ6P206MWI`80IVIV0P1U
IFD206=SH`04069RHP1QHF40HF5Q065QH@@0H61P00D0GemO05eMG@1MGEd0GemO05iNGP0305eMG@<0
GUiN0`1OGel00`1PH600HF5Q069RHP02069RHP80Hf=S0`1TI6@;06EUI@@0IVIV0`1UIFD506IVIP<0
IfMW101XJ6P00`1WIfL0J6QX06QXJ00206UYJ@0406YZJP1[Jf/0Jf][06][J`80K6a/1@1]KFd706i^
KP0706m_K`1`L700L71`071`L01aLG40L71`06m_K`0206i^KP0406m_K`1^KVh0K6a/06YZJQh0oooo
201?Cdl2051@D0<0DE5A00@0D51@04m?C`1?Cdl0CTi>0P1=CDd01@1>CTh0CDe=04];B`1;Bd/0BTY:
0080AdM700<0ATI604E5A@14A4@00P13@d<20492@P80@D510`12@T8204=3@`H0A4A41@13@d<204A4
A0D0ADE52@14A4@404=3@`040492@P15ADD0B4Q804I6AP<0ADE500<0AdM704I6AP16ATH00`16ATH5
04M7A`0:04Q8B019BDT0BDU904U9B@1:BTX0C4a<04e=C@1?Cdl0DE5A059BDP80De=C101BDU82055A
D@03051@D03oool0oooo0200oooo000P0?ooo`0=09>CT`2BTY80TI6A092@T02?Shl0SXj>08f=S@2<
S8`0RHV908N7Q`25QHD0Ph>308:2PP0307moO`@0P82000l0OWin07emO@1oOgl0P82008:2PP25QHD0
QhN708V9R@2;Rh/0T92@096AT@2CTi<0U9BD09JFUP2HV9P00`2JVYX00`2KVi/0VYZJ09ZJVP0309ZJ
VP0309^KV`2LW9`0W9bL00D0WIfM102NWYh00`2OWil0WYjN09jNWP0209nOW`80X:2P0P2QXJ420::R
XP030:>SX`2TY:@0Y:BT0080YJFU0P2VYZH00`2TY:@0XZ:R0:FUY@030:NWY`030:RXZ02YZJT0ZZZZ
0080Zj^[102/[:`01P2][Jd0[:b/0:b/[02[Zj/0ZZZZ0:VYZ@80Z:RX00@0YZJV0:BTY02RXZ80XJ6Q
0P2OWil209fMW@0309^KV`2HV9P0UYJF01h0oooo0P1XJ6P206IVIP0:06EUI@1TI6@0Hf=S06=SH`1Q
HF40H61P05mOG`1NGUh0GEeM05aLG0<0Fe]K0P1JFUX01@1IFET0EeMG05IFEP1GEeL0EUIF0080EEEE
0P1FEUH0201GEeL0F5QH05QHF01IFET0FUYJ05]KF`1LG5`0GUiN0P1OGel2065QH@<0HV9R0`1SHf<0
0`1RHV80Hf=S06=SH`0306=SH`80I6AT0P1SHf<0101TI6@0Hf=S06=SH`1SHf<306ATI0<0IFEU0P1V
IVH406MWI`0506QXJ01YJFT0J6QX06MWI`1ZJVX00P1[Jf/206a/K080KFe]0`1_Kfl2071`L003075a
L@1bLW80LW9b00<0LW9b00<0Lg=c07AdM01fMWH00P1fMWH207AdM007079bLP1cLg<0LG5a079bLP1a
LG40KVi^06][J`0N0?ooo`<0Cdm?1P1>CTh204m?C`80D51@00<0DE5A051@D01?Cdl00P1>CTh204a<
C00:04];B`1:BTX0BDU904M7A`13@d<0@D510410@00n?Sh0?Cdm03Xj>PL0>CTi00<0>c/k03`l?00m
?Cd00P0o?cl01010@400?clo03lo?`0n?Sh803dm?@l0?3`l00T0>c/k03`l?00l?3`0?3`l03dm?@0n
?Sh0?clo0410@00o?cl01@10@4040451@@80@T9200T0@d=304A4A014A4@0ADE504I6AP1:BTX0C4a<
04i>CP1ADE40101BDU8205=CD`80E5AD00<0DU9B055AD@3oool08@3oool00200oooo00h0Ti>C09:B
TP2@T900Shn?08j>SP2=SHd0S8b<08^;R`28R8P0QXJ608F5Q@23Ph<0PH6107emO@@0O7al0P1mOGd0
401lO7`0NGUi07YjNP1lO7`0Ogmo0861P@24Q8@0QhN708V9R@2>SXh0TI6A09>CT`2EUID0UiNG09VI
V@2KVi/209bLW00309fMW@2LW9`0W9bL00@0Vi^K0`2MWId209jNWP<0WinO0`2PX:030:6QX@80XZ:R
0P2SXj<20:BTY080YJFU0P2WYjL0102XZ:P0ZJVY0:VYZ@2YZJT20:ZZZP050:RXZ02WYjL0ZZZZ0:^[
Z`2/[:`00P2][Jd00`2^[Zh0/;2`0;2`/0040;6a/@040;:b/P2a/K40/K6a0;2`/080[jn_00P0[Zj^
0:f][@2[Zj/0ZJVY0:NWY`2UYJD0Xj>S0::RXP80WinO00<0W9bL09VIV@2FUYH07P3oool01P1XJ6P0
IfMW06IVIP1UIFD0I6AT06=SH`80HV9R00L0H61P05mOG`1NGUh0GEeM05aLG01JFUX0FEUI00<0F5QH
00<0EeMG05IFEP1EEED00P1CDe<03`1BDU80DE5A055AD@1ADE40DU9B05=CD`1DE5@0EEEE05IFEP1G
EeL0F5QH05YJFP1LG5`0GEeM05iNGP02061PH0L0HF5Q3P1RHV8206=SH`<0I6AT00@0IFEU06IVIP1V
IVH0IVIV0P1WIfL01P1XJ6P0JFUY06UYJ@1YJFT0JVYZ06][J`<0K6a/00<0KFe]06i^KP1`L7000P1`
L702075aL@04079bLP1cLg<0Lg=c07=cL`80M7Ad00H0MWIf07MgM`1iNGT0NGUi07MgM`1fMWH307Ee
M@0507=cL`1dM7@0LG5a06i^KP1[Jf/07P3oool204m?C`D0CTi>0`1=CDd00`1>CTh0Cdm?04m?C`02
051@D00504m?C`1>CTh0CDe=04a<C01:BTX00P19BDT02P18B4P0ADE50451@@0o?cl0?Cdm03Xj>P0i
>CT0=SHf03De=@0d=3@303<c<`0503De=@0f=SH0=cLg03Ph>00i>CT00P0l?3`303dm?@@0>c/k100j
>SX303Ti>@0303Ph>00g=cL0=cLg00`0=cLg0P0h>3P203Ti>@0303/k>`0m?Cd0?3`l00D0?3`l0P0m
?Cd303hn?P0903lo?`10@400@D510492@P13@d<0A4A404M7A`1:BTX0CDe=0080Cdm?0P1@D5001`1A
DE40De=C05=CD`1EEED0E5AD059BDP1ADE408P3oool00200oooo0140Ti>C09:BTP2?Shl0SXj>08f=
S@2<S8`0Rh^;08Z:RP27QhL0QXJ608B4Q022PX80P82007alO01jNWX0NGUi07QhN00407UiN@0B07Qh
N01gMgL0N7Qh07alO01nOWh0PH6108B4Q027QhL0SXj>092@T02CTi<0UIFE09RHV02JVYX0W9bL09fM
W@2NWYh0WinO0P2NWYh01`2MWId0W9bL09bLW02KVi/0W9bL09fMW@2NWYh00P2OWil0102PX:00XJ6Q
0:6QX@2QXJ420::RXP80Xj>S0P2TY:@0102UYJD0YZJV0:NWY`2WYjL20:RXZ0040:VYZ@2ZZZX0Zj^[
0:^[Z`80[:b/00H0[Jf]0:j^[P2^[Zh0[jn_0:f][@2/[:`20;2`/0030;6a/@2b/[80/k>c0080]KFe
0`2f][H30;Ng]`0<0;Jf]P2e]KD0]KFe0;Bd]02c/k<0/[:b0;2`/02^[Zh0ZZZZ0:RXZ02VYZH0Y:BT
0P2RXZ800`2LW9`0VIVI09JFUP0N0?ooo`0306QXJ01WIfL0IFEU0080I6AT0P1RHV802@1PH600GUiN
05eMG@1MGEd0Fe]K05YJFP1HF5P0EeMG05IFEP0205EEE@0605ADE01CDe<0DU9B051@D01?Cdl0CTi>
0`1=CDd204i>CP09051@D01ADE40De=C05ADE01FEUH0EeMG05YJFP1LG5`0GEeM0080GemO201PH60=
065QH@80HV9R0P1SHf<206ATI080IFEU00@0IVIV06MWI`1WIfL0J6QX0P1YJFT206YZJP0706][J`1/
K6`0K6a/06e]K@1^KVh0Kfm_071`L002075aL@04079bLP1cLg<0Lg=c07AdM0<0MGEe00H0MWIf07Qh
N01jNWX0O7al07]kN`1iNGT207QhN080MgMg00D0MGEe07IfMP1bLW80Kfm_06][J`0N0?ooo`80Cdm?
0`1>CTh304e=C@0304a<C01=CDd0CDe=0080CDe=101>CTh03P1=CDd0Bd];04Y:BP18B4P0AdM704E5
A@13@d<0?Cdm03/k>`0i>CT0=cLg03@d=00a<C40<30`0P0_;bl02@0^;Rh0;bl_034a<@0b<S80<c<c
03De=@0f=SH0>3Ph03Ti>@0303Xj>P<0>CTi0P0h>3P00`0g=cL0=SHf03Hf=P0203Hf=P0303De=@0d
=3@0<c<c00@0<c<c00<0<S8b03<c<`0c<c<01P0c<c<203@d=080=CDe00@0=SHf03Ph>00i>CT0>3Ph
0`0g=cL00`0h>3P0>CTi03Ti>@0203Xj>P0903/k>`0l?3`0?Cdm03hn?P0o?cl0@4100492@P16ATH0
BDU90080CDe=00X0CTi>051@D01ADE40DU9B05=CD`1DE5@0EUIF05ADE01BDU80DE5A8P3oool00200
oooo0140Ti>C09:BTP2?Shl0SXj>08f=S@2;Rh/0RXZ:08V9R@26QXH0QHF508>3P`22PX80P82007al
O01jNWX0N7Qh07MgM`0507IfMP0D07EeM@1dM7@0NWYj07alO01nOWh0PX:208F5Q@2<S8`0T92@09:B
TP2EUID0V9RH09ZJVP2MWId0WYjN09nOW`2PX:00XJ6Q0:2PX02OWil209jNWP80WIfM0P2NWYh209nO
W`040:2PX02QXJ40XZ:R0::RXP80Xj>S0P2UYJD0102VYZH0YjNW0:NWY`2XZ:P20:ZZZP060:^[Z`2/
[:`0[:b/0:f][@2^[Zh0[jn_0P2`/;020;6a/@030;:b/P2c/k<0];Bd0080/k>c00D0];Bd0;Jf]P2g
]kL0^;Rh0;Zj^P030;^k^`@0_;bl0P2k^k/02P2j^[X0]kNg0;Ng]`2f][H0/k>c0;:b/P2][Jd0Zj^[
0:RXZ02VYZH20:BTY00309fMW@2JVYX0UiNG01h0oooo00D0J6QX06MWI`1UIFD0I6AT06=SH`02065Q
H@0C05mOG`1MGEd0G5aL05]KF`1JFUX0FEUI05IFEP1EEED0E5AD05=CD`1BDU80DE5A051@D01?Cdl0
CDe=04];B`1:BTX0BDU904Q8B00204U9B@0<04Y:BP1=CDd0CTi>04m?C`1ADE40De=C05EEE@1IFET0
FUYJ05aLG01MGEd0GUiN201OGel=061PH004065QH@1RHV80HV9R069RHP80Hf=S00H0I6AT06EUI@1V
IVH0IVIV06MWI`1XJ6P206UYJ@0306YZJP1[Jf/0Jf][0080K6a/00@0KFe]06i^KP1_Kfl0LG5a0P1b
LW800`1cLg<0M7Ad07EeM@0207IfMP0407MgM`1hN7P0NGUi07alO080OWin00<0O7al07]kN`1kNg/0
0P1jNWX01P1iNGT0N7Qh07QhN01bLW80Kfm_06a/K1h0oooo0P1?Cdl0101>CTh0CDe=04e=C@1=CDd2
04a<C0P0Bd];00l0C4a<04];B`19BDT0B4Q804I6AP14A4@0@T920410@00j>SX0=cLg03De=@0b<S80
<30`02`/;00[:b/00P0Z:RX0200[:b/0;2`/02h^;P0_;bl0<30`034a<@0b<S80=CDe0P0f=SH403Lg
=`@0=SHf0P0d=3@00`0c<c<0<S8b038b<P02030`<0@0;bl_1@0^;Rh402l_;`04030`<00a<C40<C4a
034a<@80<S8b1@0c<c<01@0d=3@0=CDe03De=@0f=SH0=cLg0080>3Ph00L0>SXj03/k>`0l?3`0?Shn
0451@@17AdL0Bd];0080C4a<00X0CDe=055AD@1BDU80De=C05ADE01EEED0EUIF05ADE01BDU80DE5A
8P3oool00200oooo0180TY:B096AT@2?Shl0SXj>08b<S02;Rh/0RXZ:08R8R025QHD0Q8B408:2PP21
PH40Ogmo07alO01jNWX0N7Qh07MgM`1eMGD207AdM0<0Lg=c01<0LW9b07AdM01hN7P0O7al07moO`23
Ph<0S8b<08n?S`2BTY80UIFE09RHV02KVi/0WYjN09nOW`2PX:00XZ:R0:>SX`2RXZ80XJ6Q0080X:2P
00<0WinO09fMW@2NWYh00`2OWil01P2PX:00XJ6Q0:6QX@2RXZ80Xj>S0:BTY080YZJV00D0YjNW0:RX
Z02YZJT0ZZZZ0:b/[0020:f][@040:j^[P2_[jl0/;2`0;6a/@80/[:b00D0/k>c0;Bd]02e]KD0]KFe
0;Jf]P020;Rh^0060;Ng]`2h^;P0^[Zj0;bl_02m_Kd0_kno0`30`<040<71`@80`<3000l0_[jn0;Zj
^P2j^[X0^KVi0;Jf]P2c/k<0[jn_0:f][@2ZZZX0YjNW0:JVYP2TY:@0WYjN09ZJVP2GUiL07P3oool0
601XJ6P0IfMW06EUI@1SHf<0HV9R065QH@1PH600GUiN05aLG01KFe/0FUYJ05QHF01GEeL0EEEE05=C
D`1BDU80DE5A051@D01>CTh0CDe=04a<C01:BTX0B4Q804I6AP<0A4A400d0ADE504I6AP19BDT0Bd];
04a<C01?Cdl0DE5A05=CD`1HF5P0FEUI05YJFP1LG5`0GEeM00<0GemO1@1NGUh705mOG`0305iNGP1O
Gel0GUiN00<0GemO00<0H61P065QH@1QHF400P1RHV80101SHf<0I6AT06EUI@1VIVH206MWI`0406QX
J01YJFT0JFUY06YZJP80Jf][0P1/K6`0101]KFd0KVi^071`L01bLW8207=cL`0907AdM01eMGD0MWIf
07MgM`1hN7P0NGUi07]kN`1mOGd0Ogmo0080P82000D0Ogmo07inOP1nOWh0OGem07alO00307YjNP03
07=cL`1`L700K6a/01h0oooo0P1?Cdl0101>CTh0CDe=04e=C@1<C4`304];B`<0BTY:1P19BDT03P17
AdL0ATI604A4A012@T80@41003hn?P0i>CT0=3@d030`<00^;Rh0:b/[02PX:00W9bL09RHV0P0W9bL0
2@0X:2P0:b/[02`/;00];Bd0;Rh^02l_;`0a<C40<S8b03<c<`0203@d=0@0=CDe0P0d=3@203<c<`04
038b<P0a<C40<30`02h^;P80;Bd]0`0/;2`602/[:`80;2`/0P0];Bd602h^;P80<30`0P0_;bl01@0`
<300<C4a038b<P0b<S80<c<c0080=3@d00`0=cLg03Ph>00j>SX0?Shn0492@P1:BTX0Bd];04e=C@1>
CTh0D51@05=CD`1EEED205IFEP80EeMG00<0E5AD05=CD`1ADE408P3oool00200oooo01<0TY:B096A
T@2>SXh0SHf=08b<S02:RXX0R8R808N7Q`24Q8@0PX:20861P@1oOgl0OWin07]kN`1iNGT0MgMg07If
MP1eMGD0Lg=c0080LW9b00l0LG5a071`L01`L700Kfm_071`L01dM7@0Ng]k0820P02;Rh/0T92@09BD
U02GUiL0Vi^K09fMW@2SXj<00P2TY:@0202UYJD0YZJV0:JVYP2UYJD0Y:BT0:>SX`2RXZ80XJ6Q0P2P
X:020:6QX@80XZ:R0`2SXj<03`2TY:@0YZJV0:JVYP2WYjL0Z:RX0:VYZ@2ZZZX0[Jf]0:j^[P2_[jl0
/K6a0;:b/P2d];@0]KFe0;Jf]P020;Ng]`040;Vi^@2j^[X0^k^k0;bl_080_Kfm0P2o_kl20<30`005
0;no_`34a<@0a/K60<S8b039bLT00P3:b/X20<S8b00A0<O7a`36a/H0aLG50<30`02o_kl0^k^k0;Zj
^P2h^;P0/k>c0;6a/@2][Jd0ZZZZ0:RXZ02VYZH0WinO09^KV`2GUiL07P3oool06@1WIfL0IVIV06=S
H`1RHV80HF5Q05mOG`1NGUh0G5aL05YJFP1HF5P0EeMG05EEE@1DE5@0DE5A051@D01>CTh0CDe=04];
B`18B4P0ATI604E5A@13@d<0@D5103lo?`0k>c/00P0i>CT203`l?00;0451@@14A4@0AdM704U9B@1=
CDd0Cdm?05EEE@1GEeL0F5QH05YJFP1KFe/01@1MGEd405aLG0D0GEeM0P1LG5`305eMG@<0GUiN0P1P
H6001@1QHF40HV9R069RHP1TI6@0IFEU0080IVIV00@0IfMW06QXJ01YJFT0JFUY0P1[Jf/00`1/K6`0
KFe]06i^KP0206m_K`0>071`L01cLg<0M7Ad07EeM@1fMWH0MgMg07UiN@1mOGd0P82008:2PP24Q8@0
QHF508J6QP27QhL208F5Q@80Q8B400P0Ph>30820P01oOgl0OWin07alO01dM7@0LG5a06e]KAh0oooo
0P1>CTh00`1=CDd0C4a<04];B`0304Y:BP0704U9B@18B4P0B4Q804M7A`16ATH0ADE504A4A00204=3
@`0=0492@P0o?cl0?Shn03`l?00i>CT0=cLg03De=@0_;bl0;2`/02PX:00T92@0820P01dM7@0201`L
700;01dM7@0N7Qh07alO028R8P0T92@09RHV02LW9`0Y:BT0:b/[02`/;00];Bd00P0^;Rh00`0_;bl0
<30`030`<002030`<00302l_;`0^;Rh0;Rh^0080;Bd]00<0;2`/02/[:`0[:b/00P0Z:RX202TY:@<0
:2PX0`0W9bL602PX:0<0:BTY0P0Z:RX202/[:`0302d];@0_;bl0;Rh^00<0;Bd]00T0;Rh^030`<00i
>CT0?Cdm0451@@15ADD0B4Q804e=C@1ADE400P1BDU802P1DE5@0EeMG05UIF@1IFET0FUYJ05]KF`1I
FET0EEEE05=CD`1ADE4R0?ooo`00803oool0502BTY80TI6A08j>SP2<S8`0Rh^;08V9R@28R8P0QXJ6
08>3P`22PX80P82007moO`1mOGd0NWYj07UiN@1gMgL0MWIf07AdM01bLW80LG5a0P1`L70206m_K`0=
06i^KP1]KFd0L71`07IfMP1mOGd0RXZ:096AT@2FUYH0VYZJ09fMW@2PX:00YJFU0:JVYP040:NWY`80
YZJV00D0YJFU0:BTY02RXZ80XZ:R0:6QX@020::RXP80Xj>S0P2TY:@20:FUY@0A0:NWY`2XZ:P0ZJVY
0:ZZZP2[Zj/0[:b/0:n_[`2`/;00/[:b0;>c/`2d];@0]kNg0;Rh^02i^KT0^[Zj0;^k^`2m_Kd00P2n
_[h01P2o_kl0`<300<71`@32`/80`l?30<C4a080aLG50P37alL01038b<P0bLW90<_;b`3;bl/30<W9
b@80b<S800h0`l?30<;2`P2m_Kd0_;bl0;Zj^P2e]KD0/[:b0:j^[P2/[:`0Z:RX0:FUY@2OWil0Vi^K
09NGUah0oooo02P0IfMW06IVIP1SHf<0HF5Q061PH01OGel0GEeM05aLG01IFET0EeMG05IFEP1DE5@0
DU9B04m?C`1>CTh0C4a<04Y:BP19BDT0ADE504=3@`11@D40?clo03hn?P0k>c/0=cLg03@d=00e=CD0
=SHf03Ph>00l?3`0@41004A4A017AdL0Bd];04e=C@1DE5@0EUIF05QHF01IFET0Fe]K1@1LG5`405]K
F`@0G5aL0`1KFe/305aLG0<0GEeM0P1OGel0101PH600HF5Q069RHP1SHf<206EUI@0306IVIP1WIfL0
J6QX0080JFUY0P1[Jf/04@1/K6`0KVi^06m_K`1_Kfl0L71`079bLP1dM7@0MGEe07MgM`1hN7P0NWYj
07emO@21PH40Q8B408J6QP27QhL0RHV90080RXZ:00`0QhN708R8R027QhL0QhN708F5Q@23Ph<0PX:2
07moO`1mOGd0MGEe075aL@1]KFdN0?ooo`0504m?C`1>CTh0C4a<04a<C01;Bd/00P1:BTX08`19BDT0
B4Q804M7A`16ATH0ADE504A4A013@d<0@T920451@@10@400?clo03`l?00j>SX0>3Ph03Hf=P0c<c<0
<C4a02/[:`0X:2P09RHV024Q8@0M7Ad05aLG01DE5@0F5QH05aLG01PH600J6QX07QhN020P800R8R80
92@T02HV9P0Y:BT0:RXZ0080:b/[0P0/;2`402d];@80;2`/00D0:b/[02XZ:P0Z:RX0:BTY02PX:002
02LW9`<09RHV00<09BDU02@T900T92@01`0T92@302DU9@<09RHV01H09bLW02PX:00X:2P0:BTY02XZ
:P0/;2`0;Rh^030`<00_;bl0<C4a03Hf=P0n?Sh0@T9204I6AP18B4P0BTY:051@D01CDe<0DU9B05AD
E01FEUH0FUYJ0P1KFe/01P1MGEd0G5aL05]KF`1FEUH0E5AD059BDR80oooo000P0?ooo`0E09:BTP2A
TI40SXj>08b<S02;Rh/0RHV908N7Q`26QXH0Ph>30861P@20P800OWin07emO@1iNGT0N7Qh07IfMP1e
MGD0M7Ad075aL@1`L700Kfm_0080KVi^00h0KFe]06a/K01[Jf/0KVi^075aL@1hN7P0QXJ6096AT@2I
VIT0WIfM0:2PX02SXj<0YjNW0:RXZ0@0ZJVY00D0Z:RX0:NWY`2VYZH0YJFU0:BTY0040:>SX`040:BT
Y02UYJD0YJFU0:FUY@80YZJV0140Z:RX0:VYZ@2ZZZX0[:b/0:f][@2^[Zh0/K6a0;:b/P2d];@0]KFe
0;Ng]`2j^[X0^k^k0;bl_02m_Kd0_[jn0<30`0020<71`@090<?3``34a<@0aLG50<K6aP37alL0b<S8
0<W9b@3:b/X0c<c<0080cLg=0`3;bl/30<[:bP0@0<W9b@38b<P0aLG50<?3``2n_[h0_Kfm0;^k^`2f
][H0/k>c0;2`/02][Jd0ZJVY0:JVYP2OWil0Vi^K09NGUah0oooo01T0IfMW06IVIP1RHV80HF5Q061P
H01NGUh0G5aL05]KF`1GEeL0EUIF05ADE01BDU80DE5A04e=C@1;Bd/0BTY:04Q8B016ATH0@T920410
@00n?Sh0?3`l03Xj>P0h>3P0<c<c0080<C4a00d0<30`038b<P0g=cL0?3`l0451@@15ADD0BDU904a<
C01BDU80EEEE05MGE`1IFET0FUYJ00@0G5aL0P1KFe/305YJFP80Fe]K1P1JFUX205]KF`<0G5aL0P1N
GUh01P1OGel0H61P065QH@1SHf<0I6AT06EUI@80IVIV01H0J6QX06UYJ@1YJFT0JVYZ06][J`1/K6`0
KVi^06m_K`1`L700LG5a079bLP1eMGD0MgMg07UiN@1kNg/0Ogmo08:2PP26QXH0R8R808Z:RP2;Rh/0
S8b<0P2=SHd0302:RXX0Rh^;08^;R`2:RXX0QhN708F5Q@24Q8@0PH6107emO@1eMGD0LG5a06e]KAh0
oooo0P1>CTh00`1<C4`0Bd];04Y:BP0204U9B@0G04Q8B016ATH0ADE504E5A@14A4@0@d=30451@@10
@400?Shn03dm?@0l?3`0>3Ph03Hf=P0d=3@0<S8b030`<00^;Rh0:2PX02DU9@0R8R807alO01XJ6P0B
4Q800P0?3`l02@0A4A404a<C01DE5@0J6QX07AdM01lO7`0Q8B4092@T02LW9`0202PX:080:BTY0P0Z
:RX302/[:`0402XZ:P0Y:BT0:2PX02PX:0809bLW0P0U9BD0100T92@08b<S028R8P0R8R83024Q8@<0
820P100Q8B45028R8P0F02<S8`0T92@092@T02DU9@0V9RH09bLW02TY:@0Z:RX0;Bd]038b<P0h>3P0
?3`l04A4A017AdL0BTY:04e=C@1@D500E5AD05EEE@1FEUH0F5QH05YJFP80GEeM0P1NGUh01@1MGEd0
G5aL05MGE`1EEED0DU9B0280oooo000P0?ooo`0E09:BTP2ATI40SHf=08b<S02;Rh/0RHV908N7Q`25
QHD0PX:20861P@1oOgl0OGem07alO01iNGT0MgMg07IfMP1dM7@0Lg=c075aL@1_Kfl0KVi^0080KFe]
00d0K6a/06YZJP1YJFT0Jf][06e]K@1bLW80PX:208b<S02GUiL0X:2P0:>SX`2VYZH0ZZZZ00@0Zj^[
00H0ZZZZ0:VYZ@2XZ:P0YjNW0:JVYP2UYJD50:BTY080YZJV0P2WYjL04P2XZ:P0ZJVY0:ZZZP2[Zj/0
[Jf]0:j^[P2`/;00/[:b0;Bd]02f][H0]kNg0;Vi^@2l_;`0_[jn0;no_`30`<00`L710<?3``80a<C4
00@0a/K60<O7a`38b<P0b/[:0P3;bl/00`3<c<`0cLg=0<k>cP020<k>cP030<g=c@3<c<`0bl_;0080
bl_;0P3:b/X03`39bLT0a/K60<?3``30`<00_[jn0;bl_02f][H0];Bd0;6a/@2^[Zh0ZZZZ0:JVYP2O
Wil0Vi^K09NGU`0N0?ooo`0K06MWI`1UIFD0HV9R061PH01OGel0GEeM05aLG01JFUX0EUIF05EEE@1C
De<0DE5A04m?C`1;Bd/0BDU904M7A`16ATH0A4A40410@00m?Cd0>c/k03Ti>@0g=cL0=CDe030`<00^
;Rh0;Bd]0080;2`/00/0<S8b03Lg=`0m?Cd0@d=304M7A`1;Bd/0DU9B05EEE@1GEeL0F5QH05YJFP05
05]KF`<0FUYJ2P1IFET205YJFP80Fe]K00L0G5aL05eMG@1NGUh0GemO061PH01RHV80I6AT0080IFEU
01H0IVIV06QXJ01YJFT0JFUY06YZJP1[Jf/0KFe]06i^KP1`L700LG5a079bLP1dM7@0MgMg07YjNP1m
OGd0PH6108>3P`26QXH0RXZ:08b<S02=SHd0Shn?0P2@T9003@2?Shl0SXj>08j>SP2>SXh0S8b<08V9
R@28R8P0QXJ608:2PP1nOWh0MWIf075aL@1]KFd07P3oool07`1>CTh0CDe=04];B`1;Bd/0BTY:04U9
B@18B4P0AdM704E5A@14A4@0@d=30492@P11@D40?clo03dm?@0l?3`0>SXj03Ti>@0e=CD0<c<c034a
<@0_;bl0;Bd]02XZ:P0T92@08R8R01lO7`0L71`05aLG00l?3`0=3@d00P0:2PX0200=3@d0410@01HF
5P0I6AT071`L01lO7`0Q8B4092@T0P0V9RH202LW9`D0:2PX00@09bLW02HV9P0U9BD09BDU0P0T92@2
028R8P04024Q8@0P82007alO01lO7`807QhN200M7Ad00`0N7Qh07alO01lO7`0201lO7`0F020P800Q
8B408R8R02<S8`0T92@09BDU02XZ:P0^;Rh0=3@d03Ti>@0n?Sh0@T9204Q8B01;Bd/0Cdm?055AD@1D
E5@0EeMG05QHF01IFET0G5aL05iNGP@0H61P00D0GUiN05aLG01GEeL0E5AD059BDP0R0?ooo`00803o
ool06P2BTY80TI6A08f=S@2<S8`0RXZ:08R8R027QhL0QHF50861P@20P800OWin07emO@1kNg/0N7Qh
07MgM`1eMGD0M7Ad079bLP1`L700KVi^06e]K@1/K6`0Jf][06YZJP1YJFT0J6QX0P1ZJVX0201^KVh0
OWin08N7Q`2ATI40WinO0:RXZ02ZZZX0[Jf]0P2^[Zh20:f][@060:b/[02ZZZX0ZJVY0:RXZ02WYjL0
YZJV0`2UYJD00`2TY:@0YJFU0:JVYP020:NWY`0J0:RXZ02YZJT0ZZZZ0:^[Z`2/[:`0[Zj^0;2`/02a
/K40];Bd0;Jf]P2h^;P0^KVi0;^k^`2o_kl0`L710<;2`P33`l<0a<C40<K6aP37alL0b<S80<W9b@3:
b/X0bl_;0<g=c@3>c/h20<o?c`<0d=3@00@0clo?0<k>cP3>c/h0cLg=0`3;bl/20<[:bP0>0<O7a`34
a<@0`L710;jn_P2k^k/0][Jf0;Bd]02a/K40[Zj^0:ZZZP2VYZH0WinO09^KV`2GUiLN0?ooo`0K06MW
I`1UIFD0HV9R061PH01NGUh0G5aL05]KF`1IFET0EEEE05=CD`1ADE40Cdm?04e=C@19BDT0AdM704E5
A@13@d<0@T9203dm?@0k>c/0>3Ph03Hf=P0d=3@0<S8b02d];@0Z:RX0:BTY00809bLW00/0;Rh^038b
<P0h>3P0@41004I6AP1;Bd/0DU9B05EEE@1GEeL0F5QH05YJFP0305]KF`80FUYJ0`1IFET;05QHF005
05UIF@1JFUX0FUYJ05aLG01MGEd00P1NGUh0201OGel0HV9R06=SH`1TI6@0IFEU06IVIP1XJ6P0JFUY
0P1ZJVX04@1/K6`0KFe]06m_K`1aLG40LW9b07AdM01fMWH0Ng]k0820P023Ph<0QHF508R8R02:RXX0
SHf=08n?S`2ATI40TY:B0080Ti>C0`2BTY802P2ATI40SHf=08b<S02:RXX0QhN708:2PP1nOWh0MWIf
079bLP1]KFdN0?ooo`0Z04i>CP1=CDd0Bd];04Y:BP19BDT0B4Q804M7A`16ATH0A4A404=3@`12@T80
@41003lo?`0l?3`0>c/k03Ti>@0h>3P0=SHf038b<P0`<300;Rh^02`/;00Z:RX09bLW024Q8@0N7Qh0
6a/K01LG5`0C4a<03@d=00/;2`092@T01PH600L71`0;2`/04a<C01LG5`0J6QX07AdM01lO7`0S8b<0
92@T0`0U9BD402HV9P809BDU00<092@T02<S8`0R8R800P0Q8B40100P82007alO01hN7P0M7Ad201`L
700301/K6`0J6QX06QXJ00@06ATI0`0J6QX201/K6`8071`L0P0M7Ad05@0N7Qh0820P024Q8@0S8b<0
9RHV02h^;P0e=CD0>SXj03hn?P12@T80AdM704i>CP1ADE40De=C05EEE@1GEeL0FUYJ05aLG01OGel0
HF5Q06=SH`02069RHP0706=SH`1QHF40GemO05aLG01GEeL0EEEE059BDP0R0?ooo`00803oool0602B
TY80T92@08b<S02;Rh/0RHV908N7Q`26QXH0Q8B40861P@1oOgl0OGem07]kN`1jNWX0MWIf07EeM@1c
Lg<0LG5a071`L01]KFd0K6a/06][J`1ZJVX0JFUY06MWI`<0IFEU00P0IVIV06QXJ01fMWH0OWin08N7
Q`2BTY80WinO0:b/[0<0];Bd00L0/[:b0;2`/02^[Zh0[:b/0:^[Z`2ZZZX0Z:RX00<0YZJV0P2UYJD2
0:JVYP0E0:NWY`2XZ:P0ZZZZ0:ZZZP2/[:`0[Jf]0:j^[P2`/;00/K6a0;>c/`2g]kL0^[Zj0;bl_02m
_Kd0_kno0<C4a036a/H0alO70<W9b@3:b/X0c<c<00<0c/k>00<0clo?0=3@d03Bd]801P3De=@01`3B
d]80d=3@0=3@d03?cll0c/k>0<g=c@3;bl/00P3:b/X03P37alL0aLG50<?3``30`<00_[jn0;Ng]`2d
];@0/K6a0:j^[P2ZZZX0YjNW09nOW`2KVi/0UiNG7P3oool09`1WIfL0IFEU065QH@1OGel0GEeM05]K
F`1IFET0EeMG05=CD`1ADE40CTi>04a<C01:BTX0ATI604A4A012@T80?clo03dm?@0h>3P0=SHf03<c
<`0a<C40;Rh^02/[:`0V9RH092@T028R8P0P82007alO02HV9P0[:b/0<C4a03Ph>010@400BDU905=C
D`1FEUH0F5QH05UIF@0205]KF`<0FUYJ00@0FEUI05QHF01HF5P0EeMG301FEUH02P1GEeL0F5QH05YJ
FP1JFUX0G5aL05eMG@1NGUh0HF5Q069RHP1TI6@206EUI@0E06QXJ01YJFT0JVYZ06][J`1/K6`0KVi^
079bLP1dM7@0MWIf07UiN@1mOGd0QhN708V9R@2;Rh/0SHf=092@T02BTY80U9BD09FEU@2FUYH0UiNG
00@0VIVI00/0UiNG09JFUP2ATI40Shn?08b<S027QhL0Q8B40820P01fMWH0LW9b06e]K@0N0?ooo`0N
04i>CP1=CDd0Bd];04Y:BP18B4P0AdM704I6AP15ADD0@D510410@00o?cl0?Cdm03`l?00i>CT0=cLg
03De=@0c<c<0<S8b02d];@0[:b/0:2PX02HV9P0S8b<0820P01XJ6P0G5aL051@D014A4@0>3Ph02PX:
100820P020061PH03@d=018B4P0F5QH06QXJ01dM7@0P82008B4Q0P0R8R8302<S8`<08R8R00T08B4Q
020P800O7al07QhN01dM7@0L71`06QXJ01TI6@0H61P00P0G5aL00`0F5QH051@D01@D500701<C4`0I
01@D500E5AD05ADE01HF5P0G5aL06ATI01XJ6P0M7Ad07alO028R8P0V9RH0;2`/03/k>`0o?cl0@d=3
04Q8B01=CDd0D51@05EEE@1HF5P0Fe]K05iNGP1PH600I6AT06EUI@0306MWI`80J6QX00L0IVIV06=S
H`1PH600GUiN05QHF01EEED0DU9B0280oooo000P0?ooo`0H09:BTP2@T900S8b<08Z:RP28R8P0QhN7
08F5Q@23Ph<0P82007inOP1lO7`0Ng]k07UiN@1fMWH0M7Ad079bLP1aLG40Kfm_06a/K01[Jf/0JFUY
06QXJ01WIfL0IVIV0P1TI6@04`1SHf<0IFEU06EUI@1bLW80NWYj08>3P`2=SHd0V9RH0:BTY02j^[X0
^;Rh0;Jf]P2d];@0/[:b0:j^[P2/[:`0Zj^[0:VYZ@2XZ:P00`2VYZH00`2UYJD0YZJV0:JVYP020:NW
Y`0E0:RXZ02ZZZX0Zj^[0:f][@2^[Zh0[jn_0;2`/02b/[80];Bd0;Rh^02k^k/0_Kfm0;no_`31`L40
aLG50<O7a`39bLT0bl_;0<c<c03?cll0d=3@00<0dM7A00@0d];B0=CDe03EeMD0e]KF0`3EeMD20=CD
e080d];B01@0dM7A0<o?c`3>c/h0cLg=0<_;b`3:b/X0alO70<G5a@33`l<0`<300;jn_P2g]kL0];Bd
0;6a/@2][Jd0ZZZZ0:JVYP2NWYh0Vi^K09NGUah0oooo02H0IfMW06EUI@1QHF40GemO05aLG01JFUX0
F5QH05IFEP1BDU80Cdm?04e=C@1;Bd/0BDU904A4A012@T80@41003dm?@0k>c/0=SHf03<c<`0`<300
;Rh^02/[:`0Y:BT08b<S020P800N7Qh07AdM01/K6`0S8b<09bLW02h^;P0f=SH0?Cdm04E5A@1EEED0
EeMG05YJFP<0Fe]K0P1JFUX205UIF@80EeMG0P1FEUH305EEE@@0E5AD101EEED08@1FEUH0EeMG05QH
F01IFET0Fe]K05aLG01MGEd0H61P069RHP1SHf<0I6AT06EUI@1XJ6P0JVYZ06][J`1/K6`0KVi^06m_
K`1cLg<0MgMg07YjNP1nOWh0Ph>308^;R`2=SHd0Shn?096AT@2DU9@0UIFE09NGU`2IVIT0VYZJ09^K
V`0309bLW00<09^KV`2IVIT0V9RH09>CT`2@T900S8b<08R8R024Q8@0P82007MgM`1bLW80KFe]7P3o
ool07P1>CTh0CDe=04];B`19BDT0B4Q804M7A`15ADD0A4A40410@00o?cl0?Cdm03`l?00j>SX0=cLg
03De=@0c<c<0<C4a02l_;`0[:b/0:BTY02HV9P0S8b<08B4Q01hN7P0G5aL051@D010@400=3@d02PX:
00T92@8020P80`092@T01`0;2`/04A4A01HF5P0J6QX07AdM020P800Q8B401@0R8R82024Q8@0;020P
800O7al07QhN01dM7@0L71`06a/K01XJ6P0H61P05aLG01HF5P0E5AD00P0D51@00`0B4Q804A4A010@
4002010@40D04A4A01L04a<C01@D500E5AD05QHF01PH600J6QX07QhN028R8P0W9bL0;Bd]03De=@11
@D40A4A404M7A`1<C4`0D51@05=CD`1HF5P0G5aL05mOG`1RHV80IFEU06QXJ00206YZJP<0Jf][00P0
JFUY06MWI`1UIFD0HV9R05mOG`1IFET0EUIF059BDR80oooo000P0?ooo`0I09:BTP2@T900S8b<08Z:
RP28R8P0QXJ608F5Q@23Ph<0Ogmo07inOP1lO7`0NWYj07QhN01eMGD0Lg=c075aL@1`L700KVi^06][
J`1ZJVX0J6QX06MWI`1UIFD0I6AT069RHP02065QH@80HV9R0100Kfm_07IfMP1oOgl0RHV909>CT`2N
WYh0]kNg0;bl_02h^;P0]KFe0;:b/P2^[Zh0[:b/0:^[Z`2YZJT0Z:RX0P2VYZH30:FUY@0O0:JVYP2W
YjL0YjNW0:RXZ02YZJT0ZZZZ0:f][@2^[Zh0/;2`0;6a/@2c/k<0]KFe0;Vi^@2k^k/0_[jn0<30`033
`l<0alO70<W9b@3;bl/0cLg=0<k>cP3AdM40d];B0=?Cd`3De=@0dm?C0=CDe03EeMD0e]KF0=OGe`04
0=KFeP0G0=GEe@3De=@0e=CD0=;BdP3?cll0c/k>0<g=c@3<c<`0bl_;0<O7a`35aLD0`l?30<71`@2n
_[h0^;Rh0;Bd]02a/K40[Jf]0:ZZZP2VYZH0WinO09^KV`2HV9P07P3oool0901WIfL0IFEU061PH01N
GUh0G5aL05YJFP1GEeL0EEEE051@D01>CTh0C4a<04Y:BP17AdL0@d=30410@00n?Sh0>c/k03Ti>@0c
<c<0<C4a02h^;P0[:b/0:BTY02HV9P0P82007AdM01/K6`0J6QX061PH020P800U9BD0;2`/03<c<`0j
>SX0@T9205EEE@80Fe]K0P1LG5`205]KF`0505YJFP1IFET0F5QH05MGE`1FEUH00P1EEED205ADE0L0
De=C0P1DE5@0801EEED0EUIF05MGE`1HF5P0FUYJ05]KF`1LG5`0H61P065QH@1SHf<0I6AT06EUI@1Y
JFT0JVYZ06a/K01^KVh0Kfm_075aL@1gMgL0NWYj0820P024Q8@0R8R808j>SP2@T900Ti>C09FEU@2G
UiL0V9RH09^KV`2MWId0WYjN102OWil0302MWId0Vi^K09ZJVP2DU9@0TI6A08f=S@29RHT0Q8B40820
P01fMWH0LW9b06e]KAh0oooo01`0CTi>04e=C@1:BTX0BDU904M7A`16ATH0A4A404=3@`10@400?Shn
03`l?00k>c/0>CTi03Hf=P0d=3@0<C4a02l_;`0];Bd0:BTY02HV9P0T92@08B4Q01hN7P0K6a/05ADE
014A4@0>3Ph02`/;0`0820P02`092@T02PX:00/;2`0;2`/03@d=014A4@0G5aL06a/K01dM7@0P8200
8B4Q00<08R8R0P0Q8B402P0P82007alO01lO7`0N7Qh071`L01/K6`0J6QX06ATI01PH600F5QH201@D
500301<C4`0B4Q804A4A00803`l?0P0>3Ph0100=3@d03Ph>00h>3P0>3Ph200l?3`0G014A4@0C4a<0
51@D01HF5P0H61P06QXJ028R8P0W9bL0;Rh^03De=@0k>c/0A4A404Q8B01<C4`0D51@05ADE01GEeL0
GUiN065QH@1TI6@0IfMW06UYJ@1/K6`00P1]KFd206i^KP0906][J`1ZJVX0J6QX06EUI@1RHV80GemO
05QHF01EEED0DU9B0280oooo000P0?ooo`0I096AT@2?Shl0S8b<08Z:RP28R8P0QXJ608B4Q022PX80
OWin07emO@1kNg/0NGUi07MgM`1dM7@0LW9b071`L01^KVh0KFe]06YZJP1YJFT0IfMW06EUI@1TI6@0
HV9R061PH00205mOG`0@061PH01QHF40KFe]07AdM01lO7`0Q8B408j>SP2HV9P0[jn_0;Zj^P2h^;P0
][Jf0;>c/`2^[Zh0[:b/0:ZZZP80Z:RX0P2VYZH30:FUY@0J0:JVYP2WYjL0YjNW0:RXZ02YZJT0ZZZZ
0:f][@2^[Zh0/;2`0;6a/@2c/k<0]KFe0;Vi^@2l_;`0_kno0<;2`P34a<@0b<S80<[:bP3<c<`0clo?
0=3@d03Cdm<0e=CD0=GEe@3Fe]H20=GEe@050=KFeP3EeMD0emOG0=OGe`3Hf=P00`3GemL05P3Fe]H0
eMGE0=CDe03AdM40d=3@0<o?c`3=cLd0c<c<0<S8b036a/H0`l?30<71`@2n_[h0^;Rh0;Bd]02a/K40
[Jf]0:ZZZP2VYZH0WinO09^KV`2GUiLN0?ooo`0T06IVIP1TI6@0H61P05eMG@1KFe/0FEUI05MGE`1D
E5@0Cdm?04e=C@1;Bd/0B4Q804I6AP11@D40?Shn03`l?00i>CT0=cLg034a<@0^;Rh0;2`/02TY:@0V
9RH08b<S01dM7@0J6QX061PH01LG5`0F5QH07QhN02@T900Z:RX0<C4a03Ph>011@D40E5AD0P1MGEd0
2@1NGUh0GEeM05aLG01KFe/0FUYJ05UIF@1HF5P0EUIF05EEE@0205ADE080De=C1`1BDU8205=CD`80
E5AD01d0EUIF05MGE`1IFET0FUYJ05aLG01PH600HF5Q069RHP1TI6@0IVIV06YZJP1/K6`0KFe]071`
L01aLG40M7Ad07alO020P800QHF508V9R@2=SHd0TY:B09BDU02FUYH0VIVI09^KV`2LW9`0WYjN0:2P
X0020:6QX@80XZ:R00d0XJ6Q09nOW`2NWYh0W9bL09JFUP2BTY80SHf=08V9R@24Q8@0P82007IfMP1b
LW80KFe]01h0oooo02T0CTi>04e=C@19BDT0B4Q804I6AP15ADD0A4A40492@P0n?Sh0?Cdm03`l?00j
>SX0=cLg03@d=00b<S80<30`02d];@0[:b/09RHV02@T900Q8B407alO01`L700I6AT04Q8B00l?3`0;
2`/020P800H61P071`L020P800X:2P0<30`03@d=00h>3P0D51@061PH01TI6@0L71`07alO024Q8@04
028R8P04024Q8@0P82007alO01hN7P807AdM00H06a/K01XJ6P0I6AT061PH01HF5P0D51@2018B4P04
014A4@0@41003`l?00d=3@8030`<0P0;2`/500d=3@0G010@400B4Q8051@D01LG5`0J6QX07QhN02TY
:@0_;bl0=SHf03/k>`10@400B4Q804a<C01@D500E5AD05MGE`1KFe/0HF5Q06ATI01WIfL0JVYZ06a/
K01_Kfl00P1`L7002`1aLG40L71`06i^KP1[Jf/0JFUY06IVIP1RHV80GemO05UIF@1FEUH0DU9B0280
oooo000P0?ooo`0H096AT@2?Shl0S8b<08Z:RP28R8P0QXJ608B4Q022PX80OWin07alO01jNWX0N7Qh
07IfMP1cLg<0LG5a06m_K`1^KVh0K6a/06UYJ@1WIfL0IFEU06ATI01RHV80HF5Q0P1NGUh04`1MGEd0
GUiN061PH01ZJVX0LG5a07UiN@21PH40RXZ:09>CT`2ZZZX0][Jf0;Zj^P2f][H0/[:b0:f][@2[Zj/0
ZZZZ0:RXZ02WYjL00`2UYJD20:BTY00G0:FUY@2VYZH0YjNW0:RXZ02YZJT0ZZZZ0:b/[02^[Zh0/;2`
0;:b/P2c/k<0]KFe0;Zj^P2l_;`0_kno0<;2`P35aLD0bLW90<_;b`3=cLd0d=3@0=;BdP3EeMD00P3F
e]H0103GemL0e]KF0=KFeP3EeMD20=KFeP040=OGe`3Hf=P0emOG0=OGe`80f=SH01D0emOG0=KFeP3C
dm<0d];B0=7Ad@3?cll0cLg=0<W9b@36a/H0a<C40<71`@2n_[h0^;Rh0;Bd]02a/K40[Jf]0:ZZZP2V
YZH0WinO09^KV`2GUiL07P3oool09@1VIVH0I6AT05mOG`1MGEd0Fe]K05QHF01FEUH0De=C04i>CP1<
C4`0BDU904M7A`14A4@0?clo03`l?00j>SX0=cLg03De=@0_;bl0;2`/02TY:@0V9RH08b<S020P800J
6QX05aLG01DE5@0C4a<051@D01`L700R8R80:BTY030`<00g=cL0@41005=CD`1LG5`00P1OGel01`1N
GUh0G5aL05]KF`1JFUX0F5QH05MGE`1EEED00P1DE5@00`1CDe<0DU9B059BDP07055AD@80DU9B0P1C
De<07@1EEED0EUIF05QHF01JFUX0G5aL061PH01QHF40HV9R06ATI01WIfL0Jf][06e]K@1_Kfl0LW9b
07EeM@1hN7P0PH6108F5Q@29RHT0SHf=096AT@2EUID0UiNG09ZJVP2LW9`0WIfM09nOW`2QXJ40Xj>S
0080Y:BT00l0YJFU0:BTY02SXj<0XJ6Q0:2PX02MWId0UYJF09:BTP2=SHd0RHV908F5Q@20P800MgMg
079bLP1]KFd07P3oool0:01>CTh0C4a<04U9B@17AdL0ATI604A4A013@d<0@D5103hn?P0l?3`0>SXj
03Ph>00g=cL0<S8b030`<00];Bd0:b/[02TY:@0T92@08R8R01lO7`0L71`06ATI01HF5P0?3`l030`<
00T92@051@D010@400L71`092@T02`/;00d=3@0?3`l04Q8B01PH600I6AT06a/K01lO7`0Q8B4302<S
8`808R8R0180820P01lO7`0N7Qh07QhN01dM7@0L71`06ATI01PH600G5aL05QHF01DE5@0B4Q804A4A
010@400?3`l03Ph>00d=3@0;2`/400X:2P0K00`<300;2`/02PX:00/;2`0=3@d04A4A01<C4`0F5QH0
6QXJ01hN7P0S8b<0<C4a03Lg=`0l?3`0@T9204M7A`1=CDd0D51@05ADE01HF5P0FUYJ05eMG@1TI6@0
IfMW06UYJ@1/K6`0Kfm_0080LW9b0P1cLg<02P1bLW80Kfm_06a/K01YJFT0IFEU069RHP1OGel0FEUI
05IFEP1BDU8R0?ooo`00803oool0;P2ATI40Shn?08^;R`29RHT0QhN708F5Q@23Ph<0PH6107emO@1k
Ng/0NGUi07MgM`1dM7@0LG5a06m_K`1]KFd0Jf][06YZJP1VIVH0I6AT06=SH`1QHF40GemO05eMG@1K
Fe/0FUYJ05UIF@1KFe/0GEeM06QXJ01_Kfl0MWIf07alO025QHD0SXj>0:6QX@2[Zj/0][Jf0;>c/`2`
/;00ZZZZ0:RXZ02WYjL0YJFU0:BTY02SXj<20::RXP<0Xj>S01L0YJFU0:JVYP2WYjL0Z:RX0:VYZ@2/
[:`0[Jf]0:n_[`2a/K40/k>c0;Fe]@2i^KT0_;bl0;no_`33`l<0a/K60<_;b`3=cLd0d=3@0=;BdP3D
e=@0e]KF0=OGe`020=SHf080e]KF0P3Hf=P0103IfMT0fm_K0=_Kf`3Jf]X30=WIf@80f=SH01<0emOG
0=KFeP3De=@0d];B0=3@d03:b/X0b<S80<C4a032`/80_kno0;Rh^02e]KD0/K6a0:f][@2ZZZX0YZJV
09nOW`2KVi/0UiNG01h0oooo01X0IVIV06=SH`1NGUh0G5aL05UIF@1GEeL0E5AD055AD@1<C4`0BTY:
04M7A`14A4@0@D5103`l?00i>CT0=SHf03<c<`0a<C40:b/[02PX:00U9BD08B4Q01hN7P0K6a/051@D
018B4P803`l?01404A4A01/K6`0Q8B409bLW02h^;P0g=cL0@410051@D01IFET0I6AT069RHP1PH600
G5aL05YJFP1IFET0EeMG05IFEP0205=CD`04059BDP1ADE40D51@051@D0<0Cdm?0`1>CTh00`1?Cdl0
D51@051@D002055AD@0N05=CD`1DE5@0EUIF05UIF@1LG5`0GUiN061PH01SHf<0IfMW06UYJ@1_Kfl0
LW9b07MgM`1kNg/0OWin0861P@29RHT0SHf=092@T02EUID0V9RH09bLW02NWYh0XJ6Q0:>SX`2TY:@0
YZJV0:RXZ02YZJT0ZZZZ0P2[Zj/03P2XZ:P0YjNW0:FUY@2RXZ80WYjN09NGU`2BTY80SXj>08V9R@25
QHD0P82007MgM`1bLW80KFe]7P3oool06`1=CDd0C4a<04U9B@17AdL0ADE504=3@`12@T80@41003`l
?00j>SX0>3Ph03Hf=P0d=3@0;bl_02d];@0[:b/0:2PX02HV9P0Q8B407QhN01/K6`0H61P05ADE018B
4P0;2`/020P800@4100200<30`0900L71`092@T030`<00l?3`0C4a<061PH01hN7P0P82009BDU0080
9RHV0P0U9BD0500T92@08b<S02<S8`0P82007alO01hN7P0L71`06a/K01XJ6P0G5aL05QHF01DE5@0C
4a<04Q8B010@400>3Ph03@d=00`<300;2`/02PX:100820P07@092@T01`L700P8200:2PX03@d=00l?
3`0E5AD06ATI01lO7`0V9RH0:b/[034a<@0k>c/0?clo04A4A019BDT0CDe=05ADE01IFET0GEeM061P
H01RHV80IFEU06YZJP1]KFd0L71`07=cL`1eMGD0MgMg0080N7Qh00/0MWIf07AdM01_Kfl0K6a/06UY
J@1VIVH0HV9R05mOG`1IFET0EUIF059BDP0R0?ooo`00803oool0;@2ATI40Shn?08Z:RP29RHT0QhN7
08F5Q@23Ph<0P82007alO01jNWX0N7Qh07IfMP1dM7@0L71`06i^KP1/K6`0JVYZ06QXJ01UIFD0Hf=S
065QH@1PH600GUiN05aLG01IFET0F5QH05MGE`1IFET0G5aL06IVIP1/K6`0Lg=c07]kN`23Ph<0S8b<
09jNWP2WYjL0/k>c0;2`/02^[Zh0Z:RX0:NWY`2UYJD0Xj>S0::RXP040:6QX@80XZ:R01D0Y:BT0:FU
Y@2VYZH0YjNW0:RXZ02[Zj/0[:b/0:j^[P2`/;00/[:b0;Bd]02i^KT0^k^k0;no_`32`/80a/K60<_;
b`3>c/h0d=3@0=;BdP3De=@00P3GemL20=WIf@060=OGe`3Fe]H0emOG0=SHf03IfMT0fm_K0P3Lg=`0
0`3Kfm/0f][J0=[JfP020=WIf@0C0=SHf03GemL0e]KF0=?Cd`3AdM40bl_;0<S8b036a/H0`/;20;no
_`2i^KT0]KFe0;6a/@2][Jd0ZZZZ0:JVYP2OWil0Vi^K09NGU`0N0?ooo`0a06IVIP1SHf<0GUiN05aL
G01IFET0EUIF05=CD`1ADE40Bd];04U9B@16ATH0@d=30410@00j>SX0=cLg03@d=00b<S80;bl_02TY
:@0V9RH08R8R01lO7`0L71`06ATI018B4P0?3`l03@d=00h>3P0@41006QXJ024Q8@0W9bL0;Rh^03Lg
=`10@400D51@05UIF@1UIFD0HV9R061PH01LG5`0FUYJ05UIF@1GEeL0EEEE05=CD`1BDU80DE5A051@
D00204m?C`0304i>CP1=CDd0CDe=00<0CDe=0P1>CTh06`1?Cdl0D51@051@D01BDU80E5AD05IFEP1I
FET0G5aL05iNGP1QHF40IFEU06QXJ01[Jf/0LW9b07MgM`1lO7`0P82008>3P`26QXH0SHf=096AT@2D
U9@0V9RH09^KV`2PX:00XZ:R0:BTY0020:JVYP030:RXZ02[Zj/0[Jf]00<0[Zj^00h0Zj^[0:VYZ@2V
YZH0XZ:R09nOW`2GUiL0TY:B08j>SP29RHT0Q8B40820P01gMgL0LW9b06e]KAh0oooo01X0CDe=04a<
C018B4P0ATI604A4A012@T80@D5103lo?`0k>c/0>CTi03Lg=`0e=CD0<S8b02h^;P0[:b/0:BTY02LW
9`0T92@07alO01`L700I6AT05QHF01<C4`0@41002@T900H61P<00`<300P020P800/;2`0>3Ph04A4A
01HF5P0J6QX0820P02@T90<0:BTY0P0W9bL05P0V9RH09BDU02@T900Q8B40820P01hN7P0L71`06a/K
01XJ6P0F5QH05ADE01@D500C4a<04A4A00l?3`0>3Ph03@d=00`<300;2`/02PX:00P820071`L400P8
200J00X:2P0<30`03`l?014A4@0I6AT0820P02HV9P0/;2`0<S8b03Ph>011@D40ATI604Y:BP1>CTh0
DE5A05QHF01MGEd0HF5Q06=SH`1UIFD0J6QX06i^KP1aLG40M7Ad07MgM`1hN7P207YjNP0<07QhN01f
MWH0M7Ad06m_K`1[Jf/0JFUY06IVIP1RHV80GemO05UIF@1FEUH0DU9B8P3oool00200oooo02d0TI6A
08n?S`2:RXX0R8R808J6QP24Q8@0PX:20820P01lO7`0NWYj07QhN01eMGD0Lg=c06m_K`1]KFd0Jf][
06UYJ@1WIfL0I6AT069RHP1PH600GUiN05eMG@1KFe/0EeMG05IFEP1EEED0F5QH05]KF`1UIFD0Jf][
075aL@1iNGT0PH6108V9R@2LW9`0YZJV0;2`/02][Jd0Zj^[0:JVYP2TY:@0XZ:R0:6QX@2PX:00102O
Wil20:2PX00G0::RXP2SXj<0YJFU0:JVYP2WYjL0ZZZZ0:^[Z`2][Jd0[jn_0;6a/@2c/k<0^;Rh0;Zj
^P2n_[h0`/;20<G5a@3;bl/0c/k>0=3@d03Cdm<0e=CD0=OGe`3Hf=P00P3Jf]X03@3IfMT0emOG0=OG
e`3IfMT0f][J0=cLg03MgMd0g]kN0=gMg@3Kfm/0f][J0=WIf@3Jf]X00`3Hf=P0403EeMD0d];B0<c<
c039bLT0a/K60<?3``2o_kl0^KVi0;Fe]@2a/K40[Jf]0:ZZZP2VYZH0WinO09^KV`2GUiLN0?ooo`0_
06IVIP1SHf<0GEeM05]KF`1HF5P0EEEE05=CD`1@D500BTY:04Q8B014A4@0@D5103hn?P0i>CT0=SHf
03<c<`0`<300;Bd]02HV9P0S8b<0820P01dM7@0J6QX05QHF00l?3`0=3@d02`/;00d=3@0@41006QXJ
020P800W9bL0;bl_03Ph>00o?cl0D51@05YJFP1UIFD0HV9R061PH01LG5`0FUYJ05QHF01FEUH0EEEE
059BDP1ADE400P1?Cdl00`1>CTh0CDe=04e=C@0504a<C080CDe=0200CTi>04m?C`1?Cdl0DU9B05=C
D`1FEUH0FEUI05]KF`1OGel0Hf=S06IVIP1ZJVX0KFe]07IfMP1kNg/0P82008F5Q@27QhL0RXZ:096A
T@2DU9@0UiNG09^KV`2MWId0Xj>S0:JVYP2WYjL0Z:RX0:VYZ@2[Zj/0[Zj^0;2`/080/K6a00l0/;2`
0:f][@2ZZZX0YjNW0:>SX`2OWil0UiNG09>CT`2>SXh0RHV908B4Q020P800MgMg079bLP1]KFd07P3o
ool09@1=CDd0Bd];04Q8B016ATH0A4A40492@P10@400?Shn03Xj>P0h>3P0=CDe03<c<`0a<C40;2`/
02XZ:P0X:2P09BDU028R8P0M7Ad06QXJ01LG5`0D51@04A4A00d=3@071`L010@400820P030`<010@4
00T92@0<30`0410@01@D500I6AT06a/K028R8P0W9bL00P0/;2`0500[:b/0:BTY02TY:@0X:2P09RHV
02@T900R8R80820P01hN7P0M7Ad06a/K01TI6@0F5QH05ADE01@D500B4Q804A4A00l?3`0>3Ph030`<
0P0;2`/00`0:2PX020P800P8200400T92@0X00`<300>3Ph04A4A01DE5@0P82009BDU02`/;00b<S80
=cLg03dm?@17AdL0BTY:04e=C@1ADE40E5AD05aLG01PH600Hf=S06MWI`1YJFT0K6a/079bLP1dM7@0
MgMg07UiN@1jNWX0O7al07]kN`1iNGT0MgMg07AdM01_Kfl0K6a/06UYJ@1VIVH0HV9R05mOG`1IFET0
EEEE059BDR80oooo000P0?ooo`0]096AT@2?Shl0RXZ:08R8R026QXH0Q8B408:2PP20P800Ng]k07Ui
N@1gMgL0MGEe079bLP1^KVh0K6a/06YZJP1XJ6P0IVIV069RHP1QHF40GemO05eMG@1KFe/0FEUI05EE
E@1DE5@0EEEE05MGE`1JFUX0I6AT06YZJP1`L700N7Qh0820P027QhL0VIVI0:>SX`2^[Zh0ZZZZ0:RX
Z02SXj<0XJ6Q0:2PX02NWYh0WIfM00@0W9bL01T0WIfM09jNWP2PX:00XJ6Q0:>SX`2TY:@0YJFU0:RX
Z02ZZZX0[:b/0:j^[P2`/;00/[:b0;Jf]P2i^KT0_Kfm0<30`033`l<0b/[:0<g=c@3@d=00d];B0=CD
e03Hf=P0f][J0080fm_K00L0f][J0=SHf03GemL0f=SH0=[JfP3Lg=`0gMgM0080gmoO00@0g]kN0=cL
g03Kfm/0fm_K0`3IfMT0403Fe]H0e=CD0<g=c@3:b/X0alO70<?3``30`<00^KVi0;Fe]@2a/K40[Zj^
0:ZZZP2VYZH0WinO09^KV`2GUiLN0?ooo`0I06IVIP1SHf<0GEeM05YJFP1GEeL0EEEE059BDP1?Cdl0
BDU904I6AP13@d<0@41003dm?@0g=cL0=3@d034a<@0^;Rh0:b/[02@T900Q8B407QhN01/K6`0G5aL0
51@D00d=3@0200X:2P0H00`<300@41006QXJ024Q8@0W9bL0<30`03Lg=`0n?Sh0DE5A05]KF`1UIFD0
Hf=S061PH01LG5`0FUYJ05QHF01FEUH0E5AD055AD@1@D500Cdm?04i>CP1=CDd0C4a<101;Bd/304a<
C080CDe=0300CTi>04m?C`1ADE40De=C05IFEP1IFET0FUYJ065QH@1UIFD0J6QX06a/K01aLG40NWYj
07moO`25QHD0RHV908b<S02>SXh0U9BD09NGU`2JVYX0WIfM0:2PX02VYZH0ZJVY0:ZZZP2[Zj/0[:b/
0:j^[P2a/K40/k>c0;Bd]02c/k<0/[:b0:j^[P2ZZZX0YjNW0:BTY02PX:00UiNG09>CT`2>SXh0RHV9
08B4Q020P800MgMg079bLP1]KFdN0?ooo`0n04e=C@1;Bd/0AdM704E5A@13@d<0@D5103lo?`0m?Cd0
>CTi03Lg=`0d=3@0<S8b030`<00[:b/0:BTY02HV9P0S8b<08B4Q01/K6`0H61P05ADE018B4P0?3`l0
30`<00H61P030`<00@4100820P0410@02PX:00h>3P0A4A405QHF01XJ6P0L71`09RHV02/[:`0`<300
;bl_02h^;P0/;2`0:b/[02TY:@0X:2P09bLW02<S8`0Q8B40820P01hN7P0L71`06QXJ01LG5`0E5AD0
51@D01<C4`0B4Q803`l?00h>3P0=3@d030`<00/;2`0:2PX200T92@802PX:02X02@T900`<300?3`l0
4Q8B01DE5@0J6QX092@T02XZ:P0a<C40=cLg03dm?@12@T80Bd];04m?C`1ADE40E5AD05QHF01OGel0
Hf=S06IVIP1YJFT0Jf][06m_K`1dM7@0N7Qh07YjNP1kNg/0OGem07alO01jNWX0N7Qh07MgM`1eMGD0
Kfm_06a/K01YJFT0IVIV069RHP1OGel0FEUI05IFEP1BDU8R0?ooo`00803oool0;`2ATI40Shn?08Z:
RP28R8P0QXJ608B4Q021PH40Ogmo07]kN`1iNGT0MWIf07AdM01bLW80KVi^06][J`1YJFT0IfMW06EU
I@1QHF40GemO05iNGP1KFe/0FUYJ05QHF01DE5@0DU9B05ADE01GEeL0FUYJ06ATI01YJFT0Kfm_07Mg
M`1mOGd0Q8B409NGU`2PX:00ZZZZ0:NWY`2UYJD0X:2P09jNWP2MWId0Vi^K09ZJVP2IVIT0V9RH0080
VIVI01d0VYZJ09^KV`2MWId0WinO0:2PX02RXZ80Xj>S0:JVYP2XZ:P0ZZZZ0:b/[02^[Zh0/;2`0;Fe
]@2h^;P0_;bl0;jn_P31`L40bLW90<c<c03?cll0dM7A0=CDe03Hf=P0f][J0=cLg03MgMd0g=cL0=[J
fP020=SHf0030=WIf@3Kfm/0g]kN0080h>3P00<0gmoO0=kNgP3Lg=`00P3Lg=`04P3Kfm/0f][J0=OG
e`3EeMD0c/k>0<[:bP37alL0a<C40<30`02i^KT0]KFe0;6a/@2^[Zh0ZZZZ0:JVYP2NWYh0Vi^K09NG
Uah0oooo0380IVIV06=SH`1MGEd0FUYJ05MGE`1DE5@0DE5A04i>CP18B4P0ADE50492@P0o?cl0?3`l
03Hf=P0c<c<0;bl_02`/;00Y:BT08R8R01lO7`0L71`06ATI01DE5@0B4Q802`/;00P820092@T030`<
00l?3`0K6a/08B4Q02PX:00`<300=cLg03lo?`1BDU80Fe]K06EUI@1SHf<0H61P05aLG01IFET0EeMG
05EEE@1CDe<0D51@04m?C`1>CTh0CDe=04a<C080Bd];0P1:BTX404];B`0P04a<C01=CDd0CDe=04m?
C`1ADE40De=C05IFEP1HF5P0Fe]K069RHP1VIVH0Jf][06m_K`1dM7@0OWin08B4Q029RHT0SHf=092@
T02BTY80UiNG09ZJVP2LW9`0X:2P0:>SX`2ZZZX0[:b/0:f][@2^[Zh0[jn_0;6a/@2d];@30;Jf]P0?
0;Bd]02_[jl0Zj^[0:RXZ02TY:@0X:2P09NGU`2CTi<0SXj>08V9R@25QHD0P82007MgM`1bLW80KFe]
01h0oooo01T0CDe=04];B`17AdL0ADE50492@P10@400?Shn03`l?00h>3P0=SHf03<c<`0a<C40;Rh^
02TY:@0W9bL092@T024Q8@0O7al06ATI01HF5P0C4a<0410@00d=3@0:2PX010@400800@4102@00P82
00@4100;2`/03`l?01<C4`0H61P071`L020P800Z:RX0;bl_03<c<`0b<S80<C4a02l_;`0];Bd0;2`/
02XZ:P0Y:BT09BDU02<S8`0Q8B40820P01hN7P0L71`061PH01HF5P0E5AD051@D018B4P0@41003`l?
00h>3P0=3@d030`<00/;2`0:2PX300/;2`0J00`<300@41004a<C01HF5P0K6a/0820P02XZ:P0a<C40
=cLg03`l?011@D40ATI604m?C`1CDe<0EUIF05UIF@1LG5`0Hf=S06IVIP1YJFT0K6a/06m_K`1bLW80
MWIf07YjNP1lO7`207inOP0>07alO01kNg/0NGUi07MgM`1eMGD0Kfm_06a/K01YJFT0IVIV069RHP1O
Gel0FEUI05IFEP1BDU8R0?ooo`00803oool0602ATI40Shn?08Z:RP27QhL0QHF508>3P`21PH40OWin
07UiN@1gMgL0MGEe07=cL`1`L700K6a/06YZJP1WIfL0IFEU06=SH`1OGel0GEeM05]KF`1IFET0EeMG
05EEE@80DE5A01<0DU9B05EEE@1HF5P0Hf=S06MWI`1]KFd0Lg=c07YjNP20P800TY:B09ZJVP2SXj<0
X:2P09fMW@2IVIT0UiNG09FEU@2DU9@0Ti>C00@0TI6A01/0TY:B09>CT`2FUYH0UiNG09ZJVP2LW9`0
WYjN0:6QX@2SXj<0YJFU0:NWY`2ZZZX0[:b/0;6a/@2d];@0][Jf0;Zj^P2n_[h0aLG50<W9b@3<c<`0
d=3@0=CDe03IfMT0f][J0=_Kf`3MgMd00P3Ng]h01P3Kfm/0fMWI0=OGe`3IfMT0gMgM0>7Qh@80h^;R
00<0hN7Q0>3Ph03Ogml00P3Ogml04@3Lg=`0fMWI0=KFeP3?cll0c<c<0<S8b035aLD0`L710;Zj^P2f
][H0/[:b0:j^[P2ZZZX0YZJV09nOW`2KVi/0UiNG01h0oooo03<0IFEU069RHP1LG5`0FEUI05IFEP1C
De<0D51@04e=C@16ATH0@d=30410@00m?Cd0>CTi03<c<`0`<300;2`/02TY:@0V9RH07alO01`L700H
61P05ADE014A4@0>3Ph01`L700H61P0820P030`<010@400M7Ad08b<S02/[:`0a<C40>3Ph0410@01D
E5@0GEeM06IVIP1SHf<0HF5Q05]KF`1IFET0EUIF05ADE01BDU80Cdm?04e=C@1<C4`0Bd];04Y:BP19
BDT00P18B4P304U9B@80BTY:01/0Bd];04a<C01<C4`0CTi>059BDP1DE5@0EUIF05UIF@1MGEd0IVIV
06][J`1`L700M7Ad07]kN`27QhL0S8b<092@T02DU9@0V9RH09^KV`2NWYh0X:2P0:6QX@2UYJD0ZJVY
0:n_[`2a/K400P2c/k<05@2d];@0][Jf0;Zj^P2l_;`0^k^k0;Zj^P2g]kL0/;2`0:f][@2YZJT0YJFU
0:2PX02GUiL0Ti>C08j>SP29RHT0QHF50820P01gMgL0LW9b06e]K@0N0?ooo`0m04e=C@1;Bd/0ATI6
04A4A012@T80?clo03dm?@0k>c/0=SHf03@d=00a<C40;bl_02`/;00W9bL092@T024Q8@0O7al071`L
01HF5P0C4a<0410@00d=3@0:2PX01`L700410@0000000@4100<30`071`L03`l?01@D500I6AT07AdM
024Q8@0V9RH0<c<c03Lg=`0k>c/0>SXj03Ti>@0f=SH0=3@d038b<P0`<300;Rh^02/[:`0Y:BT09bLW
02DU9@0S8b<08B4Q01dM7@0K6a/06ATI01LG5`0F5QH04a<C018B4P0A4A40410@00l?3`0200h>3P0]
00l?3`0@41004A4A01<C4`0I6AT07AdM020P800S8b<0:2PX03Hf=P0m?Cd0@T9204I6AP1:BTX0CTi>
05MGE`1KFe/0GemO069RHP1UIFD0JVYZ06a/K01_Kfl0LG5a07=cL`1eMGD0OGem0820P021PH40PX:2
0861P@1nOWh0O7al07YjNP1hN7P0M7Ad06m_K`1/K6`0J6QX06EUI@1RHV80GemO05UIF@1FEUH0DU9B
0280oooo000P0?ooo`0H096AT@2>SXh0RHV908N7Q`25QHD0PX:20820P01nOWh0NGUi07IfMP1dM7@0
LW9b071`L01[Jf/0JFUY06IVIP1UIFD0HV9R05iNGP1LG5`0FUYJ05MGE`1EEED0De=C0P1@D5004`1B
DU80EEEE05QHF01RHV80IfMW06e]K@1aLG40N7Qh07inOP2>SXh0UYJF09nOW`2KVi/0VIVI09BDU02B
TY80TI6A08n?S`2>SXh00P2=SHd208b<S00W08f=S@2?Shl0TY:B09>CT`2EUID0V9RH09ZJVP2NWYh0
X:2P0::RXP2TY:@0YjNW0:VYZ@2_[jl0/[:b0;>c/`2g]kL0_;bl0<?3``38b<P0c<c<0<o?c`3Cdm<0
fMWI0=[JfP3Lg=`0gMgM0=oOg`3Ph>00g=cL0=_Kf`3IfMT0f][J0=cLg03QhN40h^;R0>?Sh`3Rh^80
hN7Q0080h>3P0180gmoO0=gMg@3Jf]X0emOG0=3@d03<c<`0bLW90<G5a@31`L40^[Zj0;Jf]P2b/[80
[Zj^0:ZZZP2VYZH0WinO09^KV`2GUiLN0?ooo`0H06EUI@1RHV80G5aL05QHF01EEED0DU9B04m?C`1<
C4`0ADE50492@P0o?cl0>c/k03Ph>00a<C40;Rh^02/[:`0X:2P092@T01dM7@0J6QX05QHF01<C4`0?
3`l030`<0P061PH0600820P030`<014A4@0N7Qh092@T02`/;00b<S80>SXj04=3@`1FEUH0GUiN06MW
I`1SHf<0HF5Q05]KF`1HF5P0EUIF05ADE01BDU80CTi>04e=C@1;Bd/0BTY:04U9B@80B4Q800@0AdM7
04Q8B018B4P0B4Q80P19BDT06`1:BTX0Bd];04a<C01>CTh0DU9B05EEE@1GEeL0FUYJ061PH01XJ6P0
KFe]079bLP1gMgL0OWin08b<S02?Shl0Ti>C09NGU`2KVi/0WYjN0::RXP2SXj<0Y:BT0:NWY`2[Zj/0
/K6a0;>c/`020;Jf]P0E0;Ng]`2i^KT0_Kfm0;no_`2m_Kd0^k^k0;Rh^02a/K40[Zj^0:VYZ@2UYJD0
X:2P09RHV02CTi<0SXj>08V9R@25QHD0P82007MgM`1bLW80KFe]01h0oooo01P0CDe=04];B`16ATH0
A4A40451@@0o?cl0?Cdm03/k>`0e=CD0<c<c030`<00^;Rh0:b/[02DU9@0S8b<0820P01dM7@0J6QX0
5ADE014A4@0>3Ph030`<00P820051@D20000000R00820P0410@020P8018B4P0G5aL071`L020P800V
9RH0;2`/03Ti>@0m?Cd0@D5103lo?`0n?Sh0>SXj03Ph>00f=SH0=3@d03<c<`0_;bl0;Bd]02/[:`0Y
:BT09RHV02@T900P82007QhN01`L700J6QX06ATI01DE5@0D51@04a<C018B4P804A4A02h04Q8B01<C
4`0D51@05ADE01PH600N7Qh08B4Q02@T900Y:BT0<30`03hn?P12@T80ADE504U9B@1=CDd0DU9B05]K
F`1OGel0HF5Q06EUI@1YJFT0KFe]06m_K`1bLW80Lg=c07IfMP1iNGT0P82008>3P`24Q8@0Ph>30861
P@1nOWh0OGem07YjNP1hN7P0MGEe06m_K`1[Jf/0J6QX06EUI@1RHV80GemO05UIF@1EEED0DU9B8P3o
ool00200oooo02d0TI6A08j>SP29RHT0QhN708B4Q022PX80P82007emO@1hN7P0MWIf07=cL`1aLG40
KVi^06YZJP1XJ6P0IVIV06ATI01QHF40G5aL05YJFP1HF5P0EUIF05ADE01BDU80Cdm?051@D01ADE40
EEEE05QHF01QHF40IVIV06][J`1`L700MWIf07alO02:RXX0TY:B09ZJVP2FUYH0U9BD08n?S`2=SHd0
S8b<08^;R`2:RXX00P28R8P208N7Q`0G08R8R029RHT0S8b<08j>SP2@T900Ti>C09FEU@2JVYX0W9bL
09nOW`2QXJ40Xj>S0:JVYP2/[:`0/;2`0;6a/@2e]KD0^[Zj0<71`@36a/H0b/[:0<k>cP3AdM400P3I
fMT01P3Kfm/0gMgM0=oOg`3QhN40g]kN0=cLg080fm_K00@0gMgM0>;RhP3Shn<0hn?S0P3Rh^820>7Q
h@0B0>3Ph03Ng]h0f][J0=OGe`3@d=00cLg=0<W9b@35aLD0`L710;Zj^P2f][H0/[:b0:j^[P2ZZZX0
YZJV09nOW`2KVi/0UiNG7P3oool0<@1UIFD0HV9R05]KF`1HF5P0EEEE059BDP1>CTh0Bd];04A4A011
@D40?Shn03Xj>P0g=cL0<30`02d];@0Y:BT09RHV02<S8`0K6a/061PH01@D500A4A403@d=00X:2P05
1@D01PH600P8200=3@d04Q8B01lO7`0V9RH0;Bd]03@d=00m?Cd0ATI605MGE`1OGel0IfMW06ATI01Q
HF40Fe]K05QHF01FEUH0E5AD059BDP1>CTh0CDe=04];B`1:BTX00P18B4P404M7A`0N04Q8B019BDT0
BDU904Y:BP1;Bd/0C4a<04i>CP1CDe<0EUIF05QHF01LG5`0HV9R06YZJP1_Kfl0MGEe07alO023Ph<0
Shn?09:BTP2FUYH0VYZJ09jNWP2RXZ80YJFU0:JVYP2WYjL0ZZZZ0:f][@2c/k<0][Jf0P2h^;P05@2j
^[X0_;bl0<30`031`L40_kno0;bl_02i^KT0/[:b0:j^[P2ZZZX0YJFU0:6QX@2HV9P0Ti>C08j>SP29
RHT0QHF50820P01gMgL0LW9b06e]K@0N0?ooo`0H04e=C@1:BTX0ADE504=3@`11@D40?Shn03`l?00j
>SX0=3@d038b<P0_;bl0;Bd]02XZ:P0T92@08R8R01lO7`0L71`06ATI01<C4`0@41003@d=00X:2P07
1`L010@40P0000008@020P801PH600X:2P0E5AD06QXJ01lO7`0T92@0:b/[038b<P0o?cl0@d=304I6
AP15ADD0@d=303lo?`0l?3`0>SXj03Ti>@0g=cL0<c<c034a<@0_;bl0;Bd]02/[:`0Y:BT092@T028R
8P0P82007QhN01`L700I6AT05aLG01HF5P0201DE5@0M01@D500E5AD05aLG01PH600J6QX07QhN02<S
8`0V9RH0:b/[034a<@0h>3P0@d=304M7A`1;Bd/0CTi>059BDP1FEUH0GUiN065QH@1TI6@0J6QX06][
J`1_Kfl0LW9b07EeM@1gMgL0NWYj07emO@23Ph<00P25QHD04024Q8@0PX:207moO`1mOGd0NWYj07Qh
N01eMGD0Kfm_06][J`1XJ6P0IFEU069RHP1OGel0FEUI05IFEP1BDU8R0?ooo`00803oool0:`2ATI40
SXj>08V9R@27QhL0Q8B40861P@1oOgl0O7al07QhN01eMGD0Lg=c071`L01^KVh0JFUY06MWI`1TI6@0
HV9R061PH01KFe/0FEUI05MGE`1EEED0De=C051@D01>CTh0Cdm?055AD@1EEED0F5QH065QH@1TI6@0
JVYZ06i^KP1eMGD0NWYj08N7Q`2=SHd0Ti>C096AT@2>SXh0RXZ:08V9R@27QhL00P26QXH208B4Q00Q
08>3P`22PX80PX:208:2PP26QXH0R8R808^;R`2=SHd0T92@09FEU@2HV9P0VYZJ09fMW@2OWil0XZ:R
0:ZZZP2][Jd0[Zj^0;:b/P2g]kL0_[jn0<?3``38b<P0cLg=0=3@d03Hf=P0fMWI0=_Kf`3MgMd0gmoO
0>;RhP3Ph>00gMgM0080fm_K00@0gMgM0>;RhP3UiND0i>CT0`3Shn<04`3Rh^80hN7Q0=kNgP3Kfm/0
emOG0=7Ad@3=cLd0bLW90<G5a@32`/80^[Zj0;Jf]P2b/[80[jn_0:^[Z`2WYjL0WinO09^KV`2GUiL0
7P3oool0<`1UIFD0HV9R05]KF`1HF5P0EEEE055AD@1>CTh0BTY:04=3@`10@400?Cdm03Ti>@0f=SH0
;bl_02/[:`0X:2P092@T024Q8@0J6QX05QHF018B4P0?3`l030`<00P820051@D01PH600T92@0?3`l0
51@D028R8P0X:2P0;bl_03Hf=P10@400BDU905UIF@1QHF40IfMW06ATI01PH600FUYJ05QHF01EEED0
De=C055AD@1>CTh0C4a<04];B`19BDT0B4Q804M7A`0304I6AP80AdM701H0B4Q804U9B@1:BTX0Bd];
04a<C01>CTh0E5AD05MGE`1IFET0GUiN06ATI01[Jf/0LW9b07UiN@21PH40QXJ609:BTP2EUID0V9RH
09bLW02PX:00YJFU0P2YZJT0702ZZZX0[:b/0:j^[P2e]KD0^KVi0;Zj^P2k^k/0_Kfm0;no_`32`/80
`l?30<30`02l_;`0^[Zj0;:b/P2^[Zh0ZZZZ0:FUY@2QXJ40V9RH09>CT`2>SXh0RXZ:08F5Q@20P800
MgMg079bLP1]KFdN0?ooo`0k04a<C01:BTX0ADE504=3@`11@D40?Shn03`l?00i>CT0=3@d034a<@0^
;Rh0;2`/02TY:@0T92@08B4Q01hN7P0K6a/061PH018B4P0?3`l02`/;00P820061PH00`<300000001
0@4010@400P8200=3@d06ATI01hN7P0T92@0:BTY034a<@0i>CT0ADE504Y:BP1=CDd0Bd];04Q8B013
@d<0@41003hn?P0l?3`0>SXj03Hf=P0e=CD0<c<c038b<P0`<300;Rh^02TY:@0W9bL09BDU02<S8`0P
820071`L01/K6`0J6QX00`0I6AT0;P0J6QX06a/K01dM7@0Q8B409BDU02TY:@0];Bd0<S8b03Xj>P0o
?cl0B4Q804];B`1?Cdl0DU9B05IFEP1JFUX0HF5Q06EUI@1YJFT0Jf][06e]K@1aLG40M7Ad07MgM`1i
NGT0OGem0820P025QHD0QhN708J6QP24Q8@0Ph>30820P01mOGd0NWYj07MgM`1dM7@0KVi^06][J`1X
J6P0IFEU069RHP1OGel0FEUI05EEE@1BDU8R0?ooo`00803oool0;@2ATI40SXj>08V9R@26QXH0Q8B4
0861P@1oOgl0O7al07MgM`1dM7@0LW9b06m_K`1]KFd0J6QX06IVIP1SHf<0HF5Q05mOG`1JFUX0F5QH
05IFEP1DE5@0DE5A04m?C`1>CTh0Cdm?055AD@1EEED0F5QH065QH@1TI6@0JFUY06e]K@1dM7@0N7Qh
08>3P`29RHT0S8b<08^;R`2:RXX0QhN708J6QP25QHD0Q8B408>3P`020861P@0N0820P01oOgl0Ogmo
07inOP1oOgl0PH6108B4Q027QhL0RHV908n?S`2BTY80UYJF09RHV02KVi/0WYjN0:JVYP2[Zj/0[:b/
0:n_[`2c/k<0^[Zj0<30`036a/H0c<c<0<k>cP3GemL0fMWI0=[JfP3Lg=`0gmoO0P3Rh^801`3Ogml0
gMgM0=cLg03MgMd0h^;R0>GUi@3Vi^H00`3UiND04`3Ti>@0hn?S0=oOg`3Lg=`0fMWI0=7Ad@3=cLd0
b/[:0<K6aP32`/80^[Zj0;Jf]P2c/k<0[jn_0:^[Z`2WYjL0WinO09^KV`2GUiL07P3oool0=@1UIFD0
HV9R05]KF`1GEeL0E5AD051@D01=CDd0BTY:04=3@`0o?cl0>c/k03Ph>00e=CD0;Bd]02XZ:P0V9RH0
8b<S020P800H61P051@D014A4@0=3@d02PX:00H61P051@D01`L700/;2`0@41005QHF02@T900Z:RX0
<S8b03Ti>@14A4@0C4a<05aLG01TI6@0IVIV06=SH`1OGel0FEUI05MGE`1DE5@0DU9B051@D01=CDd0
C4a<04Y:BP19BDT0B4Q804M7A`16ATH0ADE500<0ATI60P18B4P05@1:BTX0Bd];04e=C@1>CTh0EEEE
05UIF@1LG5`0HF5Q06IVIP1^KVh0MGEe07emO@25QHD0RHV909FEU@2HV9P0Vi^K09nOW`2SXj<0Z:RX
0:b/[0020:f][@080:j^[P2`/;00]kNg0;^k^`2l_;`0_[jn0<30`032`/820<C4a00A0<30`02m_Kd0
^[Zj0;>c/`2^[Zh0ZZZZ0:FUY@2QXJ40V9RH09>CT`2>SXh0RXZ:08F5Q@20P800MgMg079bLP1]KFd0
7P3oool0?01=CDd0BTY:04E5A@13@d<0@D5103hn?P0k>c/0>CTi03<c<`0a<C40;Rh^02/[:`0X:2P0
8R8R020P800M7Ad06QXJ01LG5`0A4A403@d=00X:2P071`L01@D500410@0000000P8200H61P0;2`/0
3`l?01/K6`0R8R80:2PX02l_;`0i>CT0@41004e=C@1BDU80De=C04m?C`1;Bd/0A4A40492@P0o?cl0
?Shn03`l?00i>CT0=cLg03Hf=P0d=3@0<c<c038b<P0`<300;Bd]02/[:`0X:2P09RHV028R8P0P8200
7alO01hN7P807AdM01/07QhN020P800S8b<0:2PX02`/;00`<300=3@d03Xj>P10@400ADE504e=C@1@
D500De=C05MGE`1JFUX0GUiN06ATI01XJ6P0Jf][06e]K@1_Kfl0MGEe07MgM`1iNGT0O7al0820P023
Ph<00P27QhL04@26QXH0Q8B408>3P`20P800OGem07YjNP1gMgL0M7Ad06i^KP1[Jf/0J6QX06EUI@1R
HV80GemO05UIF@1FEUH0De=C0280oooo000P0?ooo`0U096AT@2>SXh0RHV908J6QP23Ph<0PH6107in
OP1lO7`0MWIf07AdM01aLG40Kfm_06a/K01WIfL0IFEU069RHP1PH600GUiN05UIF@1GEeL0E5AD059B
DP1@D500CDe=04i>CP1?Cdl0DU9B05EEE@1HF5P0H61P06EUI@1XJ6P0KFe]07=cL`1gMgL0Ogmo08>3
P`0308J6QP0508F5Q@24Q8@0Ph>308:2PP21PH400P1oOgl0101nOWh0OGem07alO01lO7`207]kN`0L
07emO@1oOgl0Ph>308Z:RP2=SHd0T92@09BDU02GUiL0VYZJ0:>SX`2YZJT0[:b/0:f][@2a/K40]kNg
0;fm_@35aLD0bl_;0<g=c@3Fe]H0f=SH0=WIf@3Lg=`0g]kN0>7Qh@3Shn<0hN7Q0=oOg`80gMgM00@0
hn?S0>KViP3WinL0inOW0P3Vi^H04`3UiND0hn?S0>3Ph03MgMd0fMWI0=;BdP3=cLd0b/[:0<K6aP32
`/80^[Zj0;Jf]P2c/k<0[jn_0:^[Z`2WYjL0WinO09^KV`2GUiL07P3oool05`1UIFD0HF5Q05]KF`1G
EeL0De=C051@D01<C4`0BDU90492@P0n?Sh0>SXj03Lg=`0c<c<0;2`/02TY:@0U9BD08B4Q01hN7P0F
5QH04a<C00l?3`0<30`020P800801@D500/020P800`<300B4Q8061PH02HV9P0^;Rh0=3@d03hn?P18
B4P0D51@061PH00206ATI00>065QH@1MGEd0F5QH05EEE@1CDe<0DE5A051@D01<C4`0Bd];04Y:BP19
BDT0B4Q804M7A`16ATH304E5A@0H04I6AP17AdL0B4Q804U9B@1;Bd/0C4a<04m?C`1EEED0FUYJ061P
H01TI6@0JFUY071`L01gMgL0P82008R8R02<S8`0UiNG09^KV`2MWId0XZ:R0:JVYP2ZZZX0[jn_0`2`
/;006P2a/K40^KVi0;fm_@2n_[h0`L710<?3``34a<@0alO70<G5a@31`L40_kno0;^k^`2c/k<0[jn_
0:ZZZP2UYJD0XJ6Q09RHV02CTi<0SXj>08Z:RP25QHD0P82007MgM`1bLW80KFe]7P3oool05`1<C4`0
BTY:04E5A@13@d<0@41003dm?@0k>c/0>3Ph03<c<`0`<300;Bd]02XZ:P0W9bL08B4Q01lO7`0L71`0
6ATI01HF5P0?3`l030`<00T92@061PH00`<300800@4101P010@400P8200=3@d04a<C020P800V9RH0
;Bd]03Hf=P10@400AdM705MGE`1JFUX0EUIF051@D01<C4`0ADE50492@P10@400?Shn03`l?00i>CT0
>3Ph03Lg=`0f=SH203De=@80<c<c02H0<C4a02h^;P0/;2`09bLW02HV9P0T92@08b<S028R8P0Q8B40
8b<S02DU9@0Y:BT0;Rh^038b<P0g=cL0>c/k0410@016ATH0Bd];059BDP1EEED0F5QH05aLG01OGel0
HV9R06QXJ01[Jf/0KVi^071`L01aLG40MgMg07UiN@1kNg/0Ogmo08:2PP24Q8@0RHV908R8R080QXJ6
00l0QHF50820P01mOGd0NWYj07MgM`1dM7@0KVi^06][J`1XJ6P0IFEU069RHP1OGel0F5QH05EEE@1B
DU808P3oool00200oooo02L0TI6A08j>SP28R8P0QHF508>3P`20P800OGem07YjNP1eMGD0LW9b06m_
K`1]KFd0JVYZ06EUI@1SHf<0H61P05iNGP1KFe/0EeMG05ADE01BDU80D51@04i>CP1=CDd0CTi>051@
D01BDU80EUIF05YJFP1QHF40I6AT06UYJ@1^KVh0LW9b07IfMP1kNg/0OGem07moO`20P8000`21PH42
0820P00907moO`1nOWh0OWin07emO@1kNg/0NWYj07UiN@1gMgL0MWIf0080MGEe01L0MWIf07]kN`20
P800Q8B408R8R02<S8`0TI6A09^KV`2RXZ80ZZZZ0:VYZ@2][Jd0[jn_0;Jf]P2m_Kd0aLG50<[:bP3A
dM40eMGE0=SHf03Kfm/0gmoO0>7Qh@020>GUi@080>CTi03Ph>00g]kN0>CTi03WinL0jNWY0>[ZjP3Y
jNT20>SXj00B0>GUi@3QhN40gMgM0=[JfP3Bd]80c/k>0<[:bP36a/H0`/;20;Zj^P2g]kL0/k>c0:n_
[`2[Zj/0YjNW09nOW`2KVi/0V9RH7P3oool0;P1UIFD0HF5Q05YJFP1FEUH0De=C04m?C`1;Bd/0AdM7
0410@00l?3`0>3Ph03@d=00a<C40:BTY02HV9P0R8R807QhN01/K6`0C4a<03`l?00`<300820P01@D5
00@410071`L02`/;010@400G5aL07QhN02d];@0d=3@0?Cdm04Q8B01@D500FEUI05mOG`1NGUh0GEeM
05]KF`1HF5P0E5AD059BDP1@D500Cdm?04e=C@1;Bd/204Y:BP80B4Q800<0AdM704I6AP15ADD00P15
ADD06014A4@0ATI604M7A`18B4P0BTY:04a<C01?Cdl0EeMG05iNGP1VIVH0JFUY06m_K`1eMGD0OGem
08F5Q@2=SHd0Ti>C09^KV`2OWil0XZ:R0:JVYP2ZZZX0[Jf]0;>c/`@0]KFe01T0_Kfm0<30`033`l<0
a/K60<O7a`38b<P0bLW90<O7a`34a<@0`<300;bl_02c/k<0[jn_0:ZZZP2VYZH0XJ6Q09RHV02CTi<0
SXj>08Z:RP25QHD0P82007MgM`1bLW80KFe]01h0oooo02d0CDe=04Y:BP15ADD0@T9203lo?`0m?Cd0
>SXj03Lg=`0a<C40;Rh^02/[:`0X:2P09RHV020P800M7Ad06QXJ01LG5`0D51@03@d=00X:2P071`L0
10@400410@00000010@400P8200=3@d04a<C01XJ6P0X:2P0<30`03Ti>@14A4@0C4a<05IFEP1IFET0
EUIF059BDP1>CTh0BTY:04=3@`10@400?Shn03dm?@0k>c/00`0h>3P203Lg=`D0>3Ph00D0=cLg03@d
=00a<C40;bl_02d];@0202`/;00K02h^;P0a<C40=CDe03Xj>P0n?Sh0ATI604Y:BP1?Cdl0E5AD05MG
E`1MGEd0GUiN061PH01RHV80I6AT06MWI`1/K6`0KVi^075aL@1dM7@0MWIf07]kN`1nOWh0PH6108B4
Q026QXH0R8R80080RXZ:0140RHV908N7Q`25QHD0P82007emO@1jNWX0MgMg07AdM01^KVh0Jf][06QX
J01UIFD0HV9R05mOG`1IFET0EEEE059BDP0R0?ooo`00803oool0:02ATI40SXj>08R8R025QHD0PX:2
07moO`1lO7`0NWYj07AdM01aLG40KVi^06a/K01YJFT0I6AT069RHP1OGel0GEeM05YJFP1FEUH0De=C
055AD@1?Cdl0CDe=04a<C01>CTh0D51@05=CD`1GEeL0Fe]K069RHP1UIFD0JVYZ06i^KP1aLG40MGEe
07UiN@1jNWX0O7al07inOP1oOgl40820P080Ogmo01<0OWin07emO@1kNg/0NWYj07UiN@1fMWH0MGEe
07AdM01cLg<0LW9b07AdM01hN7P0OGem0861P@26QXH0S8b<09RHV02OWil0ZJVY0080Zj^[00/0[Jf]
0;:b/P2i^KT0`/;20<S8b03@d=00e=CD0=OGe`3Jf]X0g]kN0>7Qh@030>KViP0K0>;RhP3Ogml0i>CT
0>OWi`3YjNT0jn_[0>c/k03Zj^X0j>SX0>GUi@3Rh^80g]kN0=[JfP3Bd]80c/k>0<[:bP36a/H0`/;2
0;^k^`2g]kL0/k>c0:n_[`2[Zj/0YjNW09nOW`2KVi/0UiNG01h0oooo01H0IFEU065QH@1JFUX0EUIF
059BDP1>CTh0BTY:04M7A`0o?cl0>c/k03Lg=`0d=3@0<30`02PX:00T92@08B4Q01dM7@0I6AT04A4A
00d=3@0:2PX01`L70P0410@02P0820P03@d=01<C4`0I6AT08B4Q034a<@0h>3P0@d=304a<C01EEED2
05aLG00:05]KF`1IFET0F5QH05IFEP1BDU80D51@04m?C`1>CTh0C4a<04];B`80BTY:00@0BDU904Q8
B018B4P0AdM70P16ATH304E5A@0G04I6AP18B4P0BTY:04a<C01?Cdl0FEUI05mOG`1XJ6P0KFe]071`
L01hN7P0P82008N7Q`2?Shl0Ti>C09^KV`2PX:00Y:BT0:NWY`2[Zj/0[jn_0;Fe]@2g]kL00P2h^;P0
6P2g]kL0_kno0<;2`P36a/H0b<S80<W9b@3:b/X0bl_;0<S8b034a<@0`L710;bl_02d];@0[jn_0:ZZ
ZP2VYZH0XJ6Q09RHV02CTi<0Shn?08Z:RP25QHD0P82007MgM`1bLW80KFe]7P3oool05P1<C4`0BTY:
04A4A012@T80?clo03`l?00i>CT0=SHf034a<@0^;Rh0:b/[02PX:00U9BD07alO01`L700I6AT05ADE
018B4P0;2`/020P800D51@030`<200410@0F00H61P0:2PX0410@01HF5P0N7Qh0;Bd]03Hf=P11@D40
Bd];05ADE01KFe/0F5QH05ADE01@D500C4a<04Q8B011@D40?Shn03`l?00k>c/0>CTi03Ph>080=cLg
00@0>3Ph03Ti>@0i>CT0>SXj100k>c/0=00i>CT0>3Ph03De=@0c<c<0<S8b034a<@0c<c<0=CDe03Xj
>P0n?Sh0@T9204e=C@1CDe<0EUIF05QHF01JFUX0GUiN061PH01SHf<0IFEU06MWI`1YJFT0KVi^071`
L01cLg<0MWIf07QhN01nOWh0PH6108B4Q025QHD0QhN708V9R@2<S8`0Rh^;08V9R@27QhL0QHF50820
P01mOGd0NWYj07MgM`1dM7@0KVi^06][J`1XJ6P0IFEU069RHP1OGel0F5QH05EEE@1BDU8R0?ooo`00
803oool0:02@T900SXj>08R8R025QHD0PX:207inOP1lO7`0NGUi07=cL`1`L700KFe]06][J`1XJ6P0
Hf=S061PH01NGUh0G5aL05UIF@1DE5@0DU9B051@D01>CTh0CDe=04];B`1?Cdl0DU9B05ADE01GEeL0
G5aL06=SH`1VIVH0Jf][06i^KP1aLG40Lg=c07MgM`1hN7P0NWYj07]kN`1mOGd307moO`0<0820P01o
Ogl0Ogmo07moO`1nOWh0O7al07]kN`1iNGT0MGEe07AdM01bLW80LG5a0P1`L700<`1aLG40MGEe07Yj
NP20P800QXJ609>CT`2LW9`0YZJV0:b/[02[Zj/0/;2`0;:b/P2g]kL0_[jn0<C4a03?cll0d];B0=OG
e`3Jf]X0g]kN0>;RhP3WinL0i^KV0>OWi`3UiND0hN7Q0>CTi03Xj>P0j^[Z0>_[j`3]kNd0k>c/0>SX
j03UiND0h^;R0=kNgP3Jf]X0dm?C0<o?c`3;bl/0alO70<;2`P2k^k/0]kNg0;>c/`2_[jl0Zj^[0:NW
Y`2OWil0Vi^K09NGU`0N0?ooo`0]06EUI@1QHF40FEUI05EEE@1ADE40CDe=04Y:BP16ATH0?Shn03Xj
>P0f=SH0<S8b02l_;`0W9bL08b<S01lO7`0L71`061PH010@400<30`02@T900H61P0410@00`<300X:
2P0?3`l05ADE01dM7@0U9BD0=CDe03hn?P19BDT0DE5A05UIF@1LG5`0FUYJ05QHF01FEUH0EEEE05=C
D`1@D500Cdm?04i>CP1=CDd0Bd];00<0BTY:0P19BDT00`18B4P0AdM704M7A`0204I6AP80ADE501L0
ATI604M7A`19BDT0C4a<04m?C`1IFET0H61P06YZJP1`L700LW9b07emO@21PH40RHV908n?S`2DU9@0
WIfM0:6QX@2UYJD0ZJVY0:b/[02a/K40]kNg0;Vi^@030;^k^`0I0<30`034a<@0alO70<W9b@3<c<`0
cLg=0<c<c038b<P0aLG50<71`@2m_Kd0];Bd0:n_[`2[Zj/0YZJV0:6QX@2HV9P0Ti>C08n?S`2:RXX0
QHF50820P01gMgL0LW9b06e]K@0N0?ooo`0F04e=C@1:BTX0A4A40492@P0o?cl0?3`l03Ti>@0f=SH0
<30`02d];@0Z:RX09bLW02DU9@0N7Qh06a/K01PH600D51@04A4A00/;2`071`L010@400820P800@41
01D01`L700`<300C4a<06QXJ02<S8`0c<c<0?Cdm04U9B@1CDe<0Fe]K05eMG@1FEUH0DU9B04i>CP1:
BTX0ATI603lo?`0m?Cd0>c/k03Ti>@0h>3P00P0f=SH203Lg=`0403Ph>00j>SX0?3`l03dm?@D0?Shn
00`0?3`l03Ti>@0h>3P0=cLg03Ph>00k>c/0?Shn0451@@16ATH0D51@05EEE@1JFUX205iNGP0T069R
HP1TI6@0IFEU06MWI`1YJFT0Jf][075aL@1cLg<0MGEe07MgM`1kNg/0PH6108>3P`26QXH0QhN708V9
R@2<S8`0SXj>08b<S02:RXX0QhN708F5Q@20P800OGem07YjNP1gMgL0M7Ad06i^KP1[Jf/0J6QX06EU
I@1RHV80GemO05UIF@1FEUH0DU9B8P3oool00200oooo01H0T92@08f=S@27QhL0Q8B40861P@1nOWh0
Ng]k07QhN01cLg<0L71`06e]K@1ZJVX0IfMW069RHP1OGel0GEeM05]KF`1HF5P0De=C051@D01?Cdl0
CDe=0P1<C4`04@1@D500De=C05IFEP1IFET0GEeM06ATI01XJ6P0K6a/06m_K`1`L700LG5a07AdM01f
MWH0MgMg07UiN@1jNWX0OGem0080OWin101oOgl0201nOWh0OGem07alO01iNGT0MGEe07=cL`1aLG40
L71`0`1^KVh05@1_Kfl0LW9b07QhN01oOgl0SXj>09RHV02SXj<0Zj^[0:j^[P2b/[80/k>c0;Ng]`2l
_;`0`/;20<k>cP3@d=00eMGE0=WIf@3MgMd0hN7Q0>KViP020>SXj00K0>OWi`3Ti>@0i>CT0>OWi`3Y
jNT0k>c/0>k^kP3]kNd0jNWY0>GUi@3Rh^80gmoO0=_Kf`3Cdm<0clo?0<_;b`37alL0`l?30;Zj^P2g
]kL0/k>c0:n_[`2[Zj/0YjNW09nOW`2KVi/0UiNG01h0oooo01H0IFEU065QH@1IFET0EEEE055AD@1=
CDd0BDU904E5A@0m?Cd0>CTi03De=@0a<C40;Rh^02HV9P0R8R807QhN01XJ6P0F5QH03Ph>00X:2P07
1`L01@D50P0410@04`0<30`04Q8B01TI6@0Q8B40:BTY03Xj>P14A4@0CTi>05MGE`1JFUX0FEUI05MG
E`1EEED0E5AD059BDP1@D500CTi>04e=C@1<C4`00P1;Bd/604Y:BP0404U9B@18B4P0AdM704M7A`<0
ATI601L0AdM704U9B@1;Bd/0Cdm?05UIF@1QHF40JVYZ079bLP1fMWH0P82008F5Q@2;Rh/0Shn?09BD
U02OWil0XZ:R0:JVYP2YZJT0[Jf]0;:b/P2i^KT0^k^k0;fm_@020;jn_P0I0<;2`P36a/H0bLW90<_;
b`3>c/h0clo?0<c<c039bLT0aLG50<71`@2m_Kd0];Bd0:n_[`2[Zj/0YZJV0::RXP2HV9P0Ti>C08n?
S`2:RXX0QHF50820P01gMgL0LW9b06e]K@0N0?ooo`0E04e=C@1:BTX0A4A40451@@0n?Sh0?3`l03Ti
>@0f=SH0<30`02d];@0Z:RX09bLW02@T900M7Ad06QXJ01HF5P0C4a<0410@00T92@061PH00`<300<0
0@4101H02@T900l?3`0F5QH07QhN02LW9`0i>CT0A4A404m?C`1JFUX0GEeM05]KF`1DE5@0D51@04a<
C018B4P0A4A403hn?P0l?3`0>SXj03Ph>00g=cL0=SHf0P0g=cL0100h>3P0>CTi03/k>`0n?Sh20410
@080@D510`12@T807@11@D40?clo03dm?@0m?Cd0?clo0492@P15ADD0BDU905=CD`1IFET0GUiN061P
H01RHV80IFEU06MWI`1YJFT0JVYZ06a/K01_Kfl0Lg=c07EeM@1gMgL0NWYj07inOP24Q8@0QhN708R8
R029RHT0Rh^;0080SHf=0180S8b<08Z:RP28R8P0QHF50820P01mOGd0NWYj07MgM`1dM7@0KVi^06][
J`1XJ6P0IFEU069RHP1OGel0FEUI05IFEP1BDU8R0?ooo`00803oool0:@2@T900SHf=08N7Q`24Q8@0
PH6107inOP1kNg/0MgMg075aL@1_Kfl0K6a/06UYJ@1VIVH0HF5Q05iNGP1LG5`0FEUI05MGE`1BDU80
Cdm?04i>CP1=CDd0Bd];04a<C01ADE40De=C05MGE`1KFe/0GUiN06EUI@1YJFT0K6a/06i^KP1_Kfl0
L71`079bLP1cLg<0MGEe07IfMP1hN7P0NWYj0080Ng]k0P1lO7`407emO@0N07alO01jNWX0MGEe079b
LP1`L700KVi^06a/K01[Jf/0K6a/06e]K@1^KVh0LW9b07UiN@2:RXX0U9BD0:2PX02YZJT0[jn_0;Bd
]02h^;P0^KVi0;bl_02o_kl0c<c<0=3@d03Cdm<0emOG0=cLg03Ph>00inOW0`3YjNT01@3Xj>P0iNGU
0>SXj03Zj^X0k>c/0080k^k^01<0jNWY0>KViP3Rh^80gmoO0=_Kf`3Cdm<0clo?0<_;b`37alL0`l?3
0;Zj^P2g]kL0/k>c0:n_[`2[Zj/0YjNW09nOW`2KVi/0UiNG01h0oooo02X0IFEU065QH@1IFET0EEEE
051@D01=CDd0BDU904A4A00l?3`0>CTi03De=@0`<300;2`/02@T900P820071`L01TI6@0E5AD03@d=
00T92@061PH01@D500@410051@D03`l?01DE5@0L71`09BDU02d];@10@400BTY:05ADE01IFET0F5QH
05MGE`1DE5@0DU9B055AD@1?Cdl0CTi>04e=C@1<C4`204];B`@0BTY:0`1;Bd/204Y:BP80B4Q80200
AdM704I6AP17AdL0AdM704Q8B01:BTX0CTi>05UIF@1QHF40JVYZ07=cL`1jNWX0PH6108R8R02<S8`0
TI6A09FEU@2PX:00Xj>S0:NWY`2ZZZX0[jn_0;>c/`2j^[X0_Kfm0;no_`30`<00`L710<C4a037alL0
b/[:0<g=c@80d=3@01<0cLg=0<[:bP35aLD0`/;20;fm_@2d];@0/;2`0:^[Z`2VYZH0XZ:R09RHV02D
U9@0Shn?08Z:RP25QHD0PH6107MgM`1bLW80KFe]01h0oooo01D0C4a<04U9B@14A4@0@D5103hn?P0k
>c/0>CTi03Hf=P0_;bl0;Bd]02TY:@0V9RH08b<S01`L700I6AT05QHF018B4P0?3`l020P800D51@03
0`<00P010@405P030`<030`<01<C4`0J6QX08b<S02`/;011@D40C4a<05QHF01NGUh0Fe]K05UIF@1C
De<0Cdm?04];B`17AdL0@d=303lo?`0m?Cd0?3`l03Xj>P0i>CT203Ph>00703Ti>@0j>SX0>c/k03dm
?@11@D40@T9204=3@`0204A4A0@0ADE50300A4A40492@P12@T80@d=304E5A@18B4P0C4a<05ADE01J
FUX0GUiN069RHP1VIVH0J6QX06YZJP1[Jf/0KFe]06m_K`1aLG40M7Ad07MgM`1iNGT0Ng]k07moO`25
QHD0QhN708V9R@2;Rh/0SHf=08j>SP2=SHd0S8b<08Z:RP28R8P0QXJ60820P01mOGd0NWYj07QhN01e
MGD0Kfm_06a/K01YJFT0IFEU069RHP1OGel0FEUI05EEE@1BDU8R0?ooo`00803oool04`2@T900SHf=
08J6QP23Ph<0P82007emO@1jNWX0MWIf071`L01]KFd0JVYZ06MWI`1TI6@0GUiN05]KF`1IFET0EUIF
05ADE01?Cdl00P1=CDd02P1<C4`0CDe=04i>CP1DE5@0F5QH05YJFP1NGUh0HF5Q06UYJ@1/K6`206e]
K@@0K6a/00H0KVi^06m_K`1`L700L71`075aL@1bLW8207=cL`0;07AdM01eMGD0MWIf07MgM`1hN7P0
NGUi07AdM01aLG40KVi^06][J`1YJFT00`1WIfL05P1XJ6P0JVYZ06a/K01mOGd0RHV909NGU`2TY:@0
[Zj^0;Jf]P2i^KT0`<300<71`@35aLD0bLW90<g=c@3AdM40eMGE0=[JfP3Ogml0j>SX0>[ZjP3/k>`2
0>g]k@040>WYj@3[jn/0kNg]0>o_k`80lO7a01<0j^[Z0>OWi`3Shn<0h>3P0=_Kf`3Cdm<0clo?0<_;
b`37alL0`l?30;^k^`2g]kL0/k>c0:n_[`2[Zj/0YjNW09nOW`2KVi/0UiNG01h0oooo01@0I6AT061P
H01HF5P0E5AD051@D01<C4`0AdM704=3@`0k>c/0=cLg038b<P0^;Rh0:RXZ028R8P0M7Ad06QXJ01DE
5@0A4A402@T900H61P<010@4010020P801DE5@0M7Ad092@T02h^;P0g=cL0Bd];05EEE@1IFET0EeMG
05EEE@1DE5@0D51@04e=C@1<C4`0Bd];0P1<C4`404];B`0;04Y:BP1;Bd/0C4a<04e=C@1>CTh0Cdm?
04i>CP1=CDd0Bd];04Y:BP19BDT00`18B4P05`19BDT0Bd];04e=C@1GEeL0H61P06UYJ@1cLg<0Ng]k
08J6QP2:RXX0T92@09>CT`2IVIT0X:2P0:FUY@2YZJT0[:b/0;2`/02e]KD0_Kfm0;no_`33`l<0aLG5
0080alO701P0b/[:0<g=c@3@d=00dm?C0=CDe03>c/h0b/[:0<K6aP33`l<0_[jn0;Fe]@2`/;00Zj^[
0:NWY`2RXZ80V9RH09BDU02?Shl0RXZ:08F5Q@21PH40MgMg079bLP1]KFdN0?ooo`0V04a<C019BDT0
@d=30451@@0n?Sh0>c/k03Ph>00e=CD0;Rh^02/[:`0X:2P09BDU024Q8@0K6a/05aLG01@D500A4A40
3@d=00H61P030`<00@41000000010@401@D5018B4P0J6QX08b<S02d];@0g=cL0CTi>05YJFP1NGUh0
Fe]K05YJFP1HF5P0DU9B04e=C@1:BTX304U9B@0404I6AP15ADD0A4A404A4A080@T920`13@d<00`14
A4@0AdM704U9B@0204Y:BP<0Bd];0P1<C4`03P1=CDd0CTi>04a<C01<C4`0CDe=04i>CP1?Cdl0F5QH
05]KF`1NGUh0HF5Q06EUI@1]KFd0Kfm_0P1`L700801bLW80MGEe07MgM`1iNGT0O7al07inOP21PH40
QXJ608R8R02:RXX0SHf=08n?S`2ATI40Shn?08f=S@2;Rh/0RHV908J6QP20P800OWin07]kN`1hN7P0
MGEe06m_K`1/K6`0JFUY06EUI@1RHV80GemO05UIF@1FEUH0DU9B8P3oool00200oooo01<0T92@08f=
S@26QXH0Ph>307moO`1lO7`0NGUi07IfMP1_Kfl0K6a/06UYJ@1VIVH0Hf=S05eMG@1JFUX0F5QH05EE
E@1BDU80CTi>00<0CDe=00X0CTi>04m?C`1GEeL0FUYJ05eMG@1PH600IFEU06][J`1^KVh0K6a/0P1[
Jf/0201ZJVX0J6QX06MWI`1YJFT0JVYZ06a/K01_Kfl0KVi^0P1_Kfl0301`L700LG5a079bLP1cLg<0
LW9b07=cL`1eMGD0LW9b06m_K`1/K6`0JFUY06MWI`<0IFEU01H0IVIV06QXJ01ZJVX0MGEe08>3P`2A
TI40X:2P0:ZZZP2i^KT0^k^k0<71`@34a<@0alO70<_;b`3<c<`0dM7A0=GEe@3IfMT0g]kN0>SXj03[
jn/0kNg]0P3_knl0103Zj^X0jn_[0>k^kP3`l?020?;blP0C0>_[j`3WinL0hn?S0>3Ph03Lg=`0dm?C
0<o?c`3;bl/0alO70<?3``2k^k/0]kNg0;>c/`2_[jl0Zj^[0:NWY`2OWil0Vi^K09NGU`0N0?ooo`0D
06ATI01PH600F5QH05=CD`1?Cdl0Bd];04M7A`12@T80>SXj03Hf=P0a<C40;Bd]02TY:@0P820071`L
01PH600D51@0410@00L71`051@D200<30`0>00H61P0;2`/06ATI024Q8@0Y:BT0<S8b03`l?01ADE40
F5QH05MGE`1FEUH0E5AD05=CD`1>CTh204];B`<0C4a<0`1;Bd/00`1:BTX0Bd];04a<C00204i>CP08
04m?C`1@D500D51@04m?C`1=CDd0Bd];04Y:BP18B4P204U9B@0G04Y:BP1<C4`0CTi>05IFEP1NGUh0
IfMW07=cL`1kNg/0QhN708^;R`2ATI40UIFE09ZJVP2SXj<0YJFU0:VYZ@2/[:`0/K6a0;Fe]@2n_[h0
`L710<C4a037alL00P39bLT0603<c<`0clo?0=;BdP3De=@0eMGE0<o?c`3;bl/0alO70<?3``2n_[h0
]KFe0;2`/02/[:`0YjNW0::RXP2IVIT0U9BD08n?S`2:RXX0QHF50861P@1gMgL0LW9b06e]KAh0oooo
01@0C4a<04U9B@13@d<0@41003dm?@0j>SX0=cLg03@d=00^;Rh0:b/[02PX:00T92@08B4Q01XJ6P0G
5aL04a<C010@400<30`010@400410@80000000P00P8200L71`0E5AD07QhN02PX:00b<S80?Cdm05EE
E@<0G5aL00@0FUYJ05QHF01CDe<0D51@0P1>CTh02@1=CDd0BDU904U9B@19BDT0AdM704E5A@16ATH0
AdM704Q8B00304U9B@0304a<C01=CDd0CDe=00@0CTi>0P1?Cdl0401@D500DE5A055AD@1ADE40D51@
055AD@1CDe<0EeMG05YJFP1NGUh0HF5Q06EUI@1]KFd0L71`075aL@1cLg<207EeM@0N07UiN@1kNg/0
OGem07moO`22PX80QhN708Z:RP2=SHd0Shn?092@T02BTY80Shn?08f=S@2;Rh/0RHV908J6QP21PH40
OWin07]kN`1hN7P0MGEe06m_K`1/K6`0JFUY06IVIP1SHf<0GemO05UIF@1FEUH0DU9B8P3oool00200
oooo01<0T92@08f=S@26QXH0PX:207moO`1lO7`0N7Qh07EeM@1^KVh0Jf][06QXJ01UIFD0HV9R05]K
F`1IFET0EUIF05ADE01ADE40C4a<0080Bd];00P0C4a<04i>CP1ADE40F5QH05]KF`1OGel0Hf=S06IV
IP80KFe]00X0K6a/06][J`1YJFT0J6QX06EUI@1SHf<0I6AT06IVIP1WIfL0J6QX0P1YJFT03@1XJ6P0
JFUY06][J`1/K6`0KVi^06m_K`1^KVh0Kfm_075aL@1^KVh0JVYZ06QXJ01VIVH00P1SHf<05`1TI6@0
IFEU06IVIP1XJ6P0LG5a07alO02;Rh/0Vi^K0:RXZ02j^[X0_Kfm0<71`@38b<P0b/[:0=7Ad@3?cll0
d=3@0=CDe03IfMT0g]kN0>SXj03[jn/0k^k^0080lO7a0P3/k>`05`3^k^h0l?3`0?;blP3clo<0jn_[
0>SXj03Ti>@0h>3P0=cLg03Cdm<0clo?0<_;b`37alL0`l?30;^k^`2g]kL0/k>c0:n_[`2[Zj/0YjNW
09nOW`2KVi/0UiNG01h0oooo02@0I6AT061PH01HF5P0De=C04m?C`1;Bd/0ATI60492@P0i>CT0=CDe
030`<00/;2`0:2PX01lO7`0K6a/05aLG018B4P0>3Ph01PH600@410030`<010@400P8200=3@d07AdM
02DU9@0^;Rh0>3Ph04=3@`1GEeL0F5QH05MGE`1EEED0E5AD059BDP1=CDd204];B`0304a<C01=CDd0
C4a<0080C4a<0P1;Bd/02`1=CDd0CTi>04m?C`1?Cdl0D51@055AD@1BDU80D51@04i>CP1<C4`0Bd];
0080BDU901d0BTY:04];B`1<C4`0CTi>05EEE@1LG5`0IFEU075aL@1kNg/0RHV908f=S@2ATI40UiNG
09ZJVP2UYJD0YjNW0:VYZ@2^[Zh0/K6a0;Jf]P2o_kl0`/;20<G5a@39bLT0bl_;0<c<c03=cLd0dM7A
0=?Cd`020=KFeP0C0<o?c`3;bl/0alO70<?3``2o_kl0]KFe0;2`/02/[:`0YjNW0::RXP2IVIT0U9BD
08n?S`2:RXX0QHF50820P01gMgL0LW9b06e]K@0N0?ooo`0O04a<C019BDT0@d=30410@00m?Cd0>SXj
03Lg=`0d=3@0;Rh^02/[:`0X:2P092@T024Q8@0J6QX05QHF01<C4`0?3`l02`/;00@410010@400000
00820P051@D02PX:01XJ6P0S8b<0;Bd]03Ph>014A4@0Fe]K05iNGP0205aLG00305]KF`1IFET0EEEE
0080De=C0P1BDU80101ADE40D51@04m?C`1?Cdl204i>CP0304m?C`1>CTh0Cdm?00<0D51@1`1ADE40
101BDU80De=C05=CD`1DE5@205=CD`80EEEE02T0F5QH05aLG01MGEd0H61P06=SH`1[Jf/0L71`07=c
L`1eMGD0MWIf07MgM`1kNg/0O7al07inOP21PH40Q8B408V9R@2<S8`0Shn?092@T02BTY80Ti>C08n?
S`2=SHd0S8b<08V9R@27QhL0PH6107inOP1kNg/0N7Qh07EeM@1_Kfl0K6a/06UYJ@1VIVH0HV9R05mO
G`1IFET0EUIF059BDP0R0?ooo`00803oool04`2@T900SHf=08J6QP22PX80OWin07]kN`1gMgL0M7Ad
06e]K@1ZJVX0IVIV06=SH`1PH600FUYJ05MGE`1EEED0DU9B051@D01;Bd/00P1:BTX03`1=CDd0Cdm?
059BDP1JFUX0GUiN065QH@1UIFD0JFUY06i^KP1]KFd0K6a/06YZJP1XJ6P0IVIV061PH00205aLG003
05eMG@1NGUh0GemO0080H61P0P1OGel0:01QHF40Hf=S06ATI01UIFD0I6AT06EUI@1XJ6P0JFUY06MW
I`1UIFD0I6AT069RHP1QHF40HV9R06=SH`1UIFD0IVIV06i^KP1fMWH0QHF509JFUP2UYJD0^KVi0;no
_`31`L40b<S80<g=c@3Fe]H0eMGE0=?Cd`3De=@0fMWI0=gMg@3WinL0jn_[0>k^kP3bl_80lo?c0?3`
l03^k^h20?7al@0E0??cl`3bl_80k>c/0>SXj03Ti>@0h>3P0=cLg03Cdm<0clo?0<_;b`37alL0`l?3
0;^k^`2g]kL0/k>c0:n_[`2[Zj/0YjNW09nOW`2KVi/0UiNG01h0oooo01<0I6AT061PH01GEeL0De=C
04i>CP1:BTX0ATI60451@@0h>3P0=3@d030`<00[:b/09bLW01hN7P0I6AT05ADE014A4@0<30`01@D5
00800`<300T01PH600X:2P0@41008B4Q02XZ:P0d=3@0?Shn04U9B@1HF5P00P1GEeL0101EEED0E5AD
059BDP1?Cdl204a<C0D0CTi>0P1=CDd00`1?Cdl0D51@055AD@0405=CD`04055AD@1?Cdl0CDe=04];
B`<0BTY:01P0Bd];04e=C@1>CTh0E5AD05YJFP1TI6@0Kfm_07YjNP29RHT0SXj>096AT@2GUiL0W9bL
0:NWY`2YZJT0Zj^[0:f][@2b/[80]kNg0<30`033`l<0alO70<_;b`3=cLd20<o?c`0G0=;BdP3De=@0
emOG0=OGe`3?cll0c<c<0<S8b034a<@0_kno0;Fe]@2a/K40[:b/0:NWY`2RXZ80VIVI09BDU02?Shl0
RXZ:08F5Q@21PH40MgMg079bLP1]KFd07P3oool04`1<C4`0BDU904=3@`10@400?Cdm03Xj>P0g=cL0
=3@d02h^;P0[:b/09bLW02@T900Q8B406ATI01HF5P0B4Q803Ph>00X:2P030`<00P010@402@030`<0
1`L700d=3@0O7al0:2PX03<c<`0o?cl0BTY:05eMG@0405aLG00705]KF`1MGEd0GEeM05eMG@1NGUh0
GEeM05aLG00205]KF`80FUYJ00@0G5aL05]KF`1LG5`0GEeM0P1NGUh0101KFe/0EeMG05EEE@1DE5@2
05=CD`<0E5AD0P1EEED00`1FEUH0EeMG05MGE`0205MGE`0D05YJFP1KFe/0GUiN061PH01RHV80JFUY
06i^KP1bLW80MGEe07MgM`1iNGT0O7al07inOP20P800Ph>308F5Q@2:RXX0S8b<08n?S`2ATI4209BD
U00C092@T02>SXh0S8b<08Z:RP27QhL0PH6107moO`1lO7`0NGUi07EeM@1_Kfl0K6a/06UYJ@1VIVH0
HV9R05mOG`1IFET0EUIF059BDP0R0?ooo`00803oool09P2@T900S8b<08F5Q@21PH40OWin07YjNP1g
MgL0Lg=c06a/K01YJFT0IFEU069RHP1OGel0F5QH05IFEP1CDe<0D51@04i>CP1:BTX0BDU904Y:BP1=
CDd0D51@05=CD`1LG5`0H61P06EUI@1YJFT0KFe]06m_K`1^KVh0K6a/06YZJP1WIfL0IFEU05mOG`1K
Fe/0F5QH0P1GEeL205QHF0<0FEUI00@0Fe]K05aLG01NGUh0HF5Q0P1RHV80>@1TI6@0IFEU06ATI01S
Hf<0HV9R065QH@1PH600HF5Q069RHP1TI6@0IVIV06a/K01cLg<0Ogmo08n?S`2PX:00]kNg0;no_`33
`l<0alO70<o?c`3IfMT0f][J0=WIf@3Fe]H0fMWI0=gMg@3WinL0jn_[0>o_k`3clo<0m?Cd0?;blP3`
l?00l_;b0??cl`3fm_H0lo?c0>c/k03Xj>P0i>CT0>3Ph03Kfm/0dm?C0<o?c`3;bl/0alO70<;2`P2k
^k/0]kNg0;>c/`2_[jl0Zj^[0:NWY`2OWil0Vi^K09NGU`0N0?ooo`0M06ATI01PH600EeMG059BDP1>
CTh0BTY:04E5A@11@D40>3Ph03<c<`0_;bl0:RXZ02HV9P0L71`061PH01<C4`0?3`l02`/;00@41002
0P800`<300L71`0=3@d051@D02DU9@0_;bl0>CTi04A4A01>CTh00P1HF5P01@1GEeL0EEEE05ADE01B
DU80D51@0080CTi>1@1?Cdl01@1>CTh0Cdm?051@D01ADE40DU9B00<0De=C0200DU9B055AD@1?Cdl0
CDe=04a<C01;Bd/0BTY:04];B`1<C4`0CDe=04m?C`1DE5@0FEUI069RHP1]KFd0NGUi08V9R@2>SXh0
TY:B09JFUP2NWYh0ZJVY0:b/[02^[Zh0[jn_0;Bd]02g]kL0`<300<C4a038b<P0cLg=0<k>cP80dM7A
01L0e=CD0=KFeP3IfMT0emOG0=3@d03<c<`0bLW90<C4a02o_kl0][Jf0;6a/@2/[:`0YjNW0::RXP2I
VIT0U9BD08n?S`2:RXX0QHF50861P@1gMgL0LW9b06e]K@0N0?ooo`0N04a<C019BDT0@d=30410@00m
?Cd0>c/k03Lg=`0d=3@0;Rh^02/[:`0W9bL092@T020P800I6AT05ADE014A4@0=3@d02@T900<30`01
0@400P8200D51@0;2`/04Q8B02<S8`0];Bd0>3Ph04=3@`1?Cdl0Fe]K0`1LG5`205eMG@0305mOG`1Q
HF40I6AT0080IVIV00@0IFEU06ATI01SHf<0Hf=S0`1TI6@206=SH`06065QH@1PH600GEeM05YJFP1H
F5P0EeMG0P1FEUH01P1EEED0EUIF05IFEP1FEUH0EeMG05QHF080FEUI01H0FUYJ05]KF`1KFe/0G5aL
05eMG@1OGel0HV9R06QXJ01/K6`0LG5a07EeM@1iNGT0Ng]k07emO@1oOgl0PX:208B4Q025QHD0Rh^;
08f=S@2@T900TI6A0P2DU9@04`2ATI40Shn?08f=S@2;Rh/0R8R808:2PP1oOgl0O7al07UiN@1fMWH0
Kfm_06a/K01YJFT0IVIV06=SH`1PH600FEUI05IFEP1BDU808P3oool00200oooo02P0T92@08b<S024
Q8@0PH6107emO@1iNGT0MGEe079bLP1ZJVX0IVIV06=SH`1OGel0G5aL05EEE@1BDU80Cdm?04a<C019
BDT0AdM704Q8B01:BTX0CDe=055AD@1FEUH0H61P06EUI@1ZJVX0L71`07IfMP1aLG40Kfm_06a/K01Z
JVX0IfMW06EUI@1PH600GUiN05aLG01KFe/0FUYJ0P1IFET01`1JFUX0Fe]K05]KF`1MGEd0GUiN05mO
G`1PH6000`1QHF401@1PH600GemO05mOG`1NGUh0GEeM0080GUiN0140GemO065QH@1SHf<0JFUY06i^
KP1gMgL0QHF509NGU`2a/K40^[Zj0<;2`P37alL0cLg=0=_Kf`3Ph>00hN7Q0>3Ph0020=oOg`060>KV
iP3Zj^X0kno_0?;blP3fm_H0moOg0P3dm?@05P3emOD0moOg0?Cdm03/k>`0jNWY0>CTi03Ph>00fm_K
0=?Cd`3?cll0b/[:0<K6aP32`/80^[Zj0;Jf]P2b/[80[jn_0:^[Z`2WYjL0WinO09^KV`2GUiLN0?oo
o`0B06ATI01PH600EUIF059BDP1=CDd0BDU904A4A010@400=SHf038b<P0];Bd0:2PX02<S8`0J6QX0
5ADE010@400<30`01`L70P020P8020061PH030`<01<C4`0L71`0;bl_03Ti>@13@d<0CTi>0`1IFET0
1P1HF5P0EUIF05EEE@1DE5@0DE5A051@D080Cdm?00<0CTi>04e=C@1<C4`00`1=CDd00`1?Cdl0D51@
055AD@03059BDP05055AD@1?Cdl0CTi>04e=C@1<C4`00`1;Bd/0<@1<C4`0CDe=04m?C`1DE5@0F5QH
05iNGP1YJFT0M7Ad08N7Q`2=SHd0Ti>C09RHV02NWYh0ZZZZ0;2`/02c/k<0]KFe0;Jf]P2j^[X0`/;2
0<K6aP3;bl/0clo?0=?Cd`3Fe]H0eMGE0=OGe`3IfMT0g=cL0=WIf@3AdM40c/k>0<W9b@35aLD0`<30
0;Jf]P2a/K40[:b/0:NWY`2RXZ80VIVI09BDU02?Shl0RXZ:08F5Q@21PH40MgMg079bLP1]KFd07P3o
ool0801<C4`0BDU904=3@`10@400?Cdm03Xj>P0g=cL0=3@d02h^;P0Z:RX09bLW02@T900P820061PH
01DE5@0A4A403@d=00T92@030`<00P8200H61P0<30`04a<C01XJ6P0];Bd0=cLg0451@@1;Bd/0EUIF
05]KF`1LG5`0GEeM0P1NGUh00`1OGel0H61P065QH@02065QH@03069RHP1QHF40H61P00@0GemO0P1P
H603065QH@0305mOG`1NGUh0GEeM0080Fe]K00@0FUYJ05UIF@1IFET0FEUI0P1JFUX205]KF`0305eM
G@1NGUh0GEeM0080GUiN02L0GemO065QH@1UIFD0JFUY06a/K01`L700M7Ad07MgM`1kNg/0PH6108>3
P`25QHD0QhN708Z:RP2>SXh0T92@09:BTP2EUID0UYJF09FEU@2BTY80T92@08j>SP2;Rh/0RHV908>3
P`1oOgl0O7al07YjNP1fMWH0L71`06e]K@1YJFT0IVIV06=SH`1OGel0FEUI05IFEP1CDe<08P3oool0
0200oooo02P0Shn?08b<S024Q8@0P82007alO01hN7P0M7Ad075aL@1YJFT0IFEU065QH@1NGUh0FUYJ
05=CD`1@D500CDe=04Y:BP18B4P0ADE504M7A`1:BTX0CTi>059BDP1GEeL0HV9R06QXJ01]KFd0LW9b
07UiN@1bLW80L71`06e]K@1ZJVX0J6QX06EUI@1QHF40GemO05eMG@1LG5`0Fe]K0P1JFUX01P1KFe/0
G5aL05aLG01NGUh0GemO061PH0<0HF5Q00<0H61P05mOG`1MGEd0101LG5`0401MGEd0GUiN061PH01R
HV80JFUY06e]K@1eMGD0PX:2096AT@2][Jd0]kNg0;no_`36a/H0c<c<0=_Kf`3Rh^820>CTi0080>;R
hP3QhN40inOW0>[ZjP3`l?00l_;b0?KfmP3hn?P20?Gem@80m_Kf01@0m?Cd0>c/k03Xj>P0i>CT0=oO
g`3Kfm/0d];B0<k>cP3:b/X0a/K60<;2`P2j^[X0][Jf0;:b/P2_[jl0ZZZZ0:NWY`2OWil0Vi^K09NG
Uah0oooo01d0I6AT05mOG`1FEUH0DU9B04e=C@18B4P0@d=303lo?`0e=CD0<C4a02`/;00W9bL08R8R
01PH600D51@03`l?00X:2P051@D00@4100@4100820P03`l?01LG5`0O7al0<c<c03hn?P18B4P0DU9B
05aLG00205YJFP0705QHF01GEeL0EUIF05ADE01BDU80D51@04m?C`0204i>CPD0C4a<00@0Cdm?051@
D01@D500DE5A0P1BDU801@1ADE40D51@04i>CP1=CDd0C4a<0080Bd];0P1<C4`05`1=CDd0Cdm?05AD
E01GEeL0GEeM06IVIP1aLG40QXJ608f=S@2CTi<0VIVI09jNWP2[Zj/0/K6a0;Fe]@2h^;P0^[Zj0;bl
_033`l<0a/K60<c<c03@d=00eMGE0080f=SH01L0fMWI0=cLg03Lg=`0f][J0=;BdP3?cll0b/[:0<G5
a@30`<00][Jf0;6a/@2/[:`0YjNW0:>SX`2IVIT0U9BD08n?S`2:RXX0QHF50861P@1gMgL0LW9b06e]
K@0N0?ooo`0O04a<C019BDT0A4A40451@@0n?Sh0>c/k03Lg=`0d=3@0;Rh^02XZ:P0W9bL092@T020P
800I6AT05ADE014A4@0<30`020P800@410061PH02PX:010@400G5aL07alO034a<@0k>c/0ADE504m?
C`1GEeL0G5aL05eMG@0205iNGP80GemO1@1PH6000`1OGel0GUiN05eMG@0205eMG@0305iNGP1OGel0
GemO0080H61P00H0HF5Q061PH01OGel0GemO05iNGP1MGEd705]KF`0]05aLG01MGEd0GUiN05mOG`1P
H600HF5Q069RHP1TI6@0IVIV06UYJ@1]KFd0L71`07=cL`1iNGT0OGem08:2PP24Q8@0QhN708Z:RP2=
SHd0T92@09:BTP2DU9@0UiNG09RHV02GUiL0U9BD09:BTP2?Shl0S8b<08V9R@23Ph<0P82007emO@1j
NWX0MgMg071`L01]KFd0JFUY06IVIP1SHf<0H61P05UIF@1FEUH0DU9B0280oooo000P0?ooo`0A08n?
S`2;Rh/0Ph>307moO`1kNg/0MgMg07AdM01`L700J6QX06ATI01PH600G5aL05UIF@1BDU80CTi>04Y:
BP17AdL00P15ADD05@17AdL0Bd];04i>CP1CDe<0F5QH06=SH`1ZJVX0Kfm_07EeM@1iNGT0Lg=c071`
L01]KFd0Jf][06QXJ01VIVH0HF5Q061PH01NGUh0G5aL05]KF`0205YJFP0505]KF`1LG5`0GEeM05mO
G`1PH600101QHF401P1OGel0GUiN05eMG@1LG5`0Fe]K05YJFP80Fe]K00l0G5aL05iNGP1PH600IfMW
06a/K01bLW80OGem08f=S@2[Zj/0]KFe0;jn_P35aLD0c<c<0=[JfP3Rh^800`3Vi^H07`3UiND0inOW
0>[ZjP3`l?00m?Cd0?Ogm`3inOT0moOg0?Gem@3gmoL0mOGe0?Cdm03/k>`0j>SX0>CTi03Ogml0fm_K
0=;BdP3>c/h0b/[:0<K6aP32`/80^[Zj0;Jf]P2b/[80[Zj^0:ZZZP2WYjL0WinO09^KV`2GUiL07P3o
ool0:01TI6@0GemO05IFEP1ADE40CDe=04Q8B013@d<0?Shn03De=@0`<300:b/[02HV9P0Q8B405aLG
018B4P0=3@d020P800@410020P801@D500/;2`0B4Q806QXJ02<S8`0g=cL0@T9204a<C01GEeL0GemO
05]KF`1JFUX0FEUI05MGE`1FEUH0EEEE059BDP1ADE40Cdm?04i>CP1=CDd304];B`80C4a<00@0CTi>
051@D01ADE40DE5A0P1BDU801@1ADE40D51@04i>CP1=CDd0C4a<0080Bd];0P1<C4`0<01>CTh0Cdm?
05ADE01GEeL0G5aL06ATI01`L700QHF508b<S02CTi<0VIVI09nOW`2/[:`0/[:b0;Rh^02k^k/0_;bl
0;jn_P34a<@0b<S80<k>cP3Bd]80e]KF0=_Kf`3Jf]X0fm_K0=kNgP3Lg=`0fm_K0=?Cd`3?cll0b/[:
0<G5a@30`<00][Jf0;6a/@2/[:`0Z:RX0:>SX`2IVIT0U9BD08n?S`2:RXX0QXJ60861P@1gMgL0LW9b
06e]KAh0oooo01h0C4a<04U9B@14A4@0@D5103hn?P0j>SX0=cLg03@d=00];Bd0:RXZ02LW9`0S8b<0
820P01PH600E5AD04A4A00`<300820P01@D500P8200=3@d051@D01/K6`0T92@0=cLg0410@019BDT0
E5AD05]KF`1MGEd205iNGP80GemO1@1PH6000`1OGel0GUiN05eMG@0305aLG00405eMG@1NGUh0GemO
05mOG`80H61P00<0HF5Q061PH01OGel00P1NGUh305eMG@0305aLG01MGEd0GEeM0080GEeM02`0GUiN
05mOG`1PH600HF5Q069RHP1SHf<0IFEU06MWI`1/K6`0KVi^079bLP1gMgL0NGUi07emO@24Q8@0QXJ6
08V9R@2;Rh/0SXj>09>CT`2EUID0UiNG09ZJVP2HV9P0UiNG09FEU@2CTi<0T92@08f=S@2:RXX0Ph>3
0820P01mOGd0NWYj07MgM`1`L700KFe]06YZJP1WIfL0Hf=S061PH01IFET0EUIF059BDR80oooo000P
0?ooo`0Y08n?S`2;Rh/0Ph>307moO`1kNg/0MgMg07=cL`1_Kfl0IfMW06=SH`1OGel0Fe]K05MGE`1?
Cdl0C4a<04Q8B015ADD0@T9204A4A017AdL0Bd];051@D01DE5@0FUYJ06IVIP1[Jf/0LG5a07UiN@1h
N7P0Lg=c071`L01^KVh0Jf][06QXJ01VIVH0HV9R061PH01NGUh0G5aL05]KF`1IFET00P1HF5P01P1J
FUX0G5aL05mOG`1PH600HF5Q069RHP80HF5Q00<0GemO05eMG@1LG5`00P1JFUX205UIF@0A05YJFP1K
Fe/0GEeM05mOG`1UIFD0JVYZ071`L01jNWX0RHV90:RXZ02c/k<0_Kfm0<?3``3;bl/0f=SH0=oOg`3X
j>P00P3YjNT07`3WinL0j>SX0>[ZjP3_knl0m?Cd0?Shn03kno/0n?Sh0?KfmP3gmoL0mOGe0?Cdm03]
kNd0j>SX0>?Sh`3Ogml0f][J0=;BdP3>c/h0b/[:0<K6aP32`/80^[Zj0;Jf]P2b/[80[Zj^0:ZZZP2V
YZH0WinO09^KV`2GUiL07P3oool0:01TI6@0GemO05IFEP1ADE40C4a<04M7A`12@T80?Shn03@d=00_
;bl0:RXZ02DU9@0P82005QHF014A4@0<30`01`L700820P030`<01`L700h>3P0F5QH07QhN02LW9`0l
?3`0ATI6051@D01LG5`0GemO05aLG01KFe/0FUYJ05QHF01FEUH0EEEE059BDP1ADE40Cdm?04i>CP1=
CDd204];B`0604Y:BP1;Bd/0C4a<04m?C`1@D500DE5A0`1BDU800`1ADE40D51@04i>CP0204e=C@80
Bd];0P1<C4`05`1>CTh0Cdm?05=CD`1GEeL0G5aL06=SH`1]KFd0Ph>308^;R`2CTi<0VIVI0:2PX02/
[:`0/[:b0;^k^`2l_;`0_kno0<;2`P36a/H0bLW90<k>cP3Cdm<0emOG00<0gMgM01H0gmoO0=gMg@3K
fm/0e=CD0<o?c`3:b/X0aLG50<30`02f][H0/K6a0:b/[02XZ:P0Xj>S09VIV@2DU9@0Shn?08Z:RP26
QXH0PH6107MgM`1bLW80KFe]7P3oool07P1<C4`0BDU904A4A011@D40?Shn03Xj>P0g=cL0=3@d02h^
;P0Z:RX09bLW02<S8`0P82006ATI01DE5@0A4A403@d=00T92@071`L02`/;010@400G5aL07alO02PX
:00j>SX0A4A404e=C@1HF5P0GEeM05iNGP<0GemO101PH60205mOG`<0GUiN0P1MGEd01P1LG5`0GEeM
05iNGP1NGUh0GemO061PH0<0HF5Q0`1PH60205mOG`D0GUiN02d0GemO061PH01PH600H61P069RHP1S
Hf<0IFEU06MWI`1ZJVX0Kfm_075aL@1dM7@0MWIf07YjNP1oOgl0QHF508R8R02;Rh/0SHf=08n?S`2E
UID0UiNG09ZJVP2KVi/0VIVI09RHV02EUID0Ti>C092@T02=SHd0RXZ:08B4Q021PH40OWin07YjNP1g
MgL0LG5a06e]K@1ZJVX0IfMW06=SH`1PH600FEUI05IFEP1BDU808P3oool00200oooo02H0Shn?08^;
R`23Ph<0OWin07YjNP1fMWH0LW9b06i^KP1VIVH0HV9R05iNGP1JFUX0EUIF04i>CP1:BTX0ATI60492
@P10@400@d=304M7A`1;Bd/0D51@05IFEP1KFe/0IfMW06e]K@1dM7@0O7al07QhN01cLg<0LG5a06i^
KP1[Jf/0JFUY06IVIP1RHV80H61P05iNGP80G5aL00T0F5QH05IFEP1FEUH0EeMG05]KF`1NGUh0GemO
065QH@1RHV800P1QHF401@1NGUh0GEeM05]KF`1JFUX0FEUI0080F5QH0140FEUI05YJFP1KFe/0GEeM
06=SH`1XJ6P0KVi^07IfMP23Ph<0Y:BT0;2`/02j^[X0`/;20<[:bP3Fe]H0g]kN0>KViP030>[ZjP0N
0>SXj03[jn/0kno_0?Gem@3hn?P0o?cl0?[jnP3hn?P0m_Kf0?Ogm`3clo<0k>c/0>OWi`3Shn<0g]kN
0=[JfP3AdM40c/k>0<W9b@35aLD0`L710;Vi^@2f][H0/[:b0:j^[P2ZZZX0YZJV09nOW`2KVi/0UiNG
7P3oool06`1TI6@0GemO05EEE@1ADE40C4a<04M7A`12@T80?Cdm03<c<`0^;Rh0:BTY02@T900O7al0
5ADE010@400;2`/01@D500410@0410@02PX:014A4@0I6AT08R8R02/[:`10@400BDU905ADE002061P
H00:05eMG@1LG5`0FUYJ05UIF@1GEeL0EEEE059BDP1ADE40Cdm?04e=C@80C4a<00@0Bd];04Y:BP1:
BTX0Bd];0P1?Cdl01`1ADE40DU9B05=CD`1CDe<0DE5A051@D01?Cdl00P1=CDd304a<C00H04e=C@1>
CTh0Cdm?05=CD`1GEeL0Fe]K065QH@1ZJVX0PX:208^;R`2CTi<0VYZJ0:6QX@2/[:`0];Bd0;^k^`2o
_kl0`l?30<C4a037alL0bl_;0<o?c`3De=@0fMWI0P3Ogml05`3Ph>00g]kN0=kNgP3Kfm/0eMGE0<o?
c`3:b/X0aLG50<30`02f][H0/K6a0:b/[02XZ:P0Xj>S09VIV@2DU9@0Shn?08Z:RP25QHD0PH6107Mg
M`1bLW80KFe]01h0oooo01d0C4a<04U9B@13@d<0@41003dm?@0j>SX0=cLg03@d=00^;Rh0:RXZ02LW
9`0T92@0820P01TI6@0E5AD04A4A00d=3@092@T02PX:00l?3`0E5AD071`L02@T900];Bd0?clo04M7
A`1@D500FUYJ05eMG@0205mOG`L0H61P0P1NGUh02P1QHF40H61P05mOG`1NGUh0GEeM05mOG`1NGUh0
GemO061PH01QHF42069RHP<0HF5Q2@1PH6005@1QHF40HV9R069RHP1TI6@0IVIV06MWI`1ZJVX0K6a/
075aL@1dM7@0MWIf07QhN01nOWh0PH6108N7Q`29RHT0Rh^;08j>SP2ATI40UiNG09VIV@0309^KV`0D
09ZJVP2GUiL0U9BD096AT@2>SXh0Rh^;08B4Q021PH40OWin07]kN`1gMgL0LG5a06i^KP1ZJVX0IfMW
06=SH`1PH600FEUI05IFEP1BDU8R0?ooo`00803oool0:P2?Shl0Rh^;08:2PP1mOGd0NGUi07EeM@1`
L700K6a/06=SH`1OGel0Fe]K05MGE`1BDU80BTY:04I6AP12@T80?Cdm03/k>`12@T80AdM704a<C01A
DE40EUIF05eMG@1YJFT0L71`07MgM`1kNg/0N7Qh07=cL`1`L700KVi^06][J`1YJFT0IVIV069RHP1P
H600GemO05aLG01JFUX0EeMG05EEE@80E5AD00D0EEEE05YJFP1KFe/0G5aL05iNGP02061PH00305eM
G@1LG5`0Fe]K0080FEUI0`1GEeL205QHF00>05YJFP1PH600I6AT06YZJP1`L700NGUi09ZJVP2YZJT0
/k>c0;fm_@34a<@0d];B0=[JfP3Ph>030>_[j`050>SXj03[jn/0k^k^0??cl`3hn?P00P3moOd05`3j
n_X0moOg0?Gem@3clo<0j^[Z0>KViP3Rh^80gMgM0=WIf@3AdM40cLg=0<W9b@35aLD0`L710;Vi^@2e
]KD0/K6a0:j^[P2ZZZX0YZJV09nOW`2KVi/0UiNG01h0oooo02X0I6AT05mOG`1EEED0D51@04];B`16
ATH0@D5103`l?00b<S80;Bd]02PX:00S8b<07QhN01<C4`0>3Ph020P800<30`00000020P800l?3`0H
61P08B4Q02XZ:P0d=3@0ATI6059BDP1NGUh0I6AT069RHP1NGUh0GEeM05]KF`1IFET0EeMG05EEE@1C
De<0DE5A051@D01?Cdl0CTi>04a<C01;Bd/204Y:BP0<04a<C01?Cdl0Cdm?055AD@1CDe<0E5AD05=C
D`1ADE40D51@04m?C`1>CTh0CDe=0`1<C4`04P1=CDd0CTi>04m?C`1CDe<0EeMG05]KF`1PH600IfMW
0820P02;Rh/0U9BD09^KV`2QXJ40[Zj^0;Fe]@2l_;`0a/K60<O7a`80b/[:00L0c/k>0=;BdP3GemL0
g=cL0>?Sh`3Ti>@0hn?S0080hN7Q01@0gmoO0=GEe@3@d=00b/[:0<G5a@30`<00][Jf0;6a/@2/[:`0
Z:RX0:>SX`2IVIT0U9BD08n?S`2:RXX0QHF50861P@1gMgL0LW9b06e]KAh0oooo01/0CDe=04Y:BP14
A4@0@D5103hn?P0k>c/0>3Ph03De=@0^;Rh0:b/[02PX:00T92@08B4Q01TI6@0F5QH04Q8B00h>3P0<
30`04A4A01LG5`0N7Qh09bLW02l_;`0h>3P0AdM7055AD@1KFe/01`1QHF44061PH003065QH@1RHV80
HV9R00<0HV9R0`1SHf<406ATI00406=SH`1RHV80HV9R069RHP80HF5Q0`1RHV8306=SH`0]06ATI01U
IFD0IVIV06IVIP1[Jf/0KFe]06m_K`1aLG40Lg=c07MgM`1jNWX0OGem08:2PP24Q8@0QhN708^;R`2>
SXh0TI6A09BDU02FUYH0Vi^K09fMW@2NWYh0WinO0:2PX02OWil0VIVI09JFUP2BTY80Shn?08b<S025
QHD0PX:207inOP1kNg/0N7Qh075aL@1^KVh0JVYZ06MWI`1TI6@0H61P05YJFP1FEUH0De=C0280oooo
000P0?ooo`0J08n?S`2:RXX0PH6107emO@1hN7P0M7Ad06m_K`1[Jf/0HV9R05iNGP1IFET0EEEE055A
D@18B4P0A4A403lo?`0k>c/0>CTi0492@P16ATH0C4a<059BDP1GEeL0GEeM06YZJP1bLW8207UiN@0E
07MgM`1bLW80L71`06i^KP1[Jf/0JFUY06MWI`1RHV80HF5Q05mOG`1MGEd0Fe]K05MGE`1FEUH0EEEE
05ADE01FEUH0FEUI05]KF`1LG5`0GUiN0080GemO00D0GEeM05aLG01KFe/0FUYJ05UIF@0405MGE`0`
05QHF01IFET0GUiN069RHP1WIfL0KVi^07IfMP2FUYH0YJFU0;2`/02k^k/0`L710=3@d03Hf=P0gmoO
0>SXj03[jn/0k>c/0>SXj03Zj^X0k^k^0?;blP3hn?P0o_kn0?gmo@3jn_X0n?Sh0?Gem@3bl_80jNWY
0>GUi@3QhN40gMgM0=WIf@3@d=00c<c<0<S8b034a<@0`<300;Vi^@2e]KD0/K6a0:f][@2ZZZX0YZJV
09nOW`2KVi/0UiNG7P3oool09P1TI6@0GemO05EEE@1@D500Bd];04I6AP11@D40>c/k034a<@0/;2`0
9bLW028R8P0M7Ad04Q8B00d=3@071`L00P820000000;2`/04Q8B01`L700T92@0;Bd]03Lg=`1:BTX0
EUIF069RHP1TI6@0Hf=S05mOG`1MGEd0Fe]K05UIF@1GEeL0EUIF05=CD`1BDU80DE5A0P1?Cdl02@1<
C4`0Bd];04Y:BP1:BTX0Bd];04i>CP1?Cdl0DE5A059BDP0205=CD`05055AD@1@D500Cdm?04i>CP1=
CDd00P1<C4`204e=C@0I04i>CP1?Cdl0De=C05MGE`1KFe/0H61P06IVIP1oOgl0Rh^;09>CT`2LW9`0
XZ:R0:n_[`2g]kL0_[jn0<O7a`39bLT0c<c<0<g=c@3@d=00e=CD0=SHf03MgMd0iNGU0>KViP020>CT
i00E0>;RhP3Ogml0eMGE0=3@d03:b/X0aLG50<30`02f][H0/K6a0:b/[02XZ:P0Xj>S09VIV@2DU9@0
Shn?08Z:RP25QHD0PH6107MgM`1bLW80KFe]01h0oooo01d0C4a<04Y:BP14A4@0@D5103hn?P0k>c/0
>3Ph03De=@0_;bl0:b/[02PX:00U9BD08B4Q01XJ6P0F5QH04a<C00l?3`0=3@d05QHF01dM7@0T92@0
;2`/03@d=00l?3`0C4a<05IFEP1PH600I6AT06=SH`02069RHP80HF5Q1@1PH606065QH@80HV9R00H0
Hf=S06ATI01UIFD0IFEU06ATI01SHf<6069RHP80Hf=S00P0I6AT06EUI@1UIFD0IVIV06MWI`1XJ6P0
JVYZ06i^KP80LG5a00h0M7Ad07MgM`1kNg/0OWin08:2PP26QXH0R8R808^;R`2?Shl0TI6A09BDU02F
UYH0V9RH09jNWP80X:2P01H0XJ6Q0::RXP2QXJ40VYZJ09JFUP2CTi<0T92@08b<S025QHD0PX:207mo
O`1lO7`0N7Qh075aL@1^KVh0Jf][06MWI`1TI6@0H61P05YJFP1FEUH0De=C8P3oool00200oooo0100
Shn?08Z:RP21PH40O7al07QhN01cLg<0KVi^06YZJP1QHF40GEeM05QHF01CDe<0Cdm?04I6AP12@T80
?Cdm0P0i>CT06012@T80B4Q804e=C@1BDU80F5QH05iNGP1[Jf/0Lg=c07alO01hN7P0MWIf079bLP1`
L700KVi^06a/K01ZJVX0IfMW06=SH`1QHF40H61P05iNGP1LG5`0F5QH05IFEP80EEEE00D0EUIF05UI
F@1KFe/0G5aL05eMG@0205iNGP0505eMG@1LG5`0Fe]K05YJFP1IFET0101GEeL205QHF00@05eMG@1P
H600IFEU06][J`1cLg<0TI6A0:6QX@2/[:`0]kNg0;no_`3>c/h0e]KF0=kNgP3Vi^H0j^[Z0>_[j`80
jNWY01`0k^k^0?;blP3hn?P0o_kn0?gmo@3jn_X0nOWi0?KfmP3alO40jNWY0>GUi@3Ph>00g=cL0=SH
f03@d=00c<c<0<S8b034a<@0`<300;Vi^@2e]KD0/K6a0:f][@2YZJT0YZJV09jNWP2KVi/0UiNG7P3o
ool0:P1TI6@0GemO05EEE@1@D500BTY:04E5A@10@400>c/k034a<@0/;2`09bLW024Q8@0L71`04A4A
00`<30061PH00@410000000=3@d05QHF01lO7`0X:2P0<C4a03Xj>P1>CTh0FUYJ06IVIP1TI6@0Hf=S
05mOG`1MGEd0Fe]K05UIF@1GEeL0EUIF05=CD`1BDU80DE5A051@D01?Cdl0C4a<04];B`80BTY:00@0
Bd];04i>CP1?Cdl0DE5A0`1CDe<00`1ADE40D51@04m?C`0204i>CP<0CDe=01<0CTi>04m?C`1@D500
E5AD05MGE`1KFe/0H61P06IVIP1nOWh0RXZ:09>CT`2LW9`0Xj>S0;2`/02h^;P0_kno0<O7a`3<c<`0
c/k>0080d=3@00<0eMGE0=WIf@3Ogml00P3Xj>P20>KViP0E0>CTi03Ogml0e=CD0<o?c`3:b/X0aLG5
0<30`02f][H0/K6a0:b/[02WYjL0Xj>S09VIV@2DU9@0Shn?08Z:RP25QHD0PH6107MgM`1bLW80KFe]
01h0oooo0100C4a<04U9B@14A4@0@D5103hn?P0k>c/0>3Ph03De=@0_;bl0;2`/02PX:00U9BD08R8R
01/K6`0G5aL04a<C0P0?3`l02@0I6AT0820P02PX:00a<C40>3Ph0410@01@D500FUYJ06=SH`0206AT
I080HV9R00<0HF5Q061PH01PH6002`1PH6000`1RHV80Hf=S06ATI00206EUI@0306ATI01SHf<0HV9R
00<0HV9R0`1SHf<06`1TI6@0IFEU06IVIP1WIfL0J6QX06UYJ@1[Jf/0KFe]075aL@1cLg<0MWIf07Qh
N01jNWX0Ogmo08>3P`26QXH0RHV908b<S02>SXh0Ti>C09BDU02EUID0V9RH09^KV`2RXZ80Xj>S0::R
XP020:BTY00D0:6QX@2JVYX0UiNG09>CT`2@T900SHf=08J6QP23Ph<0Ogmo07alO01iNGT0LW9b06i^
KP1[Jf/0IfMW06ATI01PH600FUYJ05IFEP1CDe<R0?ooo`00803oool0:P2?Shl0RXZ:0861P@1lO7`0
MgMg079bLP1]KFd0JFUY05mOG`1KFe/0EUIF059BDP1=CDd0A4A40410@00k>c/0=SHf03Ph>011@D40
B4Q804a<C01BDU80F5QH05iNGP1/K6`0LW9b07YjNP1gMgL0MGEe075aL@1_Kfl0KVi^06a/K01ZJVX0
J6QX06ATI01RHV80H61P05mOG`1MGEd0FEUI05MGE`<0EUIF00@0FEUI05YJFP1LG5`0GEeM0`1NGUh0
1@1MGEd0Fe]K05]KF`1JFUX0F5QH00<0EeMG0140F5QH05UIF@1KFe/0GemO06ATI01ZJVX0LG5a08f=
S@2LW9`0ZZZZ0;Bd]02m_Kd0c<c<0=?Cd`3Kfm/0i>CT0>SXj0020>[ZjP0M0>SXj03]kNd0l_;b0?Sh
n03oool0oOgm0?Win@3hn?P0m?Cd0?3`l03Xj>P0hn?S0=oOg`3Kfm/0emOG0<o?c`3;bl/0alO70<C4
a030`<00^;Rh0;Bd]02a/K40[Jf]0:VYZ@2VYZH0WYjN09^KV`2GUiL07P3oool0:P1TI6@0GemO05AD
E01?Cdl0BTY:04E5A@10@400>c/k030`<00[:b/09RHV024Q8@0K6a/0410@00/;2`051@D000000082
0P0@41006QXJ02<S8`0/;2`0=3@d03dm?@1CDe<0GUiN06QXJ01UIFD0Hf=S05iNGP1LG5`0Fe]K05UI
F@1GEeL0EUIF05=CD`1BDU80DE5A051@D01?Cdl0C4a<04];B`80BTY:00X0Bd];04i>CP1@D500DE5A
059BDP1CDe<0DU9B055AD@1@D500Cdm?0P1>CTh304e=C@0J04i>CP1?Cdl0D51@05ADE01GEeL0Fe]K
061PH01WIfL0OGem08V9R@2CTi<0W9bL0:BTY02b/[80^KVi0<71`@39bLT0cLg=0=3@d03Bd]80dM7A
0=KFeP3Kfm/0hN7Q0>WYj@3Zj^X20>SXj00E0>CTi03Ogml0e=CD0<o?c`3:b/X0aLG50<30`02f][H0
/K6a0:b/[02WYjL0XZ:R09VIV@2DU9@0Shn?08Z:RP25QHD0PH6107MgM`1bLW80KFe]01h0oooo01l0
C4a<04U9B@14A4@0@D5103hn?P0k>c/0>CTi03Hf=P0`<300;Bd]02TY:@0V9RH08R8R01`L700H61P0
5ADE018B4P0C4a<07QhN02LW9`0_;bl0=SHf03dm?@14A4@0EeMG065QH@1WIfL0IVIV06EUI@1SHf<0
HF5Q0080H61P1P1OGel2061PH080GemO00P0H61P065QH@1SHf<0Hf=S06ATI01UIFD0I6AT06=SH`80
HV9R0P1QHF42069RHP0c06=SH`1TI6@0IFEU06EUI@1VIVH0JFUY06YZJP1[Jf/0KFe]06m_K`1eMGD0
MgMg07QhN01jNWX0OGem08>3P`27QhL0RXZ:08j>SP2@T900TY:B09FEU@2FUYH0V9RH09ZJVP2MWId0
Xj>S0:FUY@2WYjL0Z:RX0:JVYP2RXZ80Vi^K09RHV02EUID0TI6A08j>SP27QhL0Ph>30820P01lO7`0
NGUi079bLP1^KVh0Jf][06QXJ01TI6@0HF5Q05YJFP1FEUH0De=C0280oooo000P0?ooo`0J08n?S`2:
RXX0P82007]kN`1fMWH0LW9b06e]K@1XJ6P0GUiN05YJFP1EEED0D51@04a<C012@T80?Shn03Ti>@0d
=3@0=cLg0492@P18B4P0CDe=05=CD`1HF5P0GEeM06][J`1aLG4207EeM@0>07AdM01`L700Kfm_06i^
KP1/K6`0JVYZ06UYJ@1UIFD0Hf=S065QH@1OGel0GUiN05UIF@1GEeL305IFEP0305UIF@1KFe/0G5aL
00@0GUiN00D0GEeM05aLG01KFe/0Fe]K05UIF@0405QHF00_05UIF@1LG5`0GUiN069RHP1YJFT0L71`
08V9R@2IVIT0YZJV0;:b/P2k^k/0c<c<0=;BdP3Jf]X0h^;R0>OWi`3YjNT0j^[Z0>SXj03]kNd0lO7a
0?Shn03oool0oOgm0?[jnP3hn?P0m?Cd0>o_k`3WinL0hn?S0=oOg`3Jf]X0e]KF0<o?c`3;bl/0alO7
0<?3``2o_kl0^;Rh0;Bd]02`/;00[Jf]0:VYZ@2UYJD0WYjN09^KV`2GUiL07P3oool0:P1TI6@0GemO
05ADE01?Cdl0BTY:04E5A@10@400>SXj030`<00Z:RX09BDU020P800K6a/0410@00X:2P051@D00000
00@4100D51@07QhN02HV9P0_;bl0>3Ph0410@01HF5P0Hf=S06MWI`1TI6@0HV9R05iNGP1LG5`0FUYJ
05UIF@1GEeL0EUIF05=CD`1BDU80DE5A051@D01?Cdl0C4a<04];B`80BTY:00@0Bd];04i>CP1@D500
DE5A0P1BDU80101ADE40D51@051@D01?Cdl304i>CP0J04e=C@1>CTh0Cdm?051@D01ADE40EEEE05MG
E`1KFe/0HF5Q06MWI`1lO7`0R8R809>CT`2LW9`0Y:BT0;Bd]02j^[X0`/;20<[:bP3?cll0dM7A0=CD
e03Bd]80emOG0=cLg03Shn<20>c/k00G0>[ZjP3YjNT0i>CT0=oOg`3De=@0clo?0<[:bP35aLD0`<30
0;Jf]P2a/K40[:b/0:NWY`2RXZ80VIVI09BDU02?Shl0RXZ:08F5Q@21PH40MgMg079bLP1]KFd07P3o
ool0801=CDd0BTY:04A4A011@D40?clo03`l?00i>CT0=SHf030`<00];Bd0:RXZ02LW9`0S8b<071`L
01TI6@0F5QH051@D01LG5`0T92@0;2`/03<c<`0j>SX0@T9204];B`1OGel0JFUY06a/K01XJ6P0IVIV
069RHP1QHF40H61P0P1OGel305iNGP<0GemO101PH6000`1QHF40Hf=S06=SH`0206ATI080Hf=S1@1Q
HF42069RHP0D06ATI01UIFD0IVIV06MWI`1ZJVX0Jf][06e]K@1_Kfl0LG5a07MgM`1iNGT0Ng]k07in
OP21PH40QXJ608Z:RP2=SHd0TI6A09BDU02EUID209NGU`0509ZJVP2LW9`0X:2P0:NWY`2XZ:P00P2Y
ZJT05@2VYZH0Xj>S09bLW02IVIT0UIFE09:BTP2>SXh0QhN708B4Q020P800OGem07UiN@1bLW80Kfm_
06][J`1XJ6P0I6AT065QH@1JFUX0EUIF05=CD`0R0?ooo`00803oool0602?Shl0RXZ:0820P01jNWX0
MGEe071`L01[Jf/0IVIV05aLG01GEeL0DU9B04e=C@18B4P0?Shn03Ti>@0d=3@0=CDe03Ph>014A4@0
BDU904i>CP1DE5@0F5QH05mOG`80L71`0`1aLG403@1`L700Kfm_06i^KP1]KFd0K6a/06][J`1XJ6P0
IVIV06ATI01RHV80GemO05]KF`1HF5P00P1FEUH0101GEeL0FUYJ05]KF`1MGEd205mOG`04061PH01O
Gel0GemO05mOG`80GUiN0P1LG5`0<P1KFe/0FUYJ05YJFP1JFUX0GEeM05mOG`1QHF40IfMW06i^KP23
Ph<0TY:B0:2PX02][Jd0]kNg0<W9b@3@d=00f=SH0>3Ph03UiND0inOW0>_[j`3YjNT0k>c/0?3`l03h
n?P0oooo0?knoP3kno/0m_Kf0?;blP3^k^h0iNGU0>7Qh@3MgMd0fMWI0=GEe@3=cLd0bLW90<G5a@32
`/80_[jn0;Ng]`2c/k<0/;2`0:b/[02YZJT0YJFU09jNWP2JVYX0UiNG7P3oool0601TI6@0GUiN05AD
E01?Cdl0BDU904A4A00o?cl0>CTi02l_;`0Y:BT092@T01lO7`0I6AT03Ph>00T92@020P800`<300T9
2@0L71`092@T02d];@0f=SH0?clo04];B`<0Hf=S01@0HF5Q061PH01LG5`0FUYJ05QHF01GEeL0EUIF
05EEE@1DE5@0De=C059BDP1ADE40D51@04e=C@1<C4`0Bd];04Y:BP1;Bd/0CTi>04m?C`80D51@0P1A
DE4204m?C`<0CTi>0P1?Cdl2051@D00B055AD@1BDU80EUIF05UIF@1LG5`0HF5Q06QXJ01jNWX0QXJ6
096AT@2LW9`0YJFU0;Fe]@2m_Kd0aLG50<c<c03AdM40dm?C0P3Fe]H00`3IfMT0gmoO0>OWi`020?3`
l00G0>g]k@3YjNT0i>CT0=kNgP3De=@0clo?0<[:bP35aLD0`<300;Jf]P2a/K40[:b/0:NWY`2RXZ80
V9RH09BDU02?Shl0RXZ:08F5Q@20P800MgMg079bLP1]KFd07P3oool0601=CDd0BTY:04E5A@12@T80
?clo03dm?@0j>SX0=cLg034a<@0^;Rh0:b/[02PX:00U9BD07alO01/K6`0F5QH05aLG01dM7@0];Bd0
=3@d03`l?014A4@0CDe=05MGE`80Jf][00H0JVYZ06MWI`1TI6@0HF5Q05mOG`1MGEd505aLG00405eM
G@1NGUh0GUiN05mOG`@0H61P0`1QHF42061PH00305mOG`1NGUh0GUiN00<0GUiN01@0H61P065QH@1S
Hf<0I6AT06IVIP1WIfL0Jf][06e]K@1_Kfl0LG5a07AdM01jNWX0OGem07moO`22PX80QHF508b<S02?
Shl0Ti>C09NGU`80VIVI00H0VYZJ09^KV`2NWYh0XJ6Q0:JVYP2/[:`20:f][@0F0:^[Z`2WYjL0Y:BT
09fMW@2JVYX0UYJF09>CT`2?Shl0R8R808F5Q@21PH40OWin07YjNP1cLg<0Kfm_06a/K01XJ6P0IFEU
065QH@1JFUX0EUIF05=CDb80oooo000P0?ooo`0J08j>SP29RHT0Ogmo07YjNP1eMGD0Kfm_06YZJP1U
IFD0Fe]K05EEE@1@D500C4a<04I6AP0l?3`0=cLg030`<00c<c<0=cLg04A4A019BDT0Cdm?05EEE@1J
FUX0HF5Q06i^KP1_Kfl3071`L080Kfm_0P1^KVh04@1]KFd0K6a/06YZJP1WIfL0IFEU06=SH`1QHF40
G5aL05YJFP1GEeL0EUIF05MGE`1KFe/0G5aL05iNGP1OGel0H61P00<0HF5Q0`1PH600101OGel0GUiN
05iNGP1MGEd205aLG00@05iNGP1PH600HV9R06MWI`1]KFd0PX:2092@T02NWYh0Zj^[0;Jf]P38b<P0
d=3@0=WIf@3Ph>00i>CT0>KViP80j^[Z00<0jn_[0?3`l03gmoL00P3oool05`3jn_X0m_Kf0?7al@3]
kNd0i>CT0>3Ph03Lg=`0f=SH0=CDe03<c<`0bLW90<G5a@31`L40_[jn0;Jf]P2c/k<0[jn_0:b/[02X
Z:P0YJFU09jNWP2JVYX0UiNG01h0oooo02/0I6AT05iNGP1DE5@0Cdm?04U9B@14A4@0?clo03Ti>@0_
;bl0:BTY02@T900N7Qh06ATI00h>3P0820P00P8200H61P0=3@d07alO02LW9`0`<300>SXj04A4A01?
Cdl0Hf=S069RHP1QHF40GemO05iNGP1KFe/0FEUI05QHF01GEeL0EUIF05EEE@1DE5@0De=C059BDP1A
DE40D51@04i>CP1<C4`0Bd];0080BTY:00<0CDe=04i>CP1?Cdl00`1@D500101?Cdl0CTi>04i>CP1>
CTh204m?C`80D51@0340DE5A059BDP1CDe<0EeMG05YJFP1MGEd0HF5Q06QXJ01iNGT0QHF5096AT@2L
W9`0YJFU0;Jf]P2m_Kd0a/K60<k>cP3AdM40dm?C0=OGe`3Hf=P0fm_K0>7Qh@3YjNT0lO7a0?;blP3^
k^h0jNWY0>CTi03Ng]h0e=CD0<o?c`3:b/X0aLG50<30`02f][H0/K6a0:b/[02WYjL0XZ:R09RHV02D
U9@0Shn?08Z:RP25QHD0P82007MgM`1bLW80KFe]01h0oooo01l0CDe=04Y:BP15ADD0@T920410@00m
?Cd0>SXj03Lg=`0b<S80;bl_02`/;00Y:BT09RHV01lO7`0L71`06QXJ01dM7@0S8b<0<S8b03Ti>@11
@D40BDU9059BDP1LG5`0K6a/06YZJP1XJ6P0IFEU06=SH`1OGel0GEeM0080Fe]K0P1JFUX205]KF`03
05aLG01MGEd0GUiN00<0GemO101PH60205mOG`0305iNGP1MGEd0G5aL00<0Fe]K01D0G5aL05iNGP1O
Gel0HF5Q06=SH`1UIFD0IfMW06][J`1]KFd0Kfm_079bLP1dM7@0NWYj07emO@20P800Ph>308J6QP2=
SHd0TI6A09BDU02HV9P00P2JVYX07P2MWId0WinO0:6QX@2UYJD0ZZZZ0:j^[P2`/;00[Zj^0:^[Z`2X
Z:P0YJFU09jNWP2JVYX0UiNG09>CT`2@T900RHV908F5Q@21PH40OWin07YjNP1cLg<0L71`06a/K01Y
JFT0IFEU065QH@1JFUX0EUIF05=CDb80oooo000P0?ooo`0J08j>SP29RHT0OWin07UiN@1dM7@0Kfm_
06UYJ@1TI6@0FEUI05ADE01?Cdl0BTY:04E5A@0j>SX0=CDe030`<00c<c<0=cLg04A4A01;Bd/0D51@
05IFEP1MGEd0HV9R06a/K01^KVh606m_K`<0KVi^00h0K6a/06YZJP1WIfL0IFEU069RHP1MGEd0FUYJ
05MGE`1EEED0EUIF05]KF`1LG5`0GUiN061PH080HF5Q1P1RHV82065QH@0H061PH01OGel0GUiN05mO
G`1QHF40Hf=S06IVIP1]KFd0P82008j>SP2LW9`0ZZZZ0;Jf]P38b<P0d=3@0=WIf@3Rh^80hn?S0>KV
iP3Zj^X0k>c/0>_[j`3bl_80moOg0P3no_h05`3jn_X0mOGe0?3`l03/k>`0hn?S0=oOg`3Kfm/0emOG
0=?Cd`3<c<`0b<S80<C4a031`L40_Kfm0;Jf]P2c/k<0[jn_0:^[Z`2XZ:P0YJFU09jNWP2JVYX0UiNG
01h0oooo0280Hf=S05iNGP1DE5@0CTi>04U9B@14A4@0?Shn03Ti>@0^;Rh0:BTY02<S8`0N7Qh061PH
00d=3@0820P00`<300T92@0?3`l08R8R02/[:`0d=3@0?Cdm04U9B@1DE5@0HF5Q061PH01OGel0GUiN
05aLG01IFET0F5QH05MGE`1FEUH0EEEE0P1DE5@205=CD`05059BDP1ADE40CTi>04e=C@1;Bd/00P1:
BTX0101<C4`0CDe=04i>CP1>CTh204m?C`D0CTi>0P1@D5006@1ADE40DU9B05=CD`1DE5@0F5QH05]K
F`1NGUh0HV9R06QXJ01iNGT0Q8B4092@T02KVi/0YZJV0;Ng]`2n_[h0a/K60<o?c`3AdM40e=CD0=SH
f03Kfm/0g=cL0>CTi03Zj^X00P3clo<05`3^k^h0jNWY0>CTi03Ng]h0e=CD0<o?c`3:b/X0aLG50;no
_`2e]KD0/;2`0:b/[02WYjL0XZ:R09RHV02DU9@0Shn?08Z:RP25QHD0P82007MgM`1bLW80KFe]01h0
oooo02<0CDe=04Y:BP15ADD0@T920410@00m?Cd0>c/k03Ph>00b<S80<30`02d];@0Z:RX09bLW024Q
8@0N7Qh071`L024Q8@0W9bL0=CDe03`l?014A4@0CDe=05MGE`1RHV80K6a/06UYJ@1VIVH0I6AT065Q
H@1MGEd0Fe]K05YJFP1IFET0F5QH05MGE`0205UIF@0405]KF`1LG5`0GEeM05mOG`<0H61P0P1OGel0
1P1NGUh0GEeM05eMG@1LG5`0Fe]K05YJFP<0FEUI03D0FUYJ05aLG01NGUh0H61P069RHP1TI6@0IfMW
06][J`1^KVh0L71`07=cL`1fMWH0Ng]k07inOP21PH40Q8B408R8R02?Shl0TY:B09FEU@2JVYX0Vi^K
09bLW02NWYh0X:2P0:>SX`2WYjL0[:b/0;6a/@2b/[80/;2`0:b/[02YZJT0YZJV09nOW`2KVi/0V9RH
09BDU02@T900RHV908J6QP22PX80OWin07]kN`1cLg<0L71`06a/K01YJFT0IFEU065QH@1JFUX0EUIF
05=CD`0R0?ooo`00803oool06P2>SXh0RHV907inOP1hN7P0Lg=c06i^KP1XJ6P0Hf=S05QHF01CDe<0
CTi>04Q8B013@d<0>CTi03@d=00a<C40=CDe03Ph>014A4@0Bd];055AD@1HF5P0GemO06IVIP1/K6`0
KFe]0P1^KVh706m_K`0806i^KP1/K6`0JVYZ06MWI`1TI6@0GUiN05]KF`1HF5P205EEE@0605YJFP1L
G5`0GUiN061PH01QHF40HV9R0P1SHf<0101TI6@0IFEU06EUI@1UIFD206ATI00H069RHP1QHF40HF5Q
065QH@1RHV80I6AT06MWI`1]KFd0Ogmo08b<S02KVi/0Z:RX0;Fe]@37alL0clo?0=SHf03QhN40hn?S
0>KViP3Zj^X0k^k^0>_[j`3clo<0moOg0P3moOd05`3hn?P0lo?c0>o_k`3[jn/0h^;R0=kNgP3Jf]X0
e]KF0=;BdP3;bl/0alO70<?3``30`<00_;bl0;Fe]@2b/[80[jn_0:^[Z`2XZ:P0Y:BT09jNWP2JVYX0
UiNG01h0oooo01P0Hf=S05iNGP1DE5@0CTi>04U9B@13@d<0?Shn03Ph>00^;Rh0:2PX02<S8`0M7Ad0
61PH00`<30071`L01@D500`<300B4Q8092@T02h^;P0g=cL0@D5104e=C@1IFET205iNGP0505eMG@1L
G5`0Fe]K05QHF01FEUH00P1EEED505ADE00905=CD`1BDU80Cdm?04i>CP1<C4`0BTY:04U9B@1;Bd/0
C4a<0080CDe=0P1>CTh304e=C@80CTi>01/0D51@055AD@1CDe<0De=C05ADE01FEUH0FEUI05aLG01O
Gel0Hf=S06QXJ01iNGT0Ph>308n?S`2KVi/0YZJV0;Ng]`2o_kl0alO70=3@d03Bd]80e=CD0=WIf@3M
gMd0g]kN0>KViP3/k>`00P3dm?@05`3^k^h0jNWY0>?Sh`3Ng]h0e=CD0<o?c`39bLT0a<C40;no_`2e
]KD0/;2`0:^[Z`2VYZH0XZ:R09RHV02CTi<0Shn?08Z:RP25QHD0P82007MgM`1bLW80KFe]01h0oooo
00h0CDe=04Y:BP16ATH0@d=30410@00n?Sh0>c/k03Ph>00c<c<0<30`02d];@0[:b/0:2PX024Q8@80
7AdM014092@T02XZ:P0j>SX0@D5104Q8B01ADE40Fe]K06IVIP1XJ6P0IVIV06ATI01RHV80GemO05]K
F`1IFET0EeMG05IFEP0205EEE@0605MGE`1HF5P0FUYJ05aLG01MGEd0GemO0`1PH600201OGel0GUiN
05eMG@1LG5`0Fe]K05YJFP1IFET0EeMG101FEUH0=01JFUX0G5aL05iNGP1QHF40I6AT06IVIP1[Jf/0
KVi^071`L01cLg<0MWIf07alO01nOWh0PX:208F5Q@29RHT0T92@09BDU02HV9P0Vi^K09bLW02MWId0
WinO0::RXP2UYJD0ZZZZ0:n_[`2e]KD0];Bd0;6a/@2^[Zh0ZZZZ0:NWY`2PX:00W9bL09RHV02EUID0
TI6A08Z:RP26QXH0PX:207moO`1kNg/0M7Ad071`L01/K6`0JFUY06EUI@1RHV80FUYJ05IFEP1CDe<R
0?ooo`00803oool06@2>SXh0R8R807emO@1hN7P0LW9b06e]K@1WIfL0HV9R05MGE`1BDU80C4a<04M7
A`11@D40=cLg034a<@0b<S80=3@d03Ti>@15ADD0C4a<059BDP1JFUX0HF5Q06YZJP1/K6`0101^KVh3
06m_K`80L71`00T0LG5a071`L01^KVh0K6a/06UYJ@1UIFD0GemO05]KF`1HF5P00P1EEED02P1HF5P0
Fe]K05eMG@1OGel0HF5Q069RHP1SHf<0I6AT06IVIP1WIfL306QXJ00306MWI`1VIVH0I6AT0080Hf=S
01@0I6AT06EUI@1YJFT0KFe]07moO`2:RXX0VIVI0:NWY`2d];@0alO70<o?c`3GemL0h>3P0>;RhP3U
iND0jNWY0>o_k`3[jn/0l_;b0?Shn080no_k01L0m_Kf0?;blP3]kNd0jNWY0>7Qh@3MgMd0fMWI0=GE
e@3AdM40b/[:0<K6aP33`l<0_kno0;bl_02e]KD0/[:b0:j^[P2[Zj/0YjNW0:BTY02MWId0VYZJ09NG
U`0N0?ooo`0H06=SH`1NGUh0De=C04i>CP19BDT0@d=303hn?P0h>3P0;Bd]02PX:00R8R807AdM01LG
5`0<30`01PH600P8200>3Ph05ADE02LW9`0`<300>SXj04I6AP1ADE40Fe]K0P1MGEd01@1LG5`0FUYJ
05UIF@1FEUH0EEEE0080E5AD00<0De=C05ADE01EEED00P1EEED02P1DE5@0De=C051@D01>CTh0C4a<
04Y:BP19BDT0BTY:04];B`1<C4`304e=C@<0C4a<03H0CDe=04i>CP1ADE40De=C05ADE01EEED0EUIF
05MGE`1JFUX0GEeM061PH01TI6@0JFUY07UiN@22PX80Shn?09^KV`2VYZH0^;Rh0<30`038b<P0dM7A
0=?Cd`3EeMD0f][J0>7Qh@3Ph>00j>SX0>o_k`3emOD0m?Cd0>k^kP3YjNT0hn?S0=kNgP3Cdm<0c/k>
0<W9b@34a<@0_kno0;Fe]@2`/;00Zj^[0:JVYP2QXJ40V9RH09>CT`2>SXh0RXZ:08F5Q@20P800MgMg
079bLP1]KFdN0?ooo`0G04e=C@1;Bd/0ATI604=3@`11@D40?Shn03`l?00i>CT0=3@d034a<@0^;Rh0
:b/[02PX:00S8b<07alO028R8P0Y:BT0;Rh^03`l?013@d<0Bd];05EEE@1NGUh00P1UIFD0201TI6@0
HV9R061PH01NGUh0FEUI05IFEP1EEED0E5AD0P1CDe<01P1FEUH0EeMG05YJFP1LG5`0GEeM061PH080
HF5Q00D0H61P05mOG`1MGEd0G5aL05]KF`0205YJFP0305QHF01EEED0De=C0080De=C03D0E5AD05QH
F01JFUX0GEeM061PH01SHf<0IFEU06][J`1^KVh0L71`07=cL`1fMWH0O7al07moO`23Ph<0QXJ608Z:
RP2BTY80UYJF09VIV@2MWId0WYjN09nOW`2RXZ80YZJV0:VYZ@2^[Zh0/[:b0;Rh^02g]kL0/k>c0:n_
[`2[Zj/0Z:RX0:2PX02MWId0VIVI09FEU@2ATI40RXZ:08J6QP23Ph<0Ogmo07]kN`1dM7@0L71`06e]
K@1YJFT0IFEU069RHP1JFUX0EeMG05=CD`0R0?ooo`00803oool06P2>SXh0R8R807alO01fMWH0LG5a
06][J`1UIFD0H61P05ADE01?Cdl0BDU904=3@`0n?Sh0<c<c02`/;00c<c<0=SHf03dm?@19BDT0Cdm?
05MGE`1OGel0IfMW06QXJ01^KVh0KFe]0`1/K6`0701]KFd0KVi^071`L01aLG40LW9b07=cL`1dM7@0
Lg=c071`L01/K6`0IfMW061PH01KFe/0EeMG05=CD`1ADE40E5AD05MGE`1IFET0G5aL05mOG`1PH600
HV9R06=SH`1VIVH0JVYZ06][J`1]KFd206i^KP0306a/K01ZJVX0JFUY0080IfMW02`0J6QX06][J`1`
L700OWin08R8R02DU9@0XZ:R0;6a/@37alL0clo?0=KFeP3Ng]h0h^;R0>?Sh`3Xj>P0k^k^0>_[j`3a
lO40n?Sh0?[jnP3hn?P0lo?c0>k^kP3Zj^X0i^KV0=kNgP3Jf]X0emOG0=?Cd`3?cll0b<S80<G5a@31
`L40_[jn0;Zj^P2d];@0/K6a0:f][@2ZZZX0YjNW0:BTY02MWId0VYZJ09NGUah0oooo01P0Hf=S05iN
GP1CDe<0CTi>04Q8B013@d<0?Cdm03Ph>00];Bd09bLW028R8P0L71`05QHF00`<30061PH03Ph>018B
4P0K6a/0;2`/03De=@12@T80CDe=05IFEP1HF5P205]KF`0405UIF@1GEeL0EEEE059BDP<0DE5A00/0
DU9B05=CD`1HF5P0F5QH05UIF@1HF5P0EUIF05=CD`1@D500CDe=04Y:BP0204Q8B00504U9B@1:BTX0
BTY:04];B`1:BTX00P19BDT01P1:BTX0C4a<04m?C`1CDe<0EEEE05QHF080FEUI02l0FUYJ05eMG@1O
Gel0HV9R06EUI@1ZJVX0NGUi08>3P`2>SXh0VYZJ0:JVYP2j^[X0`/;20<[:bP3Bd]80eMGE0=OGe`3O
gml0inOW0>GUi@3/k>`0m?Cd0?Ogm`3dm?@0k^k^0>SXj03Shn<0gMgM0=?Cd`3>c/h0b<S80<?3``2n
_[h0];Bd0;2`/02[Zj/0YZJV0:6QX@2HV9P0Ti>C08j>SP29RHT0QHF50820P01gMgL0LW9b06e]K@0N
0?ooo`0F04e=C@1;Bd/0AdM704A4A012@T80@41003dm?@0k>c/0=SHf03<c<`0`<300;Rh^02/[:`0V
9RH09BDU02TY:@0/;2`0<S8b0451@@18B4P0DU9B05]KF`80HF5Q00P0HV9R065QH@1OGel0GEeM05YJ
FP1DE5@0DU9B051@D080Cdm?00P0D51@05EEE@1HF5P0Fe]K05iNGP1PH600Hf=S06ATI080Hf=S00T0
HV9R05mOG`1MGEd0G5aL05YJFP1HF5P0EUIF05=CD`1ADE400P1?Cdl0=@1ADE40EUIF05QHF01LG5`0
GemO069RHP1UIFD0Jf][06e]K@1`L700Lg=c07IfMP1mOGd0PX:208J6QP2:RXX0SHf=09FEU@2IVIT0
WIfM0:2PX02RXZ80Xj>S0:ZZZP2`/;00/K6a0;Fe]@2j^[X0^k^k0;Zj^P2f][H0/[:b0:j^[P2ZZZX0
XZ:R09jNWP2JVYX0UiNG09>CT`2;Rh/0QhN708>3P`20P800O7al07EeM@1aLG40KFe]06UYJ@1VIVH0
HV9R05YJFP1GEeL0De=C0280oooo000P0?ooo`0H08j>SP28R8P0O7al07IfMP1`L700JVYZ06ATI01O
Gel0De=C04e=C@18B4P0@T9203`l?00b<S80;bl_038b<P0f=SH0?Shn04];B`1@D500FUYJ065QH@1V
IVH0IfMW0P1]KFd206][J`0R06YZJP1/K6`0KVi^06e]K@1/K6`0Kfm_07=cL`1eMGD0Lg=c079bLP1^
KVh0J6QX05mOG`1JFUX0EUIF059BDP1?Cdl0D51@05=CD`1GEeL0FEUI05iNGP1PH600GUiN05mOG`1S
Hf<0J6QX06YZJP1]KFd0Kfm_071`L01^KVh0K6a/06YZJP80JFUY02`0JVYZ06a/K01aLG40Ogmo08R8
R02DU9@0X:2P0;2`/036a/H0clo?0=KFeP3MgMd0h>3P0>;RhP3Xj>P0k^k^0>_[j`3`l?00m_Kf0?Sh
n03fm_H0lO7a0>g]k@3YjNT0iNGU0=gMg@3IfMT0eMGE0=;BdP3>c/h0alO70<C4a030`<00_Kfm0;Zj
^P2c/k<0/;2`0:f][@2ZZZX0YZJV0:>SX`2MWId0VYZJ09NGUah0oooo01H0Hf=S05iNGP1CDe<0CTi>
04Q8B013@d<0?Cdm03Ph>00];Bd09bLW024Q8@0L71`05QHF00X:2P0820P03Ph>01<C4`0M7Ad0;bl_
03Ph>016ATH0D51@0P1FEUH02`1KFe/0FUYJ05QHF01EEED0De=C051@D01ADE40DU9B055AD@1BDU80
E5AD0080FUYJ00L0Fe]K05YJFP1HF5P0EEEE055AD@1>CTh0BTY:00<0B4Q800`0BDU904M7A`19BDT0
BTY:04U9B@18B4P0BDU904e=C@1@D500E5AD05MGE`1JFUX205]KF`0_05aLG01OGel0H61P06=SH`1V
IVH0Jf][07YjNP23Ph<0SXj>09VIV@2VYZH0^k^k0<C4a03;bl/0dm?C0=KFeP3IfMT0hN7Q0>WYj@3X
j>P0kno_0?KfmP3gmoL0lo?c0>g]k@3Xj>P0h^;R0=gMg@3Bd]80cLg=0<S8b033`l<0_[jn0;Bd]02_
[jl0ZZZZ0:FUY@2QXJ40UiNG09>CT`2>SXh0RHV908F5Q@20P800MgMg079bLP1]KFd07P3oool03@1=
CDd0Bd];04M7A`15ADD0@T920410@00n?Sh0>c/k03Lg=`0d=3@0<S8b02l_;`0/;2`00P0U9BD03P0[
:b/0;Rh^03@d=013@d<0Bd];05EEE@1NGUh0HV9R061PH01QHF40H61P05iNGP1LG5`0FEUI0P1BDU82
05ADE007059BDP1ADE40F5QH05YJFP1LG5`0H61P06=SH`0306IVIP0606EUI@1TI6@0HV9R05mOG`1M
GEd0F5QH0`1FEUH0>01CDe<0DE5A05=CD`1DE5@0EeMG05YJFP1MGEd0H61P06=SH`1WIfL0Jf][06i^
KP1`L700Lg=c07IfMP1nOWh0PX:208N7Q`2:RXX0SXj>09NGU`2KVi/0X:2P0:>SX`2UYJD0YjNW0:j^
[P2c/k<0]KFe0;Zj^P2o_kl0_[jn0;^k^`2g]kL0/k>c0:n_[`2[Zj/0Xj>S09nOW`2KVi/0UiNG09>C
T`2;Rh/0R8R808B4Q020P800O7al07EeM@1aLG40KFe]06UYJ@1VIVH0HV9R05YJFP1GEeL0De=C8P3o
ool00200oooo00d0SHf=08N7Q`1kNg/0MGEe06m_K`1YJFT0Hf=S05eMG@1BDU80C4a<04I6AP10@400
>c/k0080;Rh^0200<C4a03Hf=P0m?Cd0CDe=059BDP1MGEd0IfMW06IVIP1XJ6P0KFe]06][J`1ZJVX0
JFUY06QXJ01YJFT0Jf][06YZJP1XJ6P0JVYZ06e]K@1bLW80LG5a06m_K`1]KFd0J6QX05iNGP1IFET0
E5AD051@D01=CDd0C4a<04i>CP80DU9B00T0EEEE05]KF`1IFET0Fe]K05iNGP1SHf<0IVIV06UYJ@1]
KFd00P1_Kfl0<01/K6`0Jf][06UYJ@1ZJVX0Jf][06e]K@1aLG40Ogmo08V9R@2DU9@0X:2P0:n_[`35
aLD0c/k>0=KFeP3Lg=`0gmoO0>;RhP3WinL0kNg]0>_[j`3bl_80mOGe0?Ogm`3clo<0kno_0>_[j`3W
inL0hn?S0=_Kf`3Hf=P0e=CD0=7Ad@3=cLd0a/K60<?3``30`<00_;bl0;Vi^@2c/k<0/;2`0:b/[02Y
ZJT0YZJV0:>SX`2MWId0VYZJ09NGUah0oooo01h0Hf=S05iNGP1CDe<0CDe=04Q8B013@d<0?Cdm03Ph
>00/;2`09bLW024Q8@0K6a/05QHF00X:2P0;2`/03`l?01DE5@0N7Qh0<S8b03/k>`17AdL0De=C05AD
E01FEUH0Fe]K05UIF@1GEeL0E5AD055AD@1@D50205=CD`04051@D01BDU80EEEE05]KF`<0GEeM00P0
Fe]K05IFEP1BDU80Cdm?04];B`19BDT0AdM704I6AP80AdM700/0BDU904a<C017AdL0AdM704Y:BP1?
Cdl0DE5A05EEE@1HF5P0G5aL05eMG@0205iNGP0^061PH01RHV80I6AT06MWI`1/K6`0Ng]k08B4Q02>
SXh0VIVI0:JVYP2l_;`0aLG50<g=c@3De=@0f=SH0=_Kf`3Ti>@0jn_[0>[ZjP3bl_80moOg0?Shn03c
lo<0kNg]0>OWi`3Rh^80g=cL0=;BdP3=cLd0b<S80<?3``2n_[h0];Bd0:n_[`2ZZZX0YJFU0:2PX02G
UiL0TY:B08j>SP29RHT0Q8B40820P01fMWH0LW9b06e]KAh0oooo0200CDe=04];B`17AdL0ADE504=3
@`11@D40?clo03dm?@0h>3P0=CDe038b<P0`<300;Bd]02PX:00Z:RX0;Bd]038b<P0g=cL0ATI604e=
C@1EEED0G5aL05mOG`1PH600HV9R061PH01NGUh0G5aL05UIF@1EEED0F5QH05UIF@80EeMG00H0FEUI
05eMG@1PH600Hf=S06EUI@1VIVH206UYJ@0706QXJ01WIfL0IfMW06ATI01RHV80H61P05mOG`0205iN
GP0305QHF01FEUH0F5QH0080FUYJ01X0GEeM05iNGP1QHF40Hf=S06IVIP1YJFT0KFe]06m_K`1aLG40
M7Ad07MgM`1oOgl0Ph>308J6QP2:RXX0T92@09ZJVP2NWYh0XZ:R0:JVYP2XZ:P0Zj^[0;>c/`2g]kL0
^;Rh0;jn_P80`L7101P0_Kfm0;Rh^02d];@0/;2`0:b/[02TY:@0X:2P09bLW02HV9P0U9BD08b<S028
R8P0Q8B40820P01mOGd0MGEe075aL@1]KFd0JVYZ06IVIP1RHV80FUYJ05MGE`1CDe<R0?ooo`00803o
ool05@2=SHd0QhN707]kN`1eMGD0KVi^06QXJ01RHV80G5aL051@D01:BTX0A4A403lo?`0i>CT0;Bd]
02`/;00a<C40=cLg03hn?P1>CTh0E5AD05aLG00206MWI`0:06UYJ@1/K6`0Jf][06QXJ01UIFD0I6AT
06IVIP1ZJVX0JFUY06ATI080IVIV01L0KFe]06m_K`1/K6`0JVYZ06IVIP1LG5`0EeMG059BDP1>CTh0
Bd];04M7A`19BDT0Bd];04m?C`1@D500EEEE05=CD`1GEeL0F5QH061PH01QHF40I6AT06UYJ@0306a/
K00E06][J`1YJFT0JVYZ06a/K01^KVh0LW9b07moO`28R8P0TY:B09jNWP2][Jd0aLG50<g=c@3EeMD0
fm_K0=oOg`3QhN40inOW0>c/k03Zj^X0l_;b0080mOGe01P0lO7a0>g]k@3YjNT0iNGU0>7Qh@3Jf]X0
e]KF0=?Cd`3?cll0c<c<0<G5a@32`/80_kno0;^k^`2h^;P0/[:b0:n_[`2/[:`0ZJVY0:JVYP2SXj<0
WIfM09ZJVP2FUYHN0?ooo`0=06=SH`1NGUh0De=C04e=C@18B4P0@T9203dm?@0g=cL0;2`/02HV9P0Q
8B406a/K01DE5@0200`<300600l?3`0G5aL0820P03De=@0n?Sh0BDU90P1DE5@01@1FEUH0FUYJ05UI
F@1FEUH0De=C0080D51@0P1DE5@0101ADE40EEEE05EEE@1MGEd3061PH00605iNGP1HF5P0De=C04m?
C`1<C4`0BDU90`16ATH204Q8B00904];B`16ATH0BTY:04Y:BP1@D500DU9B05EEE@1JFUX0GUiN0080
GemO01D0H61P065QH@1SHf<0IFEU06QXJ01]KFd0O7al08F5Q@2>SXh0VYZJ0:RXZ02n_[h0a/K60<o?
c`3EeMD0fMWI0=gMg@3WinL0kNg]0>c/k03emOD00P3hn?P0603bl_80k>c/0>OWi`3QhN40g=cL0=7A
d@3<c<`0alO70<;2`P2m_Kd0/k>c0:n_[`2ZZZX0YJFU0:2PX02GUiL0TY:B08f=S@29RHT0Q8B40820
P01fMWH0LW9b06e]KAh0oooo01P0CDe=04a<C018B4P0ATI604A4A012@T80@41003dm?@0i>CT0=SHf
03@d=00a<C40;Rh^02`/;00];Bd0;Rh^03<c<`0i>CT0B4Q8051@D01HF5P0GUiN05eMG@1NGUh2065Q
H@0505mOG`1MGEd0Fe]K05UIF@1JFUX00P1KFe/2061PH00406EUI@1WIfL0JFUY06][J`80KFe]00L0
K6a/06][J`1[Jf/0JVYZ06QXJ01WIfL0IFEU0080I6AT0200HV9R05aLG01NGUh0GEeM05mOG`1PH600
HV9R06ATI01XJ6P0JFUY06YZJP1/K6`0Kfm_071`L01bLW80MGEe07QhN020P800QHF508V9R@2>SXh0
U9BD09bLW02QXJ40YZJV0:VYZ@2[Zj/0[jn_0;Ng]`2k^k/0_;bl0<71`@80`l?301P0_[jn0;Zj^P2e
]KD0/K6a0:f][@2TY:@0X:2P09bLW02HV9P0U9BD08b<S029RHT0QHF50861P@1mOGd0MGEe075aL@1]
KFd0JVYZ06IVIP1RHV80FUYJ05MGE`1CDe<R0?ooo`00803oool05@2=SHd0QhN707YjNP1dM7@0KVi^
06QXJ01QHF40Fe]K04m?C`19BDT0@d=303dm?@0g=cL0<S8b02d];@0`<300=SHf03hn?P1?Cdl0EeMG
05mOG`0206MWI`0806UYJ@1/K6`0JFUY06IVIP1RHV80GemO05iNGP1RHV8206=SH`0<06EUI@1RHV80
IFEU06MWI`1VIVH0I6AT069RHP1JFUX0EEEE051@D01<C4`0BDU90P13@d<00`15ADD0B4Q804a<C002
04i>CP0905=CD`1BDU80F5QH05]KF`1OGel0HV9R06EUI@1WIfL0J6QX00<0JFUY02`0Jf][06i^KP1b
LW80Ogmo08N7Q`2@T900W9bL0:ZZZP33`l<0c<c<0=GEe@3IfMT0gMgM0>7Qh@3WinL0j^[Z0>WYj@3`
l?00lo?c0?;blP3^k^h0j^[Z0>OWi`3Shn<0gmoO0=SHf03EeMD0dM7A0<k>cP3;bl/0a<C40<71`@2n
_[h0^k^k0;Rh^02a/K40[Zj^0:^[Z`2XZ:P0YJFU0::RXP2LW9`0VIVI09JFUQh0oooo01D0Hf=S05iN
GP1CDe<0CDe=04Q8B012@T80?Cdm03Lg=`0/;2`09RHV020P800J6QX051@D00d=3@0<30`04A4A01TI
6@0R8R80=cLg0451@@1;Bd/00P1CDe<03@1FEUH0FUYJ05UIF@1FEUH0De=C055AD@1BDU80EEEE05AD
E01CDe<0EeMG05QHF01PH6000P1SHf<01`1RHV80H61P05QHF01DE5@0D51@04e=C@1:BTX00`16ATH2
04Q8B00904Y:BP17AdL0Bd];04];B`1BDU80E5AD05QHF01MGEd0H61P0080HF5Q0180HV9R06=SH`1T
I6@0IVIV06YZJP1^KVh0OGem08J6QP2?Shl0Vi^K0:VYZ@2o_kl0b<S80=7Ad@3Fe]H0fm_K0>3Ph03Z
j^X20>o_k`0K0?KfmP3inOT0moOg0?7al@3[jn/0i^KV0>7Qh@3Kfm/0dM7A0<c<c037alL0`/;20;fm
_@2c/k<0[Zj^0:VYZ@2TY:@0X:2P09JFUP2BTY80SHf=08V9R@24Q8@0Ogmo07IfMP1bLW80KFe]01h0
oooo01D0CDe=04a<C018B4P0ATI604A4A012@T80@41003hn?P0j>SX0=cLg03De=@0b<S80;bl_02TY
:@0/;2`0<C4a03Hf=P0m?Cd0BTY:055AD@1HF5P00P1LG5`00`1NGUh0HV9R06=SH`03069RHP80I6AT
0P1QHF402P1TI6@0JFUY075aL@1cLg<0M7Ad07EeM@1dM7@0LG5a071`L01_Kfl206i^KP0906e]K@1/
K6`0Jf][06YZJP1XJ6P0IfMW06=SH`1TI6@0IVIV0080JVYZ00<0K6a/071`L01aLG400`1`L700;P1a
LG40Lg=c07AdM01fMWH0NGUi08:2PP27QhL0S8b<09:BTP2HV9P0X:2P0:BTY02YZJT0[Jf]0;2`/02c
/k<0_;bl0<30`031`L40aLG50<K6aP34a<@0_kno0;^k^`2f][H0/[:b0:j^[P2UYJD0XJ6Q09fMW@2I
VIT0UIFE08f=S@29RHT0QHF50861P@1mOGd0MGEe075aL@1]KFd0JVYZ06IVIP1RHV80Fe]K05MGE`1C
De<R0?ooo`00803oool07P2=SHd0QXJ607UiN@1cLg<0K6a/06IVIP1OGel0FEUI04a<C015ADD0?clo
03Ti>@0b<S80:RXZ02l_;`0b<S80>CTi0451@@1@D500FUYJ069RHP1WIfL0JFUY06][J`1/K6`0J6QX
06ATI01OGel0FUYJ059BDP<0D51@00<0DU9B05ADE01JFUX00P1MGEd0201LG5`0FUYJ05ADE01ADE40
CDe=04U9B@15ADD0?clo0P0n?Sh00`0o?cl0@D510492@P0304A4A00f04I6AP18B4P0D51@05ADE01G
EeL0FUYJ05eMG@1QHF40IFEU06MWI`1YJFT0K6a/071`L01nOWh0QhN7096AT@2LW9`0Z:RX0;jn_P39
bLT0dm?C0=OGe`3Jf]X0g]kN0>KViP3Xj>P0inOW0>g]k@3`l?00k>c/0>WYj@3Vi^H0h^;R0=oOg`3K
fm/0eMGE0=;BdP3>c/h0bl_;0<S8b032`/80_kno0;bl_02i^KT0][Jf0;2`/02][Jd0ZZZZ0:NWY`2U
YJD0XZ:R09bLW02IVIT0UYJF7P3oool0701SHf<0GUiN05=CD`1=CDd0B4Q80492@P0m?Cd0=cLg02`/
;00V9RH0820P01XJ6P0D51@03@d=00l?3`0C4a<07AdM02LW9`0i>CT0A4A404e=C@1BDU80EEEE05QH
F01MGEd0Fe]K05YJFP1HF5P205MGE`0@05QHF01IFET0Fe]K05eMG@1PH600Hf=S06EUI@1TI6@0Hf=S
061PH01IFET0EEEE059BDP1?Cdl0C4a<04Q8B0<0AdM700T0BDU904];B`1>CTh0D51@059BDP1EEED0
F5QH05iNGP1OGel00P1PH6004`1QHF40HV9R06ATI01VIVH0JFUY06a/K01aLG40P82008V9R@2BTY80
WYjN0:^[Z`31`L40bl_;0=GEe@3Kfm/0g]kN0>CTi03_knl00P3bl_806`3hn?P0o?cl0?Gem@3_knl0
j^[Z0>CTi03Ogml0f][J0<o?c`3:b/X0aLG50<30`02k^k/0/[:b0:f][@2XZ:P0Y:BT09nOW`2FUYH0
TI6A08f=S@28R8P0Q8B407moO`1fMWH0LG5a06e]K@0N0?ooo`0S04i>CP1<C4`0BDU904Q8B016ATH0
A4A40492@P11@D40?3`l03Xj>P0h>3P0=CDe03<c<`0a<C40;bl_038b<P0i>CT0@41004a<C01CDe<0
F5QH05YJFP1LG5`0GemO06EUI@1WIfL0JFUY06a/K01_Kfl0MgMg07YjNP1lO7`0OWin0820P022PX80
0P21PH401P20P800OWin07alO01gMgL0MWIf07EeM@80M7Ad101cLg<01P1dM7@0MGEe07QhN01kNg/0
OWin0861P@80Ph>303<0PH6107moO`1mOGd0NWYj07UiN@1gMgL0N7Qh07YjNP1lO7`0Ogmo08N7Q`2;
Rh/0T92@09JFUP2LW9`0Z:RX0:b/[02a/K40]KFe0;Rh^02l_;`0a<C40<O7a`38b<P0bl_;0<g=c@37
alL0`/;20;fm_@2h^;P0];Bd0:n_[`2VYZH0XZ:R09jNWP2JVYX0UYJF08f=S@29RHT0QHF50861P@1m
OGd0MWIf079bLP1^KVh0JVYZ06IVIP1RHV80Fe]K05MGE`1CDe<08P3oool00200oooo01l0SHf=08J6
QP1iNGT0LW9b06a/K01UIFD0GUiN05MGE`1:BTX0A4A403dm?@0g=cL0<30`02HV9P0];Bd0<S8b03Ti
>@11@D40Cdm?05YJFP1RHV80IfMW06YZJP1[Jf/0KFe]06UYJ@1UIFD0HF5Q05aLG01EEED0De=C0080
DE5A00@0E5AD05IFEP1JFUX0Fe]K0P1IFET01`1GEeL0DU9B04m?C`1<C4`0B4Q804E5A@0m?Cd00P0k
>c/0100l?3`0?clo0492@P14A4@204=3@`0f04E5A@17AdL0CTi>059BDP1EEED0F5QH05]KF`1NGUh0
Hf=S06EUI@1XJ6P0K6a/071`L01nOWh0QXJ6092@T02KVi/0Z:RX0;jn_P38b<P0dM7A0=OGe`3IfMT0
g]kN0>KViP3Xj>P0inOW0>c/k03`l?00j^[Z0>OWi`3Shn<0h>3P0=gMg@3Jf]X0dm?C0=3@d03=cLd0
b/[:0<O7a`31`L40_[jn0;^k^`2h^;P0]KFe0:n_[`2][Jd0ZZZZ0:NWY`2TY:@0XJ6Q09bLW02IVIT0
UYJF7P3oool07@1SHf<0GUiN05=CD`1=CDd0B4Q80492@P0m?Cd0=cLg02/[:`0U9BD0820P01XJ6P0D
51@02@T900l?3`0F5QH07alO02TY:@0j>SX0ADE504e=C@1BDU80EUIF05UIF@1NGUh0GEeM05aLG01K
Fe/0FUYJ0080FEUI00l0FUYJ05]KF`1MGEd0GemO06=SH`1UIFD0I6AT069RHP1OGel0FEUI05EEE@1C
De<0D51@04e=C@19BDT00`17AdL07P19BDT0Bd];051@D01BDU80E5AD05IFEP1HF5P0G5aL05eMG@1N
GUh0GemO061PH01QHF40IFEU06MWI`1ZJVX0KFe]07=cL`21PH40RXZ:09BDU02OWil0[:b/0<;2`P3=
cLd0emOG0=gMg@3Ph>00i^KV0?7al@80m?Cd01/0n_[j0?clo03clo<0k^k^0>WYj@3Shn<0g]kN0=WI
f@3>c/h0bLW90<C4a030`<00^k^k0;6a/@2/[:`0Z:RX0:>SX`2OWil0UIFE096AT@2<S8`0R8R808>3
P`1oOgl0MWIf075aL@1]KFd07P3oool0901>CTh0C4a<04Y:BP18B4P0AdM704E5A@14A4@0@T9203hn
?P0l?3`0>CTi03Lg=`0e=CD0<30`034a<@0f=SH0?Cdm04=3@`1?Cdl0E5AD05QHF01KFe/0GEeM061P
H01WIfL0JFUY06][J`1]KFd0L71`07MgM`1jNWX0O7al07emO@1nOWh0Ogmo0861P@80Ph>300@0PH61
07inOP1jNWX0N7Qh0`1fMWH307MgM`80MGEe03X0MWIf07]kN`1oOgl0PH6108>3P`24Q8@0PX:20820
P01nOWh0O7al07]kN`1iNGT0NWYj07]kN`1lO7`0Ogmo08:2PP2:RXX0SXj>09>CT`2IVIT0WinO0:ZZ
ZP2`/;00]KFe0;Rh^02l_;`0`<300<O7a`3:b/X0bl_;0<k>cP3?cll0alO70<;2`P2n_[h0^KVi0;Bd
]02`/;00YjNW0:>SX`2NWYh0VYZJ09JFUP2>SXh0RXZ:08J6QP22PX80OWin07IfMP1bLW80KVi^06YZ
JP1VIVH0HV9R05]KF`1GEeL0De=C8P3oool00200oooo01l0SHf=08J6QP1hN7P0LW9b06][J`1TI6@0
GEeM05IFEP18B4P0@T9203/k>`0e=CD0;bl_028R8P0[:b/0<30`03Lg=`0o?cl0CTi>05QHF01PH600
IVIV06YZJP1/K6`0KFe]06UYJ@1VIVH0Hf=S05mOG`1HF5P0EUIF0080E5AD00<0De=C05ADE01DE5@0
0`1FEUH03@1EEED0DE5A04i>CP1;Bd/0B4Q804E5A@0m?Cd0>SXj03Lg=`0f=SH0>CTi03dm?@15ADD0
0P16ATH06@18B4P0BDU904i>CP1BDU80E5AD05MGE`1IFET0G5aL065QH@1SHf<0IVIV06YZJP1_Kfl0
OGem08J6QP2?Shl0Vi^K0:JVYP2m_Kd0alO70<k>cP3De=@0f=SH0=gMg@3UiND00P3Xj>P06`3/k>`0
k^k^0>OWi`3Ti>@0hN7Q0=kNgP3Kfm/0f=SH0=7Ad@3>c/h0bl_;0<S8b035aLD0`<300;fm_@2j^[X0
]kNg0;Bd]02_[jl0[:b/0:VYZ@2VYZH0Y:BT0:6QX@2LW9`0VIVI09JFUP0N0?ooo`0M06=SH`1NGUh0
De=C04i>CP18B4P0@d=303dm?@0g=cL0:b/[02DU9@0P82006ATI01@D500820P04A4A01PH600R8R80
:b/[03/k>`16ATH0CDe=05=CD`1GEeL0FUYJ061PH01OGel0GUiN05eMG@1LG5`00`1JFUX00`1KFe/0
GUiN065QH@0206EUI@0:06=SH`1QHF40GUiN05QHF01EEED0De=C051@D01>CTh0BTY:04U9B@80B4Q8
03/0BTY:04a<C01ADE40De=C05ADE01FEUH0EeMG05YJFP1LG5`0GEeM05iNGP1OGel0H61P06EUI@1W
IfL0JVYZ06m_K`1dM7@0PX:208^;R`2EUID0XJ6Q0:f][@35aLD0d=3@0=SHf03Ng]h0hn?S0>SXj03b
l_80mOGe0?KfmP3jn_X0o?cl0?;blP3]kNd0inOW0>;RhP3MgMd0f=SH0<k>cP39bLT0a<C40;no_`2j
^[X0/K6a0:b/[02WYjL0Xj>S09jNWP2EUID0TI6A08b<S028R8P0Ph>307moO`1fMWH0LG5a06e]K@0N
0?ooo`0[04i>CP1=CDd0BTY:04U9B@18B4P0ATI604E5A@13@d<0@41003hn?P0k>c/0>CTi03Hf=P0b
<S80=cLg03`l?012@T80B4Q8059BDP1GEeL0FUYJ05aLG01OGel0HV9R06UYJ@1[Jf/0KFe]06i^KP1a
LG40MWIf07QhN01iNGT0O7al0820P024Q8@0RXZ:08V9R@25QHD0PX:207moO`1jNWX0NGUi07QhN002
07MgM`0307UiN@1jNWX0O7al0080OGem0P1lO7`0201mOGd0Ogmo0820P020P800Ogmo07inOP1mOGd0
O7al0P1kNg/04`1mOGd0OWin07moO`22PX80QHF508b<S02@T900UYJF09bLW02RXZ80[jn_0;Jf]P2j
^[X0_[jn0<30`034a<@0b/[:0<_;b`3=cLd00P3@d=006@38b<P0`l?30;jn_P2j^[X0]KFe0;2`/02W
YjL0Xj>S09nOW`2JVYX0UYJF08j>SP2:RXX0QXJ608:2PP1nOWh0MWIf079bLP1^KVh0JVYZ06IVIP1R
HV80Fe]K05MGE`1CDe<08P3oool00200oooo02@0SHf=08J6QP1hN7P0LG5a06YZJP1SHf<0G5aL05EE
E@17AdL0@41003Ti>@0b<S80;2`/024Q8@0X:2P0;Rh^03@d=00l?3`0C4a<05IFEP1NGUh0IFEU06YZ
JP1/K6`0KFe]06UYJ@1UIFD0I6AT065QH@1KFe/0F5QH05EEE@1CDe<0DE5A04m?C`1CDe<305ADE00Z
05=CD`1@D500CDe=04];B`18B4P0ADE503hn?P0k>c/0>3Ph03De=@0c<c<0=CDe03dm?@12@T80ATI6
04Q8B01;Bd/0Cdm?059BDP1DE5@0EUIF05QHF01IFET0GUiN065QH@1TI6@0JFUY06i^KP1kNg/0Ph>3
08n?S`2IVIT0YJFU0;jn_P38b<P0c/k>0=?Cd`3GemL0fm_K0>CTi03Vi^H0jNWY0P3/k>`06@3UiND0
h^;R0=oOg`3Lg=`0fMWI0=KFeP3@d=00cLg=0<[:bP37alL0a<C40;jn_P2l_;`0^KVi0;Jf]P2d];@0
[Zj^0:^[Z`2YZJT0YZJV0:>SX`2QXJ40Vi^K09VIV@2FUYH07P3oool06P1SHf<0GUiN05=CD`1>CTh0
B4Q804=3@`0m?Cd0=cLg02`/;00U9BD07alO01TI6@0B4Q802PX:01<C4`0K6a/092@T02`/;00m?Cd0
ATI604e=C@1CDe<0F5QH05aLG01RHV80HF5Q0P1NGUh04P1MGEd0G5aL05]KF`1LG5`0H61P069RHP1S
Hf<0I6AT06=SH`1RHV80H61P05eMG@1HF5P0EEEE05=CD`1ADE40Cdm?04a<C0<0BTY:0200Bd];04e=
C@1ADE40De=C05ADE01EEED0EUIF05UIF@1JFUX0Fe]K05eMG@1OGel0HF5Q06IVIP1XJ6P0Jf][071`
L01fMWH0Q8B408b<S02GUiL0Xj>S0:j^[P37alL0d];B0=[JfP3Ph>00iNGU0>[ZjP3clo<0mOGe0?Sh
n080o?cl01T0lO7a0>c/k03Vi^H0hN7Q0=cLg03GemL0cLg=0<S8b033`l<0_[jn0;Vi^@2`/;00Zj^[
0:NWY`2RXZ80WYjN09FEU@2@T900S8b<08N7Q`23Ph<0OWin07IfMP1aLG40KFe]01h0oooo00`0CTi>
04e=C@1;Bd/0BTY:04U9B@18B4P0ATI604E5A@11@D40?clo03dm?@0k>c/203Hf=P0L03`l?012@T80
BDU904e=C@1EEED0FEUI05aLG01NGUh0HF5Q06EUI@1/K6`0KVi^06m_K`1`L700LG5a07EeM@1gMgL0
O7al08>3P`29RHT0S8b<08Z:RP28R8P0QHF508:2PP1oOgl0NWYj07UiN@<0N7Qh00X0NWYj07]kN`1n
OWh0PH6108B4Q026QXH0Q8B40861P@1oOgl0OWin0P1mOGd307alO00C07emO@1oOgl0PH6108:2PP23
Ph<0QHF508R8R02@T900U9BD09ZJVP2PX:00YZJV0;6a/@2h^;P0_[jn0<71`@34a<@0b<S80<g=c@02
0<k>cP80d];B01T0bLW90<C4a02o_kl0^[Zj0;Fe]@2a/K40Z:RX0:>SX`2OWil0Vi^K09JFUP2>SXh0
RXZ:08J6QP22PX80OWin07IfMP1bLW80KVi^06YZJP1VIVH0HV9R05]KF`1GEeL0De=C0280oooo000P
0?ooo`0P08b<S025QHD0MgMg071`L01YJFT0HV9R05]KF`1DE5@0ADE503hn?P0g=cL0;bl_02LW9`0T
92@09bLW02`/;00b<S80>3Ph04Y:BP1CDe<0Fe]K065QH@1WIfL0Jf][06e]K@1YJFT0Hf=S061PH01M
GEd0F5QH05EEE@1CDe<3059BDP0>05=CD`1DE5@0E5AD05=CD`1BDU80Cdm?04e=C@1;Bd/0B4Q804E5
A@10@400?Cdm03Xj>P0h>3P203Hf=P0i03Ph>00j>SX0?Cdm03lo?`14A4@0Bd];04e=C@1@D500DE5A
05ADE01GEeL0G5aL05mOG`1SHf<0IfMW06e]K@1kNg/0Ph>308j>SP2IVIT0YJFU0;fm_@38b<P0c<c<
0=7Ad@3Fe]H0fMWI0>;RhP3Ti>@0j>SX0>_[j`3YjNT0h^;R0=oOg`3Lg=`0fMWI0=KFeP3Cdm<0c/k>
0<_;b`38b<P0aLG50<?3``2m_Kd0^[Zj0;Rh^02e]KD0/k>c0:f][@2[Zj/0Z:RX0:FUY@2SXj<0X:2P
09^KV`2IVIT0UYJF01h0oooo0200Hf=S05iNGP1CDe<0CTi>04U9B@13@d<0?Cdm03Ph>00/;2`09RHV
020P800I6AT04A4A00d=3@0F5QH07QhN02HV9P0];Bd0?Cdm04I6AP1=CDd0De=C05UIF@1NGUh0I6AT
06=SH`1QHF40H61P05mOG`1NGUh0GemO065QH@<0Hf=S00`0HV9R065QH@1PH600GUiN05aLG01GEeL0
EEEE05=CD`1ADE40D51@04e=C@1<C4`204];B`0404a<C01>CTh0DE5A05=CD`80EEEE03D0EUIF05UI
F@1JFUX0GEeM05iNGP1PH600HV9R06IVIP1YJFT0K6a/075aL@1gMgL0QHF508f=S@2IVIT0Y:BT0:n_
[`39bLT0eMGE0=cLg03QhN40inOW0>c/k03emOD0m_Kf0?[jnP3no_h0no_k0?3`l03Zj^X0iNGU0>3P
h03Kfm/0e]KF0<c<c037alL0`/;20;fm_@2h^;P0[jn_0:^[Z`2VYZH0XZ:R09fMW@2DU9@0T92@08^;
R`27QhL0Ph>307inOP1fMWH0LG5a06e]K@0N0?ooo`0P04i>CP1=CDd0C4a<04];B`1:BTX0BDU904Q8
B016ATH0A4A40492@P10@400?Cdm03Ti>@0h>3P0@D5104Q8B01>CTh0DU9B05UIF@1LG5`0GemO069R
HP1UIFD0J6QX06m_K`1aLG40M7Ad07MgM`1hN7P0Ng]k0820P025QHD308V9R@0608N7Q`25QHD0PX:2
0820P01nOWh0NWYj101iNGT02`1jNWX0O7al07inOP20P800Ph>308F5Q@29RHT0RXZ:08V9R@27QhL0
Q8B40080PH6100<0PX:208>3P`23Ph<00P23Ph<0;@24Q8@0QXJ608V9R@2<S8`0TY:B09NGU`2MWId0
XJ6Q0:NWY`2e]KD0_Kfm0<;2`P35aLD0bLW90<c<c03@d=00dM7A0=?Cd`3Fe]H0dm?C0<W9b@34a<@0
_kno0;^k^`2f][H0/K6a0:RXZ02TY:@0WinO09^KV`2GUiL0SXj>08Z:RP26QXH0PX:207inOP1fMWH0
LW9b06i^KP1ZJVX0IVIV069RHP1KFe/0EeMG05=CD`0R0?ooo`00803oool0302<S8`0QHF507MgM`1_
Kfl0J6QX065QH@1IFET0DU9B0492@P0j>SX0<S8b02TY:@80820P014092@T02/[:`0^;Rh0=3@d04A4
A01=CDd0EEEE05aLG01SHf<0J6QX06e]K@1ZJVX0IVIV06=SH`1PH600FUYJ05QHF00205MGE`80EUIF
0P1EEED0:@1DE5@0De=C059BDP1?Cdl0CTi>04a<C01:BTX0B4Q804A4A012@T80@41003hn?P0m?Cd0
?3`l03dm?@0n?Sh0?clo0410@012@T80ATI604Q8B01;Bd/0CTi>051@D01DE5@0FEUI05aLG01PH600
IVIV06][J`1hN7P0P82008^;R`2FUYH0XZ:R0;^k^`37alL0b<S80<g=c@3De=@0eMGE0080h>3P01`0
iNGU0>KViP3Rh^80gMgM0=[JfP3GemL0eMGE0=;BdP3?cll0b/[:0<O7a`35aLD0`/;20<30`02k^k/0
^;Rh0;Jf]P2c/k<0/K6a0:b/[02YZJT0YjNW0:BTY02RXZ80X:2P09^KV`2HV9P0UYJF7P3oool07@1S
Hf<0GUiN05ADE01>CTh0BDU904A4A00n?Sh0>CTi02d];@0W9bL0820P01XJ6P0B4Q805ADE01`L700S
8b<0:2PX02h^;P0n?Sh0ATI604e=C@1DE5@0Fe]K061PH01WIfL0IVIV06EUI@1TI6@0Hf=S00@0HV9R
0P1QHF402P1OGel0GUiN05eMG@1KFe/0FUYJ05IFEP1EEED0De=C059BDP1@D50204i>CP80CDe=0P1>
CTh06`1@D500DU9B05=CD`1DE5@0EUIF05QHF01JFUX0G5aL05eMG@1OGel0HV9R06MWI`1ZJVX0KVi^
07AdM01iNGT0QhN7092@T02KVi/0YjNW0;Bd]03>c/h0g=cL0=oOg`3UiND0k>c/0>k^kP020?Shn080
o_kn01X0n?Sh0>g]k@3Xj>P0h^;R0=gMg@3Hf=P0dm?C0<[:bP35aLD0`<300;^k^`2g]kL0[Zj^0:VY
Z@2UYJD0X:2P09bLW02CTi<0Shn?08^;R`26QXH0PX:207inOP1eMGD0LG5a06e]KAh0oooo00D0Cdm?
04i>CP1=CDd0CDe=04a<C00204];B`0H04Y:BP19BDT0B4Q804I6AP15ADD0@d=304I6AP1<C4`0DU9B
05EEE@1IFET0H61P06=SH`1VIVH0J6QX06a/K01^KVh0M7Ad07EeM@1gMgL0NGUi07]kN`20P800PX:2
0P23Ph<208:2PP050820P01oOgl0OWin07alO01kNg/00P1hN7P307MgM`0607UiN@1jNWX0Ng]k07em
O@1nOWh0P8200P23Ph<208B4Q0L0QHF502h0QhN708V9R@2;Rh/0SHf=092@T02IVIT0WYjN0:>SX`2Y
ZJT0/;2`0;no_`37alL0bl_;0<k>cP3Bd]80dm?C0=OGe`3Hf=P0g=cL0=_Kf`3EeMD0bl_;0<K6aP30
`<00_;bl0;Ng]`2b/[80ZJVY0:BTY02PX:00Vi^K09NGU`2?Shl0RXZ:08J6QP22PX80OWin07IfMP1b
LW80KVi^06YZJP1VIVH0HV9R05]KF`1GEeL0De=C8P3oool00200oooo0240S8b<08F5Q@1fMWH0Kfm_
06QXJ01PH600F5QH055AD@11@D40>3Ph030`<00V9RH071`L01dM7@0R8R80:BTY02d];@0c<c<0@D51
04Y:BP1BDU80FUYJ065QH@1VIVH0KFe]06YZJP1WIfL0I6AT069RHP1LG5`0Fe]K05YJFP1HF5P00P1G
EeL03`1FEUH0EEEE05EEE@1DE5@0De=C051@D01>CTh0CDe=04];B`19BDT0ATI604A4A013@d<0@D51
0410@00203lo?`0h0410@011@D40@T9204=3@`16ATH0B4Q804Y:BP1=CDd0D51@059BDP1HF5P0G5aL
061PH01UIFD0Jf][07QhN021PH40Rh^;09JFUP2RXZ80_;bl0<S8b039bLT0c<c<0=;BdP3Cdm<0g]kN
0=oOg`3Ti>@0h^;R0=oOg`3Jf]X0emOG0=GEe@3Bd]80d=3@0<g=c@38b<P0a/K60<?3``31`L40_[jn
0;Vi^@2g]kL0]KFe0;:b/P2`/;00Zj^[0:VYZ@2VYZH0Y:BT0::RXP2OWil0Vi^K09RHV02FUYHN0?oo
o`0M06=SH`1NGUh0E5AD04m?C`1:BTX0A4A403lo?`0j>SX0;Rh^02PX:00R8R806a/K01@D500G5aL0
7AdM02@T900Y:BT0;bl_03hn?P16ATH0CDe=05EEE@1LG5`0HF5Q06QXJ01WIfL0IVIV06EUI@1TI6@0
0P1SHf<03`1RHV80HF5Q065QH@1PH600GUiN05eMG@1LG5`0FUYJ05UIF@1FEUH0E5AD05=CD`1BDU80
DE5A04m?C`0404i>CP0j04m?C`1@D500DE5A059BDP1DE5@0EEEE05QHF01IFET0Fe]K05eMG@1OGel0
HF5Q06MWI`1ZJVX0Kfm_07EeM@1jNWX0R8R8096AT@2MWId0ZJVY0;Fe]@3AdM40g]kN0>7Qh@3WinL0
kNg]0>o_k`3inOT0n_[j0?ooo`3lo?`0m_Kf0>_[j`3Vi^H0hN7Q0=cLg03GemL0d];B0<S8b034a<@0
_kno0;Zj^P2f][H0[Jf]0:RXZ02TY:@0X:2P09^KV`2CTi<0SXj>08Z:RP26QXH0PX:207inOP1eMGD0
LG5a06e]KAh0oooo0P1?Cdl204i>CP<0CDe=00@0C4a<04];B`1;Bd/0BTY:0P19BDT04P1=CDd0DE5A
05ADE01GEeL0G5aL06=SH`1VIVH0J6QX06][J`1_Kfl0LG5a07IfMP1gMgL0N7Qh07YjNP1kNg/0OWin
07moO`@0P82000D0OWin07emO@1lO7`0NWYj07UiN@0207MgM`<0MWIf00L0MgMg07QhN01iNGT0NWYj
07alO01mOGd0P8200080PH6100@0PX:208>3P`24Q8@0Q8B40P25QHD208J6QP0^08V9R@2:RXX0S8b<
092@T02BTY80VYZJ09jNWP2VYZH0[Jf]0;>c/`32`/80b/[:0<k>cP3Bd]80e]KF0=OGe`3Kfm/0g=cL
0=oOg`3Lg=`0e]KF0<_;b`36a/H0`L710;bl_02g]kL0/[:b0:VYZ@2TY:@0X:2P09^KV`2GUiL0Shn?
08Z:RP26QXH0PX:207inOP1fMWH0LW9b06i^KP1ZJVX0IVIV069RHP1KFe/0EeMG05=CDb80oooo000P
0?ooo`0T08b<S025QHD0MWIf06m_K`1WIfL0H61P05QHF01@D500@41003Lg=`0^;Rh09BDU01/K6`0J
6QX0820P02LW9`0/;2`0<C4a03lo?`17AdL0Cdm?05MGE`1OGel0I6AT06][J`1ZJVX0J6QX06EUI@1S
Hf<0GUiN05aLG01KFe/0FUYJ05UIF@1HF5P0EeMG0P1FEUH0301EEED0E5AD055AD@1@D500CTi>04e=
C@1;Bd/0B4Q804I6AP15ADD0A4A404=3@`<0@T9203L0@d=304A4A015ADD0AdM704U9B@1;Bd/0CDe=
04m?C`1BDU80F5QH05]KF`1OGel0IFEU06YZJP1hN7P0PH6108^;R`2FUYH0XZ:R0;bl_037alL0b/[:
0<_;b`3@d=00dM7A0=_Kf`3Ng]h0hN7Q0=kNgP3Lg=`0emOG0=GEe@3Bd]80d=3@0<g=c@3;bl/0a/K6
0<C4a032`/80_kno0;fm_@2h^;P0][Jf0;Bd]02a/K40[jn_0:ZZZP2XZ:P0YZJV0:>SX`2QXJ40WinO
09ZJVP2HV9P0UYJF01h0oooo01d0I6AT05mOG`1DE5@0Cdm?04Y:BP15ADD0@41003Xj>P0_;bl0:BTY
02<S8`0M7Ad05QHF01PH600N7Qh092@T02XZ:P0`<300?Shn04I6AP1>CTh0EEEE05eMG@1RHV80JFUY
06QXJ01WIfL0IVIV06EUI@0206=SH`0>069RHP1QHF40H61P05mOG`1MGEd0G5aL05]KF`1JFUX0F5QH
05EEE@1DE5@0De=C059BDP1ADE4604m?C`0i051@D01ADE40DU9B05=CD`1EEED0EeMG05UIF@1KFe/0
GEeM05mOG`1QHF40IfMW06][J`1`L700MGEe07]kN`29RHT0Ti>C09nOW`2ZZZX0]kNg0=CDe03Ph>00
iNGU0>WYj@3^k^h0l?3`0?Win@3moOd0oooo0?[jnP3dm?@0j^[Z0>CTi03Ogml0f][J0=GEe@3AdM40
alO70<;2`P2n_[h0^KVi0;Fe]@2/[:`0Z:RX0:>SX`2OWil0Vi^K09:BTP2>SXh0RXZ:08J6QP21PH40
OGem07EeM@1aLG40KFe]01h0oooo101?Cdl904i>CP0;055AD@1DE5@0EeMG05YJFP1NGUh0IFEU06QX
J01/K6`0Kfm_07=cL`1eMGD00P1hN7P0101iNGT0Ng]k07alO01mOGd407inOP0807emO@1kNg/0NWYj
07UiN@1hN7P0MgMg07IfMP1eMGD307AdM080MWIf00T0N7Qh07UiN@1jNWX0Ng]k07emO@1nOWh0Ogmo
0820P021PH400P23Ph<0<P24Q8@0QHF508J6QP26QXH0RHV908^;R`2>SXh0TI6A09BDU02LW9`0XZ:R
0:VYZ@2_[jl0][Jf0<K6aP3=cLd0dM7A0=KFeP3IfMT0fm_K0=oOg`3QhN40h^;R0=gMg@3GemL0c<c<
0<K6aP31`L40_;bl0;Ng]`2b/[80ZJVY0:BTY02PX:00Vi^K09NGU`2?Shl0RXZ:08J6QP22PX80OWin
07IfMP1bLW80KVi^06YZJP1VIVH0HV9R05]KF`1GEeL0De=C8P3oool00200oooo0380S8b<08F5Q@1f
MWH0KVi^06MWI`1OGel0EeMG04m?C`0o?cl0=SHf02d];@0T92@06QXJ01HF5P0L71`08R8R02PX:00_
;bl0?3`l04A4A01=CDd0E5AD05aLG01RHV80JVYZ06UYJ@1XJ6P0IVIV06=SH`1OGel0GUiN05aLG01K
Fe/0FUYJ05UIF@1HF5P0EeMG05IFEP1EEED0E5AD059BDP1ADE40Cdm?04i>CP1=CDd0BTY:04Q8B017
AdL0ATI604E5A@@0A4A401H0ADE504I6AP18B4P0BDU904];B`1=CDd0Cdm?055AD@1GEeL0Fe]K05mO
G`1TI6@0JVYZ07MgM`21PH40Rh^;09JFUP2RXZ80^k^k0<K6aP3;bl/0c<c<0P3AdM407P3Fe]H0g=cL
0=gMg@3Kfm/0f=SH0=CDe03Bd]80d=3@0<g=c@3;bl/0bLW90<C4a032`/80`<300;jn_P2k^k/0]kNg
0;Fe]@2b/[80/;2`0:j^[P2ZZZX0YjNW0:FUY@2SXj<0XJ6Q09nOW`2JVYX0V9RH09JFUQh0oooo01P0
I6AT05mOG`1EEED0D51@04];B`16ATH0@D5103/k>`0`<300:b/[02DU9@0O7al06ATI01PH600N7Qh0
9BDU02/[:`0a<C40?clo04I6AP1>CTh0EEEE05eMG@1RHV8206UYJ@0@06QXJ01WIfL0IVIV06ATI01S
Hf<0HV9R065QH@1OGel0GUiN05aLG01KFe/0FUYJ05UIF@1GEeL0EEEE05ADE080DU9B00<0DE5A051@
D01?Cdl0101?Cdl0>@1@D500DE5A059BDP1CDe<0EEEE05MGE`1IFET0Fe]K05eMG@1OGel0HF5Q06QX
J01/K6`0LG5a07IfMP1lO7`0Rh^;09FEU@2PX:00[:b/0;Zj^P3Fe]H0h^;R0>OWi`3Zj^X0l?3`0?;b
lP3jn_X0oooo0?gmo@3hn?P0l_;b0>SXj03Shn<0g]kN0=WIf@3De=@0clo?0<K6aP31`L40_Kfm0;Rh
^02d];@0Zj^[0:NWY`2RXZ80WYjN09ZJVP2BTY80SHf=08V9R@25QHD0PH6107emO@1eMGD0LG5a06e]
K@0N0?ooo`80Cdm?1P1@D503055AD@80DU9B00/0EUIF05UIF@1LG5`0H61P069RHP1XJ6P0K6a/06m_
K`1bLW80MGEe07QhN00207YjNP80Ng]k0P1lO7`207emO@80O7al00L0Ng]k07UiN@1hN7P0MgMg07If
MP1eMGD0M7Ad00@0Lg=c00L0M7Ad07EeM@1fMWH0MgMg07QhN01iNGT0O7al0080OGem03H0OWin07mo
O`21PH40PX:208B4Q025QHD0QXJ608N7Q`2:RXX0SHf=092@T02CTi<0UYJF09nOW`2UYJD0Zj^[0;6a
/@2j^[X0b/[:0=7Ad@3De=@0emOG0=_Kf`3Ogml0i>CT0>KViP3Shn<0gMgM0=OGe`3<c<`0a/K60<71
`@2l_;`0]kNg0;:b/P2YZJT0Y:BT0:2PX02KVi/0UiNG08n?S`2:RXX0QXJ608:2PP1nOWh0MWIf079b
LP1^KVh0JVYZ06IVIP1RHV80Fe]K05MGE`1CDe<R0?ooo`00803oool0602<S8`0QHF507IfMP1^KVh0
IfMW05mOG`1GEeL0Cdm?03hn?P0f=SH0;2`/02<S8`0I6AT04a<C01TI6@0O7al09BDU02`/;00j>SX0
@T9204Y:BP1BDU80FUYJ061PH080J6QX00X0IfMW06IVIP1TI6@0H61P05mOG`1NGUh0G5aL05]KF`1J
FUX0FEUI0P1GEeL0301FEUH0EEEE05=CD`1BDU80DE5A04m?C`1>CTh0C4a<04Y:BP19BDT0B4Q804M7
A`D0ATI601D0AdM704U9B@1;Bd/0C4a<04i>CP1@D500DU9B05MGE`1KFe/0H61P06ATI01ZJVX0MgMg
0861P@2:RXX0UYJF0::RXP2j^[X0a<C40<[:bP3<c<`00P3@d=007P3Cdm<0fMWI0=SHf03GemL0eMGE
0=7Ad@3?cll0cLg=0<_;b`39bLT0alO70<?3``30`<00_[jn0;bl_02j^[X0][Jf0;Bd]02a/K40[jn_
0:f][@2YZJT0YjNW0:FUY@2RXZ80X:2P09jNWP2JVYX0V9RH09JFUQh0oooo01P0I6AT05mOG`1EEED0
D51@04a<C017AdL0@T9203`l?00b<S80;2`/02LW9`0Q8B406a/K01TI6@0O7al09RHV02/[:`0a<C40
?clo04I6AP1>CTh0EUIF05eMG@1RHV8306UYJ@0?06MWI`1VIVH0I6AT069RHP1QHF40H61P05mOG`1N
GUh0G5aL05YJFP1IFET0F5QH05MGE`1DE5@0De=C0080DU9B00<0DE5A051@D01?Cdl0101?Cdl2055A
D@0g059BDP1CDe<0EEEE05MGE`1IFET0Fe]K05eMG@1OGel0HV9R06QXJ01]KFd0LW9b07MgM`1mOGd0
SHf=09NGU`2RXZ80[jn_0;fm_@3IfMT0hn?S0>WYj@3/k>`0l_;b0?Gem@3kno/0oooo0?_kn`3emOD0
l?3`0>KViP3QhN40g=cL0=OGe`3Bd]80c/k>0<G5a@30`<00_;bl0;Ng]`2c/k<0ZZZZ0:JVYP2RXZ80
WIfM09VIV@2ATI40SHf=08V9R@25QHD0PH6107emO@1eMGD0LG5a06e]K@0N0?ooo`0304m?C`1@D500
D51@00<0DE5A0P1BDU804@1CDe<0E5AD05EEE@1EEED0EUIF05]KF`1NGUh0HF5Q06=SH`1UIFD0Jf][
06i^KP1bLW80MGEe07QhN01jNWX0Ng]k00@0O7al0`1kNg/207YjNP0707UiN@1gMgL0MWIf07EeM@1d
M7@0Lg=c079bLP03075aL@10079bLP1cLg<0Lg=c07AdM01eMGD0MWIf07MgM`1jNWX0Ng]k07alO01n
OWh0Ogmo0861P@22PX80Ph>308F5Q@26QXH0QhN708b<S02>SXh0TI6A09BDU02HV9P0XZ:R0:RXZ02^
[Zh0][Jf0;jn_P3?cll0eMGE0=OGe`3Kfm/0gmoO0>?Sh`3YjNT0j^[Z0>CTi03MgMd0emOG0<c<c036
a/H0`L710;bl_02g]kL0/[:b0:VYZ@2TY:@0X:2P09^KV`2GUiL0SXj>08Z:RP26QXH0PX:207inOP1f
MWH0LW9b06i^KP1ZJVX0IVIV069RHP1KFe/0EeMG05=CDb80oooo000P0?ooo`0I08b<S025QHD0MWIf
06i^KP1WIfL0GemO05MGE`1?Cdl0?Shn03De=@0/;2`08b<S01PH600;2`/04A4A01LG5`0O7al09RHV
03De=@0n?Sh0ADE504i>CP1FEUH0Fe]K06=SH`0206EUI@0606ATI01SHf<0HF5Q061PH01OGel0GEeM
0P1LG5`03@1JFUX0FEUI05QHF01HF5P0EeMG05EEE@1DE5@0De=C059BDP1ADE40Cdm?04i>CP1=CDd0
0P1<C4`00`1;Bd/0BTY:04Y:BP0304Y:BP0d04a<C01=CDd0CTi>04m?C`1@D500DU9B05MGE`1KFe/0
GemO06ATI01YJFT0N7Qh0820P02:RXX0UIFE0::RXP2j^[X0_kno0<G5a@39bLT0clo?0=3@d03Cdm<0
d];B0=7Ad@3@d=00clo?0<c<c03:b/X0b<S80<K6aP34a<@0`l?30;no_`2m_Kd0^k^k0;Vi^@2g]kL0
/k>c0;6a/@2_[jl0[Jf]0:^[Z`2WYjL0YJFU0:>SX`2QXJ40WinO09fMW@2IVIT0UiNG09FEUAh0oooo
02H0I6AT05mOG`1FEUH0DU9B04e=C@18B4P0A4A403lo?`0e=CD0<30`02/[:`0V9RH0820P01/K6`0O
7al092@T02/[:`0a<C40?clo04M7A`1>CTh0EUIF05eMG@1RHV80J6QX06UYJ@1XJ6P0IfMW06IVIP1S
Hf<0HV9R061PH01OGel0GEeM05aLG01JFUX0F5QH05MGE`80EUIF0P1CDe<00`1BDU80DE5A055AD@02
051@D080Cdm?0P1@D500>@1ADE40DU9B05=CD`1DE5@0EEEE05QHF01JFUX0G5aL05iNGP1QHF40Hf=S
06YZJP1^KVh0Lg=c07YjNP20P800TI6A09^KV`2WYjL0]KFe0<?3``3Ogml0iNGU0>_[j`3`l?00moOg
0?Win@3moOd0n_[j0?Gem@3`l?00jn_[0>;RhP3MgMd0f=SH0=CDe03?cll0bl_;0<;2`P2m_Kd0^KVi
0;Fe]@2a/K40Z:RX0:BTY02PX:00W9bL09RHV02@T900S8b<08R8R024Q8@0P82007alO01dM7@0L71`
06a/K00N0?ooo`80D51@0P1BDU805@1CDe<0E5AD05EEE@1FEUH0F5QH05YJFP1KFe/0GEeM05mOG`1V
IVH0IFEU06MWI`1YJFT0Jf][075aL@1cLg<0MgMg07YjNP1lO7`0OWin07moO`0207inOP0;07emO@1l
O7`0NWYj07UiN@1hN7P0MgMg07IfMP1eMGD0Lg=c079bLP1aLG400P1`L70506i^KP0o06m_K`1`L700
L71`075aL@1bLW80M7Ad07IfMP1hN7P0NGUi07]kN`1lO7`0Ogmo0861P@23Ph<0QHF508N7Q`29RHT0
SXj>096AT@2DU9@0VIVI09fMW@2XZ:P0[Zj^0;Jf]P2o_kl0b<S80=WIf@3MgMd0h>3P0>?Sh`3WinL0
j^[Z0>c/k03Xj>P0h^;R0=cLg03Fe]H0bl_;0<K6aP31`L40_;bl0;Ng]`2b/[80Z:RX0:BTY02OWil0
Vi^K09NGU`2>SXh0RXZ:08J6QP22PX80OWin07IfMP1bLW80KVi^06YZJP1VIVH0HV9R05]KF`1GEeL0
De=C0280oooo000P0?ooo`0K08b<S025QHD0MWIf06i^KP1WIfL0GemO05MGE`1?Cdl0?clo03Hf=P0]
;Bd08b<S01TI6@0820P030`<01<C4`0J6QX08R8R038b<P0k>c/0@d=304];B`1CDe<0FEUI065QH@1S
Hf<0I6AT0080Hf=S00L0HF5Q061PH01OGel0GUiN05eMG@1LG5`0FUYJ0080FEUI0P1HF5P01P1FEUH0
EEEE05EEE@1DE5@0De=C055AD@80D51@00<0Cdm?04i>CP1=CDd01@1<C4`0=01=CDd0CTi>04m?C`1A
DE40DU9B05=CD`1HF5P0Fe]K05mOG`1TI6@0JVYZ07QhN021PH40RXZ:09FEU@2RXZ80^KVi0;fm_@33
`l<0b<S80<k>cP3?cll0dM7A0=3@d03>c/h0cLg=0<c<c039bLT0alO70<K6aP34a<@0`/;20<71`@2m
_Kd0^k^k0;Vi^@2g]kL0][Jf0;:b/P2`/;00[Zj^0:b/[02ZZZX0YjNW0:FUY@2SXj<0XJ6Q09nOW`2M
WId0VIVI09NGU`2EUIDN0?ooo`0I06ATI01PH600EeMG059BDP1>CTh0BDU904E5A@10@400=cLg038b
<P0];Bd0:2PX02<S8`0J6QX07alO02@T900[:b/0<C4a03lo?`17AdL0CTi>05IFEP1MGEd0HF5Q06MW
I`0206QXJ00>06MWI`1UIFD0HV9R065QH@1PH600GUiN05eMG@1LG5`0FEUI05QHF01GEeL0EUIF05EE
E@1CDe<2059BDP80DE5A0P1@D500101?Cdl0D51@051@D01@D502059BDP0g05=CD`1EEED0EEEE05QH
F01KFe/0GEeM05mOG`1QHF40I6AT06][J`1`L700MGEe07]kN`22PX80Ti>C09jNWP2ZZZX0^;Rh0<K6
aP3QhN40i^KV0>c/k03bl_80nOWi0?_kn`3lo?`0moOg0?;blP3^k^h0jNWY0>3Ph03Kfm/0e]KF0=;B
dP3=cLd0bLW90<30`02l_;`0^;Rh0;>c/`2_[jl0YjNW0:>SX`2OWil0Vi^K09NGU`2?Shl0Rh^;08N7
Q`23Ph<0P82007alO01dM7@0L71`06a/K00N0?ooo`0Q051@D01ADE40De=C05=CD`1DE5@0EEEE05IF
EP1HF5P0FUYJ05aLG01NGUh0H61P06=SH`1WIfL0JFUY06a/K01]KFd0L71`07AdM01fMWH0NGUi07al
O01nOWh0Ogmo0820P01oOgl0OWin07emO@1kNg/0NGUi07QhN01gMgL0MGEe0080M7Ad00H0LW9b075a
L@1`L700Kfm_06i^KP1]KFd406a/K00o06e]K@1^KVh0KVi^06m_K`1aLG40LW9b07EeM@1fMWH0N7Qh
07YjNP1kNg/0OWin0820P022PX80QHF508N7Q`2:RXX0Shn?09>CT`2GUiL0Vi^K09nOW`2[Zj/0/[:b
0;^k^`34a<@0c<c<0=gMg@3QhN40i>CT0>OWi`3[jn/0kNg]0>c/k03WinL0hN7Q0=cLg03Fe]H0bl_;
0<K6aP30`<00^k^k0;Jf]P2a/K40Z:RX0:>SX`2OWil0Vi^K09JFUP2>SXh0RXZ:08F5Q@21PH40OGem
07EeM@1bLW80KVi^06YZJP1VIVH0HV9R05YJFP1GEeL0De=C0280oooo000P0?ooo`0=08b<S025QHD0
MWIf06m_K`1WIfL0GemO05QHF01@D500?clo03Lg=`0^;Rh092@T01/K6`0200H61P0;00d=3@0E5AD0
7AdM02d];@0g=cL0@41004U9B@1ADE40EeMG05mOG`1QHF400`1RHV82061PH00505mOG`1NGUh0GEeM
05aLG01KFe/00P1JFUX205UIF@0505QHF01GEeL0EUIF05IFEP1EEED00P1CDe<2055AD@80D51@00<0
Cdm?04i>CP1>CTh00`1>CTh0501?Cdl0D51@059BDP1CDe<0E5AD05QHF01LG5`0H61P06ATI01YJFT0
MgMg0820P02:RXX0U9BD0:2PX02h^;P0_;bl0<30`036a/H0c<c<0P3>c/h07@3=cLd0c<c<0<[:bP39
bLT0a/K60<G5a@33`l<0`/;20<30`02n_[h0^k^k0;Vi^@2h^;P0][Jf0;Bd]02a/K40[jn_0:f][@2[
Zj/0ZJVY0:JVYP2TY:@0XZ:R0:2PX02OWil0WIfM09VIV@2GUiL0UIFE01h0oooo01T0I6AT061PH01G
EeL0De=C04m?C`1:BTX0ATI60492@P0i>CT0=3@d02l_;`0[:b/09RHV01dM7@0O7al092@T02/[:`0a
<C40?clo04I6AP1>CTh0EEEE05aLG01PH600IVIV0080IfMW00l0IVIV06ATI01QHF40H61P05mOG`1M
GEd0G5aL05]KF`1HF5P0EeMG05IFEP1EEED0E5AD05=CD`1BDU800`1ADE45051@D00j055AD@1BDU80
De=C05ADE01EEED0EUIF05UIF@1KFe/0GUiN061PH01RHV80IFEU06a/K01aLG40MgMg07emO@24Q8@0
UYJF0:6QX@2^[Zh0^k^k0<W9b@3Shn<0j>SX0>g]k@3dm?@0n_[j0?clo03inOT0m?Cd0?3`l03[jn/0
inOW0=gMg@3IfMT0e=CD0=3@d03<c<`0alO70;no_`2j^[X0][Jf0;:b/P2^[Zh0YZJV0::RXP2NWYh0
VYZJ09JFUP2?Shl0Rh^;08N7Q`23Ph<0Ogmo07]kN`1dM7@0L71`06a/K1h0oooo02D0D51@055AD@1C
De<0E5AD05EEE@1GEeL0F5QH05UIF@1MGEd0GUiN065QH@1SHf<0IVIV06a/K01`L700LG5a07=cL`1e
MGD0N7Qh07YjNP1kNg/0OGem07moO`20P800PH610820P01nOWh0OGem07]kN`1hN7P0MgMg07IfMP1d
M7@0Lg=c079bLP1`L700KVi^0080KFe]00<0K6a/06][J`1ZJVX00`1ZJVX0?`1[Jf/0K6a/06a/K01^
KVh0Kfm_071`L01cLg<0M7Ad07IfMP1hN7P0NGUi07inOP20P800PX:208F5Q@27QhL0RXZ:096AT@2D
U9@0VIVI09jNWP2SXj<0/;2`0;Rh^031`L40bLW90=;BdP3QhN40iNGU0>SXj03/k>`0kno_0?3`l03/
k>`0i^KV0>3Ph03Kfm/0eMGE0<[:bP35aLD0`<300;^k^`2f][H0/K6a0:RXZ02SXj<0WinO09ZJVP2F
UYH0SHf=08V9R@25QHD0PH6107emO@1eMGD0LG5a06e]K@1ZJVX0IVIV069RHP1JFUX0EeMG05=CD`0R
0?ooo`00803oool06`2<S8`0QHF507IfMP1_Kfl0IfMW061PH01HF5P0D51@0410@00h>3P0;bl_02HV
9P0M7Ad020P800<30`0820P0410@01LG5`0Y:BT0<S8b03`l?016ATH0CTi>05EEE@1MGEd0GemO061P
H002065QH@03061PH01OGel0GemO0080GUiN00@0GEeM05aLG01KFe/0Fe]K0P1JFUX00`1IFET0F5QH
05QHF00205MGE`0605IFEP1EEED0E5AD05ADE01CDe<0DU9B0`1ADE43051@D00c055AD@1BDU80De=C
05ADE01EEED0FUYJ05aLG01PH600IFEU06YZJP1gMgL0Ogmo08Z:RP2DU9@0WinO0;Rh^02l_;`0_[jn
0<G5a@39bLT0c<c<0<_;b`3:b/X0bLW90<O7a`36a/H0a<C40<;2`P31`L40_kno0;jn_P2l_;`0^KVi
0;Rh^02f][H0];Bd0;>c/`2_[jl0[Zj^0:b/[02ZZZX0ZJVY0:FUY@2SXj<0XZ:R0:2PX02NWYh0W9bL
09VIV@2GUiL0UIFE01h0oooo01X0I6AT061PH01HF5P0E5AD051@D01;Bd/0AdM704=3@`0j>SX0=SHf
038b<P0^;Rh0:BTY024Q8@0O7al092@T02/[:`0a<C40?Shn04E5A@1=CDd0EEEE05]KF`1PH600IFEU
06IVIP80IFEU00d0Hf=S065QH@1OGel0GUiN05aLG01KFe/0FUYJ05MGE`1FEUH0EEEE05ADE01CDe<0
DU9B00<0DE5A1P1@D500>P1ADE40DU9B05=CD`1DE5@0EEEE05MGE`1JFUX0G5aL05mOG`1QHF40Hf=S
06IVIP1^KVh0Lg=c07UiN@1oOgl0QXJ609ZJVP2UYJD0/K6a0;jn_P3;bl/0iNGU0>[ZjP3_knl0m_Kf
0?[jnP3lo?`0m_Kf0?;blP3]kNd0jNWY0>CTi03Kfm/0emOG0=;BdP3>c/h0b/[:0<G5a@2m_Kd0^KVi
0;Fe]@2a/K40[Jf]0:FUY@2QXJ40WIfM09VIV@2EUID0SXj>08Z:RP26QXH0Ph>307moO`1kNg/0M7Ad
071`L01/K6`N0?ooo`0V051@D01ADE40E5AD05EEE@1FEUH0F5QH05UIF@1KFe/0GUiN065QH@1SHf<0
IVIV06UYJ@1aLG40Lg=c07IfMP1hN7P0NGUi07alO01mOGd0OWin0820P021PH40PX:20861P@20P800
OWin07alO01jNWX0MgMg07IfMP1dM7@0Lg=c075aL@1`L700KFe]06a/K01[Jf/206YZJPD0J6QX0P1Y
JFT07@1ZJVX0Jf][06a/K01^KVh0LG5a07=cL`1dM7@0MWIf07QhN01mOGd0P82008:2PP25QHD0R8R8
08^;R`2BTY80UYJF09^KV`2PX:00YZJV0;Fe]@2m_Kd0a/K60<o?c`3GemL0i>CT0>SXj03/k>`0l?3`
0080l_;b01h0jn_[0>GUi@3Ph>00f][J0=CDe03:b/X0a<C40;no_`2j^[X0]KFe0;2`/02WYjL0Xj>S
09jNWP2JVYX0UIFE08f=S@29RHT0QHF50861P@1mOGd0MGEe075aL@1]KFd0JFUY06IVIP1RHV80FUYJ
05MGE`1CDe<R0?ooo`00803oool06P2<S8`0QHF507MgM`1_Kfl0J6QX061PH01IFET0DE5A0451@@0i
>CT0<C4a02PX:00O7al030`<00820P030`<02@T9014A4@0S8b<0;Rh^03Ph>012@T80C4a<05=CD`1K
Fe/0GEeM1P1OGel205iNGP0305eMG@1LG5`0G5aL00<0Fe]K0P1JFUX305UIF@0405QHF01GEeL0EUIF
05IFEP80EEEE0P1DE5@505=CD`80E5AD0300EEEE05IFEP1KFe/0GEeM065QH@1UIFD0JVYZ07MgM`1o
Ogl0RHV909BDU02NWYh0]KFe0;Zj^P2n_[h0a<C40<S8b03:b/X0b<S80<O7a`36a/H0aLG50<C4a031
`L40`<300;no_`2m_Kd0_;bl0;Zj^P2h^;P0][Jf0;Fe]@2c/k<0/K6a0:j^[P2][Jd0Zj^[0:VYZ@2X
Z:P0Y:BT0:>SX`2QXJ40WinO09jNWP2LW9`0VIVI09NGU`2EUIDN0?ooo`0V06EUI@1QHF40FEUI05EE
E@1ADE40C4a<04Q8B014A4@0?3`l03Ph>00d=3@0<30`02`/;00U9BD08B4Q02DU9@0Z:RX0<30`03dm
?@14A4@0C4a<05=CD`1JFUX0GemO06ATI01UIFD0I6AT06=SH`1RHV80H61P05iNGP1MGEd0Fe]K05YJ
FP1IFET0EUIF05EEE@1DE5@205=CD`80DE5A1`1@D502055AD@0i05=CD`1DE5@0EEEE05IFEP1HF5P0
Fe]K05eMG@1PH600HV9R06EUI@1XJ6P0L71`07EeM@1kNg/0PX:208V9R@2MWId0Z:RX0;Bd]031`L40
cLg=0>OWi`3/k>`0l?3`0?KfmP3jn_X0no_k0?Cdm03_knl0jn_[0>KViP3Rh^80fMWI0=GEe@3@d=00
c<c<0<S8b034a<@0^k^k0;Ng]`2c/k<0/;2`0:b/[02TY:@0X:2P09bLW02HV9P0UIFE08f=S@29RHT0
QXJ608:2PP1nOWh0Ng]k07=cL`1`L700K6a/01h0oooo0140D51@059BDP1DE5@0EUIF05MGE`1IFET0
FUYJ05aLG01PH600HV9R06EUI@1XJ6P0Jf][07=cL`1gMgL0O7al07inOP0207moO`030820P021PH40
PX:20080PX:200h0PH610820P01nOWh0O7al07YjNP1fMWH0M7Ad07=cL`1aLG40L71`06i^KP1[Jf/0
JVYZ06UYJ@80J6QX1P1VIVH0?P1WIfL0J6QX06UYJ@1ZJVX0K6a/06m_K`1aLG40Lg=c07EeM@1gMgL0
O7al07moO`22PX80QHF508R8R02;Rh/0Ti>C09RHV02MWId0Xj>S0:ZZZP2j^[X0`l?30<_;b`3Cdm<0
fm_K0>WYj@3/k>`0kno_0?;blP3dm?@0lo?c0>[ZjP3Ti>@0gmoO0=WIf@3De=@0bLW90<C4a02n_[h0
^KVi0;Fe]@2`/;00YZJV0::RXP2NWYh0VIVI09FEU@2=SHd0R8R808B4Q020P800O7al07EeM@1aLG40
KFe]06UYJ@1UIFD0HV9R05YJFP1GEeL0De=C8P3oool00200oooo01d0S8b<08F5Q@1gMgL0L71`06UY
J@1RHV80Fe]K05=CD`14A4@0?3`l03@d=00/;2`092@T01<C4`0;2`/010@40000000410@06QXJ02DU
9@0`<300>c/k04E5A@1=CDd0F5QH05YJFP1KFe/0G5aL05eMG@0505iNGP@0GEeM2@1LG5`305]KF`03
05YJFP1IFET0F5QH00<0F5QH0`1GEeL0<@1HF5P0FEUI05UIF@1MGEd0H61P06=SH`1WIfL0Jf][07Mg
M`1oOgl0R8R8096AT@2KVi/0[Jf]0;>c/`2j^[X0_kno0<?3``34a<@0`/;20<71`@30`<00_kno0;jn
_P2l_;`0^k^k0;Zj^P2i^KT0^;Rh0;Ng]`2d];@0/k>c0;6a/@2`/;00[jn_0:b/[02ZZZX0ZJVY0:NW
Y`2VYZH0Xj>S0:6QX@2PX:00WYjN09fMW@2KVi/0V9RH09NGU`2EUID07P3oool06`1UIFD0HF5Q05YJ
FP1FEUH0DU9B04m?C`1;Bd/0AdM70410@00l?3`0>CTi03De=@0b<S80;2`/02/[:`0Y:BT0:RXZ02`/
;00i>CT0@41004Q8B01@D500EUIF05aLG01QHF40HV9R065QH@02061PH00805eMG@1LG5`0FUYJ05UI
F@1HF5P0EeMG05ADE01CDe<2059BDP03055AD@1@D500Cdm?00<0Cdm?101@D500>`1ADE40DU9B05AD
E01EEED0EUIF05QHF01JFUX0GUiN061PH01RHV80IFEU06QXJ01[Jf/0M7Ad07YjNP21PH40RHV9096A
T@2TY:@0[jn_0;^k^`37alL0e=CD0>WYj@3/k>`0l_;b0?Ogm`3inOT0n?Sh0>o_k`3Zj^X0iNGU0>7Q
h@3MgMd0e=CD0=3@d03<c<`0b<S80<C4a030`<00^;Rh0;Bd]02`/;00[Jf]0:VYZ@2QXJ40WYjN09ZJ
VP2FUYH0Ti>C08b<S028R8P0QHF50861P@1nOWh0NWYj07=cL`1`L700K6a/01h0oooo01<0DE5A059B
DP1EEED0EeMG05UIF@1JFUX0G5aL05iNGP1SHf<0IFEU06QXJ01[Jf/0KVi^07MgM`1lO7`0PX:208J6
QP25QHD0PX:20080Ph>301@0Q8B408>3P`23Ph<0P82007moO`1lO7`0NWYj07QhN01dM7@0LW9b071`
L01^KVh0KFe]06][J`1XJ6P0IfMW06EUI@1TI6@0Hf=S069RHP@0HF5Q01/0HV9R06=SH`1SHf<0I6AT
06IVIP1XJ6P0K6a/06i^KP1`L700Lg=c07EeM@1lO7`0Ogmo08:2PP26QXH0RHV908j>SP2HV9P0WIfM
0:BTY02/[:`0];Bd0<G5a@3=cLd0e]KF0=oOg`3Xj>P00P3dm?@08P3fm_H0n?Sh0?Ogm`3dm?@0j>SX
0>;RhP3MgMd0emOG0=;BdP37alL0`/;20;fm_@2h^;P0/k>c0:j^[P2UYJD0XJ6Q09bLW02HV9P0U9BD
08^;R`27QhL0Ph>30820P01lO7`0M7Ad071`L01/K6`0JFUY06EUI@1QHF40FUYJ05IFEP1CDe<R0?oo
o`00803oool07@2=SHd0QXJ607QhN01aLG40JVYZ06=SH`1LG5`0E5AD04E5A@0n?Sh0=SHf02l_;`0W
9bL061PH014A4@0:2PX01@D500820P0F5QH08B4Q02`/;00g=cL0@D5104Y:BP1EEED0F5QH05YJFP1K
Fe/0G5aL00/0GEeM201NGUh305eMG@0305aLG01KFe/0FUYJ00@0FUYJ0380FEUI05YJFP1JFUX0Fe]K
05iNGP1QHF40I6AT06QXJ01/K6`0MgMg07moO`27QhL0T92@09ZJVP2YZJT0/;2`0;Ng]`2l_;`0_kno
0<30`02o_kl0_[jn0;fm_@2l_;`0^k^k0;Zj^P2i^KT0^;Rh0;Ng]`2f][H0]KFe0;:b/P2a/K40/;2`
0:n_[`2][Jd0Zj^[0:VYZ@2XZ:P0YZJV0:FUY@2RXZ80XJ6Q09nOW`2NWYh0W9bL09^KV`2HV9P0UYJF
09FEUAh0oooo01X0IFEU065QH@1JFUX0EeMG05=CD`1@D500C4a<04U9B@12@T80?Shn03/k>`0h>3P0
=CDe02l_;`0];Bd0;2`/02XZ:P0Y:BT0=SHf03hn?P16ATH0CTi>05ADE01JFUX0GemO061PH080GemO
00T0GUiN05aLG01JFUX0FEUI05QHF01GEeL0EEEE05=CD`1BDU800P1ADE400`1@D500Cdm?04m?C`02
04i>CP80Cdm?0P1@D500?01ADE40DU9B05=CD`1EEED0EUIF05MGE`1IFET0Fe]K05mOG`1QHF40I6AT
06MWI`1ZJVX0KFe]07MgM`1mOGd0QHF508f=S@2EUID0Z:RX0;>c/`2o_kl0bl_;0=WIf@3WinL0k>c/
0??cl`3gmoL0n?Sh0?Gem@3/k>`0inOW0>?Sh`3Ng]h0f][J0=;BdP3>c/h0b/[:0<K6aP32`/80_[jn
0;Jf]P2c/k<0[jn_0:^[Z`2XZ:P0X:2P09fMW@2IVIT0UYJF09:BTP2;Rh/0QhN708B4Q021PH40OGem
07YjNP1cLg<0Kfm_06a/K1h0oooo01@0DE5A059BDP1FEUH0EeMG05UIF@1KFe/0GEeM05mOG`1TI6@0
IVIV06UYJ@1/K6`0Kfm_07MgM`1kNg/0Ogmo08:2PP23Ph<0PX:208>3P`@0Q8B40140PH6107inOP1l
O7`0NWYj07MgM`1cLg<0LG5a06m_K`1]KFd0Jf][06UYJ@1VIVH0IFEU06=SH`1RHV80HF5Q05mOG`04
05iNGP0o05mOG`1PH600HF5Q069RHP1TI6@0IVIV06YZJP1/K6`0Kfm_079bLP1eMGD0Ng]k07inOP22
PX80QXJ608^;R`2@T900VYZJ0:6QX@2YZJT0/K6a0;Zj^P3;bl/0dm?C0=cLg03Vi^H0lO7a0?KfmP3g
moL0n_[j0?_kn`3inOT0m?Cd0>OWi`3QhN40fm_K0=KFeP3@d=00a/K60<71`@2l_;`0]kNg0;:b/P2]
[Jd0Y:BT0:2PX02KVi/0UiNG09>CT`2;Rh/0QhN708>3P`1oOgl0Ng]k07AdM01`L700K6a/06QXJ01U
IFD0HF5Q05YJFP1FEUH0De=C0280oooo000P0?ooo`0M08f=S@26QXH0N7Qh079bLP1[Jf/0I6AT05eM
G@1FEUH0AdM70410@00i>CT0<C4a02XZ:P0K6a/05ADE00h>3P092@T010@401@D500N7Qh0:2PX03<c
<`0m?Cd0ATI6059BDP1EEED0EeMG05UIF@1JFUX0101LG5`405eMG@@0GUiN0P1OGel2061PH003065Q
H@1PH600H61P0080H61P00<0GemO05iNGP1NGUh00`1MGEd305aLG0<0GEeM00h0H61P069RHP1UIFD0
JFUY06i^KP1fMWH0Ogmo08N7Q`2?Shl0VYZJ0:JVYP2][Jd0];Bd0;Vi^@80_;bl0P2k^k/00`2j^[X0
^KVi0;Vi^@020;Ng]`0G0;Jf]P2e]KD0];Bd0;>c/`2a/K40/;2`0:j^[P2][Jd0[:b/0:VYZ@2XZ:P0
YjNW0:JVYP2TY:@0XJ6Q0:2PX02OWil0WIfM09bLW02KVi/0V9RH09JFUP2EUID07P3oool06@1UIFD0
HV9R05]KF`1GEeL0E5AD055AD@1=CDd0BTY:04=3@`10@400?Cdm03Xj>P0g=cL0<S8b030`<00^;Rh0
;2`/02TY:@0e=CD0?Cdm04A4A01<C4`0DU9B05MGE`1MGEd00P1NGUh02P1MGEd0G5aL05YJFP1IFET0
F5QH05IFEP1EEED0E5AD059BDP1ADE42051@D00304m?C`1>CTh0CTi>00<0CTi>01h0Cdm?051@D01A
DE40DE5A059BDP1DE5@0EUIF05MGE`1HF5P0FUYJ05aLG01PH600Hf=S06EUI@1YJFT0K6a/071`L01k
Ng/0PH6108V9R@2ATI40VYZJ0:b/[02g]kL0`l?30=3@d03Kfm/0inOW0>g]k@3clo<20?KfmP0O0?;b
lP3YjNT0i>CT0>3Ph03Lg=`0f=SH0<o?c`3;bl/0b<S80<C4a030`<00_;bl0;Fe]@2a/K40[Jf]0:ZZ
ZP2VYZH0WinO09bLW02HV9P0U9BD096AT@2:RXX0QhN708>3P`20P800OGem07UiN@1cLg<0Kfm_06a/
K00N0?ooo`0C055AD@1CDe<0EUIF05QHF01JFUX0G5aL05iNGP1PH600IFEU06MWI`1ZJVX0KFe]071`
L01gMgL0NWYj07inOP20P800PH6108>3P`0408F5Q@0B08B4Q020P800OWin07alO01iNGT0MgMg079b
LP1`L700KVi^06a/K01ZJVX0J6QX06ATI01SHf<0HF5Q061PH01OGel0GEeM0P1LG5`0@@1KFe/0G5aL
05eMG@1NGUh0GemO065QH@1SHf<0I6AT06UYJ@1[Jf/0KVi^075aL@1dM7@0Ng]k07moO`22PX80QhN7
08b<S02ATI40WYjN0:JVYP2^[Zh0][Jf0;no_`3AdM40fMWI0>?Sh`3^k^h0m?Cd0?Win@3kno/0oOgm
0?clo03inOT0lo?c0>KViP3Ph>00f][J0=GEe@3?cll0a<C40;no_`2j^[X0][Jf0;6a/@2/[:`0Xj>S
09nOW`2KVi/0UYJF09:BTP2:RXX0QXJ608:2PP1nOWh0Ng]k07=cL`1_Kfl0K6a/06QXJ01UIFD0HF5Q
05YJFP1FEUH0De=C0280oooo000P0?ooo`0N08f=S@26QXH0NGUi079bLP1[Jf/0IFEU05iNGP1GEeL0
BDU90492@P0k>c/0=3@d02d];@0O7al061PH018B4P0<30`01PH600l?3`0K6a/09BDU030`<00i>CT0
@T9204m?C`1CDe<0EEEE05MGE`1HF5P0FUYJ0`1KFe/205aLG00405eMG@1NGUh0GUiN05iNGP80GemO
00D0H61P065QH@1QHF40HV9R06=SH`05069RHP<0HF5Q0P1PH6000`1OGel0GUiN05iNGP0305mOG`0?
065QH@1TI6@0IfMW06YZJP1_Kfl0MgMg07emO@26QXH0Shn?09RHV02TY:@0ZZZZ0;2`/02e]KD0^KVi
00<0^;Rh0P2g]kL06P2f][H0]KFe0;Bd]02d];@0/k>c0;:b/P2a/K40[jn_0:j^[P2][Jd0[:b/0:^[
Z`2XZ:P0YjNW0:JVYP2UYJD0Xj>S0:6QX@2OWil0WYjN09fMW@2LW9`0VYZJ09RHV02FUYH0UIFE7P3o
ool06@1UIFD0HV9R05]KF`1HF5P0EEEE059BDP1>CTh0Bd];04E5A@12@T80?clo03`l?00i>CT0=3@d
038b<P0_;bl0;Bd]02TY:@0c<c<0>c/k0492@P1:BTX0D51@05EEE@1KFe/00`1LG5`02P1KFe/0FEUI
05QHF01GEeL0EEEE05ADE01CDe<0DE5A051@D01?Cdl204i>CP@0CDe=01l0CTi>051@D01@D500DE5A
059BDP1CDe<0E5AD05MGE`1HF5P0FUYJ05aLG01NGUh0HV9R06EUI@1XJ6P0K6a/06m_K`1cLg<0OWin
08F5Q@2=SHd0UIFE09jNWP2`/;00_;bl0<S8b03Bd]80g=cL0>SXj03]kNd0l_;b0080lo?c01l0k^k^
0>GUi@3QhN40gMgM0=WIf@3EeMD0cLg=0<W9b@35aLD0`/;20;jn_P2j^[X0/k>c0:n_[`2/[:`0Z:RX
0:FUY@2NWYh0VYZJ09NGU`2CTi<0T92@08V9R@26QXH0Ph>307moO`1lO7`0NGUi079bLP1_Kfl0K6a/
01h0oooo02X0DE5A05=CD`1FEUH0F5QH05YJFP1LG5`0GUiN061PH01UIFD0J6QX06][J`1]KFd0LG5a
07MgM`1jNWX0OGem07moO`20P800QHF508B4Q025QHD0QXJ608F5Q@24Q8@0P82007emO@1kNg/0NGUi
07IfMP1bLW80Kfm_06e]K@1[Jf/0J6QX06IVIP1RHV80HF5Q05mOG`1NGUh0GEeM05]KF`1JFUX305UI
F@0o05]KF`1LG5`0GEeM05mOG`1QHF40Hf=S06MWI`1YJFT0K6a/071`L01cLg<0Ng]k07moO`24Q8@0
RHV908j>SP2DU9@0XZ:R0:ZZZP2b/[80^k^k0<C4a03Fe]H0hN7Q0>_[j`3bl_80moOg0?clo03no_h0
oooo0?clo03hn?P0l_;b0>GUi@3Ng]h0fMWI0=?Cd`3>c/h0`l?30;jn_P2i^KT0];Bd0;2`/02[Zj/0
XZ:R09jNWP2JVYX0UIFE096AT@29RHT0QXJ608:2PP1nOWh0NWYj07=cL`1_Kfl0Jf][06QXJ01TI6@0
HF5Q05YJFP1FEUH0De=C0280oooo000P0?ooo`0M08f=S@26QXH0NGUi07=cL`1/K6`0IVIV05mOG`1H
F5P0Bd];04A4A00m?Cd0=SHf02l_;`0R8R806a/K01@D500>3Ph01PH600X:2P0F5QH08B4Q02`/;00f
=SH0?clo04a<C01@D500De=C05EEE@1FEUH00P1IFET205YJFP0305]KF`1LG5`0GEeM00<0GUiN00L0
GemO061PH01PH600HF5Q069RHP1SHf<0IFEU0080I6AT0`1UIFD01@1TI6@0Hf=S06=SH`1SHf<0HV9R
0080HF5Q101PH6003`1RHV80IFEU06QXJ01/K6`0L71`07UiN@1oOgl0QhN708b<S02FUYH0Xj>S0:RX
Z02^[Zh0/[:b0;Bd]0030;Fe]@<0];Bd00H0/k>c0;:b/P2b/[80/K6a0;2`/02_[jl20:f][@0A0:b/
[02[Zj/0ZZZZ0:NWY`2VYZH0YJFU0:BTY02SXj<0X:2P09nOW`2NWYh0W9bL09^KV`2JVYX0UiNG09JF
UP2EUID07P3oool06@1UIFD0HV9R05aLG01IFET0EUIF05=CD`1@D500C4a<04M7A`14A4@0@D5103hn
?P0k>c/0=SHf03@d=00a<C40;Rh^02XZ:P0`<300>CTi0410@017AdL0CDe=05=CD`1IFET00`1JFUX0
2P1IFET0F5QH05IFEP1EEED0De=C059BDP1ADE40D51@04m?C`1>CTh204e=C@<0C4a<0440CDe=04i>
CP1@D500D51@055AD@1BDU80De=C05EEE@1HF5P0FEUI05]KF`1MGEd0GemO06ATI01WIfL0JVYZ06i^
KP1bLW80MgMg08:2PP29RHT0TI6A09ZJVP2RXZ80]KFe0;no_`3<c<`0dm?C0=cLg03YjNT0k>c/0?3`
l03alO40kno_0>[ZjP3Rh^80g]kN0=[JfP3Fe]H0d];B0<[:bP37alL0`l?30;no_`2l_;`0^;Rh0;6a
/@2^[Zh0ZZZZ0:NWY`2SXj<0WIfM09VIV@2FUYH0TY:B08n?S`29RHT0QHF508:2PP1oOgl0O7al07Ui
N@1bLW80Kfm_06a/K00N0?ooo`0Z055AD@1CDe<0EeMG05QHF01JFUX0GEeM05mOG`1QHF40IVIV06QX
J01[Jf/0KVi^075aL@1gMgL0NWYj07emO@1oOgl0PH6108F5Q@26QXH0QhN708J6QP25QHD0Q8B40820
P01mOGd0Ng]k07QhN01fMWH0LG5a06m_K`1/K6`0JVYZ06MWI`1UIFD0HF5Q05mOG`1NGUh0G5aL05]K
F`1IFET0F5QH0P1GEeL07@1HF5P0FEUI05]KF`1LG5`0GEeM05mOG`1QHF40IFEU06QXJ01/K6`0Kfm_
07=cL`1kNg/0P82008F5Q@2;Rh/0TI6A09RHV02WYjL0[jn_0;Ng]`30`<00bLW90=cLg03UiND0l?3`
0?KfmP3inOT0o_kn0080oooo0240oOgm0?Ogm`3_knl0hn?S0=gMg@3GemL0dM7A0<c<c032`/80_Kfm
0;Rh^02c/k<0[Zj^0:ZZZP2QXJ40WIfM09VIV@2DU9@0T92@08V9R@25QHD0PH6107emO@1iNGT0LW9b
06m_K`1[Jf/0IfMW06ATI01PH600FEUI05IFEP1CDe<08P3oool00200oooo01h0SHf=08N7Q`1kNg/0
M7Ad06i^KP1XJ6P0HV9R05]KF`1?Cdl0B4Q80492@P0k>c/0=CDe02PX:00Q8B406QXJ01<C4`0;2`/0
0`<300/;2`0F5QH07alO02XZ:P0d=3@0A4A404U9B@1=CDd0Cdm?055AD@1DE5@205EEE@0405IFEP1H
F5P0FEUI05]KF`80GEeM00P0GUiN05mOG`1PH600H61P065QH@1RHV80I6AT06IVIPD0IfMW0`1XJ6P2
06MWI`0306IVIP1UIFD0I6AT0080I6AT0P1UIFD03`1WIfL0Jf][06e]K@1bLW80O7al08:2PP29RHT0
SXj>09FEU@2QXJ40YJFU0:VYZ@2/[:`0[Jf]0:j^[P050:n_[`<0[Zj^00@0[Jf]0:b/[02/[:`0ZZZZ
0P2YZJT0402XZ:P0YjNW0:FUY@2TY:@0Xj>S0::RXP2QXJ40WinO09jNWP2MWId0W9bL09ZJVP2IVIT0
UiNG09JFUP2EUIDN0?ooo`0K06IVIP1SHf<0GEeM05YJFP1GEeL0E5AD059BDP1?Cdl0BDU904M7A`14
A4@0@T9203lo?`0j>SX0>3Ph03Hf=P0c<c<0<30`02l_;`0f=SH0?Cdm04=3@`18B4P0CDe=05ADE01F
EUH0EeMG0080EUIF00L0EEEE05=CD`1BDU80DE5A04m?C`1>CTh0CDe=0080C4a<1@1;Bd/0@@1<C4`0
CTi>051@D01ADE40DU9B05ADE01EEED0EUIF05YJFP1LG5`0GemO065QH@1TI6@0JVYZ06e]K@1aLG40
MWIf07YjNP1oOgl0Rh^;09:BTP2KVi/0Xj>S0:^[Z`2m_Kd0alO70<o?c`3EeMD0gMgM0>OWi`3Zj^X0
jn_[0>[ZjP3Vi^H0hn?S0=_Kf`3GemL0e=CD0=3@d03<c<`0aLG50<;2`P2n_[h0^k^k0;Ng]`2d];@0
[Jf]0:ZZZP2WYjL0Y:BT0:2PX02JVYX0UiNG09>CT`2@T900SHf=08N7Q`24Q8@0PH6107inOP1kNg/0
N7Qh079bLP1_Kfl0K6a/01h0oooo02P0DE5A05=CD`1GEeL0FEUI05]KF`1MGEd0GemO069RHP1VIVH0
JFUY06a/K01^KVh0LG5a07MgM`1jNWX0OWin0861P@25QHD0Rh^;08j>SP2=SHd0S8b<08Z:RP27QhL0
PH6107inOP1lO7`0NGUi07MgM`1aLG40Kfm_06a/K01YJFT0IVIV06=SH`1NGUh0GEeM05]KF`1JFUX0
F5QH0P1GEeL0@P1FEUH0EeMG05MGE`1HF5P0FEUI05]KF`1MGEd0GUiN065QH@1VIVH0JFUY06e]K@1a
LG40MGEe0820P025QHD0S8b<09>CT`2IVIT0X:2P0;6a/@2j^[X0a<C40<g=c@3De=@0iNGU0>g]k@3b
l_80m_Kf0?_kn`3oool0o_kn0?clo03hn?P0lO7a0>_[j`3Ng]h0f=SH0=?Cd`3=cLd0b<S80;jn_P2i
^KT0]KFe0;2`/02[Zj/0YjNW09nOW`2JVYX0UYJF09:BTP2>SXh0QhN708>3P`1oOgl0O7al07QhN01a
LG40KVi^06YZJP1WIfL0Hf=S061PH01IFET0EUIF059BDR80oooo000P0?ooo`0]08f=S@27QhL0Ng]k
07EeM@1_Kfl0JFUY06=SH`1MGEd0D51@04Y:BP14A4@0?Shn03Lg=`0[:b/092@T01hN7P0G5aL03`l?
00<30`061PH03Ph>01TI6@0S8b<0;Bd]03hn?P15ADD0BTY:04a<C01=CDd0D51@059BDP1CDe<0E5AD
05IFEP1GEeL0FUYJ05]KF`1LG5`0GEeM05aLG01NGUh0GemO061PH01QHF40HV9R0080IFEU0`1VIVH0
1@1WIfL0J6QX06QXJ01WIfL0J6QX00<0IfMW01D0IVIV06EUI@1UIFD0IFEU06MWI`1YJFT0KFe]06m_
K`1bLW80Ogmo08B4Q028R8P0SXj>09BDU02OWil0Y:BT0:RXZ02YZJT0ZZZZ0:^[Z`2/[:`0102][Jd3
0:b/[080Zj^[00<0ZZZZ0:VYZ@2XZ:P00P2WYjL03`2VYZH0Y:BT0:>SX`2RXZ80XJ6Q0:2PX02NWYh0
WIfM09bLW02KVi/0VYZJ09VIV@2GUiL0UYJF09FEU@0N0?ooo`0J06IVIP1SHf<0GUiN05]KF`1HF5P0
EEEE05=CD`1@D500Bd];04Q8B016ATH0A4A40451@@0m?Cd0>SXj03Ph>00f=SH0=3@d038b<P0e=CD0
>c/k0410@015ADD0Bd];055AD@1DE5@305EEE@0705=CD`1BDU80D51@04m?C`1>CTh0CDe=04a<C003
04];B`1504Y:BP1;Bd/0Bd];04];B`1=CDd0CTi>055AD@1BDU80De=C05EEE@1FEUH0F5QH05aLG01O
Gel0HF5Q06ATI01WIfL0KFe]075aL@1eMGD0NGUi07inOP24Q8@0T92@09NGU`2OWil0YjNW0:j^[P30
`<00bLW90=3@d03Fe]H0gMgM0>KViP3Xj>P0jNWY0>KViP3Rh^80gmoO0=SHf03De=@0d=3@0<g=c@39
bLT0`l?30;no_`2l_;`0^;Rh0;Fe]@2b/[80Zj^[0:RXZ02UYJD0XZ:R09nOW`2IVIT0UYJF09:BTP2?
Shl0S8b<08J6QP23Ph<0P82007emO@1jNWX0MgMg075aL@1^KVh0K6a/01h0oooo01<0DE5A05=CD`1G
EeL0FEUI05]KF`1MGEd0GemO069RHP1VIVH0JFUY06a/K01^KVh0LG5a07MgM`1jNWX0OWin0861P@25
QHD0Shn?0080TI6A0100SXj>08b<S02:RXX0Ph>307moO`1lO7`0NWYj07QhN01cLg<0L71`06a/K01X
J6P0IFEU06=SH`1NGUh0G5aL0P1KFe/00`1JFUX0F5QH05QHF00205QHF01005UIF@1KFe/0G5aL05eM
G@1OGel0HF5Q06=SH`1YJFT0KFe]071`L01dM7@0NGUi08>3P`29RHT0T92@09NGU`2OWil0YjNW0;Ng
]`2o_kl0b<S80=3@d03Hf=P0inOW0>o_k`3emOD0nOWi0?clo03no_h0o?cl0?Win@3dm?@0k^k^0>SX
j03Lg=`0e]KF0=3@d03;bl/0a/K60;bl_02g]kL0/k>c0:j^[P2ZZZX0YZJV09fMW@2IVIT0UIFE096A
T@2=SHd0QXJ608:2PP1oOgl0Ng]k07MgM`1`L700KFe]06YZJP1VIVH0Hf=S061PH01IFET0EUIF059B
DR80oooo000P0?ooo`0V08j>SP28R8P0O7al07IfMP1`L700JVYZ06ATI01NGUh0DU9B04a<C016ATH0
@41003Xj>P0^;Rh09bLW024Q8@0K6a/051@D00H61P0410@01`L7014A4@0L71`09bLW03Lg=`0o?cl0
A4A404Q8B01:BTX0CDe=04i>CP1@D500DE5A05=CD`1DE5@0EeMG05QHF01JFUX205]KF`0605aLG01M
GEd0GEeM05mOG`1PH600HV9R0P1SHf<206ATI080IFEU0P1VIVH206MWI`0306IVIP1WIfL0J6QX00<0
J6QX0100JFUY06][J`1^KVh0LW9b07EeM@1nOWh0Q8B408V9R@2>SXh0Ti>C09jNWP2SXj<0YJFU0:JV
YP2WYjL0Z:RX0`2ZZZX20:^[Z`@0ZZZZ0P2YZJT20:NWY`80YZJV00l0YJFU0:>SX`2SXj<0XJ6Q0:2P
X02OWil0WYjN09fMW@2LW9`0Vi^K09ZJVP2IVIT0UiNG09JFUP2DU9@07P3oool06`1VIVH0Hf=S05iN
GP1KFe/0FEUI05IFEP1DE5@0DE5A04a<C01:BTX0B4Q804E5A@13@d<0?clo03`l?00j>SX0>3Ph03Lg
=`0d=3@0=SHf03Ph>00m?Cd0@T9204Q8B01>CTh0DU9B05=CD`0205ADE005055AD@1@D500CTi>04e=
C@1<C4`01@1;Bd/0A@1:BTX0Bd];04];B`1<C4`0CDe=04m?C`1BDU80De=C05EEE@1GEeL0F5QH05YJ
FP1OGel0HV9R06ATI01WIfL0JVYZ075aL@1dM7@0NGUi07inOP23Ph<0R8R809BDU02KVi/0Xj>S0:ZZ
ZP2b/[80`l?30<_;b`3AdM40emOG0=gMg@3Shn<0i^KV0>GUi@3Rh^80g]kN0=_Kf`3De=@0dM7A0<g=
c@3:b/X0a/K60<30`02m_Kd0^KVi0;Jf]P2c/k<0/;2`0:VYZ@2VYZH0Xj>S0:2PX02MWId0UiNG09BD
U02ATI40SXj>08^;R`25QHD0PX:20820P01mOGd0NWYj07MgM`1aLG40KVi^06][J`0N0?ooo`0C055A
D@1CDe<0EeMG05UIF@1KFe/0GEeM05mOG`1RHV80IfMW06UYJ@1/K6`0KVi^075aL@1gMgL0NWYj07in
OP21PH40QHF5092@T00209FEU@0A09:BTP2>SXh0Rh^;08F5Q@22PX80P82007emO@1jNWX0Lg=c071`
L01/K6`0JFUY06IVIP1SHf<0H61P05mOG`1NGUh00P1LG5`305]KF`0M05aLG01MGEd0GemO061PH01R
HV80IFEU06IVIP1YJFT0Kfm_07=cL`1fMWH0NWYj07inOP29RHT0SXj>09>CT`2JVYX0Xj>S0:ZZZP2k
^k/0a<C40<c<c03Cdm<0fm_K0>c/k03alO40mOGe0?Win@3lo?`00P3kno/08P3gmoL0lO7a0>_[j`3U
iND0fMWI0=?Cd`3>c/h0bLW90<C4a02j^[X0][Jf0;6a/@2][Jd0Z:RX0:BTY02LW9`0V9RH09BDU02@
T900S8b<08F5Q@21PH40OGem07YjNP1gMgL0L71`06a/K01YJFT0IVIV06=SH`1OGel0FEUI05IFEP1B
DU8R0?ooo`00803oool09@2>SXh0R8R807emO@1gMgL0LG5a06][J`1VIVH0H61P05EEE@1?Cdl0BDU9
04=3@`0m?Cd0<C4a02/[:`0U9BD07alO01PH600=3@d02@T900H61P0=3@d05ADE020P800`<300>3Ph
03hn?P14A4@0ATI604Y:BP1;Bd/0C4a<04i>CP1?Cdl0DE5A05ADE01FEUH00P1GEeL0201HF5P0FEUI
05UIF@1JFUX0Fe]K05eMG@1NGUh0GemO101PH60206=SH`80I6AT0`1UIFD05@1WIfL0J6QX06UYJ@1Y
JFT0Jf][06e]K@1_Kfl0LW9b07IfMP1oOgl0Q8B408V9R@2>SXh0U9BD09fMW@2QXJ40Xj>S0:BTY02U
YJD0YZJV0:NWY`030:RXZ080ZJVY102XZ:P0102WYjL0YZJV0:JVYP2UYJD20:BTY00>0::RXP2QXJ40
XJ6Q0:2PX02OWil0WIfM09bLW02KVi/0VYZJ09VIV@2HV9P0UYJF09FEU@2DU9@N0?ooo`0B06IVIP1T
I6@0GemO05aLG01JFUX0EeMG05EEE@1BDU80CTi>04];B`19BDT0AdM704E5A@11@D40?clo03dm?@0k
>c/0>CTi0P0g=cL0300f=SH0>SXj03lo?`15ADD0CDe=051@D01ADE40DU9B055AD@1?Cdl0CTi>04a<
C080Bd];0P1:BTX504];B`1304a<C01=CDd0Cdm?051@D01CDe<0EUIF05MGE`1HF5P0FUYJ05aLG01R
HV80I6AT06IVIP1ZJVX0KFe]07AdM01gMgL0OGem08:2PP27QhL0S8b<09VIV@2OWil0YZJV0:j^[P2f
][H0aLG50<c<c03Bd]80emOG0=_Kf`3Rh^80i>CT0>7Qh@3MgMd0f][J0=OGe`3@d=00cLg=0<[:bP37
alL0a<C40;fm_@2j^[X0]kNg0;Bd]02a/K40[Zj^0:NWY`2TY:@0XJ6Q09jNWP2LW9`0UYJF09>CT`2@
T900SHf=08Z:RP24Q8@0PX:207moO`1lO7`0NGUi07IfMP1aLG40KVi^06][J`0N0?ooo`0D055AD@1C
De<0EeMG05UIF@1KFe/0GEeM05mOG`1RHV80IfMW06UYJ@1/K6`0KVi^075aL@1gMgL0NWYj07emO@21
PH40QHF508f=S@2ATI4209:BTP0@096AT@2?Shl0RHV908N7Q`22PX80Ogmo07YjNP1dM7@0L71`06e]
K@1ZJVX0J6QX06IVIP1RHV80HF5Q061PH0@0GemO01`0H61P065QH@1RHV80IFEU06MWI`1YJFT0Jf][
06i^KP1aLG40MWIf07UiN@1lO7`0PH6108F5Q@2?Shl0U9BD09ZJVP2QXJ40Z:RX0;2`/030`<00b<S8
0=3@d03Hf=P0h>3P0>k^kP3clo<0moOg0`3jn_X08`3inOT0lo?c0>g]k@3WinL0h^;R0=KFeP3AdM40
c<c<0<O7a`32`/80^;Rh0;>c/`2_[jl0Zj^[0:JVYP2RXZ80VYZJ09JFUP2BTY80Shn?08^;R`24Q8@0
P82007emO@1iNGT0MWIf06m_K`1/K6`0JFUY06EUI@1RHV80GemO05UIF@1EEED0DU9B0280oooo000P
0?ooo`0D08j>SP28R8P0OWin07QhN01bLW80KFe]06MWI`1QHF40EUIF055AD@1;Bd/0ADE50410@00d
=3@0;Rh^02PX:00S8b<07AdM018B4P0=3@d200P8200A014A4@0J6QX0;Bd]03@d=00j>SX0?clo0492
@P15ADD0AdM704U9B@1:BTX0C4a<04e=C@1@D500DU9B05=CD`1DE5@00P1EEED205IFEP0305QHF01I
FET0G5aL00<0GEeM0P1NGUh2061PH003069RHP1SHf<0I6AT0080IFEU01D0IVIV06QXJ01YJFT0JVYZ
06e]K@1^KVh0LG5a07AdM01gMgL0Ogmo08B4Q02:RXX0Shn?09BDU02NWYh0WinO0:2PX02RXZ80Xj>S
0:BTY02UYJD00`2VYZH30:NWY`@0YZJV00<0YJFU0:BTY02TY:@00P2SXj<01@2QXJ40X:2P0:2PX02O
Wil0WYjN0080W9bL00L0Vi^K09ZJVP2IVIT0V9RH09JFUP2EUID0U9BD01h0oooo01/0IVIV06ATI01O
Gel0GEeM05YJFP1HF5P0EUIF05=CD`1?Cdl0CDe=04];B`18B4P0ATI604=3@`11@D40?clo03dm?@0l
?3`0>CTi03Ph>00g=cL0>3Ph03dm?@11@D40BTY:04e=C@1>CTh00P1@D500101>CTh0C4a<04];B`1;
Bd/304Y:BP<0Bd];0P1<C4`0@`1=CDd0CTi>051@D01BDU80EEEE05MGE`1IFET0FUYJ05eMG@1OGel0
I6AT06EUI@1YJFT0K6a/071`L01gMgL0Ng]k0861P@26QXH0Rh^;096AT@2MWId0Xj>S0:ZZZP2b/[80
^KVi0<O7a`3=cLd0d];B0=GEe@3IfMT0hN7Q0>3Ph03Lg=`0fMWI0=KFeP3Cdm<0cLg=0<[:bP37alL0
a<C40<71`@2j^[X0]kNg0;Bd]02a/K40[Zj^0:^[Z`2UYJD0Xj>S0:2PX02MWId0VYZJ09BDU02ATI40
Shn?08b<S029RHT0Q8B40861P@1nOWh0Ng]k07UiN@1fMWH0LG5a06i^KP1[Jf/07P3oool09P1ADE40
De=C05MGE`1IFET0Fe]K05eMG@1PH600HV9R06MWI`1YJFT0K6a/06i^KP1aLG40MgMg07YjNP1mOGd0
P82008B4Q02;Rh/0Shn?09>CT`2DU9@0TY:B08n?S`29RHT0QXJ608>3P`20P800OGem07IfMP1bLW80
Kfm_06a/K01ZJVX0J6QX06IVIP1UIFD0I6AT0P1SHf<07@1TI6@0IFEU06IVIP1WIfL0J6QX06][J`1]
KFd0Kfm_075aL@1dM7@0MgMg07emO@1nOWh0PX:208F5Q@2:RXX0U9BD09ZJVP2QXJ40YjNW0:f][@2e
]KD0a<C40<c<c03De=@0g=cL0>CTi03alO40mOGe00<0m_Kf02@0n?Sh0?Gem@3_knl0jNWY0>CTi03N
g]h0dm?C0<k>cP39bLT0a<C40;no_`2f][H0/K6a0:f][@2YZJT0Y:BT0:2PX02IVIT0UIFE096AT@2=
SHd0RXZ:08>3P`1oOgl0O7al07QhN01eMGD0KVi^06][J`1XJ6P0IFEU069RHP1OGel0F5QH05EEE@1B
DU8R0?ooo`00803oool09`2>SXh0RHV907inOP1iNGT0Lg=c06i^KP1YJFT0Hf=S05QHF01CDe<0CDe=
04Q8B012@T80=cLg038b<P0/;2`09bLW024Q8@0G5aL04Q8B00h>3P0820P02`/;01@D500W9bL0;Rh^
03@d=00i>CT0?Cdm0410@012@T80A4A404I6AP18B4P0BDU904];B`1=CDd0Cdm?051@D002055AD@80
DU9B00<0De=C05ADE01GEeL00P1IFET305YJFP0505eMG@1NGUh0GemO061PH01SHf<00P1TI6@05@1U
IFD0IVIV06MWI`1XJ6P0Jf][06e]K@1`L700Lg=c07MgM`20P800QHF508Z:RP2ATI40UIFE09bLW02M
WId0WYjN09nOW`2PX:00XJ6Q0:>SX`030:BTY0H0YJFU0P2TY:@20:>SX`80XZ:R0P2PX:001P2OWil0
WYjN09fMW@2LW9`0Vi^K09ZJVP80VIVI00@0V9RH09JFUP2EUID0U9BD7P3oool06`1VIVH0I6AT061P
H01MGEd0Fe]K05UIF@1GEeL0E5AD051@D01>CTh0C4a<04Y:BP18B4P0A4A404=3@`11@D40?clo03hn
?P0l?3`0>SXj03Ti>@0h>3P0>SXj03hn?P18B4P0BTY:04e=C@0204i>CP0504a<C01:BTX0BTY:04Y:
BP19BDT00P1:BTX204];B`1604a<C01=CDd0CTi>04m?C`1@D500DU9B05ADE01GEeL0FUYJ05]KF`1M
GEd0GemO065QH@1UIFD0J6QX06a/K01^KVh0Lg=c07]kN`20P800QHF508Z:RP2@T900UYJF0:6QX@2X
Z:P0[jn_0;Fe]@2m_Kd0b<S80<c<c03?cll0e=CD0=SHf03Ogml0fm_K0=SHf03EeMD0d];B0<o?c`39
bLT0a/K60<C4a031`L40_[jn0;Rh^02e]KD0/[:b0:n_[`2/[:`0ZJVY0:>SX`2QXJ40WYjN09^KV`2H
V9P0Ti>C092@T02=SHd0Rh^;08R8R023Ph<0P82007emO@1kNg/0N7Qh07IfMP1`L700KVi^06][Jah0
oooo01D0DE5A05=CD`1GEeL0FEUI05]KF`1MGEd0H61P069RHP1VIVH0JFUY06][J`1^KVh0LG5a07If
MP1iNGT0O7al0820P023Ph<0RXZ:08f=S@2@T9000P2DU9@03P2ATI40S8b<08R8R026QXH0Ph>30820
P01iNGT0MGEe075aL@1_Kfl0KFe]06a/K01[Jf/0JVYZ0`1YJFT0A01ZJVX0Jf][06a/K01^KVh0L71`
079bLP1dM7@0MWIf07QhN01lO7`0OWin08:2PP24Q8@0RHV908b<S02?Shl0Vi^K0:6QX@2XZ:P0/;2`
0;Ng]`2n_[h0c<c<0=CDe03Kfm/0h^;R0>[ZjP3alO40l_;b0?7al@3bl_80mOGe0?Ogm`3alO40jn_[
0>KViP3Ph>00fm_K0=3@d03;bl/0a/K60<71`@2m_Kd0/k>c0:n_[`2[Zj/0YjNW0:>SX`2OWil0UiNG
09>CT`2?Shl0S8b<08R8R021PH40OWin07]kN`1gMgL0M7Ad06i^KP1[Jf/0IfMW06ATI01QHF40GUiN
05QHF01EEED0DU9B8P3oool00200oooo02H0SXj>08V9R@1oOgl0NWYj07IfMP1`L700Jf][06IVIP1L
G5`0EeMG059BDP1=CDd0B4Q803hn?P0i>CT0=3@d02l_;`0Z:RX0820P01/K6`0F5QH04Q8B00`<300;
2`/06a/K028R8P0[:b/0<C4a03De=@0g=cL0>3Ph03Ti>@0m?Cd0?clo0451@@13@d<0A4A404I6AP80
AdM70P18B4P01@1:BTX0Bd];04Y:BP1;Bd/0C4a<0080Cdm?01h0D51@055AD@1BDU80E5AD05EEE@1G
EeL0FEUI05iNGP1OGel0HF5Q06=SH`1TI6@0IVIV06YZJP1]KFd0L71`07EeM@1hN7P0Ph>308J6QP2:
RXX0SXj>096AT@2GUiL0VIVI09ZJVP2KVi/0W9bL09fMW@2OWil20:2PX080XJ6Q1P2RXZ820:6QX@<0
X:2P00L0WinO09jNWP2MWId0WIfM09bLW02KVi/0VYZJ0080VIVI00D0V9RH09NGU`2FUYH0UIFE09BD
U00N0?ooo`0N06MWI`1TI6@0H61P05iNGP1LG5`0FUYJ05QHF01FEUH0DU9B055AD@1?Cdl0CDe=04];
B`18B4P0ATI604E5A@13@d<0@T9203lo?`0n?Sh0?Cdm03`l?00j>SX0>CTi04=3@`15ADD0BDU904];
B`1<C4`0BTY:0P18B4P01P19BDT0BTY:04];B`1;Bd/0C4a<04i>CP80Cdm?04@0DU9B05=CD`1EEED0
EUIF05QHF01KFe/0GEeM061PH01RHV80I6AT06IVIP1[Jf/0KVi^075aL@1fMWH0NWYj08>3P`28R8P0
SHf=09:BTP2HV9P0WYjN0:VYZ@2^[Zh0/k>c0;Vi^@2m_Kd0aLG50<[:bP3@d=00e=CD0=SHf03Fe]H0
dm?C0=3@d03=cLd0bl_;0<S8b032`/80`<300;fm_@2j^[X0]kNg0;:b/P2_[jl0[Jf]0:ZZZP2WYjL0
YJFU09nOW`2MWId0VYZJ09RHV02EUID0T92@08f=S@2;Rh/0R8R808J6QP21PH40OWin07alO01jNWX0
MgMg07EeM@1`L700KFe]06][Jah0oooo0240DE5A05=CD`1GEeL0FEUI05]KF`1MGEd0GemO065QH@1V
IVH0J6QX06][J`1]KFd0L71`07EeM@1hN7P0Ng]k07inOP21PH40QhN708Z:RP2<S8`0Shn?09:BTP2A
TI40T92@08f=S@29RHT0QXJ608>3P`1nOWh0O7al07UiN@1gMgL00P1fMWH307EeM@80MWIf04@0NGUi
07]kN`1lO7`0OGem0820P024Q8@0QXJ608R8R02:RXX0S8b<08n?S`2DU9@0V9RH09^KV`2PX:00Xj>S
0:b/[02c/k<0^KVi0;no_`35aLD0cLg=0=WIf@3Ng]h0h^;R0>KViP3YjNT0j^[Z0>k^kP3clo<0m_Kf
0?Shn03_knl0jNWY0>?Sh`3Ng]h0fMWI0=CDe03:b/X0aLG50<30`02l_;`0]kNg0:j^[P2ZZZX0YZJV
0::RXP2NWYh0VYZJ09>CT`2@T900S8b<08V9R@25QHD0Ogmo07alO01hN7P0MGEe079bLP1/K6`0JFUY
06IVIP1SHf<0H61P05eMG@1HF5P0EEEE059BDR80oooo000P0?ooo`0M08n?S`2:RXX0P82007]kN`1g
MgL0LW9b06e]K@1XJ6P0GUiN05YJFP1EEED0D51@04];B`11@D40?3`l03Lg=`0b<S80;Rh^02@T900O
7al06a/K01HF5P0A4A402PX:01HF5P0O7al09BDU02/[:`0`<3000`0c<c<01@0h>3P0>SXj03dm?@0n
?Sh0?clo0080@T9202T0@d=304A4A015ADD0A4A404I6AP15ADD0ATI604M7A`19BDT0B4Q804Y:BP1;
Bd/0C4a<04i>CP1@D500DU9B05ADE01JFUX0G5aL05iNGP1PH600HF5Q06ATI01YJFT0K6a/071`L01d
M7@0NGUi0861P@26QXH0RXZ:08j>SP2@T900U9BD09JFUP2HV9P0VIVI09ZJVP2KVi/0WIfM09jNWP02
09nOW`80X:2P102QXJ430:2PX0<0WinO00D0WYjN09fMW@2MWId0W9bL09^KV`0209ZJVP0709VIV@2H
V9P0V9RH09NGU`2FUYH0UIFE09BDU00N0?ooo`0L06MWI`1UIFD0HF5Q05mOG`1MGEd0Fe]K05UIF@1G
EeL0E5AD059BDP1@D500CTi>04e=C@1:BTX0B4Q804M7A`15ADD0A4A40451@@10@400?clo03dm?@0l
?3`0>SXj03lo?`13@d<0AdM704U9B@80BTY:00@0B4Q804M7A`19BDT0BTY:0P1<C4`01@1=CDd0D51@
051@D01ADE40E5AD0080EUIF0440FUYJ05]KF`1NGUh0GemO06=SH`1TI6@0IfMW06UYJ@1^KVh0LG5a
07EeM@1hN7P0OGem08N7Q`2<S8`0TI6A09NGU`2LW9`0XJ6Q0:b/[02`/;00]KFe0;Vi^@2l_;`0aLG5
0<_;b`3@d=00eMGE0=OGe`3AdM40clo?0<c<c039bLT0alO70<C4a02o_kl0_;bl0;Zj^P2g]kL0];Bd
0:n_[`2][Jd0ZZZZ0:NWY`2UYJD0XZ:R09fMW@2KVi/0V9RH09JFUP2DU9@0Shn?08b<S02:RXX0QhN7
08F5Q@20P800OWin07]kN`1iNGT0MgMg07AdM01`L700KFe]06][J`0N0?ooo`0Q055AD@1CDe<0EeMG
05UIF@1KFe/0GEeM05mOG`1QHF40IFEU06QXJ01ZJVX0K6a/06m_K`1dM7@0MgMg07YjNP1lO7`0Ogmo
08F5Q@28R8P0Rh^;08j>SP2@T900U9BD092@T02>SXh0S8b<08Z:RP26QXH0PX:20820P01nOWh0OGem
0080O7al00<0Ng]k07alO01lO7`00P1mOGd06@20P800PX:208B4Q028R8P0RXZ:08f=S@2?Shl0Ti>C
09BDU02GUiL0VYZJ09nOW`2RXZ80YZJV0:VYZ@2][Jd0]kNg0;^k^`31`L40b<S80<k>cP3De=@0gMgM
0>7Qh@3UiND00P3WinL0:@3/k>`0l?3`0??cl`3fm_H0moOg0>_[j`3UiND0gmoO0=[JfP3EeMD0d=3@
0<K6aP31`L40_Kfm0;Rh^02d];@0[:b/0:NWY`2SXj<0X:2P09bLW02HV9P0TI6A08j>SP2:RXX0QhN7
08B4Q01mOGd0NWYj07MgM`1dM7@0LG5a06][J`1XJ6P0IVIV06=SH`1PH600GEeM05MGE`1EEED0DU9B
0280oooo000P0?ooo`0V08n?S`2:RXX0PH6107alO01hN7P0Lg=c06i^KP1ZJVX0H61P05aLG01GEeL0
DU9B04i>CP14A4@0@41003/k>`0f=SH0<C4a02PX:00T92@07alO01XJ6P0E5AD0410@00`<300G5aL0
8B4Q02LW9`0/;2`0<30`02l_;`0^;Rh0<S8b03De=@0f=SH0>CTi03Xj>P0l?3`203hn?P80@41000<0
?clo0451@@10@4000P0o?cl404=3@`0K04I6AP18B4P0BDU904];B`1=CDd0E5AD05MGE`1KFe/0GUiN
05mOG`1QHF40JFUY06e]K@1aLG40MWIf07]kN`20P800QHF508V9R@2>SXh0Shn?09:BTP2DU9@0UYJF
09NGU`2IVIT0VYZJ0080W9bL00<0WIfM09jNWP2NWYh0202OWil309jNWP0309fMW@2LW9`0W9bL0080
Vi^K00@0VYZJ09VIV@2IVIT0V9RH0P2GUiL209FEU@0309BDU03oool0oooo01`0oooo02T0IfMW06EU
I@1QHF40GemO05eMG@1LG5`0FUYJ05QHF01EEED0De=C055AD@1@D500CTi>04];B`1:BTX0B4Q804M7
A`16ATH0@d=30492@P11@D40?clo03hn?P0m?Cd0?3`l0451@@15ADD0AdM704U9B@1:BTX0B4Q804M7
A`19BDT0Bd];04a<C01>CTh0Cdm?051@D01BDU80De=C05MGE`0205UIF@1105eMG@1NGUh0H61P069R
HP1VIVH0IfMW06YZJP1/K6`0LG5a07EeM@1hN7P0O7al0820P02:RXX0Shn?09FEU@2JVYX0WinO0:BT
Y02/[:`0/;2`0;>c/`2f][H0_;bl0<K6aP3<c<`0d=3@0=GEe@3Bd]80cLg=0<[:bP38b<P0aLG50<?3
``30`<00^k^k0;Vi^@2f][H0];Bd0;6a/@2/[:`0ZZZZ0:NWY`2UYJD0XZ:R0:2PX02KVi/0VIVI09NG
U`2DU9@0TY:B08f=S@2;Rh/0R8R808J6QP24Q8@0Ogmo07emO@1kNg/0N7Qh07IfMP1dM7@0Kfm_06e]
K@1[Jf/07P3oool08@1ADE40De=C05MGE`1IFET0Fe]K05eMG@1OGel0HF5Q06EUI@1WIfL0JFUY06a/
K01^KVh0Lg=c07IfMP1iNGT0Ng]k07inOP24Q8@0QhN708V9R@2<S8`0Shn?09:BTP2FUYH0TI6A08f=
S@2;Rh/0RHV908J6QP25QHD0Ph>308:2PP0308>3P`<0Q8B401T0QXJ608V9R@2<S8`0SXj>096AT@2C
Ti<0VIVI09^KV`2LW9`0WinO0:>SX`2UYJD0ZZZZ0:j^[P2b/[80]KFe0;Vi^@31`L40a/K60<_;b`3@
d=00eMGE0=[JfP3Ogml0hN7Q0080h^;R02X0iNGU0>o_k`3bl_80mOGe0?KfmP3alO40i^KV0>7Qh@3K
fm/0e]KF0=7Ad@3<c<`0`l?30;jn_P2i^KT0]KFe0;6a/@2YZJT0YJFU0:6QX@2MWId0VYZJ09JFUP2?
Shl0S8b<08V9R@25QHD0PX:207alO01iNGT0MWIf07=cL`1`L700JVYZ06QXJ01UIFD0HV9R05mOG`1M
GEd0EeMG05EEE@1BDU8R0?ooo`00803oool0902?Shl0Rh^;08:2PP1mOGd0NGUi07EeM@1`L700Jf][
069RHP1NGUh0FUYJ05EEE@1@D500AdM704=3@`0n?Sh0>SXj03De=@0/;2`0:2PX02<S8`0O7al06QXJ
01DE5@0<30`03Ph>01PH600Q8B409bLW02d];@0/;2`0:RXZ02`/;00a<C40<S8b03De=@80=SHf00@0
>CTi03Xj>P0k>c/0?3`l0P0k>c/01@0l?3`0>CTi03Ph>00i>CT0>c/k0080?Shn01d0?clo0451@@12
@T80A4A404E5A@1<C4`0D51@05ADE01HF5P0GEeM065QH@1WIfL0KFe]071`L01cLg<0NWYj07moO`22
PX80QhN708Z:RP2<S8`0T92@09:BTP2DU9@0UIFE09NGU`2HV9P0VYZJ09^KV`0209bLW00309fMW@2N
WYh0WYjN00L0WYjN0P2MWId209bLW080Vi^K00<0VYZJ09VIV@2IVIT00P2HV9P01@2GUiL0UYJF09FE
U@2EUID0U9BD01h0oooo04D0IfMW06EUI@1RHV80H61P05iNGP1LG5`0Fe]K05UIF@1FEUH0E5AD05=C
D`1ADE40D51@04e=C@1;Bd/0BTY:04U9B@18B4P0ADE504A4A013@d<0@T920410@00o?cl0?3`l03hn
?P13@d<0ATI604U9B@1:BTX0BDU904Q8B01:BTX0CDe=04i>CP1@D500DE5A059BDP1DE5@0EUIF05YJ
FP1KFe/0GEeM05mOG`1QHF40I6AT06EUI@1YJFT0JVYZ06e]K@1_Kfl0M7Ad07QhN01kNg/0P82008>3
P`2=SHd0Ti>C09RHV02LW9`0XJ6Q0:FUY@2[Zj/0/;2`0;:b/P2f][H0_[jn0<S8b03<c<`00P3AdM40
9@3=cLd0b<S80<K6aP34a<@0`L710;no_`2m_Kd0^;Rh0;Fe]@2c/k<0/K6a0:j^[P2YZJT0YjNW0:FU
Y@2RXZ80X:2P09jNWP2IVIT0UiNG09FEU@2BTY80T92@08b<S029RHT0QhN708F5Q@23Ph<0OWin07al
O01jNWX0N7Qh07IfMP1cLg<0Kfm_06e]K@1[Jf/07P3oool0601ADE40De=C05MGE`1HF5P0FUYJ05aL
G01NGUh0H61P06ATI01WIfL0JFUY06][J`1]KFd0LW9b07EeM@1gMgL0NWYj07emO@22PX80QHF508R8
R02;Rh/0SXj>096AT@80UYJF00<0Ti>C08n?S`2=SHd01`29RHT06P2:RXX0Rh^;08b<S02=SHd0TY:B
09BDU02GUiL0VYZJ09bLW02SXj<0YjNW0:ZZZP2[Zj/0[:b/0:n_[`2f][H0^[Zj0;fm_@32`/80a/K6
0<k>cP3Bd]80e]KF0=SHf03Jf]X0g=cL0P3Ph>00;03QhN40i>CT0>WYj@3alO40mOGe0?Ogm`3dm?@0
kNg]0>7Qh@3Lg=`0emOG0=;BdP3=cLd0b<S80;no_`2j^[X0][Jf0;:b/P2^[Zh0YZJV0::RXP2NWYh0
Vi^K09NGU`2DU9@0SHf=08Z:RP27QhL0Q8B40861P@1kNg/0MgMg07AdM01bLW80Kfm_06YZJP1WIfL0
I6AT065QH@1OGel0G5aL05MGE`1DE5@0DU9B8P3oool00200oooo01d0Shn?08^;R`22PX80OWin07Yj
NP1fMWH0LG5a06e]K@1UIFD0H61P05aLG01HF5P0De=C04];B`16ATH0@T9203hn?P0i>CT0<C4a02`/
;00X:2P08b<S01lO7`0J6QX03`l?00/;2`0?3`l061PH020P800202XZ:P0:02PX:00W9bL0:b/[02h^
;P0_;bl0<30`034a<@0c<c<0=CDe03Hf=P@0=cLg0240=SHf03@d=00d=3@0=3@d03De=@0f=SH0>SXj
03/k>`0m?Cd0@4100492@P18B4P0C4a<051@D01FEUH0Fe]K061PH01XJ6P0K6a/06m_K`1bLW80MgMg
07inOP22PX80QHF508R8R02:RXX0Shn?096AT@2BTY80U9BD09FEU@2GUiL00P2IVIT0102JVYX0Vi^K
09bLW02LW9`909fMW@0409bLW02KVi/0Vi^K09^KV`80VYZJ00<0VIVI09RHV02HV9P00P2GUiL0102F
UYH0UIFE09FEU@2DU9@N0?ooo`0M06MWI`1UIFD0HV9R061PH01OGel0GEeM05]KF`1JFUX0EeMG05EE
E@1DE5@0DU9B055AD@1>CTh0CDe=04a<C01:BTX0BDU904M7A`16ATH0ADE504A4A013@d<0@D5103lo
?`0n?Sh0@D5104A4A017AdL00`1;Bd/0901:BTX0CDe=04m?C`1ADE40De=C05ADE01FEUH0F5QH05aL
G01NGUh0H61P069RHP1TI6@0J6QX06UYJ@1[Jf/0KFe]071`L01aLG40N7Qh07]kN`1nOWh0PX:208J6
QP2@T900U9BD09RHV02LW9`0XJ6Q0:BTY02ZZZX0[jn_0;>c/`2i^KT0`<300<S8b080cLg=02H0bl_;
0<W9b@34a<@0`/;20;no_`2m_Kd0^k^k0;Vi^@2d];@0/[:b0;2`/02][Jd0Zj^[0:NWY`2TY:@0XZ:R
0:2PX02NWYh0W9bL09NGU`2EUID0Ti>C096AT@2?Shl0RXZ:08R8R026QXH0Q8B408:2PP1mOGd0Ng]k
07UiN@1gMgL0MGEe07=cL`1_Kfl0KFe]06][Jah0oooo01T0DE5A05=CD`1FEUH0F5QH05YJFP1LG5`0
GUiN061PH01TI6@0IVIV06QXJ01ZJVX0KFe]075aL@1dM7@0MWIf07UiN@1lO7`0PH6108B4Q027QhL0
RHV908b<S02?Shl0UYJF0080VIVI00D0UYJF09:BTP2=SHd0SHf=08n?S`03092@T00I09:BTP2CTi<0
U9BD09FEU@2GUiL0Vi^K09jNWP2PX:00XZ:R0:JVYP2][Jd0/K6a0;Bd]02g]kL0^KVi0;^k^`31`L40
a<C40<O7a`3:b/X0c/k>0=GEe@3Hf=P0fMWI0=[JfP020=cLg00^0=gMg@3Ph>00hn?S0>WYj@3^k^h0
lo?c0?KfmP3emOD0k^k^0>SXj03Lg=`0emOG0=;BdP3=cLd0b<S80<?3``2k^k/0]kNg0;:b/P2^[Zh0
ZZZZ0:>SX`2OWil0W9bL09RHV02EUID0TI6A08^;R`28R8P0QHF508:2PP1oOgl0NGUi07IfMP1cLg<0
LG5a06i^KP1YJFT0IVIV06=SH`1QHF40GUiN05aLG01GEeL0E5AD059BDR80oooo000P0?ooo`0O092@
T02<S8`0Q8B40820P01lO7`0N7Qh07AdM01aLG40JFUY06EUI@1QHF40GEeM05UIF@1ADE40CDe=04U9
B@15ADD0@D5103Ti>@0e=CD0<C4a02d];@0Y:BT092@T01XJ6P0E5AD0410@00d=3@0A4A407AdM020P
800202<S8`808B4Q0P0V9RH02@0W9bL09RHV02LW9`0Z:RX0;2`/02h^;P0];Bd0<30`02l_;`0202h^
;P0N02`/;00Z:RX0:b/[030`<00c<c<0=SHf03Xj>P0m?Cd0ATI604];B`1@D500E5AD05UIF@1MGEd0
I6AT06QXJ01[Jf/0KVi^07=cL`1kNg/0Ogmo08:2PP25QHD0R8R808b<S02>SXh0T92@096AT@2CTi<0
U9BD0P2GUiL0102HV9P0VIVI09VIV@2JVYX:09^KV`80VYZJ0`2IVIT209RHV080UiNG0P2FUYH00`2E
UID0U9BD09BDU00N0?ooo`0`06MWI`1VIVH0Hf=S065QH@1PH600GUiN05eMG@1LG5`0FEUI05MGE`1F
EUH0EEEE05ADE01ADE40D51@04m?C`1>CTh0CDe=04];B`1:BTX0BDU904Q8B017AdL0ATI604A4A013
@d<0@T9204=3@`15ADD0Bd];04e=C@1?Cdl0D51@055AD@1BDU80EUIF05QHF01JFUX0Fe]K05iNGP1R
HV80I6AT06IVIP1XJ6P0K6a/06m_K`1`L700LW9b0P1cLg<0>P1fMWH0O7al07moO`22PX80QHF508R8
R02?Shl0TY:B09FEU@2JVYX0WYjN0:>SX`2][Jd0/k>c0;Rh^02k^k/0`<300<K6aP34a<@0`/;20<30
`02o_kl0^[Zj0;Vi^@2g]kL0]KFe0;>c/`2a/K40[Jf]0:^[Z`2YZJT0YjNW0:FUY@2QXJ40WinO09fM
W@2KVi/0VIVI09NGU`2CTi<0TI6A08n?S`2=SHd0Rh^;08N7Q`25QHD0Ph>30861P@1oOgl0Ng]k07Yj
NP1hN7P0MWIf07AdM01bLW80KVi^06a/K01ZJVXN0?ooo`0N055AD@1CDe<0EUIF05QHF01IFET0Fe]K
05eMG@1OGel0Hf=S06EUI@1WIfL0JFUY06][J`1_Kfl0LW9b07AdM01fMWH0NGUi07inOP20P800Ph>3
08J6QP29RHT0S8b<09>CT`2GUiL0Vi^K09nOW`2NWYh0W9bL0P2KVi/04`2LW9`0WinO0:6QX@2RXZ80
YJFU0:NWY`2ZZZX0[Jf]0:n_[`2`/;00/k>c0;Fe]@2i^KT0_[jn0<71`@34a<@0alO70<[:bP3<c<`0
0P3AdM40103Cdm<0e=CD0=KFeP3GemL20=KFeP070=SHf03Kfm/0gMgM0>KViP3[jn/0kno_0?3`l002
0??cl`0X0>g]k@3WinL0hN7Q0=_Kf`3AdM40c<c<0<O7a`33`l<0_[jn0;Zj^P2c/k<0[jn_0:^[Z`2W
YjL0Xj>S09bLW02IVIT0UYJF09>CT`2@T900S8b<08J6QP24Q8@0PH6107inOP1kNg/0MWIf07=cL`1a
LG40KVi^06a/K01WIfL0I6AT069RHP1PH600GEeM05]KF`1FEUH0E5AD055ADB80oooo000P0?ooo`0T
092@T02<S8`0QHF50861P@1mOGd0NWYj07IfMP1bLW80Jf][06MWI`1SHf<0H61P05aLG01DE5@0DE5A
04e=C@19BDT0ADE503dm?@0j>SX0=SHf038b<P0];Bd0:BTY020P800K6a/05QHF014A4@0>3Ph05aLG
01dM7@0Q8B408R8R024Q8@0O7al08B4Q100S8b<02@0R8R8092@T02LW9`0W9bL0:RXZ02`/;00[:b/0
;Rh^02l_;`0202d];@0K034a<@0c<c<0=cLg03`l?010@400B4Q804Y:BP1>CTh0DU9B05IFEP1JFUX0
HF5Q06IVIP1YJFT0K6a/071`L01jNWX0OGem0861P@24Q8@0QXJ608^;R`2=SHd0Shn?092@T02BTY80
Ti>C0080UYJF00@0UiNG09RHV02IVIT0VIVI1@2JVYX00`2KVi/0VYZJ09ZJVP0309ZJVP<0VIVI0P2H
V9P209NGU`<0UYJF00<0UIFE09BDU02DU9@07P3oool06@1WIfL0IVIV06=SH`1RHV80H61P05mOG`1N
GUh0G5aL05YJFP1HF5P0EeMG05IFEP1EEED0De=C059BDP1@D500Cdm?04i>CP1=CDd0C4a<04];B`1:
BTX0BDU904Q8B017AdL00P16ATH01@15ADD0ATI604];B`1=CDd0D51@0080De=C00/0E5AD05UIF@1K
Fe/0GEeM05mOG`1QHF40I6AT06IVIP1ZJVX0Jf][06i^KP02075aL@0C07=cL`1dM7@0MGEe07IfMP1l
O7`0OWin0861P@23Ph<0QXJ608j>SP2ATI40UYJF09^KV`2OWil0Y:BT0:n_[`2e]KD0^;Rh0;^k^`02
0<30`00X0;jn_P2m_Kd0^k^k0;Vi^@2f][H0];Bd0;>c/`2a/K40[jn_0:f][@2ZZZX0Z:RX0:FUY@2T
Y:@0XZ:R09jNWP2LW9`0VYZJ09RHV02GUiL0UIFE096AT@2?Shl0SHf=08^;R`29RHT0QXJ608B4Q022
PX80P82007inOP1kNg/0NGUi07MgM`1eMGD0Lg=c079bLP1^KVh0K6a/06YZJQh0oooo01h0DE5A059B
DP1FEUH0EeMG05UIF@1KFe/0GEeM05iNGP1RHV80I6AT06IVIP1XJ6P0JVYZ06i^KP1`L700Lg=c07Ee
M@1gMgL0O7al07moO`21PH40Q8B408N7Q`2:RXX0TI6A09FEU@2IVIT0WYjN0:>SX`2PX:0209jNWP0=
0:6QX@2SXj<0YZJV0:^[Z`2][Jd0/;2`0;>c/`2f][H0^k^k0;bl_02n_[h0`<300<;2`P020<G5a@80
a/K600<0bLW90<_;b`3?cll0103@d=00=03Cdm<0eMGE0=WIf@3Lg=`0gmoO0>?Sh`3/k>`0kno_0?7a
l@3bl_80mOGe0>_[j`3UiND0h>3P0=[JfP3EeMD0bl_;0<O7a`32`/80_[jn0;Zj^P2f][H0[Zj^0:ZZ
ZP2VYZH0Xj>S0:2PX02IVIT0UYJF09>CT`2@T900SHf=08Z:RP24Q8@0PH6107moO`1lO7`0NGUi07Ad
M01bLW80Kfm_06e]K@1ZJVX0IVIV06=SH`1QHF40GemO05eMG@1JFUX0EUIF05ADE01ADE4R0?ooo`00
803oool08P2@T900S8b<08F5Q@22PX80OWin07]kN`1gMgL0M7Ad06e]K@1YJFT0IVIV069RHP1OGel0
F5QH05ADE01@D500CDe=04U9B@12@T80?Shn03Xj>P0f=SH0<c<c02l_;`0V9RH08R8R01dM7@0I6AT0
5ADE010@400F5QH07AdM024Q8@0S8b<7024Q8@04020P800Q8B408B4Q02@T9080:BTY01l0:b/[02d]
;@0^;Rh0<30`03@d=00g=cL0>c/k03`l?010@400AdM704U9B@1<C4`0Cdm?059BDP1EEED0GemO06AT
I01WIfL0J6QX06m_K`1iNGT0O7al0820P023Ph<0QHF508Z:RP2<S8`0SXj>08n?S`2ATI40TY:B0080
UIFE00@0UYJF09NGU`2HV9P0V9RH102IVIT509ZJVP<0VIVI0`2HV9P309NGU`80UYJF0P2EUID209BD
U1h0oooo01<0IfMW06IVIP1SHf<0HV9R065QH@1PH600GUiN05eMG@1KFe/0FEUI05QHF01GEeL0EUIF
05ADE01CDe<0DU9B055AD@1@D500CTi>0080CDe=00D0C4a<04];B`1;Bd/0BTY:04U9B@0204Q8B00A
04U9B@1:BTX0CDe=055AD@1DE5@0EUIF05MGE`1LG5`0GUiN061PH01RHV80I6AT06MWI`1YJFT0KFe]
06i^KP1`L7000P1bLW80?@1cLg<0MGEe07EeM@1gMgL0NWYj07alO01oOgl0PX:208J6QP2>SXh0TY:B
09NGU`2LW9`0XJ6Q0:JVYP2`/;00];Bd0;Vi^@2j^[X0_;bl0;Zj^P2i^KT0^;Rh0;Jf]P2e]KD0/[:b
0;2`/02^[Zh0[Jf]0:^[Z`2ZZZX0YZJV0:BTY02RXZ80X:2P09nOW`2KVi/0VYZJ09RHV02FUYH0U9BD
09:BTP2?Shl0SHf=08^;R`2:RXX0R8R808B4Q022PX80PH6107moO`1mOGd0NWYj07QhN01fMWH0M7Ad
07=cL`1aLG40KVi^06a/K01ZJVX07P3oool07P1ADE40DU9B05EEE@1GEeL0FEUI05YJFP1LG5`0GUiN
065QH@1SHf<0IFEU06MWI`1YJFT0KFe]06m_K`1aLG40Lg=c07IfMP1jNWX0OGem0820P022PX80QHF5
08R8R02?Shl0Ti>C09NGU`2KVi/0WinO0:FUY@<0Y:BT00h0YJFU0:VYZ@2`/;00/k>c0;Jf]P2i^KT0
_;bl0<71`@35aLD0bLW90<[:bP3;bl/0bLW90<S8b080bLW903/0b<S80<W9b@3:b/X0bLW90<_;b`3=
cLd0clo?0=GEe@3Hf=P0gMgM0>7Qh@3UiND0j^[Z0>o_k`3`l?00m?Cd0?Gem@3`l?00i>CT0=kNgP3I
fMT0e=CD0<o?c`36a/H0`L710;fm_@2i^KT0]KFe0;6a/@2ZZZX0YZJV0:>SX`2OWil0W9bL09JFUP2C
Ti<0T92@08f=S@2:RXX0QhN708:2PP1oOgl0OGem07YjNP1hN7P0Lg=c071`L01^KVh0K6a/06UYJ@1U
IFD0HV9R061PH01NGUh0G5aL05YJFP1FEUH0De=C055AD@0R0?ooo`00803oool08`2@T900SHf=08J6
QP23Ph<0P82007alO01iNGT0MWIf06m_K`1/K6`0J6QX06EUI@1RHV80Fe]K05MGE`1DE5@0DE5A04e=
C@16ATH0@d=303lo?`0l?3`0>3Ph03@d=00/;2`0:BTY02@T900P820071`L01<C4`0B4Q805QHF01hN
7P0R8R8092@T00<08b<S0P0T92@202DU9@809bLW02<0:2PX02XZ:P0[:b/0;Bd]02l_;`0`<300<S8b
03Hf=P0g=cL0>c/k03`l?00o?cl0ATI604M7A`1:BTX0C4a<051@D01DE5@0GEeM065QH@1WIfL0Jf][
071`L01hN7P0O7al07moO`22PX80Q8B408V9R@2;Rh/0SHf=08n?S`2@T900TI6A09BDU00209FEU@04
09JFUP2GUiL0UiNG09RHV0T0VIVI0`2HV9P409NGU`<0UYJF0P2EUID209BDU1h0oooo00h0IfMW06IV
IP1TI6@0HV9R065QH@1PH600GemO05iNGP1LG5`0FUYJ05UIF@1HF5P0EeMG05EEE@80E5AD00<0De=C
059BDP1@D5000P1?Cdl00`1>CTh0CDe=04e=C@0204a<C0@0Bd];00l0Cdm?051@D01DE5@0F5QH05UI
F@1NGUh0H61P065QH@1TI6@0IFEU06UYJ@1ZJVX0K6a/06e]K@1^KVh00P1aLG40501cLg<0M7Ad07Ad
M01fMWH0NGUi07alO020P800PX:208N7Q`2@T900U9BD09VIV@2NWYh0Xj>S0:JVYP2`/;00];Bd0;Jf
]P2e]KD0][Jf0P2d];@09`2b/[80/K6a0;2`/02][Jd0[:b/0:ZZZP2YZJT0YjNW0:JVYP2SXj<0XJ6Q
09nOW`2MWId0W9bL09RHV02GUiL0UIFE09>CT`2BTY80T92@08f=S@2;Rh/0RHV908R8R026QXH0Ph>3
0861P@1oOgl0OGem07alO01iNGT0MgMg07EeM@1dM7@0LW9b075aL@1]KFd0K6a/06YZJP0N0?ooo`0]
055AD@1BDU80EEEE05MGE`1HF5P0FUYJ05]KF`1MGEd0H61P069RHP1TI6@0IVIV06QXJ01/K6`0KVi^
071`L01bLW80M7Ad07UiN@1kNg/0OWin0820P023Ph<0QXJ608f=S@2@T900U9BD09RHV02LW9`0YZJV
0:^[Z`2YZJT0YjNW0:RXZ02YZJT0/;2`0;Bd]02f][H0^;Rh0;Zj^P30`<00`L710<;2`P33`l<0a<C4
00<0a/K60`35aLD0>@37alL0bLW90<c<c03>c/h0dM7A0=SHf03MgMd0hn?S0>OWi`3[jn/0k>c/0?3`
l03clo<0lO7a0>_[j`3Vi^H0g=cL0=OGe`3Bd]80cLg=0<W9b@30`<00_;bl0;Rh^02d];@0/;2`0:b/
[02UYJD0XZ:R09nOW`2LW9`0VIVI09>CT`2@T900SHf=08Z:RP27QhL0QHF507moO`1mOGd0NWYj07Qh
N01fMWH0LG5a06m_K`1]KFd0JVYZ06QXJ01TI6@0HV9R05mOG`1MGEd0Fe]K05UIF@1EEED0De=C055A
D@0R0?ooo`00803oool0902@T900SHf=08N7Q`24Q8@0PH6107inOP1kNg/0MgMg075aL@1^KVh0Jf][
06QXJ01UIFD0GUiN05]KF`1HF5P0EEEE055AD@1;Bd/0AdM704A4A011@D40?Cdm03Xj>P0c<c<0;bl_
02/[:`0W9bL092@T01`L700I6AT05QHF01PH600O7al08b<S02LW9`@0:2PX0P0Y:BT202XZ:P0502/[
:`0^;Rh0;Rh^030`<00a<C400P0b<S807@0g=cL0>3Ph03/k>`0l?3`0?Shn04A4A016ATH0B4Q804a<
C01@D500E5AD05aLG01RHV80IfMW06a/K01`L700N7Qh07alO01oOgl0PX:208B4Q029RHT0Rh^;08b<
S02>SXh0Shn?096AT@2CTi<0U9BD0080UIFE00<0UYJF09NGU`2GUiL01@2HV9P309VIV@<0V9RH102G
UiL309JFUP80UIFE0`2DU9@N0?ooo`0D06MWI`1VIVH0I6AT06=SH`1RHV80HF5Q061PH01OGel0G5aL
05]KF`1JFUX0FEUI05QHF01GEeL0EUIF05EEE@1DE5@0De=C059BDP1ADE42051@D080Cdm?1@1>CTh0
401?Cdl0D51@055AD@1DE5@0F5QH05]KF`1OGel0HF5Q069RHP1TI6@0IVIV06UYJ@1[Jf/0K6a/06e]
K@1^KVh2071`L00@075aL@1cLg<0M7Ad07EeM@1jNWX0OGem0861P@24Q8@0RHV909:BTP2GUiL0VYZJ
09jNWP2RXZ80YZJV0:j^[P@0/;2`02T0[jn_0:j^[P2][Jd0[:b/0:^[Z`2YZJT0YjNW0:JVYP2UYJD0
Xj>S0::RXP2OWil0WIfM09bLW02JVYX0VIVI09JFUP2DU9@0Ti>C096AT@2?Shl0SXj>08^;R`29RHT0
QhN708J6QP24Q8@0PH610820P01nOWh0O7al07]kN`1hN7P0MWIf07EeM@1cLg<0LW9b071`L01]KFd0
K6a/06YZJP0N0?ooo`0Q055AD@1BDU80EEEE05IFEP1HF5P0FEUI05]KF`1LG5`0H61P065QH@1SHf<0
IFEU06MWI`1ZJVX0K6a/06i^KP1`L700LW9b07MgM`1iNGT0Ng]k07inOP21PH40Q8B408Z:RP2=SHd0
TI6A09BDU02HV9P0XJ6Q0:JVYP2[Zj/0[Jf]0080[:b/00T0[Zj^0;2`/02b/[80]KFe0;Rh^02l_;`0
_Kfm0;no_`30`<001031`L40?032`/80`l?30<C4a036a/H0bLW90<c<c03@d=00e]KF0=kNgP3Rh^80
iNGU0>SXj03YjNT0jn_[0>o_k`3/k>`0inOW0>;RhP3MgMd0e=CD0<o?c`3;bl/0a/K60<;2`P2j^[X0
][Jf0;:b/P2_[jl0Zj^[0:NWY`2QXJ40WYjN09^KV`2HV9P0UIFE08n?S`2<S8`0RXZ:08N7Q`24Q8@0
PX:207emO@1jNWX0N7Qh07IfMP1dM7@0Kfm_06e]K@1[Jf/0JFUY06MWI`1SHf<0HF5Q05mOG`1MGEd0
Fe]K05UIF@1EEED0De=C055ADB80oooo000P0?ooo`0[096AT@2>SXh0RHV908J6QP23Ph<0P82007in
OP1kNg/0MGEe07=cL`1`L700KFe]06YZJP1UIFD0HV9R05mOG`1LG5`0FEUI05ADE01ADE40CTi>04];
B`18B4P0ADE503lo?`0l?3`0>CTi03Hf=P0c<c<0;Bd]02/[:`0X:2P09RHV02DU9@0S8b<09BDU02TY
:@0];Bd0<30`034a<@0c<c<0<S8b03<c<`02038b<P80<C4a0240<S8b03@d=00e=CD0=CDe03@d=00g
=cL0>SXj03/k>`0o?cl0ATI604M7A`19BDT0C4a<059BDP1GEeL0HF5Q06IVIP1ZJVX0KVi^07=cL`1i
NGT0O7al07moO`22PX80Q8B408R8R02:RXX0S8b<08f=S@2?Shl0T92@09:BTP2CTi<00P2DU9@00`2E
UID0UYJF09JFUP0209JFUP<0UiNG0P2HV9P00`2GUiL0V9RH09RHV00209NGU`D0UYJF0`2EUID309BD
U1h0oooo00X0J6QX06MWI`1UIFD0I6AT06=SH`1RHV80HF5Q061PH01NGUh0GEeM0P1LG5`01P1KFe/0
FEUI05QHF01HF5P0EeMG05IFEP80EEEE0P1DE5@305=CD`80DU9B0P1CDe<03@1DE5@0EEEE05MGE`1H
F5P0FUYJ05]KF`1QHF40HV9R06ATI01VIVH0IfMW06YZJP1[Jf/00P1]KFd0501^KVh0Kfm_071`L01b
LW80M7Ad07EeM@1hN7P0O7al0861P@25QHD0QhN708^;R`2CTi<0UiNG09VIV@2MWId0WinO0:2PX02S
Xj<0Y:BT102UYJD0:02TY:@0Xj>S0:>SX`2RXZ80X:2P09nOW`2NWYh0WIfM09bLW02JVYX0V9RH09NG
U`2EUID0U9BD09>CT`2@T900Shn?08f=S@2<S8`0RXZ:08V9R@26QXH0QHF508B4Q022PX80PH6107in
OP1mOGd0Ng]k07YjNP1hN7P0MWIf07AdM01cLg<0LW9b075aL@1_Kfl0KFe]06][J`1ZJVXN0?ooo`0U
051@D01BDU80E5AD05IFEP1GEeL0F5QH05YJFP1KFe/0GUiN05mOG`1QHF40HV9R06ATI01WIfL0JFUY
06][J`1]KFd0Kfm_07=cL`1eMGD0MgMg07UiN@1lO7`0OWin08>3P`26QXH0RHV908f=S@2@T900V9RH
09bLW02PX:00Y:BT0:VYZ@2][Jd0/k>c0;6a/@020:n_[`150;2`/02d];@0][Jf0;Ng]`2h^;P0^[Zj
0;bl_02n_[h0_kno0<71`@32`/80aLG50<g=c@3AdM40e=CD0=KFeP3Hf=P0g]kN0>7Qh@3Ti>@0iNGU
0>?Sh`3Ph>00f][J0=OGe`3Cdm<0clo?0<_;b`33`l<0_kno0;bl_02h^;P0];Bd0:f][@2ZZZX0YZJV
0:>SX`2PX:00WIfM09NGU`2DU9@0TY:B08n?S`2=SHd0R8R808F5Q@23Ph<0PH6107inOP1lO7`0MgMg
07EeM@1cLg<0LG5a06m_K`1[Jf/0JFUY06MWI`1VIVH0I6AT061PH01OGel0GEeM05]KF`1IFET0EeMG
05ADE01CDe<0DE5A0280oooo000P0?ooo`0R096AT@2>SXh0RHV908N7Q`24Q8@0PX:207moO`1mOGd0
MgMg07EeM@1bLW80L71`06e]K@1XJ6P0IFEU06=SH`1QHF40GEeM05QHF01EEED0De=C051@D01=CDd0
Bd];04E5A@13@d<0@41003dm?@0j>SX0=CDe03<c<`0a<C40;bl_02h^;P80;Bd]00D0:b/[02d];@0_
;bl0<c<c03Hf=P0303Lg=`0T03Hf=P0d=3@0=3@d03<c<`0d=3@0=CDe03Lg=`0h>3P0>SXj03hn?P10
@400@D5104Q8B01<C4`0Cdm?05=CD`1GEeL0Fe]K06ATI01YJFT0K6a/071`L01dM7@0NWYj07emO@20
P800PX:208B4Q028R8P0RXZ:08^;R`2=SHd0SXj>08n?S`2BTY80Ti>C0P2DU9@0102EUID0UYJF09JF
UP2FUYH809NGU`0309RHV02GUiL0UiNG00@0UYJF102EUID309BDU1h0oooo00H0J6QX06MWI`1UIFD0
I6AT06=SH`1RHV82065QH@0505mOG`1NGUh0GEeM05eMG@1LG5`00P1JFUX205UIF@0405QHF01GEeL0
EUIF05IFEP@0EEEE00X0E5AD05EEE@1EEED0EEEE05IFEP1GEeL0F5QH05YJFP1KFe/0GEeM0P1QHF40
6P1TI6@0IFEU06MWI`1[Jf/0K6a/06e]K@1^KVh0Kfm_071`L01aLG40LW9b07AdM01gMgL0NGUi07em
O@21PH40Q8B408N7Q`2;Rh/0Ti>C09FEU@2GUiL0V9RH09ZJVP2LW9`0WYjN0P2OWil30:2PX080WinO
02H0WYjN09fMW@2LW9`0Vi^K09ZJVP2IVIT0V9RH09NGU`2DU9@0Ti>C09:BTP2ATI40T92@08f=S@2<
S8`0RXZ:08V9R@28R8P0QhN708B4Q023Ph<0PX:20820P01oOgl0OGem07]kN`1jNWX0N7Qh07MgM`1e
MGD0M7Ad079bLP1aLG40L71`06m_K`1/K6`0Jf][06YZJQh0oooo02P0D51@059BDP1DE5@0EEEE05IF
EP1HF5P0FEUI05YJFP1MGEd0GUiN061PH01QHF40Hf=S06IVIP1WIfL0JFUY06][J`1/K6`0L71`079b
LP1dM7@0MgMg07UiN@1kNg/0P82008>3P`26QXH0RHV908b<S02CTi<0UYJF09ZJVP2NWYh0XZ:R0:JV
YP2[Zj/0[Zj^0;6a/@2`/;00[jn_0P2a/K40@P2c/k<0]KFe0;Jf]P2j^[X0_Kfm0;no_`31`L40`l?3
0<K6aP3:b/X0cLg=0<k>cP3AdM40eMGE0=_Kf`3Jf]X0fMWI0=SHf03Fe]H0e=CD0<o?c`3<c<`0b<S8
0<G5a@32`/80^k^k0;Ng]`2d];@0/;2`0:f][@2WYjL0Y:BT0:6QX@2NWYh0Vi^K09RHV02BTY80T92@
08f=S@2;Rh/0R8R808>3P`21PH40Ogmo07alO01jNWX0NGUi07EeM@1cLg<0LG5a06m_K`1]KFd0JFUY
06MWI`1UIFD0I6AT069RHP1OGel0GEeM05aLG01JFUX0FEUI05MGE`1DE5@0DU9B055ADB80oooo000P
0?ooo`0S096AT@2?Shl0RXZ:08R8R025QHD0Ph>30861P@1nOWh0NWYj07MgM`1eMGD0Lg=c071`L01[
Jf/0JFUY06IVIP1TI6@0HF5Q05eMG@1JFUX0F5QH05EEE@1CDe<0D51@04];B`19BDT0ATI604A4A012
@T80?Cdm03/k>`0j>SX0>3Ph03Lg=`0f=SH00P0e=CD01@0d=3@0<c<c03@d=00g=cL0>3Ph00@0>SXj
100k>c/07P0l?3`0?Shn03hn?P10@400@T9204I6AP1=CDd0DE5A05EEE@1HF5P0Fe]K061PH01WIfL0
Jf][06m_K`1bLW80MGEe07]kN`1nOWh0P82008>3P`25QHD0R8R808Z:RP2;Rh/0SHf=08j>SP2?Shl0
TI6A09:BTP80Ti>C00<0U9BD09FEU@2FUYH00`2FUYH0102GUiL0UYJF09NGU`2FUYH409NGU`<0UYJF
1P2EUID309BDU1h0oooo00<0J6QX06MWI`1UIFD00P1TI6@01@1SHf<0HV9R065QH@1PH600GemO0080
GUiN00<0GEeM05aLG01KFe/00P1JFUX00`1IFET0F5QH05QHF00405MGE`80EUIF0`1GEeL03@1HF5P0
FEUI05YJFP1KFe/0GEeM05iNGP1QHF40HV9R06ATI01UIFD0J6QX06][J`1]KFd00P1^KVh04`1_Kfl0
L71`075aL@1bLW80MGEe07MgM`1iNGT0OGem0820P024Q8@0QhN708Z:RP2?Shl0TI6A09>CT`2DU9@0
UIFE09NGU`2IVIT00P2JVYX309^KV`<0VYZJ02D0VIVI09RHV02GUiL0UYJF09FEU@2DU9@0Ti>C096A
T@2@T900Shn?08j>SP2=SHd0RXZ:08V9R@28R8P0QhN708J6QP24Q8@0PX:20861P@20P800OWin07em
O@1kNg/0NWYj07QhN01gMgL0MWIf07AdM01cLg<0LW9b075aL@1_Kfl0KVi^06a/K01[Jf/0JVYZ01h0
oooo02P0D51@055AD@1DE5@0EEEE05IFEP1GEeL0F5QH05YJFP1LG5`0GEeM05mOG`1PH600HF5Q06AT
I01VIVH0IfMW06UYJ@1[Jf/0KVi^071`L01bLW80M7Ad07IfMP1hN7P0OGem07moO`22PX80QHF508R8
R02>SXh0TI6A09BDU02HV9P0Vi^K09jNWP2SXj<0YZJV0:RXZ02[Zj/0[Zj^0P2a/K420;:b/P100;>c
/`2e]KD0][Jf0;Ng]`2k^k/0_[jn0<30`035aLD0bLW90<g=c@3?cll0d=3@0<o?c`3>c/h0cLg=0<c<
c03;bl/0bLW90<C4a032`/80_kno0;bl_02i^KT0/k>c0:n_[`2/[:`0ZJVY0:JVYP2QXJ40WYjN09^K
V`2HV9P0UIFE09>CT`2>SXh0Rh^;08V9R@27QhL0Q8B40820P01mOGd0Ng]k07UiN@1hN7P0MWIf079b
LP1`L700KVi^06e]K@1[Jf/0IfMW06IVIP1TI6@0HV9R065QH@1NGUh0G5aL05]KF`1IFET0F5QH05MG
E`1DE5@0DU9B055ADB80oooo000P0?ooo`0S096AT@2?Shl0Rh^;08V9R@27QhL0Q8B408:2PP20P800
O7al07YjNP1gMgL0MGEe07=cL`1_Kfl0K6a/06YZJP1XJ6P0IVIV065QH@1OGel0GEeM05YJFP1HF5P0
EUIF059BDP1?Cdl0CDe=04];B`19BDT0ADE504=3@`12@T80@D510410@00o?cl01@0m?Cd203hn?P80
?clo00D0@41003hn?P0n?Sh0?Shn03lo?`020410@00M04=3@`15ADD0AdM704Y:BP1=CDd0De=C05MG
E`1KFe/0GUiN061PH01TI6@0Jf][06i^KP1bLW80M7Ad07MgM`1lO7`0Ogmo0861P@23Ph<0QHF508V9
R@2:RXX0Rh^;08f=S@2>SXh0Shn?096AT@2BTY800P2CTi<00`2DU9@0UIFE09FEU@0209FEU@<0UYJF
00<0UiNG09JFUP2FUYH01P2FUYH609FEU@<0U9BD7P3oool01@1XJ6P0IfMW06IVIP1UIFD0I6AT0080
Hf=S00<0HV9R065QH@1PH6000P1OGel01@1NGUh0GEeM05aLG01LG5`0Fe]K0080FUYJ101IFET405QH
F080FEUI02<0FUYJ05]KF`1LG5`0GEeM05iNGP1OGel0HV9R06=SH`1UIFD0IVIV06QXJ01[Jf/0K6a/
06e]K@1^KVh0Kfm_071`L01aLG40Lg=c07EeM@1gMgL0NGUi07emO@20P800PX:208F5Q@27QhL0Rh^;
08f=S@2?Shl0T92@096AT@2BTY80U9BD09FEU@0609JFUP80UIFE00T0U9BD09>CT`2BTY80TI6A092@
T02?Shl0SXj>08f=S@2<S8`00P2:RXX02`27QhL0QXJ608F5Q@24Q8@0Ph>308:2PP20P800Ogmo07in
OP1lO7`0Ng]k0080NGUi00`0MgMg07IfMP1eMGD0Lg=c079bLP1aLG40L71`06m_K`1^KVh0K6a/06][
J`1ZJVXN0?ooo`0g051@D01ADE40De=C05ADE01EEED0EeMG05QHF01IFET0Fe]K05aLG01NGUh0GemO
061PH01SHf<0I6AT06IVIP1WIfL0J6QX06a/K01^KVh0Kfm_075aL@1cLg<0MGEe07UiN@1lO7`0OWin
0861P@23Ph<0RHV908b<S02?Shl0TI6A09BDU02GUiL0W9bL09nOW`2QXJ40Xj>S0:JVYP2YZJT0ZZZZ
0:^[Z`2/[:`0[Jf]0;2`/02c/k<0]KFe0;Ng]`2j^[X0_;bl0<30`031`L40`/;20<?3``020<C4a00c
0<?3``32`/80`L710;no_`2m_Kd0^KVi0;Ng]`2e]KD0/k>c0;2`/02[Zj/0Z:RX0:FUY@2RXZ80WinO
09ZJVP2HV9P0UIFE09:BTP2?Shl0SHf=08V9R@26QXH0Q8B408:2PP20P800O7al07YjNP1hN7P0MWIf
07AdM01cLg<0Kfm_06e]K@1/K6`0JVYZ06QXJ01UIFD0I6AT06=SH`1QHF40GemO05eMG@1KFe/0FUYJ
05UIF@1GEeL0EUIF05=CD`1BDU80D51@0280oooo000P0?ooo`0S096AT@2@T900S8b<08Z:RP28R8P0
QXJ608B4Q022PX80OWin07alO01jNWX0N7Qh07IfMP1bLW80L71`06i^KP1/K6`0JVYZ06IVIP1TI6@0
HV9R061PH01NGUh0G5aL05QHF01FEUH0E5AD059BDP1@D500CDe=04];B`1:BTX0BDU904Q8B017AdL0
1@15ADD204I6AP<0AdM70`16ATH07`17AdL0B4Q804Q8B01;Bd/0CDe=04m?C`1BDU80E5AD05YJFP1M
GEd0H61P06=SH`1UIFD0J6QX06i^KP1aLG40M7Ad07MgM`1iNGT0OWin0820P022PX80Q8B408J6QP29
RHT0Rh^;08b<S02=SHd0SXj>08n?S`2ATI400P2BTY800`2CTi<0U9BD09BDU00509FEU@P0UYJF1`2E
UID409BDU1h0oooo00<0J6QX06MWI`1VIVH00P1UIFD00`1TI6@0Hf=S06=SH`02065QH@80H61P00<0
GemO05iNGP1MGEd00P1MGEd0101LG5`0Fe]K05]KF`1KFe/605YJFP80Fe]K0P1LG5`02`1MGEd0GUiN
05mOG`1PH600Hf=S06ATI01UIFD0IVIV06QXJ01[Jf/0K6a/0080KFe]01<0KVi^071`L01aLG40Lg=c
07AdM01fMWH0MgMg07alO01nOWh0P82008:2PP24Q8@0R8R808Z:RP2;Rh/0S8b<08f=S@2>SXh0T92@
0080TI6A0`2BTY84096AT@80Shn?0180SXj>08f=S@2<S8`0S8b<08Z:RP29RHT0R8R808N7Q`26QXH0
QHF508B4Q023Ph<0PX:20861P@20P800OWin07emO@1lO7`207YjNP0<07QhN01gMgL0MWIf07EeM@1d
M7@0LW9b075aL@1`L700Kfm_06i^KP1]KFd0Jf][0P1ZJVXN0?ooo`0f051@D01ADE40De=C05ADE01E
EED0EUIF05MGE`1HF5P0FUYJ05]KF`1LG5`0GEeM05mOG`1QHF40HV9R06ATI01UIFD0IfMW06UYJ@1[
Jf/0KFe]06i^KP1`L700LW9b07IfMP1hN7P0NWYj07alO01oOgl0Q8B408J6QP29RHT0Rh^;08j>SP2@
T900UIFE09NGU`2IVIT0Vi^K09fMW@2PX:00XJ6Q0:>SX`2TY:@0YJFU0:RXZ02ZZZX0[:b/0:j^[P2`
/;00/K6a0;Bd]02f][H0]kNg102h^;P0<P2g]kL0][Jf0;Bd]02c/k<0[jn_0:f][@2[Zj/0ZJVY0:NW
Y`2RXZ80WinO09fMW@2KVi/0V9RH09>CT`2ATI40Shn?08b<S02:RXX0R8R808B4Q022PX80P82007in
OP1lO7`0N7Qh07IfMP1eMGD0Lg=c075aL@1`L700K6a/06][J`1YJFT0J6QX06IVIP1SHf<0HV9R065Q
H@1PH600GUiN05]KF`1JFUX0FEUI05QHF01GEeL0EEEE05=CD`1ADE40D51@8P3oool00200oooo0200
TY:B092@T02=SHd0S8b<08Z:RP28R8P0QhN708F5Q@22PX80PH6107moO`1mOGd0O7al07UiN@1gMgL0
MGEe07AdM01bLW80Kfm_06e]K@1/K6`0JVYZ06QXJ01WIfL0I6AT069RHP1QHF40GemO05iNGP1KFe/0
FUYJ05UIF@80F5QH00<0EeMG05IFEP1EEED00P1EEED905IFEP0L05MGE`1HF5P0F5QH05]KF`1LG5`0
GUiN061PH01QHF40IVIV06QXJ01ZJVX0KFe]06m_K`1aLG40MGEe07QhN01jNWX0O7al07inOP22PX80
Q8B408F5Q@27QhL0R8R808^;R`2<S8`0SHf=08j>SP80Shn?00D0TI6A09:BTP2BTY80TY:B09>CT`02
09BDU0`0UIFE00<0UYJF09FEU@2EUID00P2EUID609BDU1h0oooo0P1XJ6P206IVIP80IFEU0P1TI6@0
1@1SHf<0HV9R069RHP1RHV80HF5Q0080H61P0`1OGel305iNGPD0GEeM0`1NGUh0101OGel0H61P061P
H01QHF42069RHP0806ATI01UIFD0IVIV06MWI`1XJ6P0JVYZ06][J`1/K6`206e]K@0>06m_K`1`L700
LG5a079bLP1dM7@0MGEe07QhN01jNWX0Ng]k07emO@1nOWh0PH6108:2PP23Ph<208F5Q@0308J6QP27
QhL0R8R800H0RHV90P28R8P208N7Q`80QXJ60P25QHD208>3P`0408:2PP21PH40P82007moO`80OWin
00@0OGem07alO01kNg/0NGUi0P1hN7P0101gMgL0MWIf07EeM@1dM7@207=cL`0:075aL@1`L700Kfm_
06m_K`1^KVh0KFe]06a/K01[Jf/0JVYZ06UYJAh0oooo00D0D51@055AD@1BDU80De=C05ADE00205EE
E@0]05IFEP1HF5P0FEUI05YJFP1KFe/0G5aL05iNGP1OGel0H61P065QH@1RHV80I6AT06IVIP1WIfL0
J6QX06YZJP1[Jf/0KVi^071`L01bLW80M7Ad07EeM@1iNGT0Ng]k07emO@1oOgl0PH6108:2PP26QXH0
R8R808Z:RP2<S8`0SHf=08n?S`2ATI40TY:B09>CT`2DU9@0UiNG09RHV02JVYX0Vi^K09bLW02MWId0
X:2P0080XJ6Q0`2RXZ820:6QX@0a0:2PX02OWil0WYjN09^KV`2JVYX0VIVI09NGU`2EUID0TI6A08n?
S`2>SXh0Rh^;08V9R@26QXH0Q8B408:2PP20P800Ogmo07emO@1jNWX0N7Qh07IfMP1eMGD0Lg=c071`
L01_Kfl0KFe]06a/K01[Jf/0JFUY06MWI`1UIFD0I6AT06=SH`1RHV80GemO05iNGP1MGEd0G5aL05]K
F`1IFET0F5QH05MGE`1FEUH0EEEE05ADE01BDU80DE5A051@D00R0?ooo`00803oool07@2BTY80TI6A
08j>SP2=SHd0Rh^;08Z:RP28R8P0QhN708B4Q023Ph<0PX:20820P01oOgl0O7al07]kN`1iNGT0N7Qh
07IfMP1cLg<0LW9b071`L01_Kfl0KVi^06a/K01ZJVX0J6QX06MWI`1VIVH0IFEU0080HV9R00D0HF5Q
061PH01OGel0GemO05iNGP0305eMG@T0GUiN0P1OGel05`1PH600HV9R06=SH`1UIFD0IVIV06QXJ01/
K6`0KVi^06m_K`1bLW80M7Ad07EeM@1iNGT0Ng]k07emO@1oOgl0P82008B4Q026QXH0QhN708R8R029
RHT0S8b<0080SHf=00@0SXj>08n?S`2@T900TI6A0`2BTY80102CTi<0U9BD09BDU02DU9@>09FEU@<0
U9BD00<0UIFE09BDU02DU9@00P2DU9@N0?ooo`80J6QX00<0IfMW06IVIP1VIVH00P1UIFD206ATI080
Hf=S0P1RHV83065QH@<0H61P2P1OGel00`1PH600HF5Q065QH@02069RHP0706=SH`1UIFD0IFEU06IV
IP1WIfL0J6QX06YZJP0206][J`0A06a/K01]KFd0KVi^06m_K`1`L700LG5a079bLP1dM7@0MWIf07Qh
N01iNGT0NWYj07]kN`1nOWh0Ogmo0820P021PH400P22PX801023Ph<0Q8B408B4Q024Q8@308F5Q@<0
Q8B40P23Ph<308:2PP070861P@20P800Ogmo07moO`1nOWh0OGem07alO00207]kN`0407YjNP1iNGT0
NGUi07MgM`80MWIf00D0MGEe07AdM01cLg<0Lg=c079bLP02075aL@0306m_K`1^KVh0KVi^0080KFe]
00@0K6a/06YZJP1ZJVX0JFUY7P3oool2051@D004059BDP1CDe<0De=C05ADE080EEEE0240EeMG05QH
F01IFET0FEUI05YJFP1LG5`0GEeM05iNGP1OGel0H61P069RHP1SHf<0I6AT06EUI@1WIfL0J6QX06][
J`1/K6`0KVi^06m_K`1aLG40M7Ad07IfMP1gMgL0NGUi07]kN`1lO7`0Ogmo0861P@23Ph<0Q8B408F5
Q@28R8P00P29RHT02P2:RXX0S8b<08j>SP2?Shl0T92@09:BTP2CTi<0U9BD09FEU@2FUYH509NGU`0T
09JFUP2EUID0U9BD09BDU02BTY80TI6A08n?S`2=SHd0S8b<08V9R@27QhL0QHF508>3P`22PX80Ogmo
07emO@1lO7`0NWYj07UiN@1gMgL0MGEe07=cL`1bLW80L71`06m_K`1/K6`0JVYZ06UYJ@1XJ6P0IfMW
06IVIP1SHf<0HV9R065QH@1PH600GemO0P1MGEd0301LG5`0Fe]K05YJFP1HF5P0EeMG05IFEP1EEED0
E5AD05=CD`1BDU80DE5A051@D280oooo000P0?ooo`0P09:BTP2ATI40Shn?08j>SP2<S8`0Rh^;08Z:
RP29RHT0QXJ608F5Q@24Q8@0Ph>308:2PP1oOgl0OWin07emO@1lO7`0NWYj07QhN01gMgL0MGEe07Ad
M01cLg<0LW9b071`L01_Kfl0KVi^06a/K01[Jf/0JVYZ06UYJ@1XJ6P206MWI`80IVIV1@1UIFD00`1V
IVH0IFEU06IVIP0406IVIP80IfMW01X0J6QX06UYJ@1ZJVX0K6a/06e]K@1^KVh0LW9b07=cL`1eMGD0
MWIf07QhN01jNWX0OGem07inOP20P800PX:208>3P`25QHD0QhN708R8R02:RXX0Rh^;08b<S02=SHd0
SXj>08n?S`80T92@00<0TI6A09:BTP2CTi<00P2CTi<609BDU0X0UIFE2@2DU9@N0?ooo`80J6QX0P1W
IfL206IVIP80IFEU0`1TI6@206=SH`@0HV9R0P1QHF47061PH0<0HF5Q0`1RHV8206=SH`0306ATI01U
IFD0IVIV0080IfMW00H0J6QX06YZJP1ZJVX0Jf][06a/K01]KFd206i^KP0606m_K`1`L700LG5a079b
LP1dM7@0MGEe0P1gMgL01@1iNGT0Ng]k07alO01lO7`0OGem0080OWin00<0Ogmo0820P020P8001`20
P80307moO`80OWin0P1mOGd207alO00407]kN`1jNWX0NGUi07UiN@80N7Qh00<0MgMg07IfMP1eMGD0
0P1dM7@207=cL`03079bLP1aLG40LG5a0080L71`0P1^KVh206e]K@0506a/K01[Jf/0JVYZ06YZJP1Y
JFT07P3oool2051@D007055AD@1BDU80De=C05=CD`1DE5@0EEEE05IFEP0205MGE`0U05QHF01IFET0
FUYJ05]KF`1LG5`0GEeM05iNGP1OGel0H61P065QH@1RHV80Hf=S06ATI01WIfL0J6QX06UYJ@1[Jf/0
K6a/06m_K`1`L700LW9b07=cL`1dM7@0MWIf07UiN@1jNWX0Ng]k07alO01mOGd0Ogmo0820P021PH40
PX:208>3P`25QHD0QXJ608N7Q`0208R8R00408V9R@2;Rh/0S8b<08b<S0<0SHf=0P2<S8`0:`2;Rh/0
RXZ:08Z:RP28R8P0QhN708J6QP25QHD0Q8B40861P@1oOgl0OWin07alO01kNg/0N7Qh07MgM`1fMWH0
M7Ad07=cL`1aLG40Kfm_06i^KP1/K6`0Jf][06YZJP1XJ6P0IfMW06IVIP1UIFD0I6AT06=SH`1QHF40
H61P05mOG`1NGUh0GEeM05aLG01KFe/0FUYJ05UIF@1HF5P0EeMG05IFEP1EEED00P1DE5@0101CDe<0
DE5A051@D01@D50R0?ooo`00803oool0502BTY80TI6A092@T02?Shl0SXj>08f=S@2<S8`0Rh^;08V9
R@28R8P0QhN708J6QP25QHD0Ph>308:2PP21PH40P82007moO`1mOGd0Ng]k0P1jNWX02@1iNGT0N7Qh
07IfMP1eMGD0M7Ad07=cL`1bLW80LG5a071`L00306m_K`0306i^KP1]KFd0KFe]00L0KFe]1@1^KVh2
06m_K`0>071`L01aLG40Lg=c07=cL`1dM7@0MgMg07UiN@1jNWX0Ng]k07alO01nOWh0PH6108:2PP23
Ph<208F5Q@0508R8R029RHT0RXZ:08^;R`2<S8`00P2>SXh00`2?Shl0T92@092@T002096AT@0409:B
TP2CTi<0Ti>C09>CT`@0U9BD00@0UIFE09BDU02EUID0U9BD0`2EUID00`2DU9@0UIFE09FEU@0209FE
U@L0U9BD0P2CTi<N0?ooo`80J6QX0`1WIfL306IVIP<0IFEU0P1TI6@506=SH`/0HV9R0`1SHf<206AT
I00406EUI@1VIVH0IfMW06MWI`80J6QX00L0JFUY06YZJP1[Jf/0Jf][06a/K01]KFd0KVi^0080Kfm_
00L0L71`075aL@1bLW80Lg=c07AdM01eMGD0MWIf0080N7Qh00<0NGUi07YjNP1jNWX00P1kNg/207al
O00307emO@1lO7`0O7al00@0O7al101kNg/207YjNP80NGUi0P1hN7P207MgM`80MWIf0P1eMGD00`1d
M7@0Lg=c079bLP02079bLP03075aL@1`L700L71`0080Kfm_00<0KVi^06e]K@1]KFd00P1/K6`206][
J`80JVYZ00<0JFUY0?ooo`3oool0703oool2051@D003055AD@1BDU80DU9B0080De=C00@0E5AD05EE
E@1EEED0EUIF0P1GEeL00`1HF5P0FEUI05YJFP0205]KF`80GEeM01H0GUiN05mOG`1PH600HF5Q06=S
H`1TI6@0IFEU06IVIP1WIfL0JVYZ06][J`1/K6`0KFe]06i^KP1_Kfl0LW9b07=cL`1dM7@0MGEe07If
MP1gMgL0N7Qh0P1iNGT00`1jNWX0O7al07emO@0207inOP0407moO`20P800PH610861P@D0PX:20`21
PH404P20P800OWin07emO@1mOGd0O7al07YjNP1hN7P0MgMg07IfMP1eMGD0M7Ad075aL@1`L700Kfm_
06i^KP1]KFd0K6a/06YZJP80J6QX00P0IfMW06IVIP1TI6@0Hf=S069RHP1QHF40H61P05mOG`80GEeM
00@0G5aL05]KF`1KFe/0FEUI0P1HF5P205MGE`80EEEE0P1DE5@01@1CDe<0DU9B055AD@1ADE40D51@
0280oooo000P0?ooo`0;09>CT`2BTY80T92@092@T02?Shl0SXj>08f=S@2<S8`0Rh^;08Z:RP29RHT0
0P28R8P01P26QXH0QHF508B4Q024Q8@0Ph>30861P@80P82000D0Ogmo07inOP1mOGd0O7al07]kN`02
07YjNP0407UiN@1hN7P0MgMg07MgM`<0MWIf0`1eMGD207AdM0L0MGEe101fMWH03P1gMgL0N7Qh07Ui
N@1jNWX0Ng]k07alO01nOWh0Ogmo0820P021PH40PX:208B4Q025QHD0QXJ60P28R8P00`2:RXX0Rh^;
08b<S00208f=S@80Shn?0P2@T902096AT@<0TY:B0`2CTi<<09BDU00309FEU@2DU9@0U9BD00P0U9BD
00<0Ti>C0?ooo`3oool0703oool306QXJ0@0IfMW0`1VIVH406EUI@@0I6AT2P1SHf<406ATI080IFEU
00<0IVIV06MWI`1WIfL00`1XJ6P00`1YJFT0JVYZ06YZJP0206][J`0306a/K01]KFd0KFe]0080KVi^
00@0Kfm_071`L01aLG40LW9b0P1cLg<207EeM@80MWIf0P1gMgL<07QhN0@0MgMg00@0MWIf07EeM@1e
MGD0MGEe0P1dM7@307=cL`80LW9b00D0LG5a071`L01`L700L71`06m_K`0406i^KP0406e]K@1/K6`0
K6a/06a/K080Jf][0P1ZJVX206UYJAh0oooo0P1@D502055AD@<0DU9B00<0De=C05ADE01DE5@00P1E
EED00`1FEUH0EeMG05MGE`0205QHF00505UIF@1JFUX0FUYJ05]KF`1LG5`00P1MGEd03P1OGel0H61P
065QH@1RHV80Hf=S06ATI01UIFD0IVIV06MWI`1XJ6P0JFUY06][J`1/K6`0KFe]0P1^KVh01P1_Kfl0
L71`071`L01aLG40LW9b07=cL`80M7Ad00<0MGEe07IfMP1fMWH00P1gMgL607QhN00407MgM`1fMWH0
MWIf07EeM@80M7Ad00D0Lg=c079bLP1`L700Kfm_06i^KP0206e]K@0406][J`1ZJVX0JFUY06QXJ080
IfMW00T0IFEU06ATI01SHf<0HV9R065QH@1PH600GemO05iNGP1MGEd00P1LG5`01P1KFe/0FUYJ05YJ
FP1IFET0F5QH05MGE`<0EUIF00<0EEEE05ADE01DE5@00P1CDe<2059BDP03055AD@1@D500Cdm?0280
oooo000P0?ooo`80Ti>C00@0TY:B096AT@2ATI40TI6A0P2@T90208n?S`<0SXj>00<0SHf=08b<S02<
S8`00P2;Rh/308Z:RP80RHV90P28R8P208N7Q`@0QXJ60`25QHD00`24Q8@0QHF508B4Q00808B4Q0@0
QHF500<0Q8B408F5Q@26QXH00P26QXH208N7Q`0308R8R029RHT0RHV90080RXZ:00<0Rh^;08b<S02=
SHd00P2=SHd208j>SP0308n?S`2@T900T92@0080TI6A1`2BTY8209>CT`0309BDU02CTi<0Ti>C0080
U9BD00<0Ti>C09BDU02DU9@0402DU9@209>CTah0oooo1`1XJ6P906MWIa00IVIV0`1WIfL506QXJ0<0
JFUY0P1ZJVX506][J`80K6a/0P1]KFd306i^KP<0Kfm_1P1`L700101aLG40L71`071`L01aLG48071`
L0D0Kfm_101^KVh406e]K@@0K6a/101[Jf/506YZJP@0JFUY7P3oool00`1?Cdl0D51@051@D002051@
D0@0DE5A101BDU8205=CD`<0E5AD101EEED205IFEP0305MGE`1HF5P0F5QH0080FEUI0`1JFUX205]K
F`0305aLG01MGEd0GEeM00<0GUiN0P1OGel3061PH080HF5Q0`1RHV8406=SH`80I6AT1@1SHf<2069R
HP@0HF5Q00@0H61P05mOG`1OGel0GUiN0P1MGEd205aLG0<0Fe]K0P1JFUX205UIF@0305QHF01GEeL0
EeMG0080EeMG0P1FEUH205EEE@<0E5AD0`1CDe<3059BDP<0DE5A0`1@D50204m?Cb80oooo000P0?oo
o`<0Ti>C1@2BTY84096AT@@0T92@0P2?Shl708j>SPH0SHf=202<S8`00`2;Rh/0S8b<08b<S00908b<
S0D0SHf=0`2>SXh308n?S`D0T92@0`2ATI4309:BTP`0Ti>C202DU9@00`2CTi<0U9BD09BDU00509BD
U00309>CT`2DU9@0U9BD0080U9BD0P2CTi<N0?ooo`0306UYJ@1XJ6P0J6QX00d0J6QX3`1WIfL706QX
J00306UYJ@1XJ6P0JFUY00@0JFUY1`1ZJVX306][J`0306a/K01[Jf/0K6a/00L0K6a/0P1]KFd206a/
K00306e]K@1/K6`0K6a/00/0K6a/2P1[Jf/806YZJPL0JFUY7P3oool204m?C`P0D51@1@1ADE47059B
DPD0De=C101DE5@305EEE@80EUIF1P1GEeL505QHF0L0FEUI0P1JFUX605UIF@H0F5QH0`1GEeL305IF
EPD0EEEE101DE5@405=CD`L0DU9B1`1ADE44051@D0<0Cdm?8P3oool00?l0oooo``3oool00?l0oooo
``3oool00?l0oooo``3oool00?l0oooo``3oool00?l0oooo``3oool005T0oooo0T00002;0?ooo`90
0000R`3oool2@00004d0oooo001K0?ooo`03@000003oool0oooo08X0oooo00=000000?ooo`3oool0
RP3oool00d000000oooo0?ooo`1:0?ooo`00B@3oool00d000000oooo0?ooo`030?ooo`=000000P3o
ool2@00000<0oooo0d0000050?ooo`03@000003oool0oooo06/0oooo0T0000040?ooo`03@000003o
ool0oooo00@0oooo0d0000020?ooo`9000000`3oool3@00000D0oooo00=000000?ooo`3oool0I03o
ool5@00000040?oood0000100000@00000<0oooo00=000000?ooo`3oool01@3oool3@0000080oooo
0T0000030?ooo`=000001@3oool00d000000oooo0?ooo`140?ooo`00B03oool00d000000oooo@000
00030?ooo`06@000003oool0oooo@000003ooom00000103oool014000000oooo0?oood00001c0?oo
o`03@000003ooom000000080oooo00=000000?oood000000103oool01T000000oooo0?oood000000
oooo@00000@0oooo00A000000?ooo`3ooom00000KP3oool01D000000oooo0?ooo`3ooom0000000@0
oooo00=000000?oood0000001@3oool01T000000oooo0?oood000000oooo@00000@0oooo00A00000
0?ooo`3ooom00000C03oool004P0oooo00=000000?oood0000000`3oool01D000000oooo0?oood00
0000oooo00=000000P3oool014000000oooo0?oood00001c0?ooo`03@000003ooom000000080oooo
00=000000?oood000000103oool01D000000oooo0?oood000000oooo00=000000P3oool014000000
oooo0?oood00001^0?ooo`03@000003oool0oooo0080oooo00M000000?ooo`3oool0oooo@000003o
oom0000000D0oooo00E000000?ooo`3ooom000000?ooo`03@0000080oooo00A000000?ooo`3ooom0
0000C03oool004P0oooo00=000000?oood000000103oool3@00000040?oood0000100000@00000<0
oooo0d00001c0?ooo`9000000`3oool00d000000oooo@00000050?ooo`=0000000@0oooo@0000400
001000000`3oool3@00006h0oooo00=000000?ooo`3oool00P3oool01d000000oooo0?ooo`3ooom0
00000?oood0000001P3oool3@00000040?oood0000100000@00000<0oooo0d00001<0?ooo`00B03o
ool00d000000oooo@00000060?ooo`03@000003oool0oooo07/0oooo00=000000?ooo`3oool00P3o
ool00d000000oooo@00000070?ooo`03@000003oool0oooo07H0oooo00M000000?ooo`3oool0oooo
@000003ooom000000080oooo00=000000?oood000000203oool00d000000oooo0?ooo`1D0?ooo`00
B@3oool00d000000oooo0?ooo`040?ooo`900000OP3oool2@00000<0oooo00=000000?ooo`3oool0
1@3oool2@00007L0oooo0T0000040?ooo`03@000003oool0oooo0080oooo00=000000?ooo`3oool0
1P3oool2@00005H0oooo003o0?oool<0oooo003o0?oool<0oooo003o0?oool<0oooo003o0?oool<0
oooo003o0?oool<0oooo003o0?oool<0oooo003o0?oool<0oooo003o0?oool<0oooo003o0?oool<0
oooo003o0?oool<0oooo003o0?oool<0oooo003o0?oool<0oooo003o0?oool<0oooo003o0?oool<0
oooo003o0?oool<0oooo003o0?oool<0oooo003o0?oool<0oooo002W0?ooo`900000J@3oool2@000
0:h0oooo002Y0?ooo`03@000003oool0oooo06P0oooo00=000000?ooo`3oool0Z`3oool009/0oooo
0d0000030?ooo`=000000`3oool3@00000D0oooo00=000000?ooo`3oool01D0000020?ooo`03@000
003oool0oooo00D0oooo00=000000?ooo`3oool0203oool3@0000080oooo0d0000020?ooo`=00000
0`3oool3@00000030?oood000010000000<0oooo0d0000030?ooo`9000000`3oool2@0000100oooo
0d0000001`3ooom000000?oood000000oooo@000003oool0140000020?ooo`=000000P3oool2@000
0080oooo0T00002U0?ooo`00W03oool00d000000oooo0?ooo`030?ooo`05@000003oool0oooo0?oo
od0000000P3oool00d000000oooo0?ooo`080?ooo`07@000003oool0oooo0?oood000000oooo@000
000B0?ooo`03@000003oool0oooo0080oooo00=000000?ooo`3oool00P3oool01D000000oooo0?oo
o`3ooom000000080oooo00E000000?ooo`3oool0oooo@00000030?ooo`03@000003oool0oooo0080
oooo0T0000020?ooo`03@000003oool0oooo0140oooo00U000000?ooo`3ooom000000?oood000000
oooo@000003oool00d0000020?ooo`06@000003oool0oooo@000003ooom000001P3oool00d000000
oooo0?ooo`2R0?ooo`00W03oool00d000000oooo0?ooo`030?ooo`05@000003oool0oooo0?oood00
00000P3oool00d000000oooo0?ooo`080?ooo`07@000003oool0oooo0?oood000000oooo@000000B
0?ooo`03@000003oool0oooo0080oooo00=000000?ooo`3oool00P3oool01D000000oooo0?ooo`3o
oom000000080oooo00A000000?ooo`3ooom00000103oool01D000000oooo0?ooo`3ooom000000080
oooo00=000000?oood0000000T00000A0?ooo`08@000003oool0oooo@000003ooom000000?oood00
00030?ooo`04@000003oool0oooo@0000080oooo00=000000?oood0000000T0000030?ooo`03@000
003oool0oooo0:<0oooo002L0?ooo`9000000`3oool2@00000@0oooo0d00000:0?ooo`07@000003o
ool0oooo0?oood000000oooo@000000B0?ooo`03@000003oool0oooo0080oooo00=000000?ooo`3o
ool00P3oool00d000000oooo0?ooo`02@00000030?oood00001000000080oooo0T0000020?ooo`90
00000P3oool2@0000080oooo00=000000?oood0000000T00000@0?ooo`9000000P3oool2@0000003
0?oood000000oooo0080oooo0T0000030?ooo`=0000000@0oooo@0000400001000000`3oool2@000
0:@0oooo002L0?ooo`04@000003oool0oooo@00001@0oooo00M000000?ooo`3oool0oooo@000003o
oom000000180oooo00=000000?ooo`3oool00P3oool00d000000oooo0?ooo`020?ooo`03@000003o
ool0oooo0>P0oooo002K0?ooo`E000000P3oool00d000000oooo0?ooo`0>0?ooo`900000103oool0
0d000000oooo0?ooo`0@0?ooo`=000000P3oool2@00000<0oooo0T00000>0?ooo`03@000003oool0
oooo01X0oooo00=000000?ooo`3oool0_03oool00?l0oooo``3oool00?l0oooo``3oool00001\
\>"],
  ImageRangeCache->{{{0, 449}, {294.313, 0}} -> {-0.178538, -0.0492293, 
  0.00747679, 0.00747679}, {{23.875, 149.25}, {287.688, 
  162.313}} -> {-39.4226, -10.476, 1.19477, 1.19477}, {{161.75, 287.188}, {
  287.688, 162.313}} -> {-204.189, -10.476, 1.19477, 1.19477}, {{299.688, 
  425.063}, {287.688, 162.313}} -> {-368.956, -10.476, 1.19477, 1.19477}, {{
  23.875, 149.25}, {149.75, 24.375}} -> {-39.4226, -175.28, 1.19477, 
  1.19477}, {{161.75, 287.188}, {149.75, 24.375}} -> {-204.189, -175.28, 
  1.19477, 1.19477}, {{299.688, 425.063}, {149.75, 
  24.375}} -> {-368.956, -175.28, 1.19477, 1.19477}}]
}, Open  ]],

Cell[TextData[{
  StyleBox["\t",
    FontFamily->"Times New Roman",
    FontSize->10.5],
  StyleBox[
  "After setting a mouse cursor on a following image, twice clicking the left \
side button of mouse animates the facial changes depending on the lighting \
angles. This is only effective on the ",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"],
  StyleBox["Mathematica",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox[" notebook.",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell[CellGroupData[{

Cell["Do[Show[GraphicsArray[{illusionG[[i]]}]],{i,rotation}];", "Input",
  CellLabel->"In[57]:="],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0238095 0.952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0238095 0.97619 0.97619 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00751202 0.0192308 0.00751202 [
[.5 1.0125 -17 0 ]
[.5 1.0125 17 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
69.000000 12.812500 moveto
(deg) show
87.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(.) show
93.000000 12.812500 moveto
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
128 string
128 128 8 [128 0 0 128 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
93939393929292929291908F8F8F8F908F8F909090908F8C
90908F909091919192929292929394949594949595959595
959696969696969696969696969595969695959595959596
969696969696969797979798989694979797979797979898
989898989998989999999999989898979797969696969696
9695949797969594
9393939392919190908F8D8B8A8B8B8B8B8B8C8C8C8D8B87
8B8C8C8C8C8D8E8F90919192929394959596969696969797
969798989898989898989898989897989897979797979898
989898999999999A9A9A9B9C9C9A96999B9B9B9B9B9B9C9C
9C9C9D9D9D9D9D9E9E9E9E9E9D9D9C9B9B9B9A9999999998
989797999A989795
939393929191908F8E8D8B89878787878787888888888884
85898888898A8B8C8E8F9091929394959797979797979898
9898999A9A9A9A9A9A9A9A9A9A9A9A9A9999999999999A9A
9A9B9B9B9C9C9C9D9D9E9E9F9F9F9B999C9F9F9F9F9F9FA0
A1A1A1A2A2A2A2A2A3A3A3A2A2A1A0A09F9F9E9D9C9C9B9B
9B98989A9B9A9895
9392929190908F8E8D8B8A88868483838383848484848483
7F8284848586888A8C8D8F90919394959798989899999999
9999999A9B9B9B9B9B9B9C9C9C9C9C9C9C9C9C9C9C9C9C9C
9D9D9E9E9E9F9FA0A0A1A1A2A2A2A2A09D9FA3A2A3A3A3A4
A4A5A5A6A7A7A7A7A8A8A7A7A7A6A5A4A4A3A3A1A09E9E9E
9D9C9A9B9C9B9996
93929191908F8E8D8C8A8987858382807F7F7F8080808080
7E7D7F8081828587898B8E909193949698999A9A9A9B9A9A
9A9A9A9A9B9C9C9C9D9D9D9D9D9D9E9E9E9E9E9F9E9E9F9F
A0A0A0A1A1A2A2A3A3A4A4A5A5A6A6A6A4A2A5A7A7A7A7A8
A9AAAAABABACACACACADADACACABAAA9A9A8A8A6A4A2A2A1
9F9F9D9D9E9B9896
939291908F8E8D8C8B8A88868583817F7D7C7C7C7C7C7D7D
7C797A7C7E7F818487898C8E91939597999A9B9C9C9D9C9C
9C9B9B9B9B9C9D9D9D9E9E9F9F9F9FA0A0A0A0A1A1A1A2A2
A3A3A3A4A4A5A5A6A7A7A8A9A9A9A9AAAAA8A7AAABABACAD
ADAEAFB0B0B1B1B1B1B2B2B1B1B0AFAFAFAEADABA9A7A7A5
A3A29F9F9E9C9996
9392908F8E8D8C8B8A8987868482807E7C7A797879797979
797877787A7C7E8184878B8E909395989A9B9C9D9E9F9E9E
9E9D9C9C9B9C9C9D9E9F9FA0A0A1A1A1A2A2A3A3A3A4A4A5
A6A6A7A7A8A8A9AAAAABABACACADADAEAEAFADACAEB0B0B1
B2B3B4B5B5B6B6B6B7B6B7B7B6B5B5B4B4B3B2B0AEAAAAA8
A6A4A2A29F9C9996
9392918F8E8D8B8A898886858382807E7C7A787776767676
76767574767A7C7E8285898C909295989A9C9D9E9FA0A1A0
A09F9E9E9D9D9D9E9E9F9FA0A0A1A2A2A3A3A4A5A5A6A7A7
A8A9AAAAABACACADADAEAFB0B0B0B1B1B2B3B4B3B2B3B4B6
B7B8B9BABBBBBBBCBCBCBCBCBBBBBAB9B7B7B6B3B2AFADAB
A8A6A4A4A19D9A97
9291908F8E8C8B8A8887858482817F7E7C7A787775757474
737373727174787C7F83888C8F9295989B9D9E9FA0A2A3A3
A2A1A0A09F9E9D9E9F9F9FA0A1A1A1A2A3A4A5A6A6A7A8A9
AAABACADADAEAFB0B0B1B2B2B3B3B4B5B5B6B8B8B8B7B8BA
BCBDBEBFC0C0C0C1C1C1C1C1C0C0BEBCBABAB9B6B3B1AFAD
AAA7A6A4A29E9A97
9291908F8D8C8A898886858382807F7D7C7A787775747373
73727171717073797E81868B8F93969A9D9FA1A2A2A3A4A4
A4A3A2A1A1A09F9F9FA0A0A1A1A2A2A2A3A3A4A5A5A6A8A8
AAABACADAEAFB0B1B1B2B3B4B5B6B6B7B8B9B9BABBBBBBBB
BCBFC3C3C4C4C5C6C6C7C8C7C5C4C1BFBDBCBAB8B5B3B1B0
ABA9A8A5A29E9B97
9291908E8D8C8A8887858482817F7E7C7B79777675747372
72717070706F70747B80858B9094979B9DA1A3A4A4A5A6A6
A6A5A4A3A2A1A1A0A0A1A1A2A2A2A3A3A3A4A5A6A6A7A8A9
AAACADAEAFB1B2B3B4B5B6B7B7B9B9BABBBCBDBDBEBFBFC0
C0BFC3C4C6C8C9CACAC9C8C8C7C6C5C2C0BFBBBAB8B5B3B1
ADAAA8A6A29F9B97
9291908E8C8B898886858382807F7D7B7A79777674737271
70706F6F6E6E6D70767D838A91969A9DA0A3A5A6A7A7A7A8
A7A6A6A5A4A3A2A2A1A2A2A3A3A3A4A4A5A5A6A7A8A9AAAB
ACADAFB0B2B3B4B5B7B8B9BABBBCBDBEBEBFC0C1C2C2C3C4
C5C5C7C7C7C8C9CBCBCAC9C9C9C8C8C5C3C2BDBCBAB6B5B2
AEACA8A5A29F9B97
92918F8E8C8B898786848381807E7D7B7978767574737170
6F6E6E6D6D6C6B6E7178808691999DA0A3A5A7A8A9A9A9A9
A9A8A7A6A5A4A4A3A3A3A3A4A4A5A5A5A6A6A7A8A9AAACAD
AEAFB1B2B4B5B7B8BABBBCBDBEBFC0C1C1C3C4C5C5C6C7C8
C9CACBCCCDCDCBCBCBCBCACACAC9C8C6C5C3BEBDBBB7B6B3
B0ADA9A6A29F9B97
92918F8D8C8B8987858482817F7D7C7A797776747372716F
6E6D6D6C6B6A696B6D727B828C97A0A3A6A8AAABABABABAB
AAA9A8A7A6A5A5A4A4A4A4A4A5A6A6A7A7A8A8A9AAABADAE
B0B1B2B4B6B7B9BBBCBEBFC0C1C2C3C4C4C6C7C8C9CACBCB
CCCDCECECECECDCCCBCACBCBCACAC9C7C6C3C0BEBCB9B6B4
B1AEAAA6A29F9B97
92918F8D8C8A8887858381807E7D7B7A787775747271706E
6D6C6B6A6969686A6A6E767E87919FA8AAACADAEAEADADAD
ACAAA9A8A7A7A6A5A5A5A4A5A5A6A7A7A8A9A9AAABACAEB0
B1B3B4B6B8B9BBBDBFC1C2C3C4C5C6C7C8C9CACBCCCDCECF
CFD0D0D0D0CFCECECDCBCBCBCBCACAC8C7C4C1BEBBB9B6B4
B1AEAAA6A39F9B97
92908F8D8B8A88868483817F7E7C7A797775747271706F6D
6C6B6A6968676668686A707A828C98A6AEAFB1B1B1B0AFAE
ADABAAA9A8A7A6A6A5A5A5A6A6A7A7A8A9AAAAABACADAFB1
B2B4B6B8BABBBDBFC2C3C5C6C7C8C9CACBCCCDCED0D1D2D2
D2D3D3D3D2D0CFD0CFCDCBCBCBCBCBC9C7C4C2BFBCB9B6B4
B2AEABA7A39F9B97
92908E8C8B8987868482817F7D7B7A7876757371706F6D6C
6B6A69676665656566686D767E87929FACB4B4B4B4B2B0AF
AEACABAAA8A7A6A6A6A5A5A6A6A6A7A8AAAAABACADAEB0B1
B3B5B7BABCBDBFC1C4C6C7C9CACBCCCECECECFD0D1D2D4D4
D4D4D4D4D4D2D0D0CFCFCECDCBCACAC9C7C5C3C0BEBAB7B4
B1AEAAA7A29F9B97
92908E8C8A8887858381807E7C7B7978767472716F6E6C6B
696867666564646365656B727A838D98A4B2BAB8B6B4B2B0
AEACABA9A8A8A6A6A6A5A6A6A6A7A7A8AAABACADAEAFB0B2
B4B6B8BBBDBFC1C3C5C7C9CBCCCECFD0D1D1D1D2D3D4D5D6
D5D5D5D5D4D4D2D2D1D0CFCECDCBCAC9C7C5C3C0BEBBB7B4
B1ADAAA6A29E9B97
92908E8C8A88868583817F7E7C7A7876757371706E6D6B6A
68676564636261616262696F767F89939EAAB7BCB8B5B2B0
AEACABA9A8A7A6A6A5A5A5A6A6A7A7A8A9AAABADAEB0B1B3
B5B7B9BBBEC0C3C5C7C9CBCDCED0D1D2D3D4D3D4D4D5D6D7
D6D6D7D6D6D5D4D4D2D0CFCECDCCCBC9C7C5C3C1BEBBB8B4
B1ADAAA6A29F9B98
918F8E8C8A88868482807E7D7B7977767472706E6D6B6A69
6765646261605F5F6061676D747C848E98A4AFBAB8B6B3B0
AEACAAA8A8A7A6A6A5A5A5A6A6A7A7A8A9AAABADAEB0B1B3
B5B7B9BCBFC2C4C6C8CACCCFD0D2D3D4D5D6D5D5D4D6D5D7
D7D8D8D7D7D7D6D5D4D2D1D0CFCDCCCAC8C6C3C1BEBBB8B4
B1ADAAA6A29F9B97
918F8D8C8A88868482807E7C7A78767573716F6E6C6A6967
65646261605E5E5D5E60656A7179818A939EAAB6BAB6B2AF
ADABAAA8A7A6A5A5A5A4A4A5A6A6A7A8A9AAABACAEB0B2B3
B5B7BABCBFC2C5C8C9CBCDD0D2D3D5D6D6D7D6D6D5D5D6D6
D7D8D8D7D7D8D8D7D6D5D3D2D1CFCDCBC9C6C4C1BEBBB8B4
B1ADAAA6A29F9B97
918F8D8B89878583817F7D7B7977757472706E6D6B696766
6462615F5E5D5C5B5C5F646970777E87909AA5AFB8B5B1AF
ACAAA8A7A6A5A4A4A4A4A4A4A5A6A7A7A8A9ABACAEB0B1B4
B5B7BABCBFC2C6C9CACCCFD1D3D4D6D7D8D8D6D6D7D7D7D8
DADAD9D9D8D9D9D7D7D6D5D3D2D0CECCC9C7C4C2BEBBB8B5
B1ADAAA6A29F9B97
918F8D8B89878583817F7D7B79777473716F6D6B6A686664
63615F5D5C5B5A595B5D62686F767C858E97A1ABB6B3B0AD
AAA8A7A5A4A3A3A2A2A3A3A3A4A5A6A7A8A9AAACADAFB1B3
B5B7B9BCBFC3C6C9CBCDD0D2D4D5D6D7D8D8D6D6D6D8D8D9
DBDBDBDAD9D9D9D8D8D7D7D6D4D2D0CDCAC8C4C2BFBCB8B5
B1ADAAA6A29F9B97
918F8D8A89878583807E7C7A78767472706E6C6A68676563
61605E5C5A595857595C60666C737B838C949EA7B3B0AEAB
A8A7A5A3A2A1A1A1A1A1A2A2A3A4A5A6A7A8AAABACAEB0B2
B4B7B9BBBFC2C6C9CBCED0D2D4D5D7D7D9D9D7D6D6D7D8D9
DBDCDCDCDBDADAD9D9D8D8D7D6D3D1CECBC8C6C2BFBCB9B5
B1ADAAA6A29F9B97
918F8D8A88868482807E7C7A787573716F6D6B6967666462
605E5D5B59575655585B5F656B71798189929CA6B0ADABA8
A6A4A2A1A09F9F9F9F9FA0A0A1A2A3A5A6A7A8AAABADAFB1
B3B5B8BABEC2C5C8CBCED0D3D4D6D7D8DADAD9D7D6D7D9DA
DCDDDEDEDDDBDAD9DAD9D8D8D8D5D2CFCCC9C6C3BFBCB9B5
B1ADAAA6A29F9B97
918F8C8A88868482807D7B79777572706E6C6A6866656261
5F5D5B5957555455575A5E646A707880878F99A3AEAAA8A5
A3A1A09E9D9D9C9C9C9C9D9E9FA0A1A3A4A5A6A8AAACAEB0
B2B4B6B9BDC0C3C6CACDD0D2D4D6D8DADBDBDAD8D7D7D8DA
DCDDDEDFDFDEDCDBDBDAD9D9D9D6D4D0CDCAC7C3C0BCB9B5
B1AEAAA6A29F9B97
918F8C8A888684817F7D7B79767472706E6B69676563615F
5E5B5A5856545254575A5E64696F777D848D97A0AAA7A5A2
A09E9D9B9A9A999899999A9B9C9D9FA0A2A3A5A6A8AAACAE
B0B3B5B8BCBEC1C5C9CCCFD1D4D6D8DADCDDDCDAD9D8D8D9
DBDEE0E0E0DFDEDCDCDCDCDBDAD7D5D2CECAC7C4C0BDB9B5
B1AEAAA6A29E9B97
918F8C8A888583817F7C7A787673716F6D6B69676562605E
5C5A58565452515355595D63686E757B828C959DA7A3A29F
9D9B99989796969595969697989A9C9EA0A1A3A4A6A8AAAC
AFB1B3B6BABDC0C4C7CACDD0D4D6D8DADBDDDDDCDAD8D7D8
DBDDE0E1E1E1DFDEDEDEDEDDDBD8D6D2CFCCC8C4C0BDB9B5
B2AEAAA6A29F9B97
918F8C8A878583817E7C79777573706E6C6A676563615F5D
5B5957555351515255585D63676D737A8089929AA3A09D9B
9997959493929191919192939496979A9C9EA0A1A3A5A7AA
ACAFB1B4B6BABEC2C5C9CCD0D4D8D9DADBDDDEDEDDDBD9D7
D9DDDFE1E2E2E1E0DFDFDFDFDCD9D6D3CFCCC8C5C1BDBAB6
B2AEAAA6A29F9B97
918E8C89878582807E7B79767472706D6B69666562605E5C
5A5755535150505255585C62676D71787E868E969F9B9997
9492918F8E8D8D8D8C8C8D8F90929395989A9C9EA0A2A4A7
A9ACAFB2B3B7BCC0C3C8CCCFD3D7D9DADCDDDFE0DFDCDBD9
DADCDEE1E2E3E2E1E0E1E0DFDDDAD7D4D0CCC9C5C1BDBAB6
B2AEAAA6A29F9B97
918E8C89878482807D7B787673716E6C6A686664615F5C5A
58565452504F505155585C61666B70767C838A929A969491
8F8D8C8B8A898888878788898A8C8E909395989A9C9FA1A3
A6A9ACB0B1B5BABDC1C6CACED1D6D9D9DBDDDFE1E0DEDCDB
DBDDDFE2E3E3E2E2E1E1E1E0DEDAD7D4D0CDC9C5C1BDBAB6
B2AEAAA6A39F9B97
918E8C898784817F7C7A787573706E6B69676462605E5B59
575553504E4E4F5155585C61646A6E757A80878D93918E8C
8A89878686858484838282828486888B8D909395989A9D9F
A2A6AAADAEB2B7BABEC3C8CDD0D5D8D9DBDDDFE2E2E0DDDB
DBDDDFE2E5E4E3E3E3E3E2E1DEDBD7D4D1CDC9C5C2BEBAB6
B2AFABA7A39F9B97
918E8C898684817F7C797774726F6D6A686663615F5D5A58
5654514F4E4E4F5155585D6164696D74787D83898C8B8A88
8786858483828181807F7F7E7E7F818487898C8F9296989B
9EA2A6ABACAFB3B5BAC0C6CCCED4D7D9DADCDFE2E3E2DFDD
DCDDDFE2E5E6E5E5E5E4E4E3DFDCD9D5D1CDCAC6C2BEBAB6
B3AFABA7A39F9B97
918E8B898683817E7C797674716F6C6A676562605E5B5957
5452504D4D4E4F5255585C6065686D73777B7F8386868686
8584838281807F7F7E7D7C7C7B7B7B7D7F83868A8D909497
9A9EA3A9ACADB1B1B7BDC5CBCDD1D6D8D9DCDEE1E3E3E1DF
DDDDE0E3E6E7E7E6E6E5E5E3E0DDD9D5D2CDCAC6C2BEBAB6
B3AFABA7A39F9B97
918E8B888583807D7B787673706E6B696664615F5D5A5755
53514F4D4C4E4F52565A5D6165686E7276797B7F82838383
8382818180807F7E7D7C7A7A79797878797B7F83878A8E92
969A9FA5ABABB0AEB2B9C0C9CDCED4D7D8DCDEE1E4E4E4E1
DEDDE0E4E6E7E8E8E7E7E7E4E0DDD9D6D2CECAC6C2BEBAB6
B2AFABA7A39F9B97
918E8B888583807D7A7775726F6D6A686563605E5B595754
52504E4D4C4E5052565A5E6164696E72767A7B7D7F808181
818180807F7F7E7E7D7B7A79787776757576787B8084888C
91969BA2AAA9ADADAFB6BDC5CACCD1D5D8DBDFE1E4E5E5E4
E0DEE0E4E7E9EAE9E8E8E8E5E1DDDAD6D2CECAC6C2BEBAB7
B3AFABA7A39F9B98
918E8B8885827F7C7A7774716E6C696764625F5D5A585653
514F4D4C4C4E5053575B5F62656A6E717577797A7C7E7F7F
808080807F7F7F7E7D7B7A797776757473727374787D8186
8C91989FA9ABABAEADB2B9C2C8CDD0D4D7DADEE1E4E6E6E6
E2DFE0E4E7E9EBECEAE9E8E5E2DEDAD7D2CECAC6C2BEBBB7
B3AFABA7A39F9B97
908E8A8885827E7C797673706D6B686663605E5C59565452
504E4D4B4D4F5254575C5F63666B6E71737577787A7B7D7E
7F7F7F807F7F7F7F7E7C7B79777574727170707071757A80
868C939CA6ACABAFB0B2B7BEC4CBCFD2D7DADEE2E4E7E6E7
E5E1E0E4E8EAEBEDECEAE8E5E2DEDAD7D3CFCBC7C2BEBBB7
B3AFABA7A39F9B97
908D8A8784817E7B787573706D6A6764625F5D5B58565350
4F4D4C4C4D505356595D6064686C6F707173747677797A7C
7D7E7E7F7F7E7F7F7E7D7C7977757371706E6E6E6E6F7278
7F878E98A3ABAEAEB2B3B7BCC2C9CED0D5D9DDE1E4E6E8E8
E7E4E2E4E7E9ECEEEDECE9E5E2DFDBD7D3CFCBC7C3BFBAB7
B3AFABA7A39F9B97
908D8A8784817E7B7774716F6C696663615E5C595754524F
4E4D4B4C4E5153575B5E6165696C6E6F7071727375767879
7A7B7B7C7C7C7D7D7D7D7C7A787572706E6C6C6B6C6D6E72
79818A94A0A9AFB0B4B8B9BCBFC6CCD0D3D7DCE0E5E7E9E9
E9E8E4E5E8EAECEEEEEEE9E6E2DFDBD7D3CFCBC7C3BFBAB7
B3AFABA7A39F9B97
908D8A8784807D7A7774716E6B6865625F5D5A585653514F
4D4C4C4D4F5356585D6063676B706E6E6E6F6F7071737677
777777787878797B7B7C7C7A7775726F6C6B6A69696A6B6D
717A848F9CA7B0B2B3B9BCBEC1C4C9CFD3D6DBE0E5E8EAEB
EBEAE7E7E9EBEEEFEFEEEBE7E3DFDBD7D3CFCBC7C3BFBAB7
B3AFABA7A39F9B97
908D8A8683807D7A7673706D6A6764615E5B595654524F4D
4D4C4D4E5154585A5E6165696C6D6D6C6C6C6C6C6E6F7071
7071727373737475767778797774716E6B6968676767686A
6C727D8997A4AEB6B6B9C0C1C5C7C9CDD1D5DADFE4E8EAEC
EDEDEAE9EBEDEFF1F1EDEAE7E3E0DBD7D3CFCBC7C3BFBBB7
B3AFABA7A39F9B97
908D8986837F7C7976726F6C696663605D5A585552504E4D
4D4D4E4F52575A5D6065686B6E6C6B6B6A696867696A6C6E
6F6E6F6F707071727372737576726F6C6967666565656668
6A6E758391A0AAB5B9BBC1C4C7CBCBCCD1D5D9DEE4E8EBED
EFEFEDEAEBEEF0F2F2EEEBE7E3E0DCD7D3CFCBC7C3BFBBB7
B3AFABA7A39F9B97
908D8986827F7C7875726E6B6865625E5B595654514F4C4B
4B4C4E5154585B5F63666A6D6D6C6B696866656364666768
68696968696A6B6C6E6F6E6F71716E6A6866656363646566
686C717C8B9BA8B4BABDC1C8CACFD1CFD0D4D9DEE3E8EBEE
F1F1EFECECEEF0F2F3EFEBE8E4E0DCD7D3CFCBC7C3BFBBB7
B3AFABA7A39F9B97
908D8986827E7B7774716D6A6663605D5A575552504D4B4A
4A4D4F52565A5E6165696D6E6D6C6A686662605C5C5D5E5F
5F60605F5F60616364656465676869676564636261626365
666A6E768596A5B0B9BFC1C8CDD1D6D5D3D4D9DDE2E7EBEE
F2F3F2F0EEF1F1F3F2EFECE8E4E0DCD7D3CFCBC7C3BFBBB7
B3AFABA7A39F9B97
908C8985817E7A7773706C6965625F5B585653504E4B4A49
4A4D5053585C6065696D726F6E6C6A6765625F5B58575758
5858595959595B5C5E616262646465646362616160616264
66686C737F8FA0ACB7BFC3C7CFD3D9DAD9D6D9DDE1E7EBEF
F3F4F5F2F0F2F3F6F3EFECE8E4E0DBD7D3CFCBC7C2BFBBB7
B3AFABA7A39F9B97
908C8885817D7A76726F6B6864615D5A5754514E4C4A4949
4A4D5155595E63686C7172706E6C6A676562605D5B595858
5958595A5B5B5C5D5F6061626262626261605F5F5F606162
65686B717B8A9CA8B3BBC2C6CFD5D9DDDDDBDBDDE1E6EBF0
F4F6F7F4F2F3F4F7F3EFECE8E4E0DBD7D3CFCBC7C3BFBAB6
B2AFABA7A39F9B97
908C8884817D7975726E6A66635F5C5855524F4C49474748
4A4D51565B60656A707674716F6C6A676562605E5C5B5A59
59595A5B5B5C5D5E5F6061616161605F5F5E5E5D5E5E5F61
6366696E778597A6B1BAC2C7CDD5DBE0E1E0DFDFE2E6EAEF
F2F6F8F7F4F4F5F7F4EFECE9E4E0DBD7D3CFCAC6C2BEBAB6
B2AFABA7A39F9B97
8F8C8884807C7874716D6965615E5A5753504D4A48464547
4A4E52575C62686D72797572706D6A686563615F5D5C5B5A
5A5A5B5C5C5D5E5F6061616160605F5D5C5C5C5C5C5D5E60
6265696D758291A2ADB7BFC6CCD4DBE2E4E4E2E1E3E7EAF0
F2F6F8F8F5F5F6F6F4F0ECE8E4DFDBD7D2CECAC6C2BEBAB6
B2AFAAA7A39F9B97
8F8B87837F7B7774706C6864605C5955524E4A4745444547
4B4E53585E636A6F75797673706D6B68666361605E5C5B5B
5A5A5B5C5D5E5F6061616161605F5E5D5C5B5A5A5B5B5C5E
6063676C727D8D9DABB5BEC5CCD2DAE2E6E6E6E5E4E7EAF0
F4F7F9F9F7F5F7F5F4F0ECE8E4DFDBD6D2CECAC6C2BEBAB6
B2AEAAA7A39F9B97
8F8B87837F7B77736F6B67635F5B57534F4C484542424447
4B50545A60666B7179787673706E6B68666462605E5C5B5A
5958585A5C5D5F6061626161605F5D5C5A5A5959595A5B5D
5F61656A707A899AA8B3BDC3CBD0D8DFE8E9E9E7E5E8EAEF
F4F8FAFBF8F6F7F5F4F1EDE8E3DFDAD6D2CECAC6C2BEBAB6
B2AEAAA6A39F9B97
8F8B87837E7A76726E6A66625E5A56524E4A464240404347
4B50565B61676D747C787673716E6B69666462605E5C5C5B
585656575B5D5E5F616261615F5E5D5B5A59595858595A5B
5D6063686E768395A4B0BAC2CACFD6DEE6EAEAEAE8E8EBEF
F5F8FBFCFAF8F6F7F3F0ECE7E3DEDAD6D1CEC9C5C1BDB9B6
B2AEAAA6A39F9B97
8F8B87827E7A75716D6965615C5854504C4844403D3F4246
4B50565C62686F767C787673706D6B69666462605E5A5859
5755545355585A5B5E6161615F5E5C5B5A5958575758595A
5C5F62666B737E909FADB7BFC7CFD4DDE4ECEBEBEAE8EBEE
F4F8FBFDFCFAF7F7F3EFEBE7E2DEDAD5D1CDC9C5C1BDB9B5
B2AEAAA6A39F9B97
8F8B86827D7975706C67635F5B57524E4A46423D3B3E4247
4C51565D636970777B787573706E6B69666462605F5C5A58
5755545455585A5B5C5E60605F5D5C5B5959585757575858
5A5D60646A70798B9AA9B3BDC4CDD2DAE0EBEBEBEAE8EBEE
F3F8FBFDFDFAF7F5F3EFEAE6E2DDD9D5D1CDC9C5C1BDB9B5
B1AEAAA6A29F9B97
8F8A86817D78746F6B66625E5955514C48443F3B393D4246
4C52575D636A727979777472706E6B69676562615F5D5B59
575655545658595B5C5E5F5F5E5D5C5B5A59585757575758
595B5E62676E768596A5B0BBC1CAD0D8DFE8EBECEBE8EAEE
F2F8FCFEFDFAF8F5F2EEE9E5E1DDD9D4D0CCC8C4C0BDB9B5
B1ADAAA6A29F9B97
8F8A86817C78736E6A65615D58534F4B46423D39393D4248
4D52585E646B737C78767472706E6C6A67656361605E5C5B
585655555658595B5C5D5E5E5E5D5C5B5A59585757575758
585A5D60656B737F91A1ACB7BFC7CED6DEE6EAEBEBE9E9EE
F2F8FBFEFDFAF9F6F1EDE9E5E0DCD8D4D0CCC8C4C0BCB9B5
B1ADA9A6A29E9B97
8F8A86817C77726D69645F5B56524D4944403B36383D4148
4C52585E656C727A777573716F6E6C6A68666462605F5D5B
595756565658595A5C5D5E5E5E5E5D5B5B5A595857575758
595A5B5F646A717C8D9CAAB4BDC5CCD3DBE4E8EAEBEAE8ED
F2F8FCFFFDF9F8F4F0ECE8E3DFDBD7D3CFCBC7C4C0BCB8B4
B1ADA9A6A29E9B97
8F8A85807B76726D68635E5A55504C47423E3934373C4248
4D53585D656B7175757472706F6E6C6A69676563615F5E5C
595756565658595B5C5E5E5E5E5E5D5C5B5B5A5958585858
595A5C5E626970788999A6B2BBC3CCD2DAE2E7E9EAEAE8ED
F1F8FCFFFDFAF8F4EFEBE7E3DFDAD6D2CFCBC7C3BFBBB8B4
B0ADA9A5A29E9B97
8F8A85807B76716C67625D58544F4A45403C3734373C4348
4D53595F656C6F72727271706F6D6D6C6A68666462605E5D
5A58565556585A5B5D5E5F5F5E5E5E5D5D5C5B5A5A595959
595A5C5E61676F778494A2AEB9C1CAD1D9E1E6E8EAEBE8EC
F1F8FCFFFEFAF7F3EEEAE6E2DEDAD6D2CECAC6C3BFBBB7B4
B0ADA9A5A29E9A97
8F8A84807A75706B66615C57524D48433E393435383D4449
4E54585F66707071717170706F6E6D6C6B69686664625F5E
5B58565657595A5B5D5F5F60605F5F5F5E5E5D5C5C5B5A5A
5A5B5D5F61676E778392A0ADB7C0C9D0D8E0E5E7E9EBE9EC
F0F8FCFFFEFBF6F2EEE9E5E1DDD9D5D1CDC9C5C2BEBBB7B3
B0ACA9A5A29E9A97
8E89847F7A756F6A65605B55504C46413C373033373D4449
4F555A61686E6F707070706F6F6E6E6D6C6B6A676563615F
5C5A575657595B5C5E5F6061616161606060605F5E5E5D5C
5C5D5E6062676D7682909EABB6C0C8D0D9E0E4E6E9EAEAEB
F0F7FCFFFFFAF6F1EDE8E4E0DCD8D4D0CCC9C5C1BEBAB6B3
AFACA8A5A19E9A97
8E89847E79746F69645F59544F4A453F3A353033373D444B
50565D62696C6E6F6F6F706F6F6F6E6E6E6D6C6A67656260
5D5A575556585B5C5E60616162626262626262626161605F
5E5E5F6163666D75808E9CAAB6C0C8D0D9E2E3E6E8EAECEB
F2F7FBFEFEFAF5F0ECE7E3DFDBD7D3CFCCC8C4C1BDBAB6B3
AFABA8A5A19E9A97
8E89837E78736E68635E58534E48433E39343135383E444B
51585F666A6C6D6E6E6F6F6F6F6F6F6F6F6F6E6C6A676461
5E5B585555575A5C5E606162626363646565656564646261
6160616264676D757F8C9BA8B5BFC7CFD8E1E3E6E8EAEEEB
F3F7FAFDFDF8F3EFEBE6E2DEDAD6D2CFCBC7C3C0BCB9B5B2
AFABA8A4A19E9A97
8E88837D78726D67625C57524C47413C373132343940454C
525A616A6B6C6E6E6E6E6E6F6F6F70707171706E6C696562
5F5B58555556585B5D5F6162626364666768686868676664
6363636465696D757F8A99A7B4BFC7CFD7E0E2E5E8E9EFEB
F2F8FAFBFBF6F2EDE9E5E1DDD9D5D1CECAC6C3BFBCB8B5B2
AEABA7A4A19D9A97
8E88827D77716C66615B56504B45403A352E34353A41474D
545D63696B6D6E6D6D6D6D6E6F707171727373716E6B6763
605B5854535457595C5E606162636467696A6B6C6C6B6968
66656565676A6F757E8896A6B3BEC7CFD7E0E2E4E8E8EFEB
F1F8FAFBF9F5F0ECE8E4E0DCD8D4D0CDC9C6C2BFBBB8B4B1
AEABA7A4A19D9A97
8E88827C76716B65605A544F49433E38332C33363D43494F
575F67686C6E6D6C6C6C6C6D6E70717273747473706C6764
605B575351525457595C5F60616263666A6B6C6D6E6E6C6A
69686767686B70767E8894A2B1BEC7CFD6DEE2E3E6E8EEEB
F1F8F9FAF8F3EEEAE6E2DEDAD7D3CFCCC8C5C1BEBAB7B4B1
ADAAA7A4A09D9A97
8E88827C76706A645F59534D48423C37322F32363E444B50
5A6166676B6D6D6B6B6A6B6C6E6D6C6F73747573726E6864
5F5A56524F4E505357595E605F5E5F63686A6C6D6F706E6C
6A6969696A6C71777F8894A0B0BDC6CFD6DDE0E2E6E8EEEB
F0F6F7F8F6F1EDE9E5E1DDD9D5D2CECBC7C4C0BDBAB7B3B0
ADAAA6A3A09D9A97
8D87817B756F69635D57524C46403B352E2E31363D464D52
5D6766686A6D6B6A696868696B6A686A6D7172716F6D6863
5E5954504D4B4C4E5252555B5A595B5E636669696D6F6F6C
6B6A696A6B6D71787F8994A0AFBCC5CED6DCDFE2E5E7EDEB
F2F5F6F7F3EFEBE7E3DFDBD8D4D1CDCAC6C3C0BCB9B6B3B0
ACA9A6A3A09D9A97
8D87817B756E68625C56504A443F39342D2C31373E474E54
5C6767696B6C6B68656463666A696466666D6D6F6C6A6661
5C57524E4B4847494B4F50555853575860616564696C6C6C
6B6A696A6C6E72787F88929EADBBC5CDD5DBDFE1E4E7ECEA
F2F5F5F5F1EDE9E5E1DDDAD6D3CFCCC9C5C2BFBBB8B5B2AF
ACA9A6A3A09D9A96
8D87817A746E68615B554F49433D3733322D30363E474F57
5F6767696B6C6966625F5D5E62636365626565676664625E
5A55504C4946434345484C4E514E5352585B5F5F62656768
696969696B6E72787F87909CAAB7C3CCD5D9DDE1E5E7EAE9
F0F3F4F2EEEAE7E3DFDCD8D5D1CECBC7C4C1BEBBB8B4B1AE
ABA8A5A29F9C9996
8D87807A736D67605A544D47413B342E302F313840475059
6267686A6C6C68645F5A56565858585A5C5E5F60605F5D5B
57534F4A47434140404244484A4747494D5255585A5D6062
646667686A6D71787F87909BA9B5C0CBD3D8DBDFE4E6E9E8
EEF1F2EFECE8E4E1DDDAD7D3D0CDC9C6C3C0BDBAB7B4B1AE
ABA8A5A29F9C9996
8D868079736C665F59524C453F39322A2A2F32394149505A
6267696B6D6C68645F5A55525050505254575A5D5D5C5A57
54514D4945423F3E3E3F41424444444446484C5054575A5D
61636567696C70777E87919CA8B4BEC9D3D7DADEE4E6E8E7
EDF0EFECE9E6E2DFDBD8D5D2CECBC8C5C2BFBCB9B6B3B0AD
AAA7A5A29F9C9996
8D867F79726C655E57514A443D37302A262D323941484F5A
62676A6B6D6D6965615C58555351515456585A5B59595755
524F4C4845413D3B3B3C3F424444434345474B4E5255585B
5E616365686C70767E86909BA8B4BEC8D1D7D9DEE4E6E8E7
ECF0EDEAE7E3E0DDDAD6D3D0CDCAC7C4C1BEBBB8B5B2AFAD
AAA7A4A19F9C9996
8D867F78726B645D564F48423B352F2A222B30373F474E58
60666A6C6E6D6966635F5B58565454535454545656565553
514E4B4845413D3A3736393D4145464648494C4E52545759
5C5F6163666A6F757D868F9BA6B2BDC7CED4D8DDE3E5E8E8
ECEEEBE7E4E1DEDBD8D4D1CECBC8C5C3C0BDBAB7B4B2AFAC
A9A6A4A19E9C9996
8D867F78716A635C554E474039322C2A21282E343C454C56
5E656A6C6E6D696564615E5B585553514F51535454545351
504D4B4845423E3B38353335383D4246484B4D4F52545658
595C5E6164696E747B838F99A5B1BEC8CED3D7DBE1E4E6E9
ECECE8E5E2DFDCD9D6D3D0CDCAC7C4C1BEBCB9B6B4B1AEAB
A9A6A3A19E9B9996
8C857E777069625B544D453E372F272724272C3238424A53
5B61676B6E6D6963605D5B58555352525252535454535251
4F4D4B484543403D3A38363636383A3D3F44484B4D505154
575A5C5F63676D727B838E99A5B1BDC8CCD1D6D9DFE2E4E8
EBE9E5E2DFDCD9D6D3D1CECBC8C5C3C0BDBAB8B5B3B0ADAB
A8A5A3A09E9B9996
8C857E777069615A534B443C342C232022262C2F363E4750
575F65696D6D6965615D5957555555545454545454535251
4F4D4B494744423F3D3B3A39393A3C3E3E404245484C4F51
55585B5E62676C7178828D99A4B0BCC7CACFD5D7DEE1E1E7
E9E6E3E0DDDAD7D4D1CFCCC9C7C4C1BFBCB9B7B4B2AFADAA
A8A5A2A09D9B9896
8C857E776F686159524A423A3229201C20242B2E343C444D
555C63686D6D6A6663605C5A585757565655555554535251
4F4E4C4A48464442403E3D3C3D3D3E3F40424346484B4E50
5456595C60666B7178808B96A2AFBBC7C8CDD4D5DBE0E0E5
E6E2E0DDDAD7D5D2CFCDCAC7C5C2C0BDBBB8B6B3B1AEACA9
A7A4A2A09D9B9896
8C857E766F6860585149413830261C171D22292D3339414A
525A61666B6D6A6764625F5C5B5A58575756565555545352
504E4D4B494846444341403F3F3F404142434546484A4D50
5255585C60656B7178818B96A2B0BCC8C9CCD2D3D8DEDFE4
E2DFDCDAD7D5D2D0CDCBC8C6C3C1BEBCB9B7B5B2B0ADABA9
A6A4A29F9D9B9896
8C857D766F676058504840372E251B131A20272C31383F47
4F575F64686B6A686563605E5C5B5A595857575656555452
51504E4D4B494846454443424242424344454647494B4D4F
5255585B5F656A7178818B96A2AFBCC7CACBD0D1D5DBDEE1
DEDCD9D7D5D2D0CDCBC9C6C4C2BFBDBBB8B6B4B1AFADAAA8
A6A3A19F9D9A9896
8C857D766E675F574F473F362D241A11161C22282F353C44
4D545C62666A69686663615F5E5C5B5A5959585756555454
52514F4E4D4B4A48474645444444444445464748494B4D4F
5154575B5F646A7077818B96A2AEBBC6CBCCD1D1D3D6DCDD
DBD8D6D4D2D0CDCBC9C7C4C2C0BEBBB9B7B5B2B0AEACAAA7
A5A3A19F9C9A9896
8C857D766E675F574F473E362C23190E13191F252C333A42
4A525A6064686867666462605F5E5C5B5A59595757565554
5352514F4E4D4C4A4948474646464646464748494B4C4E50
5254575B60646A7077818A96A2AEBAC4CACCD0D0D2D3D9D8
D7D5D3D1CFCDCBC9C7C5C3C0BEBCBAB8B6B4B1AFADABA9A7
A5A2A09E9C9A9896
8C857D766E675F574F473E352C23190E10141B2229303840
4851585E62666766656462615F5E5D5C5B5A595857575655
54535251504F4D4C4B4A49494848484848494A4B4C4D4E50
5155575B5F646A7078808A96A2ADBAC1C7CCD0D1D2D3D5D5
D3D2D0CECCCBC9C7C5C3C1BFBDBBB9B6B4B2B0AEACAAA8A6
A4A2A09E9C9A9896
8C857D766E675F574F473E352C23180C0B11171F262D353E
454E565B5F63656564636261605F5D5C5C5B5A5958585756
5554535251504F4E4D4C4C4B4A4A4A4A4A4A4B4C4D4E4F50
5255575B5F64696F78808A95A2ADBABFC5C9CFD0D1D3D2D1
D0CFCDCCCAC8C6C4C3C1BFBDBBB9B7B5B3B1AFADABA9A7A5
A3A19F9D9B999795
8C857D766E675F574F473F362D23190F080C131A2229323B
434B53595E61636463636261605F5E5D5C5B5A5959585857
5655555453525150504F4E4D4D4C4C4C4C4C4C4D4E4F5152
5355585B5F646A7078818A95A2ADB9BDC3C8CECFD0D1D0CE
CDCCCAC9C7C6C4C2C1BFBDBBB9B7B6B4B2B0AEACAAA8A7A5
A3A19F9D9B999795
8C857D766F675F5850483F372E241B1106060D151D252D37
404951575C5F616262626160605F5E5D5C5C5B5A5A595958
5857565655545353515150504F4F4E4E4E4E4E4E4F505253
5456585C6064696F77808A94A0ACB8BCC0C6CCCECECECDCC
CAC9C8C6C5C3C2C0BEBDBBB9B8B6B4B2B1AFADABA9A8A6A4
A2A09F9D9B999795
8C857E766F676058504840382F261D130803081017202932
3C464E55595D5F60616161605F5F5E5E5D5C5C5B5B5A5A59
595858575756565554545352525151515050505051525354
55575A5C60656A6F777F8A949FABB8BCBEC5C9CCCDCBCAC9
C7C6C5C4C2C1BFBEBCBBB9B8B6B4B3B1AFAEACAAA9A7A5A3
A2A09E9C9B999795
8C857E776F6860595149413931281F150C020309111A232E
38424C53585B5D5F5F5F605F5F5F5E5E5D5D5C5C5B5B5B5A
5A5A59595958585756565555545454535353535353545455
56585B5D61656A70777F89949EA9B5BABEC4C8CACAC8C7C6
C5C4C2C1C0BFBDBCBAB9B8B6B5B3B1B0AEADABA9A8A6A4A3
A19F9E9C9A999795
8C857E777068615A524A423A322A21180F0400020A141E28
343F4850565A5C5D5E5F5F5F5F5E5E5E5E5D5D5C5C5C5B5B
5B5B5B5B5B5A5A5959585857575656565555555555555657
585A5C5F62666B70777F88939DA7B1B6BBC1C6C8C6C5C4C3
C2C1C0BFBDBCBBBAB8B7B6B4B3B1B0AFADABAAA8A7A5A4A2
A09F9D9C9A989795
8C857F777069625B534C443C342C241C130B0400040F1A25
303B454D53585A5B5C5D5E5E5E5E5E5E5D5D5D5D5D5C5C5C
5C5C5C5C5C5C5C5C5B5B5B5A595958585858575757575859
595B5D6063676B71777F88919BA6ADB3BABFC3C4C3C2C1C0
BFBEBDBCBBBAB9B8B7B5B4B3B1B0AFADACAAA9A7A6A4A3A1
A09E9D9B9A989795
8D867F78716A635C544D453E362F271F18110A05020A1621
2C37414A5055585A5B5C5D5D5D5D5D5D5D5D5D5D5D5D5D5D
5E5E5E5E5E5E5E5E5E5D5D5D5C5C5B5A5A5A5A5A5A595A5A
5B5D5E6164686C70777F87909AA2A9B0B7BCBFC0BFBFBEBD
BCBBBBBAB9B8B7B6B5B4B2B1B0AFADACABA9A8A6A5A4A2A1
9F9E9C9B99989695
8D867F78726B645D564E474039312A221B150E090406141E
28333D464D525557595A5B5C5C5C5C5D5D5D5D5D5E5E5E5E
5E5F5F60606061606060605F5F5E5E5D5D5D5D5C5C5C5D5D
5D5E606265696E71767F878F9AA1A6ADB4B9BCBCBCBBBBBA
B9B9B8B7B7B6B5B4B3B2B1B0AEADACABA9A8A7A6A4A3A1A0
9F9D9C9B99989695
8D868079726B655E575049423B342D251F18120C06050F1B
25303942494F53555758595A5B5B5B5C5C5D5D5E5E5E5F5F
5F60616162636362626262626261616160605F5F5E5E5F5F
5F606164676A6F73777D868F989EA4AAB0B5B9B8B8B8B8B7
B7B6B6B5B4B4B3B2B1B0AFAEADACABAAA8A7A6A5A3A2A19F
9E9D9C9A99989695
8D868079736C665F58524B443D362F28221B140E06050A16
212C363F464C505355565759595A5A5B5C5C5D5E5E5E5F5F
606061626364656464656565656463636362626161606060
60616265686C7074797F878C969DA3A8AEB2B4B5B5B5B5B4
B4B4B3B3B2B2B1B0AFAEADADACABAAA8A7A6A5A4A3A1A09F
9E9C9B9A99979695
8D87807A746D67605A534D463F39322B251E171008050612
1C26313A42484C5052545557575859595A5B5C5D5E5E5F5F
606161636465666666666767676666666565646463626262
62636466696C70747A80888D959BA2A6ABB0B1B1B2B2B2B2
B2B1B1B1B0B0AFAEADADACABAAA9A8A7A6A5A4A3A2A19F9E
9D9C9B9A98979695
8D87817B746E68625B554F48423B352E28211A130B06030B
161F2A343D44494D4F51525455555658595A5B5D5D5E5F5F
606061626465666767676767686868686767666665646464
656565676B6D72777C82898E959BA1A5A9ACADAEAFAFAFAF
AFAFAFAEAEAEADACACABAAA9A9A8A7A6A5A4A3A2A1A09F9E
9D9C9A9998979695
8D87817B756F69635D57504A443E37312B241E170F070306
0E19232D363E454A4C4D4F505253545657585A5B5C5D5C5D
5E5F60616264656566666667676868676867676767666565
656667696D6F72787F84888E949A9FA4A8A9AAABACACADAD
ADADADACACACABABAAAAA9A8A7A7A6A5A4A3A2A1A09F9E9D
9C9B9A9998979695
8E88827C76706A645E58524C46403A342E27211B140D0604
07111C2730373F44484A4B4D4E505153545657585A5B5B5B
5C5D5D5F6061626363646465656566666767676667686868
6869696B6E7275787E84898E93999EA3A5A6A7A8A9AAAAAA
ABABABAAAAAAAAA9A9A8A7A7A6A6A5A4A3A3A1A09F9F9E9D
9C9B9A9998979694
8E88827D77716B66605A554F49433D37312B251F18130D09
060D15202930383E4446494A4B4C4E4F5152545657575859
59595A5B5D5E5E5F60606060626363646465656565676869
696A6B6D6F72767A7F84898E94999DA1A3A4A5A6A6A7A8A8
A8A9A9A9A8A8A8A8A7A7A6A6A5A4A4A3A2A1A1A09F9E9D9C
9B9A999897969594
8E88837E78726D67615C56514B45403A342E28231D17120D
0808111A242D343A3F42444547494A4C4D4F505253545555
55565658595A5C5D5D5D5E5E5E6060626364656565666869
6A6C6D6E7174777B7F848A8F94999E9FA0A2A3A4A4A5A6A6
A6A7A7A7A7A6A6A6A6A5A5A4A4A3A3A2A1A0A09F9E9D9C9C
9B9A999897969594
8E89837E79736E69635E58534D48423D37322C27211C1712
0E080B141D272E34393D3F4042444648494B4B4D4F505151
5152525354545759595A5A5A5B5D5E5F6063646464656667
686A6B6D7073777A80858A9195999C9D9E9FA0A1A2A3A4A4
A4A5A5A5A5A5A5A5A4A4A4A3A3A2A2A1A0A09F9E9D9D9C9B
9A99999897969594
8E89847F7A746F6A65605A55504A45403B35302B25201B17
120E0B1019232A3137393B3C3C3F4244454748494B4B4C4D
4D4D4E4E4F504F535455565757585A5B5C5E606162636566
686A6B6C6F73787C8085899093999A9B9C9D9E9FA0A1A2A2
A3A3A3A3A3A3A3A3A3A3A2A2A2A1A1A09F9F9E9D9D9C9B9B
9A99989797969594
8E89847F7A76706B66615C57524D48433E39342F2A25201B
16120C0B141B222B3135373738393D3F4142434446474749
48484A4B4A4B4B4C4F4F50515152545557595C5E5F616364
66686A6D7075787D83868A8E919597999A9B9C9D9E9FA0A0
A1A1A2A2A2A2A2A2A2A1A1A1A0A0A09F9F9E9D9D9C9B9B9A
9999989796969594
8F8A85807B77726D68635E5A55504B46413C37322E29241F
1B16110A0C161F252B3033333333383A3D3E3E3F42424345
444544464545464749484A4B4B4C4E505254575A5C5E6061
6467696C7074797C81868A8E9092949698999A9B9C9D9E9F
9FA0A0A0A1A1A1A1A0A0A0A09F9F9F9E9E9D9D9C9B9B9A9A
9998989796969594
8F8A86817C78736E6A65605C57524E4944403B36312D2824
1F1A15100B0C1721272C2F302F2E32353639393A3C3E3E3F
40403F41403F3F3F43434343454648494B4D5154575B5E5F
6165696D71767B7D8085898E8F9192949697999A9A9C9C9D
9E9E9F9F9F9F9F9F9F9F9F9F9E9E9E9D9D9C9C9B9B9A9A99
9998979796959594
8F8B86827D7975706B67625E5A55504C47433E3A35312C28
231F1A15110C0E1821272B2D2C2A2C313233353636393A3A
3B3C3B3B3C3B3938393B3E3E3E3F41424445494C5054585D
6164676D70737A7D7F82878A8C8E909294959798999A9B9C
9C9D9D9E9E9E9E9E9E9E9E9E9E9D9D9D9C9C9B9B9A9A9999
9898979696959594
8F8B87827E7A76716D6965605C58534F4B46423E3935312C
28231F1A150F0B0F1820262A2A28272B2E2E2F3031333536
363737373738363434343536383A3B3D404245484C50565B
6065686C6F72777A7E8285888A8C8F91929495979899999A
9B9C9C9C9D9D9D9D9D9D9D9D9D9D9C9C9B9B9B9A9A999998
9897979696959594
8F8B87837F7B77736F6B67635E5A56524E4A46413D393531
2C28231F1A150F0C11171D2225262324282A2A2A2B2B2E2F
3131323233333230302E2F30333637393B3E42474B4F555C
6064686C6D7075797C808386898B8D8F9193949597989899
9A9A9B9B9C9C9C9C9C9C9C9C9C9C9C9B9B9A9A9A99999898
9897979696959494
908C8884807C7874716D6965615D5955514D4945413D3935
312D29241F1A15100D11171D202323212125262627262728
2A2C2E2D302F2F2E2E2C2A2B2E3033363A3D41464B505459
5D6164686B6E73787B7F8285888A8C8E9091939496979798
99999A9A9B9B9B9B9B9B9B9B9B9B9B9A9A9A999999989898
9797969695959494
908C8885817D7A76726F6B6763605C5854514D4945413D3A
36322D2925201B16110E10171D2122211F20212323232322
222427272A2B2C2B2E2F2D2D2F3133373C4044484A4E5256
5A5D6166696C70767A7D818486898B8D8F90929395969697
989999999A9A9A9A9A9B9B9A9A9A9A9A9A99999998989897
9796969695959494
908C8985827E7B7774706D6966625F5B5854504D4945423E
3A36332F2B26221D19151010161D2123211F212121212122
21202121242729292B2D2E303234373B3C404447494C4F52
555A5F6467686F75797C808385888A8C8E8F919294959596
97989898999999999A9A9A9A9A9A99999999989898989797
9796969595959494
908D8A8683807C7976726F6C6865625E5B5754514D494643
3F3C3834302C2924201C181312161E222423232323242424
25252727282A2A2B2D2F30323536373B3C3F4246474A4C50
54585D61676B7074787C7F828487898B8D8F909193949595
969797979899999999999999999999989898989797979797
9696969595959494
908D8A8784817E7B7774716E6B6865615E5B5855514E4B47
44413D3A36332F2B2724201C1916181F2326272828282828
29292A2A2B2D2E2E303132323637383B3C3E404446484C50
54575C62676C7074787C7F828486898B8C8E8F9192939495
959696979798989898989899999998989898979797979796
9696959595949494
918E8B8885827F7C797673706D6A6764615E5B5855524F4C
4946433F3C3936322F2C2825221F1B1D1F25292B2B2C2D2D
2E2E2F2F2F303132333434343437393A3B3E3F4246494D4F
52585E64686D7175797C7F828486888A8C8D8F9091939394
959596969797979798989898989898989897979697969696
9696959595949494
918E8B898683807E7B787573706D6A6865625F5C59565451
4E4B4845423F3C393633302D2B282625232325292D303132
3332333232313131323435353434373A3B3F424647494C52
575C61666A6E7376797C7F828486888A8C8D8F9091929394
949595969696969797979798989798989897979696969696
9695959594949494
918E8C898784827F7D7A777572706D6B686563615D5B5855
53504D4B484543403D3A383533312F2E2D2C2D2B2D2F3335
36373737363534343334353738383A3E404144484C4F5357
5B6064696C7074777A7D80828486888A8B8D8E8F91929394
949595969696979797979797979797979897979696969696
9595959594949494
918F8C8A888583817E7C7A777573706E6B696664615F5D5A
585553504E4B494644423F3D3B3A38373635353534333436
37383A3A3A3A3A3B3B3B3B3C3D3E3E404246494D5155585B
6063676B6F7275787B7E80838587888A8B8D8E8F90919293
939495959696969697969697969797979797969696959595
9595959594949494
918F8D8B89878482807E7C7A777573716F6C6A686664615F
5D5A585654524F4D4B494745434241403F3E3D3D3D3D3D3E
3E3E3F3F403F3E3E3E3F4040414345474A4D5053575B5E60
64686B6E7274777A7C7F81838587898A8B8D8E8F90919293
939494959595959696969697969696969696969696959595
9595959594949494
91908E8C8A88868482807E7C7A78767472706E6C6A686664
62605E5C5A58565452504E4D4B4A49484746454545454546
4646474747474646464748484A4B4D4F5254575A5D606365
686B6E717477797C7E8082848688898B8C8D8E8F90919292
939494949595959595969696969696969696969595959595
9595959494949494
92908E8C8B8987858482807E7C7B7977757372706E6C6A68
676563615F5E5C5A59575554535150504F4E4E4D4D4D4D4E
4E4E4F4E4E4E4E4E4F4F505152535557595B5E606365686A
6C6F7275777A7C7E8082848587898A8B8D8D8E8F90919292
929394949595959595959596969696969696969695959595
9595949494949493
92908F8D8C8A8887858482817F7D7C7A7977757472716F6D
6C6A6867656462615F5E5D5B5A5958585756565555555656
565656565656565656575858595B5C5E60616466686A6D6F
717375787A7C7E8082848587888A8B8C8D8E8F8F90919292
929394949495959595959595959595959595959695959595
9594949494949494
92918F8E8D8B8A888786848382807F7D7C7B797876757372
706F6E6C6B6A6867666564626261605F5F5E5E5D5D5D5E5D
5E5E5E5E5E5E5E5E5E5F5F606162636566686A6C6E6F7274
7577797B7D7F808284868788898B8C8D8D8E8F9091919292
929393949494959595959595959595959595959595959594
9494959494949494
9291908F8E8C8B8A89888685848382817F7E7D7C7A797877
7574737271706F6E6C6B6B6A696867676666666565656565
65666566666666666667676868696A6C6D6E707273757678
7A7B7D7E808283848587888A8B8C8C8D8E8F909091919293
939393949494949494959595959595959595959595949494
9494949494949494
929191908F8E8D8C8B8A898887868584838281807F7E7D7B
7A7A79787776757473727171706F6F6F6E6E6D6D6D6D6D6D
6D6D6D6D6E6E6E6E6E6E6F6F7070717373747677797A7B7C
7E7F81828385858788898A8B8C8D8E8E8F90909191919293
939393949494949594949594959595959495959595949494
9494949494949393
93929190908F8E8D8C8C8B8A898888878685848483828180
807F7E7D7C7C7B7A7A797878777776767676757575747475
757575757575757576767676777778797A7B7C7C7E7F8081
82838485868888898A8B8C8D8D8E8F8F9090919191929292
939393939494949494949494949494959494959494949494
9494949493949493
9392929191908F8F8E8E8D8C8C8B8B8A8989888787868685
858483838282818180807F7F7E7E7D7D7D7D7D7C7D7D7C7C
7C7C7D7D7D7D7D7D7D7D7D7E7E7E7F808081828283848586
87878888898A8B8C8C8D8E8E8F8F90909091919192929292
939393939494949494949494949494949494949494949494
9494949394949393
939392929191919090908F8F8E8E8E8D8D8C8C8B8B8A8A8A
8A8989888888878786868686868585858485858484848484
848484848484858585858485868686868787878889898A8A
8B8C8C8D8D8D8E8E8E8F9090919191929292929292929293
939494939394949394949494949494949494949494949494
9494949494949393
939393939292929292919191919190909090908F8F8F8E8E
8E8E8E8E8E8E8D8D8D8D8D8D8D8C8C8C8C8C8C8C8C8C8B8C
8C8C8C8C8C8C8C8C8C8C8C8C8C8D8D8D8D8D8D8E8E8E8F8F
8F9090909090909091919192929292939393939393939393
939394939394949494949494949493949494949494939494
9394949494949393
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[57]:=",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`004`3oool809>CT`T0TY:B0P2ATI42092@T0P0Shn?
0P2@T90408n?S`P0T92@0P2?Shl208b<S0<0T92@0P2?Shl4092@T0H0TI6A2P2BTY8209>CT`@0U9BD
00<0UIFE09BDU02DU9@00P2DU9@<09FEUAL0UYJF102EUID409JFUP`0UIFE3`2FUYH809NGU`@0V9RH
0P2FUYH209BDU0d0UiNG302HV9P209VIV@@0V9RH2@2IVIT609RHV0H0UiNG3@2FUYH209FEU@80U9BD
102GUiL209JFUP80UIFE0P2DU9@E0?ooo`004`3oool809>CT`T0TY:B0P2ATI42092@T0P0Shn?0P2@
T90408n?S`P0T92@0P2?Shl208b<S0<0T92@0P2?Shl4092@T0H0TI6A2P2BTY8209>CT`@0U9BD00<0
UIFE09BDU02DU9@00P2DU9@<09FEUAL0UYJF102EUID409JFUP`0UIFE3`2FUYH809NGU`@0V9RH0P2F
UYH209BDU0d0UiNG302HV9P209VIV@@0V9RH2@2IVIT609RHV0H0UiNG3@2FUYH209FEU@80U9BD102G
UiL209JFUP80UIFE0P2DU9@E0?ooo`004`3oool809>CT`80TY:B102ATI43092@T080Shn?0P2=SHd2
08^;R`80RXZ:2P2;Rh/608b<S080SHf=0P2;Rh/208N7Q`0308^;R`2<S8`0S8b<00H0S8b<0P2=SHd2
08j>SP80Shn?0P2@T904096AT@@0TY:B0P2CTi<209BDU0<0UIFE2P2FUYH409NGU`80UYJF0P2GUiLG
09RHV080UiNG102HV9P:09NGU`T0V9RH202IVIT609ZJVP80Vi^K102LW9`209ZJVP80UYJF0P2IVIT;
09^KV`P0W9bL2P2MWId909jNWP@0WIfM0P2LW9`609^KV`80VYZJ202IVIT309RHV0@0UiNG0P2IVIT2
09ZJVP80V9RH0P2GUiL209FEUAD0oooo000C0?ooo`P0Ti>C0P2BTY84096AT@<0T92@0P2?Shl208f=
S@80Rh^;0P2:RXX:08^;R`H0S8b<0P2=SHd208^;R`80QhN700<0Rh^;08b<S02<S8`01P2<S8`208f=
S@80SXj>0P2?Shl2092@T0@0TI6A102BTY8209>CT`80U9BD0`2EUID:09JFUP@0UiNG0P2FUYH209NG
UaL0V9RH0P2GUiL409RHV0X0UiNG2@2HV9P809VIV@H0VYZJ0P2KVi/409bLW080VYZJ0P2FUYH209VI
V@/0Vi^K202LW9`:09fMW@T0WYjN102MWId209bLW0H0Vi^K0P2JVYX809VIV@<0V9RH102GUiL209VI
V@80VYZJ0P2HV9P209NGU`80UIFE5@3oool001<0oooo1P2CTi<209:BTP@0TI6A0P2@T90208n?S`03
08j>SP2=SHd0SHf=0080Rh^;0P29RHT<08N7Q`X0R8R80P24Q8@00`25QHD0RHV908V9R@0408R8R080
RHV90P2:RXX208^;R`80S8b<0P2>SXh208n?S`80T92@0P2ATI4209:BTP80Ti>C0P2DU9@209FEU@/0
UiNG202HV9P209VIVAT0VYZJ302IVIT509ZJVPH0Vi^K1P2LW9`409fMW@@0WYjN1P2OWil209^KV`80
VIVI00<0W9bL09nOW`2OWil02P2OWil20:2PX0H0XJ6Q2P2RXZ850:>SX`@0XZ:R0P2QXJ440:2PX0@0
WinO0P2NWYh209fMW@@0W9bL1@2KVi/409RHV080VYZJ0P2KVi/209ZJVP80V9RH0P2EUIDE0?ooo`00
4`3oool609>CT`80TY:B102ATI42092@T080Shn?00<0SXj>08f=S@2=SHd00P2;Rh/208V9R@`0QhN7
2P28R8P208B4Q00308F5Q@29RHT0RHV900@0R8R80P29RHT208Z:RP80Rh^;0P2<S8`208j>SP80Shn?
0P2@T902096AT@80TY:B0P2CTi<209BDU080UIFE2`2GUiL809RHV080VIVI6@2JVYX<09VIV@D0VYZJ
1P2KVi/609bLW0@0WIfM102NWYh609nOW`80Vi^K0P2IVIT00`2LW9`0WinO09nOW`0:09nOW`80X:2P
1P2QXJ4:0::RXPD0Xj>S102RXZ820:6QX@@0X:2P102OWil209jNWP80WIfM102LW9`509^KV`@0V9RH
0P2JVYX209^KV`80VYZJ0P2HV9P209FEUAD0oooo000C0?ooo`80Ti>C102BTY82096AT@@0T92@0P2?
Shl208j>SP0308f=S@2;Rh/0Rh^;0080RXZ:0P28R8P208J6QP80Q8B42023Ph<:08B4Q080Ph>300<0
Ogmo08:2PP22PX801024Q8@208F5Q@80QXJ60P28R8P208Z:RP80S8b<0P2=SHd208n?S`80T92@0P2A
TI4209>CT`80U9BD0P2EUID00`2GUiL0V9RH09RHV00409RHV0h0VIVI0P2JVYX;09^KVa`0W9bL0`2M
WId609jNWP@0WinO102PX:040:6QX@P0XZ:R0P2PX:000`2MWId0WinO09nOW`020:>SX`80XZ:R1P2S
Xj<40:BTY0@0YJFU0P2VYZH80:NWY`<0Z:RX1P2WYjL20:JVYP80YJFU102TY:@40:>SX`80XJ6Q0P2P
X:0609jNWP0309fMW@2LW9`0W9bL0080VYZJ0P2KVi/209bLW080Vi^K0P2IVIT209JFUQD0oooo000C
0?ooo`80Ti>C102BTY82096AT@@0T92@0P2?Shl208j>SP0308f=S@2;Rh/0Rh^;0080RXZ:0P28R8P2
08J6QP80Q8B42023Ph<:08B4Q080Ph>300<0Ogmo08:2PP22PX801024Q8@208F5Q@80QXJ60P28R8P2
08Z:RP80S8b<0P2=SHd208n?S`80T92@0P2ATI4209>CT`80U9BD0P2EUID00`2GUiL0V9RH09RHV004
09RHV0h0VIVI0P2JVYX;09^KVa`0W9bL0`2MWId609jNWP@0WinO102PX:040:6QX@P0XZ:R0P2PX:00
0`2MWId0WinO09nOW`020:>SX`80XZ:R1P2SXj<40:BTY0@0YJFU0P2VYZH80:NWY`<0Z:RX1P2WYjL2
0:JVYP80YJFU102TY:@40:>SX`80XJ6Q0P2PX:0609jNWP0309fMW@2LW9`0W9bL0080VYZJ0P2KVi/2
09bLW080Vi^K0P2IVIT209JFUQD0oooo000C0?ooo`80Ti>C0P2BTY84096AT@80T92@0P2?Shl208j>
SP80SHf=00<0S8b<08Z:RP2:RXX00P29RHT208N7Q`80QHF50P23Ph<208:2PP80P8201P1oOgl:0820
P00307inOP1mOGd0OGem0080Ogmo0P20P8020861P@80PX:20P25QHD208N7Q`80RHV90P2;Rh/208j>
SP80T92@0P2ATI4209>CT`80U9BD0P2FUYH00`2HV9P0VIVI09VIV@0609ZJVP80Vi^K302JVYX209^K
V`H0W9bL2`2MWId:09jNWP80WinO102NWYh409nOW`D0X:2P102QXJ440::RXP@0Xj>S102TY:@40:FU
Y@H0YZJV00<0Y:BT0::RXP2RXZ800P2UYJD80:NWY`80Z:RX0P2YZJT40:ZZZP@0Zj^[1`2/[:`40:f]
[@@0[:b/0P2[Zj/20:ZZZP@0ZJVY102XZ:P20:JVYP80Y:BT102RXZ820:6QX@<0WinO102MWId209jN
WP80Vi^K0P2HV9P209JFUQD0oooo000C0?ooo`80Ti>C0P2BTY84096AT@80T92@0P2?Shl208j>SP80
SHf=00<0S8b<08Z:RP2:RXX00P29RHT208N7Q`80QHF50P23Ph<208:2PP80P8201P1oOgl:0820P003
07inOP1mOGd0OGem0080Ogmo0P20P8020861P@80PX:20P25QHD208N7Q`80RHV90P2;Rh/208j>SP80
T92@0P2ATI4209>CT`80U9BD0P2FUYH00`2HV9P0VIVI09VIV@0609ZJVP80Vi^K302JVYX209^KV`H0
W9bL2`2MWId:09jNWP80WinO102NWYh409nOW`D0X:2P102QXJ440::RXP@0Xj>S102TY:@40:FUY@H0
YZJV00<0Y:BT0::RXP2RXZ800P2UYJD80:NWY`80Z:RX0P2YZJT40:ZZZP@0Zj^[1`2/[:`40:f][@@0
[:b/0P2[Zj/20:ZZZP@0ZJVY102XZ:P20:JVYP80Y:BT102RXZ820:6QX@<0WinO102MWId209jNWP80
Vi^K0P2HV9P209JFUQD0oooo000C0?ooo`80Ti>C0P2BTY82096AT@80T92@0P2?Shl208j>SP80SHf=
0P2<S8`00`2;Rh/0RXZ:08Z:RP0208R8R080QXJ60P25QHD208>3P`80PH610P1oOgl207emO@X0O7al
101mOGd00`1lO7`0NGUi07UiN@0207YjNP80O7al0P1nOWh207moO`80PH610P24Q8@208N7Q`80RHV9
0P2<S8`208j>SP80TI6A0P2CTi<209FEU@80UiNG00<0VIVI09ZJVP2JVYX00P2KVi/409bLW080WIfM
1P2LW9`809^KV`80W9bL1@2MWId409jNWPP0WinO202PX:060:6QX@@0XZ:R1@2SXj<40:BTY0@0YJFU
0P2VYZH40:NWY`80Z:RX202YZJT30:ZZZP80Z:RX0P2WYjL20:ZZZP@0Zj^[0P2/[:`40:f][@80[Zj^
0P2_[jl40;2`/0L0/K6a102b/[840;6a/@80/;2`1P2_[jl20:j^[P80[Jf]0P2[Zj/20:VYZ@@0YjNW
0P2UYJD00`2SXj<0XZ:R0::RXP0409nOW`80WYjN0P2LW9`209VIV@80UYJF5@3oool001<0oooo0P2C
Ti<209:BTP80TI6A0P2@T90208n?S`80SXj>0P2=SHd208b<S00308^;R`2:RXX0RXZ:0080R8R80P26
QXH208F5Q@80Ph>30P21PH4207moO`80OGem2P1lO7`407emO@0307alO01iNGT0NGUi0080NWYj0P1l
O7`207inOP80Ogmo0P21PH4208B4Q080QhN70P29RHT208b<S080SXj>0P2ATI4209>CT`80UIFE0P2G
UiL00`2IVIT0VYZJ09ZJVP0209^KV`@0W9bL0P2MWId609bLW0P0Vi^K0P2LW9`509fMW@@0WYjN202O
Wil80:2PX0H0XJ6Q102RXZ850:>SX`@0Y:BT102UYJD20:JVYP@0YjNW0P2XZ:P80:VYZ@<0ZZZZ0P2X
Z:P20:NWY`80ZZZZ102[Zj/20:b/[0@0[Jf]0P2^[Zh20:n_[`@0/;2`1`2a/K440;:b/P@0/K6a0P2`
/;060:n_[`80[Zj^0P2][Jd20:^[Z`80ZJVY102WYjL20:FUY@030:>SX`2RXZ80XZ:R00@0WinO0P2N
WYh209bLW080VIVI0P2FUYHE0?ooo`004`3oool209>CT`80TY:B0P2@T90208n?S`80SXj>0P2=SHd2
08b<S080Rh^;00<0RXZ:08V9R@29RHT00P27QhL208J6QP80Q8B40P22PX820820P080OWin0P1lO7`2
07YjNP80NGUi0P1hN7P907UiN@80N7Qh0P1gMgL207QhN080NWYj0P1lO7`207inOP80PH610P24Q8@2
08N7Q`80Rh^;0P2>SXh2092@T080Ti>C0P2EUID209RHV00309ZJVP2KVi/0Vi^K0080W9bL0P2MWId2
09jNWP80WinO1P2NWYh209fMW@@0W9bL0P2KVi/409bLW080WIfM00<0WYjN09nOW`2OWil00P2OWil4
0:2PX0H0XJ6Q102RXZ860:>SX`@0Y:BT0P2UYJD30:JVYP@0YjNW102XZ:P20:VYZ@@0ZZZZ102[Zj/4
0:b/[0@0[Jf]0`2^[Zh20:n_[`80[Jf]0P2/[:`20:j^[P@0/;2`0P2a/K420;:b/P80/k>c0P2d];@4
0;Fe]@H0][Jf00<0]kNg0;Jf]P2f][H0102g]kL20;Jf]P@0]KFe102d];@20;>c/`80/[:b0P2`/;02
0:j^[P@0ZZZZ0P2XZ:P00`2VYZH0Y:BT0:BTY0040::RXP80WinO0P2LW9`209VIV@80UYJF5@3oool0
01<0oooo0P2CTi<209:BTP80T92@0P2?Shl208j>SP80SHf=0P2<S8`208^;R`0308Z:RP29RHT0RHV9
0080QhN70P26QXH208B4Q080PX:20P20P80207inOP80O7al0P1jNWX207UiN@80N7Qh2@1iNGT207Qh
N080MgMg0P1hN7P207YjNP80O7al0P1nOWh20861P@80Q8B40P27QhL208^;R`80SXj>0P2@T90209>C
T`80UIFE0P2HV9P00`2JVYX0Vi^K09^KV`0209bLW080WIfM0P2NWYh209nOW`H0WYjN0P2MWId409bL
W080Vi^K102LW9`209fMW@0309jNWP2OWil0WinO0080WinO102PX:060:6QX@@0XZ:R1P2SXj<40:BT
Y080YJFU0`2VYZH40:NWY`@0Z:RX0P2YZJT40:ZZZP@0Zj^[102/[:`40:f][@<0[Zj^0P2_[jl20:f]
[@80[:b/0P2^[Zh40;2`/080/K6a0P2b/[820;>c/`80];Bd102e]KD60;Jf]P030;Ng]`2f][H0][Jf
00@0]kNg0P2f][H40;Fe]@@0];Bd0P2c/k<20;:b/P80/;2`0P2^[Zh40:ZZZP80Z:RX00<0YZJV0:BT
Y02TY:@0102RXZ8209nOW`80W9bL0P2IVIT209JFUQD0oooo000C0?ooo`80Ti>C0P2BTY82096AT@80
Shn?0P2>SXh208f=S@80Rh^;0P2:RXX00`29RHT0R8R808R8R00208J6QP80QHF50P23Ph<208:2PP80
P8200P1nOWh207alO080NWYj0P1hN7P207MgM`/0MWIf0P1eMGD207AdM080MWIf0P1jNWX207alO080
OWin0P22PX8208F5Q@80RHV90P2<S8`2092@T080TY:B0P2EUID209RHV00309ZJVP2LW9`0W9bL0080
WIfM0P2NWYh209nOW`80X:2P0P2QXJ440:2PX080WinO102NWYh609fMW@<0WYjN102OWil40:2PX080
XJ6Q102RXZ840:>SX`80Y:BT102UYJD20:JVYP@0YjNW00<0Z:RX0:VYZ@2YZJT0102ZZZX20:^[Z`@0
[:b/102][Jd20:j^[P80[jn_1P2`/;040;6a/@030;:b/P2c/k<0/k>c0080];Bd0P2c/k<20;:b/P80
/k>c0P2d];@20;Jf]P80]kNg0P2h^;P20;Vi^@80^[Zj1P2k^k/90;bl_0@0^k^k0P2j^[X20;Vi^@@0
]kNg0P2f][H20;>c/`80/[:b0P2_[jl20:f][@80Zj^[00<0Z:RX0:JVYP2VYZH0102TY:@20:6QX@80
WIfM0P2JVYX209NGUaD0oooo000C0?ooo`80Ti>C0P2BTY82096AT@80Shn?0P2>SXh208f=S@80Rh^;
0P2:RXX00`29RHT0R8R808R8R00208J6QP80QHF50P23Ph<208:2PP80P8200P1nOWh207alO080NWYj
0P1hN7P207MgM`/0MWIf0P1eMGD207AdM080MWIf0P1jNWX207alO080OWin0P22PX8208F5Q@80RHV9
0P2<S8`2092@T080TY:B0P2EUID209RHV00309ZJVP2LW9`0W9bL0080WIfM0P2NWYh209nOW`80X:2P
0P2QXJ440:2PX080WinO102NWYh609fMW@<0WYjN102OWil40:2PX080XJ6Q102RXZ840:>SX`80Y:BT
102UYJD20:JVYP@0YjNW00<0Z:RX0:VYZ@2YZJT0102ZZZX20:^[Z`@0[:b/102][Jd20:j^[P80[jn_
1P2`/;040;6a/@030;:b/P2c/k<0/k>c0080];Bd0P2c/k<20;:b/P80/k>c0P2d];@20;Jf]P80]kNg
0P2h^;P20;Vi^@80^[Zj1P2k^k/90;bl_0@0^k^k0P2j^[X20;Vi^@@0]kNg0P2f][H20;>c/`80/[:b
0P2_[jl20:f][@80Zj^[00<0Z:RX0:JVYP2VYZH0102TY:@20:6QX@80WIfM0P2JVYX209NGUaD0oooo
000C0?ooo`80TY:B0P2ATI42092@T080Shn?0P2>SXh208b<S080Rh^;0P2:RXX00`28R8P0QhN708N7
Q`0208F5Q@80Q8B40P22PX820861P@80Ogmo0P1nOWh207alO080NWYj0P1hN7P207MgM`@0MGEe101d
M7@507=cL`80LW9b0P1aLG4207AdM080N7Qh0P1lO7`207moO`80Ph>30P28R8P208b<S080Shn?0P2B
TY8209FEU@80V9RH00<0Vi^K09fMW@2MWId00P2NWYh209nOW`80X:2P0P2RXZ840:>SX`80XZ:R0P2Q
XJ440:2PX080WinO0P2NWYh209fMW@80WYjN1@2OWil20:2PX0H0XJ6Q0P2RXZ820:>SX`80Y:BT0P2U
YJD40:JVYP80YjNW0P2XZ:P20:VYZ@030:ZZZP2[Zj/0Zj^[0080[:b/102][Jd20:j^[P80[jn_102`
/;020;6a/@@0/[:b102c/k<20;Bd]0<0]KFe0P2f][H60;Rh^080]kNg0P2h^;P20;Zj^P80_;bl0P2m
_Kd20;jn_P80_kno1P30`<090<71`@@0`<300P2n_[h20;bl_0@0^[Zj0P2i^KT20;Jf]P80/k>c0P2a
/K420:n_[`80[Jf]00<0ZZZZ0:NWY`2WYjL00P2VYZH20:BTY080XZ:R0P2NWYh209ZJVP80UiNG5@3o
ool001<0oooo0P2BTY82096AT@80T92@0P2?Shl208f=S@80S8b<0P2:RXX208V9R@0308R8R026QXH0
QXJ60080QHF50P23Ph<208:2PP80P8200P1oOgl207emO@80O7al0P1jNWX207QhN080MgMg0P1eMGD2
07AdM0D0Lg=c0P1bLW86075aL@80L71`0P1cLg<207UiN@80OWin0P21PH4208J6QP80Rh^;0P2?Shl2
09>CT`80UYJF0P2JVYX00`2MWId0WinO09nOW`020:6QX@@0XZ:R0P2SXj<60:BTY080Xj>S0P2RXZ84
0:6QX@80X:2P1@2OWil40:2PX0@0XJ6Q1P2RXZ840:>SX`80Y:BT102UYJD20:JVYP@0Z:RX00<0ZZZZ
0:^[Z`2[Zj/00P2/[:`20:f][@80[Zj^0P2_[jl20;2`/0@0/K6a0P2b/[820;>c/`80];Bd0P2e]KD4
0;Jf]P80]kNg00<0^;Rh0;Vi^@2i^KT00P2i^KT20;Zj^PP0^k^k0P2l_;`20;no_`@0`l?31034a<@2
0<G5a@<0a/K60P37alL20<S8b080alO70P35aLD20<C4a080`L710P2o_kl20;fm_@80_;bl0P2j^[X2
0;Rh^080]KFe0P2c/k<20;6a/@80/;2`00<0Zj^[0:VYZ@2YZJT00P2XZ:P20:FUY@80XZ:R0P2NWYh2
09^KV`80UiNG5@3oool001<0oooo0P2BTY82096AT@80T92@0P2?Shl208f=S@80S8b<0P2:RXX208V9
R@0308R8R026QXH0QXJ60080QHF50P23Ph<208:2PP80P8200P1oOgl207emO@80O7al0P1jNWX207Qh
N080MgMg0P1eMGD207AdM0D0Lg=c0P1bLW86075aL@80L71`0P1cLg<207UiN@80OWin0P21PH4208J6
QP80Rh^;0P2?Shl209>CT`80UYJF0P2JVYX00`2MWId0WinO09nOW`020:6QX@@0XZ:R0P2SXj<60:BT
Y080Xj>S0P2RXZ840:6QX@80X:2P1@2OWil40:2PX0@0XJ6Q1P2RXZ840:>SX`80Y:BT102UYJD20:JV
YP@0Z:RX00<0ZZZZ0:^[Z`2[Zj/00P2/[:`20:f][@80[Zj^0P2_[jl20;2`/0@0/K6a0P2b/[820;>c
/`80];Bd0P2e]KD40;Jf]P80]kNg00<0^;Rh0;Vi^@2i^KT00P2i^KT20;Zj^PP0^k^k0P2l_;`20;no
_`@0`l?31034a<@20<G5a@<0a/K60P37alL20<S8b080alO70P35aLD20<C4a080`L710P2o_kl20;fm
_@80_;bl0P2j^[X20;Rh^080]KFe0P2c/k<20;6a/@80/;2`00<0Zj^[0:VYZ@2YZJT00P2XZ:P20:FU
Y@80XZ:R0P2NWYh209^KV`80UiNG5@3oool001<0oooo0P2BTY82096AT@80T92@0P2>SXh208f=S@80
S8b<0P2:RXX208R8R00308N7Q`25QHD0QHF50080Q8B40P22PX820861P@80Ogmo0P1nOWh207alO080
Ng]k0P1iNGT207MgM`80MWIf0P1eMGD207AdM080Lg=c0`1bLW82075aL@H0L71`0P1_Kfl2071`L080
M7Ad0P1kNg/20820P080QHF50P2;Rh/2092@T080U9BD0P2GUiL209^KV`0309fMW@2QXJ40XJ6Q0080
Xj>S102TY:@20:FUY@H0YZJV0P2UYJD20:BTY080Xj>S0P2RXZ840:6QX@<0X:2P102QXJ460::RXPH0
Xj>S0P2TY:@20:FUY@@0YZJV0P2WYjL20:RXZ080ZJVY00<0ZZZZ0:b/[02/[:`00P2][Jd20:j^[P80
[jn_0P2a/K420;:b/P80/k>c0P2d];@20;Fe]@80][Jf102g]kL40;Vi^@80^[Zj00<0^k^k0;bl_02l
_;`0102m_Kd20;jn_P@0_kno1030`<020;no_`80`l?30P34a<@20<K6aP80b<S80P39bLT30<[:bP80
bLW91038b<P20<O7a`80a/K60P35aLD20<;2`P80`<300P2o_kl20;^k^`80^[Zj0P2h^;P20;Fe]@80
/k>c0P2a/K400`2][Jd0ZZZZ0:ZZZP020:RXZ080YZJV0P2RXZ8209nOW`80Vi^K0P2GUiLE0?ooo`00
4`3oool209:BTP80TI6A0P2@T90208j>SP80SHf=0P2<S8`208Z:RP80R8R800<0QhN708F5Q@25QHD0
0P24Q8@208:2PP80PH610P1oOgl207inOP80O7al0P1kNg/207UiN@80MgMg0P1fMWH207EeM@80M7Ad
0P1cLg<3079bLP80LG5a1P1`L70206m_K`80L71`0P1dM7@207]kN`80P8200P25QHD208^;R`80T92@
0P2DU9@209NGU`80Vi^K00<0WIfM0:6QX@2QXJ400P2SXj<40:BTY080YJFU1P2VYZH20:FUY@80Y:BT
0P2SXj<20::RXP@0XJ6Q0`2PX:040:6QX@H0XZ:R1P2SXj<20:BTY080YJFU102VYZH20:NWY`80Z:RX
0P2YZJT00`2ZZZX0[:b/0:b/[0020:f][@80[Zj^0P2_[jl20;6a/@80/[:b0P2c/k<20;Bd]080]KFe
0P2f][H40;Ng]`@0^KVi0P2j^[X00`2k^k/0_;bl0;bl_0040;fm_@80_[jn102o_kl40<30`080_kno
0P33`l<20<C4a080a/K60P38b<P20<W9b@<0b/[:0P39bLT40<S8b080alO70P36a/H20<G5a@80`/;2
0P30`<020;no_`80^k^k0P2j^[X20;Rh^080]KFe0P2c/k<20;6a/@030:f][@2ZZZX0ZZZZ0080Z:RX
0P2VYZH20::RXP80WinO0P2KVi/209NGUaD0oooo000C0?ooo`80TY:B0P2ATI42092@T080SXj>0P2<
S8`208^;R`80RHV90P28R8P00`26QXH0QHF508F5Q@0208>3P`80PX:20P20P80207moO`80OGem0P1k
Ng/207YjNP80NGUi0P1gMgL207IfMP80M7Ad0P1cLg<2079bLP80LG5a0`1`L70406m_K`@0KVi^0P1]
KFd2071`L080MWIf0P1mOGd208>3P`80RXZ:0P2ATI4209JFUP80VYZJ0P2MWId00`2PX:00Xj>S0:>S
X`020:FUY@80YZJV1P2WYjL20:RXZ080YjNW102VYZH20:FUY@80Y:BT0P2SXj<40::RXP030:6QX@2R
XZ80XZ:R0080XZ:R1P2SXj<40:BTY0@0YJFU0P2VYZH20:NWY`80Z:RX0P2YZJT20:ZZZP80Zj^[00<0
[:b/0:f][@2][Jd00P2_[jl20;2`/080/[:b0P2c/k<20;Bd]080]KFe0P2g]kL20;Rh^080^KVi0P2j
^[X20;^k^`80_;bl0P2m_Kd30;jn_P80_kno0P30`<020<71`@@0`/;20P33`l<20<C4a0@0aLG51P37
alL20<S8b080bLW90`3;bl/20<[:bPH0bLW91038b<P20<G5a@80`l?30P32`/820;fm_@80_;bl0P2j
^[X20;Jf]P80]KFe0P2b/[800`2^[Zh0[:b/0:b/[0020:RXZ080YJFU0P2RXZ8209nOW`80Vi^K0P2G
UiLE0?ooo`004`3oool209:BTP80TI6A0P2@T90208j>SP80S8b<0P2;Rh/208V9R@80R8R800<0QXJ6
08F5Q@25QHD00P23Ph<208:2PP80P8200P1oOgl207emO@80Ng]k0P1jNWX207UiN@80MgMg0P1fMWH2
07AdM080Lg=c0P1bLW82075aL@<0L71`101_Kfl406i^KP80KFe]0P1`L70207IfMP80OGem0P23Ph<2
08Z:RP80TI6A0P2FUYH209ZJVP80WIfM00<0X:2P0:>SX`2SXj<00P2UYJD20:JVYPH0YjNW0P2XZ:P2
0:NWY`@0YZJV0P2UYJD20:BTY080Xj>S102RXZ800`2QXJ40XZ:R0::RXP020::RXPH0Xj>S102TY:@4
0:FUY@80YZJV0P2WYjL20:RXZ080ZJVY0P2ZZZX20:^[Z`030:b/[02][Jd0[Jf]0080[jn_0P2`/;02
0;:b/P80/k>c0P2d];@20;Fe]@80]kNg0P2h^;P20;Vi^@80^[Zj0P2k^k/20;bl_080_Kfm0`2n_[h2
0;no_`80`<300P31`L440<;2`P80`l?30P34a<@40<G5a@H0alO70P38b<P20<W9b@<0bl_;0P3:b/X6
0<W9b@@0b<S80P35aLD20<?3``80`/;20P2m_Kd20;bl_080^[Zj0P2f][H20;Fe]@80/[:b00<0[Zj^
0:b/[02/[:`00P2XZ:P20:FUY@80XZ:R0P2OWil209^KV`80UiNG5@3oool001<0oooo0P2BTY82096A
T@80Shn?0P2>SXh208b<S080Rh^;0P29RHT208N7Q`0308J6QP24Q8@0Q8B40080Ph>30P21PH420820
P080OWin0P1mOGd207]kN`80NGUi0P1hN7P207IfMP80MGEe0P1dM7@207=cL`80LG5a0P1`L7000`1_
Kfl0KVi^06i^KP0206i^KP@0KFe]0P1/K6`206][J`80KVi^0P1aLG4207QhN080P8200P26QXH2096A
T@80VIVI0P2MWId20:2PX0030:>SX`2UYJD0YJFU0080YjNW0P2XZ:P:0:VYZ@80Z:RX0P2WYjL20:JV
YP80YJFU102TY:@70:>SX`@0Y:BT1P2UYJD40:JVYP80YjNW0P2XZ:P20:VYZ@80ZZZZ0P2/[:`20:f]
[@030:j^[P2_[jl0[jn_0080/K6a0P2b/[820;Bd]080]KFe0P2g]kL20;Rh^080^[Zj0P2k^k/20;bl
_080_Kfm0P2n_[h20;no_`80`<300`31`L420<?3``80a<C41035aLD20<K6aP80alO70P38b<P20<W9
b@80b/[:0P3;bl/20<c<c0@0cLg=1`3;bl/60<[:bP80bLW90P38b<P20<K6aP80aLG50P33`l<20;jn
_P80_Kfm0P2k^k/20;Ng]`80][Jf0P2c/k<00`2`/;00[Jf]0:f][@020:VYZ@80YZJV0P2RXZ8209nO
W`80Vi^K0P2GUiLE0?ooo`004`3oool209:BTP80TI6A0P2?Shl208j>SP80S8b<0P2;Rh/208V9R@80
QhN700<0QXJ608B4Q024Q8@00P23Ph<20861P@80P8200P1nOWh207emO@80Ng]k0P1iNGT207QhN080
MWIf0P1eMGD207AdM080Lg=c0P1aLG42071`L00306m_K`1^KVh0KVi^0080KVi^101]KFd206a/K080
Jf][0P1^KVh2075aL@80N7Qh0P20P80208J6QP80TI6A0P2IVIT209fMW@80X:2P00<0Xj>S0:FUY@2U
YJD00P2WYjL20:RXZ0X0ZJVY0P2XZ:P20:NWY`80YZJV0P2UYJD40:BTY0L0Xj>S102TY:@60:FUY@@0
YZJV0P2WYjL20:RXZ080ZJVY0P2ZZZX20:b/[080[Jf]00<0[Zj^0:n_[`2_[jl00P2a/K420;:b/P80
];Bd0P2e]KD20;Ng]`80^;Rh0P2j^[X20;^k^`80_;bl0P2m_Kd20;jn_P80_kno0P30`<030<71`@80
`l?30P34a<@40<G5a@80a/K60P37alL20<S8b080bLW90P3:b/X20<_;b`80c<c<103=cLd70<_;b`H0
b/[:0P39bLT20<S8b080a/K60P35aLD20<?3``80_[jn0P2m_Kd20;^k^`80]kNg0P2f][H20;>c/`03
0;2`/02][Jd0[Jf]0080ZJVY0P2VYZH20::RXP80WinO0P2KVi/209NGUaD0oooo000C0?ooo`80TY:B
0P2ATI4208n?S`80SHf=0P2<S8`208^;R`80RHV90P27QhL00`25QHD0Q8B408B4Q00208:2PP80PH61
0P1oOgl207emO@80O7al0P1jNWX207UiN@80MgMg0P1fMWH207AdM080Lg=c0P1bLW82075aL@80Kfm_
00<0KVi^06e]K@1]KFd00P1]KFd206a/K080Jf][0P1ZJVX206UYJ@80Jf][0P1]KFd2079bLP80Ng]k
0P22PX8208b<S080UiNG0P2PX:020:>SX`030:JVYP2XZ:P0Z:RX0080ZZZZ2P2[Zj/20:ZZZP80ZJVY
0P2XZ:P20:NWY`80YZJV102UYJD90:BTY080YJFU102VYZH40:NWY`@0Z:RX0P2YZJT20:ZZZP80Zj^[
0P2][Jd20:j^[P030;2`/02a/K40/K6a0080/[:b0P2d];@20;Jf]P80]kNg0P2i^KT20;^k^`80_;bl
0P2n_[h20;no_`80`<300P31`L420<;2`P80`l?30`34a<@20<K6aP80alO70P38b<P20<W9b@80b/[:
103;bl/20<c<c080cLg=203>c/h20<g=c@80c<c<00<0bl_;0<[:bP3:b/X0103;bl/40<[:bP80bLW9
0P37alL20<K6aP80`l?30P30`<020;jn_P80_;bl0P2i^KT20;Jf]P80];Bd00<0/K6a0:j^[P2^[Zh0
0P2ZZZX20:JVYP80XZ:R0P2OWil209^KV`80UiNG5@3oool001<0oooo0P2BTY82096AT@80Shn?0P2=
SHd208b<S080Rh^;0P29RHT208N7Q`0308F5Q@24Q8@0Q8B40080PX:20P21PH4207moO`80OGem0P1l
O7`207YjNP80NGUi0P1gMgL207IfMP80M7Ad0P1cLg<2079bLP80LG5a0P1_Kfl00`1^KVh0KFe]06e]
K@0206e]K@80K6a/0P1[Jf/206YZJP80JFUY0P1[Jf/206e]K@80LW9b0P1kNg/208:2PP80S8b<0P2G
UiL20:2PX080Xj>S00<0YZJV0:RXZ02XZ:P00P2ZZZX:0:^[Z`80ZZZZ0P2YZJT20:RXZ080YjNW0P2V
YZH40:FUY@T0Y:BT0P2UYJD40:JVYP@0YjNW102XZ:P20:VYZ@80ZZZZ0P2[Zj/20:f][@80[Zj^00<0
/;2`0;6a/@2a/K400P2b/[820;Bd]080][Jf0P2g]kL20;Vi^@80^k^k0P2l_;`20;jn_P80_kno0P30
`<020<71`@80`/;20P33`l<30<C4a080a/K60P37alL20<S8b080bLW90P3:b/X40<_;b`80c<c<0P3=
cLd80<k>cP80cLg=0P3<c<`00`3;bl/0b/[:0<[:bP040<_;b`@0b/[:0P39bLT20<O7a`80a/K60P33
`l<20<30`080_[jn0P2l_;`20;Vi^@80][Jf0P2d];@00`2a/K40[Zj^0:j^[P020:ZZZP80YZJV0P2R
XZ8209nOW`80Vi^K0P2GUiLE0?ooo`004`3oool209:BTP80TI6A0P2?Shl208f=S@80S8b<0P2:RXX2
08R8R080QhN700<0QHF508>3P`23Ph<00P21PH420820P080OWin0P1mOGd207]kN`80NWYj0P1hN7P2
07MgM`80MGEe0P1dM7@2079bLP80LG5a0P1`L70206i^KP0306e]K@1/K6`0K6a/0080Jf][0P1ZJVX4
06UYJ@80J6QX101ZJVX206i^KP80MWIf0P1nOWh208N7Q`80TI6A0P2OWil20:RXZ0030:ZZZP2/[:`0
[:b/0080[Jf]102^[Zh60:f][@80[:b/0P2ZZZX20:VYZ@80Z:RX102WYjL20:JVYPD0YJFU0P2TY:@4
0:FUY@80YZJV102WYjL20:RXZ0@0ZJVY0P2ZZZX20:^[Z`80[:b/0P2^[Zh20;2`/0030;6a/@2c/k<0
/k>c0080];Bd0P2f][H20;Rh^080^KVi0P2k^k/20;fm_@80_kno0P31`L420<;2`P80`l?30P34a<@2
0<G5a@80a/K60P37alL00`38b<P0bLW90<W9b@020<[:bP80bl_;0P3<c<`20<g=c@80c/k>103?cll8
0=3@d080clo?103>c/h00`3=cLd0bl_;0<_;b`060<_;b`@0b/[:0P38b<P20<O7a`80a<C40P31`L42
0;jn_P80^k^k0P2i^KT20;Jf]P80];Bd00<0/K6a0:j^[P2^[Zh00P2ZZZX20:JVYP80Xj>S0P2OWil2
09^KV`80UiNG5@3oool001<0oooo0P2BTY82096AT@80Shn?0P2=SHd208b<S080RXZ:0P28R8P208N7
Q`0308F5Q@23Ph<0Ph>30080PH610P20P80207inOP80OGem0P1kNg/207YjNP80N7Qh0P1gMgL207Ee
M@80M7Ad0P1bLW82075aL@80L71`0P1^KVh00`1]KFd0K6a/06a/K00206][J`80JVYZ101YJFT206QX
J0@0JVYZ0P1^KVh207IfMP80OWin0P27QhL2096AT@80WinO0P2XZ:P00`2ZZZX0[:b/0:b/[0020:f]
[@@0[Zj^1P2][Jd20:b/[080ZZZZ0P2YZJT20:RXZ0@0YjNW0P2VYZH50:FUY@80Y:BT102UYJD20:JV
YP@0YjNW0P2XZ:P40:VYZ@80ZZZZ0P2[Zj/20:b/[080[Zj^0P2`/;000`2a/K40/k>c0;>c/`020;Bd
]080][Jf0P2h^;P20;Vi^@80^k^k0P2m_Kd20;no_`80`L710P32`/820<?3``80a<C40P35aLD20<K6
aP80alO700<0b<S80<W9b@39bLT00P3:b/X20<_;b`80c<c<0P3=cLd20<k>cP@0clo?203@d=020<o?
c`@0c/k>00<0cLg=0<_;b`3;bl/01P3;bl/40<[:bP80b<S80P37alL20<C4a080`L710P2n_[h20;^k
^`80^KVi0P2f][H20;Bd]0030;6a/@2^[Zh0[Zj^0080ZZZZ0P2VYZH20:>SX`80WinO0P2KVi/209NG
UaD0oooo000C0?ooo`80TY:B0P2@T90208n?S`80SHf=0P2;Rh/208Z:RP80R8R80P26QXH00`24Q8@0
Ph>308>3P`020861P@80Ogmo0P1nOWh207alO080NWYj0P1iNGT207MgM`80MGEe0P1dM7@2079bLP80
LG5a0P1`L70206m_K`80KFe]00<0K6a/06][J`1[Jf/00P1ZJVX206UYJ@80J6QX0P1WIfL206IVIP@0
J6QX0P1ZJVX2071`L080NWYj0P22PX8208b<S080V9RH0P2VYZH00`2^[Zh0[jn_0:n_[`060;6a/@80
/;2`0P2_[jl20:j^[P80[Jf]0P2[Zj/20:ZZZP80ZJVY0P2XZ:P20:NWY`@0YZJV1@2UYJD40:JVYP@0
YjNW0P2XZ:P20:VYZ@@0ZZZZ0P2[Zj/20:b/[080[Jf]0P2_[jl20;6a/@030;:b/P2d];@0];Bd0080
][Jf0P2h^;P20;Zj^P80^k^k0P2m_Kd20;no_`80`/;20P33`l<20<G5a@80a/K60P37alL20<S8b080
bLW90P3:b/X00`3;bl/0c<c<0<c<c0020<g=c@80c/k>0P3@d=020=7Ad@H0d];B1P3Cdm<20=;BdP80
d=3@0P3?cll20=3@d0030<o?c`3=cLd0cLg=00X0bl_;0P39bLT20<O7a`80a<C40P32`/820;no_`80
_;bl0P2i^KT20;Jf]P80];Bd00<0/[:b0:j^[P2^[Zh00P2[Zj/20:NWY`80Xj>S0P2OWil209^KV`80
UiNG5@3oool001<0oooo0P2BTY82092@T080Shn?0P2=SHd208^;R`80RXZ:0P28R8P208J6QP0308B4
Q023Ph<0Ph>30080PH610P1oOgl207inOP80O7al0P1jNWX207UiN@80MgMg0P1eMGD207AdM080LW9b
0P1aLG42071`L080Kfm_0P1]KFd00`1/K6`0Jf][06][J`0206YZJP80JFUY0P1XJ6P206MWI`80IVIV
101XJ6P206YZJP80L71`0P1jNWX208:2PP80S8b<0P2HV9P20:JVYP030:j^[P2_[jl0[jn_00H0/K6a
0P2`/;020:n_[`80[Zj^0P2][Jd20:^[Z`80ZZZZ0P2YZJT20:RXZ080YjNW102VYZH50:FUY@@0YZJV
102WYjL20:RXZ080ZJVY102ZZZX20:^[Z`80[:b/0P2][Jd20:n_[`80/K6a00<0/[:b0;Bd]02d];@0
0P2f][H20;Rh^080^[Zj0P2k^k/20;fm_@80_kno0P32`/820<?3``80aLG50P36a/H20<O7a`80b<S8
0P39bLT20<[:bP030<_;b`3<c<`0c<c<0080cLg=0P3>c/h20=3@d080dM7A1P3Bd]860=?Cd`80d];B
0P3@d=020<o?c`80d=3@00<0clo?0<g=c@3=cLd02P3;bl/20<W9b@80alO70P34a<@20<;2`P80_kno
0P2l_;`20;Vi^@80][Jf0P2d];@00`2b/[80[Zj^0:j^[P020:^[Z`80YjNW0P2SXj<209nOW`80Vi^K
0P2GUiLE0?ooo`004`3oool209:BTP80T92@0P2>SXh208b<S080Rh^;0P29RHT208N7Q`80QXJ600<0
Q8B408:2PP22PX800P21PH4207moO`80OGem0P1kNg/207YjNP80N7Qh0P1fMWH207EeM@80Lg=c0P1a
LG42071`L080Kfm_0P1]KFd206a/K00306][J`1ZJVX0JVYZ0080JFUY0P1WIfL206IVIPH0IFEU0P1V
IVH206QXJ080KFe]0P1fMWH207inOP80QhN70P2BTY8209nOW`030:b/[02d];@0];Bd00H0];Bd0P2b
/[820;2`/080[jn_0P2^[Zh20:b/[080Zj^[0P2ZZZX20:RXZ080YjNW1@2VYZH40:FUY@H0YZJV0P2W
YjL20:RXZ0@0ZZZZ0P2[Zj/20:b/[080[Jf]0P2^[Zh20;2`/080/K6a00<0/k>c0;Fe]@2e]KD00P2g
]kL20;Zj^P80_;bl0P2m_Kd20;no_`80`L710P34a<@20<K6aP80alO70P39bLT20<[:bP80bl_;0P3<
c<`50<k>cP80clo?0P3@d=020=7Ad@80d];B3P3De=@20=;BdP@0d=3@0`3?cll20<k>cP80cLg=0P3;
bl/40<[:bP80bLW90P37alL20<G5a@80`l?30P30`<020;jn_P80^[Zj0P2g]kL20;Bd]0030;6a/@2^
[Zh0[Zj^0080ZZZZ0P2WYjL20::RXP80WinO0P2KVi/209NGUaD0oooo000C0?ooo`80TY:B0P2@T902
08j>SP80S8b<0P2;Rh/208V9R@80QhN70P26QXH00`24Q8@0PX:208:2PP020861P@80Ogmo0P1mOGd2
07]kN`80NWYj0P1hN7P207IfMP80MGEe0P1cLg<2075aL@80L71`0P1_Kfl206e]K@80K6a/00<0Jf][
06YZJP1ZJVX00P1YJFT206MWI`80IVIV1P1UIFD206IVIP80J6QX0P1]KFd207IfMP80OWin0P27QhL2
09:BTP80WinO00<0[:b/0;Bd]02d];@01P2d];@20;:b/P80/;2`0P2_[jl20:j^[P80[:b/0P2[Zj/2
0:ZZZP80Z:RX0P2WYjL50:JVYP@0YJFU1P2VYZH20:NWY`80Z:RX102ZZZX20:^[Z`80[:b/0P2][Jd2
0:j^[P80/;2`0P2a/K400`2c/k<0]KFe0;Fe]@020;Ng]`80^[Zj0P2l_;`20;fm_@80_kno0P31`L42
0<C4a080a/K60P37alL20<W9b@80b/[:0P3;bl/20<c<c0D0c/k>0P3?cll20=3@d080dM7A0P3Bd]8>
0=CDe080d];B103@d=030<o?c`80c/k>0P3=cLd20<_;b`@0b/[:0P39bLT20<O7a`80aLG50P33`l<2
0<30`080_[jn0P2j^[X20;Ng]`80];Bd00<0/K6a0:j^[P2^[Zh00P2ZZZX20:NWY`80XZ:R0P2OWil2
09^KV`80UiNG5@3oool001<0oooo0P2BTY82092@T080SXj>0P2<S8`208Z:RP80R8R80P27QhL208F5
Q@0308>3P`21PH40PH610080P8200P1nOWh207alO080Ng]k0P1iNGT207QhN080MWIf0P1dM7@2079b
LP80LG5a0P1_Kfl206i^KP80K6a/0P1[Jf/00`1YJFT0J6QX06QXJ00206MWI`80IVIV0P1UIFD406AT
I080Hf=S101UIFD206][J`80LW9b0P1jNWX208>3P`80SHf=0P2HV9P00`2TY:@0/[:b0;:b/P020;Zj
^P80^;Rh0P2f][H20;Bd]080/[:b0P2`/;020:j^[P80[:b/0P2[Zj/20:VYZ@@0Z:RX1@2VYZH20:FU
Y@H0YZJV102WYjL20:RXZ080ZZZZ0P2[Zj/20:b/[080[Jf]0P2^[Zh20:n_[`80/;2`0P2b/[800`2d
];@0][Jf0;Jf]P020;Rh^080^k^k0P2m_Kd20;no_`80`L710P33`l<20<G5a@80alO70P39bLT20<_;
b`80c<c<0P3>c/h20<o?c`80d=3@1@3AdM420=;BdP80dm?C0P3De=@20=GEe@80e]KF203EeMD40=CD
e0@0d];B00<0dM7A0=3@d03@d=000P3?cll20<k>cP80cLg=0P3;bl/20<[:bP80bLW90P37alL20<G5
a@80`l?30P30`<020;jn_P80^k^k0P2g]kL20;Bd]0030;6a/@2][Jd0[Jf]0080ZZZZ0P2VYZH20::R
XP80WYjN0P2KVi/209NGUaD0oooo000C0?ooo`80TY:B0P2@T90208j>SP80S8b<0P2:RXX208R8R080
QhN70P25QHD00`23Ph<0PH610861P@020820P080OWin0P1lO7`207]kN`80NGUi0P1hN7P207IfMP80
M7Ad0P1bLW82075aL@80Kfm_0P1^KVh206a/K080Jf][00<0JFUY06QXJ01XJ6P00P1WIfL206IVIP80
IFEU101TI6@206=SH`@0IFEU0P1[Jf/2079bLP80NWYj0P23Ph<208f=S@80V9RH00<0Y:BT0;:b/P2b
/[800P2j^[X20;Rh^080][Jf0P2d];@20;:b/P80/;2`0P2^[Zh20:b/[080Zj^[0P2YZJT40:RXZ0D0
YZJV0P2UYJD60:JVYP@0YjNW0P2XZ:P20:ZZZP80Zj^[0P2/[:`20:f][@80[Zj^0P2_[jl20;2`/080
/[:b00<0];Bd0;Jf]P2f][H00P2h^;P20;^k^`80_Kfm0P2o_kl20<71`@80`l?30P35aLD20<O7a`80
bLW90P3;bl/20<c<c080c/k>0P3?cll20=3@d0D0dM7A0P3Bd]820=?Cd`80e=CD0P3EeMD20=KFePP0
eMGE103De=@40=;BdP030=7Ad@3@d=00d=3@0080clo?0P3>c/h20<g=c@80bl_;0P3:b/X20<W9b@80
alO70P35aLD20<?3``80`<300P2n_[h20;^k^`80]kNg0P2d];@00`2a/K40[Jf]0:f][@020:ZZZP80
YZJV0P2RXZ8209jNWP80Vi^K0P2GUiLE0?ooo`004`3oool209:BTP80T92@0P2>SXh208b<S080RXZ:
0P28R8P208J6QP80QHF500<0Ph>30861P@21PH400P1oOgl207inOP80O7al0P1jNWX207QhN080MWIf
0P1eMGD207=cL`80LG5a0P1`L70206i^KP80KFe]0P1[Jf/206YZJP0306QXJ01WIfL0IfMW0080IFEU
0P1TI6@206=SH`80HV9R101QHF44069RHP80JFUY0P1_Kfl207IfMP80Ogmo0P29RHT209>CT`0309jN
WP2ZZZX0ZZZZ0080]kNg0P2l_;`20;Rh^080]KFe0P2b/[820;2`/080[Zj^0P2/[:`20:^[Z`80ZJVY
0P2XZ:P20:NWY`@0YZJV1@2UYJD40:JVYP@0YjNW0P2XZ:P20:VYZ@80ZZZZ0P2[Zj/20:f][@80[Zj^
0P2`/;020;6a/@80/k>c00<0]KFe0;Ng]`2g]kL00P2i^KT20;^k^`80_[jn0P30`<020<?3``80aLG5
0P37alL20<W9b@80bl_;0P3=cLd20<k>cP80d=3@0P3AdM420=;BdP030=?Cd`3De=@0e=CD0080dm?C
103De=@20=GEe@80e]KF0P3GemL40=KFeP80emOG103Fe]H20=GEe@@0e=CD00<0d];B0=3@d03@d=00
0P3?cll20<k>cP80cLg=0P3<c<`20<_;b`80bLW90P37alL20<G5a@80`l?30P31`L420;jn_P80^k^k
0P2h^;P20;Bd]0030;6a/@2][Jd0[Jf]0080ZZZZ0P2VYZH20::RXP80WinO0P2KVi/209RHV1D0oooo
000C0?ooo`80TY:B0P2@T90208j>SP80S8b<0P2:RXX208R8R080QXJ60P25QHD00`23Ph<0PH610861
P@0207moO`80OWin0P1lO7`207YjNP80N7Qh0P1fMWH207EeM@80Lg=c0P1aLG42071`L080KVi^0P1]
KFd206][J`80JVYZ00<0J6QX06MWI`1WIfL00P1UIFD206ATI080Hf=S0P1RHV84065QH@@0HV9R0P1Y
JFT206m_K`80MWIf0P1oOgl208V9R@80Ti>C00<0WYjN0:ZZZP2ZZZX00P2g]kL20;bl_080^;Rh0P2e
]KD20;:b/P80/;2`0P2^[Zh20:b/[080Zj^[0P2YZJT20:RXZ080YjNW102VYZH50:FUY@@0YZJV102W
YjL20:RXZ080ZJVY0P2ZZZX20:^[Z`80[Jf]0P2^[Zh20;2`/080/K6a0P2c/k<00`2e]KD0]kNg0;Ng
]`020;Vi^@80^k^k0P2n_[h20<30`080`l?30P35aLD20<O7a`80bLW90P3;bl/20<g=c@80c/k>0P3@
d=020=7Ad@80d];B00<0dm?C0=CDe03De=@00P3Cdm<40=CDe080eMGE0P3Fe]H20=OGe`@0e]KF0P3G
emL40=KFeP80eMGE103De=@00`3Bd]80d=3@0=3@d0020<o?c`80c/k>0P3=cLd20<c<c080bl_;0P39
bLT20<O7a`80aLG50P33`l<20<71`@80_[jn0P2k^k/20;Rh^080];Bd00<0/K6a0:f][@2][Jd00P2Z
ZZX20:JVYP80XZ:R0P2OWil209^KV`80V9RH5@3oool001<0oooo0P2ATI4208n?S`80SXj>0P2<S8`2
08Z:RP80R8R80P26QXH208B4Q00308:2PP20P800P8200080OWin0P1mOGd207]kN`80NGUi0P1gMgL2
07IfMP80M7Ad0P1bLW82071`L080KVi^0P1]KFd206][J`80JVYZ0P1YJFT00`1WIfL0IFEU06EUI@02
06ATI080HV9R0P1QHF42061PH0@0GemO0P1PH602065QH@80IfMW0P1]KFd207AdM080O7al0P24Q8@2
08j>SP0309RHV02TY:@0Y:BT0080[jn_0P2j^[X20;Rh^080][Jf0P2c/k<20;2`/080[Zj^0P2/[:`2
0:ZZZP@0Z:RX0P2WYjL40:JVYPD0YJFU102VYZH40:NWY`80Z:RX0P2YZJT20:ZZZP80Zj^[0P2][Jd2
0:j^[P80/;2`0P2a/K420;>c/`030;Fe]@2g]kL0]kNg0080^KVi0P2l_;`20;no_`80`/;20P34a<@2
0<K6aP80b<S80P3:b/X20<c<c080clo?0P3@d=020=;BdP80dm?C0P3De=@00`3EeMD0e]KF0=KFeP04
0=GEe@80e=CD0P3Fe]H20=GEe@@0emOG103Hf=P60=OGe`80e]KF0P3EeMD00`3De=@0d];B0=;BdP02
0=7Ad@80d=3@0P3?cll20<g=c@80c<c<0P3:b/X20<S8b080a/K60P33`l<20<71`@80_[jn0P2k^k/2
0;Rh^080];Bd00<0/K6a0:f][@2][Jd00P2ZZZX20:JVYP80XZ:R0P2OWil209^KV`80UiNG5@3oool0
01<0oooo0P2ATI4208n?S`80SXj>0P2<S8`208Z:RP80R8R80P26QXH208B4Q00308:2PP20P800P820
0080OWin0P1mOGd207]kN`80NGUi0P1gMgL207IfMP80M7Ad0P1bLW82071`L080KVi^0P1]KFd206][
J`80JVYZ0P1YJFT00`1WIfL0IFEU06EUI@0206ATI080HV9R0P1QHF42061PH0@0GemO0P1PH602065Q
H@80IfMW0P1]KFd207AdM080O7al0P24Q8@208j>SP0309RHV02TY:@0Y:BT0080[jn_0P2j^[X20;Rh
^080][Jf0P2c/k<20;2`/080[Zj^0P2/[:`20:ZZZP@0Z:RX0P2WYjL40:JVYPD0YJFU102VYZH40:NW
Y`80Z:RX0P2YZJT20:ZZZP80Zj^[0P2][Jd20:j^[P80/;2`0P2a/K420;>c/`030;Fe]@2g]kL0]kNg
0080^KVi0P2l_;`20;no_`80`/;20P34a<@20<K6aP80b<S80P3:b/X20<c<c080clo?0P3@d=020=;B
dP80dm?C0P3De=@00`3EeMD0e]KF0=KFeP040=GEe@80e=CD0P3Fe]H20=GEe@@0emOG103Hf=P60=OG
e`80e]KF0P3EeMD00`3De=@0d];B0=;BdP020=7Ad@80d=3@0P3?cll20<g=c@80c<c<0P3:b/X20<S8
b080a/K60P33`l<20<71`@80_[jn0P2k^k/20;Rh^080];Bd00<0/K6a0:f][@2][Jd00P2ZZZX20:JV
YP80XZ:R0P2OWil209^KV`80UiNG5@3oool001<0oooo0P2ATI4208n?S`80SHf=0P2<S8`208Z:RP80
R8R80P26QXH208B4Q00308:2PP20P800P8200080OWin0P1lO7`207YjNP80N7Qh0P1fMWH207EeM@80
Lg=c0P1aLG4206m_K`80KVi^0P1/K6`206YZJP80JFUY0P1WIfL00`1UIFD0I6AT06ATI002069RHP80
HF5Q0P1PH60405iNGP80GEeM0P1NGUh2061PH080IFEU0P1ZJVX2075aL@80NGUi0P21PH4208Z:RP03
09>CT`2NWYh0WYjN0080ZZZZ0P2f][H20;Zj^P80][Jf0P2b/[820:n_[`80[Jf]0P2[Zj/20:ZZZP80
Z:RX0P2WYjL20:JVYPD0YJFU102TY:@20:FUY@@0YZJV0P2WYjL20:RXZ080ZJVY0P2ZZZX20:^[Z`80
[:b/0P2^[Zh20;2`/080/[:b0P2c/k<00`2e]KD0]kNg0;Ng]`020;Zj^P80_;bl0P2o_kl20<;2`P80
aLG50P38b<P20<W9b@80bl_;0P3=cLd20=3@d080d];B0P3Cdm<20=GEe@<0e]KF0P3GemL40=KFeP@0
eMGE103Fe]H20=OGe`@0f=SH103GemL40=SHf080emOG00<0e]KF0=GEe@3EeMD00P3Cdm<20=;BdP80
dM7A0P3?cll20<g=c@80bl_;0P39bLT20<K6aP80a<C40P31`L420;jn_P80^k^k0P2h^;P20;Bd]003
0;6a/@2][Jd0[Jf]0080ZZZZ0P2VYZH20::RXP80WinO0P2KVi/209NGUaD0oooo000C0?ooo`80TI6A
0P2?Shl208f=S@80S8b<0P2:RXX208R8R080QXJ60P24Q8@00`22PX80P8200820P00207inOP80O7al
0P1jNWX207QhN080MWIf0P1eMGD207=cL`80LG5a0P1_Kfl206i^KP80K6a/0P1ZJVX206UYJ@80IfMW
00<0IFEU06ATI01TI6@00P1RHV82065QH@80H61P101NGUh205eMG@80GUiN0P1PH60206EUI@80JVYZ
0P1aLG4207UiN@80PH610P2:RXX00`2CTi<0WYjN09jNWP020:ZZZP80][Jf0P2j^[X20;Jf]P80/[:b
0P2_[jl20:f][@80Zj^[0P2ZZZX20:RXZ080YjNW0P2VYZH50:FUY@@0Y:BT0P2UYJD40:JVYP80YjNW
0P2XZ:P20:VYZ@80ZZZZ0P2[Zj/20:b/[080[Zj^0P2`/;020;:b/P80/k>c00<0]KFe0;Ng]`2g]kL0
0P2j^[X20;bl_080_kno0P32`/820<G5a@80b<S80P39bLT20<_;b`80cLg=0P3@d=020=;BdP80dm?C
0P3EeMD30=KFeP80emOG103Fe]H40=GEe@@0e]KF0P3GemL40=SHf0@0emOG103Hf=P20=OGe`030=KF
eP3EeMD0eMGE0080dm?C0P3Bd]820=7Ad@80clo?0P3=cLd20<_;b`80bLW90P36a/H20<C4a080`L71
0P2n_[h20;^k^`80^;Rh0P2d];@00`2a/K40[Jf]0:f][@020:ZZZP80YZJV0P2RXZ8209nOW`80Vi^K
0P2GUiLE0?ooo`004`3oool2096AT@80Shn?0P2=SHd208^;R`80RHV90P27QhL208F5Q@80Ph>300<0
PH6107moO`1oOgl00P1mOGd207]kN`80NGUi0P1gMgL207EeM@80M7Ad0P1bLW82071`L080KVi^0P1]
KFd206][J`80JFUY0P1WIfL206IVIP0306ATI01RHV80HV9R0080HF5Q0P1OGel205iNGP80GEeM0P1L
G5`205]KF`80G5aL0P1OGel206ATI080JFUY0P1`L70207MgM`80OWin0P27QhL00`2@T900VYZJ09ZJ
VP020:FUY@80[jn_0P2h^;P20;Fe]@80/K6a0P2_[jl20:b/[080ZZZZ0P2XZ:P20:NWY`80YZJV0P2U
YJD;0:BTY080YJFU0P2VYZH40:NWY`80Z:RX0P2YZJT20:^[Z`80[:b/0P2^[Zh20;2`/080/K6a0P2d
];@00`2e]KD0]kNg0;Ng]`020;Zj^P80_;bl0P2o_kl20<;2`P80a/K60P39bLT20<[:bP80c<c<0P3?
cll20=7Ad@80dm?C0P3De=@20=KFeP80emOG0`3Hf=P40=KFePH0emOG0P3Hf=P40=[JfP@0fMWI0P3H
f=P40=WIf@<0emOG0P3Fe]H20=GEe@80dm?C0P3Bd]820=3@d080c/k>0P3<c<`20<W9b@80alO70P34
a<@20<;2`P80_[jn0P2k^k/20;Rh^080]KFe00<0/K6a0:f][@2][Jd00P2ZZZX20:JVYP80XZ:R0P2O
Wil209^KV`80UiNG5@3oool001<0oooo0P2ATI4208n?S`80SHf=0P2;Rh/208V9R@80QhN70P25QHD2
08>3P`030861P@1oOgl0Ogmo0080OGem0P1kNg/207UiN@80MgMg0P1eMGD207AdM080LW9b0P1`L702
06i^KP80KFe]0P1[Jf/206UYJ@80IfMW0P1VIVH00`1TI6@0HV9R069RHP02065QH@80GemO0P1NGUh2
05eMG@80G5aL0P1KFe/205aLG080GemO0P1TI6@206UYJ@80L71`0P1gMgL207inOP80QhN700<0T92@
09ZJVP2JVYX00P2UYJD20:n_[`80^;Rh0P2e]KD20;6a/@80[jn_0P2/[:`20:ZZZP80Z:RX0P2WYjL2
0:JVYP80YJFU2`2TY:@20:FUY@80YZJV102WYjL20:RXZ080ZJVY0P2[Zj/20:b/[080[Zj^0P2`/;02
0;6a/@80];Bd00<0]KFe0;Ng]`2g]kL00P2j^[X20;bl_080_kno0P32`/820<K6aP80bLW90P3:b/X2
0<c<c080clo?0P3AdM420=?Cd`80e=CD0P3Fe]H20=OGe`<0f=SH103Fe]H60=OGe`80f=SH103Jf]X4
0=WIf@80f=SH103IfMT30=OGe`80e]KF0P3EeMD20=?Cd`80d];B0P3@d=020<k>cP80c<c<0P39bLT2
0<O7a`80a<C40P32`/820;jn_P80^k^k0P2h^;P20;Fe]@030;6a/@2][Jd0[Jf]0080ZZZZ0P2VYZH2
0::RXP80WinO0P2KVi/209NGUaD0oooo000C0?ooo`80TI6A0P2?Shl208f=S@80Rh^;0P29RHT208N7
Q`80QHF50P23Ph<00`21PH40Ogmo07moO`0207emO@80Ng]k0P1iNGT207MgM`80M7Ad0P1cLg<2075a
L@80Kfm_0P1]KFd206][J`80JVYZ0P1XJ6P206IVIP80I6AT00<0Hf=S065QH@1QHF400P1OGel205eM
G@80G5aL0P1KFe/205YJFP80FEUI0P1KFe/205eMG@80HV9R0P1XJ6P206m_K`80MWIf0P1lO7`208F5
Q@0308j>SP2GUiL0UiNG0080XJ6Q0P2[Zj/20;Jf]P80/k>c0P2`/;020:f][@80ZZZZ0P2XZ:P20:NW
Y`80YJFU0P2TY:@40:>SX`<0XZ:R1P2SXj<20:BTY080YJFU0P2VYZH20:NWY`80Z:RX0P2YZJT20:ZZ
ZP80[:b/0P2][Jd20:n_[`80/K6a0P2c/k<00`2e]KD0]kNg0;Ng]`020;Vi^@80_;bl0P2o_kl20<?3
``80a/K60P39bLT20<_;b`80cLg=0P3@d=020=;BdP80e=CD0P3EeMD20=KFeP80emOG0`3Hf=P60=KF
eP@0f=SH0P3IfMT60=_Kf`80f][J1P3IfMT30=SHf0@0emOG0P3Fe]H20=CDe080d];B0P3@d=020<g=
c@80b/[:0P38b<P20<C4a080`/;20P2o_kl20;bl_080^;Rh0P2e]KD00`2a/K40[Jf]0:f][@020:ZZ
ZP80YZJV0P2RXZ8209nOW`80Vi^K0P2GUiLE0?ooo`004`3oool2096AT@80Shn?0P2=SHd208^;R`80
RHV90P27QhL208F5Q@80Ph>300<0PH6107moO`1oOgl00P1mOGd207]kN`80NGUi0P1gMgL207AdM080
Lg=c0P1aLG4206m_K`80KFe]0P1[Jf/206YZJP80J6QX0P1VIVH206ATI00306=SH`1QHF40HF5Q0080
GemO0P1MGEd205aLG080Fe]K0P1JFUX205UIF@80Fe]K0P1MGEd2069RHP80J6QX0P1_Kfl207IfMP80
O7al0P25QHD00`2>SXh0UiNG09NGU`020:6QX@80Zj^[0P2f][H20;>c/`80/;2`0P2][Jd20:ZZZP80
Z:RX0P2WYjL20:FUY@80Y:BT102SXj<30::RXPH0Xj>S0P2TY:@20:FUY@80YZJV0P2WYjL20:RXZ080
ZJVY0P2ZZZX20:b/[080[Jf]0P2_[jl20;6a/@80/k>c00<0]KFe0;Ng]`2g]kL00P2i^KT20;bl_080
_kno0P33`l<20<K6aP80bLW90P3;bl/20<g=c@80d=3@0P3Bd]820=CDe080eMGE0P3Fe]H20=OGe`<0
f=SH1P3Fe]H40=SHf080fMWI1P3Kfm/20=[JfPH0fMWI0`3Hf=P40=OGe`80e]KF0P3De=@20=;BdP80
d=3@0P3=cLd20<[:bP80b<S80P34a<@20<;2`P80_kno0P2l_;`20;Rh^080]KFe00<0/K6a0:f][@2]
[Jd00P2ZZZX20:JVYP80XZ:R0P2OWil209^KV`80UiNG5@3oool001<0oooo0P2ATI4208n?S`80SHf=
0P2:RXX208V9R@80QhN70P25QHD208>3P`030820P01nOWh0OWin0080O7al0P1jNWX207QhN080MWIf
0P1dM7@2079bLP80L71`0P1^KVh206a/K080JVYZ0P1XJ6P206MWI`80IFEU0P1SHf<00`1QHF40H61P
061PH00205iNGP80G5aL0P1JFUX205UIF@80F5QH0P1GEeL205UIF@80G5aL0P1PH60206IVIP80K6a/
0P1cLg<207]kN`80Ph>300<0S8b<09BDU02DU9@00P2NWYh20:NWY`80/k>c0P2`/;020:j^[P80Zj^[
0P2XZ:P20:NWY`80YJFU0P2SXj<20::RXPT0XJ6Q102RXZ820:>SX`80Y:BT0P2UYJD20:JVYP80YjNW
0P2XZ:P20:ZZZP80Zj^[0P2/[:`20:j^[P80/;2`0P2b/[800`2d];@0]kNg0;Ng]`020;Vi^@80^k^k
0P2o_kl20<;2`P80a/K60P39bLT20<_;b`80c/k>0P3@d=020=;BdP80e=CD0P3EeMD40=OGe`<0fMWI
0P3GemL40=KFeP80emOG0P3Hf=P20=WIf@80fm_K1P3Lg=`20=_Kf`@0f][J0`3IfMT40=SHf080emOG
0P3Fe]H20=?Cd`80dM7A0P3>c/h20<_;b`80b<S80P36a/H20<;2`P80_kno0P2l_;`20;Vi^@80]KFe
00<0/K6a0:f][@2][Jd00P2ZZZX20:JVYP80XZ:R0P2OWil209^KV`80UiNG5@3oool001<0oooo0P2A
TI4208n?S`80SHf=0P2:RXX208V9R@80QhN70P25QHD208>3P`030820P01nOWh0OWin0080O7al0P1j
NWX207QhN080MWIf0P1dM7@2079bLP80L71`0P1^KVh206a/K080JVYZ0P1XJ6P206MWI`80IFEU0P1S
Hf<00`1QHF40H61P061PH00205iNGP80G5aL0P1JFUX205UIF@80F5QH0P1GEeL205UIF@80G5aL0P1P
H60206IVIP80K6a/0P1cLg<207]kN`80Ph>300<0S8b<09BDU02DU9@00P2NWYh20:NWY`80/k>c0P2`
/;020:j^[P80Zj^[0P2XZ:P20:NWY`80YJFU0P2SXj<20::RXPT0XJ6Q102RXZ820:>SX`80Y:BT0P2U
YJD20:JVYP80YjNW0P2XZ:P20:ZZZP80Zj^[0P2/[:`20:j^[P80/;2`0P2b/[800`2d];@0]kNg0;Ng
]`020;Vi^@80^k^k0P2o_kl20<;2`P80a/K60P39bLT20<_;b`80c/k>0P3@d=020=;BdP80e=CD0P3E
eMD40=OGe`<0fMWI0P3GemL40=KFeP80emOG0P3Hf=P20=WIf@80fm_K1P3Lg=`20=_Kf`@0f][J0`3I
fMT40=SHf080emOG0P3Fe]H20=?Cd`80dM7A0P3>c/h20<_;b`80b<S80P36a/H20<;2`P80_kno0P2l
_;`20;Vi^@80]KFe00<0/K6a0:f][@2][Jd00P2ZZZX20:JVYP80XZ:R0P2OWil209^KV`80UiNG5@3o
ool001<0oooo0P2ATI4208n?S`80SHf=0P2:RXX208R8R080QXJ60P24Q8@208:2PP030820P01nOWh0
OWin0080O7al0P1jNWX207QhN080MGEe0P1cLg<2075aL@80Kfm_0P1]KFd206][J`80JFUY0P1WIfL2
06IVIP80I6AT0P1RHV800`1PH600GUiN05iNGP0205eMG@80Fe]K0P1IFET205MGE`80EUIF0P1EEED2
05QHF080Fe]K0P1OGel206EUI@80Jf][0P1aLG4207UiN@80PH6100<0RHV909:BTP2BTY800P2LW9`2
0:JVYP80/;2`0P2][Jd20:^[Z`80Z:RX0P2VYZH20:BTY080XZ:R0P2QXJ420:2PX0T0WinO102PX:02
0:6QX@80XZ:R0P2SXj<20:FUY@80YZJV0P2WYjL20:RXZ080ZZZZ0P2[Zj/20:f][@80[jn_0P2a/K40
0`2c/k<0]KFe0;Fe]@020;Rh^080^[Zj0P2n_[h20<;2`P80aLG50P38b<P20<_;b`80c/k>0P3@d=02
0=?Cd`80e=CD0P3Fe]H20=OGe`80f=SH0`3Jf]X20=WIf@80emOG0P3Fe]H20=OGe`80fMWI0P3Jf]X2
0=cLg080gMgM103Ng]h20=gMg@80fm_K0P3Jf]X20=WIf@030=[JfP3IfMT0fMWI00H0f=SH0P3EeMD2
0=;BdP80clo?0P3<c<`20<W9b@80a/K60P33`l<20;no_`80_;bl0P2i^KT20;Fe]@030;6a/@2][Jd0
[Jf]0080ZZZZ0P2VYZH20::RXP80WinO0P2KVi/209NGUaD0oooo000C0?ooo`80TI6A0P2?Shl208b<
S080RXZ:0P28R8P208J6QP80Q8B40P22PX800`20P800OGem07emO@0207]kN`80NGUi0P1gMgL207Ee
M@80LW9b0P1`L70206i^KP80K6a/0P1ZJVX206QXJ080IVIV0P1UIFD2069RHP80HF5Q00<0GemO05eM
G@1MGEd00P1KFe/205UIF@80EeMG0P1EEED205ADE080EEEE0P1GEeL205YJFP80GUiN0P1TI6@206YZ
JP80L71`0P1hN7P20820P00308N7Q`2?Shl0Shn?0080VIVI0P2SXj<20:j^[P80ZZZZ0P2XZ:P20:FU
Y@80Xj>S0P2QXJ420:2PX080WYjN102MWId709bLW080WIfM0P2NWYh209nOW`80X:2P0P2QXJ420:>S
X`80Y:BT0P2UYJD20:JVYP80Z:RX0P2ZZZX20:b/[080[Zj^0P2`/;000`2b/[80];Bd0;Bd]0020;Jf
]P80^KVi0P2m_Kd20<30`080`l?30P36a/H20<[:bP80cLg=0P3@d=020=;BdP80e=CD0P3Fe]H20=SH
f080f][J0`3Kfm/20=[JfP80f=SH103GemL20=SHf080f][J0P3Lg=`20=gMg@80g]kN103Ogml20=kN
gP80g=cL0`3Kfm/20=[JfPH0fMWI0P3Fe]H20=CDe080d=3@0P3=cLd20<[:bP80alO70P33`l<20<30
`080_;bl0P2i^KT20;Fe]@030;6a/@2^[Zh0[Zj^0080ZZZZ0P2VYZH20::RXP80WinO0P2KVi/209NG
UaD0oooo000C0?ooo`80TI6A0P2?Shl208b<S080RXZ:0P28R8P208J6QP80Q8B40P22PX800`20P800
OGem07emO@0207]kN`80NGUi0P1gMgL207EeM@80LW9b0P1`L70206i^KP80K6a/0P1ZJVX206QXJ080
IVIV0P1UIFD2069RHP80HF5Q00<0GemO05eMG@1MGEd00P1KFe/205UIF@80EeMG0P1EEED205ADE080
EEEE0P1GEeL205YJFP80GUiN0P1TI6@206YZJP80L71`0P1hN7P20820P00308N7Q`2?Shl0Shn?0080
VIVI0P2SXj<20:j^[P80ZZZZ0P2XZ:P20:FUY@80Xj>S0P2QXJ420:2PX080WYjN102MWId709bLW080
WIfM0P2NWYh209nOW`80X:2P0P2QXJ420:>SX`80Y:BT0P2UYJD20:JVYP80Z:RX0P2ZZZX20:b/[080
[Zj^0P2`/;000`2b/[80];Bd0;Bd]0020;Jf]P80^KVi0P2m_Kd20<30`080`l?30P36a/H20<[:bP80
cLg=0P3@d=020=;BdP80e=CD0P3Fe]H20=SHf080f][J0`3Kfm/20=[JfP80f=SH103GemL20=SHf080
f][J0P3Lg=`20=gMg@80g]kN103Ogml20=kNgP80g=cL0`3Kfm/20=[JfPH0fMWI0P3Fe]H20=CDe080
d=3@0P3=cLd20<[:bP80alO70P33`l<20<30`080_;bl0P2i^KT20;Fe]@030;6a/@2^[Zh0[Zj^0080
ZZZZ0P2VYZH20::RXP80WinO0P2KVi/209NGUaD0oooo000C0?ooo`80TI6A0P2?Shl208b<S080RXZ:
0P28R8P208J6QP80Q8B40P21PH400`1oOgl0OGem07emO@0207]kN`80NGUi0P1fMWH207AdM080LW9b
0P1`L70206i^KP80Jf][0P1YJFT206MWI`80IFEU0P1SHf<2065QH@80GemO00<0GUiN05]KF`1KFe/0
0P1JFUX205QHF080EUIF0P1DE5@2059BDP80E5AD0P1GEeL205YJFP80GUiN0P1TI6@206UYJ@80Kfm_
0P1gMgL207emO@0308B4Q02=SHd0SHf=0080UiNG0P2PX:020:ZZZP80YjNW0P2UYJD20::RXP80X:2P
0P2NWYh209fMW@80Vi^K102JVYX209VIV@80V9RH0`2IVIT209ZJVP80Vi^K0P2LW9`209fMW@80WinO
0P2PX:020::RXP80Xj>S0P2UYJD20:JVYP80Z:RX0P2ZZZX20:b/[080[Zj^00<0/;2`0;>c/`2c/k<0
0P2e]KD20;Rh^080_;bl0P2n_[h20<71`@80aLG50P39bLT20<c<c080clo?0P3AdM420=CDe080e]KF
0P3Hf=P20=[JfP030=cLg03MgMd0gMgM0080g=cL0P3Jf]X20=WIf@@0f=SH0P3IfMT20=_Kf`80g]kN
1P3Ph>020=oOg`80g]kN1`3Lg=`20=_Kf`80f][J0P3GemL20=GEe@80d];B0P3>c/h20<[:bP80alO7
0P34a<@20<30`080_Kfm0P2i^KT20;Fe]@030;6a/@2^[Zh0[Zj^0080ZZZZ0P2VYZH20::RXP80WYjN
0P2KVi/209NGUaD0oooo000C0?ooo`80TI6A0P2?Shl208b<S080RXZ:0P28R8P208J6QP80Q8B40P21
PH400`1oOgl0OGem07emO@0207]kN`80NGUi0P1fMWH207AdM080LW9b0P1`L70206i^KP80Jf][0P1Y
JFT206MWI`80IFEU0P1SHf<2065QH@80GemO00<0GUiN05]KF`1KFe/00P1JFUX205QHF080EUIF0P1D
E5@2059BDP80E5AD0P1GEeL205YJFP80GUiN0P1TI6@206UYJ@80Kfm_0P1gMgL207emO@0308B4Q02=
SHd0SHf=0080UiNG0P2PX:020:ZZZP80YjNW0P2UYJD20::RXP80X:2P0P2NWYh209fMW@80Vi^K102J
VYX209VIV@80V9RH0`2IVIT209ZJVP80Vi^K0P2LW9`209fMW@80WinO0P2PX:020::RXP80Xj>S0P2U
YJD20:JVYP80Z:RX0P2ZZZX20:b/[080[Zj^00<0/;2`0;>c/`2c/k<00P2e]KD20;Rh^080_;bl0P2n
_[h20<71`@80aLG50P39bLT20<c<c080clo?0P3AdM420=CDe080e]KF0P3Hf=P20=[JfP030=cLg03M
gMd0gMgM0080g=cL0P3Jf]X20=WIf@@0f=SH0P3IfMT20=_Kf`80g]kN1P3Ph>020=oOg`80g]kN1`3L
g=`20=_Kf`80f][J0P3GemL20=GEe@80d];B0P3>c/h20<[:bP80alO70P34a<@20<30`080_Kfm0P2i
^KT20;Fe]@030;6a/@2^[Zh0[Zj^0080ZZZZ0P2VYZH20::RXP80WYjN0P2KVi/209NGUaD0oooo000C
0?ooo`80TI6A0P2?Shl208b<S080RXZ:0P28R8P208F5Q@80Ph>30P21PH400`1oOgl0O7al07alO002
07YjNP80N7Qh0P1fMWH207=cL`80LG5a0P1_Kfl206e]K@80Jf][0P1YJFT206MWI`80IFEU0P1RHV82
061PH080GUiN00<0G5aL05YJFP1JFUX00P1HF5P205IFEP80E5AD0P1BDU82055AD@80De=C0P1EEED2
05UIF@80GEeM0P1SHf<206QXJ080KVi^0P1eMGD207]kN`0308:2PP2<S8`0S8b<0080UIFE0P2MWId2
0:NWY`80Xj>S0P2RXZ8209nOW`80WIfM0P2KVi/209VIV@80V9RH0P2GUiL409JFUP<0UIFE102FUYH2
09NGU`80V9RH0P2JVYX209bLW080WYjN0P2PX:020:6QX@80Xj>S0P2TY:@20:JVYP80Z:RX0P2ZZZX2
0:b/[0030:n_[`2a/K40/K6a0080/k>c0P2f][H20;Zj^P80_Kfm0P30`<020<C4a080alO70P3:b/X2
0<g=c@80d=3@0P3De=@20=KFeP80f=SH0P3Jf]X00`3Kfm/0gMgM0=gMg@020=gMg@80g=cL0P3Jf]X2
0=SHf080emOG0P3Hf=P20=_Kf`80gMgM0P3Ph>060>7Qh@80gmoO1`3Ng]h20=gMg@80fm_K0P3Hf=P2
0=KFeP80d];B0P3?cll20<c<c080b<S80P34a<@20<30`080_Kfm0P2i^KT20;Fe]@030;:b/P2^[Zh0
[Zj^0080ZZZZ0P2VYZH20::RXP80WinO0P2KVi/209NGUaD0oooo000C0?ooo`80TI6A0P2?Shl208b<
S080RXZ:0P28R8P208F5Q@80Ph>30P21PH400`1oOgl0O7al07alO00207YjNP80N7Qh0P1fMWH207=c
L`80LG5a0P1_Kfl206e]K@80Jf][0P1YJFT206MWI`80IFEU0P1RHV82061PH080GUiN00<0G5aL05YJ
FP1JFUX00P1HF5P205IFEP80E5AD0P1BDU82055AD@80De=C0P1EEED205UIF@80GEeM0P1SHf<206QX
J080KVi^0P1eMGD207]kN`0308:2PP2<S8`0S8b<0080UIFE0P2MWId20:NWY`80Xj>S0P2RXZ8209nO
W`80WIfM0P2KVi/209VIV@80V9RH0P2GUiL409JFUP<0UIFE102FUYH209NGU`80V9RH0P2JVYX209bL
W080WYjN0P2PX:020:6QX@80Xj>S0P2TY:@20:JVYP80Z:RX0P2ZZZX20:b/[0030:n_[`2a/K40/K6a
0080/k>c0P2f][H20;Zj^P80_Kfm0P30`<020<C4a080alO70P3:b/X20<g=c@80d=3@0P3De=@20=KF
eP80f=SH0P3Jf]X00`3Kfm/0gMgM0=gMg@020=gMg@80g=cL0P3Jf]X20=SHf080emOG0P3Hf=P20=_K
f`80gMgM0P3Ph>060>7Qh@80gmoO1`3Ng]h20=gMg@80fm_K0P3Hf=P20=KFeP80d];B0P3?cll20<c<
c080b<S80P34a<@20<30`080_Kfm0P2i^KT20;Fe]@030;:b/P2^[Zh0[Zj^0080ZZZZ0P2VYZH20::R
XP80WinO0P2KVi/209NGUaD0oooo000C0?ooo`80TI6A0P2?Shl208b<S080RXZ:0P27QhL208F5Q@80
Ph>30P21PH400`1nOWh0O7al07alO00207UiN@80MgMg0P1eMGD207=cL`80L71`0P1^KVh206a/K080
JVYZ0P1WIfL206EUI@80Hf=S0P1QHF4205mOG`80GEeM00<0Fe]K05UIF@1IFET00P1GEeL205EEE@80
De=C101ADE42059BDP80EEEE0P1HF5P205eMG@80Hf=S0P1WIfL206e]K@80Lg=c0P1jNWX00`20P800
RHV908V9R@0209:BTP80VYZJ0P2SXj<20:2PX080WIfM0P2KVi/209VIV@80UiNG0P2EUID209BDU080
Ti>C0P2BTY87096AT@80TY:B0P2CTi<209BDU080UYJF0P2GUiL209ZJVP80W9bL0P2NWYh20:2PX080
XJ6Q0P2SXj<20:FUY@80YjNW0P2ZZZX00`2/[:`0[jn_0:n_[`020;6a/@80];Bd0P2f][H20;Zj^P80
_[jn0P32`/820<G5a@80bLW90P3<c<`20=3@d080e=CD0P3Hf=P20=WIf@80f][J00<0fm_K0=gMg@3M
gMd0103Ng]h20=gMg@80fm_K0P3IfMT20=OGe`80fMWI0P3MgMd20=oOg`80hN7Q103Rh^820>7Qh@80
h>3P1`3Ogml20=cLg080fMWI0P3Fe]H20=?Cd`80clo?0P3<c<`20<S8b080aLG50P31`L420;fm_@80
^[Zj0P2f][H00`2b/[80[Zj^0:j^[P020:ZZZP80YZJV0P2RXZ8209nOW`80Vi^K0P2GUiLE0?ooo`00
4`3oool2096AT@80Shn?0P2<S8`208Z:RP80QhN70P25QHD208>3P`80PH6100<0OWin07alO01lO7`0
0P1iNGT207MgM`80MGEe0P1cLg<2071`L080KVi^0P1/K6`206YZJP80IfMW0P1UIFD206=SH`80HF5Q
0P1OGel205eMG@0305]KF`1IFET0FEUI0080EeMG0P1EEED205=CD`@0DE5A0P1BDU8205EEE@80F5QH
0P1MGEd206=SH`80IfMW0P1]KFd207=cL`80NWYj00<0P82008V9R@29RHT00P2BTY8209ZJVP80Xj>S
0P2PX:0209fMW@80Vi^K0P2IVIT209NGU`80UIFE0P2DU9@209>CT`80TY:B1`2ATI4209:BTP80Ti>C
0P2DU9@209JFUP80UiNG0P2JVYX209bLW080WYjN0P2PX:020:6QX@80Xj>S0P2UYJD20:NWY`80ZZZZ
00<0[:b/0:n_[`2_[jl00P2a/K420;Bd]080][Jf0P2j^[X20;jn_P80`/;20P35aLD20<W9b@80c<c<
0P3@d=020=CDe080f=SH0P3IfMT20=[JfP030=_Kf`3MgMd0gMgM00@0g]kN0P3MgMd20=_Kf`80fMWI
0P3GemL20=WIf@80gMgM0P3Ogml20>7Qh@@0h^;R0P3QhN420>3Ph0L0gmoO0P3Lg=`20=WIf@80e]KF
0P3Cdm<20<o?c`80c<c<0P38b<P20<G5a@80`L710P2m_Kd20;Zj^P80][Jf00<0/[:b0:j^[P2^[Zh0
0P2ZZZX20:JVYP80XZ:R0P2OWil209^KV`80UiNG5@3oool001<0oooo0P2ATI4208j>SP80S8b<0P29
RHT208N7Q`80QHF50P22PX820820P00307inOP1kNg/0Ng]k0080NGUi0P1fMWH207AdM080LW9b0P1`
L70206e]K@80Jf][0P1YJFT206IVIP80IFEU0P1RHV82061PH080GUiN0P1LG5`00`1JFUX0EeMG05MG
E`0205EEE@80De=C0P1ADE44051@D080DU9B0P1EEED205QHF080G5aL0P1RHV8206MWI`80KFe]0P1a
LG4207QhN00307inOP26QXH0QXJ60080SXj>0P2FUYH209nOW`80Vi^K0P2IVIT209NGU`80U9BD0P2B
TY82096AT@80Shn?0P2>SXh608f=S@<0S8b<0P2=SHd208n?S`80T92@0P2BTY8209>CT`80UIFE0P2H
V9P209ZJVP80W9bL0P2NWYh20:2PX080XZ:R0P2TY:@20:NWY`030:VYZ@2/[:`0[:b/0080[jn_0P2b
/[820;>c/`80]kNg0P2l_;`20<30`080`l?30P38b<P20<c<c080clo?0P3Cdm<20=OGe`80fMWI0P3J
f]X00`3Lg=`0gMgM0=gMg@020=oOg`80h>3P0P3Ogml20=cLg080fm_K0P3IfMT20=[JfP80g=cL0P3N
g]h20>7Qh@80h^;R0P3Shn<20>;RhP80hN7Q00<0h>3P0>7Qh@3QhN400P3Ph>020=oOg`80gMgM0P3J
f]X20=OGe`80e=CD0P3@d=020<c<c080bLW90P35aLD20<71`@80_Kfm0P2j^[X20;Jf]P030;:b/P2^
[Zh0[Zj^0080ZZZZ0P2VYZH20::RXP80WinO0P2KVi/209NGUaD0oooo000C0?ooo`80TI6A0P2>SXh2
08b<S080RHV90P27QhL208F5Q@80PX:20P20P8000`1nOWh0Ng]k07]kN`0207UiN@80MWIf0P1dM7@2
079bLP80L71`0P1]KFd206][J`80JFUY0P1VIVH206EUI@80HV9R0P1PH60205iNGP80G5aL00<0FUYJ
05MGE`1GEeL00P1EEED205=CD`80DE5A101@D502059BDP80EEEE0P1HF5P205aLG080HV9R0P1WIfL2
06e]K@80LG5a0P1hN7P00`1nOWh0QXJ608J6QP0208j>SP80UYJF0P2OWil209^KV`80VIVI0P2GUiL2
09BDU080TY:B0P2ATI4208n?S`80SXj>1P2=SHd308b<S080SHf=0P2?Shl2092@T080TY:B0P2CTi<2
09FEU@80V9RH0P2JVYX209bLW080WYjN0P2PX:020::RXP80Y:BT0P2WYjL00`2YZJT0[:b/0:b/[002
0:n_[`80/[:b0P2c/k<20;Ng]`80_;bl0P30`<020<?3``80b<S80P3<c<`20<o?c`80dm?C0P3GemL2
0=WIf@80f][J00<0g=cL0=gMg@3MgMd00P3Ogml20>3Ph080gmoO0P3Lg=`20=_Kf`80fMWI0P3Jf]X2
0=cLg080g]kN0P3QhN420>;RhP80hn?S0P3Rh^820>7Qh@030>3Ph03QhN40hN7Q0080h>3P0P3Ogml2
0=gMg@80f][J0P3GemL20=CDe080d=3@0P3<c<`20<W9b@80aLG50P31`L420;fm_@80^[Zj0P2f][H0
0`2b/[80[Zj^0:j^[P020:ZZZP80YZJV0P2RXZ8209nOW`80Vi^K0P2GUiLE0?ooo`004`3oool2096A
T@80SXj>0P2<S8`208V9R@80QhN70P24Q8@208:2PP80P82000<0OGem07]kN`1kNg/00P1hN7P207If
MP80Lg=c0P1aLG4206i^KP80K6a/0P1ZJVX206QXJ080IVIV0P1TI6@2065QH@80GemO0P1LG5`205YJ
FP0305QHF01FEUH0EUIF0080E5AD0P1BDU82051@D080Cdm?0P1@D502055AD@80EEEE0P1HF5P205aL
G080HF5Q0P1VIVH206][J`80L71`0P1fMWH00`1lO7`0Ph>308>3P`0208Z:RP80TY:B0P2JVYX209JF
UP80U9BD0P2ATI4208n?S`80SHf=0P2<S8`208^;R`80RXZ:0P29RHT408R8R0<0QhN70P28R8P208V9
R@80RXZ:0P2<S8`208j>SP80T92@0P2CTi<209FEU@80V9RH0P2JVYX209bLW080WinO0P2QXJ420:>S
X`030:JVYP2YZJT0ZJVY0080[:b/0P2`/;020;6a/@80]KFe0P2j^[X20;fm_@80`L710P36a/H20<[:
bP80c/k>0P3AdM420=KFeP@0fMWI00<0fm_K0=gMg@3MgMd00P3Ogml20>7Qh@80h>3P0P3Ng]h20=cL
g0@0fm_K0P3MgMd20=oOg`80h^;R103Shn<40>;RhPD0hN7Q0P3Ph>020=kNgP80f][J0P3GemL20=CD
e080d=3@0P3=cLd20<W9b@80aLG50P31`L420;fm_@80^[Zj0P2f][H00`2b/[80[Zj^0:j^[P020:ZZ
ZP80YZJV0P2SXj<209nOW`80Vi^K0P2GUiLE0?ooo`004`3oool2096AT@80SXj>0P2<S8`208V9R@80
QhN70P24Q8@208:2PP80P82000<0OGem07]kN`1kNg/00P1hN7P207IfMP80Lg=c0P1aLG4206i^KP80
K6a/0P1ZJVX206QXJ080IVIV0P1TI6@2065QH@80GemO0P1LG5`205YJFP0305QHF01FEUH0EUIF0080
E5AD0P1BDU82051@D080Cdm?0P1@D502055AD@80EEEE0P1HF5P205aLG080HF5Q0P1VIVH206][J`80
L71`0P1fMWH00`1lO7`0Ph>308>3P`0208Z:RP80TY:B0P2JVYX209JFUP80U9BD0P2ATI4208n?S`80
SHf=0P2<S8`208^;R`80RXZ:0P29RHT408R8R0<0QhN70P28R8P208V9R@80RXZ:0P2<S8`208j>SP80
T92@0P2CTi<209FEU@80V9RH0P2JVYX209bLW080WinO0P2QXJ420:>SX`030:JVYP2YZJT0ZJVY0080
[:b/0P2`/;020;6a/@80]KFe0P2j^[X20;fm_@80`L710P36a/H20<[:bP80c/k>0P3AdM420=KFeP@0
fMWI00<0fm_K0=gMg@3MgMd00P3Ogml20>7Qh@80h>3P0P3Ng]h20=cLg0@0fm_K0P3MgMd20=oOg`80
h^;R103Shn<40>;RhPD0hN7Q0P3Ph>020=kNgP80f][J0P3GemL20=CDe080d=3@0P3=cLd20<W9b@80
aLG50P31`L420;fm_@80^[Zj0P2f][H00`2b/[80[Zj^0:j^[P020:ZZZP80YZJV0P2SXj<209nOW`80
Vi^K0P2GUiLE0?ooo`004`3oool2096AT@80SXj>0P2<S8`208V9R@80QhN70P24Q8@20861P@80Ogmo
00<0O7al07YjNP1jNWX00P1hN7P207EeM@80Lg=c0P1`L70206i^KP80Jf][0P1YJFT206MWI`80I6AT
0P1RHV82061PH080GUiN0P1KFe/205UIF@0305MGE`1EEED0EEEE0080De=C0P1@D50404i>CP80Cdm?
0P1ADE4205EEE@80F5QH0P1LG5`2065QH@80I6AT0P1ZJVX206i^KP80MGEe00<0NWYj0820P020P800
0P27QhL208f=S@80Ti>C0P2ATI4208j>SP80S8b<0P2:RXX208V9R@80QhN71026QXH208F5Q@@0Q8B4
00<0Ph>308:2PP22PX801022PX8208B4Q080QXJ60P28R8P208^;R`80SHf=0P2@T90209>CT`80UIFE
0P2HV9P209ZJVP80WIfM0P2OWil00`2RXZ80YZJV0:JVYP020:ZZZP80[Jf]0P2^[Zh20;:b/P80]kNg
0P2j^[X20;jn_P80`l?30P38b<P20<g=c@80d=3@0P3EeMD20=SHf080fMWI00<0fm_K0=gMg@3MgMd0
0P3Ogml40>;RhP80h>3P0P3MgMd40=_Kf`80gMgM0P3Ogml20>;RhP80iNGU0P3Ti>@70>?Sh`80h^;R
0P3QhN420=kNgP80fm_K0P3GemL20=CDe080dM7A0P3=cLd20<W9b@80aLG50P32`/820;jn_P80^[Zj
0P2f][H00`2b/[80[jn_0:n_[`020:^[Z`80YjNW0P2SXj<209nOW`80Vi^K0P2GUiLE0?ooo`004`3o
ool2096AT@80SXj>0P2<S8`208V9R@80QhN70P24Q8@20861P@80Ogmo00<0O7al07YjNP1jNWX00P1h
N7P207EeM@80Lg=c0P1`L70206i^KP80Jf][0P1YJFT206MWI`80I6AT0P1RHV82061PH080GUiN0P1K
Fe/205UIF@0305MGE`1EEED0EEEE0080De=C0P1@D50404i>CP80Cdm?0P1ADE4205EEE@80F5QH0P1L
G5`2065QH@80I6AT0P1ZJVX206i^KP80MGEe00<0NWYj0820P020P8000P27QhL208f=S@80Ti>C0P2A
TI4208j>SP80S8b<0P2:RXX208V9R@80QhN71026QXH208F5Q@@0Q8B400<0Ph>308:2PP22PX801022
PX8208B4Q080QXJ60P28R8P208^;R`80SHf=0P2@T90209>CT`80UIFE0P2HV9P209ZJVP80WIfM0P2O
Wil00`2RXZ80YZJV0:JVYP020:ZZZP80[Jf]0P2^[Zh20;:b/P80]kNg0P2j^[X20;jn_P80`l?30P38
b<P20<g=c@80d=3@0P3EeMD20=SHf080fMWI00<0fm_K0=gMg@3MgMd00P3Ogml40>;RhP80h>3P0P3M
gMd40=_Kf`80gMgM0P3Ogml20>;RhP80iNGU0P3Ti>@70>?Sh`80h^;R0P3QhN420=kNgP80fm_K0P3G
emL20=CDe080dM7A0P3=cLd20<W9b@80aLG50P32`/820;jn_P80^[Zj0P2f][H00`2b/[80[jn_0:n_
[`020:^[Z`80YjNW0P2SXj<209nOW`80Vi^K0P2GUiLE0?ooo`004`3oool2096AT@80SXj>0P2<S8`2
08V9R@80QXJ60P24Q8@20861P@80Ogmo00<0O7al07UiN@1iNGT00P1gMgL207AdM080LW9b0P1_Kfl2
06e]K@80JVYZ0P1XJ6P206IVIP80Hf=S0P1QHF4205mOG`80GEeM0P1JFUX205QHF00305IFEP1DE5@0
E5AD0080DE5A0P1?Cdl404i>CP80Cdm?0P1ADE4205EEE@80F5QH0P1MGEd2065QH@80I6AT0P1YJFT2
06e]K@80M7Ad00<0N7Qh07emO@1mOGd00P23Ph<208V9R@80S8b<0P2;Rh/208Z:RP80R8R80P27QhL2
08J6QP80QHF50P24Q8@208>3P`80PX:21021PH400`20P800Ogmo07moO`0207moO`@0OWin0P1oOgl2
0861P@80Q8B40P27QhL208V9R@80S8b<0P2?Shl209:BTP80UYJF0P2HV9P209^KV`0309jNWP2RXZ80
XZ:R0080YZJV0P2[Zj/20:b/[080[jn_0P2c/k<20;Fe]@80^[Zj0P30`<020<K6aP80c<c<0P3>c/h2
0=CDe080emOG0P3IfMT00`3Jf]X0g=cL0=cLg0020=oOg`80h^;R0P3Shn<20>;RhP80gmoO0P3MgMd2
0=cLg080gMgM0P3Ogml20>;RhP80iNGU0P3Vi^H50>GUi@@0i>CT0P3Shn<20=oOg`80g=cL0P3IfMT2
0=GEe@80dM7A0P3=cLd20<[:bP80a/K60P32`/820;jn_P80^[Zj0P2f][H00`2c/k<0[jn_0:n_[`02
0:^[Z`80YjNW0P2SXj<209nOW`80Vi^K0P2GUiLE0?ooo`004`3oool2096AT@80SXj>0P2<S8`208V9
R@80QXJ60P24Q8@20861P@80Ogmo00<0O7al07UiN@1iNGT00P1gMgL207AdM080LW9b0P1_Kfl206e]
K@80JVYZ0P1XJ6P206IVIP80Hf=S0P1QHF4205mOG`80GEeM0P1JFUX205QHF00305IFEP1DE5@0E5AD
0080DE5A0P1?Cdl404i>CP80Cdm?0P1ADE4205EEE@80F5QH0P1MGEd2065QH@80I6AT0P1YJFT206e]
K@80M7Ad00<0N7Qh07emO@1mOGd00P23Ph<208V9R@80S8b<0P2;Rh/208Z:RP80R8R80P27QhL208J6
QP80QHF50P24Q8@208>3P`80PX:21021PH400`20P800Ogmo07moO`0207moO`@0OWin0P1oOgl20861
P@80Q8B40P27QhL208V9R@80S8b<0P2?Shl209:BTP80UYJF0P2HV9P209^KV`0309jNWP2RXZ80XZ:R
0080YZJV0P2[Zj/20:b/[080[jn_0P2c/k<20;Fe]@80^[Zj0P30`<020<K6aP80c<c<0P3>c/h20=CD
e080emOG0P3IfMT00`3Jf]X0g=cL0=cLg0020=oOg`80h^;R0P3Shn<20>;RhP80gmoO0P3MgMd20=cL
g080gMgM0P3Ogml20>;RhP80iNGU0P3Vi^H50>GUi@@0i>CT0P3Shn<20=oOg`80g=cL0P3IfMT20=GE
e@80dM7A0P3=cLd20<[:bP80a/K60P32`/820;jn_P80^[Zj0P2f][H00`2c/k<0[jn_0:n_[`020:^[
Z`80YjNW0P2SXj<209nOW`80Vi^K0P2GUiLE0?ooo`004`3oool2096AT@80SXj>0P2;Rh/208V9R@80
QXJ60P23Ph<20861P@80OWin00<0O7al07UiN@1iNGT00P1fMWH207AdM080LG5a0P1_Kfl206a/K080
JVYZ0P1WIfL206EUI@80HV9R0P1PH60205iNGP80Fe]K0P1IFET205MGE`0305ADE01BDU80DU9B0080
D51@101=CDd204i>CP80Cdm?0P1BDU8205EEE@80F5QH0P1LG5`2061PH080IFEU0P1XJ6P206e]K@80
Lg=c00<0MgMg07]kN`1kNg/00P1oOgl208>3P`P0QXJ60P25QHD208B4Q080Ph>30P22PX820861P@80
P820101oOgl00`1nOWh0OGem07emO@0407alO0H0Ng]k0P1mOGd207moO`80Ph>30P26QXH208Z:RP80
SHf=0P2@T90209BDU080UiNG00<0VYZJ09jNWP2NWYh00P2SXj<20:VYZ@80[:b/0P2][Jd40;6a/@80
]kNg0P2m_Kd20<G5a@80bl_;0P3=cLd20=7Ad@80e]KF0P3Hf=P00`3IfMT0g=cL0=cLg0020=kNgP80
hN7Q103Shn<20>7Qh@80gmoO103MgMd20>3Ph080hn?S0P3Vi^H40>OWi`<0i^KV103UiND20>?Sh`80
h>3P0P3MgMd20=WIf@80eMGE0P3Bd]820<g=c@80b/[:0P36a/H20<;2`P80_[jn0P2j^[X20;Jf]P03
0;>c/`2_[jl0[jn_0080Zj^[0P2WYjL20:>SX`80WinO0P2KVi/209NGUaD0oooo000C0?ooo`80TI6A
0P2>SXh208^;R`80RHV90P26QXH208>3P`80PH610P1nOWh00`1lO7`0NGUi07UiN@0207IfMP80M7Ad
0P1aLG4206m_K`80K6a/0P1ZJVX206MWI`80IFEU0P1RHV82061PH080GUiN0P1KFe/205UIF@80EeMG
00<0E5AD059BDP1BDU800P1@D50404e=C@80CTi>0P1?Cdl2059BDP80EEEE0P1HF5P205aLG080H61P
0P1UIFD206QXJ080KFe]0P1cLg<00`1gMgL0Ng]k07]kN`0207moO`80Ph>32026QXH208F5Q@80Q8B4
0P23Ph<208:2PP80PH610P20P80407moO`0307inOP1mOGd0OGem00@0O7al1P1kNg/207emO@80Ogmo
0P23Ph<208J6QP80RXZ:0P2=SHd2092@T080U9BD0P2GUiL00`2JVYX0WYjN09jNWP020:>SX`80ZJVY
0P2/[:`20:f][@@0/K6a0P2g]kL20;fm_@80aLG50P3;bl/20<g=c@80dM7A0P3Fe]H20=SHf0030=WI
f@3Lg=`0g=cL0080g]kN0P3QhN440>?Sh`80hN7Q0P3Ogml40=gMg@80h>3P0P3Shn<20>KViP@0inOW
0`3Vi^H40>GUi@80hn?S0P3Ph>020=gMg@80fMWI0P3EeMD20=;BdP80cLg=0P3:b/X20<K6aP80`/;2
0P2n_[h20;Zj^P80][Jf00<0/k>c0:n_[`2_[jl00P2[Zj/20:NWY`80Xj>S0P2OWil209^KV`80UiNG
5@3oool001<0oooo0P2ATI4208j>SP80Rh^;0P28R8P208F5Q@80Ph>30P20P80207emO@0307]kN`1h
N7P0N7Qh0080MWIf0P1cLg<2071`L080KVi^0P1[Jf/206UYJ@80IVIV0P1TI6@2065QH@80GemO0P1M
GEd205YJFP80EeMG0P1EEED00`1CDe<0DE5A055AD@0204m?C`80CDe=0P1<C4`204i>CP80Cdm?0P1B
DU8205IFEP80FUYJ0P1MGEd2065QH@80IFEU0P1XJ6P206i^KP80LW9b00<0MWIf07UiN@1iNGT00P1k
Ng/207moO`80PX:22023Ph<208:2PP@0PH611020P80207moO`80OWin00<0OGem07alO01lO7`0101j
NWX407UiN@@0N7Qh0P1iNGT207]kN`80Ogmo0P23Ph<208N7Q`80RXZ:0P2>SXh209:BTP0309JFUP2J
VYX0VYZJ0080WinO0P2UYJD40:^[Z`80/;2`0P2^[Zh20;:b/P80^KVi0P30`<020<W9b@80cLg=0P3>
c/h20=CDe080emOG00<0f=SH0=cLg03Lg=`00P3Ng]h20>7Qh@H0i>CT0P3QhN420=kNgP80gMgM0P3P
h>020>CTi080i^KV0P3WinL40>SXj0D0inOW0P3Ti>@20>3Ph080gMgM0P3IfMT20=KFeP80d];B0P3>
c/h20<[:bP80a/K60P32`/820;jn_P80^[Zj0P2f][H00`2b/[80[jn_0:n_[`020:^[Z`80YjNW0P2S
Xj<209nOW`80Vi^K0P2GUiLE0?ooo`004`3oool2096AT@80SXj>0P2;Rh/208R8R080QHF50P23Ph<2
0820P080OGem00<0Ng]k07QhN01hN7P00P1fMWH207=cL`80L71`0P1^KVh206][J`80JFUY0P1VIVH2
06ATI080HF5Q0P1OGel205eMG@80FUYJ0P1GEeL205EEE@0305=CD`1ADE40DE5A0080Cdm?0P1=CDd2
04a<C080CTi>0P1?Cdl2059BDP80EUIF0P1JFUX205eMG@80HF5Q0P1UIFD206QXJ080KVi^0P1bLW80
0`1fMWH0NGUi07UiN@0207]kN`80Ogmo0P22PX8808>3P`80PX:21021PH440820P080Ogmo0P1nOWh0
0`1mOGd0O7al07alO00407YjNP@0NGUi101hN7P207UiN@80Ng]k0P1oOgl208>3P`80QhN70P2:RXX2
08j>SP80TY:B00<0UYJF09ZJVP2JVYX00P2OWil20:FUY@@0Zj^[0P2`/;020:j^[P80/[:b0P2i^KT2
0<30`080bLW90P3=cLd20<k>cP80e=CD0P3GemL00`3Hf=P0g=cL0=cLg0020=kNgP80hN7Q1P3Ti>@2
0>7Qh@80g]kN0P3MgMd20>3Ph080i>CT0P3Vi^H20>OWi`@0j>SX1@3WinL20>CTi080h>3P0P3MgMd2
0=WIf@80e]KF0P3Bd]820<k>cP80b/[:0P36a/H20<;2`P80_[jn0P2j^[X20;Jf]P030;:b/P2_[jl0
[jn_0080Zj^[0P2WYjL20:>SX`80WinO0P2KVi/209NGUaD0oooo000C0?ooo`80TI6A0P2>SXh208^;
R`80R8R80P25QHD208>3P`80P8200P1mOGd00`1jNWX0MgMg07MgM`0207EeM@80LW9b0P1_Kfl206e]
K@80JVYZ0P1XJ6P206EUI@80Hf=S0P1PH60205iNGP80Fe]K0P1IFET205MGE`80E5AD00<0DU9B051@
D01@D5000P1>CTh204e=C@80C4a<0P1>CTh2051@D080DU9B0P1FEUH205YJFP80GUiN0P1QHF4206AT
I080JFUY0P1^KVh2079bLP0307IfMP1jNWX0NWYj0080Ng]k0P1mOGd207moO`80P8202021PH440820
P0@0Ogmo101nOWh00`1mOGd0Ng]k07]kN`0207YjNP80NGUi0P1hN7P207MgM`80MWIf101eMGD207If
MP80N7Qh0P1kNg/20820P080Q8B40P28R8P208b<S003096AT@2FUYH0UYJF0080Vi^K0P2RXZ820:ZZ
ZP80ZJVY102][Jd20:n_[`80][Jf0P2m_Kd20<G5a@80b/[:0P3<c<`20=7Ad@80eMGE00<0f=SH0=_K
f`3Kfm/00P3Ogml20>7Qh@80i>CT103UiND20>CTi080h>3P0P3Ng]h20>3Ph080i>CT0P3WinL20>WY
j@80j^[Z0P3YjNT50>SXj080iNGU0P3QhN420=gMg@80f][J0P3Fe]H20=;BdP80c/k>0P3:b/X20<K6
aP80`/;20P2n_[h20;Zj^P80]kNg00<0/k>c0:n_[`2_[jl00P2[Zj/20:NWY`80Xj>S0P2OWil209^K
V`80V9RH5@3oool001<0oooo0P2ATI4208j>SP80Rh^;0P28R8P208F5Q@80Ph>30P20P80207emO@03
07YjNP1gMgL0MgMg0080MGEe0P1bLW8206m_K`80KFe]0P1ZJVX206QXJ080IFEU0P1SHf<2061PH080
GUiN0P1KFe/205UIF@80EeMG0P1DE5@00`1BDU80D51@051@D00204i>CP80CDe=0P1<C4`204i>CP80
D51@0P1BDU8205IFEP80FUYJ0P1NGUh2065QH@80I6AT0P1YJFT206i^KP80LW9b00<0MWIf07YjNP1j
NWX00P1kNg/207emO@80Ogmo0P20P8080861P@@0P820101oOgl407inOP0307emO@1kNg/0Ng]k0080
NWYj0P1iNGT207QhN080MgMg0P1fMWH407EeM@80MWIf0P1hN7P207]kN`80P8200P24Q8@208R8R080
S8b<00<0TI6A09JFUP2FUYH00P2KVi/20::RXP80ZZZZ0P2YZJT40:f][@80[jn_0P2f][H20;fm_@80
aLG50P3:b/X20<c<c080dM7A0P3EeMD00`3Hf=P0fm_K0=_Kf`020=oOg`80hN7Q0P3Ti>@40>GUi@80
i>CT0P3Ph>020=kNgP80h>3P0P3Ti>@20>OWi`80jNWY0P3Zj^X20>WYj@D0j>SX0P3UiND20>7Qh@80
gMgM0P3Jf]X20=KFeP80d];B0P3>c/h20<[:bP80a/K60P32`/820;jn_P80^[Zj0P2g]kL00`2c/k<0
[jn_0:n_[`020:^[Z`80YjNW0P2SXj<209nOW`80Vi^K0P2HV9PE0?ooo`004`3oool2096AT@80SXj>
0P2;Rh/208R8R080QHF50P22PX8207moO`80O7al00<0NWYj07MgM`1gMgL00P1dM7@2075aL@80KVi^
0P1/K6`206UYJ@80IfMW0P1TI6@2069RHP80GemO0P1MGEd205YJFP80F5QH0P1FEUH205=CD`03055A
D@1?Cdl0Cdm?0080CDe=101<C4`204i>CP80D51@0P1CDe<205MGE`80Fe]K0P1OGel2069RHP80IFEU
0P1ZJVX206i^KP80LG5a00<0MGEe07MgM`1gMgL00P1iNGT207YjNP80O7al0P1nOWh407moO`P0P820
1P1oOgl207inOP0307emO@1kNg/0Ng]k0080NWYj0P1iNGT207MgM`80MWIf0P1eMGD207AdM080Lg=c
0P1bLW8207=cL`80M7Ad0P1hN7P207emO@80PH610P26QXH00`2<S8`0TI6A096AT@0209RHV080WinO
0P2YZJT40:^[Z`80[Zj^0P2][Jd20;:b/P80^KVi0P32`/820<S8b080cLg=0P3@d=020=CDe0030=OG
e`3Jf]X0f][J0080g]kN0P3QhN420>CTi0H0i^KV0P3Rh^820=oOg`80h>3P0P3Ti>@20>OWi`80jNWY
0P3[jn/20>c/k0030>[ZjP3YjNT0jNWY0080j>SX0P3UiND20>;RhP80g]kN0P3Jf]X20=OGe`80d];B
0P3>c/h20<[:bP80a/K60P32`/820;jn_P80^k^k0P2g]kL00`2c/k<0[jn_0:n_[`020:^[Z`80YjNW
0P2SXj<209nOW`80Vi^K0P2GUiLE0?ooo`004`3oool2096AT@80SXj>0P2;Rh/208R8R080QHF50P22
PX8207moO`80O7al00<0NWYj07MgM`1gMgL00P1dM7@2075aL@80KVi^0P1/K6`206UYJ@80IfMW0P1T
I6@2069RHP80GemO0P1MGEd205YJFP80F5QH0P1FEUH205=CD`03055AD@1?Cdl0Cdm?0080CDe=101<
C4`204i>CP80D51@0P1CDe<205MGE`80Fe]K0P1OGel2069RHP80IFEU0P1ZJVX206i^KP80LG5a00<0
MGEe07MgM`1gMgL00P1iNGT207YjNP80O7al0P1nOWh407moO`P0P8201P1oOgl207inOP0307emO@1k
Ng/0Ng]k0080NWYj0P1iNGT207MgM`80MWIf0P1eMGD207AdM080Lg=c0P1bLW8207=cL`80M7Ad0P1h
N7P207emO@80PH610P26QXH00`2<S8`0TI6A096AT@0209RHV080WinO0P2YZJT40:^[Z`80[Zj^0P2]
[Jd20;:b/P80^KVi0P32`/820<S8b080cLg=0P3@d=020=CDe0030=OGe`3Jf]X0f][J0080g]kN0P3Q
hN420>CTi0H0i^KV0P3Rh^820=oOg`80h>3P0P3Ti>@20>OWi`80jNWY0P3[jn/20>c/k0030>[ZjP3Y
jNT0jNWY0080j>SX0P3UiND20>;RhP80g]kN0P3Jf]X20=OGe`80d];B0P3>c/h20<[:bP80a/K60P32
`/820;jn_P80^k^k0P2g]kL00`2c/k<0[jn_0:n_[`020:^[Z`80YjNW0P2SXj<209nOW`80Vi^K0P2G
UiLE0?ooo`004`3oool2092@T080SXj>0P2:RXX208R8R080QHF50P22PX8207inOP80O7al00<0NGUi
07IfMP1fMWH00P1cLg<2071`L080KFe]0P1[Jf/206QXJ080IVIV0P1SHf<2061PH080GUiN0P1LG5`2
05UIF@80EUIF0P1DE5@2059BDP03051@D01>CTh0CTi>0080CDe=0P1;Bd/204e=C@80Cdm?0P1BDU82
05ADE080EeMG0P1LG5`205mOG`80Hf=S0P1VIVH206][J`80KVi^0P1aLG400`1cLg<0MGEe07EeM@02
07MgM`80N7Qh0P1jNWX207]kN`80OGem0P1nOWh607moO`80P820201oOgl00`1nOWh0O7al07alO002
07]kN`80NGUi0P1gMgL207EeM@80M7Ad0P1bLW82075aL@H0L71`0P1aLG4207EeM@80NWYj0P20P800
0`26QXH0S8b<08b<S00209>CT`80W9bL0P2VYZH20:b/[080Zj^[0P2_[jl20;2`/080/[:b0P2g]kL2
0;jn_P80a<C40P3;bl/20<o?c`80d];B00<0emOG0=[JfP3Jf]X00P3Ng]h20>;RhP80i>CT0P3WinL2
0>KViP80inOW0P3UiND20>7Qh@80h>3P0P3Ti>@20>SXj080j^[Z0P3[jn/20>g]k@030>c/k03Zj^X0
j^[Z0080j>SX0P3UiND20>;RhP80g]kN0P3Jf]X20=OGe`80dm?C0P3?cll20<_;b`80alO70P32`/82
0;jn_P80^k^k0P2g]kL00`2c/k<0[jn_0:n_[`020:^[Z`80YjNW0P2SXj<209nOW`80Vi^K0P2GUiLE
0?ooo`004`3oool2092@T080SXj>0P2:RXX208R8R080QHF50P22PX8207inOP80O7al00<0NGUi07If
MP1fMWH00P1cLg<2071`L080KFe]0P1[Jf/206QXJ080IVIV0P1SHf<2061PH080GUiN0P1LG5`205UI
F@80EUIF0P1DE5@2059BDP03051@D01>CTh0CTi>0080CDe=0P1;Bd/204e=C@80Cdm?0P1BDU8205AD
E080EeMG0P1LG5`205mOG`80Hf=S0P1VIVH206][J`80KVi^0P1aLG400`1cLg<0MGEe07EeM@0207Mg
M`80N7Qh0P1jNWX207]kN`80OGem0P1nOWh607moO`80P820201oOgl00`1nOWh0O7al07alO00207]k
N`80NGUi0P1gMgL207EeM@80M7Ad0P1bLW82075aL@H0L71`0P1aLG4207EeM@80NWYj0P20P8000`26
QXH0S8b<08b<S00209>CT`80W9bL0P2VYZH20:b/[080Zj^[0P2_[jl20;2`/080/[:b0P2g]kL20;jn
_P80a<C40P3;bl/20<o?c`80d];B00<0emOG0=[JfP3Jf]X00P3Ng]h20>;RhP80i>CT0P3WinL20>KV
iP80inOW0P3UiND20>7Qh@80h>3P0P3Ti>@20>SXj080j^[Z0P3[jn/20>g]k@030>c/k03Zj^X0j^[Z
0080j>SX0P3UiND20>;RhP80g]kN0P3Jf]X20=OGe`80dm?C0P3?cll20<_;b`80alO70P32`/820;jn
_P80^k^k0P2g]kL00`2c/k<0[jn_0:n_[`020:^[Z`80YjNW0P2SXj<209nOW`80Vi^K0P2GUiLE0?oo
o`004`3oool2092@T080SHf=0P2:RXX208N7Q`80Q8B40P21PH4207inOP80Ng]k00<0N7Qh07EeM@1e
MGD00P1cLg<2071`L080KFe]0P1ZJVX206MWI`80I6AT0P1RHV8205mOG`80GEeM0P1KFe/205QHF080
EUIF0P1CDe<2051@D00304m?C`1=CDd0CDe=00@0C4a<0P1=CDd2051@D080De=C0P1FEUH205UIF@80
GEeM0P1PH60206ATI080J6QX0P1/K6`206m_K`80L71`00<0LG5a07=cL`1cLg<00P1dM7@207IfMP80
MgMg0P1iNGT207YjNP80O7al0P1mOGd407inOP@0Ogmo0P1nOWh407moO`0307inOP1mOGd0OGem0080
O7al0P1iNGT207MgM`80MGEe0P1cLg<2075aL@80L71`201^KVh206m_K`80LW9b0P1hN7P00`1oOgl0
QhN708N7Q`0208j>SP80V9RH0P2SXj<20:^[Z`@0[Zj^0P2b/[820;>c/`80]kNg0P2l_;`20<;2`P80
bLW90P3>c/h20=3@d0030=GEe@3IfMT0fMWI0080gMgM0P3QhN420>CTi080i^KV103Xj>P20>OWi`80
i>CT0P3Rh^820>CTi080inOW0P3YjNT20>c/k080k^k^00<0kNg]0>c/k03/k>`00P3YjNT20>GUi@80
h^;R0P3Ogml20=_Kf`80emOG0P3Cdm<20<o?c`80bl_;0P37alL20<?3``80_kno0P2j^[X20;Ng]`03
0;>c/`2_[jl0[jn_0080Zj^[0P2WYjL20:>SX`80WinO0P2KVi/209NGUaD0oooo000C0?ooo`80T92@
0P2=SHd208Z:RP80QhN70P24Q8@20861P@80OWin0P1kNg/00`1hN7P0MGEe07EeM@0207=cL`80L71`
0P1]KFd206YZJP80IfMW0P1TI6@2069RHP80GemO0P1MGEd205]KF`80F5QH0P1FEUH205=CD`80D51@
00<0Cdm?04e=C@1=CDd0101<C4`204e=C@80D51@0P1CDe<205IFEP80FEUI0P1MGEd2061PH080I6AT
0P1XJ6P206a/K080Kfm_0P1`L7000`1aLG40Lg=c07=cL`0207AdM080MWIf0P1gMgL207UiN@80NWYj
0P1lO7`207emO@@0OWin101oOgl207inOP@0Ogmo00<0OWin07emO@1mOGd00P1lO7`207UiN@80MgMg
0P1eMGD207=cL`80LG5a0P1`L70806i^KP80Kfm_0P1bLW8207QhN00307moO`27QhL0QhN70080SXj>
0P2HV9P20:>SX`80Zj^[102^[Zh20;:b/P80/k>c0P2g]kL20;bl_080`/;20P39bLT20<k>cP80d=3@
00<0eMGE0=WIf@3IfMT00P3MgMd20>7Qh@80i>CT0P3Vi^H40>SXj080inOW0P3Ti>@20>;RhP80i>CT
0P3WinL20>WYj@80k>c/0P3^k^h00`3]kNd0k>c/0>c/k0020>WYj@80iNGU0P3Rh^820=oOg`80fm_K
0P3GemL20=?Cd`80clo?0P3;bl/20<O7a`80`l?30P2o_kl20;Zj^P80]kNg00<0/k>c0:n_[`2_[jl0
0P2[Zj/20:NWY`80Xj>S0P2OWil209^KV`80UiNG5@3oool001<0oooo0P2@T90208f=S@80RXZ:0P27
QhL208B4Q080PH610P1nOWh207]kN`0307MgM`1dM7@0M7Ad0080LG5a0P1_Kfl206a/K080JFUY0P1V
IVH206=SH`80HF5Q0P1NGUh205aLG080FEUI0P1GEeL205ADE080DU9B0P1?Cdl00`1>CTh0CDe=04e=
C@0204];B`80C4a<0P1>CTh2055AD@80De=C0P1GEeL205]KF`80GUiN0P1QHF4206EUI@80JFUY0P1/
K6`206i^KP80Kfm_00<0L71`075aL@1aLG400P1bLW8207=cL`80MGEe0P1fMWH207QhN080NGUi0P1j
NWX407]kN`H0O7al1`1mOGd207alO080NWYj0P1hN7P207EeM@80LW9b0P1`L70206i^KP@0K6a/0P1[
Jf/206a/K080KFe]0P1^KVh2079bLP0307UiN@21PH40PH610080RXZ:0P2DU9@20:2PX080ZJVY0P2_
[jl20;2`/080];Bd0P2h^;P20;Vi^@80_;bl0P2o_kl20<K6aP80c<c<0P3@d=000`3Cdm<0emOG0=OG
e`020=cLg080h>3P0P3UiND20>OWi`H0jNWY0P3Xj>P20>CTi080iNGU0P3Xj>P20>[ZjP80k>c/1@3^
k^h20>WYj@80i^KV0P3Rh^820=oOg`80fm_K0P3GemL20=?Cd`80clo?0P3;bl/20<O7a`80`l?30P2o
_kl20;Zj^P80]kNg00<0/k>c0:n_[`2_[jl00P2[Zj/20:NWY`80Xj>S0P2OWil209^KV`80UiNG5@3o
ool001<0oooo0P2@T90208f=S@80RXZ:0P27QhL208B4Q080PH610P1nOWh207]kN`0307MgM`1dM7@0
M7Ad0080LG5a0P1_Kfl206a/K080JFUY0P1VIVH206=SH`80HF5Q0P1NGUh205aLG080FEUI0P1GEeL2
05ADE080DU9B0P1?Cdl00`1>CTh0CDe=04e=C@0204];B`80C4a<0P1>CTh2055AD@80De=C0P1GEeL2
05]KF`80GUiN0P1QHF4206EUI@80JFUY0P1/K6`206i^KP80Kfm_00<0L71`075aL@1aLG400P1bLW82
07=cL`80MGEe0P1fMWH207QhN080NGUi0P1jNWX407]kN`H0O7al1`1mOGd207alO080NWYj0P1hN7P2
07EeM@80LW9b0P1`L70206i^KP@0K6a/0P1[Jf/206a/K080KFe]0P1^KVh2079bLP0307UiN@21PH40
PH610080RXZ:0P2DU9@20:2PX080ZJVY0P2_[jl20;2`/080];Bd0P2h^;P20;Vi^@80_;bl0P2o_kl2
0<K6aP80c<c<0P3@d=000`3Cdm<0emOG0=OGe`020=cLg080h>3P0P3UiND20>OWi`H0jNWY0P3Xj>P2
0>CTi080iNGU0P3Xj>P20>[ZjP80k>c/1@3^k^h20>WYj@80i^KV0P3Rh^820=oOg`80fm_K0P3GemL2
0=?Cd`80clo?0P3;bl/20<O7a`80`l?30P2o_kl20;Zj^P80]kNg00<0/k>c0:n_[`2_[jl00P2[Zj/2
0:NWY`80Xj>S0P2OWil209^KV`80UiNG5@3oool001<0oooo0P2@T90208f=S@80RXZ:0P27QhL208B4
Q080P8200P1mOGd207YjNP0307MgM`1dM7@0M7Ad0080LG5a0P1^KVh206][J`80J6QX0P1UIFD2069R
HP80GemO0P1MGEd205YJFP80F5QH0P1FEUH205=CD`80DE5A0P1?Cdl00`1=CDd0C4a<04a<C00204a<
C080CDe=0P1?Cdl205=CD`80EUIF0P1HF5P205eMG@80H61P0P1SHf<206MWI`80Jf][0P1`L70506i^
KP@0Kfm_0P1`L702075aL@80Lg=c0P1fMWH807MgM`H0N7Qh0P1iNGT307]kN`@0O7al0P1jNWX207Mg
M`80MGEe0P1bLW8206m_K`80K6a/0P1[Jf/206YZJP@0JFUY0P1ZJVX206][J`80KFe]00<0LG5a07Yj
NP1jNWX00P24Q8@208n?S`80W9bL0P2WYjL20;2`/080/[:b0P2c/k<20;Vi^@80_;bl0P2n_[h20<71
`@80a<C40P39bLT20<o?c`030=?Cd`3Fe]H0e]KF0080fm_K0P3Ph>020>GUi@80j>SX0P3Zj^X40>_[
j`80j^[Z103WinL20>WYj@80jn_[0P3^k^h30>o_k`80k^k^0P3[jn/20>OWi`80hn?S0P3Ogml20=_K
f`80emOG0P3Cdm<20<o?c`80bl_;0P37alL20<?3``80_kno0P2j^[X20;Ng]`030;>c/`2_[jl0[jn_
0080Zj^[0P2WYjL20:>SX`80WinO0P2KVi/209NGUaD0oooo000C0?ooo`80T92@0P2=SHd208Z:RP80
QXJ60P23Ph<20820P080OGem0P1jNWX00`1fMWH0Lg=c07=cL`02071`L080KFe]0P1ZJVX206MWI`80
I6AT0P1QHF4205iNGP80Fe]K0P1IFET205IFEP80E5AD0P1BDU8204m?C`<0CDe=0P1<C4`204e=C@80
CTi>0P1ADE4205ADE080F5QH0P1JFUX205iNGP80HF5Q0P1UIFD206UYJ@80K6a/101]KFd906a/K080
KVi^0P1_Kfl2071`L080LG5a0P1`L702075aL@80LW9b1P1cLg<207AdM080MGEe00<0MWIf07MgM`1g
MgL00P1hN7P207UiN@80MgMg0P1dM7@2075aL@80KVi^0P1[Jf/206UYJ@80J6QX1P1WIfL206QXJ080
JVYZ00<0K6a/079bLP1bLW800P1mOGd208V9R@80UiNG0P2TY:@20:j^[P@0][Jf0P2i^KT20<30`080
`L710P35aLD20<O7a`80bLW90P3=cLd00`3AdM40eMGE0=GEe@020=[JfP80gmoO0P3Ti>@20>SXj080
j^[Z0P3/k>`40>g]k@80j^[Z0P3YjNT20>_[j`80kNg]0P3_knl30?7al@80kNg]0P3Zj^X20>OWi`80
hn?S0P3Ph>020=_Kf`80emOG0P3Cdm<20<o?c`80bl_;0P37alL20<?3``80_kno0P2k^k/20;Ng]`03
0;>c/`2_[jl0[jn_0080Zj^[0P2WYjL20:>SX`80WinO0P2KVi/209NGUaD0oooo000C0?ooo`80T92@
0P2=SHd208Z:RP80QXJ60P23Ph<20820P080OGem0P1jNWX00`1fMWH0Lg=c07=cL`02071`L080KFe]
0P1ZJVX206MWI`80I6AT0P1QHF4205iNGP80Fe]K0P1IFET205IFEP80E5AD0P1BDU8204m?C`<0CDe=
0P1<C4`204e=C@80CTi>0P1ADE4205ADE080F5QH0P1JFUX205iNGP80HF5Q0P1UIFD206UYJ@80K6a/
101]KFd906a/K080KVi^0P1_Kfl2071`L080LG5a0P1`L702075aL@80LW9b1P1cLg<207AdM080MGEe
00<0MWIf07MgM`1gMgL00P1hN7P207UiN@80MgMg0P1dM7@2075aL@80KVi^0P1[Jf/206UYJ@80J6QX
1P1WIfL206QXJ080JVYZ00<0K6a/079bLP1bLW800P1mOGd208V9R@80UiNG0P2TY:@20:j^[P@0][Jf
0P2i^KT20<30`080`L710P35aLD20<O7a`80bLW90P3=cLd00`3AdM40eMGE0=GEe@020=[JfP80gmoO
0P3Ti>@20>SXj080j^[Z0P3/k>`40>g]k@80j^[Z0P3YjNT20>_[j`80kNg]0P3_knl30?7al@80kNg]
0P3Zj^X20>OWi`80hn?S0P3Ph>020=_Kf`80emOG0P3Cdm<20<o?c`80bl_;0P37alL20<?3``80_kno
0P2k^k/20;Ng]`030;>c/`2_[jl0[jn_0080Zj^[0P2WYjL20:>SX`80WinO0P2KVi/209NGUaD0oooo
000C0?ooo`80T92@0P2=SHd208V9R@80QXJ60P23Ph<207moO`80O7al0P1iNGT00`1fMWH0LW9b079b
LP0206m_K`80K6a/0P1YJFT206IVIP80Hf=S0P1PH60205eMG@80FUYJ0P1HF5P205EEE@80DU9B0P1@
D50204i>CPD0CDe=0P1>CTh204m?C`80DU9B0P1GEeL205YJFP80GEeM0P1PH60206EUI@80J6QX0P1[
Jf/206i^KP80K6a/101[Jf/00`1ZJVX0JFUY06UYJ@0206QXJ080IfMW0P1YJFT206YZJP80K6a/0P1^
KVh206m_K`80KVi^101_Kfl4071`L080LG5a0P1bLW800`1cLg<0LW9b079bLP0207=cL`80MGEe0P1f
MWH2079bLP80Kfm_0P1/K6`206UYJ@80IfMW0P1VIVH606EUI@80IVIV0P1XJ6P00`1ZJVX0KVi^06i^
KP0207EeM@80Ph>30P2ATI420:2PX080ZZZZ0P2e]KD20;Vi^@80^k^k0P31`L420<C4a080alO7103;
bl/20<c<c0030=7Ad@3EeMD0eMGE0080fMWI0P3Ng]h20>CTi080j>SX0P3[jn/20>g]k@@0kno_0P3]
kNd20>[ZjP80jn_[0P3^k^h20?3`l0<0l_;b0P3^k^h20>_[j`80inOW0P3Shn<20>3Ph080g=cL0P3G
emL20=?Cd`80clo?0P3;bl/20<O7a`80`l?30P2o_kl20;^k^`80]kNg00<0/k>c0:n_[`2_[jl00P2[
Zj/20:NWY`80Xj>S0P2OWil209^KV`80UiNG5@3oool001<0oooo0P2@T90208f=S@80RHV90P26QXH2
08>3P`80Ogmo0P1lO7`207UiN@0307IfMP1bLW80LW9b0080Kfm_0P1/K6`206UYJ@80IVIV0P1SHf<2
061PH080GEeM0P1JFUX205QHF080EEEE0P1BDU82051@D080CTi>1@1=CDd204i>CP80Cdm?0P1BDU82
05MGE`80FUYJ0P1MGEd2061PH080IFEU0P1XJ6P206][J`80KVi^0P1/K6`406][J`0306YZJP1YJFT0
JFUY0080J6QX0P1WIfL206UYJ@80JVYZ0P1/K6`206i^KP80Kfm_0P1^KVh406m_K`@0L71`0P1aLG42
079bLP0307=cL`1bLW80LW9b0080Lg=c0P1eMGD207IfMP80LW9b0P1_Kfl206a/K080JFUY0P1WIfL2
06IVIPH0IFEU0P1VIVH206QXJ00306YZJP1^KVh0KVi^0080MGEe0P23Ph<2096AT@80X:2P0P2ZZZX2
0;Fe]@80^KVi0P2k^k/20<71`@80a<C40P37alL40<_;b`80c<c<00<0dM7A0=GEe@3EeMD00P3IfMT2
0=kNgP80i>CT0P3Xj>P20>_[j`80kNg]103_knl20>g]k@80j^[Z0P3[jn/20>k^kP80l?3`0`3bl_82
0>k^kP80jn_[0P3WinL20>?Sh`80h>3P0P3Lg=`20=OGe`80dm?C0P3?cll20<_;b`80alO70P33`l<2
0;no_`80^k^k0P2g]kL00`2c/k<0[jn_0:n_[`020:^[Z`80YjNW0P2SXj<209nOW`80Vi^K0P2GUiLE
0?ooo`004`3oool2092@T080SHf=0P29RHT208J6QP80PX:20P1oOgl207alO080N7Qh00<0MGEe079b
LP1bLW800P1^KVh206][J`80J6QX0P1UIFD2069RHP80GUiN0P1KFe/205UIF@80EUIF0P1DE5@2055A
D@80Cdm?0P1<C4`304];B`80C4a<0P1>CTh2055AD@80E5AD0P1HF5P205]KF`80GemO0P1SHf<206IV
IP80JVYZ101]KFd206a/K080Jf][0P1YJFT00`1XJ6P0IVIV06IVIP0206EUI@80Hf=S0P1TI6@206IV
IP80IfMW101XJ6P406UYJ@80J6QX0P1YJFT206YZJP80Jf][0P1/K6`00`1^KVh0Kfm_06m_K`0206i^
KP80Kfm_101aLG4206i^KP80JVYZ0P1XJ6P206IVIP80IFEU101SHf<206ATI080IFEU0P1VIVH00`1X
J6P0K6a/06a/K002075aL@80O7al0P2;Rh/209^KV`80Z:RX0P2d];@20;Zj^P80_Kfm0P31`L420<S8
b080b/[:0P3?cll20=7Ad@80clo?00<0d=3@0=CDe03De=@00P3IfMT20=kNgP80hn?S0P3Xj>P20>_[
j`80k^k^103alO420>o_k`@0k>c/0P3^k^h20?3`l080l_;b00<0lo?c0>o_k`3_knl00P3[jn/20>SX
j080i>CT0P3Ph>020=cLg080emOG0P3Cdm<20<o?c`80bl_;0P37alL20<?3``80_kno0P2k^k/20;Ng
]`030;>c/`2_[jl0[jn_0080Zj^[0P2WYjL20:>SX`80WinO0P2KVi/209NGUaD0oooo000C0?ooo`80
T92@0P2=SHd208V9R@80QXJ60P22PX8207moO`80O7al0P1hN7P00`1eMGD0LW9b079bLP0206i^KP80
Jf][0P1XJ6P206EUI@80HV9R0P1NGUh205]KF`80FEUI0P1FEUH205ADE080DE5A0P1?Cdl204a<C0<0
Bd];0P1<C4`204i>CP80DE5A0P1DE5@205QHF080Fe]K0P1OGel206=SH`80IVIV0P1ZJVX406e]K@80
K6a/0P1[Jf/206UYJ@0306QXJ01VIVH0IVIV0080IFEU0P1SHf<206ATI080IVIV0P1WIfL406QXJ0@0
JFUY0P1XJ6P206UYJ@80JVYZ0P1[Jf/206a/K00306i^KP1_Kfl0Kfm_0080KVi^0P1_Kfl4075aL@80
KVi^0P1ZJVX206QXJ080IVIV0P1UIFD406=SH`80I6AT0P1UIFD206IVIP0306QXJ01/K6`0K6a/0080
LG5a0P1lO7`208^;R`80Vi^K0P2XZ:P20;Bd]080^[Zj0P2m_Kd20<71`@80b<S80P3:b/X20<o?c`80
dM7A0P3?cll00`3@d=00e=CD0=CDe0020=WIf@80g]kN0P3Shn<20>SXj080jn_[0P3^k^h40?7al@80
kno_103/k>`20>k^kP80l?3`0P3bl_800`3clo<0kno_0>o_k`020>_[j`80j>SX0P3Ti>@20>3Ph080
g=cL0P3GemL20=?Cd`80clo?0P3;bl/20<O7a`80`l?30P2o_kl20;^k^`80]kNg00<0/k>c0:n_[`2_
[jl00P2[Zj/20:NWY`80Xj>S0P2OWil209^KV`80UiNG5@3oool001<0oooo0P2@T90208f=S@80RHV9
0P26QXH208:2PP80OWin0P1kNg/207MgM`0307AdM01aLG40LG5a0080KFe]0P1ZJVX206IVIP80Hf=S
0P1PH60205eMG@80FUYJ0P1GEeL205EEE@80DU9B0P1@D50204e=C@80Bd];0`1:BTX204e=C@80Cdm?
0P1BDU8205IFEP80FUYJ0P1NGUh2065QH@80IFEU0P1YJFT206e]K@80KVi^0P1]KFd206a/K080JVYZ
0P1XJ6P00`1VIVH0HV9R069RHP02061PH0@0G5aL0P1MGEd205iNGP@0GemO101PH60405mOG`80H61P
0P1QHF4206=SH`0306ATI01UIFD0IFEU0080I6AT0P1UIFD206MWI`80J6QX0P1YJFT206MWI`80IFEU
0P1TI6@206=SH`80HV9R0P1QHF42069RHP80Hf=S0P1UIFD00`1VIVH0JVYZ06YZJP0206i^KP80MWIf
0P25QHD209JFUP80YJFU0P2`/;020;Vi^@80_kno0P31`L420<S8b080cLg=0P3AdM420=KFeP80eMGE
00<0dm?C0=CDe03De=@00P3IfMT20=gMg@80h^;R0P3WinL20>_[j`80k^k^0P3bl_820??cl`80l_;b
0P3`l?020>k^kP@0lO7a0P3clo<00`3bl_80kno_0>o_k`020>c/k080j>SX0P3Ti>@20>3Ph080g=cL
0P3GemL20=?Cd`80clo?0P3;bl/20<O7a`80`l?30P2o_kl20;^k^`80]kNg00<0/k>c0:n_[`2_[jl0
0P2[Zj/20:NWY`80Xj>S0P2OWil209^KV`80UiNG5@3oool001<0oooo0P2@T90208f=S@80RHV90P26
QXH208:2PP80OWin0P1kNg/207MgM`0307AdM01aLG40LG5a0080KFe]0P1ZJVX206IVIP80Hf=S0P1P
H60205eMG@80FUYJ0P1GEeL205EEE@80DU9B0P1@D50204e=C@80Bd];0`1:BTX204e=C@80Cdm?0P1B
DU8205IFEP80FUYJ0P1NGUh2065QH@80IFEU0P1YJFT206e]K@80KVi^0P1]KFd206a/K080JVYZ0P1X
J6P00`1VIVH0HV9R069RHP02061PH0@0G5aL0P1MGEd205iNGP@0GemO101PH60405mOG`80H61P0P1Q
HF4206=SH`0306ATI01UIFD0IFEU0080I6AT0P1UIFD206MWI`80J6QX0P1YJFT206MWI`80IFEU0P1T
I6@206=SH`80HV9R0P1QHF42069RHP80Hf=S0P1UIFD00`1VIVH0JVYZ06YZJP0206i^KP80MWIf0P25
QHD209JFUP80YJFU0P2`/;020;Vi^@80_kno0P31`L420<S8b080cLg=0P3AdM420=KFeP80eMGE00<0
dm?C0=CDe03De=@00P3IfMT20=gMg@80h^;R0P3WinL20>_[j`80k^k^0P3bl_820??cl`80l_;b0P3`
l?020>k^kP@0lO7a0P3clo<00`3bl_80kno_0>o_k`020>c/k080j>SX0P3Ti>@20>3Ph080g=cL0P3G
emL20=?Cd`80clo?0P3;bl/20<O7a`80`l?30P2o_kl20;^k^`80]kNg00<0/k>c0:n_[`2_[jl00P2[
Zj/20:NWY`80Xj>S0P2OWil209^KV`80UiNG5@3oool001<0oooo0P2@T90208b<S080RHV90P25QHD2
0861P@80OWin0P1jNWX207MgM`0307=cL`1`L700L71`0080K6a/0P1YJFT206EUI@80HV9R0P1OGel2
05]KF`80F5QH0P1FEUH205=CD`80D51@0P1>CTh204];B`80BTY:0P19BDT00`1:BTX0CDe=04e=C@02
051@D080De=C0P1HF5P205aLG080H61P0P1UIFD206UYJ@80KFe]0P1bLW8206m_K`80KVi^0P1/K6`2
06YZJP80IfMW00<0IFEU069RHP1RHV800P1OGel205]KF`80F5QH101GEeL605QHF0P0FEUI0P1KFe/2
05aLG00305iNGP1QHF40HF5Q00@0HV9R101TI6@206EUI@80I6AT0P1SHf<2069RHP@0HF5Q0P1PH602
065QH@80HV9R0P1TI6@00`1VIVH0J6QX06QXJ00206a/K080Lg=c0P1oOgl208n?S`80X:2P0P2/[:`2
0;Ng]`80_kno0P33`l<20<O7a`80clo?0P3Cdm<20=WIf@80f][J00<0fMWI0=KFeP3Fe]H00P3IfMT2
0=gMg@80hN7Q0P3WinL20>_[j`80kno_0P3clo<20?Cdm080mOGe0P3bl_820?3`l080l_;b0P3clo<2
0?KfmP030??cl`3_knl0kno_0080k>c/0P3Xj>P20>CTi080h>3P0P3Kfm/20=OGe`80dm?C0P3?cll2
0<_;b`80alO70P32`/820;no_`80^k^k0P2g]kL00`2c/k<0[jn_0:n_[`020:^[Z`80YjNW0P2SXj<2
09nOW`80Vi^K0P2GUiLE0?ooo`004`3oool2092@T080S8b<0P29RHT208F5Q@80PH610P1nOWh207Yj
NP80MgMg00<0Lg=c071`L01`L7000P1/K6`206UYJ@80IFEU0P1RHV8205mOG`80Fe]K0P1HF5P205IF
EP80De=C0P1@D50204i>CP80Bd];0P1:BTX204U9B@0304Y:BP1=CDd0CDe=0080D51@0P1CDe<205QH
F080G5aL0P1PH60206EUI@80JFUY0P1]KFd2079bLP80Kfm_0P1^KVh206a/K080JVYZ0P1WIfL00`1U
IFD0HV9R069RHP0205mOG`80Fe]K0P1HF5P405MGE`H0F5QH201IFET205]KF`80G5aL00<0GUiN065Q
H@1QHF40101RHV8406ATI080IFEU0P1TI6@206=SH`80HV9R101QHF42061PH080HF5Q0P1RHV8206AT
I00306IVIP1XJ6P0J6QX0080K6a/0P1cLg<207moO`80Shn?0P2PX:020:b/[080]kNg0P2o_kl20<?3
``80alO70P3?cll20=?Cd`80fMWI0P3Jf]X00`3IfMT0e]KF0=KFeP020=WIf@80gMgM0P3QhN420>OW
i`80jn_[0P3_knl20??cl`80m?Cd0P3emOD20?;blP80l?3`0P3bl_820??cl`80m_Kf00<0lo?c0>o_
k`3_knl00P3/k>`20>SXj080i>CT0P3Ph>020=_Kf`80emOG0P3Cdm<20<o?c`80bl_;0P37alL20<;2
`P80_kno0P2k^k/20;Ng]`030;>c/`2_[jl0[jn_0080Zj^[0P2WYjL20:>SX`80WinO0P2KVi/209NG
UaD0oooo000C0?ooo`80T92@0P2<S8`208R8R080QHF50P21PH4207emO@80NWYj0P1fMWH00`1bLW80
Kfm_06m_K`0206][J`80J6QX0P1TI6@2065QH@80GEeM0P1JFUX205MGE`80E5AD0P1ADE4204i>CP80
C4a<0P1:BTX404U9B@0304Y:BP1=CDd0CDe=0080DE5A0P1EEED205UIF@80GUiN0P1SHf<206QXJ080
K6a/0P1aLG42079bLP80L71`0P1^KVh206a/K080JVYZ0P1WIfL00`1UIFD0HV9R069RHP02061PH080
GEeM0P1KFe/205UIF@@0F5QH0P1IFET205QHF080FEUI0P1JFUX405]KF`80G5aL0P1MGEd00`1OGel0
H61P061PH002065QH@X0HV9R0P1QHF42061PH0H0GemO0P1PH602065QH@80HV9R00<0IFEU06QXJ01X
J6P00P1[Jf/2075aL@80Ng]k0P2:RXX209bLW080Z:RX0P2c/k<20;^k^`80`/;20P36a/H20<o?c`80
eMGE0P3IfMT30=gMg@@0fm_K0P3MgMd20>7Qh@80i^KV0P3[jn/20?3`l080m?Cd0P3fm_H20?Ogm`80
m?Cd0P3bl_820??cl`80m?Cd0P3gmoL00`3clo<0kno_0>o_k`020>c/k080j>SX0P3Ti>@20>3Ph080
fm_K0P3GemL20=?Cd`80clo?0P3;bl/20<O7a`80`l?30P2o_kl20;Zj^P80][Jf00<0/[:b0:n_[`2_
[jl00P2[Zj/20:NWY`80Xj>S0P2OWil209^KV`80UiNG5@3oool001<0oooo0P2@T90208b<S080R8R8
0P25QHD20861P@80OGem0P1jNWX207IfMP03079bLP1_Kfl0Kfm_0080Jf][0P1XJ6P206ATI080HF5Q
0P1MGEd205YJFP80EeMG0P1DE5@2055AD@80CTi>0P1<C4`204Y:BP@0BDU900<0BTY:04e=C@1=CDd0
0P1ADE4205EEE@80FEUI0P1NGUh206=SH`80J6QX0P1/K6`2075aL@80LW9b0P1`L70206i^KP80K6a/
0P1ZJVX206MWI`0306EUI@1RHV80HV9R0080H61P0P1MGEd205]KF`80FEUI101HF5P205UIF@80F5QH
0P1IFET205YJFP@0Fe]K0P1LG5`205eMG@0305mOG`1PH600H61P0080HF5Q2P1RHV82065QH@80H61P
1P1OGel2061PH080HF5Q0P1RHV800`1UIFD0J6QX06QXJ00206][J`80LG5a0P1kNg/208Z:RP80W9bL
0P2XZ:P20;>c/`80^k^k0P32`/820<K6aP80clo?0P3EeMD20=WIf@<0gMgM103Kfm/20=gMg@80hN7Q
0P3Vi^H20>_[j`80l?3`0P3dm?@20?KfmP80moOg0P3dm?@20?;blP80lo?c0P3dm?@20?Ogm`030??c
l`3_knl0kno_0080k>c/0P3Xj>P20>CTi080h>3P0P3Kfm/20=OGe`80dm?C0P3?cll20<_;b`80alO7
0P33`l<20;no_`80^[Zj0P2f][H00`2b/[80[jn_0:n_[`020:^[Z`80YjNW0P2SXj<209nOW`80Vi^K
0P2GUiLE0?ooo`004`3oool2092@T080S8b<0P28R8P208B4Q080PH610P1mOGd207UiN@80MGEe00<0
LW9b06i^KP1^KVh00P1ZJVX206IVIP80Hf=S0P1OGel205aLG080F5QH0P1EEED2059BDP80Cdm?0P1<
C4`204U9B@@0AdM70P18B4P00`1:BTX0CDe=04e=C@02055AD@80EUIF0P1KFe/2061PH080IFEU0P1Z
JVX2071`L080MWIf0P1dM7@2075aL@80Kfm_0P1/K6`206YZJP80IfMW00<0IFEU069RHP1RHV800P1P
H60205iNGP80G5aL0P1KFe/205YJFPH0FEUI0P1JFUX405]KF`80G5aL0P1MGEd205iNGP0305mOG`1P
H600H61P00P0HF5Q0P1PH60405mOG`@0GUiN0P1MGEd405iNGP80GemO0P1QHF400`1SHf<0IVIV06IV
IP0206UYJ@80KVi^0P1gMgL208F5Q@80UiNG0P2VYZH20;6a/@80^[Zj0P32`/820<O7a`80cLg=0P3E
eMD20=_Kf`80h>3P00<0hN7Q0>3Ph03Ph>00103Ogml20>;RhP80i^KV0P3Zj^X20>o_k`80l_;b0P3f
m_H20?Shn080moOg103dm?@20?Gem@80moOg00<0m?Cd0>o_k`3_knl00P3/k>`20>WYj@80i>CT0P3P
h>020=_Kf`80emOG0P3Cdm<20<o?c`80b/[:0P36a/H20<;2`P80_[jn0P2j^[X20;Jf]P030;:b/P2_
[jl0[jn_0080Zj^[0P2WYjL20:>SX`80WinO0P2KVi/209NGUaD0oooo000C0?ooo`80T92@0P2<S8`2
08R8R080Q8B40P21PH4207emO@80NGUi0P1eMGD00`1bLW80KVi^06i^KP0206YZJP80IVIV0P1SHf<2
05mOG`80G5aL0P1HF5P205EEE@80DU9B0P1?Cdl204a<C080BDU91017AdL204Q8B00304Y:BP1=CDd0
CDe=0080DE5A0P1FEUH205]KF`80H61P0P1UIFD206YZJP80L71`0P1fMWH207AdM080LG5a0P1_Kfl2
06a/K080JVYZ0P1WIfL00`1UIFD0HV9R069RHP02061PH080GUiN0P1LG5`205]KF`80FUYJ1P1IFET2
05YJFP@0Fe]K0P1LG5`205eMG@80GUiN00<0GemO061PH01PH600201QHF42061PH0@0GemO101NGUh2
05eMG@@0GUiN0P1OGel2065QH@0306=SH`1VIVH0IVIV0080JFUY0P1^KVh207MgM`80QHF50P2GUiL2
0:JVYP80/K6a0P2j^[X20<;2`P80alO70P3=cLd20=GEe@80fm_K0P3Ph>000`3QhN40h>3P0>3Ph004
0=oOg`80h^;R0P3Vi^H20>[ZjP80kno_0P3bl_820?KfmP80n?Sh0P3gmoL40?Cdm080mOGe0P3gmoL0
0`3dm?@0kno_0>o_k`020>c/k080jNWY0P3Ti>@20>3Ph080fm_K0P3GemL20=?Cd`80clo?0P3:b/X2
0<K6aP80`/;20P2n_[h20;Zj^P80][Jf00<0/[:b0:n_[`2_[jl00P2[Zj/20:NWY`80Xj>S0P2OWil2
09^KV`80UiNG5@3oool001<0oooo0P2?Shl208b<S080R8R80P24Q8@20820P080O7al0P1hN7P207Ad
M003075aL@1]KFd0KFe]0080JFUY0P1UIFD2065QH@80GUiN0P1JFUX205MGE`80De=C0P1@D50204e=
C@80BTY:0P18B4P204I6AP80ADE50P17AdL00`1:BTX0CTi>04i>CP02059BDP80EeMG0P1LG5`2069R
HP80J6QX0P1]KFd2079bLP80NGUi0P1eMGD2079bLP80L71`0P1]KFd206YZJP80J6QX00<0IFEU06=S
H`1SHf<00P1QHF4205mOG`80GEeM0P1LG5`205]KF`H0FUYJ0P1KFe/405aLG080GEeM0P1NGUh205mO
G`03061PH01QHF40HF5Q00@0HF5Q101PH60205mOG`80GEeM2P1LG5`205eMG@80GUiN0P1PH6000`1R
HV80IFEU06EUI@0206UYJ@80KFe]0P1eMGD208:2PP80TI6A0P2RXZ820:f][@80]kNg0P2o_kl20<K6
aP80c<c<0P3De=@20=_Kf`80h^;R0`3Ti>@20>;RhP80hN7Q0P3Shn<20>OWi`80j^[Z0P3`l?020?;b
lP80m_Kf103hn?P40?Gem@@0m_Kf00<0m?Cd0?3`l03`l?000P3/k>`20>SXj080i>CT0P3Ogml20=_K
f`80emOG0P3Bd]820<k>cP80b/[:0P36a/H20<;2`P80_[jn0P2j^[X20;Jf]P030;:b/P2_[jl0[jn_
0080ZZZZ0P2WYjL20:>SX`80WinO0P2KVi/209NGUaD0oooo000C0?ooo`80Shn?0P2<S8`208R8R080
Q8B40P20P80207alO080N7Qh0P1dM7@00`1aLG40KFe]06e]K@0206UYJ@80IFEU0P1QHF4205iNGP80
FUYJ0P1GEeL205=CD`80D51@0P1=CDd204Y:BP80B4Q80P16ATH204E5A@80AdM700<0BTY:04i>CP1>
CTh00P1BDU8205MGE`80G5aL0P1RHV8206QXJ080KFe]0P1bLW8207UiN@80MGEe0P1bLW82071`L080
KFe]0P1ZJVX206QXJ00306EUI@1SHf<0Hf=S0080HF5Q0P1OGel205eMG@80G5aL0P1KFe/605YJFP80
Fe]K101LG5`205eMG@80GUiN0P1OGel00`1PH600HF5Q065QH@04065QH@@0H61P0P1OGel205eMG@X0
G5aL0P1MGEd205iNGP80H61P00<0HV9R06EUI@1UIFD00P1YJFT206e]K@80MGEe0P22PX82096AT@80
XZ:R0P2][Jd20;Ng]`80_kno0P36a/H20<c<c080e=CD0P3Kfm/20>;RhP<0i>CT0P3Rh^820>7Qh@80
hn?S0P3WinL20>[ZjP80l?3`0P3bl_820?KfmP@0n?Sh103emOD40?KfmP030?Cdm03`l?00l?3`0080
k>c/0P3Xj>P20>CTi080gmoO0P3Kfm/20=OGe`80d];B0P3>c/h20<[:bP80a/K60P32`/820;jn_P80
^[Zj0P2f][H00`2b/[80[jn_0:n_[`020:ZZZP80YjNW0P2SXj<209nOW`80Vi^K0P2GUiLE0?ooo`00
4`3oool208n?S`80Rh^;0P27QhL208>3P`80Ogmo0P1kNg/207MgM`80M7Ad00<0L71`06a/K01/K6`0
0P1XJ6P206ATI080H61P0P1LG5`205UIF@80EEEE0P1BDU8204i>CP80BTY:0P17AdL204E5A@80A4A4
0P15ADD204M7A`0304];B`1>CTh0CTi>0080De=C0P1HF5P205iNGP80Hf=S0P1ZJVX206m_K`80MGEe
0P1iNGT207IfMP80Lg=c0P1`L70206e]K@80Jf][0P1XJ6P00`1VIVH0Hf=S06=SH`02065QH@80H61P
0P1NGUh205aLG0@0Fe]K101JFUX205]KF`80G5aL0P1MGEd205iNGP80GemO0P1PH607065QH@80H61P
0P1OGel205iNGP80GEeM0P1LG5`205]KF`@0FUYJ101KFe/205aLG080GUiN00<0H61P06=SH`1SHf<0
0P1WIfL206a/K080LW9b0P1mOGd208f=S@80WIfM0P2[Zj/20;Fe]@80_[jn0P35aLD20<c<c080d];B
0P3Jf]X20>;RhPD0i^KV0P3UiND20>CTi080inOW0P3Zj^X20?3`l080m?Cd0P3gmoL40?Win@80moOg
0P3emOD20?Ogm`80mOGe00<0m?Cd0?3`l03`l?000P3/k>`20>SXj080i>CT0P3Ogml20=_Kf`80e]KF
0P3Bd]820<k>cP80b/[:0P36a/H20<;2`P80_[jn0P2j^[X20;Jf]P030;:b/P2^[Zh0[Zj^0080ZZZZ
0P2WYjL20:>SX`80WinO0P2KVi/209NGUaD0oooo000C0?ooo`80Shn?0P2;Rh/208N7Q`80Ph>30P1o
Ogl207]kN`80MgMg0P1dM7@00`1`L700K6a/06a/K00206QXJ080I6AT0P1PH60205aLG080FEUI0P1E
EED2059BDP80CTi>0P1:BTX204M7A`80ADE50P14A4@204E5A@80AdM700<0Bd];04i>CP1>CTh00P1C
De<205QHF080GUiN0P1SHf<206YZJP80Kfm_0P1eMGD207UiN@80MWIf0P1cLg<2071`L080KFe]0P1[
Jf/206QXJ00306IVIP1SHf<0Hf=S0080HF5Q0P1PH60205iNGP80G5aL101KFe/405YJFP80Fe]K0P1L
G5`205eMG@80GUiN0P1OGel2061PH0L0HF5Q0P1PH60205mOG`80GUiN0P1MGEd205aLG080Fe]K101J
FUX405]KF`80G5aL0P1NGUh00`1PH600Hf=S06=SH`0206MWI`80K6a/0P1bLW8207emO@80SHf=0P2M
WId20:^[Z`80]KFe0P2n_[h20<G5a@80c<c<0P3Bd]820=[JfP80h^;R1@3Vi^H20>GUi@80i>CT0P3W
inL20>[ZjP80l?3`0P3dm?@20?Ogm`@0nOWi0P3gmoL20?Gem@80moOg0P3emOD00`3dm?@0l?3`0?3`
l0020>c/k080j>SX0P3Ti>@20=oOg`80fm_K0P3Fe]H20=;BdP80c/k>0P3:b/X20<K6aP80`/;20P2n
_[h20;Zj^P80][Jf00<0/[:b0:j^[P2^[Zh00P2ZZZX20:NWY`80Xj>S0P2OWil209^KV`80UiNG5@3o
ool001<0oooo0P2?Shl208^;R`80QhN70P23Ph<207moO`80Ng]k0P1gMgL207=cL`0306m_K`1[Jf/0
Jf][0080IfMW0P1SHf<205mOG`80Fe]K0P1GEeL205=CD`80Cdm?0P1<C4`204Q8B080ADE51012@T82
04A4A080AdM700<0Bd];051@D01@D5000P1DE5@205YJFP80H61P0P1VIVH206][J`80LG5a0P1iNGT2
07QhN080MWIf0P1cLg<2071`L080KVi^0P1[Jf/206QXJ00306IVIP1TI6@0I6AT0080HV9R0P1PH602
05iNGP80G5aL0P1KFe/205YJFP80FEUI101HF5P205YJFP80G5aL0P1MGEd205mOG`80H61P00<0HF5Q
069RHP1RHV80101QHF42061PH080GemO0P1MGEd205aLG0@0FUYJ1P1IFET205YJFP80Fe]K0P1MGEd0
0`1OGel0HF5Q065QH@0206EUI@80JVYZ0P1`L70207YjNP80RHV90P2JVYX20:RXZ080/k>c0P2m_Kd2
0<?3``80bl_;0P3@d=020=SHf080gmoO00<0j>SX0>WYj@3YjNT00P3YjNT20>OWi`80iNGU0P3Xj>P2
0>[ZjP80kno_0P3dm?@20?Shn080n_[j0P3kno/20?Shn080m_Kf0P3gmoL20?Gem@030?Cdm03alO40
lO7a0080kNg]0P3Xj>P20>?Sh`80gmoO0P3Jf]X20=KFeP80d];B0P3>c/h20<[:bP80a/K60P32`/82
0;jn_P80^[Zj0P2f][H00`2b/[80[Zj^0:j^[P020:ZZZP80YZJV0P2SXj<209nOW`80Vi^K0P2GUiLE
0?ooo`004`3oool208n?S`80Rh^;0P27QhL208>3P`80Ogmo0P1kNg/207MgM`80Lg=c00<0Kfm_06][
J`1[Jf/00P1WIfL206=SH`80GemO0P1KFe/205MGE`80De=C0P1?Cdl204a<C080B4Q80P15ADD40492
@P80A4A40P17AdL00`1;Bd/0D51@051@D00205ADE080FUYJ0P1PH60206IVIP80Jf][0P1aLG4207Ui
N@80N7Qh0P1fMWH207=cL`80L71`0P1^KVh206][J`80J6QX00<0IVIV06ATI01TI6@00P1RHV82061P
H080GUiN0P1LG5`205]KF`80FUYJ0P1IFET405QHF080FUYJ0P1LG5`205eMG@80GemO0P1PH6000`1Q
HF40HV9R069RHP04065QH@80H61P0P1OGel205eMG@80G5aL101JFUX605UIF@80FUYJ0P1KFe/205eM
G@0305mOG`1QHF40HF5Q0080IFEU0P1ZJVX2071`L080NWYj0P29RHT209ZJVP80Z:RX0P2c/k<20;fm
_@80`l?30P3;bl/20=3@d080f=SH0P3Ogml00`3Xj>P0jNWY0>WYj@020>WYj@80inOW0P3UiND20>SX
j080j^[Z0P3_knl20?Cdm080n?Sh0P3jn_X20?_kn`80n?Sh0P3fm_H20?Ogm`80mOGe00<0m?Cd0?7a
l@3alO400P3]kNd20>SXj080hn?S0P3Ogml20=[JfP80e]KF0P3Bd]820<k>cP80b/[:0P36a/H20<;2
`P80_[jn0P2j^[X20;Jf]P030;:b/P2^[Zh0[Zj^0080ZZZZ0P2VYZH20:>SX`80WinO0P2KVi/209NG
UaD0oooo000C0?ooo`80Shn?0P2;Rh/208N7Q`80Ph>30P1nOWh207YjNP80MWIf0P1bLW800`1^KVh0
JVYZ06YZJP0206IVIP80HV9R0P1NGUh205YJFP80EUIF0P1BDU8204i>CP80BTY:0P16ATH20492@P@0
@4100P13@d<204M7A`0304];B`1@D500D51@0080EUIF0P1KFe/2065QH@80IfMW0P1]KFd207AdM080
O7al0P1hN7P207IfMP80Lg=c0P1aLG4206i^KP80Jf][0P1YJFT00`1VIVH0I6AT06ATI002069RHP80
H61P0P1NGUh405aLG080Fe]K0P1HF5P405IFEP80EeMG0P1KFe/205eMG@80GUiN0P1OGel00`1QHF40
HV9R069RHP04065QH@80GemO0P1NGUh205eMG@80Fe]K0P1JFUX405UIF@@0F5QH0P1IFET205YJFP80
Fe]K00<0GEeM061PH01PH6000P1SHf<206QXJ080KVi^0P1fMWH208>3P`80UIFE0P2TY:@20;2`/080
^[Zj0P32`/820<[:bP80clo?0P3Fe]H20=kNgP030>KViP3Zj^X0j^[Z00@0j^[Z103Xj>P20>_[j`80
kno_0P3emOD20?Shn080no_k0P3lo?`20?[jnP80n?Sh0P3fm_H20?Ogm`030??cl`3`l?00l?3`0080
k>c/0P3WinL20>?Sh`80g]kN0P3Jf]X20=KFeP80dM7A0P3>c/h20<W9b@80aLG50P31`L420;fm_@80
^KVi0P2f][H00`2b/[80[Zj^0:j^[P020:ZZZP80YZJV0P2SXj<209nOW`80Vi^K0P2GUiLE0?ooo`00
4`3oool208n?S`80Rh^;0P27QhL208>3P`80OWin0P1jNWX207IfMP80LW9b00<0KVi^06YZJP1ZJVX0
0P1VIVH2069RHP80GUiN0P1JFUX205IFEP80DU9B0P1>CTh204Y:BP80ATI60P12@T840410@080@d=3
0P17AdL00`1;Bd/0D51@051@D00205IFEP80Fe]K0P1QHF4206MWI`80KFe]0P1dM7@207alO080N7Qh
0P1fMWH207=cL`80LG5a0P1^KVh206][J`80JFUY00<0IVIV06ATI01TI6@00P1RHV82061PH080GUiN
101LG5`205]KF`80F5QH101FEUH205MGE`80Fe]K0P1MGEd205iNGP80GemO00<0HF5Q069RHP1RHV80
101QHF4205mOG`80GUiN0P1MGEd205]KF`80FUYJ101IFET405QHF080FEUI0P1JFUX205]KF`0305eM
G@1PH600H61P0080Hf=S0P1XJ6P206i^KP80MWIf0P23Ph<209FEU@80Y:BT0P2`/;020;Zj^P80`/;2
0P3:b/X20<o?c`80e]KF0P3Ng]h00`3Vi^H0j^[Z0>[ZjP040>[ZjP@0j>SX0P3[jn/20>o_k`80mOGe
0P3hn?P20?_kn`80o?cl0P3jn_X20?Shn080m_Kf0P3gmoL00`3clo<0l?3`0?3`l0020>c/k080inOW
0P3Shn<20=kNgP80f][J0P3Fe]H20=7Ad@80c/k>0P39bLT20<G5a@80`L710P2m_Kd20;Vi^@80][Jf
00<0/[:b0:j^[P2^[Zh00P2ZZZX20:JVYP80Xj>S0P2OWil209^KV`80UiNG5@3oool001<0oooo0P2?
Shl208^;R`80QhN70P22PX8207inOP80NWYj0P1eMGD2075aL@0306e]K@1YJFT0JFUY0080IFEU0P1Q
HF4205aLG080F5QH0P1DE5@2051@D080C4a<0P18B4P204A4A080@4100P0m?Cd203lo?`80@T920P16
ATH00`1;Bd/0D51@051@D00205IFEP80G5aL0P1RHV8206QXJ080Kfm_0P1fMWH207alO080N7Qh0P1f
MWH207=cL`80L71`0P1]KFd206][J`80JFUY00<0IVIV06ATI01TI6@00P1RHV82061PH080GUiN0P1J
FUX205QHF080FEUI0P1GEeL205EEE@80E5AD0P1CDe<205EEE@80F5QH0P1JFUX205]KF`0305iNGP1Q
HF40HF5Q00@0HF5Q0P1OGel205iNGP80G5aL0P1KFe/205YJFP80FEUI0P1HF5P405MGE`80F5QH0P1I
FET205YJFP0305aLG01OGel0GemO0080HV9R0P1VIVH206][J`80Lg=c0P1nOWh2092@T080WinO0P2]
[Jd20;Ng]`80_kno0P37alL20<o?c`80e=CD0P3MgMd00`3Ti>@0k>c/0>c/k0040>_[j`80j^[Z0P3X
j>P20>_[j`80k^k^0P3dm?@20?Shn080no_k0P3moOd20?clo080n_[j103gmoL00`3clo<0kno_0>o_
k`020>_[j`80inOW0P3Rh^820=kNgP80f][J0P3EeMD20=7Ad@80cLg=0P39bLT20<G5a@80`L710P2m
_Kd20;Vi^@80]KFe00<0/[:b0:j^[P2^[Zh00P2ZZZX20:JVYP80Xj>S0P2OWil209^KV`80UiNG5@3o
ool001<0oooo0P2?Shl208^;R`80QhN70P22PX8207inOP80NWYj0P1eMGD2075aL@0306e]K@1YJFT0
JFUY0080IFEU0P1QHF4205aLG080F5QH0P1DE5@2051@D080C4a<0P18B4P204A4A080@4100P0m?Cd2
03lo?`80@T920P16ATH00`1;Bd/0D51@051@D00205IFEP80G5aL0P1RHV8206QXJ080Kfm_0P1fMWH2
07alO080N7Qh0P1fMWH207=cL`80L71`0P1]KFd206][J`80JFUY00<0IVIV06ATI01TI6@00P1RHV82
061PH080GUiN0P1JFUX205QHF080FEUI0P1GEeL205EEE@80E5AD0P1CDe<205EEE@80F5QH0P1JFUX2
05]KF`0305iNGP1QHF40HF5Q00@0HF5Q0P1OGel205iNGP80G5aL0P1KFe/205YJFP80FEUI0P1HF5P4
05MGE`80F5QH0P1IFET205YJFP0305aLG01OGel0GemO0080HV9R0P1VIVH206][J`80Lg=c0P1nOWh2
092@T080WinO0P2][Jd20;Ng]`80_kno0P37alL20<o?c`80e=CD0P3MgMd00`3Ti>@0k>c/0>c/k004
0>_[j`80j^[Z0P3Xj>P20>_[j`80k^k^0P3dm?@20?Shn080no_k0P3moOd20?clo080n_[j103gmoL0
0`3clo<0kno_0>o_k`020>_[j`80inOW0P3Rh^820=kNgP80f][J0P3EeMD20=7Ad@80cLg=0P39bLT2
0<G5a@80`L710P2m_Kd20;Vi^@80]KFe00<0/[:b0:j^[P2^[Zh00P2ZZZX20:JVYP80Xj>S0P2OWil2
09^KV`80UiNG5@3oool001<0oooo0P2?Shl208^;R`80QXJ60P22PX8207emO@80NGUi0P1eMGD2071`
L00306a/K01WIfL0IfMW0080Hf=S0P1OGel205]KF`80EeMG0P1BDU8204i>CP80BTY:0P16ATH20492
@P80?Cdm0P0k>c/203hn?P80@T920P17AdL00`1<C4`0DE5A055AD@0205IFEP80GEeM0P1SHf<206UY
J@80L71`0P1gMgL207]kN`80N7Qh0P1eMGD207=cL`80L71`0P1^KVh206][J`80JFUY00<0IVIV06AT
I01TI6@00P1RHV82061PH080GemO0P1LG5`205YJFP80F5QH0P1GEeL205EEE@@0E5AD0P1EEED205QH
F080FUYJ0P1KFe/00`1LG5`0GUiN05iNGP04061PH080GemO0P1MGEd205aLG080Fe]K101IFET205QH
F0H0EeMG101HF5P00`1JFUX0GEeM05eMG@02061PH080I6AT0P1ZJVX2071`L080NGUi0P2;Rh/209ZJ
VP80ZJVY0P2c/k<20;fm_@80a<C40P3=cLd20=;BdP80f][J00<0h>3P0>_[j`3[jn/0103[jn/20>[Z
jP80j>SX0P3[jn/20>k^kP80lo?c0P3hn?P20?_kn`@0oOgm0P3jn_X20?Ogm`80mOGe00<0lo?c0>o_
k`3_knl00P3Zj^X20>KViP80h^;R0P3MgMd20=WIf@80eMGE0P3AdM420<g=c@80bLW90P35aLD20<71
`@80_Kfm0P2i^KT20;Fe]@030;6a/@2^[Zh0[Zj^0080ZZZZ0P2VYZH20::RXP80WinO0P2KVi/209NG
UaD0oooo000C0?ooo`80Shn?0P2;Rh/208J6QP80PX:20P1mOGd207UiN@80MGEe0P1`L7000`1/K6`0
IfMW06MWI`0206=SH`80GemO0P1KFe/205MGE`80DU9B0P1>CTh204Y:BP80ATI60P12@T8203dm?@80
>c/k0P0n?Sh20492@P80AdM700<0C4a<055AD@1ADE400P1FEUH205eMG@80Hf=S0P1YJFT2071`L080
MgMg0P1kNg/207QhN080MGEe0P1cLg<2071`L080KVi^0P1[Jf/206UYJ@0306IVIP1TI6@0I6AT0080
HV9R0P1PH60205mOG`80G5aL0P1JFUX205QHF080EeMG0P1EEED405ADE080EEEE0P1HF5P205YJFP80
Fe]K00<0G5aL05iNGP1NGUh0101PH60205mOG`80GEeM0P1LG5`205]KF`@0FEUI0P1HF5P605MGE`@0
F5QH00<0FUYJ05eMG@1MGEd00P1PH60206ATI080JVYZ0P1`L70207UiN@80Rh^;0P2JVYX20:VYZ@80
/k>c0P2m_Kd20<C4a080cLg=0P3Bd]820=[JfP030>3Ph03[jn/0jn_[00@0jn_[0P3Zj^X20>SXj080
jn_[0P3^k^h20??cl`80n?Sh0P3kno/40?gmo@80n_[j0P3gmoL20?Gem@030??cl`3_knl0kno_0080
j^[Z0P3Vi^H20>;RhP80gMgM0P3IfMT20=GEe@80dM7A0P3=cLd20<W9b@80aLG50P31`L420;fm_@80
^KVi0P2e]KD00`2a/K40[Zj^0:j^[P020:ZZZP80YZJV0P2RXZ8209nOW`80Vi^K0P2GUiLE0?ooo`00
4`3oool208n?S`80RXZ:0P26QXH20861P@80OGem0P1hN7P207AdM080Kfm_00<0Jf][06IVIP1VIVH0
0P1RHV8205iNGP80FEUI0P1EEED2055AD@80C4a<0P18B4P204A4A080?clo0P0k>c/203Ti>@80?Cdm
0P12@T8204I6AP0304a<C01BDU80DU9B0080EeMG0P1MGEd206=SH`80JVYZ0P1bLW8407UiN@80MgMg
0P1dM7@2079bLP80L71`0P1^KVh206][J`80JFUY00<0IfMW06EUI@1UIFD00P1RHV82065QH@80GemO
0P1MGEd205]KF`80FEUI0P1GEeL205IFEP80EEEE0P1DE5@205IFEP80F5QH0P1IFET205]KF`0305aL
G01NGUh0GUiN00@0GemO0P1NGUh205eMG@80G5aL0P1KFe/205YJFP80FEUI0P1HF5P805MGE`80F5QH
00<0FEUI05]KF`1KFe/00P1NGUh2069RHP80IfMW0P1^KVh207IfMP80QHF50P2FUYH20:FUY@80/;2`
0P2k^k/20<71`@80b/[:0P3@d=020=SHf0030=oOg`3Xj>P0j>SX0080jn_[0P3/k>`20>_[j`80j>SX
0P3Zj^X20>k^kP80l_;b0P3hn?P20?clo080o_kn0P3moOd20?[jnP80n?Sh0P3emOD00`3bl_80k^k^
0>k^kP020>WYj@80iNGU0P3QhN420=gMg@80fMWI0P3De=@20=3@d080c<c<0P38b<P20<C4a080`<30
0P2m_Kd20;Vi^@80]KFe00<0/K6a0:f][@2][Jd00P2ZZZX20:JVYP80XZ:R0P2OWil209^KV`80UiNG
5@3oool001<0oooo0P2?Shl208Z:RP80QXJ60P21PH4207emO@80N7Qh0P1dM7@206m_K`0306][J`1V
IVH0IVIV0080HV9R0P1NGUh205UIF@80EEEE0P1ADE4204a<C080B4Q80P14A4@203lo?`80>c/k0P0i
>CT203dm?@80@T920P16ATH00`1<C4`0DU9B059BDP0205MGE`80GEeM0P1SHf<206YZJP80LW9b101i
NGT207MgM`80M7Ad0P1bLW82071`L080KVi^0P1[Jf/206UYJ@0306MWI`1UIFD0IFEU0080HV9R0P1Q
HF4205mOG`80GEeM0P1KFe/205UIF@80EeMG0P1FEUH205EEE@80E5AD0P1FEUH205QHF080FEUI0P1K
Fe/00`1LG5`0GUiN05iNGP0405mOG`80GUiN0P1MGEd205aLG080Fe]K0P1JFUX205UIF@80F5QH201G
EeL205QHF00305UIF@1KFe/0Fe]K0080GUiN0P1RHV8206MWI`80KVi^0P1fMWH208F5Q@80UYJF0P2U
YJD20;2`/080^k^k0P31`L420<[:bP80d=3@0P3Hf=P00`3Ogml0j>SX0>SXj0020>_[j`80k>c/0P3[
jn/20>SXj080j^[Z0P3^k^h20?;blP80n?Sh0P3lo?`20?knoP80oOgm0P3jn_X20?Shn080mOGe00<0
l_;b0>k^kP3^k^h00P3YjNT20>GUi@80hN7Q0P3MgMd20=WIf@80e=CD0P3@d=020<c<c080b<S80P34
a<@20<30`080_Kfm0P2i^KT20;Fe]@030;6a/@2][Jd0[Jf]0080ZZZZ0P2VYZH20::RXP80WinO0P2K
Vi/209NGUaD0oooo000C0?ooo`80Shn?0P2:RXX208J6QP80PH610P1lO7`207QhN080Lg=c0P1^KVh0
0`1ZJVX0IFEU06EUI@02065QH@80GEeM0P1HF5P205=CD`80Cdm?0P1;Bd/204I6AP80@T920P0m?Cd4
03Ti>@80?Cdm0P12@T8204Q8B00304e=C@1BDU80DU9B0080F5QH0P1NGUh206ATI080Jf][0P1cLg<2
07alO080N7Qh0P1fMWH207AdM080LW9b0P1`L70206i^KP80K6a/0P1ZJVX00`1WIfL0IFEU06EUI@02
06=SH`80HF5Q0P1PH60205iNGP80G5aL0P1KFe/205QHF080EUIF101EEED205IFEP80F5QH0P1IFET2
05]KF`0305aLG01MGEd0GEeM00H0GUiN0P1MGEd205aLG080Fe]K0P1JFUX205UIF@80F5QH201GEeL3
05QHF080FUYJ0P1MGEd2061PH080IFEU0P1[Jf/207=cL`80Ogmo0P2ATI420:6QX@80[:b/0P2g]kL2
0;no_`80alO70P3>c/h20=KFeP030=kNgP3Vi^H0i^KV0080j^[Z103[jn/40>WYj@80k^k^0P3bl_82
0?Shn080no_k0P3no_h20?gmo@80n_[j0P3inOT20?KfmP030?7al@3]kNd0kNg]0080jNWY0P3UiND2
0>3Ph080g=cL0P3Hf=P20=CDe080d=3@0P3<c<`20<S8b080a<C40P30`<020;bl_080^KVi0P2e]KD0
0`2a/K40[Jf]0:f][@020:VYZ@80YZJV0P2RXZ8209jNWP80Vi^K0P2GUiLE0?ooo`004`3oool208n?
S`80RXZ:0P26QXH20861P@80O7al0P1hN7P207=cL`80KVi^00<0JVYZ06EUI@1UIFD00P1QHF4205eM
G@80F5QH0P1CDe<204m?C`80Bd];0P16ATH20492@P80?Cdm100i>CT203dm?@80@T920P18B4P00`1=
CDd0DU9B059BDP0205QHF080GUiN0P1TI6@206][J`80Lg=c0P1lO7`207QhN080MWIf0P1dM7@2079b
LP80L71`0P1^KVh206a/K080JVYZ00<0IfMW06EUI@1UIFD00P1SHf<2065QH@80H61P0P1NGUh205aL
G080Fe]K0P1HF5P205IFEP@0EEEE0P1FEUH205QHF080FEUI0P1KFe/00`1LG5`0GEeM05eMG@0605iN
GP80GEeM0P1LG5`205]KF`80FUYJ0P1IFET205QHF0P0EeMG0`1HF5P205YJFP80GEeM0P1PH60206EU
I@80Jf][0P1cLg<207moO`80TI6A0P2QXJ420:b/[080]kNg0P2o_kl20<O7a`80c/k>0P3Fe]H00`3N
g]h0i^KV0>KViP020>[ZjP@0jn_[103YjNT20>k^kP80l_;b0P3hn?P20?_kn`80o_kn0P3moOd20?[j
nP80nOWi0P3fm_H00`3alO40kNg]0>g]k@020>WYj@80iNGU0P3Ph>020=cLg080f=SH0P3De=@20=3@
d080c<c<0P38b<P20<C4a080`<300P2l_;`20;Vi^@80]KFe00<0/K6a0:f][@2][Jd00P2YZJT20:JV
YP80XZ:R0P2NWYh209^KV`80UiNG5@3oool001<0oooo0P2?Shl208Z:RP80QXJ60P21PH4207alO080
MgMg0P1bLW8206e]K@0306UYJ@1TI6@0I6AT0080GemO0P1KFe/205IFEP80DU9B0P1=CDd204U9B@80
A4A40P10@40203/k>`80=SHf0P0h>3P203dm?@80@D510P18B4P00`1<C4`0DU9B059BDP0205QHF080
GUiN0P1UIFD206a/K080LW9b0P1jNWX207MgM`80MGEe0P1cLg<2075aL@80Kfm_0P1^KVh206a/K080
JVYZ00<0J6QX06IVIP1VIVH00P1TI6@2069RHP80H61P0P1OGel205eMG@80Fe]K0P1IFET205MGE`H0
EUIF0P1HF5P205UIF@80FUYJ00<0G5aL05eMG@1MGEd0201NGUh205eMG@@0Fe]K0P1JFUX205UIF@80
F5QH1P1GEeL205QHF00305UIF@1JFUX0FUYJ0080Fe]K0P1OGel206ATI080JVYZ0P1aLG4207alO080
SHf=0P2LW9`20:ZZZP80];Bd0P2m_Kd20<G5a@80c<c<0P3Cdm<00`3Kfm/0i>CT0>CTi0020>SXj080
j^[Z0P3[jn/20>[ZjP80j>SX0P3]kNd20?;blP80n?Sh0P3lo?`20?ooo`80oOgm0P3inOT20?Shn080
m?Cd00<0l?3`0>c/k03/k>`00P3Xj>P20>?Sh`80gmoO0P3Kfm/20=OGe`80dm?C0P3?cll20<_;b`80
alO70P34a<@20<30`080_;bl0P2h^;P20;Bd]0030;6a/@2][Jd0[Jf]0080ZJVY0P2VYZH20::RXP80
WYjN0P2KVi/209NGUaD0oooo000C0?ooo`80Shn?0P2:RXX208F5Q@80P8200P1kNg/207IfMP80LW9b
0P1]KFd00`1XJ6P0Hf=S06=SH`0205iNGP80FUYJ0P1EEED2051@D080C4a<0P17AdL20492@P80?Shn
0P0i>CT203@d=080=cLg0P0l?3`20492@P80B4Q800<0CDe=05=CD`1CDe<00P1HF5P205eMG@80IFEU
0P1[Jf/2075aL@@0MGEe0P1dM7@2079bLP80L71`0P1_Kfl206i^KP80K6a/0P1ZJVX00`1YJFT0IfMW
06MWI`0206EUI@80Hf=S0P1QHF4205mOG`80GUiN0P1LG5`205UIF@80EeMG1P1FEUH205QHF080FEUI
0P1KFe/00`1LG5`0GUiN05iNGP0805iNGP80GEeM0P1LG5`405]KF`80FUYJ0P1IFET805QHF00305UI
F@1JFUX0FUYJ0080G5aL0P1NGUh2069RHP80JFUY0P1`L70207QhN080RHV90P2IVIT20:JVYP80/[:b
0P2k^k/20<?3``80c<c<0P3Bd]800`3Jf]X0h^;R0>;RhP020>OWi`80jNWY103Zj^X20>SXj080kNg]
0P3alO420?Shn080o?cl0P3oool20?gmo@80n_[j0P3hn?P20?Cdm0030>o_k`3[jn/0jn_[0080inOW
0P3Shn<20=oOg`80f][J0P3Fe]H20=;BdP80clo?0P3;bl/20<O7a`80`l?30P2o_kl20;^k^`80^;Rh
0P2d];@00`2`/;00[Jf]0:f][@020:VYZ@80YJFU0P2RXZ8209jNWP80Vi^K0P2GUiLE0?ooo`004`3o
ool208n?S`80RXZ:0P25QHD20820P080Ng]k0P1fMWH2079bLP80KFe]00<0J6QX06=SH`1SHf<00P1N
GUh205YJFP80EEEE0P1@D50204a<C080AdM70P12@T8203hn?P80>CTi0P0d=3@203Lg=`80?3`l0P12
@T8204Q8B00304e=C@1CDe<0De=C0080F5QH0P1MGEd206EUI@80Jf][0P1aLG4407EeM@80M7Ad0P1b
LW82071`L080Kfm_0P1^KVh206a/K080JVYZ00<0JFUY06MWI`1WIfL00P1UIFD206=SH`80HF5Q0P1O
Gel205iNGP80G5aL0P1IFET205MGE`H0EUIF0P1HF5P205UIF@80Fe]K00<0G5aL05iNGP1NGUh0201N
GUh205eMG@80G5aL101KFe/205YJFP80FEUI201HF5P00`1IFET0FUYJ05YJFP0205aLG080GUiN0P1R
HV8206UYJ@80L71`0P1hN7P208V9R@80VIVI0P2VYZH20;:b/P80^k^k0P33`l<20<c<c080d];B00<0
f][J0>;RhP3Rh^800P3WinL20>WYj@@0j^[Z0P3Xj>P20>g]k@80lO7a0P3hn?P20?clo080oooo0P3m
oOd20?[jnP80n?Sh0P3dm?@00`3_knl0jn_[0>_[j`020>OWi`80hn?S0P3Ogml20=[JfP80e]KF0P3B
d]820<o?c`80bl_;0P37alL20<?3``80_kno0P2k^k/20;Rh^080];Bd00<0/;2`0:f][@2][Jd00P2Y
ZJT20:FUY@80XZ:R0P2NWYh209^KV`80UiNG5@3oool001<0oooo0P2?Shl208Z:RP80QHF50P20P802
07]kN`80MWIf0P1aLG4206a/K00306MWI`1RHV80HV9R0080GEeM0P1HF5P205ADE080Cdm?0P1:BTX2
04E5A@80@4100P0l?3`203Lg=`80=3@d0P0g=cL203`l?080@d=30P18B4P00`1=CDd0De=C05=CD`02
05UIF@80GemO0P1UIFD206a/K080Kfm_1P1bLW82075aL@80L71`0P1_Kfl406e]K@80K6a/00<0JVYZ
06QXJ01XJ6P00P1VIVH206ATI080HV9R0P1PH60205iNGP80GEeM0P1JFUX205QHF080EUIF0P1EEED2
05IFEP80F5QH0P1JFUX205]KF`0305eMG@1NGUh0GUiN00@0GemO1P1NGUh405eMG@80G5aL0P1KFe/4
05YJFPL0FEUI0P1JFUX205aLG080GUiN0P1QHF4206MWI`80Kfm_0P1gMgL208B4Q080U9BD0P2RXZ82
0:j^[P80^KVi0P31`L420<[:bP80dM7A00<0fMWI0>7Qh@3QhN400P3Vi^H20>SXj080j^[Z0P3[jn/2
0>SXj080k>c/0P3alO420?Shn080o?cl0P3oool20?knoP80n_[j0P3gmoL20??cl`030>k^kP3Zj^X0
j^[Z0080i^KV0P3Rh^820=kNgP80f][J0P3Fe]H20=;BdP80c/k>0P3:b/X20<K6aP80`l?30P2o_kl2
0;^k^`80]kNg0P2d];@00`2`/;00[Jf]0:f][@020:VYZ@80YJFU0P2RXZ8209jNWP80VYZJ0P2GUiLE
0?ooo`004`3oool208n?S`80RXZ:0P25QHD20820P080Ng]k0P1fMWH2075aL@80K6a/00<0IfMW069R
HP1RHV800P1MGEd205QHF080E5AD0P1?Cdl204Y:BP80ADE50P10@40203`l?080=cLg0P0d=3@203Lg
=`80?3`l0P13@d<204Q8B00304e=C@1CDe<0De=C0080FEUI0P1OGel206EUI@80K6a/0P1_Kfl6079b
LP80LG5a0P1`L70206m_K`@0KFe]0P1/K6`00`1ZJVX0J6QX06QXJ00206IVIP80I6AT0P1RHV82061P
H080GUiN0P1MGEd205YJFP80F5QH0P1FEUH205EEE@80EUIF0P1HF5P205YJFP80Fe]K00<0GEeM05iN
GP1NGUh0101OGel605iNGP@0GEeM0P1LG5`205]KF`@0FUYJ1`1IFET205YJFP80G5aL0P1NGUh2065Q
H@80IfMW0P1_Kfl207MgM`80Q8B40P2DU9@20::RXP80[Zj^0P2i^KT20<71`@80b/[:0P3AdM400`3I
fMT0hN7Q0>7Qh@020>KViP80j>SX0P3Zj^X20>_[j`80j>SX0P3/k>`20?7al@80n?Sh0P3lo?`20?oo
o`80o_kn0P3jn_X20?Ogm`80lo?c00<0k^k^0>[ZjP3Zj^X00P3Vi^H20>;RhP80g]kN0P3Jf]X20=KF
eP80d];B0P3>c/h20<[:bP80a/K60P33`l<20;no_`80^k^k0P2g]kL20;Bd]0030;2`/02][Jd0[Jf]
0080ZJVY0P2UYJD20::RXP80WYjN0P2JVYX209NGUaD0oooo000C0?ooo`80Shn?0P2:RXX208B4Q080
P8200P1jNWX207EeM@80L71`0P1[Jf/00`1VIVH0HF5Q065QH@0205aLG080EeMG0P1BDU8204e=C@80
B4Q80P13@d<203hn?P80>CTi0P0d=3@203De=@80>3Ph0P0m?Cd204A4A080BDU900<0CTi>05ADE01D
E5@00P1HF5P205mOG`80IVIV101`L706075aL@@0L71`0P1_Kfl206i^KP80KFe]0P1/K6`00`1[Jf/0
JFUY06UYJ@0206QXJ080IVIV0P1TI6@2069RHP80GemO0P1NGUh205]KF`80F5QH101FEUH205MGE`80
FEUI0P1JFUX205]KF`0305eMG@1OGel0GemO0080GemO101PH60605mOG`@0GUiN0P1MGEd405aLG080
Fe]K1@1JFUX205]KF`80GEeM0P1OGel2065QH@80IfMW0P1^KVh207MgM`80Ph>30P2BTY820:2PX080
[Jf]0P2g]kL20<30`080bLW90P3@d=000`3Hf=P0h>3P0>3Ph0020>GUi@80inOW0P3YjNT20>_[j`80
jNWY0P3/k>`20?3`l080n?Sh0P3lo?`20?ooo`80o_kn0P3kno/20?KfmP80l_;b00<0k^k^0>WYj@3Y
jNT00P3UiND20>7Qh@80gMgM0P3IfMT20=GEe@80dM7A0P3=cLd20<W9b@80aLG50P32`/820;jn_P80
^k^k0P2g]kL20;>c/`030;2`/02/[:`0[:b/0080ZJVY0P2UYJD20::RXP80WYjN0P2JVYX209NGUaD0
oooo000C0?ooo`80Shn?0P2:RXX208B4Q080P8200P1jNWX207EeM@80L71`0P1[Jf/00`1VIVH0HF5Q
065QH@0205aLG080EeMG0P1BDU8204e=C@80B4Q80P13@d<203hn?P80>CTi0P0d=3@203De=@80>3Ph
0P0m?Cd204A4A080BDU900<0CTi>05ADE01DE5@00P1HF5P205mOG`80IVIV101`L706075aL@@0L71`
0P1_Kfl206i^KP80KFe]0P1/K6`00`1[Jf/0JFUY06UYJ@0206QXJ080IVIV0P1TI6@2069RHP80GemO
0P1NGUh205]KF`80F5QH101FEUH205MGE`80FEUI0P1JFUX205]KF`0305eMG@1OGel0GemO0080GemO
101PH60605mOG`@0GUiN0P1MGEd405aLG080Fe]K1@1JFUX205]KF`80GEeM0P1OGel2065QH@80IfMW
0P1^KVh207MgM`80Ph>30P2BTY820:2PX080[Jf]0P2g]kL20<30`080bLW90P3@d=000`3Hf=P0h>3P
0>3Ph0020>GUi@80inOW0P3YjNT20>_[j`80jNWY0P3/k>`20?3`l080n?Sh0P3lo?`20?ooo`80o_kn
0P3kno/20?KfmP80l_;b00<0k^k^0>WYj@3YjNT00P3UiND20>7Qh@80gMgM0P3IfMT20=GEe@80dM7A
0P3=cLd20<W9b@80aLG50P32`/820;jn_P80^k^k0P2g]kL20;>c/`030;2`/02/[:`0[:b/0080ZJVY
0P2UYJD20::RXP80WYjN0P2JVYX209NGUaD0oooo000C0?ooo`80SXj>0P29RHT208B4Q080Ogmo0P1j
NWX207EeM@80Kfm_0P1ZJVX00`1UIFD0H61P061PH00205]KF`80EEEE0P1@D50204a<C080ATI60P11
@D4203`l?080=cLg0P0`<30203<c<`80=cLg0P0m?Cd204A4A080BDU900<0Cdm?05EEE@1EEED00P1J
FUX2065QH@80J6QX0P1^KVh206m_K`P0L71`101_Kfl406i^KP80KFe]00<0K6a/06][J`1[Jf/00P1Z
JVX206MWI`80IFEU0P1SHf<2065QH@80GemO0P1LG5`205YJFP80EeMG0P1FEUH205MGE`80FEUI0P1K
Fe/205aLG00305iNGP1OGel0GemO0080H61P201QHF48061PH080GemO101NGUh205eMG@<0G5aL0P1M
GEd205iNGP80H61P0P1RHV8206MWI`80KFe]0P1fMWH208:2PP80T92@0P2NWYh20:^[Z`80][Jf0P30
`<020<S8b080d=3@00<0fMWI0>3Ph03Ph>000P3Ti>@20>KViP80jNWY103Zj^X20>_[j`80l?3`0P3g
moL20?clo0@0oooo0P3jn_X20?KfmP80lO7a00<0kNg]0>SXj03Xj>P00P3Ti>@20>3Ph080g=cL0P3H
f=P20=CDe080d=3@0P3<c<`20<W9b@80aLG50P31`L420;jn_P80^[Zj0P2f][H20;>c/`030:n_[`2/
[:`0[:b/0080Z:RX0P2UYJD20:6QX@80WYjN0P2JVYX209NGUaD0oooo000C0?ooo`80SXj>0P29RHT2
08B4Q080Ogmo0P1jNWX207EeM@80Kfm_0P1ZJVX00`1UIFD0H61P061PH00205]KF`80EEEE0P1@D502
04a<C080ATI60P11@D4203`l?080=cLg0P0`<30203<c<`80=cLg0P0m?Cd204A4A080BDU900<0Cdm?
05EEE@1EEED00P1JFUX2065QH@80J6QX0P1^KVh206m_K`P0L71`101_Kfl406i^KP80KFe]00<0K6a/
06][J`1[Jf/00P1ZJVX206MWI`80IFEU0P1SHf<2065QH@80GemO0P1LG5`205YJFP80EeMG0P1FEUH2
05MGE`80FEUI0P1KFe/205aLG00305iNGP1OGel0GemO0080H61P201QHF48061PH080GemO101NGUh2
05eMG@<0G5aL0P1MGEd205iNGP80H61P0P1RHV8206MWI`80KFe]0P1fMWH208:2PP80T92@0P2NWYh2
0:^[Z`80][Jf0P30`<020<S8b080d=3@00<0fMWI0>3Ph03Ph>000P3Ti>@20>KViP80jNWY103Zj^X2
0>_[j`80l?3`0P3gmoL20?clo0@0oooo0P3jn_X20?KfmP80lO7a00<0kNg]0>SXj03Xj>P00P3Ti>@2
0>3Ph080g=cL0P3Hf=P20=CDe080d=3@0P3<c<`20<W9b@80aLG50P31`L420;jn_P80^[Zj0P2f][H2
0;>c/`030:n_[`2/[:`0[:b/0080Z:RX0P2UYJD20:6QX@80WYjN0P2JVYX209NGUaD0oooo000C0?oo
o`80SXj>0P29RHT208B4Q080OWin0P1iNGT207AdM080Kfm_0P1YJFT00`1TI6@0GemO05mOG`0205UI
F@80E5AD0P1?Cdl204Y:BP80ADE50P0o?cl203Xj>P80=CDe0P0`<30203<c<`80=cLg0P0m?Cd204A4
A080Bd];00<0D51@05IFEP1FEUH00P1MGEd2069RHP80JFUY0P1/K6`206i^KPH0Kfm_0P1`L70606m_
K`D0KVi^0P1]KFd206a/K080JVYZ0P1WIfL206EUI@80HV9R0P1PH60205eMG@80FUYJ0P1GEeL205EE
E@80EUIF0P1HF5P205]KF`80G5aL00<0GUiN061PH01PH600101QHF4@069RHP@0HF5Q0P1PH60205mO
G`<0GUiN0P1OGel2065QH@80Hf=S0P1VIVH206e]K@80MGEe0P20P80208j>SP80W9bL0P2ZZZX20;Jf
]P80`<300P38b<P20=3@d0030=WIf@3Rh^80h^;R0080hn?S0P3Vi^H20>SXj080j^[Z0P3/k>`20>_[
j`80l_;b0P3gmoL20?_kn`@0o_kn0P3jn_X20?Gem@80l?3`00<0k>c/0>OWi`3WinL00P3Shn<20=oO
g`80fm_K0P3GemL20=?Cd`80clo?0P3<c<`20<S8b080a<C40P31`L420;fm_@80^[Zj0P2f][H20;>c
/`030:n_[`2[Zj/0Zj^[0080Z:RX0P2UYJD20:6QX@80WYjN0P2JVYX209NGUaD0oooo000C0?ooo`80
SXj>0P29RHT208B4Q080OWin0P1iNGT207AdM080Kfm_0P1YJFT00`1TI6@0GemO05mOG`0205UIF@80
E5AD0P1?Cdl204Y:BP80ADE50P0o?cl203Xj>P80=CDe0P0`<30203<c<`80=cLg0P0m?Cd204A4A080
Bd];00<0D51@05IFEP1FEUH00P1MGEd2069RHP80JFUY0P1/K6`206i^KPH0Kfm_0P1`L70606m_K`D0
KVi^0P1]KFd206a/K080JVYZ0P1WIfL206EUI@80HV9R0P1PH60205eMG@80FUYJ0P1GEeL205EEE@80
EUIF0P1HF5P205]KF`80G5aL00<0GUiN061PH01PH600101QHF4@069RHP@0HF5Q0P1PH60205mOG`<0
GUiN0P1OGel2065QH@80Hf=S0P1VIVH206e]K@80MGEe0P20P80208j>SP80W9bL0P2ZZZX20;Jf]P80
`<300P38b<P20=3@d0030=WIf@3Rh^80h^;R0080hn?S0P3Vi^H20>SXj080j^[Z0P3/k>`20>_[j`80
l_;b0P3gmoL20?_kn`@0o_kn0P3jn_X20?Gem@80l?3`00<0k>c/0>OWi`3WinL00P3Shn<20=oOg`80
fm_K0P3GemL20=?Cd`80clo?0P3<c<`20<S8b080a<C40P31`L420;fm_@80^[Zj0P2f][H20;>c/`03
0:n_[`2[Zj/0Zj^[0080Z:RX0P2UYJD20:6QX@80WYjN0P2JVYX209NGUaD0oooo000C0?ooo`80SXj>
0P29RHT208>3P`80OWin0P1hN7P207=cL`80KVi^0P1XJ6P00`1SHf<0GUiN05iNGP0205QHF080De=C
0P1>CTh204Q8B080@d=30P0n?Sh203Ti>@80=3@d0P0a<C4203De=@80>3Ph0P0n?Sh204A4A080Bd];
00<0DE5A05QHF01HF5P00P1OGel206IVIP80JVYZ0P1/K6`206e]K@@0KVi^4@1_Kfl206i^KP80K6a/
0P1ZJVX206MWI`80I6AT0P1QHF4205iNGP80Fe]K0P1HF5P405EEE@80EeMG0P1JFUX205aLG00305iN
GP1PH600H61P0080HF5Q101RHV8406=SH`80I6AT201UIFD406ATI080HV9R0`1QHF42061PH080HF5Q
0P1RHV8206ATI080IfMW0P1]KFd207EeM@80Ogmo0P2<S8`209^KV`80Z:RX0P2e]KD20;no_`80alO7
0P3?cll00`3Hf=P0hN7Q0>7Qh@020>?Sh`80i^KV0P3Xj>P20>[ZjP80k^k^0P3[jn/20??cl`80moOg
0P3jn_X40?gmo@80n?Sh0P3clo<20>o_k`030>_[j`3Vi^H0i^KV0080h^;R0P3Ng]h20=[JfP80e]KF
0P3Bd]820<o?c`80bl_;0P37alL20<?3``80`<300P2l_;`20;Vi^@80]KFe0P2b/[800`2_[jl0Zj^[
0:^[Z`020:RXZ080Y:BT0P2QXJ4209jNWP80VYZJ0P2GUiLE0?ooo`004`3oool208j>SP80RHV90P23
Ph<207inOP80N7Qh0P1cLg<206i^KP80J6QX00<0Hf=S05iNGP1NGUh00P1HF5P205=CD`80CTi>0P18
B4P204=3@`80?Shn0P0i>CT203@d=080<C4a0P0e=CD203Ph>080?Shn0P14A4@204];B`03055AD@1H
F5P0F5QH0080GemO0P1VIVH206YZJP80K6a/0P1]KFd406i^KQ40Kfm_0P1^KVh206a/K080JVYZ0P1W
IfL206ATI080HF5Q0P1NGUh205]KF`80F5QH101EEED205MGE`80FUYJ0P1LG5`00`1NGUh0H61P061P
H002065QH@@0HV9R101SHf<206ATI0P0IFEU101TI6@2069RHP<0HF5Q0P1PH602065QH@80HV9R0P1T
I6@206MWI`80KFe]0P1eMGD207moO`80S8b<0P2KVi/20:RXZ080]KFe0P2o_kl20<O7a`80clo?00<0
f=SH0>7Qh@3QhN400P3Shn<20>KViP80j>SX0P3Zj^X20>k^kP80jn_[0P3clo<20?Ogm`80n_[j103m
oOd20?Shn080lo?c0P3_knl00`3[jn/0i^KV0>KViP020>;RhP80g]kN0P3Jf]X20=KFeP80d];B0P3?
cll20<_;b`80alO70P33`l<20<30`080_;bl0P2i^KT20;Fe]@80/[:b00<0[jn_0:^[Z`2[Zj/00P2X
Z:P20:BTY080XJ6Q0P2NWYh209ZJVP80UiNG5@3oool001<0oooo0P2>SXh208R8R080Ph>30P1mOGd2
07QhN080LW9b0P1]KFd206MWI`03069RHP1LG5`0G5aL0080EeMG0P1BDU8204a<C080AdM70P11@D42
03`l?080=cLg0P0a<C42038b<P80=3@d0P0i>CT20410@080ADE50P1<C4`00`1BDU80FUYJ05YJFP02
065QH@80JVYZ0P1[Jf/206a/K0X0KVi^1P1_Kfl4071`L0<0LG5a0P1`L70206i^KP80K6a/0P1YJFT2
06EUI@80HV9R0P1OGel205]KF`80F5QH101EEED205IFEP80F5QH0P1KFe/00`1MGEd0GemO05mOG`02
065QH@@0HV9R0P1SHf<206ATI080IVIV0P1WIfL806QXJ080IfMW0P1VIVH206ATI0D0Hf=S0P1TI6@2
06EUI@80JFUY0P1]KFd207EeM@80Ogmo0P2:RXX209VIV@80YjNW0P2d];@20;no_`80alO70P3?cll0
0`3GemL0h>3P0>3Ph0020>;RhP80iNGU0P3Xj>P20>WYj@80kno_0P3[jn/20?;blP80n?Sh0P3jn_X4
0?_kn`80m_Kf0P3bl_820>g]k@030>WYj@3UiND0iNGU0080hN7Q0P3MgMd20=WIf@80eMGE0P3AdM42
0<k>cP80b/[:0P36a/H20<?3``80_kno0P2l_;`20;Rh^080]KFe0P2b/[800`2^[Zh0Zj^[0:^[Z`02
0:NWY`80Y:BT0P2QXJ4209fMW@80VYZJ0P2GUiLE0?ooo`004`3oool208j>SP80R8R80P23Ph<207em
O@80N7Qh0P1bLW8206e]K@80IfMW00<0HV9R05aLG01LG5`00P1GEeL2059BDP80C4a<0P17AdL20451
@@80?3`l0P0g=cL2034a<@80<S8b0P0d=3@203Ti>@80@4100P15ADD204a<C003059BDP1JFUX0FUYJ
0080HF5Q0P1ZJVX206][J`80K6a/2P1^KVh606m_K`@0L71`0`1aLG42071`L080KVi^0P1/K6`206UY
J@80IFEU0P1RHV8205mOG`80Fe]K0P1HF5P405EEE@80EUIF0P1HF5P205]KF`0305eMG@1OGel0GemO
0080HF5Q101RHV8206=SH`80I6AT0P1VIVH206MWI`P0J6QX0P1WIfL206IVIP80I6AT1@1SHf<206AT
I080IFEU0P1YJFT206e]K@80MGEe0P1oOgl208Z:RP80VIVI0P2WYjL20;Bd]080_kno0P37alL20<o?
c`030=OGe`3Ph>00h>3P0080h^;R0P3UiND20>SXj080jNWY0P3_knl20>_[j`80l_;b0P3hn?P20?[j
nP@0no_k0P3fm_H20?;blP80kNg]00<0jNWY0>GUi@3UiND00P3QhN420=gMg@80fMWI0P3EeMD20=7A
d@80c/k>0P3:b/X20<K6aP80`l?30P2o_kl20;bl_080^;Rh0P2e]KD20;:b/P030:j^[P2[Zj/0Zj^[
0080YjNW0P2TY:@20:6QX@80WIfM0P2JVYX209NGUaD0oooo000C0?ooo`80SXj>0P28R8P208:2PP80
OGem0P1gMgL2075aL@80K6a/0P1VIVH00`1QHF40Fe]K05]KF`0205IFEP80D51@0P1;Bd/204E5A@80
@4100P0j>SX203De=@80;Rh^0P0d=3@203De=@80>SXj0P11@D4204M7A`80CDe=00<0E5AD05eMG@1M
GEd00P1SHf<206UYJ@80Jf][0P1]KFd206i^KPP0KFe]0P1^KVh206m_K`80L71`101aLG400`1bLW80
Lg=c07=cL`0207=cL`80LG5a0P1^KVh206][J`80IfMW0P1SHf<2061PH080Fe]K0P1HF5P205ADE080
De=C0P1DE5@205MGE`80FEUI00<0G5aL05iNGP1NGUh00P1PH602065QH@80HV9R0P1SHf<206ATI080
IfMW0P1YJFT206YZJP80Jf][101/K6`206][J`80JFUY0P1XJ6P00`1VIVH0IFEU06EUI@0406EUI@80
IfMW0P1ZJVX206m_K`80MGEe0P1nOWh208R8R080UYJF0P2VYZH20;>c/`80_[jn0P37alL20<o?c`03
0=OGe`3Ph>00h>3P0080h^;R0P3Ti>@40>SXj080kno_0P3[jn/20?7al@80n?Sh0P3jn_X20?_kn`80
nOWi0P3emOD20?3`l080k>c/00<0j>SX0>CTi03Ti>@00P3Ph>020=cLg080f=SH0P3De=@20=3@d080
cLg=0P39bLT20<K6aP80`/;20P2o_kl20;^k^`80^;Rh0P2d];@20;6a/@030:j^[P2[Zj/0Zj^[0080
YjNW0P2TY:@20:6QX@80WIfM0P2JVYX209NGUaD0oooo000C0?ooo`80SXj>0P28R8P208:2PP80OGem
0P1gMgL2075aL@80K6a/0P1VIVH00`1QHF40Fe]K05]KF`0205IFEP80D51@0P1;Bd/204E5A@80@410
0P0j>SX203De=@80;Rh^0P0d=3@203De=@80>SXj0P11@D4204M7A`80CDe=00<0E5AD05eMG@1MGEd0
0P1SHf<206UYJ@80Jf][0P1]KFd206i^KPP0KFe]0P1^KVh206m_K`80L71`101aLG400`1bLW80Lg=c
07=cL`0207=cL`80LG5a0P1^KVh206][J`80IfMW0P1SHf<2061PH080Fe]K0P1HF5P205ADE080De=C
0P1DE5@205MGE`80FEUI00<0G5aL05iNGP1NGUh00P1PH602065QH@80HV9R0P1SHf<206ATI080IfMW
0P1YJFT206YZJP80Jf][101/K6`206][J`80JFUY0P1XJ6P00`1VIVH0IFEU06EUI@0406EUI@80IfMW
0P1ZJVX206m_K`80MGEe0P1nOWh208R8R080UYJF0P2VYZH20;>c/`80_[jn0P37alL20<o?c`030=OG
e`3Ph>00h>3P0080h^;R0P3Ti>@40>SXj080kno_0P3[jn/20?7al@80n?Sh0P3jn_X20?_kn`80nOWi
0P3emOD20?3`l080k>c/00<0j>SX0>CTi03Ti>@00P3Ph>020=cLg080f=SH0P3De=@20=3@d080cLg=
0P39bLT20<K6aP80`/;20P2o_kl20;^k^`80^;Rh0P2d];@20;6a/@030:j^[P2[Zj/0Zj^[0080YjNW
0P2TY:@20:6QX@80WIfM0P2JVYX209NGUaD0oooo000C0?ooo`80SXj>0P28R8P208:2PP80O7al0P1f
MWH2075aL@80Jf][0P1UIFD00`1PH600FUYJ05YJFP0205ADE080Cdm?0P19BDT204=3@`80?Shn0P0h
>3P203<c<`80;2`/0P0c<c<203Hf=P80?Cdm0P13@d<204U9B@80Cdm?00<0EeMG05mOG`1OGel00P1W
IfL206QXJ080K6a/0P1^KVh206e]K@P0K6a/0P1]KFd206i^KP80L71`0P1aLG42079bLP0307=cL`1d
M7@0M7Ad0080M7Ad0P1cLg<2071`L080K6a/0P1WIfL206ATI080H61P0P1KFe/205MGE`80De=C0P1A
DE42059BDP80E5AD0P1GEeL00`1IFET0G5aL05aLG00205mOG`80H61P0P1QHF42069RHP80Hf=S0P1V
IVH206YZJP80Jf][0P1/K6`206e]K@@0KVi^0P1/K6`206YZJP0306UYJ@1XJ6P0J6QX00@0IfMW0P1X
J6P206][J`80L71`0P1fMWH207inOP80R8R80P2DU9@20::RXP80/K6a0P2n_[h20<O7a`80clo?00<0
e]KF0=kNgP3Ng]h00P3Rh^820>?Sh`80i^KV0P3Xj>P20>k^kP80jn_[0P3alO420?Shn080nOWi0P3j
n_X20?Shn080lo?c0P3^k^h20>[ZjP030>KViP3Rh^80h^;R0080g]kN0P3Jf]X20=OGe`80dm?C0P3?
cll20<c<c080b<S80P35aLD20<71`@80_[jn0P2j^[X20;Ng]`80];Bd0P2a/K400`2][Jd0ZZZZ0:ZZ
ZP020:NWY`80Y:BT0P2PX:0209fMW@80VYZJ0P2GUiLE0?ooo`004`3oool208j>SP80R8R80P22PX82
07alO080MWIf0P1aLG4206][J`80IFEU00<0H61P05YJFP1JFUX00P1DE5@204m?C`80BDU90P13@d<2
03hn?P80>3Ph0P0c<c<202`/;080<c<c0P0f=SH203dm?@80@d=30P19BDT204m?C`0305MGE`1OGel0
GemO0080IfMW0P1XJ6P206a/K080KVi^0P1]KFd806a/K080KFe]0P1^KVh2071`L080LG5a0P1bLW80
0`1cLg<0M7Ad07AdM00207AdM080Lg=c0P1`L70206a/K080IfMW0P1TI6@2061PH080Fe]K0P1GEeL2
05=CD`80DE5A0P1BDU8205ADE080EeMG00<0FEUI05aLG01LG5`00P1OGel2061PH080HF5Q0P1RHV82
06=SH`80IVIV0P1ZJVX206][J`80K6a/0P1]KFd406i^KP80K6a/0P1ZJVX00`1YJFT0J6QX06QXJ004
06MWI`80J6QX0P1[Jf/2071`L080MWIf0P1nOWh208R8R080U9BD0P2RXZ820;6a/@80_[jn0P37alL2
0<o?c`030=KFeP3Ng]h0g]kN0080h^;R0P3Shn<20>KViP80j>SX0P3^k^h20>_[j`80lO7a0P3hn?P2
0?Win@80n_[j0P3hn?P20??cl`80k^k^0P3Zj^X00`3Vi^H0h^;R0>;RhP020=kNgP80f][J0P3GemL2
0=?Cd`80clo?0P3<c<`20<S8b080aLG50P31`L420;jn_P80^[Zj0P2g]kL20;Bd]080/K6a00<0[Jf]
0:ZZZP2ZZZX00P2WYjL20:BTY080X:2P0P2MWId209ZJVP80UiNG5@3oool001<0oooo0P2>SXh208R8
R080PX:20P1lO7`207IfMP80L71`0P1ZJVX206ATI00305mOG`1IFET0FEUI0080De=C0P1=CDd204Q8
B080@T920P0l?3`203Lg=`80<S8b0P0_;bl2038b<P80=SHf0P0n?Sh204A4A080Bd];0P1@D5000`1J
FUX0HF5Q065QH@0206IVIP80IfMW0P1[Jf/406e]K@@0Jf][0P1ZJVX206][J`80K6a/0P1^KVh206e]
K@80K6a/0P1_Kfl00`1cLg<0M7Ad07AdM00207EeM@80Lg=c0P1bLW8206i^KP80J6QX0P1TI6@205mO
G`80FUYJ0P1FEUH2059BDP80Cdm?0P1>CTh2051@D080De=C00<0EeMG05UIF@1IFET00P1NGUh2061P
H080GemO0P1NGUh205mOG`80Hf=S0P1XJ6P206YZJP80K6a/0P1]KFd206m_K`80L71`0P1^KVh206a/
K00306YZJP1YJFT0JFUY00@0JFUY0P1ZJVX206a/K080LG5a0P1gMgL207moO`80R8R80P2DU9@20:2P
X080/;2`0P2m_Kd20<K6aP80clo?00<0e]KF0=gMg@3MgMd00P3Ph>020>;RhP80i^KV0P3Xj>P20>k^
kP80jn_[0P3`l?020?KfmP80moOg0P3hn?P20?KfmP80lO7a0P3]kNd20>WYj@030>GUi@3QhN40hN7Q
0080gMgM0P3IfMT20=GEe@80d];B0P3>c/h20<_;b`80alO70P34a<@20<30`080_Kfm0P2j^[X20;Ng
]`80/k>c0P2`/;000`2][Jd0ZZZZ0:ZZZP020:JVYP80Xj>S0P2PX:0209fMW@80VYZJ0P2GUiLE0?oo
o`004`3oool208j>SP80R8R80P22PX8207alO080MWIf0P1`L70206YZJP80I6AT00<0GemO05UIF@1I
FET00P1CDe<204e=C@80B4Q80P12@T8203`l?080=cLg0P0b<S8202l_;`80<S8b0P0f=SH203hn?P80
A4A40P1;Bd/2051@D00305YJFP1QHF40HF5Q0080IVIV0P1WIfL206][J`@0KFe]101[Jf/206YZJP80
Jf][0P1/K6`206i^KP80KFe]0P1/K6`206m_K`0307=cL`1dM7@0M7Ad0080MGEe0P1cLg<2079bLP80
KVi^0P1XJ6P206ATI080GemO0P1JFUX205IFEP80DU9B0P1?Cdl204i>CP80D51@0P1CDe<00`1GEeL0
FEUI05UIF@0205iNGP80H61P0P1OGel205iNGP80GemO0P1SHf<206QXJ080JVYZ0P1/K6`206e]K@80
Kfm_0P1`L70206i^KP80K6a/00<0JVYZ06UYJ@1YJFT0101YJFT206YZJP80K6a/0P1aLG4207MgM`80
Ogmo0P28R8P209BDU080X:2P0P2`/;020;fm_@80a/K60P3?cll00`3Fe]H0gMgM0=gMg@020>3Ph080
h^;R0P3Vi^H20>SXj080k^k^0P3[jn/20?3`l080m_Kf0P3gmoL20?Shn080m_Kf0P3alO420>g]k@80
jNWY00<0iNGU0>7Qh@3QhN400P3MgMd20=WIf@80eMGE0P3Bd]820<k>cP80bl_;0P37alL20<C4a080
`<300P2m_Kd20;Zj^P80]kNg0P2c/k<20;2`/0030:f][@2ZZZX0ZZZZ0080YZJV0P2SXj<20:2PX080
WIfM0P2JVYX209NGUaD0oooo000C0?ooo`80SHf=0P27QhL20861P@80Ng]k0P1eMGD206m_K`80JFUY
0P1SHf<00`1MGEd0EeMG05MGE`02059BDP80C4a<0P16ATH20410@080>c/k0P0e=CD402h^;P80<C4a
0P0f=SH203dm?@80ATI60P1=CDd2059BDP0305eMG@1WIfL0IfMW0080IVIV0P1XJ6P206YZJP80KFe]
0P1[Jf/206YZJP80JFUY101XJ6P206UYJ@80Jf][0P1ZJVX206QXJ080JVYZ00<0KFe]075aL@1aLG40
0P1bLW82075aL@80Kfm_0P1]KFd206QXJ080Hf=S0P1NGUh205UIF@80E5AD0P1@D50204e=C@80Bd];
0P1<C4`204i>CP<0DU9B0P1EEED205]KF`80FUYJ0P1IFET205]KF`80GUiN0P1SHf<206IVIP@0JFUY
0P1]KFd406m_K`80K6a/00<0Jf][06YZJP1ZJVX00P1YJFT206YZJP80Jf][0P1]KFd2075aL@80N7Qh
0P1oOgl208V9R@80U9BD0P2PX:020:n_[`80_;bl0P35aLD20<k>cP030=KFeP3Lg=`0g=cL0080gmoO
0P3Rh^820>GUi@80inOW0P3]kNd20>_[j`80l_;b0P3emOD20?KfmP80moOg0P3clo<20>o_k`80jn_[
0P3WinL00`3Shn<0gmoO0=oOg`020=_Kf`80f=SH0P3De=@20=7Ad@80cLg=0P3:b/X20<K6aP80`l?3
0P30`<020;bl_080^KVi0P2f][H20;>c/`80/;2`00<0[:b/0:VYZ@2YZJT00P2VYZH20:>SX`80X:2P
0P2MWId209ZJVP80UiNG5@3oool001<0oooo0P2=SHd208N7Q`80PH610P1kNg/207EeM@80Kfm_0P1Y
JFT206=SH`0305eMG@1GEeL0EeMG0080DU9B0P1<C4`204I6AP80@4100P0k>c/203De=@@0;Rh^0P0a
<C4203Hf=P80?Cdm0P16ATH204e=C@80DU9B00<0GEeM06MWI`1WIfL00P1VIVH206QXJ080JVYZ0P1]
KFd206][J`80JVYZ0P1YJFT406QXJ080JFUY0P1[Jf/206YZJP80J6QX0P1ZJVX00`1]KFd0LG5a075a
L@02079bLP80LG5a0P1_Kfl206e]K@80J6QX0P1SHf<205iNGP80FEUI0P1DE5@2051@D080CDe=0P1;
Bd/204a<C080CTi>0`1BDU8205EEE@80Fe]K0P1JFUX205UIF@80Fe]K0P1NGUh206=SH`80IVIV101Y
JFT206e]K@@0Kfm_0P1/K6`00`1[Jf/0JVYZ06YZJP0206UYJ@80JVYZ0P1[Jf/206e]K@80LG5a0P1h
N7P207moO`80RHV90P2DU9@20:2PX080[jn_0P2l_;`20<G5a@80c/k>00<0e]KF0=cLg03Lg=`00P3O
gml20>;RhP80iNGU0P3WinL20>g]k@80jn_[0P3bl_820?Gem@80m_Kf0P3gmoL20??cl`80kno_0P3[
jn/20>OWi`030>?Sh`3Ogml0gmoO0080fm_K0P3Hf=P20=CDe080dM7A0P3=cLd20<[:bP80a/K60P33
`l<20<30`080_;bl0P2i^KT20;Jf]P80/k>c0P2`/;000`2/[:`0ZJVY0:VYZ@020:JVYP80Xj>S0P2P
X:0209fMW@80VYZJ0P2GUiLE0?ooo`004`3oool208f=S@80QhN70P21PH4207]kN`80MGEe0P1^KVh2
06QXJ080HV9R00<0G5aL05IFEP1FEUH00P1@D50204Y:BP80A4A40P0o?cl203Ti>@80=3@d0P0];Bd2
02`/;080<C4a0P0g=cL203hn?P80AdM70P1>CTh205ADE00305aLG01WIfL0IfMW0080IfMW0P1YJFT2
06][J`80K6a/0P1[Jf/206QXJ080IFEU0P1TI6@206=SH`80IVIV0P1ZJVX206UYJ@80I6AT0`1VIVH4
06e]K@80Kfm_0P1/K6`206YZJP80IVIV0P1QHF4205aLG080EeMG0P1BDU8204i>CP80Bd];0P18B4P2
04M7A`80BDU900<0Bd];04m?C`1?Cdl00P1@D50205EEE@80F5QH0P1CDe<205MGE`80F5QH0P1PH602
065QH@80IFEU0P1TI6@206UYJ@H0K6a/00<0Jf][06YZJP1ZJVX00P1YJFT206YZJP80K6a/0P1^KVh2
079bLP80N7Qh0P1oOgl208R8R080TY:B0P2NWYh20:f][@80^k^k0P35aLD20<g=c@030=GEe@3Kfm/0
fm_K0080gmoO0P3QhN420>CTi080inOW0P3/k>`20>[ZjP80l_;b1P3emOD20?7al@80kNg]0P3YjNT2
0>GUi@030>7Qh@3MgMd0gMgM0080f][J0P3Fe]H20=?Cd`80clo?0P3<c<`20<W9b@80aLG50P32`/82
0;no_`80^k^k0P2h^;P20;Fe]@80/[:b0P2_[jl00`2/[:`0ZJVY0:VYZ@020:JVYP80Xj>S0P2PX:02
09fMW@80VYZJ0P2FUYHE0?ooo`004`3oool208f=S@80QhN70P21PH4207]kN`80MGEe0P1^KVh206QX
J080HV9R00<0G5aL05IFEP1FEUH00P1@D50204Y:BP80A4A40P0o?cl203Ti>@80=3@d0P0];Bd202`/
;080<C4a0P0g=cL203hn?P80AdM70P1>CTh205ADE00305aLG01WIfL0IfMW0080IfMW0P1YJFT206][
J`80K6a/0P1[Jf/206QXJ080IFEU0P1TI6@206=SH`80IVIV0P1ZJVX206UYJ@80I6AT0`1VIVH406e]
K@80Kfm_0P1/K6`206YZJP80IVIV0P1QHF4205aLG080EeMG0P1BDU8204i>CP80Bd];0P18B4P204M7
A`80BDU900<0Bd];04m?C`1?Cdl00P1@D50205EEE@80F5QH0P1CDe<205MGE`80F5QH0P1PH602065Q
H@80IFEU0P1TI6@206UYJ@H0K6a/00<0Jf][06YZJP1ZJVX00P1YJFT206YZJP80K6a/0P1^KVh2079b
LP80N7Qh0P1oOgl208R8R080TY:B0P2NWYh20:f][@80^k^k0P35aLD20<g=c@030=GEe@3Kfm/0fm_K
0080gmoO0P3QhN420>CTi080inOW0P3/k>`20>[ZjP80l_;b1P3emOD20?7al@80kNg]0P3YjNT20>GU
i@030>7Qh@3MgMd0gMgM0080f][J0P3Fe]H20=?Cd`80clo?0P3<c<`20<W9b@80aLG50P32`/820;no
_`80^k^k0P2h^;P20;Fe]@80/[:b0P2_[jl00`2/[:`0ZJVY0:VYZ@020:JVYP80Xj>S0P2PX:0209fM
W@80VYZJ0P2FUYHE0?ooo`004`3oool208f=S@80QhN70P21PH4207YjNP80M7Ad0P1^KVh206QXJ080
HF5Q00<0Fe]K05EEE@1EEED00P1?Cdl204U9B@80@d=30P0m?Cd203Lg=`80<c<c0P0b<S8202d];@80
<30`0P0f=SH203hn?P80AdM70P1?Cdl205MGE`0305mOG`1WIfL0IfMW0080IfMW0P1YJFT206][J`80
K6a/0P1YJFT206IVIP80HV9R0P1OGel205eMG@80GUiN0P1RHV8406=SH`80IFEU00<0HV9R06EUI@1U
IFD00P1UIFD206MWI`80IVIV0P1TI6@2069RHP80GUiN0P1JFUX205EEE@80D51@0P1<C4`204U9B@80
ATI61013@d<00`15ADD0B4Q804Q8B00204a<C080CTi>0P1ADE4204i>CP80De=C0P1BDU8205QHF080
Fe]K101OGel2069RHP80IFEU0P1WIfL206QXJ0L0JFUY0P1[Jf/206i^KP80LW9b0P1hN7P207moO`80
QhN70P2@T90209bLW080ZZZZ0P2g]kL20<?3``80c<c<00<0eMGE0=WIf@3IfMT00P3MgMd20>7Qh@80
iNGU0P3WinL20>[ZjP80jNWY0P3`l?020??cl`80m?Cd0P3bl_820>k^kP80j^[Z0P3WinL20>?Sh`03
0=oOg`3Lg=`0g=cL0080f=SH0P3EeMD20=7Ad@80c/k>0P3;bl/20<O7a`80a<C40P31`L420;jn_P80
^k^k0P2h^;P20;Bd]080/K6a0P2^[Zh00`2[Zj/0Z:RX0:RXZ0020:FUY@80XZ:R0P2OWil209bLW080
VIVI0P2FUYHE0?ooo`004`3oool208f=S@80QhN70P21PH4207YjNP80M7Ad0P1^KVh206QXJ080HF5Q
00<0Fe]K05EEE@1EEED00P1?Cdl204U9B@80@d=30P0m?Cd203Lg=`80<c<c0P0b<S8202d];@80<30`
0P0f=SH203hn?P80AdM70P1?Cdl205MGE`0305mOG`1WIfL0IfMW0080IfMW0P1YJFT206][J`80K6a/
0P1YJFT206IVIP80HV9R0P1OGel205eMG@80GUiN0P1RHV8406=SH`80IFEU00<0HV9R06EUI@1UIFD0
0P1UIFD206MWI`80IVIV0P1TI6@2069RHP80GUiN0P1JFUX205EEE@80D51@0P1<C4`204U9B@80ATI6
1013@d<00`15ADD0B4Q804Q8B00204a<C080CTi>0P1ADE4204i>CP80De=C0P1BDU8205QHF080Fe]K
101OGel2069RHP80IFEU0P1WIfL206QXJ0L0JFUY0P1[Jf/206i^KP80LW9b0P1hN7P207moO`80QhN7
0P2@T90209bLW080ZZZZ0P2g]kL20<?3``80c<c<00<0eMGE0=WIf@3IfMT00P3MgMd20>7Qh@80iNGU
0P3WinL20>[ZjP80jNWY0P3`l?020??cl`80m?Cd0P3bl_820>k^kP80j^[Z0P3WinL20>?Sh`030=oO
g`3Lg=`0g=cL0080f=SH0P3EeMD20=7Ad@80c/k>0P3;bl/20<O7a`80a<C40P31`L420;jn_P80^k^k
0P2h^;P20;Bd]080/K6a0P2^[Zh00`2[Zj/0Z:RX0:RXZ0020:FUY@80XZ:R0P2OWil209bLW080VIVI
0P2FUYHE0?ooo`004`3oool208f=S@80QhN70P20P80207YjNP80Lg=c0P1]KFd206MWI`80H61P00<0
FUYJ05ADE01DE5@00P1=CDd204M7A`80@D510P0k>c/203@d=080;Rh^0P0`<30202l_;`80<C4a0P0h
>3P20410@080AdM70P1@D50205UIF@03069RHP1WIfL0IfMW0080J6QX0P1ZJVX406a/K080J6QX0P1T
I6@205mOG`80FUYJ101FEUH605QHF080FUYJ00<0G5aL05iNGP1NGUh00P1OGel4061PH080GemO0P1M
GEd205]KF`80EeMG0P1CDe<204m?C`80BTY:0P17AdL204=3@`80@D510`10@4020492@P80A4A40P18
B4P204Y:BP@0AdM70P19BDT204e=C@80DU9B0P1EEED205QHF080FUYJ0P1MGEd2061PH080HV9R00<0
I6AT06IVIP1VIVH00P1WIfL206QXJ080JVYZ0P1]KFd2075aL@80N7Qh0P1oOgl208N7Q`80T92@0P2K
Vi/20:VYZ@80]KFe0P30`<020<_;b`030=?Cd`3Hf=P0f=SH0080fm_K0P3Ogml20>CTi080i^KV0P3Y
jNT20>SXj080k^k^0P3alO420?;blP80kno_0P3/k>`20>SXj080i>CT0P3QhN400`3MgMd0f][J0=[J
fP020=OGe`80dm?C0P3@d=020<g=c@80bLW90P36a/H20<?3``80`<300P2m_Kd20;Zj^P80]kNg0P2d
];@20;6a/@80[Zj^00<0Zj^[0:RXZ02XZ:P00P2UYJD20::RXP80WinO0P2LW9`209VIV@80UYJF5@3o
ool001<0oooo0P2=SHd208N7Q`80P8200P1jNWX207=cL`80KFe]0P1WIfL2061PH00305YJFP1DE5@0
E5AD0080CDe=0P17AdL20451@@80>c/k0P0d=3@202h^;P80<30`0P0_;bl2034a<@80>3Ph0P10@402
04M7A`80D51@0P1IFET00`1RHV80IfMW06MWI`0206QXJ080JVYZ101/K6`206QXJ080I6AT0P1OGel2
05YJFP@0EUIF1P1HF5P205YJFP0305aLG01NGUh0GUiN0080GemO101PH60205mOG`80GEeM0P1KFe/2
05MGE`80De=C0P1?Cdl204Y:BP80AdM70P13@d<20451@@<0@4100P12@T8204A4A080B4Q80P1:BTX4
04M7A`80BDU90P1=CDd2059BDP80EEEE0P1HF5P205YJFP80GEeM0P1PH602069RHP0306ATI01VIVH0
IVIV0080IfMW0P1XJ6P206YZJP80KFe]0P1aLG4207QhN080Ogmo0P27QhL2092@T080Vi^K0P2YZJT2
0;Fe]@80`<300P3;bl/00`3Cdm<0f=SH0=SHf0020=_Kf`80gmoO0P3Ti>@20>KViP80jNWY0P3Xj>P2
0>k^kP80lO7a0P3bl_820>o_k`80k>c/0P3Xj>P20>CTi080hN7Q00<0gMgM0=[JfP3Jf]X00P3GemL2
0=?Cd`80d=3@0P3=cLd20<W9b@80a/K60P33`l<20<30`080_Kfm0P2j^[X20;Ng]`80];Bd0P2a/K42
0:j^[P030:^[Z`2XZ:P0Z:RX0080YJFU0P2RXZ8209nOW`80W9bL0P2IVIT209JFUQD0oooo000C0?oo
o`80SHf=0P26QXH20820P080NGUi0P1cLg<206a/K080IVIV0P1OGel00`1IFET0DU9B059BDP0204a<
C080ADE50P0o?cl203Ti>@80<S8b100Z:RX202l_;`80<S8b0P0i>CT20451@@80BDU90P1@D50205YJ
FP03069RHP1WIfL0IfMW0080JFUY0P1[Jf/206e]K@80K6a/0P1XJ6P206ATI080GemO0P1JFUX205EE
E@80DU9B1P1@D502059BDP0305ADE01GEeL0EeMG0080FUYJ101MGEd205aLG080FUYJ0P1GEeL205AD
E080DE5A0P1=CDd204U9B@80ADE50P12@T8203lo?`<0?Shn0P0o?cl20451@@80@T922014A4@204I6
AP80B4Q80P1<C4`2051@D080E5AD0P1GEeL205YJFP80GEeM00<0HF5Q06=SH`1SHf<00P1UIFD206MW
I`80JFUY0P1/K6`2071`L080MgMg0P1nOWh208N7Q`80TI6A0P2LW9`20:RXZ080];Bd0P2n_[h20<W9
b@030=?Cd`3GemL0emOG0080f][J0P3Ng]h20>CTi080i^KV0P3Xj>P20>OWi`80kNg]0P3`l?020>o_
k`80k>c/0P3YjNT20>KViP80h^;R0P3Ogml00`3Kfm/0f=SH0=SHf0020=GEe@80d];B0P3>c/h20<_;
b`80b<S80P35aLD20<;2`P80_kno0P2l_;`20;Vi^@80][Jf0P2c/k<20;2`/080[Jf]00<0ZZZZ0:NW
Y`2WYjL00P2UYJD20::RXP80WinO0P2LW9`209VIV@80UYJF5@3oool001<0oooo0P2=SHd208J6QP80
P8200P1iNGT207=cL`80K6a/0P1VIVH205mOG`0305UIF@1BDU80DU9B0080C4a<0P15ADD203lo?`80
>CTi0P0b<S8402XZ:P80;bl_0P0b<S8203Ti>@80@D510P19BDT2051@D080FUYJ00<0HV9R06MWI`1W
IfL00P1YJFT206][J`80KFe]0P1/K6`206QXJ080I6AT0P1OGel205YJFP80EEEE0P1BDU86051@D080
DU9B00<0E5AD05MGE`1GEeL00P1JFUX405eMG@80G5aL0P1JFUX205MGE`80E5AD0P1ADE4204e=C@80
BDU90P15ADD20492@P80?clo0`0n?Sh203lo?`80@D510P12@T8804A4A080ATI60P18B4P204a<C080
D51@0P1DE5@205MGE`80FUYJ0P1MGEd00`1QHF40Hf=S06=SH`0206EUI@80IfMW0P1YJFT206a/K080
L71`0P1gMgL207inOP80QhN70P2ATI4209bLW080Z:RX0P2d];@20;jn_P80bLW900<0dm?C0=OGe`3G
emL00P3Jf]X20=kNgP80i>CT0P3Vi^H20>SXj080inOW0P3]kNd20?3`l080kno_0P3/k>`20>WYj@80
i^KV0P3Rh^820=oOg`030=_Kf`3Hf=P0f=SH0080eMGE0P3Bd]820<k>cP80bl_;0P38b<P20<G5a@80
`/;20P2o_kl20;bl_080^KVi0P2f][H20;>c/`80/;2`0P2][Jd00`2ZZZX0YjNW0:NWY`020:FUY@80
XZ:R0P2OWil209bLW080VIVI0P2FUYHE0?ooo`004`3oool208f=S@80QXJ60P1oOgl207UiN@80LW9b
0P1/K6`206EUI@80GUiN00<0EeMG055AD@1ADE400P1:BTX204A4A080?Cdm0P0g=cL2030`<080:RXZ
0P0V9RH202d];@80<S8b0P0i>CT20451@@80B4Q80P1?Cdl205YJFP03069RHP1WIfL0IfMW0080JVYZ
0P1[Jf/406e]K@80JFUY0P1UIFD2065QH@80G5aL0P1HF5P205EEE@80De=C101ADE4205ADE00305IF
EP1HF5P0F5QH0080FUYJ0P1KFe/405UIF@80EeMG0P1EEED2059BDP80Cdm?0P1<C4`204Q8B080ADE5
0P11@D4203dm?@<0>c/k0P0l?3`203lo?`80@T921014A4@404=3@`80ADE50P17AdL204];B`80CTi>
0P1BDU8205EEE@80F5QH0P1KFe/00`1NGUh0HF5Q065QH@0206=SH`80IFEU0P1XJ6P206a/K080L71`
0P1fMWH207inOP80QXJ60P2@T90209^KV`80Z:RX0P2d];@20;jn_P80b<S800<0dM7A0=OGe`3GemL0
0P3IfMT20=kNgP80i>CT0P3Vi^H20>SXj080inOW0P3/k>`20?3`l080kNg]0P3Zj^X20>OWi`80hn?S
0P3Ph>020=gMg@030=[JfP3Fe]H0e]KF0080dm?C0P3@d=020<g=c@80b/[:0P37alL20<C4a080`L71
0P2n_[h20;^k^`80^;Rh0P2e]KD20;:b/P80[jn_0P2][Jd00`2ZZZX0YjNW0:NWY`020:BTY080XJ6Q
0P2OWil209bLW080VIVI0P2FUYHE0?ooo`004`3oool208f=S@80QXJ60P1oOgl207QhN080LW9b0P1[
Jf/206ATI080GEeM00<0EUIF04m?C`1?Cdl00P18B4P20492@P80>c/k0P0e=CD202l_;`80:RXZ0P0R
8R8202/[:`80<30`0P0g=cL203lo?`80AdM70P1>CTh205QHF003061PH01VIVH0IVIV0080JVYZ0P1/
K6`206i^KP80KFe]0P1YJFT206IVIP80Hf=S0P1OGel205]KF`80F5QH0P1FEUH405ADE080De=C1@1D
E5@605IFEP80EEEE0P1CDe<2055AD@80CTi>0P1;Bd/204Q8B080ADE50P11@D4203dm?@80>SXj00<0
=cLg03Hf=P0f=SH00P0i>CT203dm?@80@D510P15ADD404I6AP80B4Q80P19BDT204a<C080CTi>0P1B
DU8205ADE080EeMG0P1IFET00`1LG5`0GemO05mOG`02065QH@80Hf=S0P1VIVH206YZJP80Kfm_0P1e
MGD207emO@80QXJ60P2?Shl209^KV`80YZJV0P2b/[820;fm_@80alO700<0c/k>0=CDe03De=@00P3H
f=P20=gMg@80hn?S0P3UiND40>SXj080k>c/0P3^k^h20>_[j`80inOW0P3Ti>@20>7Qh@80g]kN0P3K
fm/00`3Hf=P0e=CD0=CDe0020=7Ad@80c/k>0P3;bl/20<S8b080aLG50P33`l<20<30`080_Kfm0P2j
^[X20;Ng]`80];Bd0P2b/[820:n_[`80[:b/00<0ZJVY0:JVYP2VYZH00P2TY:@20:6QX@80WYjN0P2L
W9`209VIV@80UYJF5@3oool001<0oooo0P2=SHd208J6QP80Ogmo0P1hN7P2079bLP80Jf][0P1TI6@2
05eMG@0305IFEP1?Cdl0Cdm?0080B4Q80P12@T8203/k>`80=CDe0P0_;bl202XZ:P808R8R0P0[:b/2
030`<080=cLg0P0o?cl204M7A`80CTi>0P1HF5P00`1PH600IVIV06IVIP0206YZJP80K6a/0P1^KVh2
06e]K@80JFUY0P1VIVH206=SH`80GemO0P1KFe/205QHF080EUIF101DE5@205=CD`D0E5AD1P1FEUH2
05EEE@80De=C0P1ADE4204i>CP80Bd];0P18B4P204E5A@80@D510P0m?Cd203Xj>P0303Lg=`0f=SH0
=SHf0080>CTi0P0m?Cd20451@@80ADE51016ATH204Q8B080BDU90P1<C4`204i>CP80DU9B0P1DE5@2
05MGE`80FEUI00<0G5aL05mOG`1OGel00P1QHF4206=SH`80IVIV0P1ZJVX206m_K`80MGEe0P1mOGd2
08J6QP80Shn?0P2KVi/20:JVYP80/[:b0P2m_Kd20<O7a`030<k>cP3De=@0e=CD0080f=SH0P3MgMd2
0>?Sh`80iNGU103Xj>P20>c/k080k^k^0P3[jn/20>OWi`80i>CT0P3QhN420=kNgP80fm_K00<0f=SH
0=CDe03De=@00P3AdM420<k>cP80bl_;0P38b<P20<G5a@80`l?30P30`<020;fm_@80^[Zj0P2g]kL2
0;Bd]080/[:b0P2_[jl20:b/[0030:VYZ@2VYZH0YZJV0080Y:BT0P2QXJ4209jNWP80W9bL0P2IVIT2
09JFUQD0oooo000C0?ooo`80SHf=0P26QXH207moO`80N7Qh0P1aLG4206YZJP80Hf=S0P1LG5`00`1E
EED0CTi>04i>CP0204M7A`80@4100P0i>CT2038b<P80;2`/0P0Z:RX2024Q8@80:2PX0P0^;Rh203@d
=080?3`l0P15ADD204a<C080EUIF00<0GUiN06EUI@1UIFD00P1ZJVX206a/K080KVi^0P1]KFd206UY
J@80IFEU0P1TI6@2065QH@80GUiN0P1KFe/205QHF080EEEE0P1CDe<2055AD@0304m?C`1ADE40DE5A
0080De=C1P1DE5@205=CD`80DE5A0P1@D50204e=C@80Bd];0P18B4P204E5A@80@T920P0n?Sh203/k
>`0303Ph>00e=CD0=CDe0080<c<c0P0e=CD203Ph>080?Cdm0P12@T8204I6AP80B4Q80P1;Bd/204e=
C@80Cdm?0P1BDU8205ADE080EUIF0P1HF5P00`1IFET0G5aL05aLG00205iNGP80HF5Q0P1TI6@206UY
J@80KVi^0P1dM7@207]kN`80Ph>30P2?Shl209VIV@80YJFU0P2a/K420;jn_P80b<S800<0c/k>0=?C
d`3Cdm<00P3GemL20=_Kf`80hN7Q0P3Ti>@20>KViP80jNWY103/k>`20>SXj080iNGU0P3Rh^820=oO
g`80g=cL0P3IfMT00`3Fe]H0dm?C0=?Cd`020=3@d080cLg=0P3:b/X20<O7a`80a<C40P31`L420;jn
_P80_;bl0P2i^KT20;Jf]P80];Bd0P2a/K420:j^[P80Zj^[00<0ZJVY0:JVYP2VYZH00P2SXj<20:6Q
X@80WYjN0P2KVi/209VIV@80UYJF5@3oool001<0oooo0P2=SHd208J6QP80Ogmo0P1hN7P2075aL@80
JVYZ0P1SHf<205aLG00305EEE@1>CTh0CTi>0080AdM70P10@40203Ti>@80<S8b0P0/;2`202XZ:P80
8B4Q0P0X:2P202h^;P80=3@d0P0l?3`204E5A@80C4a<0P1FEUH00`1NGUh0IFEU06EUI@0206YZJP80
K6a/0P1^KVh206e]K@80JFUY0P1UIFD206ATI080HF5Q0P1NGUh205]KF`80F5QH0P1EEED205=CD`80
DE5A00<0Cdm?055AD@1ADE400P1CDe<605ADE080De=C0P1ADE42051@D080CDe=0P1;Bd/204Q8B080
ADE50P12@T8203hn?P80>c/k00<0>3Ph03De=@0e=CD00P0c<c<203De=@80>3Ph0P0m?Cd20492@P80
ATI60P18B4P204];B`80CDe=0P1?Cdl2059BDP80E5AD0P1FEUH205QHF00305UIF@1LG5`0G5aL0080
GUiN0P1QHF4206ATI080JFUY0P1^KVh207AdM080Ng]k0P23Ph<208n?S`80VIVI0P2UYJD20;6a/@80
_[jn0P38b<P00`3>c/h0dm?C0=?Cd`020=OGe`80fm_K0P3QhN420>CTi080i^KV0P3YjNT40>c/k080
j>SX0P3UiND20>;RhP80gmoO0P3Lg=`20=WIf@030=KFeP3Cdm<0dm?C0080d=3@0P3=cLd20<[:bP80
alO70P34a<@20<71`@80_[jn0P2l_;`20;Vi^@80][Jf0P2d];@20;6a/@80[Zj^0P2[Zj/00`2YZJT0
YZJV0:JVYP020:>SX`80XJ6Q0P2NWYh209^KV`80VIVI0P2FUYHE0?ooo`004`3oool208b<S080QHF5
0P1nOWh207MgM`80L71`0P1YJFT2069RHP80Fe]K00<0E5AD04e=C@1=CDd00P15ADD203hn?P80=cLg
0P0_;bl402LW9`8092@T0P0W9bL202`/;080<S8b0P0h>3P20492@P80BTY:0P1CDe<00`1KFe/0HF5Q
065QH@0206MWI`80Jf][0P1^KVh206e]K@80JFUY0P1SHf<2061PH080GEeM0P1KFe/205QHF080EEEE
0P1CDe<7059BDP80De=C101DE5@205=CD`80DU9B0P1ADE4204m?C`80CDe=0P1;Bd/204Q8B080ADE5
0P13@d<20410@080?Cdm00<0>SXj03Ph>00h>3P01P0f=SH203Ph>080>SXj0P0m?Cd203lo?`80A4A4
0P18B4P204];B`80CDe=0P1@D502055AD@80E5AD00<0EeMG05YJFP1JFUX00P1LG5`205mOG`80Hf=S
0P1WIfL206e]K@80LW9b0P1kNg/208>3P`80SXj>0P2IVIT20:FUY@80/K6a0P2m_Kd20<S8b0030<c<
c03AdM40dM7A0080e]KF0P3IfMT20=oOg`80h^;R0P3Ti>@20>SXj080jn_[0P3YjNT20>GUi@80h^;R
0P3Ogml20=cLg080fMWI0P3Fe]H00`3Cdm<0dM7A0=7Ad@020<k>cP80bl_;0P38b<P20<G5a@80`l?3
0P30`<020;fm_@80^[Zj0P2h^;P20;Fe]@80/k>c0P2`/;020:f][@80Zj^[00<0Z:RX0:FUY@2UYJD0
0P2SXj<20:2PX080WYjN0P2KVi/209VIV@80UYJF5@3oool001<0oooo0P2<S8`208F5Q@80OWin0P1g
MgL2071`L080JFUY0P1RHV8205]KF`0305ADE01=CDd0CDe=0080ADE50P0n?Sh203Lg=`80;bl_100W
9bL202@T90809bLW0P0/;2`2038b<P80>3Ph0P12@T8204Y:BP80De=C00<0Fe]K065QH@1QHF400P1W
IfL206][J`80KVi^0P1]KFd206UYJ@80Hf=S0P1PH60205eMG@80Fe]K0P1HF5P205EEE@80De=C1`1B
DU8205=CD`@0E5AD0P1CDe<2059BDP80DE5A0P1?Cdl204e=C@80Bd];0P18B4P204E5A@80@d=30P10
@40203dm?@0303Xj>P0h>3P0>3Ph00H0=SHf0P0h>3P203Xj>P80?Cdm0P0o?cl204A4A080B4Q80P1;
Bd/204e=C@80D51@0P1ADE4205ADE00305MGE`1JFUX0FUYJ0080G5aL0P1OGel206=SH`80IfMW0P1]
KFd2079bLP80Ng]k0P23Ph<208j>SP80VIVI0P2UYJD20;6a/@80_Kfm0P38b<P00`3<c<`0dM7A0=7A
d@020=KFeP80fMWI0P3Ogml20>;RhP80i>CT0P3Xj>P20>_[j`80jNWY0P3UiND20>;RhP80gmoO0P3L
g=`20=WIf@80e]KF00<0dm?C0=7Ad@3AdM400P3>c/h20<_;b`80b<S80P35aLD20<?3``80`<300P2m
_Kd20;Zj^P80^;Rh0P2e]KD20;>c/`80/;2`0P2][Jd20:^[Z`030:RXZ02UYJD0YJFU0080Xj>S0P2P
X:0209jNWP80Vi^K0P2IVIT209JFUQD0oooo000C0?ooo`80S8b<0P25QHD207inOP80MgMg0P1`L702
06UYJ@80HF5Q0P1JFUX00`1CDe<0Bd];04];B`0204A4A080?3`l0P0d=3@202`/;0808b<S0P0P8202
028R8P809RHV0P0/;2`202l_;`80=SHf0P0n?Sh204M7A`80D51@00<0EeMG05mOG`1OGel00P1UIFD2
06UYJ@@0KFe]0P1YJFT206EUI@80HF5Q0P1MGEd205UIF@80EeMG1P1EEED;05ADE080De=C0P1BDU82
055AD@80Cdm?0P1=CDd204];B`80BDU90P17AdL204A4A080@T920P0o?cl00`0m?Cd0>c/k03/k>`02
03Xj>P@0>CTi0P0j>SX203`l?0@0?Shn0P10@4020492@P80ADE50P18B4P204a<C080Cdm?0P1ADE40
0`1EEED0F5QH05QHF00205]KF`80GUiN0P1RHV8206MWI`80K6a/0P1aLG4207QhN080PX:20P2=SHd2
09VIV@80Y:BT0P2`/;020;bl_080alO700<0b/[:0<o?c`3?cll00P3EeMD20=OGe`80g]kN103QhN42
0>OWi`80jNWY0P3Vi^H20>?Sh`80h>3P0P3MgMd20=[JfP80emOG0P3De=@00`3AdM40clo?0<o?c`02
0<c<c080bLW90P37alL20<C4a080`L710P2o_kl20;bl_080^KVi0P2g]kL20;Bd]080/[:b0P2_[jl2
0:f][@80ZZZZ00<0Z:RX0:FUY@2UYJD00P2RXZ820:2PX080WIfM0P2KVi/209RHV080UYJF5@3oool0
01<0oooo0P2<S8`208F5Q@80OWin0P1gMgL2071`L080JFUY0P1QHF4205YJFP0305=CD`1;Bd/0Bd];
0080A4A40P0l?3`203@d=080;2`/0P0S8b<2020P80808R8R0P0V9RH202`/;080;bl_0P0f=SH203hn
?P80AdM70P1@D5000`1GEeL0GemO05mOG`0206EUI@80JFUY101]KFd206UYJ@80IFEU0P1QHF4205eM
G@80FEUI0P1GEeL605EEE@/0E5AD0P1CDe<2059BDP80DE5A0P1?Cdl204e=C@80Bd];0P19BDT204M7
A`80A4A40P12@T8203lo?`0303dm?@0k>c/0>c/k0080>SXj100i>CT203Xj>P80?3`l100n?Sh20410
@080@T920P15ADD204Q8B080C4a<0P1?Cdl2055AD@0305EEE@1HF5P0F5QH0080Fe]K0P1NGUh2069R
HP80IfMW0P1/K6`2075aL@80N7Qh0P22PX8208f=S@80VIVI0P2TY:@20;2`/080_;bl0P37alL00`3:
b/X0clo?0<o?c`020=GEe@80emOG0P3Ng]h40>7Qh@80inOW0P3YjNT20>KViP80hn?S0P3Ph>020=gM
g@80f][J0P3GemL20=CDe0030=7Ad@3?cll0clo?0080c<c<0P39bLT20<O7a`80a<C40P31`L420;no
_`80_;bl0P2i^KT20;Ng]`80];Bd0P2b/[820:n_[`80[Jf]0P2ZZZX00`2XZ:P0YJFU0:FUY@020::R
XP80X:2P0P2MWId209^KV`80V9RH0P2FUYHE0?ooo`004`3oool208b<S080QHF50P1nOWh207MgM`80
Kfm_0P1XJ6P2065QH@80FEUI00<0DU9B04Y:BP1:BTX00P12@T8203Xj>P80<S8b0P0Y:BT2020P8080
71`L0P0P820202@T9080:b/[0P0^;Rh203@d=080?3`l0P14A4@204e=C@0305EEE@1LG5`0G5aL0080
Hf=S0P1XJ6P406e]K@80JVYZ0P1VIVH206=SH`80H61P0P1LG5`205YJFP80F5QH101GEeL305IFEPH0
EEEE0P1DE5@205=CD`80DU9B0P1ADE4204m?C`80CTi>0P1<C4`204Y:BP80B4Q80P16ATH204A4A080
@T9200<0@41003hn?P0n?Sh00P0m?Cd203`l?0@0?Cdm0P0n?Sh203lo?`80@4100P12@T8204=3@`80
ATI60P18B4P204];B`80CTi>0P1@D5000`1DE5@0EUIF05IFEP0205UIF@80G5aL0P1PH60206IVIP80
Jf][0P1aLG4207QhN080P8200P2;Rh/209JFUP80XZ:R0P2_[jl20;^k^`80alO700<0b<S80<g=c@3=
cLd00P3De=@20=GEe@80fm_K103Ph>020>GUi@80i^KV0P3Rh^820>3Ph080gMgM0P3Jf]X20=OGe`80
eMGE0P3Bd]800`3?cll0cLg=0<g=c@020<[:bP80alO70P35aLD20<;2`P80`<300P2m_Kd20;^k^`80
^;Rh0P2f][H20;>c/`80/K6a0P2^[Zh20:b/[080ZJVY00<0YjNW0:BTY02TY:@00P2RXZ820:2PX080
WIfM0P2KVi/209RHV080UYJF5@3oool001<0oooo0P2<S8`208F5Q@80OWin0P1gMgL206m_K`80J6QX
0P1QHF4205UIF@03059BDP1:BTX0BTY:0080@T920P0j>SX2038b<P80:BTY0P0P820201`L7080820P
0P0T92@202/[:`80;Rh^0P0d=3@203`l?080A4A40P1=CDd00`1EEED0G5aL05aLG00206=SH`80J6QX
101]KFd206YZJP80IVIV0P1SHf<2061PH080G5aL0P1JFUX205QHF0@0EeMG0`1FEUH605EEE@80E5AD
0P1CDe<2059BDP80DE5A0P1?Cdl204i>CP80C4a<0P1:BTX204Q8B080ATI60P14A4@20492@P030410
@00n?Sh0?Shn0080?Cdm0P0l?3`403dm?@80?Shn0P0o?cl20410@080@T920P13@d<204I6AP80B4Q8
0P1;Bd/204i>CP80D51@00<0E5AD05IFEP1FEUH00P1IFET205aLG080H61P0P1VIVH206][J`80LG5a
0P1hN7P20820P080Rh^;0P2FUYH20::RXP80[jn_0P2k^k/20<O7a`030<S8b03=cLd0cLg=0080e=CD
0P3EeMD20=_Kf`@0h>3P0P3UiND20>KViP80h^;R0P3Ph>020=gMg@80f][J0P3GemL20=GEe@80d];B
00<0clo?0<g=c@3=cLd00P3:b/X20<O7a`80aLG50P32`/820<30`080_Kfm0P2k^k/20;Rh^080][Jf
0P2c/k<20;6a/@80[Zj^0P2/[:`20:VYZ@030:NWY`2TY:@0Y:BT0080XZ:R0P2PX:0209fMW@80Vi^K
0P2HV9P209JFUQD0oooo000C0?ooo`80S8b<0P25QHD207inOP80MWIf0P1_Kfl206QXJ080H61P0P1H
F5P00`1ADE40BDU904U9B@020451@@80>3Ph0P0`<30202HV9P8071`L0P0G5aL201dM7@808R8R0P0Y
:BT202d];@80<c<c0P0i>CT20451@@80BTY:00<0DU9B05YJFP1JFUX00P1QHF4206IVIP80Jf][0P1]
KFd206YZJP80IfMW0P1TI6@2069RHP80GemO0P1LG5`205]KF`80FUYJ0P1HF5P305MGE`@0EUIF101E
EED205ADE080De=C0P1BDU82051@D080CTi>0P1=CDd204];B`80BDU90P18B4P204I6AP80A4A400<0
@d=30451@@11@D400P10@40603lo?`80@4100P11@D420492@P80@d=30P15ADD204I6AP80B4Q80P1:
BTX204e=C@80D51@00<0DU9B05EEE@1EEED00P1HF5P205aLG080H61P0P1UIFD206][J`80LG5a0P1h
N7P20861P@80Rh^;0P2FUYH20::RXP80/;2`0P2l_;`20<S8b0030<W9b@3<c<`0c<c<0080d];B0P3C
dm<20=SHf080g]kN0P3Ogml20>CTi080h^;R0P3Ogml20=cLg080f][J0P3GemL20=GEe@80d];B0P3@
d=000`3=cLd0bl_;0<_;b`020<S8b080a/K60P33`l<20<71`@80_[jn0P2l_;`20;Vi^@80]kNg0P2e
]KD20;:b/P80/;2`0P2][Jd20:^[Z`80ZJVY00<0YZJV0:BTY02TY:@00P2RXZ8209nOW`80WIfM0P2K
Vi/209RHV080UYJF5@3oool001<0oooo0P2<S8`208F5Q@80OWin0P1fMWH206m_K`80J6QX0P1PH602
05QHF003055AD@19BDT0BDU90080@D510P0h>3P2030`<0809RHV0P0L71`201LG5`807AdM0P0R8R82
02TY:@80;Bd]0P0c<c<203Ti>@80@D510P1:BTX00`1BDU80FUYJ05YJFP02065QH@80IVIV0P1[Jf/2
06e]K@80JVYZ0P1WIfL206ATI080HV9R0P1OGel205aLG080Fe]K0P1JFUX205QHF0<0EeMG101FEUH4
05EEE@80E5AD0P1CDe<2059BDP80D51@0P1>CTh204e=C@80Bd];0P19BDT204Q8B080ATI60P14A4@0
0`13@d<0@D510451@@020410@0H0?clo0P10@4020451@@80@T920P13@d<204E5A@80ATI60P18B4P2
04Y:BP80CDe=0P1@D5000`1BDU80EEEE05EEE@0205QHF080G5aL0P1PH60206EUI@80Jf][0P1aLG42
07QhN080PH610P2;Rh/209JFUP80XZ:R0P2`/;020;bl_080b<S800<0bLW90<c<c03<c<`00P3Bd]82
0=?Cd`80f=SH0P3Ng]h20=oOg`80i>CT0P3Rh^820=oOg`80g=cL0P3Jf]X20=OGe`80eMGE0P3Bd]82
0=3@d0030<g=c@3;bl/0bl_;0080b<S80P36a/H20<?3``80`L710P2n_[h20;bl_080^KVi0P2g]kL2
0;Fe]@80/[:b0P2`/;020:f][@80Zj^[0P2YZJT00`2VYZH0Y:BT0:BTY0020::RXP80WinO0P2MWId2
09^KV`80V9RH0P2FUYHE0?ooo`004`3oool208b<S080QHF50P1mOGd207IfMP80Kfm_0P1WIfL2061P
H080F5QH00<0D51@04Q8B018B4P00P10@40203Lg=`80;Rh^0P0U9BD201/K6`804a<C0P0J6QX2020P
80809bLW0P0/;2`2034a<@80>3Ph0P0o?cl204M7A`0304m?C`1GEeL0EeMG0080GemO0P1TI6@206QX
J080Jf][0P1ZJVX206QXJ080IFEU0P1SHf<2061PH080GUiN0P1LG5`205]KF`80FUYJ0P1IFET00`1H
F5P0EeMG05MGE`0205MGE`@0EUIF0P1EEED205ADE080DU9B0P1ADE42051@D080CTi>0P1=CDd204];
B`80BDU90P18B4P204I6AP0304E5A@14A4@0A4A40080@d=32012@T8204=3@`80A4A40P15ADD204I6
AP80AdM70P19BDT204];B`80CDe=0P1?Cdl00`1BDU80EEEE05EEE@0205QHF080Fe]K0P1OGel206EU
I@80JVYZ0P1aLG4207QhN080PH610P2;Rh/209JFUP80XZ:R0P2_[jl20;bl_080alO700<0b/[:0<_;
b`3;bl/00P3@d=020=7Ad@80eMGE0P3Kfm/20=kNgP80hN7Q0P3Ng]h20=cLg080fMWI0P3GemL20=GE
e@80d];B0P3@d=020<g=c@030<_;b`39bLT0bLW90080a/K60P34a<@20<;2`P80_kno0P2m_Kd20;^k
^`80^;Rh0P2f][H20;Bd]080/K6a0P2_[jl20:f][@80ZZZZ0P2XZ:P00`2VYZH0Xj>S0:>SX`020:6Q
X@80WinO0P2MWId209ZJVP80V9RH0P2FUYHE0?ooo`004`3oool208b<S080QHF50P1mOGd207IfMP80
Kfm_0P1WIfL2061PH080F5QH00<0D51@04Q8B018B4P00P10@40203Lg=`80;Rh^0P0U9BD201/K6`80
4a<C0P0J6QX2020P80809bLW0P0/;2`2034a<@80>3Ph0P0o?cl204M7A`0304m?C`1GEeL0EeMG0080
GemO0P1TI6@206QXJ080Jf][0P1ZJVX206QXJ080IFEU0P1SHf<2061PH080GUiN0P1LG5`205]KF`80
FUYJ0P1IFET00`1HF5P0EeMG05MGE`0205MGE`@0EUIF0P1EEED205ADE080DU9B0P1ADE42051@D080
CTi>0P1=CDd204];B`80BDU90P18B4P204I6AP0304E5A@14A4@0A4A40080@d=32012@T8204=3@`80
A4A40P15ADD204I6AP80AdM70P19BDT204];B`80CDe=0P1?Cdl00`1BDU80EEEE05EEE@0205QHF080
Fe]K0P1OGel206EUI@80JVYZ0P1aLG4207QhN080PH610P2;Rh/209JFUP80XZ:R0P2_[jl20;bl_080
alO700<0b/[:0<_;b`3;bl/00P3@d=020=7Ad@80eMGE0P3Kfm/20=kNgP80hN7Q0P3Ng]h20=cLg080
fMWI0P3GemL20=GEe@80d];B0P3@d=020<g=c@030<_;b`39bLT0bLW90080a/K60P34a<@20<;2`P80
_kno0P2m_Kd20;^k^`80^;Rh0P2f][H20;Bd]080/K6a0P2_[jl20:f][@80ZZZZ0P2XZ:P00`2VYZH0
Xj>S0:>SX`020:6QX@80WinO0P2MWId209ZJVP80V9RH0P2FUYHE0?ooo`004`3oool208b<S080QHF5
0P1mOGd207IfMP80KVi^0P1WIfL205mOG`80EeMG00<0Cdm?04M7A`17AdL00P0o?cl203Hf=P80;Bd]
0P0T92@201XJ6P804A4A0P0F5QH201`L70808R8R0P0X:2P202l_;`80=CDe0P0l?3`204A4A00304e=
C@1DE5@0E5AD0080G5aL0P1RHV8206IVIP80JVYZ0P1YJFT206QXJ080IVIV0P1SHf<2065QH@80GemO
0P1NGUh205aLG080Fe]K0P1JFUX305UIF@80F5QH0P1GEeL205IFEP80EEEE101DE5@2059BDP80DE5A
0P1?Cdl204i>CP80CDe=0P1;Bd/204Y:BP80B4Q800<0AdM704I6AP16ATH00P15ADD:04A4A080ADE5
0P16ATH204M7A`80B4Q80P19BDT204];B`80CDe=0P1?Cdl00`1ADE40E5AD05ADE00205MGE`80Fe]K
0P1OGel206ATI080JVYZ0P1`L70207MgM`80PH610P2;Rh/209JFUP80XZ:R0P2^[Zh20;^k^`80a/K6
00<0bl_;0<c<c03<c<`0103AdM420=?Cd`80e]KF0P3Lg=`20=gMg@80fm_K0P3Hf=P20=KFeP80e=CD
0P3Bd]820=3@d080cLg=0P3;bl/00`39bLT0alO70<O7a`020<C4a080`/;20P30`<020;jn_P80^k^k
0P2i^KT20;Ng]`80]KFe0P2b/[820;2`/080[Zj^0P2/[:`20:ZZZP80YjNW00<0YJFU0:>SX`2SXj<0
0P2QXJ4209nOW`80W9bL0P2JVYX209RHV080UYJF5@3oool001<0oooo0P2<S8`208F5Q@80OGem0P1f
MWH206i^KP80IfMW0P1OGel205MGE`0304m?C`17AdL0AdM70080?clo0P0f=SH202d];@8092@T0P0J
6QX2014A4@805QHF0P0L71`2028R8P80:2PX0P0_;bl203De=@80?3`l0P14A4@00`1=CDd0E5AD05AD
E00205aLG080HV9R0P1VIVH206YZJP80JFUY0P1XJ6P206IVIP80Hf=S0P1QHF4205mOG`80GUiN0P1L
G5`205]KF`80FUYJ0`1IFET205QHF080EeMG0P1FEUH205EEE@@0E5AD0P1BDU82055AD@80Cdm?0P1>
CTh204e=C@80Bd];0P1:BTX204Q8B00304M7A`16ATH0ATI60080ADE52P14A4@204E5A@80ATI60P17
AdL204Q8B080BDU90P1;Bd/204e=C@80Cdm?00<0DE5A05ADE01DE5@00P1GEeL205]KF`80GemO0P1T
I6@206YZJP80L71`0P1gMgL20861P@80Rh^;0P2FUYH20::RXP80[Zj^0P2k^k/20<K6aP030<_;b`3<
c<`0c<c<00@0dM7A0P3Cdm<20=KFeP80g=cL0P3MgMd20=_Kf`80f=SH0P3Fe]H20=CDe080d];B0P3@
d=020<g=c@80bl_;00<0bLW90<O7a`37alL00P34a<@20<;2`P80`<300P2n_[h20;^k^`80^KVi0P2g
]kL20;Fe]@80/[:b0P2`/;020:j^[P80[:b/0P2ZZZX20:NWY`030:FUY@2SXj<0Xj>S0080XJ6Q0P2O
Wil209bLW080VYZJ0P2HV9P209JFUQD0oooo000C0?ooo`80S8b<0P25QHD207emO@80MWIf0P1^KVh2
06MWI`80GemO0P1GEeL00`1?Cdl0AdM704M7A`0203hn?P80=SHf0P0/;2`202<S8`806ATI0P0>3Ph2
01<C4`806ATI0P0O7al202DU9@80;2`/0P0c<c<203Xj>P80@T9200<0BTY:059BDP1BDU800P1JFUX2
061PH080I6AT101XJ6P206MWI`80IVIV0P1TI6@2069RHP80H61P0P1OGel205iNGP80G5aL0P1KFe/0
0`1JFUX0FEUI05UIF@0205UIF@@0EeMG0P1FEUH205EEE@80E5AD0P1CDe<2059BDP80DE5A0P1?Cdl2
04i>CP80CDe=0P1<C4`204Y:BP0304U9B@18B4P0B4Q80080AdM73016ATH204M7A`80B4Q80P19BDT2
04];B`80C4a<0P1>CTh2051@D003059BDP1DE5@0E5AD0080EeMG0P1KFe/2061PH080I6AT0P1ZJVX2
071`L080MgMg0P21PH4208Z:RP80UYJF0P2RXZ820:j^[P80^[Zj0P34a<@00`3:b/X0c<c<0<c<c004
0=3@d080d];B0P3Cdm<20=WIf@80f=SH0P3GemL20=GEe@80dm?C0P3AdM420<o?c`80cLg=0P3;bl/2
0<W9b@030<O7a`35aLD0aLG50080`l?30P30`<020;jn_P80_;bl0P2j^[X20;Rh^080][Jf0P2d];@2
0;6a/@80[jn_0P2][Jd20:^[Z`80ZJVY0P2WYjL00`2UYJD0XZ:R0::RXP020:2PX080WYjN0P2LW9`2
09ZJVP80V9RH0P2FUYHE0?ooo`004`3oool208b<S080QHF50P1mOGd207IfMP80KVi^0P1WIfL205mO
G`80EeMG00<0Cdm?04M7A`17AdL00P0n?Sh203Hf=P80;2`/0P0S8b<201TI6@803Ph>0P0C4a<201TI
6@807alO0P0U9BD202`/;080<c<c0P0j>SX20492@P0304Y:BP1BDU80DU9B0080FUYJ0P1PH60206AT
I0@0J6QX0P1WIfL206IVIP80I6AT0P1RHV82061PH080GemO0P1NGUh205aLG080Fe]K00<0FUYJ05UI
F@1IFET00P1IFET405MGE`80EUIF0P1EEED205ADE080De=C0P1BDU82055AD@80Cdm?0P1>CTh204e=
C@80C4a<0P1:BTX00`19BDT0B4Q804Q8B00204M7A``0ATI60P17AdL204Q8B080BDU90P1;Bd/204a<
C080CTi>0P1@D5000`1BDU80E5AD05ADE00205MGE`80Fe]K0P1PH60206ATI080JVYZ0P1`L70207Mg
M`80PH610P2:RXX209JFUP80XZ:R0P2^[Zh20;Zj^P80a<C400<0b/[:0<c<c03<c<`0103@d=020=;B
dP80dm?C0P3IfMT20=SHf080emOG0P3EeMD20=?Cd`80dM7A0P3?cll20<g=c@80bl_;0P39bLT00`37
alL0aLG50<G5a@020<?3``80`<300P2n_[h20;bl_080^[Zj0P2h^;P20;Jf]P80];Bd0P2a/K420:n_
[`80[Jf]0P2[Zj/20:VYZ@80YjNW00<0YJFU0::RXP2RXZ800P2PX:0209jNWP80W9bL0P2JVYX209RH
V080UYJF5@3oool001<0oooo0P2<S8`208F5Q@80OGem0P1fMWH206i^KP80IfMW0P1OGel205MGE`03
04m?C`17AdL0AdM70080?Shn0P0e=CD202`/;0808b<S0P0I6AT200h>3P80410@0P0D51@201/K6`80
8R8R0P0Y:BT2030`<080>3Ph0P10@4000`18B4P0DE5A055AD@0205QHF080GUiN0P1RHV8206IVIP80
IfMW0P1VIVH206EUI@80I6AT0P1RHV82065QH@80GemO0P1NGUh205eMG@80G5aL00<0Fe]K05YJFP1J
FUX00P1IFET205QHF0@0EeMG0P1FEUH205EEE@80E5AD0P1CDe<2059BDP80DE5A0P1@D50204m?C`80
CDe=0P1<C4`00`1;Bd/0BTY:04Y:BP0404U9B@X0B4Q80P19BDT204Y:BP80Bd];0P1<C4`204e=C@80
CTi>0P1@D5000`1ADE40EEEE05EEE@0205MGE`80Fe]K0P1OGel206ATI080JVYZ0P1`L70207QhN080
P8200P2:RXX209JFUP80XZ:R0P2][Jd20;Zj^P80`L7100<0alO70<c<c03<c<`00P3@d=020=7Ad@80
d];B0P3Cdm<40=GEe@80dm?C0P3Bd]820=3@d080c/k>0P3<c<`20<_;b`80bLW90P37alL00`35aLD0
`l?30<?3``020<71`@80_kno0P2m_Kd20;^k^`80^KVi0P2f][H20;Bd]080/[:b0P2`/;020:j^[P80
[:b/0P2ZZZX20:RXZ080YZJV00<0Y:BT0::RXP2RXZ800P2PX:0209jNWP80W9bL0P2JVYX209RHV080
UYJF5@3oool001<0oooo0P2<S8`208F5Q@80OGem0P1fMWH206i^KP80IfMW0P1OGel205MGE`0304m?
C`17AdL0AdM70080?Shn0P0e=CD202`/;0808b<S0P0I6AT200h>3P80410@0P0D51@201/K6`808R8R
0P0Y:BT2030`<080>3Ph0P10@4000`18B4P0DE5A055AD@0205QHF080GUiN0P1RHV8206IVIP80IfMW
0P1VIVH206EUI@80I6AT0P1RHV82065QH@80GemO0P1NGUh205eMG@80G5aL00<0Fe]K05YJFP1JFUX0
0P1IFET205QHF0@0EeMG0P1FEUH205EEE@80E5AD0P1CDe<2059BDP80DE5A0P1@D50204m?C`80CDe=
0P1<C4`00`1;Bd/0BTY:04Y:BP0404U9B@X0B4Q80P19BDT204Y:BP80Bd];0P1<C4`204e=C@80CTi>
0P1@D5000`1ADE40EEEE05EEE@0205MGE`80Fe]K0P1OGel206ATI080JVYZ0P1`L70207QhN080P820
0P2:RXX209JFUP80XZ:R0P2][Jd20;Zj^P80`L7100<0alO70<c<c03<c<`00P3@d=020=7Ad@80d];B
0P3Cdm<40=GEe@80dm?C0P3Bd]820=3@d080c/k>0P3<c<`20<_;b`80bLW90P37alL00`35aLD0`l?3
0<?3``020<71`@80_kno0P2m_Kd20;^k^`80^KVi0P2f][H20;Bd]080/[:b0P2`/;020:j^[P80[:b/
0P2ZZZX20:RXZ080YZJV00<0Y:BT0::RXP2RXZ800P2PX:0209jNWP80W9bL0P2JVYX209RHV080UYJF
5@3oool001<0oooo0P2<S8`208F5Q@80OGem0P1fMWH206i^KP80IfMW0P1OGel205MGE`0304m?C`17
AdL0AdM70080?Shn0P0e=CD202`/;0808b<S0P0H61P200`<30802`/;0P0A4A4201LG5`807alO0P0V
9RH202d];@80=CDe0P0n?Sh00`15ADD0CTi>04i>CP0205IFEP80Fe]K0P1OGel206=SH`@0IFEU0P1T
I6@206=SH`80HV9R0P1QHF42061PH080GemO0P1MGEd305aLG080Fe]K0P1JFUX205UIF@@0F5QH0P1G
EeL205IFEP80EEEE0P1DE5@205=CD`80DU9B0P1ADE42051@D080Cdm?0P1>CTh00`1=CDd0C4a<04a<
C00204a<C080Bd];301:BTX204];B`80C4a<0P1=CDd204i>CP80Cdm?0P1@D5000`1BDU80EEEE05EE
E@0205MGE`80Fe]K0P1OGel206ATI080JFUY0P1_Kfl207QhN080P8200P2:RXX209FEU@80XZ:R0P2]
[Jd20;Zj^P80_kno00<0aLG50<W9b@39bLT00P3?cll20=3@d080dM7A0P3Cdm<20=;BdP80dM7A0P3@
d=020<o?c`80cLg=0P3<c<`20<[:bP80b<S80P36a/H20<C4a0030<?3``31`L40`L710080_kno0P2m
_Kd20;^k^`80^KVi0P2g]kL20;Fe]@80/k>c0P2a/K420:n_[`80[Jf]0P2[Zj/20:VYZ@80YjNW0P2U
YJD00`2SXj<0XJ6Q0:6QX@0209nOW`80WIfM0P2KVi/209VIV@80UiNG0P2EUIDE0?ooo`004`3oool2
08b<S080QHF50P1mOGd207IfMP80KVi^0P1WIfL205mOG`80EeMG00<0Cdm?04M7A`17AdL00P0n?Sh2
03De=@80;2`/0P0S8b<201PH608030`<0P0;2`/2014A4@805aLG0P0O7al202HV9P80;Bd]0P0e=CD2
03hn?P0304E5A@1>CTh0CTi>0080EUIF0P1KFe/205mOG`80Hf=S101UIFD206ATI080Hf=S0P1RHV82
065QH@80H61P0P1OGel205eMG@<0G5aL0P1KFe/205YJFP80FEUI101HF5P205MGE`80EUIF0P1EEED2
05ADE080De=C0P1BDU82055AD@80D51@0P1?Cdl204i>CP0304e=C@1<C4`0C4a<0080C4a<0P1;Bd/<
04Y:BP80Bd];0P1<C4`204e=C@80CTi>0P1?Cdl2051@D003059BDP1EEED0EEEE0080EeMG0P1KFe/2
05mOG`80I6AT0P1YJFT206m_K`80N7Qh0P20P80208Z:RP80UIFE0P2RXZ820:f][@80^[Zj0P2o_kl0
0`35aLD0bLW90<W9b@020<o?c`80d=3@0P3AdM420=?Cd`80d];B0P3AdM420=3@d080clo?0P3=cLd2
0<c<c080b/[:0P38b<P20<K6aP80a<C400<0`l?30<71`@31`L400P2o_kl20;fm_@80^k^k0P2i^KT2
0;Ng]`80]KFe0P2c/k<20;6a/@80[jn_0P2][Jd20:^[Z`80ZJVY0P2WYjL20:FUY@030:>SX`2QXJ40
XJ6Q0080WinO0P2MWId209^KV`80VIVI0P2GUiL209FEUAD0oooo000C0?ooo`80S8b<0P25QHD207em
O@80MWIf0P1^KVh206MWI`80GemO0P1GEeL00`1?Cdl0AdM704M7A`0203lo?`80=SHf0P0];Bd202<S
8`806ATI0P0?3`l200P8208030`<0P0C4a<201XJ6P808R8R0P0Y:BT2038b<P80>c/k00<0@d=304];
B`1;Bd/00P1CDe<205UIF@80GUiN0P1QHF4206=SH`80I6AT101SHf<2069RHP80HF5Q0P1PH60205mO
G`80GUiN0P1MGEd00`1LG5`0Fe]K05]KF`0205YJFP@0FEUI101HF5P205MGE`80EUIF101EEED205AD
E080De=C0P1BDU82055AD@<0D51@0P1?Cdl204i>CP@0CDe=301<C4`204e=C@80CTi>0P1?Cdl2055A
D@80DU9B00<0De=C05EEE@1EEED00P1HF5P205]KF`80GemO0P1TI6@206YZJP80L71`0P1hN7P20861
P@80RXZ:0P2EUID20::RXP80[Jf]0P2i^KT20;fm_@030<?3``38b<P0b<S80080c/k>0P3?cll20=3@
d080dM7A0P3@d=020<k>cP80cLg=0P3<c<`20<[:bP80bLW90P37alL20<K6aP80a<C40P32`/800`31
`L40_kno0;no_`020;fm_@80^k^k0P2i^KT20;Ng]`80][Jf0P2d];@20;:b/P80/;2`0P2^[Zh20:b/
[080ZZZZ0P2XZ:P20:NWY`80YJFU00<0Xj>S0:6QX@2QXJ400P2OWil209fMW@80Vi^K0P2IVIT209NG
U`80UIFE5@3oool001<0oooo0P2<S8`208F5Q@80OGem0P1fMWH206i^KP80IfMW0P1OGel205MGE`03
04m?C`17AdL0AdM70080?clo0P0f=SH202d];@808b<S0P0I6AT200l?3`8020P80P0<30`201<C4`80
6QXJ0P0R8R8202TY:@80<S8b0P0k>c/00`13@d<0Bd];04];B`0205=CD`80FEUI0P1NGUh2065QH@80
Hf=S0P1TI6@406=SH`80HV9R0P1QHF42061PH080GemO0P1NGUh205eMG@0305aLG01KFe/0Fe]K0080
FUYJ101IFET405QHF080EeMG0P1FEUH405EEE@80E5AD0P1CDe<2059BDP80DE5A0`1@D50204m?C`80
CTi>101=CDd<04a<C080CDe=0P1>CTh204m?C`80DE5A0P1BDU800`1CDe<0EEEE05EEE@0205QHF080
Fe]K0P1OGel206ATI080JVYZ0P1`L70207QhN080PH610P2:RXX209FEU@80XZ:R0P2][Jd20;Vi^@80
_Kfm00<0`l?30<S8b038b<P00P3>c/h20<o?c`80d=3@0P3AdM420=3@d080c/k>0P3=cLd20<c<c080
b/[:0P39bLT20<O7a`80a/K60P34a<@20<;2`P030<71`@2o_kl0_kno0080_Kfm0P2k^k/20;Vi^@80
]kNg0P2f][H20;Bd]080/[:b0P2`/;020:j^[P80[:b/0P2ZZZX20:RXZ080YjNW0P2UYJD00`2SXj<0
XJ6Q0:6QX@0209nOW`80WIfM0P2KVi/209VIV@80UiNG0P2EUIDE0?ooo`004`3oool208b<S080QHF5
0P1mOGd207IfMP80Kfm_0P1WIfL205mOG`80F5QH00<0D51@04Q8B018B4P00P0o?cl203Lg=`80;Rh^
0P0T92@201/K6`804A4A10061PH200d=3@805ADE0P0M7Ad202DU9@80;Bd]0P0g=cL00`10@400BDU9
04U9B@02055AD@80EeMG0P1LG5`205mOG`80HF5Q1P1RHV82065QH@@0H61P0P1OGel205iNGP80GEeM
0`1LG5`205]KF`@0FUYJ101IFET405QHF080EeMG101FEUH205EEE@80E5AD101CDe<3055AD@@0D51@
101?Cdl<04i>CP80Cdm?0P1@D502059BDP80De=C00<0E5AD05IFEP1FEUH00P1HF5P205aLG080H61P
0P1TI6@206UYJ@80Kfm_0P1gMgL20820P080RXZ:0P2DU9@20:2PX080[:b/0P2h^;P20;bl_0030<30
`036a/H0a/K60080c<c<1P3>c/h20<g=c@80c<c<0P3:b/X20<W9b@80b<S80P36a/H20<G5a@80`l?3
0P32`/820<30`0030;jn_P2m_Kd0_Kfm0080^k^k0P2i^KT20;Rh^080][Jf0P2d];@20;:b/P80/K6a
0P2_[jl20:f][@80Zj^[0P2YZJT20:RXZ080YZJV0P2TY:@00`2RXZ80X:2P0:2PX00209nOW`80WIfM
0P2KVi/209VIV@80UiNG0P2EUIDE0?ooo`004`3oool208b<S080QHF50P1mOGd207IfMP80Kfm_0P1W
IfL205mOG`80F5QH00<0D51@04Q8B018B4P00P0o?cl203Lg=`80;Rh^0P0T92@201/K6`804A4A1006
1PH200d=3@805ADE0P0M7Ad202DU9@80;Bd]0P0g=cL00`10@400BDU904U9B@02055AD@80EeMG0P1L
G5`205mOG`80HF5Q1P1RHV82065QH@@0H61P0P1OGel205iNGP80GEeM0`1LG5`205]KF`@0FUYJ101I
FET405QHF080EeMG101FEUH205EEE@80E5AD101CDe<3055AD@@0D51@101?Cdl<04i>CP80Cdm?0P1@
D502059BDP80De=C00<0E5AD05IFEP1FEUH00P1HF5P205aLG080H61P0P1TI6@206UYJ@80Kfm_0P1g
MgL20820P080RXZ:0P2DU9@20:2PX080[:b/0P2h^;P20;bl_0030<30`036a/H0a/K60080c<c<1P3>
c/h20<g=c@80c<c<0P3:b/X20<W9b@80b<S80P36a/H20<G5a@80`l?30P32`/820<30`0030;jn_P2m
_Kd0_Kfm0080^k^k0P2i^KT20;Rh^080][Jf0P2d];@20;:b/P80/K6a0P2_[jl20:f][@80Zj^[0P2Y
ZJT20:RXZ080YZJV0P2TY:@00`2RXZ80X:2P0:2PX00209nOW`80WIfM0P2KVi/209VIV@80UiNG0P2E
UIDE0?ooo`004`3oool208b<S080QHF50P1nOWh207IfMP80Kfm_0P1WIfL2061PH080F5QH00<0D51@
04Q8B018B4P00P10@40203Ph>080;bl_0P0V9RH201dM7@804a<C0P0820P200<30`8020P80P0@4102
01LG5`80820P0P0Y:BT2038b<P0303`l?016ATH0ATI60080CTi>0P1EEED205UIF@80GEeM0P1OGel2
061PH0H0HF5Q0P1PH60405mOG`@0GUiN00<0GEeM05aLG01LG5`00P1LG5`405]KF`@0FUYJ101IFET4
05QHF0@0EeMG101FEUH205EEE@<0E5AD0P1CDe<4059BDPH0DE5A201@D502055AD@80DU9B0P1CDe<2
05ADE00305EEE@1GEeL0EeMG0080FUYJ0P1LG5`2061PH080IFEU0P1ZJVX206m_K`80MgMg0P1oOgl2
08Z:RP80U9BD0P2OWil20:^[Z`80^;Rh0P2l_;`00`2n_[h0aLG50<G5a@020<W9b@80c<c<0P3=cLd2
0<_;b`80b/[:0P39bLT20<O7a`80a/K60P35aLD20<C4a080`/;20P31`L420;no_`80_[jn00<0_;bl
0;^k^`2k^k/00P2i^KT20;Rh^080][Jf0P2d];@20;>c/`80/K6a0P2_[jl20:j^[P80[:b/0P2ZZZX2
0:VYZ@80YjNW0P2UYJD20:>SX`030::RXP2PX:00X:2P0080WYjN0P2LW9`209^KV`80VIVI0P2GUiL2
09FEUAD0oooo000C0?ooo`80S8b<0P25QHD207inOP80MWIf0P1_Kfl206MWI`80H61P0P1HF5P00`1@
D500B4Q804Q8B0020410@080>3Ph0P0_;bl202HV9P807AdM0P0C4a<200P820800`<30P0820P2010@
40805aLG0P0P820202TY:@80<S8b00<0?3`l04I6AP16ATH00P1>CTh205EEE@80FEUI0P1MGEd205mO
G`80H61P1P1QHF42061PH0@0GemO101NGUh00`1MGEd0G5aL05aLG00205aLG0@0Fe]K101JFUX405UI
F@@0F5QH101GEeL405IFEP80EEEE0`1DE5@205=CD`@0DU9B1P1ADE48051@D080DE5A0P1BDU8205=C
D`80E5AD00<0EEEE05MGE`1GEeL00P1JFUX205aLG080H61P0P1UIFD206YZJP80Kfm_0P1gMgL207mo
O`80RXZ:0P2DU9@209nOW`80Zj^[0P2h^;P20;bl_0030;jn_P35aLD0aLG50080bLW90P3<c<`20<g=
c@80bl_;0P3:b/X20<W9b@80alO70P36a/H20<G5a@80a<C40P32`/820<71`@80_kno0P2n_[h00`2l
_;`0^k^k0;^k^`020;Vi^@80^;Rh0P2f][H20;Bd]080/k>c0P2a/K420:n_[`80[Zj^0P2/[:`20:ZZ
ZP80ZJVY0P2WYjL20:FUY@80Xj>S00<0XZ:R0:2PX02PX:000P2NWYh209bLW080Vi^K0P2IVIT209NG
U`80UIFE5@3oool001<0oooo0P2<S8`208F5Q@80OWin0P1gMgL206m_K`80J6QX0P1PH60205UIF@03
055AD@19BDT0BDU90080@D510P0i>CT2034a<@80:2PX0P0O7al201DE5@8030`<0P020P8200<30`80
2@T90P0A4A4201XJ6P808b<S0P0^;Rh00`0h>3P0@T920492@P0204a<C080De=C0P1HF5P205]KF`80
GEeM1P1OGel2061PH0H0GemO101NGUh305eMG@@0G5aL1P1KFe/605YJFPH0FEUI101HF5P205MGE`<0
EUIF101EEED605ADE0`0De=C101DE5@205EEE@0305IFEP1HF5P0F5QH0080Fe]K0P1MGEd2065QH@80
IFEU0P1ZJVX2071`L080MgMg0P1oOgl208V9R@80U9BD0P2NWYh20:VYZ@80]KFe0P2j^[X00`2n_[h0
a<C40<C4a0020<S8b0@0b/[:0P38b<P20<O7a`80a/K60P35aLD20<C4a080`/;20P31`L420<30`080
_kno0P2m_Kd20;bl_0030;Zj^P2i^KT0^KVi0080^;Rh0P2f][H20;Fe]@80/k>c0P2a/K420;2`/080
[Zj^0P2][Jd20:^[Z`80ZJVY0P2XZ:P20:JVYP80Y:BT0P2SXj<00`2QXJ40WinO09nOW`0209jNWP80
W9bL0P2JVYX209VIV@80UiNG0P2EUIDE0?ooo`004`3oool208b<S080QHF50P1nOWh207MgM`80Kfm_
0P1XJ6P2061PH080FEUI00<0DE5A04U9B@19BDT00P11@D4203Ti>@80<C4a0P0X:2P201lO7`805ADE
0P0<30`200820P800`<30P092@T2014A4@806QXJ0P0S8b<202h^;P0303Ph>012@T80@T920080C4a<
0P1CDe<205QHF080Fe]K0P1MGEd605mOG`80H61P1P1OGel405iNGP<0GEeM101LG5`605]KF`H0FUYJ
1P1IFET405QHF080EeMG0`1FEUH405EEE@H0E5AD301CDe<405ADE080EEEE00<0EUIF05QHF01HF5P0
0P1KFe/205eMG@80HF5Q0P1UIFD206YZJP80L71`0P1gMgL207moO`80RHV90P2DU9@209jNWP80ZJVY
0P2e]KD20;Zj^P030;jn_P34a<@0a<C40080b<S8103:b/X20<S8b080alO70P36a/H20<G5a@80a<C4
0P32`/820<71`@80`<300P2o_kl20;fm_@80_;bl00<0^[Zj0;Vi^@2i^KT00P2h^;P20;Jf]P80]KFe
0P2c/k<20;6a/@80/;2`0P2^[Zh20:f][@80Zj^[0P2YZJT20:RXZ080YZJV0P2TY:@20:>SX`030:6Q
X@2OWil0WinO0080WYjN0P2LW9`209ZJVP80VIVI0P2GUiL209FEUAD0oooo000C0?ooo`80S8b<0P25
QHD207inOP80MgMg0P1`L70206QXJ080HF5Q0P1JFUX00`1BDU80BTY:04Y:BP020492@P80>SXj0P0b
<S8202XZ:P808B4Q0P0H61P200l?3`8010@40P00000200820P802PX:0P0D51@201hN7P80:2PX00<0
=3@d03lo?`0o?cl00P18B4P2051@D080EUIF0P1JFUX205aLG080GEeM0P1NGUh805mOG`L0GUiN101M
GEd605aLG0h0Fe]K101JFUX305UIF@@0F5QH101GEeL605IFEP`0EEEE0P1FEUH205MGE`0305QHF01J
FUX0FUYJ0080G5aL0P1OGel2069RHP80IVIV0P1[Jf/2071`L080MgMg0P1oOgl208R8R080Ti>C0P2M
WId20:NWY`80/K6a0P2f][H00`2k^k/0`L710<71`@020<K6aP80b<S80P36a/H20<G5a@80a<C40P33
`l<20<;2`P80`L710P30`<020;no_`80_Kfm0P2l_;`20;^k^`80^[Zj00<0^;Rh0;Ng]`2g]kL00P2f
][H20;Bd]080/k>c0P2a/K420;2`/080[jn_0P2][Jd20:^[Z`80ZZZZ0P2XZ:P20:NWY`80YJFU0P2T
Y:@20::RXP030:2PX02OWil0WinO0080WIfM0P2LW9`209ZJVP80V9RH0P2GUiL209FEUAD0oooo000C
0?ooo`80S8b<0P25QHD207moO`80MgMg0P1`L70206UYJ@80HV9R0P1KFe/00`1CDe<0C4a<04a<C002
04A4A080?3`l0P0d=3@202`/;08092@T0P0L71`201<C4`802`/;0P0410@20000008010@40P0?3`l2
01XJ6P809BDU00<0<30`03/k>`0k>c/00P15ADD204e=C@80De=C0P1HF5P205YJFP80Fe]K0P1LG5`2
05eMG@`0GUiN2@1MGEdF05aLG0D0Fe]K0P1JFUX405UIF@P0F5QH201GEeL205QHF0<0FEUI0P1KFe/2
05eMG@80H61P0P1SHf<206MWI`80Jf][0P1aLG4207MgM`80Ogmo0P28R8P2096AT@80Vi^K0P2VYZH2
0:f][@80/k>c00<0^[Zj0;no_`2o_kl00P33`l<20<C4a080`l?30P32`/820<71`@80`<300P2o_kl2
0;jn_P80_Kfm0P2l_;`20;^k^`80^[Zj0P2i^KT20;Rh^0030;Ng]`2e]KD0]KFe0080];Bd0P2c/k<2
0;6a/@80/;2`0P2_[jl20:f][@80[:b/0P2ZZZX20:VYZ@80YjNW0P2VYZH20:BTY080Xj>S0P2QXJ40
0`2PX:00WYjN09jNWP0209fMW@80Vi^K0P2JVYX209RHV080UiNG0P2EUIDE0?ooo`004`3oool208b<
S080QHF50P1oOgl207MgM`80L71`0P1YJFT2069RHP80Fe]K00<0De=C04a<C01<C4`00P14A4@203`l
?080=3@d0P0/;2`202@T908071`L0P0C4a<200/;2`8010@40P00000200@410803`l?0P0J6QX202DU
9@03030`<00k>c/0>c/k0080ADE50P1=CDd205=CD`80F5QH0P1JFUX205]KF`80G5aL0P1MGEd<05iN
GPT0GEeM5P1LG5`505]KF`80FUYJ101IFET805QHF0P0EeMG0P1HF5P305UIF@80Fe]K0P1MGEd2061P
H080Hf=S0P1WIfL206][J`80LG5a0P1gMgL207moO`80R8R80P2ATI4209^KV`80YZJV0P2][Jd20;>c
/`030;Zj^P2o_kl0_kno0080`l?30P34a<@20<?3``80`/;20P31`L420<30`080_kno0P2n_[h20;fm
_@80_;bl0P2k^k/20;Zj^P80^KVi0P2h^;P00`2g]kL0]KFe0;Fe]@020;Bd]080/k>c0P2a/K420;2`
/080[jn_0P2][Jd20:b/[080ZZZZ0P2YZJT20:NWY`80YZJV0P2TY:@20:>SX`80XJ6Q00<0X:2P09jN
WP2NWYh00P2MWId209^KV`80VYZJ0P2HV9P209NGU`80UIFE5@3oool001<0oooo0P2=SHd208J6QP80
Ogmo0P1hN7P2075aL@80JVYZ0P1SHf<205aLG00305ADE01=CDd0CDe=0080ADE50P0n?Sh203Hf=P80
;bl_0P0W9bL201lO7`8061PH0P0A4A4200X:2P801@D50P020P8200X:2P805QHF0P0Q8B400`0/;2`0
=cLg03Lg=`020451@@80BTY:0P1@D50205EEE@80F5QH0P1JFUX205]KF`80G5aL6`1MGEdA05iNGPH0
GEeM101LG5`205]KF``0FUYJ0P1IFET405YJFP0305]KF`1MGEd0GEeM0080GUiN0P1QHF4206ATI080
J6QX0P1/K6`2071`L080MgMg0P1oOgl208N7Q`80T92@0P2JVYX20::RXP80ZJVY0P2`/;000`2g]kL0
_;bl0;bl_0020;no_`80`<30102o_kl20;jn_P80_Kfm0P2l_;`40;^k^`80^[Zj0P2i^KT20;Rh^080
]kNg0P2f][H00`2e]KD0];Bd0;Bd]0020;:b/P80/K6a0P2`/;020:n_[`80[Jf]0P2/[:`20:^[Z`80
ZJVY0P2XZ:P20:JVYP80YJFU0P2TY:@20::RXP80XJ6Q00<0WinO09jNWP2NWYh00P2LW9`209^KV`80
VIVI0P2HV9P209JFUP80UIFE5@3oool001<0oooo0P2=SHd208J6QP80Ogmo0P1hN7P2075aL@80JVYZ
0P1SHf<205aLG00305ADE01=CDd0CDe=0080ADE50P0n?Sh203Hf=P80;bl_0P0W9bL201lO7`8061PH
0P0A4A4200X:2P801@D50P020P8200X:2P805QHF0P0Q8B400`0/;2`0=cLg03Lg=`020451@@80BTY:
0P1@D50205EEE@80F5QH0P1JFUX205]KF`80G5aL6`1MGEdA05iNGPH0GEeM101LG5`205]KF``0FUYJ
0P1IFET405YJFP0305]KF`1MGEd0GEeM0080GUiN0P1QHF4206ATI080J6QX0P1/K6`2071`L080MgMg
0P1oOgl208N7Q`80T92@0P2JVYX20::RXP80ZJVY0P2`/;000`2g]kL0_;bl0;bl_0020;no_`80`<30
102o_kl20;jn_P80_Kfm0P2l_;`40;^k^`80^[Zj0P2i^KT20;Rh^080]kNg0P2f][H00`2e]KD0];Bd
0;Bd]0020;:b/P80/K6a0P2`/;020:n_[`80[Jf]0P2/[:`20:^[Z`80ZJVY0P2XZ:P20:JVYP80YJFU
0P2TY:@20::RXP80XJ6Q00<0WinO09jNWP2NWYh00P2LW9`209^KV`80VIVI0P2HV9P209JFUP80UIFE
5@3oool001<0oooo0P2=SHd208J6QP80Ogmo0P1hN7P2079bLP80Jf][0P1TI6@205eMG@0305IFEP1>
CTh0CTi>0080AdM70P10@40203Ti>@80<C4a0P0Z:RX2028R8P806a/K0P0E5AD200h>3P802@T90P04
10@200H61P8051@D0P0N7Qh00`0X:2P0<c<c03<c<`0203dm?@80ATI60P1=CDd2059BDP80EEEE0P1G
EeL205UIF@80FUYJ0P1KFe/805aLG0T0GEeM2P1NGUh405mOG`H0H61P0P1QHF47061PH0@0GemO101N
GUh805eMG@H0G5aL1@1MGEd205iNGP80H61P0P1RHV8206EUI@80JFUY0P1^KVh2075aL@80MWIf0P1o
Ogl208N7Q`80Shn?0P2JVYX20:6QX@80YZJV0P2][Jd00`2d];@0^KVi0;Vi^@060;bl_0@0^k^k0P2j
^[X40;Vi^@80^;Rh102g]kL20;Jf]P80]KFe0P2d];@00`2c/k<0/[:b0;:b/P020;6a/@80/;2`0P2^
[Zh20:f][@80[:b/0P2[Zj/20:VYZ@80Z:RX0P2WYjL20:JVYP80Y:BT0P2SXj<20:6QX@80X:2P00<0
WinO09fMW@2MWId00P2LW9`209^KV`80VIVI0P2HV9P209JFUP80UIFE5@3oool001<0oooo0P2=SHd2
08J6QP80Ogmo0P1hN7P2079bLP80Jf][0P1TI6@205eMG@0305IFEP1>CTh0CTi>0080AdM70P10@402
03Ti>@80<C4a0P0Z:RX2028R8P806a/K0P0E5AD200h>3P802@T90P0410@200H61P8051@D0P0N7Qh0
0`0X:2P0<c<c03<c<`0203dm?@80ATI60P1=CDd2059BDP80EEEE0P1GEeL205UIF@80FUYJ0P1KFe/8
05aLG0T0GEeM2P1NGUh405mOG`H0H61P0P1QHF47061PH0@0GemO101NGUh805eMG@H0G5aL1@1MGEd2
05iNGP80H61P0P1RHV8206EUI@80JFUY0P1^KVh2075aL@80MWIf0P1oOgl208N7Q`80Shn?0P2JVYX2
0:6QX@80YZJV0P2][Jd00`2d];@0^KVi0;Vi^@060;bl_0@0^k^k0P2j^[X40;Vi^@80^;Rh102g]kL2
0;Jf]P80]KFe0P2d];@00`2c/k<0/[:b0;:b/P020;6a/@80/;2`0P2^[Zh20:f][@80[:b/0P2[Zj/2
0:VYZ@80Z:RX0P2WYjL20:JVYP80Y:BT0P2SXj<20:6QX@80X:2P00<0WinO09fMW@2MWId00P2LW9`2
09^KV`80VIVI0P2HV9P209JFUP80UIFE5@3oool001<0oooo0P2=SHd208J6QP80P8200P1iNGT2079b
LP80Jf][0P1UIFD205iNGP0305MGE`1@D500D51@0080BDU90P12@T8203/k>`80=3@d0P0];Bd202DU
9@807alO0P0H61P2018B4P8030`<0P061PH200D51@803`l?0P0K6a/00`0U9BD0<30`030`<00203Ti
>@80@T920P19BDT204m?C`80De=C0P1EEED205MGE`80F5QH0P1IFET205YJFPH0Fe]K0`1LG5`405eM
G@H0GUiN1P1OGel2061PH0@0HF5Q0P1RHV8406=SH`/0HV9R1P1QHF44061PH0@0GemO101NGUh505mO
G`80H61P0P1QHF4206ATI080IfMW0P1ZJVX206m_K`80Lg=c0P1gMgL207emO@80QXJ60P2?Shl209RH
V080WYjN0P2TY:@20:ZZZP030;2`/02e]KD0]KFe0080^KVi202h^;P40;Ng]`@0][Jf0P2e]KD40;Bd
]080/k>c0P2b/[800`2a/K40/;2`0;2`/0020:n_[`80[Zj^0P2][Jd20:b/[080Zj^[0P2ZZZX20:RX
Z080YjNW0P2VYZH20:FUY@80Xj>S0P2RXZ820:6QX@80WinO00<0WYjN09fMW@2MWId00P2LW9`209ZJ
VP80VIVI0P2HV9P209JFUP80UIFE5@3oool001<0oooo0P2=SHd208J6QP80P8200P1iNGT2079bLP80
Jf][0P1UIFD205iNGP0305MGE`1@D500D51@0080BDU90P12@T8203/k>`80=3@d0P0];Bd202DU9@80
7alO0P0H61P2018B4P8030`<0P061PH200D51@803`l?0P0K6a/00`0U9BD0<30`030`<00203Ti>@80
@T920P19BDT204m?C`80De=C0P1EEED205MGE`80F5QH0P1IFET205YJFPH0Fe]K0`1LG5`405eMG@H0
GUiN1P1OGel2061PH0@0HF5Q0P1RHV8406=SH`/0HV9R1P1QHF44061PH0@0GemO101NGUh505mOG`80
H61P0P1QHF4206ATI080IfMW0P1ZJVX206m_K`80Lg=c0P1gMgL207emO@80QXJ60P2?Shl209RHV080
WYjN0P2TY:@20:ZZZP030;2`/02e]KD0]KFe0080^KVi202h^;P40;Ng]`@0][Jf0P2e]KD40;Bd]080
/k>c0P2b/[800`2a/K40/;2`0;2`/0020:n_[`80[Zj^0P2][Jd20:b/[080Zj^[0P2ZZZX20:RXZ080
YjNW0P2VYZH20:FUY@80Xj>S0P2RXZ820:6QX@80WinO00<0WYjN09fMW@2MWId00P2LW9`209ZJVP80
VIVI0P2HV9P209JFUP80UIFE5@3oool001<0oooo0P2=SHd208J6QP80P8200P1iNGT207=cL`80K6a/
0P1VIVH205mOG`0305QHF01BDU80DU9B0080Bd];0P14A4@203dm?@80=SHf0P0_;bl202PX:0808R8R
0P0K6a/201@D50803Ph>0P061PH200D51@802PX:0P0F5QH00`0Q8B40;2`/02`/;00203Hf=P80?clo
0P16ATH204a<C080D51@0P1CDe<205EEE@80EUIF0P1GEeL405UIF@@0FUYJ0P1KFe/305aLG080GEeM
1P1NGUh405mOG`@0H61P0P1QHF42069RHP80Hf=S0P1TI6@206EUI@<0I6AT201UIFD206ATI0H0Hf=S
101RHV84065QH@L0H61P0P1QHF42069RHP80IFEU0P1XJ6P206a/K080L71`0P1dM7@207UiN@80Ogmo
0P27QhL208b<S080UYJF0P2MWId20:>SX`80Z:RX00<0[Zj^0;:b/P2b/[800P2d];@80;Fe]@H0];Bd
102c/k<40;:b/P80/K6a0P2`/;000`2_[jl0[Zj^0:j^[P040:f][@80[:b/0P2[Zj/20:ZZZP80Z:RX
0P2WYjL20:JVYP80YJFU0P2TY:@20:>SX`80XJ6Q0P2PX:0209nOW`0309jNWP2LW9`0W9bL0080Vi^K
0P2JVYX209VIV@80UiNG0P2FUYH209FEUAD0oooo000C0?ooo`80SHf=0P26QXH20820P080NGUi0P1c
Lg<206a/K080IVIV0P1OGel00`1HF5P0DU9B059BDP0204];B`80A4A40P0m?Cd203Hf=P80;bl_0P0X
:2P2028R8P806a/K0P0D51@200h>3P801PH60P051@D200X:2P805QHF00<08B4Q02`/;00/;2`00P0f
=SH203lo?`80ATI60P1<C4`2051@D080De=C0P1EEED205IFEP80EeMG101IFET405YJFP80Fe]K0`1L
G5`205eMG@H0GUiN101OGel4061PH080HF5Q0P1RHV8206=SH`80I6AT0P1UIFD306ATI0P0IFEU0P1T
I6@606=SH`@0HV9R101QHF47061PH080HF5Q0P1RHV8206EUI@80J6QX0P1/K6`2071`L080M7Ad0P1i
NGT207moO`80QhN70P2<S8`209JFUP80WIfM0P2SXj<20:RXZ0030:j^[P2b/[80/[:b0080];Bd202e
]KD60;Bd]0@0/k>c102b/[820;6a/@80/;2`00<0[jn_0:j^[P2^[Zh0102][Jd20:b/[080Zj^[0P2Z
ZZX20:RXZ080YjNW0P2VYZH20:FUY@80Y:BT0P2SXj<20:6QX@80X:2P0P2OWil00`2NWYh0W9bL09bL
W00209^KV`80VYZJ0P2IVIT209NGU`80UYJF0P2EUIDE0?ooo`004`3oool208f=S@80QhN70P20P802
07YjNP80M7Ad0P1]KFd206MWI`80H61P00<0FUYJ05=CD`1CDe<00P1=CDd204I6AP80?clo0P0i>CT2
038b<P80:b/[0P0U9BD201hN7P805aLG0P0@410200P820801@D50P061PH2018B4P0301`L700V9RH0
9RHV0080<C4a0P0j>SX20492@P80B4Q80P1<C4`2051@D080DU9B0P1DE5@205EEE@@0EeMG0P1HF5P4
05UIF@0305YJFP1KFe/0Fe]K0080G5aL0P1MGEd405iNGP@0GemO0P1PH604065QH@80Hf=S0P1TI6@2
06EUI@L0IVIV1P1WIfL606IVIP@0IFEU101TI6@206=SH`L0HV9R0P1SHf<206ATI080IVIV0P1YJFT2
06a/K080L71`0P1dM7@207YjNP80P8200P28R8P208f=S@80UIFE0P2KVi/20::RXP80YZJV00<0Zj^[
0;2`/02`/;00102a/K4:0;:b/PH0/K6a102`/;020:n_[`80[Zj^0`2][Jd20:b/[080Zj^[0P2ZZZX2
0:VYZ@80Z:RX0P2WYjL20:JVYP80YJFU0P2TY:@20:>SX`80XZ:R0P2QXJ4209nOW`80WYjN00<0WIfM
09bLW02LW9`00P2KVi/209ZJVP80V9RH0P2GUiL209JFUP80UIFE5@3oool001<0oooo0P2=SHd208N7
Q`80P8200P1jNWX207AdM080KFe]0P1WIfL2061PH00305YJFP1CDe<0De=C0080CDe=0P16ATH203lo
?`80>CTi0P0b<S8202/[:`809BDU0P0N7Qh201LG5`80410@0P0820P200D51@801PH60P0B4Q800`0L
71`09RHV02HV9P02034a<@80>SXj0P12@T8204Q8B080C4a<0P1@D502059BDP80E5AD0P1EEED405MG
E`80F5QH101IFET00`1JFUX0Fe]K05]KF`0205aLG080GEeM101NGUh405mOG`80H61P101QHF4206=S
H`80I6AT0P1UIFD706IVIPH0IfMW1P1VIVH406EUI@@0I6AT0P1SHf<7069RHP80Hf=S0P1TI6@206IV
IP80JFUY0P1/K6`2071`L080M7Ad0P1jNWX20820P080R8R80P2=SHd209FEU@80Vi^K0P2RXZ820:JV
YP030:^[Z`2`/;00/;2`00@0/K6a2P2b/[860;6a/@@0/;2`0P2_[jl20:j^[P<0[Jf]0P2/[:`20:^[
Z`80ZZZZ0P2YZJT20:RXZ080YjNW0P2VYZH20:FUY@80Y:BT0P2SXj<20::RXP80XJ6Q0P2OWil209jN
WP0309fMW@2LW9`0W9bL0080Vi^K0P2JVYX209RHV080UiNG0P2FUYH209FEUAD0oooo000C0?ooo`80
SHf=0P27QhL20861P@80Ng]k0P1dM7@206i^KP80J6QX0P1RHV800`1KFe/0EEEE05EEE@0204m?C`80
B4Q80P12@T8203/k>`80=CDe0P0^;Rh202PX:0808B4Q0P0J6QX201<C4`802`/;0P061PH200<30`80
2`/;00<05QHF01lO7`0O7al00P0Z:RX203@d=080?Cdm0P14A4@204U9B@80CDe=0P1?Cdl2055AD@80
DU9B0P1DE5@405EEE@80EUIF0P1HF5P00`1IFET0FUYJ05YJFP0205]KF`@0GEeM0P1NGUh405mOG`@0
H61P0P1QHF42069RHP80I6AT0P1UIFD206IVIPT0IfMW201XJ6P406MWI`@0IVIV0P1UIFD606ATI0D0
IFEU0P1WIfL206][J`80KFe]0P1bLW8207MgM`80O7al0P22PX8208V9R@80SXj>0P2EUID209^KV`80
XJ6Q0P2UYJD00`2YZJT0[:b/0:b/[0020:f][@80[Zj^3P2_[jl60:j^[P80[Jf]0`2/[:`20:^[Z`80
ZZZZ102YZJT20:RXZ080YjNW0P2VYZH20:FUY@80Y:BT0P2SXj<20::RXP80XJ6Q0P2PX:0209nOW`80
WYjN00<0WIfM09bLW02LW9`00P2JVYX209VIV@80V9RH0P2GUiL209JFUP80UIFE5@3oool001<0oooo
0P2=SHd208N7Q`80PH610P1kNg/207AdM080KVi^0P1XJ6P2069RHP0305]KF`1EEED0EEEE0080Cdm?
0P18B4P20492@P80>c/k0P0e=CD202h^;P80:2PX0P0Q8B4201XJ6P804a<C0P0;2`/200H61P800`<3
0P0;2`/00`0F5QH07alO01lO7`0202XZ:P80=3@d0P0m?Cd204A4A080BDU90P1=CDd204m?C`80DE5A
0P1BDU8205ADE0@0EEEE0P1FEUH205QHF00305UIF@1JFUX0FUYJ0080Fe]K101MGEd205iNGP@0GemO
101PH602065QH@80HV9R0P1TI6@206EUI@80IVIV2@1WIfL806QXJ0@0IfMW101VIVH206EUI@H0I6AT
1@1UIFD206MWI`80Jf][0P1]KFd2079bLP80MgMg0P1lO7`208:2PP80RHV90P2>SXh209FEU@80Vi^K
0P2QXJ420:FUY@030:VYZ@2/[:`0[:b/0080[Jf]0P2^[Zh>0:n_[`H0[Zj^0P2][Jd30:b/[080Zj^[
0P2ZZZX40:VYZ@80Z:RX0P2WYjL20:JVYP80YJFU0P2TY:@20:>SX`80XZ:R0P2QXJ420:2PX080WinO
0P2NWYh00`2MWId0W9bL09bLW00209ZJVP80VIVI0P2HV9P209NGU`80UYJF0P2EUIDE0?ooo`004`3o
ool208f=S@80QhN70P21PH4207]kN`80MGEe0P1_Kfl206UYJ@80Hf=S00<0GEeM05MGE`1GEeL00P1@
D50204Y:BP80A4A40P0n?Sh203Lg=`80<C4a0P0[:b/202@T90807QhN0P0G5aL200l?3`801`L70P03
0`<200H61P0300h>3P0I6AT06ATI00808b<S0P0];Bd203Hf=P80?Shn0P15ADD204Y:BP80C4a<0P1=
CDd204m?C`80D51@0P1BDU8205=CD`80E5AD0P1FEUH00`1GEeL0F5QH05QHF00205YJFP80Fe]K0P1L
G5`205eMG@80G5aL0P1MGEd205iNGP80GemO0P1PH602065QH@80HV9R0P1TI6@406EUI@D0IVIV101W
IfL406QXJ080IfMW0P1XJ6P806MWI`80IVIV1@1UIFD206IVIP80IfMW0P1YJFT206e]K@80Kfm_0P1b
LW8207QhN080Ogmo0P24Q8@208R8R080SXj>0P2DU9@209ZJVP80WinO0P2TY:@00`2XZ:P0ZJVY0:VY
Z@020:ZZZP80Zj^[102/[:`:0:f][@H0[:b/102[Zj/30:ZZZP80ZJVY0P2XZ:P40:NWY`80YZJV0P2U
YJD20:BTY080Xj>S0P2RXZ820:6QX@80X:2P0P2OWil209jNWP80WIfM00<0W9bL09^KV`2KVi/00P2J
VYX209VIV@80V9RH0P2GUiL209JFUP80UIFE5@3oool001<0oooo0P2=SHd208N7Q`80PH610P1kNg/2
07EeM@80Kfm_0P1YJFT206=SH`0305eMG@1GEeL0EeMG0080D51@0P1:BTX204A4A080?Shn0P0g=cL2
034a<@80:b/[0P0T92@201hN7P805aLG0P0?3`l200L71`800`<30P061PH00`0>3Ph06ATI01TI6@02
02<S8`80;Bd]0P0f=SH203hn?P80ADE50P1:BTX204a<C080CDe=0P1?Cdl2051@D080DU9B0P1CDe<2
05ADE080EUIF00<0EeMG05QHF01HF5P00P1JFUX205]KF`80G5aL0P1MGEd205aLG080GEeM0P1NGUh2
05mOG`80H61P0P1QHF42069RHP80I6AT101UIFD506IVIP@0IfMW101XJ6P206MWI`80J6QX201WIfL2
06IVIPD0IFEU0P1VIVH206MWI`80JFUY0P1]KFd206m_K`80LW9b0P1hN7P207moO`80Q8B40P28R8P2
08j>SP80U9BD0P2JVYX209nOW`80Y:BT00<0Z:RX0:VYZ@2YZJT00P2ZZZX20:^[Z`@0[:b/2P2][Jd6
0:b/[0@0Zj^[0`2ZZZX20:VYZ@80Z:RX102WYjL20:JVYP80YJFU0P2TY:@20:>SX`80XZ:R0P2QXJ42
0:2PX080WinO0P2NWYh209fMW@0309bLW02KVi/0Vi^K0080VYZJ0P2IVIT209RHV080UiNG0P2FUYH2
09FEUAD0oooo000C0?ooo`80SXj>0P28R8P208:2PP80O7al0P1fMWH2071`L080JVYZ0P1TI6@00`1N
GUh0F5QH05QHF002059BDP80C4a<0P16ATH20410@080>SXj0P0d=3@202h^;P809bLW0P0Q8B4201/K
6`8051@D0P0=3@d200H61P8010@400<01`L7014A4@0A4A400P0L71`202LW9`80<30`0P0g=cL203lo
?`80A4A40P18B4P204Y:BP80Bd];0P1=CDd204i>CP80D51@0P1ADE4205=CD`0305ADE01FEUH0EUIF
0080EeMG0P1HF5P205YJFPH0Fe]K0P1LG5`405eMG@80GemO0P1PH602065QH@80HV9R0`1SHf<406AT
I0H0IFEU101VIVH606MWI`80IVIV0P1WIfL706QXJ0@0JFUY0P1[Jf/206i^KP80LW9b0P1eMGD207Qh
N080OWin0P24Q8@208V9R@80SXj>0P2CTi<209VIV@80WYjN0P2SXj<00`2UYJD0YZJV0:JVYP020:NW
Y`80Z:RX0P2YZJT60:ZZZPH0Zj^[202ZZZX30:VYZ@80Z:RX102WYjL40:JVYP80YJFU0P2TY:@40:>S
X`80XJ6Q0P2PX:0409nOW`80WYjN0P2MWId00`2LW9`0Vi^K09^KV`0209ZJVP80VIVI0P2HV9P209NG
U`80UYJF0P2DU9@E0?ooo`004`3oool208j>SP80R8R80P22PX8207alO080MWIf0P1`L70206YZJP80
I6AT00<0GUiN05QHF01HF5P00P1BDU8204a<C080ATI60P10@40203Xj>P80=3@d0P0^;Rh202LW9`80
8B4Q0P0K6a/201@D50803@d=0P061PH200@4100300L71`0A4A404A4A008071`L0P0W9bL2030`<080
=cLg0P0o?cl204A4A080B4Q80P1:BTX204];B`80CDe=0P1>CTh2051@D080DE5A0P1CDe<00`1DE5@0
EUIF05IFEP0205MGE`80F5QH0P1JFUX605]KF`80G5aL101MGEd205mOG`80H61P0P1QHF42069RHP<0
Hf=S101TI6@606EUI@@0IVIV1P1WIfL206IVIP80IfMW1`1XJ6P406UYJ@80Jf][0P1^KVh2079bLP80
MGEe0P1hN7P207inOP80Q8B40P29RHT208j>SP80Ti>C0P2IVIT209jNWP80Xj>S00<0YJFU0:JVYP2V
YZH00P2WYjL20:RXZ080ZJVY1P2ZZZX60:^[Z`P0ZZZZ0`2YZJT20:RXZ0@0YjNW102VYZH20:FUY@80
Y:BT102SXj<20:6QX@80X:2P102OWil209jNWP80WIfM00<0W9bL09^KV`2KVi/00P2JVYX209VIV@80
V9RH0P2GUiL209JFUP80U9BD5@3oool001<0oooo0P2>SXh208R8R080PX:20P1mOGd207MgM`80LG5a
0P1[Jf/206IVIP03061PH01JFUX0FUYJ0080EEEE0P1?Cdl204U9B@80@d=30P0m?Cd203Lg=`80<C4a
0P0[:b/202DU9@807alO0P0H61P201<C4`803@d=0P092@T00`061PH03@d=00d=3@0201DE5@80820P
0P0Y:BT2030`<080>3Ph0P0n?Sh204A4A080ATI60P19BDT204Y:BP80Bd];0P1<C4`204i>CP80Cdm?
00<0DE5A059BDP1BDU800P1DE5@205IFEP@0EeMG0P1HF5P605UIF@80FUYJ0P1KFe/205eMG@@0GUiN
0P1OGel7061PH080HV9R101SHf<406ATI0P0IFEU0P1WIfL206QXJ0<0JFUY0P1ZJVX206][J`80KFe]
0P1_Kfl2079bLP80MWIf0P1jNWX207moO`80Q8B40P29RHT208j>SP80U9BD0P2IVIT209fMW@80XJ6Q
00<0Xj>S0:BTY02TY:@00P2UYJD40:JVYP80YjNW1P2XZ:P60:VYZ@P0Z:RX0`2WYjL40:JVYP80YJFU
102TY:@20:>SX`80XZ:R102QXJ420:2PX080WinO0P2NWYh209fMW@80W9bL00<0Vi^K09ZJVP2JVYX0
0P2IVIT209RHV080UiNG0P2FUYH209FEU@80U9BD5@3oool001<0oooo0P2>SXh208R8R080PX:20P1m
OGd207MgM`80LG5a0P1[Jf/206IVIP03061PH01JFUX0FUYJ0080EEEE0P1?Cdl204U9B@80@d=30P0m
?Cd203Lg=`80<C4a0P0[:b/202DU9@807alO0P0H61P201<C4`803@d=0P092@T00`061PH03@d=00d=
3@0201DE5@80820P0P0Y:BT2030`<080>3Ph0P0n?Sh204A4A080ATI60P19BDT204Y:BP80Bd];0P1<
C4`204i>CP80Cdm?00<0DE5A059BDP1BDU800P1DE5@205IFEP@0EeMG0P1HF5P605UIF@80FUYJ0P1K
Fe/205eMG@@0GUiN0P1OGel7061PH080HV9R101SHf<406ATI0P0IFEU0P1WIfL206QXJ0<0JFUY0P1Z
JVX206][J`80KFe]0P1_Kfl2079bLP80MWIf0P1jNWX207moO`80Q8B40P29RHT208j>SP80U9BD0P2I
VIT209fMW@80XJ6Q00<0Xj>S0:BTY02TY:@00P2UYJD40:JVYP80YjNW1P2XZ:P60:VYZ@P0Z:RX0`2W
YjL40:JVYP80YJFU102TY:@20:>SX`80XZ:R102QXJ420:2PX080WinO0P2NWYh209fMW@80W9bL00<0
Vi^K09ZJVP2JVYX00P2IVIT209RHV080UiNG0P2FUYH209FEU@80U9BD5@3oool001<0oooo0P2>SXh2
08R8R080Ph>30P1nOWh207QhN080LW9b0P1]KFd206MWI`03065QH@1LG5`0G5aL0080EUIF0P1ADE42
04];B`80ADE50P10@40203Xj>P80=3@d0P0^;Rh202PX:0808b<S0P0M7Ad201LG5`804Q8B0P0=3@d3
00P820804A4A0P0J6QX202@T9080;Bd]0P0d=3@203Xj>P80?clo0P12@T8204A4A080ADE50P17AdL2
04U9B@80BTY:0P1<C4`00`1=CDd0Cdm?04m?C`02051@D080DU9B0P1CDe<205ADE0H0EEEE101FEUH2
05QHF080FEUI0P1JFUX205aLG0D0GEeM1P1NGUh4061PH080HV9R0P1SHf<206ATI0H0IFEU0P1VIVH2
06QXJ080JFUY00<0JVYZ06a/K01/K6`00P1]KFd206i^KP80LG5a0P1dM7@207MgM`80Ng]k0P1oOgl2
08B4Q080RXZ:0P2?Shl209BDU080VIVI0P2NWYh209nOW`030:2PX02RXZ80XZ:R0080Xj>S102TY:@2
0:FUY@H0YZJV202WYjL70:JVYP@0YJFU102TY:@40:>SX`80XZ:R0P2QXJ440:2PX080WinO0P2NWYh2
09fMW@@0W9bL00<0Vi^K09ZJVP2JVYX00P2IVIT209RHV080UiNG0P2FUYH209FEU@80U9BD5@3oool0
01<0oooo0P2>SXh208R8R080Ph>30P1nOWh207QhN080LW9b0P1]KFd206MWI`03065QH@1LG5`0G5aL
0080EUIF0P1ADE4204];B`80ADE50P10@40203Xj>P80=3@d0P0^;Rh202PX:0808b<S0P0M7Ad201LG
5`804Q8B0P0=3@d300P820804A4A0P0J6QX202@T9080;Bd]0P0d=3@203Xj>P80?clo0P12@T8204A4
A080ADE50P17AdL204U9B@80BTY:0P1<C4`00`1=CDd0Cdm?04m?C`02051@D080DU9B0P1CDe<205AD
E0H0EEEE101FEUH205QHF080FEUI0P1JFUX205aLG0D0GEeM1P1NGUh4061PH080HV9R0P1SHf<206AT
I0H0IFEU0P1VIVH206QXJ080JFUY00<0JVYZ06a/K01/K6`00P1]KFd206i^KP80LG5a0P1dM7@207Mg
M`80Ng]k0P1oOgl208B4Q080RXZ:0P2?Shl209BDU080VIVI0P2NWYh209nOW`030:2PX02RXZ80XZ:R
0080Xj>S102TY:@20:FUY@H0YZJV202WYjL70:JVYP@0YJFU102TY:@40:>SX`80XZ:R0P2QXJ440:2P
X080WinO0P2NWYh209fMW@@0W9bL00<0Vi^K09ZJVP2JVYX00P2IVIT209RHV080UiNG0P2FUYH209FE
U@80U9BD5@3oool001<0oooo0P2>SXh208V9R@80Ph>30P1nOWh207UiN@80Lg=c0P1^KVh206UYJ@03
06=SH`1NGUh0GUiN0080F5QH0P1CDe<204e=C@80B4Q80P12@T8203dm?@80=cLg0P0b<S8202`/;080
9bLW0P0Q8B4201`L70805aLG0P0B4Q800`0>3Ph020P800P8200200/;2`8051@D0P0M7Ad202LW9`80
;Rh^0P0d=3@203Ti>@80?Cdm0P0o?cl20410@080@T920P14A4@204I6AP80B4Q800<0BDU904];B`1;
Bd/00P1;Bd/204e=C@80Cdm?0P1@D506055AD@@0DU9B0P1CDe<405ADE080EeMG0`1IFET605YJFP80
Fe]K0P1MGEd205iNGP80GemO0P1PH60206=SH`H0I6AT0P1UIFD206IVIP80IfMW00<0J6QX06YZJP1Z
JVX00P1[Jf/206e]K@80L71`0P1cLg<207MgM`80NWYj0P20P80208F5Q@80RXZ:0P2ATI4209FEU@80
VIVI0P2LW9`209fMW@0309jNWP2OWil0WinO0080X:2P0P2QXJ420::RXP80Xj>S1P2TY:@>0:FUY@D0
Y:BT102SXj<40::RXP80XJ6Q102PX:0209nOW`80WYjN102MWId209bLW080Vi^K00<0VYZJ09VIV@2I
VIT00P2IVIT209RHV080UiNG0P2FUYH209FEU@80U9BD5@3oool001<0oooo0P2>SXh208V9R@80Ph>3
0P1nOWh207UiN@80Lg=c0P1^KVh206UYJ@0306=SH`1NGUh0GUiN0080F5QH0P1CDe<204e=C@80B4Q8
0P12@T8203dm?@80=cLg0P0b<S8202`/;0809bLW0P0Q8B4201`L70805aLG0P0B4Q800`0>3Ph020P8
00P8200200/;2`8051@D0P0M7Ad202LW9`80;Rh^0P0d=3@203Ti>@80?Cdm0P0o?cl20410@080@T92
0P14A4@204I6AP80B4Q800<0BDU904];B`1;Bd/00P1;Bd/204e=C@80Cdm?0P1@D506055AD@@0DU9B
0P1CDe<405ADE080EeMG0`1IFET605YJFP80Fe]K0P1MGEd205iNGP80GemO0P1PH60206=SH`H0I6AT
0P1UIFD206IVIP80IfMW00<0J6QX06YZJP1ZJVX00P1[Jf/206e]K@80L71`0P1cLg<207MgM`80NWYj
0P20P80208F5Q@80RXZ:0P2ATI4209FEU@80VIVI0P2LW9`209fMW@0309jNWP2OWil0WinO0080X:2P
0P2QXJ420::RXP80Xj>S1P2TY:@>0:FUY@D0Y:BT102SXj<40::RXP80XJ6Q102PX:0209nOW`80WYjN
102MWId209bLW080Vi^K00<0VYZJ09VIV@2IVIT00P2IVIT209RHV080UiNG0P2FUYH209FEU@80U9BD
5@3oool001<0oooo0P2>SXh208V9R@80Q8B40P1oOgl207YjNP80M7Ad0P1_Kfl206YZJP0306EUI@1P
H600H61P0080FUYJ0P1EEED2051@D080BTY:0P15ADD20410@080>c/k0P0e=CD2030`<080:b/[0P0U
9BD2020P80806a/K0P0G5aL00`0B4Q803Ph>00h>3P0200/;2`80410@0P0I6AT202<S8`80:RXZ0P0a
<C4203Lg=`80>CTi0P0k>c/403`l?080?clo0P12@T8204A4A00304E5A@17AdL0AdM70080B4Q80P19
BDT404];B`80C4a<1P1=CDd404i>CP80Cdm?0P1@D50204m?C`80De=C00<0E5AD05EEE@1EEED00P1F
EUH405MGE`80F5QH0P1JFUX205]KF`80G5aL0P1NGUh2061PH080HF5Q0P1RHV8206=SH`80IFEU0P1V
IVH00`1XJ6P0JVYZ06YZJP0206][J`80K6a/0P1_Kfl207=cL`80N7Qh0P1lO7`20820P080QHF50P29
RHT2092@T080Ti>C0P2IVIT209ZJVP80Vi^K00<0W9bL09fMW@2MWId00P2NWYh209nOW`80X:2P0P2Q
XJ440::RXQ<0Xj>S1P2RXZ840:6QX@80X:2P102OWil209jNWP@0WIfM0P2LW9`409^KV`0309ZJVP2I
VIT0VIVI0080V9RH102GUiL209JFUP80UIFE0P2DU9@E0?ooo`004`3oool208j>SP80RHV90P24Q8@2
07moO`80NWYj0P1dM7@206m_K`80JVYZ00<0IFEU061PH01PH6000P1JFUX205EEE@80D51@0P1:BTX2
04E5A@80@4100P0k>c/203De=@80<30`0P0[:b/202DU9@80820P0P0K6a/201LG5`03018B4P0>3Ph0
3Ph>00802`/;0P0@410201TI6@808b<S0P0Z:RX2034a<@80=cLg0P0i>CT203/k>`@0?3`l0P0o?cl2
0492@P80A4A400<0ADE504M7A`17AdL00P18B4P204U9B@@0Bd];0P1<C4`604e=C@@0CTi>0P1?Cdl2
051@D080Cdm?0P1CDe<00`1DE5@0EEEE05EEE@0205IFEP@0EeMG0P1HF5P205YJFP80Fe]K0P1LG5`2
05iNGP80H61P0P1QHF42069RHP80Hf=S0P1UIFD206IVIP0306QXJ01ZJVX0JVYZ0080Jf][0P1/K6`2
06m_K`80Lg=c0P1hN7P207alO080P8200P25QHD208V9R@80T92@0P2CTi<209VIV@80VYZJ0P2KVi/0
0`2LW9`0WIfM09fMW@0209jNWP80WinO0P2PX:020:6QX@@0XZ:R4`2SXj<60::RXP@0XJ6Q0P2PX:04
09nOW`80WYjN102MWId209bLW0@0Vi^K00<0VYZJ09VIV@2IVIT00P2HV9P409NGU`80UYJF0P2EUID2
09BDU1D0oooo000C0?ooo`80SXj>0P29RHT208B4Q080Ogmo0P1jNWX207IfMP80L71`0P1[Jf/00`1V
IVH0HF5Q065QH@0205aLG080EeMG0P1BDU8204e=C@80B4Q80P13@d<203hn?P80>CTi0P0d=3@202l_
;`80:RXZ0P0U9BD2020P80806a/K00<05QHF018B4P0B4Q800P0<30`200/;2`8051@D0P0K6a/2028R
8P80:b/[0P0a<C4203De=@@0=cLg0P0h>3P203Ti>@80?Cdm0P0o?cl00`11@D40@T920492@P0204=3
@`80A4A40P16ATH404M7A`80BDU91018B4P204Y:BP80Bd];0P1:BTX404];B`80C4a<0`1?Cdl2051@
D0@0DE5A0P1BDU8205ADE080EEEE0P1GEeL205UIF@80G5aL0P1NGUh205mOG`80HF5Q0P1SHf<206AT
I00306IVIP1XJ6P0J6QX0080JVYZ0P1]KFd2071`L080MGEe0P1hN7P207emO@80Ph>30P26QXH208Z:
RP80SXj>0P2ATI4209FEU@80UiNG0P2IVIT00`2JVYX0Vi^K09^KV`0209bLW080WIfM0P2NWYh209nO
W`@0X:2P102QXJ4=0::RXPH0XJ6Q1P2PX:0409nOW`80WYjN102MWId209bLW0@0Vi^K0P2JVYX309VI
V@80V9RH0P2GUiL409JFUP80UIFE0P2DU9@E0?ooo`004`3oool208j>SP80RHV90P24Q8@207moO`80
NWYj0P1fMWH2071`L080Jf][00<0IVIV065QH@1QHF400P1LG5`205MGE`80DU9B0P1=CDd204Q8B080
@d=30P0n?Sh203Ti>@80=3@d0P0_;bl202XZ:P809BDU0P0P820201/K6`0301HF5P0B4Q804Q8B0080
30`<0P0;2`/201@D50806a/K0P0R8R8202/[:`80<C4a0P0e=CD403Lg=`80>3Ph0P0i>CT203dm?@80
?clo00<0@D510492@P12@T800P13@d<204A4A080ATI61017AdL204U9B@@0B4Q80P1:BTX204];B`80
BTY:101;Bd/204a<C0<0Cdm?0P1@D504055AD@80DU9B0P1DE5@205EEE@80EeMG0P1IFET205aLG080
GUiN0P1OGel2065QH@80Hf=S0P1TI6@00`1VIVH0J6QX06QXJ00206YZJP80KFe]0P1`L70207EeM@80
N7Qh0P1mOGd208>3P`80QXJ60P2:RXX208j>SP80TI6A0P2EUID209NGU`80VIVI00<0VYZJ09^KV`2K
Vi/00P2LW9`209fMW@80WYjN0P2OWil40:2PX0@0XJ6Q3@2RXZ860:6QX@H0X:2P102OWil209jNWP@0
WIfM0P2LW9`409^KV`80VYZJ0`2IVIT209RHV080UiNG102FUYH209FEU@80U9BD5@3oool001<0oooo
0P2?Shl208Z:RP80QHF50P20P80207]kN`80MgMg0P1bLW8206e]K@0306QXJ01SHf<0Hf=S0080GUiN
0P1JFUX205EEE@80D51@0P1;Bd/204I6AP80@D510P0l?3`203Lg=`80<S8b0P0^;Rh202TY:@8092@T
0P0O7al00`0K6a/05QHF01HF5P02014A4@802PX:0P0<30`201HF5P807alO0P0U9BD202/[:`80<30`
200c<c<203Ph>080>SXj00<0?Cdm03hn?P0n?Sh00P0n?Sh203lo?`@0@T920P13@d<204E5A@80A4A4
0P15ADD204A4A080ATI61015ADD204I6AP80AdM700<0BDU904Q8B018B4P00P1:BTX404];B`80C4a<
0P1>CTh2051@D080DU9B0P1DE5@205MGE`80FUYJ0P1LG5`205iNGP80H61P0P1QHF400`1TI6@0IfMW
06MWI`0206UYJ@80K6a/0P1`L70207AdM080NGUi0P1lO7`20861P@80QXJ60P2:RXX208j>SP80T92@
0P2BTY8209BDU080UYJF00<0V9RH09VIV@2IVIT00P2JVYX209^KV`80W9bL0P2MWId209jNWP@0WinO
1P2PX:080:6QX@L0X:2P1P2OWil409jNWP@0WIfM0P2LW9`409^KV`@0VYZJ00<0VIVI09RHV02HV9P0
0P2HV9P209NGU`@0UYJF0P2EUID209BDU1D0oooo000C0?ooo`80Shn?0P2:RXX208F5Q@80P8200P1k
Ng/207MgM`80LW9b0P1]KFd00`1XJ6P0Hf=S06=SH`0205iNGP80FUYJ0P1EEED2051@D080Bd];0P16
ATH20451@@80?3`l0P0g=cL2038b<P80;Rh^0P0Y:BT202@T90807alO00<06a/K01HF5P0F5QH00P0A
4A4200X:2P8030`<0P0F5QH201lO7`809BDU0P0[:b/2030`<0P0<c<c0P0h>3P203Xj>P0303dm?@0n
?Sh0?Shn0080?Shn0P0o?cl40492@P80@d=30P15ADD204A4A080ADE50P14A4@204I6AP@0ADE50P16
ATH204M7A`0304U9B@18B4P0B4Q80080BTY:101;Bd/204a<C080CTi>0P1@D502059BDP80E5AD0P1G
EeL205YJFP80G5aL0P1NGUh2061PH080HF5Q00<0I6AT06MWI`1WIfL00P1YJFT206a/K080L71`0P1d
M7@207UiN@80O7al0P21PH4208J6QP80RXZ:0P2>SXh2092@T080TY:B0P2DU9@209JFUP0309RHV02I
VIT0VIVI0080VYZJ0P2KVi/209bLW080WIfM0P2NWYh409nOW`H0X:2P202QXJ470:2PX0H0WinO102N
WYh409fMW@80W9bL102KVi/409ZJVP0309VIV@2HV9P0V9RH0080V9RH0P2GUiL409JFUP80UIFE0P2D
U9@E0?ooo`004`3oool208n?S`80RXZ:0P26QXH20861P@80O7al0P1hN7P207=cL`80KVi^00<0JVYZ
06EUI@1UIFD00P1PH60205aLG080EeMG0P1BDU8204i>CP80BDU90P14A4@20410@080>c/k0P0f=SH2
034a<@80;Bd]0P0X:2P202@T900301lO7`0J6QX06QXJ00805ADE0P0@410200/;2`8030`<0P0G5aL2
024Q8@809bLW0P0/;2`202l_;`80<30`0P0_;bl202h^;P80<S8b0P0e=CD00`0f=SH0>CTi03Ti>@02
03Ti>@80>SXj0P0l?3`403hn?P80?clo1010@40203lo?`80@D510P10@40603lo?`L0@d=30P15ADD2
04I6AP80B4Q80P19BDT204];B`80CDe=0P1ADE4205ADE080EeMG0P1KFe/205iNGP80GemO00<0HF5Q
06EUI@1UIFD00P1YJFT206e]K@80LG5a0P1fMWH207]kN`80OGem0P20P80208F5Q@80RHV90P2>SXh2
08n?S`80TI6A0P2BTY8209BDU00309JFUP2GUiL0UiNG0080VIVI102JVYX409bLW080WIfM102NWYhC
09nOW`H0WYjN102MWId409bLW0@0Vi^K102JVYX309VIV@80V9RH102GUiL209JFUP@0UIFE0P2DU9@E
0?ooo`004`3oool208n?S`80Rh^;0P26QXH208:2PP80OGem0P1iNGT207EeM@80L71`00<0Jf][06MW
I`1WIfL00P1RHV8205iNGP80FUYJ0P1EEED2051@D080C4a<0P17AdL204=3@`80?Shn0P0j>SX203De
=@80<C4a0P0/;2`202PX:00302<S8`0O7al07alO00806QXJ0P0E5AD2014A4@8030`<0P0>3Ph201PH
60808B4Q0P0W9bL202/[:`80;Bd]0P0/;2`202XZ:P80;2`/0P0a<C400`0b<S80<c<c03<c<`0203De
=@@0=SHf0P0i>CT403Xj>P80>c/k0P0l?3`403/k>`80?3`l0P0k>c/203Ti>@80>3Ph00<0>CTi03/k
>`0k>c/01P0n?Sh203lo?`80@D510P12@T8204A4A080ADE50P19BDT204a<C080D51@0P1DE5@205QH
F080GEeM00<0HF5Q06ATI01TI6@00P1WIfL206e]K@80L71`0P1cLg<207YjNP80OGem0P1oOgl208:2
PP80QhN70P2:RXX208b<S080SXj>0P2@T90209:BTP0309BDU02EUID0UIFE0080UiNG0P2HV9P209VI
V@80VYZJ0P2KVi/409bLW0@0WIfM4`2NWYh609fMW@@0W9bL102KVi/409ZJVP@0VIVI0`2HV9P209NG
U`@0UYJF102EUID209BDU1D0oooo000C0?ooo`80Shn?0P2;Rh/208J6QP80PX:20P1mOGd207UiN@80
MGEe0P1`L7000`1[Jf/0IfMW06MWI`02069RHP80GUiN0P1JFUX205EEE@80D51@0P1<C4`204M7A`80
@d=30P0n?Sh203Xj>P80=CDe0P0a<C4202`/;080:2PX00<08b<S01lO7`0O7al00P0J6QX201DE5@80
4A4A0P0<30`200h>3P8061PH0P0Q8B4202LW9`80:b/[0P0];Bd202`/;080:RXZ0P0/;2`2034a<@03
038b<P0c<c<0<c<c0080=CDe100f=SH203Ti>@@0>SXj0P0k>c/203`l?0@0>c/k0P0l?3`203/k>`80
>CTi0P0h>3P00`0i>CT0>c/k03/k>`0603hn?P80?clo0P11@D420492@P80A4A40P15ADD204U9B@80
C4a<0P1@D50205ADE080F5QH0P1MGEd00`1QHF40I6AT06ATI00206MWI`80KFe]0P1`L70207=cL`80
NWYj0P1mOGd207moO`80PX:20P27QhL208Z:RP80S8b<0P2>SXh2092@T080TY:B00<0U9BD09FEU@2E
UID00P2GUiL209RHV080VIVI0P2JVYX209^KV`@0W9bL102MWIdC09jNWPH0WIfM102LW9`409^KV`@0
VYZJ102IVIT309RHV080UiNG102FUYH409FEU@80U9BD5@3oool001<0oooo0P2?Shl208^;R`80QhN7
0P22PX8207inOP80NWYj0P1fMWH2075aL@0306e]K@1YJFT0JFUY0080IFEU0P1PH60205aLG080F5QH
0P1CDe<204m?C`80Bd];0P16ATH20492@P80?Shn0P0i>CT203De=@80<C4a0P0/;2`00`0X:2P08b<S
02<S8`0201lO7`806QXJ0P0E5AD200l?3`802`/;0P0?3`l201PH6080820P0P0V9RH402XZ:P80:2PX
0P0W9bL202/[:`<0;Rh^0P0_;bl2030`<080<C4a0P0c<c<203De=@@0=SHf200g=cL203Ph>080=SHf
1@0d=3@203De=@80=SHf0P0h>3P203Xj>P80>c/k0P0m?Cd20410@080@T920P15ADD204Q8B080C4a<
0P1@D50205IFEP80Fe]K00<0H61P06EUI@1UIFD00P1XJ6P206a/K080Kfm_0P1bLW8207MgM`80NWYj
0P1nOWh208:2PP80QHF50P28R8P208Z:RP80S8b<0P2?Shl2096AT@0309:BTP2DU9@0U9BD0080UIFE
0P2GUiL209RHV0@0VIVI0P2JVYX209^KV`H0W9bL4`2MWId409bLW0H0Vi^K102JVYX409VIV@<0V9RH
102GUiL409JFUP@0UIFE0P2DU9@E0?ooo`004`3oool208n?S`80Rh^;0P27QhL208:2PP80OWin0P1j
NWX207IfMP80LG5a00<0KFe]06UYJ@1YJFT00P1UIFD2061PH080G5aL0P1HF5P205=CD`80Cdm?0P1;
Bd/204I6AP80@T920P0n?Sh203Ti>@80=CDe0P0a<C4202`/;00302PX:00S8b<08b<S00807alO0P0J
6QX201DE5@803`l?0P0;2`/200l?3`8061PH0P0P820202HV9P@0:RXZ0P0X:2P202LW9`80:b/[0`0^
;Rh202l_;`80<30`0P0a<C4203<c<`80=CDe100f=SH803Lg=`80>3Ph0P0f=SH503@d=080=CDe0P0f
=SH203Ph>080>SXj0P0k>c/203dm?@80@4100P12@T8204E5A@80B4Q80P1<C4`2051@D080EUIF0P1K
Fe/00`1PH600IFEU06EUI@0206QXJ080K6a/0P1_Kfl2079bLP80MgMg0P1jNWX207inOP80PX:20P25
QHD208R8R080RXZ:0P2<S8`208n?S`80TI6A00<0TY:B09BDU02DU9@00P2EUID209NGU`80V9RH102I
VIT209ZJVP80Vi^K1P2LW9`C09fMW@@0W9bL1P2KVi/409ZJVP@0VIVI0`2HV9P409NGU`@0UYJF102E
UID209BDU1D0oooo000C0?ooo`80Shn?0P2;Rh/208N7Q`80Ph>30P1oOgl207]kN`80MgMg0P1cLg<0
0`1_Kfl0Jf][06][J`0206MWI`80Hf=S0P1NGUh205YJFP80EUIF0P1BDU8204i>CP80BTY:0P16ATH2
0451@@80?Cdm0P0i>CT203De=@80<C4a00<0;2`/02PX:00X:2P00P0S8b<201lO7`806QXJ0P0E5AD2
00l?3`8030`<0P0A4A4201LG5`807AdM0P0R8R8202DU9@809RHV0P0S8b<202@T900302PX:00Z:RX0
:RXZ00@0:RXZ100[:b/202h^;P80;bl_100a<C44038b<P@0<c<c0P0b<S83030`<080;Rh^0P0_;bl2
030`<080<c<c0P0f=SH203Lg=`80>CTi0P0k>c/203hn?P80@T920P17AdL204];B`80Cdm?0P1EEED2
05aLG003061PH01TI6@0I6AT0080J6QX0P1/K6`206e]K@80L71`0P1eMGD207UiN@80O7al0P20P802
08>3P`80QXJ60P29RHT208^;R`80SHf=0P2?Shl00`2ATI40Ti>C09>CT`0209BDU080UIFE0P2GUiL4
09RHV080VIVI102JVYX409^KVaD0W9bL102KVi/609ZJVP@0VIVI1@2HV9P409NGU`@0UYJF0P2EUID4
09BDU1D0oooo000C0?ooo`80Shn?0P2;Rh/208N7Q`80Ph>30P1oOgl207]kN`80MgMg0P1cLg<00`1_
Kfl0Jf][06][J`0206MWI`80Hf=S0P1NGUh205YJFP80EUIF0P1BDU8204i>CP80BTY:0P16ATH20451
@@80?Cdm0P0i>CT203De=@80<C4a00<0;2`/02PX:00X:2P00P0S8b<201lO7`806QXJ0P0E5AD200l?
3`8030`<0P0A4A4201LG5`807AdM0P0R8R8202DU9@809RHV0P0S8b<202@T900302PX:00Z:RX0:RXZ
00@0:RXZ100[:b/202h^;P80;bl_100a<C44038b<P@0<c<c0P0b<S83030`<080;Rh^0P0_;bl2030`
<080<c<c0P0f=SH203Lg=`80>CTi0P0k>c/203hn?P80@T920P17AdL204];B`80Cdm?0P1EEED205aL
G003061PH01TI6@0I6AT0080J6QX0P1/K6`206e]K@80L71`0P1eMGD207UiN@80O7al0P20P80208>3
P`80QXJ60P29RHT208^;R`80SHf=0P2?Shl00`2ATI40Ti>C09>CT`0209BDU080UIFE0P2GUiL409RH
V080VIVI102JVYX409^KVaD0W9bL102KVi/609ZJVP@0VIVI1@2HV9P409NGU`@0UYJF0P2EUID409BD
U1D0oooo000C0?ooo`80T92@0P2<S8`208R8R080Q8B40P20P80207alO080N7Qh0P1dM7@00`1aLG40
KFe]06e]K@0206UYJ@80IFEU0P1QHF4205eMG@80FEUI0P1EEED2055AD@80CDe=0P19BDT204E5A@80
@D510P0m?Cd203Ti>@80=CDe00<0<C4a02d];@0];Bd00P0Y:BT202@T90807alO0P0J6QX201DE5@80
410@0P0=3@d2014A4@805aLG0P0M7Ad2020P80@08b<S0`0Q8B4202DU9@@09RHV0P0W9bL202HV9P80
9bLW0P0X:2P202XZ:P80;2`/0P0^;Rh202d];@80<30`100_;bl302h^;P80;2`/0P0Z:RX202/[:`80
;Rh^0P0`<30203<c<`80=SHf0P0j>SX203dm?@80@D510P16ATH204];B`80D51@0P1DE5@205UIF@03
05eMG@1QHF40HF5Q0080I6AT0P1XJ6P206][J`80KVi^0P1cLg<207QhN080Ng]k0P1oOgl208:2PP80
QHF50P28R8P208Z:RP80S8b<0P2>SXh00`2@T900TI6A096AT@0209>CT`80U9BD0P2FUYH409NGU`80
V9RH102IVIT409ZJVQD0Vi^K1P2JVYX609VIV@H0V9RH0`2GUiL409JFUP@0UIFE102DU9@E0?ooo`00
4`3oool2092@T080S8b<0P28R8P208B4Q080P8200P1lO7`207QhN080M7Ad00<0LG5a06e]K@1]KFd0
0P1YJFT206EUI@80HF5Q0P1MGEd205UIF@80EEEE0P1ADE4204e=C@80BDU90P15ADD20451@@80?Cdm
0P0i>CT203De=@03034a<@0];Bd0;Bd]0080:BTY0P0T92@201lO7`806QXJ0P0E5AD2010@40803@d=
0P0A4A4201LG5`807AdM0P0P820402<S8`<08B4Q0P0U9BD402HV9P809bLW0P0V9RH202LW9`80:2PX
0P0Z:RX202`/;080;Rh^0P0];Bd2030`<0@0;bl_0`0^;Rh202`/;080:RXZ0P0[:b/202h^;P80<30`
0P0c<c<203Hf=P80>SXj0P0m?Cd20451@@80ATI60P1;Bd/2051@D080E5AD0P1IFET00`1MGEd0HF5Q
065QH@0206ATI080J6QX0P1[Jf/206i^KP80Lg=c0P1hN7P207]kN`80Ogmo0P22PX8208F5Q@80R8R8
0P2:RXX208b<S080SXj>00<0T92@096AT@2ATI400P2CTi<209BDU080UYJF102GUiL209RHV0@0VIVI
102JVYXE09^KV`H0VYZJ1P2IVIT609RHV0<0UiNG102FUYH409FEU@@0U9BD5@3oool001<0oooo0P2@
T90208b<S080R8R80P25QHD20861P@80OGem0P1jNWX207IfMP03079bLP1_Kfl0Kfm_0080Jf][0P1W
IfL206=SH`80H61P0P1LG5`205QHF080E5AD0P1ADE4204e=C@80BDU90P15ADD20451@@80?Cdm0P0j
>SX00`0f=SH0<S8b038b<P0202d];@80:BTY0P0U9BD2020P80806a/K0P0F5QH2014A4@803Ph>0P0@
410201LG5`807AdM0P0Q8B42028R8P808B4Q00<07alO020P800P82000P0Q8B4802<S8`@08R8R0P0T
92@402LW9`80:RXZ0P0[:b/202`/;080:b/[00<0;Rh^02l_;`0_;bl0100];Bd202l_;`80<C4a0P0c
<c<203Lg=`80?3`l0P10@40204A4A080B4Q80P1:BTX204i>CP80DU9B0P1FEUH00`1JFUX0GEeM05eM
G@02065QH@80IVIV0P1YJFT206a/K080L71`0P1fMWH207YjNP80OGem0P21PH4208B4Q080QXJ60P29
RHT208^;R`80SHf=00<0Shn?092@T02@T9000P2BTY8209>CT`80UIFE102FUYH209NGU`80V9RH1P2I
VIT909ZJVP@0Vi^K302JVYX609VIV@H0V9RH0`2GUiL609JFUP@0UIFE102DU9@E0?ooo`004`3oool2
092@T080S8b<0P28R8P208F5Q@80PH610P1mOGd207YjNP80MWIf00<0LW9b06m_K`1_Kfl00P1[Jf/2
06MWI`80Hf=S0P1PH60205aLG080F5QH0P1DE5@2055AD@80CDe=0P19BDT204E5A@80@D510P0m?Cd2
03Xj>P0303Hf=P0b<S80<S8b0080;Bd]0P0Y:BT202DU9@80820P0P0K6a/201HF5P804A4A0P0>3Ph2
010@40805aLG0P0M7Ad2024Q8@808R8R0P0Q8B400`0O7al0820P020P8002024Q8@P08b<S100R8R82
02@T90@09bLW0P0Z:RX202/[:`80;2`/0P0[:b/00`0^;Rh0;bl_02l_;`0402d];@80;bl_0P0a<C42
03<c<`80=cLg0P0l?3`20410@080A4A40P18B4P204Y:BP80CTi>0P1BDU8205IFEP0305YJFP1MGEd0
GEeM0080HF5Q0P1VIVH206UYJ@80K6a/0P1`L70207IfMP80NWYj0P1mOGd20861P@80Q8B40P26QXH2
08V9R@80Rh^;0P2=SHd00`2?Shl0T92@092@T00209:BTP80Ti>C0P2EUID409JFUP80UiNG0P2HV9P6
09VIV@T0VYZJ102KVi/<09ZJVPH0VIVI1P2HV9P309NGU`H0UYJF102EUID409BDU1D0oooo000C0?oo
o`80T92@0P2<S8`208V9R@80QHF50P22PX8207inOP80Ng]k0P1gMgL00`1dM7@0L71`071`L00206e]
K@80JFUY0P1VIVH2069RHP80GemO0P1KFe/205QHF080E5AD0P1@D50204e=C@80BDU90P15ADD20492
@P80?Shn00<0>SXj03Hf=P0f=SH00P0c<c<202l_;`80:b/[0P0V9RH2028R8P807AdM0P0I6AT201DE
5@@0410@0P0F5QH201dM7@808B4Q0P0S8b<00`0Q8B407alO01lO7`0:024Q8@808R8R0P0Q8B42020P
80@08B4Q0P0T92@202LW9`@0:BTY00<0:b/[02d];@0];Bd00P0^;Rh2030`<080<S8b0P0d=3@203Lg
=`80>c/k0P0l?3`20410@080A4A40P17AdL204U9B@80C4a<0P1?Cdl2059BDP0305EEE@1JFUX0FUYJ
0080GemO0P1TI6@206MWI`80J6QX0P1_Kfl207EeM@80NGUi0P1lO7`20820P080Ph>30P25QHD208R8
R080RXZ:0P2<S8`00`2>SXh0Shn?08n?S`02096AT@80TY:B0P2DU9@409FEU@80UYJF0P2GUiL609RH
V0P0VIVI2`2JVYX809VIV@P0V9RH1@2GUiL409JFUPH0UIFE102DU9@E0?ooo`004`3oool2092@T080
S8b<0P29RHT208F5Q@80PX:20P1nOWh207]kN`80MgMg00<0M7Ad071`L01`L7000P1]KFd206UYJ@80
IVIV0P1RHV8205mOG`80Fe]K0P1HF5P205ADE080D51@0P1=CDd204U9B@80ADE50P12@T8203hn?P03
03Xj>P0f=SH0=SHf0080<c<c0P0_;bl202/[:`809RHV0P0R8R8201dM7@806ATI0P0E5AD4010@4080
5QHF0P0M7Ad2024Q8@808b<S00<08B4Q01lO7`0O7al02P0Q8B42028R8P808B4Q0P0P8204024Q8@80
92@T0P0W9bL402TY:@0302/[:`0];Bd0;Bd]0080;Rh^0P0`<302038b<P80=3@d0P0g=cL203/k>`80
?3`l0P10@40204A4A080AdM70P19BDT204a<C080Cdm?0P1BDU800`1EEED0FUYJ05YJFP0205mOG`80
I6AT0P1WIfL206QXJ080Kfm_0P1eMGD207UiN@80O7al0P20P80208>3P`80QHF50P28R8P208Z:RP80
S8b<00<0SXj>08n?S`2?Shl00P2ATI4209:BTP80U9BD102EUID209JFUP80UiNG1P2HV9P809VIV@/0
VYZJ202IVIT809RHV0D0UiNG102FUYH609FEU@@0U9BD5@3oool001<0oooo0P2@T90208f=S@80RXZ:
0P26QXH208>3P`80P8200P1lO7`207UiN@0307IfMP1bLW80LW9b0080Kfm_0P1/K6`206QXJ080IFEU
0P1RHV8205iNGP80Fe]K0P1GEeL205ADE080DE5A0P1=CDd204U9B@80ATI60P13@d<00`0o?cl0?3`l
03`l?00203Ph>080=3@d0P0`<30202`/;080:BTY0P0T92@2020P808071`L0P0H61P201<C4`804Q8B
0P0F5QH201hN7P808R8R00<092@T02<S8`0S8b<01P0S8b<602@T90@09BDU100W9bL202PX:0@0:RXZ
0P0[:b/00`0];Bd0;bl_02l_;`02030`<080<S8b0P0e=CD203Hf=P80=cLg0P0k>c/203`l?080?clo
0P12@T8204I6AP80AdM70P1:BTX204a<C080D51@00<0E5AD05QHF01HF5P00P1MGEd2065QH@80IfMW
0P1[Jf/2071`L080M7Ad0P1hN7P207alO080Ogmo0P22PX8208B4Q080QhN70P29RHT208^;R`0308f=
S@2?Shl0Shn?0080T92@0P2ATI4209>CT`80U9BD102EUID209JFUPH0UiNG0P2HV9PC09VIV@P0V9RH
2P2GUiL509JFUPH0UIFE102DU9@E0?ooo`004`3oool2092@T080SHf=0P2:RXX208J6QP80Ph>30P20
P80207alO080NGUi00<0MWIf079bLP1bLW800P1_Kfl206a/K080J6QX0P1UIFD2069RHP80GUiN0P1K
Fe/205MGE`80E5AD0P1ADE4204e=C@80BDU90P16ATH204=3@`0303lo?`0l?3`0?3`l0080>3Ph0P0d
=3@2030`<080;2`/0P0Y:BT202@T9080820P0P0L71`201PH60804a<C0P0B4Q8201HF5P807QhN0P0R
8R800`0T92@08b<S02<S8`0602<S8`H092@T100U9BD402LW9`80:2PX100Z:RX202/[:`0302d];@0_
;bl0;bl_0080<30`0P0b<S8203De=@80=SHf0P0g=cL203/k>`80?3`l0P0o?cl20492@P80ATI60P17
AdL204Y:BP80C4a<0P1@D5000`1DE5@0F5QH05QHF00205eMG@80HF5Q0P1WIfL206][J`80L71`0P1d
M7@207QhN080O7al0P1oOgl208:2PP80Q8B40P27QhL208V9R@80Rh^;00<0SHf=08n?S`2?Shl00P2@
T902096AT@80Ti>C0P2DU9@409FEU@80UYJF1P2GUiL209RHV1<0VIVI202HV9P:09NGU`D0UYJF1P2E
UID409BDU1D0oooo000C0?ooo`80T92@0P2=SHd208Z:RP80QhN70P24Q8@20861P@80OWin0P1kNg/0
0`1gMgL0M7Ad07AdM002075aL@80KVi^0P1[Jf/206QXJ080IFEU0P1QHF4205iNGP80Fe]K0P1HF5P2
05EEE@80DE5A0P1>CTh204];B`80AdM700<0A4A40451@@11@D400P0m?Cd203Xj>P80=SHf0P0c<c<2
02l_;`80:b/[0P0W9bL202@T9080820P0P0L71`201TI6@805QHF0P0H61P201lO7`0302<S8`0V9RH0
9RHV00809bLW2P0X:2P402TY:@@0:RXZ0P0[:b/202d];@@0;Rh^00<0<30`034a<@0a<C40100b<S82
03Hf=P80=cLg0P0h>3P203/k>`80?3`l0P0n?Sh20410@080A4A40P16ATH204Q8B080C4a<0P1@D500
0`1DE5@0EeMG05MGE`0205aLG080HV9R0P1WIfL206a/K080L71`0P1dM7@207QhN080O7al0P1oOgl2
08:2PP80Q8B40P26QXH208V9R@80Rh^;00<0S8b<08j>SP2>SXh00P2?Shl2096AT@80TY:B0P2CTi<2
09BDU0@0UIFE102FUYH409NGU`/0V9RH1P2IVIT809RHV0X0UiNG1@2FUYH609FEU@H0U9BD5@3oool0
01<0oooo0P2@T90208f=S@80RXZ:0P27QhL208B4Q080PH610P1nOWh207]kN`0307MgM`1dM7@0M7Ad
0080LG5a0P1^KVh206][J`80J6QX0P1UIFD2065QH@80GUiN0P1KFe/205QHF080EEEE0P1ADE4204i>
CP80Bd];0P17AdL00`14A4@0@D510451@@0203dm?@80>SXj0P0f=SH203<c<`80;bl_0P0[:b/202LW
9`8092@T0P0P820201`L70806ATI0P0F5QH201PH60807alO00<08b<S02HV9P0V9RH00P0W9bL:02PX
:0@0:BTY100Z:RX202/[:`80;Bd]100^;Rh00`0`<300<C4a034a<@04038b<P80=SHf0P0g=cL203Ph
>080>c/k0P0l?3`203hn?P80@4100P14A4@204I6AP80B4Q80P1<C4`2051@D00305ADE01GEeL0EeMG
0080G5aL0P1RHV8206MWI`80K6a/0P1`L70207AdM080N7Qh0P1lO7`207moO`80PX:20P24Q8@208J6
QP80RHV90P2;Rh/00`2<S8`0SXj>08j>SP0208n?S`80TI6A0P2BTY8209>CT`80U9BD102EUID409JF
UP@0UiNG2`2HV9P609VIV@P0V9RH2P2GUiL509JFUPH0UIFE1P2DU9@E0?ooo`004`3oool2096AT@80
SXj>0P2;Rh/208R8R080QHF50P22PX8207moO`80O7al00<0NGUi07IfMP1fMWH00P1cLg<2071`L080
KFe]0P1ZJVX206MWI`80I6AT0P1QHF4205iNGP80Fe]K0P1HF5P205EEE@80DU9B0P1?Cdl204a<C003
04U9B@16ATH0ATI60080@d=30P0o?cl203`l?080>CTi0P0f=SH2038b<P80;bl_0P0/;2`202PX:080
9BDU0P0R8R8201lO7`806a/K0P0M7Ad00`0O7al09BDU02DU9@0202TY:@@0:b/[0P0/;2`402d];@@0
;Rh^1P0_;bl2030`<080<C4a0P0b<S800`0c<c<0=3@d03@d=00603@d=080=cLg0P0i>CT203Xj>P80
>c/k0P0n?Sh203lo?`80@T920P16ATH204U9B@80CDe=0P1?Cdl00`1BDU80F5QH05QHF00205iNGP80
I6AT0P1XJ6P206e]K@80LG5a0P1eMGD207UiN@80O7al0P1oOgl208:2PP80Q8B40P26QXH208R8R080
RXZ:00<0S8b<08f=S@2=SHd00P2?Shl2092@T080TI6A102CTi<209BDU0@0UIFE102FUYH809NGUa40
V9RH102GUiL209JFUP80UiNG2@2FUYH609FEU@H0U9BD5@3oool001<0oooo0P2ATI4208j>SP80Rh^;
0P28R8P208F5Q@80PX:20P1oOgl207alO00307UiN@1fMWH0MWIf0080Lg=c0P1`L70206e]K@80JVYZ
0P1WIfL206ATI080HF5Q0P1NGUh205]KF`80F5QH0P1EEED2059BDP80Cdm?0P1<C4`00`19BDT0ATI6
04I6AP0204=3@`80?clo0P0l?3`203Ti>@80=SHf0P0b<S8202l_;`80;2`/0P0X:2P202DU9@808R8R
0P0O7al201/K6`807AdM00<07alO02DU9@0U9BD00P0Y:BT402/[:`80;2`/100];Bd402h^;PH0;bl_
0P0`<302034a<@80<S8b00<0<c<c03@d=00d=3@01P0d=3@203Lg=`80>CTi0P0j>SX203/k>`80?Shn
0P0o?cl20492@P80ATI60P19BDT204e=C@80Cdm?00<0DU9B05QHF01HF5P00P1NGUh206ATI080J6QX
0P1]KFd2075aL@80MGEe0P1iNGT207alO080Ogmo0P22PX8208B4Q080QXJ60P28R8P208Z:RP0308b<
S02=SHd0SHf=0080Shn?0P2@T902096AT@@0Ti>C0P2DU9@409FEU@@0UYJF202GUiLA09RHV0@0UiNG
0P2FUYH209NGU`T0UYJF1P2EUID609BDU1D0oooo000C0?ooo`80TI6A0P2>SXh208^;R`80RHV90P26
QXH208>3P`80P8200P1nOWh00`1kNg/0N7Qh07QhN00207EeM@80Lg=c0P1`L70206e]K@80JVYZ0P1X
J6P206EUI@80HV9R0P1OGel205aLG080FEUI0P1FEUH205ADE080DE5A00<0CTi>04];B`1;Bd/00P18
B4P204E5A@80@T920P0o?cl203`l?080>CTi0P0f=SH203<c<`80<30`0P0];Bd202/[:`80:2PX0P0V
9RH202DU9@<08b<S0P0U9BD202TY:@80;Bd]0P0`<302034a<@80<S8b0P0c<c<2038b<P80<c<c100b
<S86034a<@03038b<P0d=3@0=3@d00@0=CDe100d=3@203Lg=`80>SXj0P0k>c/203lo?`80@T920P16
ATH204M7A`80BDU90P1<C4`2059BDP0305MGE`1LG5`0G5aL0080HF5Q0P1VIVH206YZJP80KVi^0P1c
Lg<207IfMP80NGUi0P1lO7`207moO`80PX:20P24Q8@208J6QP80R8R80P2:RXX00`2<S8`0SHf=08f=
S@0208n?S`80T92@0P2ATI4209:BTP80Ti>C102DU9@409FEU@P0UYJF1`2GUiL409RHV080UiNG1P2H
V9P409NGU`/0UYJF1P2EUID809BDU1D0oooo000C0?ooo`80TI6A0P2>SXh208^;R`80RHV90P26QXH2
08>3P`80P8200P1nOWh00`1kNg/0N7Qh07QhN00207EeM@80Lg=c0P1`L70206e]K@80JVYZ0P1XJ6P2
06EUI@80HV9R0P1OGel205aLG080FEUI0P1FEUH205ADE080DE5A00<0CTi>04];B`1;Bd/00P18B4P2
04E5A@80@T920P0o?cl203`l?080>CTi0P0f=SH203<c<`80<30`0P0];Bd202/[:`80:2PX0P0V9RH2
02DU9@<08b<S0P0U9BD202TY:@80;Bd]0P0`<302034a<@80<S8b0P0c<c<2038b<P80<c<c100b<S86
034a<@03038b<P0d=3@0=3@d00@0=CDe100d=3@203Lg=`80>SXj0P0k>c/203lo?`80@T920P16ATH2
04M7A`80BDU90P1<C4`2059BDP0305MGE`1LG5`0G5aL0080HF5Q0P1VIVH206YZJP80KVi^0P1cLg<2
07IfMP80NGUi0P1lO7`207moO`80PX:20P24Q8@208J6QP80R8R80P2:RXX00`2<S8`0SHf=08f=S@02
08n?S`80T92@0P2ATI4209:BTP80Ti>C102DU9@409FEU@P0UYJF1`2GUiL409RHV080UiNG1P2HV9P4
09NGU`/0UYJF1P2EUID809BDU1D0oooo000C0?ooo`80TI6A0P2>SXh208b<S080RHV90P27QhL208B4
Q080PX:20P1oOgl00`1mOGd0NWYj07YjNP0207MgM`80MGEe0P1bLW82071`L080KFe]0P1[Jf/206QX
J080IFEU0P1SHf<2065QH@80GEeM0P1KFe/205QHF080EEEE00<0De=C051@D01@D5000P1=CDd204];
B`80B4Q80P15ADD204=3@`80@4100P0m?Cd203Xj>P80>3Ph0P0e=CD203<c<`80<C4a0P0_;bl202h^
;P0302d];@0/;2`0;2`/0080;Bd]0P0[:b/202d];@80;bl_0P0c<c<203De=@80=SHf1P0g=cL203Hf
=P80=CDe100d=3@00`0c<c<0=3@d03@d=00203De=@80=cLg100h>3P203Xj>P80?Shn0P10@4020451
@@80A4A40P18B4P204a<C080Cdm?0P1CDe<205MGE`0305]KF`1PH600H61P0080I6AT0P1YJFT206a/
K080L71`0P1dM7@207MgM`80NWYj0P1mOGd20820P080PX:20P24Q8@208J6QP80R8R80P2:RXX00`2;
Rh/0SHf=08f=S@0208j>SP80Shn?0P2ATI4209:BTP80Ti>C102DU9@409FEU@H0UYJF4`2GUiL209RH
V0@0UiNG2P2FUYH709FEU@P0U9BD5@3oool001<0oooo0P2ATI4208j>SP80S8b<0P29RHT208N7Q`80
Q8B40P22PX8207moO`0307emO@1jNWX0NWYj0080MgMg0P1eMGD2079bLP80L71`0P1]KFd206][J`80
J6QX0P1UIFD206=SH`80HF5Q0P1MGEd205]KF`80F5QH0P1EEED00`1CDe<0D51@051@D00204e=C@80
Bd];0P18B4P204E5A@80@d=30P10@40203dm?@80>SXj0P0h>3P203De=@80<c<c0P0a<C4202l_;`80
;Rh^00<0;Bd]02`/;00/;2`00P0];Bd202/[:`80;Bd]0P0_;bl203<c<`80=CDe0P0f=SH603Lg=`80
=SHf0P0e=CD403@d=00303<c<`0d=3@0=3@d0080=CDe0P0g=cL403Ph>080>SXj0P0n?Sh20410@080
@D510P14A4@204Q8B080C4a<0P1?Cdl205=CD`80EeMG00<0Fe]K061PH01PH6000P1TI6@206UYJ@80
K6a/0P1`L70207AdM080MgMg0P1jNWX207emO@80P8200P22PX8208B4Q080QXJ60P28R8P208Z:RP03
08^;R`2=SHd0SHf=0080SXj>0P2?Shl2096AT@80TY:B0P2CTi<409BDU0@0UIFE1P2FUYHC09NGU`80
V9RH102GUiL:09JFUPL0UIFE202DU9@E0?ooo`004`3oool2096AT@80Shn?0P2<S8`208Z:RP80R8R8
0P25QHD208>3P`80PH6100<0OWin07alO01lO7`00P1jNWX207MgM`80MGEe0P1cLg<2071`L080KVi^
0P1[Jf/206UYJ@80IVIV0P1TI6@2065QH@80GemO0P1MGEd205YJFP0305QHF01EEED0EEEE0080De=C
0P1@D50204i>CP80Bd];0P19BDT204I6AP80A4A40P12@T8203lo?`80?Cdm0P0k>c/203Xj>P80>3Ph
0P0g=cL00`0f=SH0=CDe03De=@0403De=@80=3@d0P0c<c<203@d=080=SHf0P0g=cL203Ph>0X0>SXj
1`0k>c/203`l?080?Cdm100n?Sh20410@080@T920P16ATH204U9B@80CDe=0P1ADE4205EEE@80F5QH
0P1KFe/00`1PH600Hf=S06=SH`0206MWI`80Jf][0P1_Kfl2079bLP80MGEe0P1hN7P207]kN`80OWin
0P20P80208>3P`80QHF50P27QhL208R8R080RXZ:00<0Rh^;08f=S@2=SHd00P2>SXh208n?S`80T92@
0P2ATI4209:BTP@0Ti>C0P2DU9@409FEU@P0UYJF00<0UiNG09JFUP2FUYH00P2FUYH209NGU`80UYJF
2P2GUiL609JFUPd0UIFE202DU9@E0?ooo`004`3oool2096AT@80Shn?0P2<S8`208Z:RP80R8R80P25
QHD208>3P`80PH6100<0OWin07alO01lO7`00P1jNWX207MgM`80MGEe0P1cLg<2071`L080KVi^0P1[
Jf/206UYJ@80IVIV0P1TI6@2065QH@80GemO0P1MGEd205YJFP0305QHF01EEED0EEEE0080De=C0P1@
D50204i>CP80Bd];0P19BDT204I6AP80A4A40P12@T8203lo?`80?Cdm0P0k>c/203Xj>P80>3Ph0P0g
=cL00`0f=SH0=CDe03De=@0403De=@80=3@d0P0c<c<203@d=080=SHf0P0g=cL203Ph>0X0>SXj1`0k
>c/203`l?080?Cdm100n?Sh20410@080@T920P16ATH204U9B@80CDe=0P1ADE4205EEE@80F5QH0P1K
Fe/00`1PH600Hf=S06=SH`0206MWI`80Jf][0P1_Kfl2079bLP80MGEe0P1hN7P207]kN`80OWin0P20
P80208>3P`80QHF50P27QhL208R8R080RXZ:00<0Rh^;08f=S@2=SHd00P2>SXh208n?S`80T92@0P2A
TI4209:BTP@0Ti>C0P2DU9@409FEU@P0UYJF00<0UiNG09JFUP2FUYH00P2FUYH209NGU`80UYJF2P2G
UiL609JFUPd0UIFE202DU9@E0?ooo`004`3oool2096AT@80Shn?0P2=SHd208^;R`80RHV90P27QhL2
08B4Q080PX:200<0P82007inOP1nOWh00P1lO7`207YjNP80MgMg0P1eMGD207=cL`80LG5a0P1_Kfl2
06a/K080JVYZ0P1XJ6P206IVIP80I6AT0P1QHF4205mOG`0305eMG@1JFUX0FUYJ0080F5QH0P1FEUH2
05ADE080DU9B0P1?Cdl204e=C@80Bd];0P19BDT204M7A`80ADE50P13@d<20492@P80@D510P10@400
0`0o?cl0?Shn03hn?P0:03dm?@H0?Shn100o?cl20410@080?clo1@0n?Sh203lo?`@0@4100P11@D42
04=3@`80ADE50P17AdL204Y:BP80CDe=0P1@D50205=CD`80EeMG0P1KFe/205iNGP80H61P00<0I6AT
06QXJ01XJ6P00P1[Jf/206i^KP80LW9b0P1dM7@207MgM`80NWYj0P1lO7`207moO`80PH610P23Ph<2
08F5Q@80QhN70P29RHT208Z:RP0308^;R`2=SHd0SHf=0080SXj>0P2?Shl2092@T080TI6A0P2BTY84
09>CT`@0U9BD202EUID709JFUP80UiNG4P2FUYH=09FEU@P0U9BD5@3oool001<0oooo0P2ATI4208n?
S`80SHf=0P2;Rh/208V9R@80QhN70P24Q8@208:2PP030820P01nOWh0OWin0080O7al0P1jNWX207Mg
M`80MGEe0P1cLg<2075aL@80Kfm_0P1/K6`206YZJP80J6QX0P1VIVH206ATI080HF5Q0P1OGel00`1M
GEd0FUYJ05YJFP0205QHF080EUIF0P1DE5@2059BDP80Cdm?0P1=CDd204];B`80BDU90P17AdL204E5
A@80@d=30P12@T820451@@80@41000<0?clo03hn?P0n?Sh02P0m?Cd603hn?P@0?clo0P10@40203lo
?`D0?Shn0P0o?cl40410@080@D510P13@d<204E5A@80AdM70P1:BTX204e=C@80D51@0P1CDe<205MG
E`80Fe]K0P1NGUh2061PH00306ATI01XJ6P0J6QX0080Jf][0P1^KVh2079bLP80M7Ad0P1gMgL207Yj
NP80O7al0P1oOgl20861P@80Ph>30P25QHD208N7Q`80RHV90P2:RXX00`2;Rh/0SHf=08f=S@0208j>
SP80Shn?0P2@T902096AT@80TY:B102CTi<409BDU0P0UIFE1`2FUYH209NGUa80UYJF3@2EUID809BD
U1D0oooo000C0?ooo`80TI6A0P2@T90208j>SP80S8b<0P2:RXX208R8R080QXJ60P24Q8@00`22PX80
P8200820P00207inOP80O7al0P1jNWX207QhN080MWIf0P1dM7@2079bLP80L71`0P1^KVh206a/K080
JVYZ0P1XJ6P206IVIP80I6AT00<0HV9R061PH01PH6000P1NGUh205aLG080FUYJ0P1HF5P205IFEP80
E5AD0P1BDU82051@D080CTi>0P1=CDd204];B`80BTY:0P19BDT204Q8B00304M7A`16ATH0ATI600X0
ADE51P16ATH804M7A`D0ATI60P17AdL404Q8B080BTY:0P1;Bd/204e=C@80Cdm?0P1BDU8205ADE080
EeMG0P1JFUX205eMG@80H61P0P1SHf<206EUI@0306QXJ01[Jf/0Jf][0080KVi^0P1aLG4207AdM080
MgMg0P1iNGT207alO080OWin0P20P80208:2PP80Q8B40P26QXH208R8R080RHV90P2;Rh/00`2<S8`0
SHf=08f=S@0208j>SP80Shn?0P2@T902096AT@@0TY:B0P2CTi<609BDU0T0UIFE502FUYH?09FEU@X0
U9BD5@3oool001<0oooo0P2ATI42092@T080SXj>0P2<S8`208Z:RP80R8R80P26QXH208B4Q00308:2
PP20P800P8200080OWin0P1lO7`207YjNP80N7Qh0P1fMWH207AdM080LW9b0P1`L70206i^KP80K6a/
0P1ZJVX206QXJ080IVIV0P1TI6@00`1RHV80H61P061PH00205iNGP80G5aL0P1JFUX205QHF080EUIF
0P1DE5@2059BDP80D51@0P1>CTh204e=C@80Bd];0P1:BTX204U9B@80B4Q800<0AdM704I6AP16ATH0
2P15ADD604I6APP0AdM71@16ATH204M7A`@0B4Q80P1:BTX204];B`80CDe=0P1?Cdl2059BDP80E5AD
0P1GEeL205YJFP80GEeM0P1PH60206=SH`80IFEU00<0J6QX06][J`1[Jf/00P1^KVh2075aL@80M7Ad
0P1gMgL207UiN@80O7al0P1nOWh20820P080PX:20P24Q8@208J6QP80R8R80P29RHT208^;R`0308b<
S02=SHd0SHf=0080SXj>0P2?Shl2092@T080TI6A102BTY8209>CT`H0U9BD2@2EUIDD09JFUPl0UIFE
2P2DU9@E0?ooo`004`3oool209:BTP80T92@0P2>SXh208b<S080Rh^;0P29RHT208N7Q`80QHF500<0
Q8B408:2PP22PX800P20P80207inOP80O7al0P1kNg/207UiN@80MgMg0P1eMGD207=cL`80LW9b0P1`
L70206i^KP80K6a/0P1ZJVX206QXJ00306MWI`1UIFD0IFEU0080Hf=S0P1QHF4205mOG`80GUiN0P1L
G5`205YJFP80FEUI0P1GEeL205EEE@80E5AD0P1CDe<2055AD@@0D51@00<0Cdm?04i>CP1>CTh00P1>
CTh804e=C@H0CTi>0P1?Cdl:04i>CP<0Cdm?0P1@D502055AD@80DU9B0P1CDe<205EEE@80EeMG0P1I
FET205]KF`80GUiN0P1PH60206=SH`80IFEU0P1XJ6P206YZJP0306a/K01_Kfl0Kfm_0080LW9b0P1e
MGD207MgM`80NWYj0P1lO7`207inOP80P8200P22PX8208B4Q080QHF50P27QhL208V9R@80RXZ:0P2;
Rh/308f=S@80SXj>0P2?Shl2092@T080TI6A1P2BTY8209>CT`@0U9BD3@2EUIDB09JFUP/0UIFE2P2D
U9@209>CTaD0oooo000C0?ooo`80TY:B0P2@T90208j>SP80S8b<0P2;Rh/208V9R@80QhN70P25QHD0
0`24Q8@0PX:208:2PP020820P080OWin0P1lO7`207]kN`80NGUi0P1gMgL207EeM@80Lg=c0P1bLW82
071`L080KVi^0P1/K6`206YZJP80J6QX00<0IfMW06EUI@1UIFD00P1SHf<2065QH@80GemO0P1NGUh2
05aLG080FUYJ0P1IFET205MGE`80EEEE0P1DE5@205=CD`80DE5A101@D5000`1?Cdl0CTi>04i>CP02
04i>CPP0CDe=1P1>CTh204m?C`X0CTi>0`1?Cdl2051@D080DE5A0P1BDU8205=CD`80EEEE0P1GEeL2
05UIF@80Fe]K0P1NGUh2061PH080Hf=S0P1UIFD206QXJ080JVYZ00<0K6a/06m_K`1_Kfl00P1bLW82
07EeM@80MgMg0P1jNWX207alO080OWin0P20P80208:2PP80Q8B40P25QHD208N7Q`80RHV90P2:RXX2
08^;R`<0SHf=0P2>SXh208n?S`80T92@0P2ATI4609:BTP80Ti>C102DU9@=09FEUA80UYJF2`2EUID:
09BDU080Ti>C5@3oool001<0oooo0P2BTY82092@T080Shn?0P2=SHd208b<S080RXZ:0P28R8P208N7
Q`0308F5Q@24Q8@0Q8B40080PX:20P21PH4207moO`80OGem0P1lO7`207YjNP80NGUi0P1gMgL207Ee
M@80M7Ad0P1bLW82075aL@80Kfm_0P1]KFd00`1/K6`0JVYZ06YZJP0206QXJ080IfMW0P1UIFD206AT
I080HV9R0P1QHF4205mOG`80GUiN0P1MGEd205]KF`80FUYJ0P1IFET405QHF00305MGE`1FEUH0EUIF
0080EUIF1P1EEEDE05IFEP80EeMG101HF5P205UIF@80Fe]K0P1LG5`205iNGP80H61P0P1QHF4206AT
I080IVIV0P1XJ6P206YZJP80KFe]0P1_Kfl00`1aLG40Lg=c07=cL`0207EeM@80N7Qh0P1jNWX207al
O080OWin0P20P80208:2PP80Q8B40P25QHD208N7Q`80R8R80P2:RXX208^;R`80S8b<00<0SHf=08j>
SP2>SXh0102?Shl2092@T080TI6A1P2BTY8209>CT`H0U9BD6`2EUID209JFUPT0UIFE3P2DU9@E0?oo
o`004`3oool209:BTP80TI6A0P2?Shl208j>SP80SHf=0P2;Rh/208Z:RP80R8R800<0QhN708J6QP26
QXH00P24Q8@208>3P`80PX:20P20P80207moO`80OGem0P1lO7`207]kN`80NGUi0P1hN7P207IfMP80
MGEe0P1cLg<2079bLP03071`L01_Kfl0Kfm_0080KVi^0P1/K6`206][J`80JVYZ0P1XJ6P206MWI`80
IVIV0P1UIFD206ATI0@0HV9R0P1QHF42061PH0<0GemO101NGUh605eMG@80GUiN0P1MGEdA05iNGP@0
GemO0P1PH602065QH@80HV9R0P1SHf<206EUI@80IVIV0P1XJ6P206YZJP80K6a/0P1^KVh206m_K`80
LW9b0P1dM7@00`1eMGD0MgMg07MgM`0207UiN@80Ng]k0P1mOGd207moO`80P8200P22PX8208B4Q080
QXJ60P27QhL208R8R080RHV90P2;Rh/208b<S0<0SHf=0P2>SXh208n?S`80T92@102ATI4609:BTP@0
Ti>C1P2DU9@Q09FEU@D0U9BD0P2EUID:09BDU1D0oooo000C0?ooo`80TY:B0P2ATI4208n?S`80SXj>
0P2=SHd208^;R`80RXZ:0P28R8P00`27QhL0QXJ608J6QP0208B4Q080Ph>30P22PX820820P080Ogmo
0P1mOGd207alO080Ng]k0P1iNGT207QhN080MWIf0P1eMGD207=cL`80LW9b00<0L71`06m_K`1_Kfl0
0P1^KVh206a/K080Jf][0P1ZJVX206QXJ080IfMW0P1VIVH206EUI@80I6AT101RHV82065QH@80H61P
0`1OGel405iNGPH0GEeM0P1NGUh205eMGA40GUiN101OGel2061PH080HF5Q0P1RHV8206=SH`80IFEU
0P1VIVH206QXJ080JVYZ0P1/K6`206i^KP80Kfm_0P1bLW8207AdM00307EeM@1gMgL0MgMg0080NGUi
0P1kNg/207emO@80Ogmo0P20P80208:2PP80Q8B40P26QXH208N7Q`80R8R80P29RHT208^;R`80S8b<
0`2=SHd208j>SP80Shn?0P2@T904096AT@H0TY:B102CTi<609BDU240UIFE1@2DU9@209FEU@X0U9BD
5@3oool001<0oooo0P2BTY82096AT@80T92@0P2?Shl208j>SP80S8b<0P2;Rh/208Z:RP0308V9R@28
R8P0R8R80080QXJ60P25QHD208B4Q080Ph>30P22PX820861P@80Ogmo0P1nOWh207emO@80O7al0P1j
NWX207UiN@80N7Qh0P1gMgL00`1eMGD0M7Ad07AdM00207=cL`80LW9b0P1aLG42071`L080Kfm_0P1^
KVh206a/K0@0Jf][0P1ZJVX206UYJ@80J6QX101WIfL506IVIP`0IFEU0P1VIVH206EUI@/0IVIV101W
IfL406QXJ080JFUY0P1ZJVX206a/K080KFe]0P1^KVh2071`L080LW9b0P1cLg<207EeM@80MWIf0P1h
N7P00`1jNWX0Ng]k07]kN`0207emO@80OWin0P20P80208:2PP80Ph>30P24Q8@208F5Q@80QhN70P28
R8P208Z:RP80Rh^;102<S8`208f=S@0308j>SP2?Shl0Shn?00@0T92@102ATI4209:BTPP0Ti>C2`2D
U9@H09FEUAD0U9BD5@3oool001<0oooo0P2BTY82096AT@80T92@0P2?Shl208j>SP80S8b<0P2;Rh/2
08Z:RP0308V9R@28R8P0R8R80080QXJ60P25QHD208B4Q080Ph>30P22PX820861P@80Ogmo0P1nOWh2
07emO@80O7al0P1jNWX207UiN@80N7Qh0P1gMgL00`1eMGD0M7Ad07AdM00207=cL`80LW9b0P1aLG42
071`L080Kfm_0P1^KVh206a/K0@0Jf][0P1ZJVX206UYJ@80J6QX101WIfL506IVIP`0IFEU0P1VIVH2
06EUI@/0IVIV101WIfL406QXJ080JFUY0P1ZJVX206a/K080KFe]0P1^KVh2071`L080LW9b0P1cLg<2
07EeM@80MWIf0P1hN7P00`1jNWX0Ng]k07]kN`0207emO@80OWin0P20P80208:2PP80Ph>30P24Q8@2
08F5Q@80QhN70P28R8P208Z:RP80Rh^;102<S8`208f=S@0308j>SP2?Shl0Shn?00@0T92@102ATI42
09:BTPP0Ti>C2`2DU9@H09FEUAD0U9BD5@3oool001<0oooo0P2BTY84096AT@80T92@0P2?Shl208j>
SP80SHf=0P2<S8`00`2;Rh/0RXZ:08Z:RP0208V9R@80R8R80P27QhL208J6QP80QHF50P24Q8@208>3
P`80PX:20P21PH420820P080Ogmo0P1nOWh207emO@80Ng]k0`1jNWX207UiN@80N7Qh0P1gMgL207If
MP80MGEe0P1dM7@207=cL`80LW9b101aLG42071`L0H0Kfm_0`1^KVhD06e]K@/0KVi^101_Kfl4071`
L080LG5a101cLg<207AdM080MWIf0P1gMgL207UiN@80NWYj0P1kNg/207alO00307inOP1oOgl0Ogmo
0080PH610P22PX8208>3P`@0QHF50P27QhL208R8R080RHV90P2:RXX208^;R`80S8b<0P2=SHd408j>
SP0308n?S`2@T900T92@0080T92@1P2ATI4209:BTPP0Ti>C202DU9@209FEU@<0U9BD0P2EUID209BD
U0P0UIFE0P2DU9@809FEUA40U9BD102CTi<E0?ooo`004`3oool209:BTP@0TI6A0P2@T90208n?S`80
SXj>0P2=SHd208b<S00308^;R`2:RXX0RXZ:0080RHV90P28R8P208N7Q`80QXJ60P25QHD208B4Q080
Ph>30P22PX820861P@80P8200P1oOgl207inOP80OGem0P1kNg/307YjNP80NGUi0P1hN7P207MgM`80
MWIf0P1eMGD207AdM080Lg=c0P1bLW84075aL@80L71`1P1_Kfl306i^KQ@0KFe]2`1^KVh406m_K`@0
L71`0P1aLG4407=cL`80M7Ad0P1fMWH207MgM`80NGUi0P1jNWX207]kN`80O7al00<0OWin07moO`1o
Ogl00P21PH4208:2PP80Ph>31025QHD208N7Q`80R8R80P29RHT208Z:RP80Rh^;0P2<S8`208f=S@@0
SXj>00<0Shn?092@T02@T9000P2@T906096AT@80TY:B202CTi<809BDU080UIFE0`2DU9@209FEU@80
U9BD202EUID209BDU0P0UIFE4@2DU9@409>CTaD0oooo000C0?ooo`80Ti>C0P2BTY82096AT@@0T92@
0P2?Shl208j>SP80SHf=0`2<S8`208^;R`80RXZ:0P29RHT408R8R080QhN70P26QXH208F5Q@@0Q8B4
0P23Ph<208:2PP80PH610`20P80207moO`80OWin0P1mOGd407alO080Ng]k101jNWX207UiN@@0N7Qh
101gMgL707IfMPH0MGEe101dM7@B07EeM@L0MWIf101gMgL207QhN080NGUi0P1jNWX207]kN`@0O7al
0P1nOWh207moO`80P8200P21PH400`22PX80Ph>308>3P`0208B4Q080QHF50P26QXH408R8R080RHV9
0P2:RXX208^;R`80S8b<102=SHd208j>SP@0Shn?0`2@T906096AT@H0TY:B202CTi<E09BDU080UIFE
102DU9@209FEUA40U9BD0P2CTi<409BDU080Ti>C5@3oool001<0oooo0P2CTi<209:BTP80TI6A102@
T90208n?S`80SXj>0P2=SHd308b<S080Rh^;0P2:RXX208V9R@@0R8R80P27QhL208J6QP80QHF51024
Q8@208>3P`80PX:20P21PH430820P080Ogmo0P1nOWh207emO@@0O7al0P1kNg/407YjNP80NGUi101h
N7P407MgM`L0MWIf1P1eMGD407AdM180MGEe1`1fMWH407MgM`80N7Qh0P1iNGT207YjNP80Ng]k101l
O7`207inOP80Ogmo0P20P8020861P@0308:2PP23Ph<0Ph>30080Q8B40P25QHD208J6QP@0R8R80P29
RHT208Z:RP80Rh^;0P2<S8`408f=S@80SXj>102?Shl3092@T0H0TI6A1P2BTY8809>CTaD0U9BD0P2E
UID409BDU080UIFE4@2DU9@209>CT`@0U9BD0P2CTi<E0?ooo`004`3oool209>CT`@0TY:B102ATI42
092@T0@0Shn?0`2>SXh208f=S@@0S8b<102;Rh/208Z:RP@0RHV90P28R8P408N7Q`@0QXJ60`25QHD2
08B4Q0@0Ph>31022PX840861P@@0P820101oOgl407inOPT0OGem0P1lO7`407emO@P0O7al4@1mOGd6
07inOP80Ogmo1020P8020861P@@0PX:20P23Ph<208B4Q080QHF50P26QXH308N7Q`@0R8R80P29RHT2
08Z:RP80Rh^;102<S8`208f=S@@0SXj>102?Shl5092@T0H0TI6A202BTY8809>CTb`0U9BD0P2CTi<4
09BDU0@0Ti>C5@3oool001<0oooo0P2CTi<409:BTP@0TI6A0P2@T90408n?S`<0SXj>0P2=SHd408b<
S0@0Rh^;0P2:RXX408V9R@80R8R81027QhL408J6QP<0QHF50P24Q8@408>3P`@0PX:21021PH440820
P0@0Ogmo101nOWh907emO@80O7al101mOGd807alO140OGem1P1nOWh207moO`@0P8200P21PH4408:2
PP80Ph>30P24Q8@208F5Q@80QXJ60`27QhL408R8R080RHV90P2:RXX208^;R`@0S8b<0P2=SHd408j>
SP@0Shn?1@2@T906096AT@P0TY:B202CTi</09BDU080Ti>C102DU9@409>CTaD0oooo000C0?ooo`@0
Ti>C102BTY86096AT@D0T92@102?Shl608j>SP@0SHf=102<S8`408^;R`L0RXZ:1029RHT608R8R0@0
QhN72P26QXH608F5Q@0308B4Q025QHD0QHF50080QHF55P24Q8@708F5Q@80Q8B40P25QHD808J6QPH0
QhN70P28R8P408V9R@@0RXZ:00<0Rh^;08b<S02<S8`00P2<S8`608f=S@H0SXj>0P2?Shl4092@T0H0
TI6A3`2BTY8409>CT`@0U9BD102CTi<409BDU080Ti>C:P2DU9@409>CTaD0oooo000C0?ooo`@0Ti>C
102BTY86096AT@D0T92@102?Shl608j>SP@0SHf=102<S8`408^;R`L0RXZ:1029RHT608R8R0@0QhN7
2P26QXH608F5Q@0308B4Q025QHD0QHF50080QHF55P24Q8@708F5Q@80Q8B40P25QHD808J6QPH0QhN7
0P28R8P408V9R@@0RXZ:00<0Rh^;08b<S02<S8`00P2<S8`608f=S@H0SXj>0P2?Shl4092@T0H0TI6A
3`2BTY8409>CT`@0U9BD102CTi<409BDU080Ti>C:P2DU9@409>CTaD0oooo000C0?ooo`P0Ti>C2@2B
TY8:096AT@X0T92@1P2?Shl?08j>SPh0SHf=4@2<S8`208^;Ra/0S8b<302=SHd608j>SPD0Shn?3P2@
T906096AT@P0TY:B5@2CTi<209BDU0@0Ti>C4@2DU9@209>CT``0U9BD0P2CTi<409BDU00309>CT`2D
U9@0U9BD00P0U9BD102CTi<E0?ooo`004`3oool809>CT`T0TY:B2P2ATI4:092@T0H0Shn?3`2>SXh>
08f=SA40S8b<0P2;Rh/K08b<S0`0SHf=1P2>SXh508n?S`h0T92@1P2ATI4809:BTQD0Ti>C0P2DU9@4
09>CTa40U9BD0P2CTi<<09BDU080Ti>C102DU9@00`2CTi<0U9BD09BDU00809BDU0@0Ti>C5@3oool0
0?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool0
0?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool0
0980oooo0T00002<0?ooo`00U03oool00d000000oooo0?ooo`290?ooo`00PP3oool00d000000oooo
0?ooo`030?ooo`=000000P3oool2@00000<0oooo0d0000050?ooo`03@000003oool0oooo08<0oooo
00210?ooo`03@000003ooom0000000<0oooo00I000000?ooo`3ooom000000?oood0000040?ooo`04
@000003oool0oooo@00008/0oooo00210?ooo`03@000003ooom0000000<0oooo00E000000?ooo`3o
oom000000?ooo`03@0000080oooo00A000000?ooo`3ooom00000R`3oool00840oooo00=000000?oo
od000000103oool3@00000040?oood0000100000@00000<0oooo0d00002;0?ooo`00P@3oool00d00
0000oooo@00000060?ooo`03@000003oool0oooo09<0oooo00220?ooo`03@000003oool0oooo00@0
oooo0T00002E0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?oo
o`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?oo
o`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.0250052, -0.0250052, 
  0.00365857, 0.00365857}, {{6.8125, 280.125}, {280.125, 
  6.8125}} -> {-10.161, -6.11446, 0.516914, 0.516914}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0238095 0.952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0238095 0.97619 0.97619 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00751202 0.0192308 0.00751202 [
[.5 1.0125 -20 0 ]
[.5 1.0125 20 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(60) show
75.000000 12.812500 moveto
(deg) show
93.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(.) show
99.000000 12.812500 moveto
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
128 string
128 128 8 [128 0 0 128 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
696868686868686868676766666666666666666666666562
666665656565656565656565656666666666666666676767
676867686868676767676767676767686867676868686868
686868686868686868686969696766696969696969696A6A
6A6A6A6A6A6A6A6A6B6A6B6A6A6A6A6A6A6A6A6B6B6B6B6B
6C6A696C6C6B6A69
68686868676767666666656464646464636363636363625F
626261616161616162626262626363646464646464656565
666666666766666666666666666666676766666766666667
67676767676767686868686969676668696969696A6A6A6A
6B6B6B6B6C6B6C6C6C6C6C6C6C6C6C6C6C6D6D6E6E6E6E6E
6E6C6C6D6E6D6B6A
686868676766666565646363626161616160606060605F5D
5D5F5E5D5D5D5D5E5E5E5E5F5F5F60616262626263636464
646465656565656565656565656565666666666665656566
666666666667676767686868686867686869696A6A6B6B6B
6C6C6C6D6D6D6D6D6E6E6E6E6E6E6E6E6E6F707070717170
6F6E6E6F706E6C6A
68686767666665646463626160605F5F5E5E5E5D5D5D5C5C
595B5B5A5959595A5A5A5B5B5C5C5D5E5F5F606061626263
636364646464646464646464646465656564646564646465
6565656566666667676767686868686867696A6A6B6B6B6C
6C6D6D6E6E6E6F6F6F707070707070707172737373737272
7170707071706D6B
6868676666656463636261605F5E5D5C5C5B5B5B5A5A5A59
57565756565555565657575858595A5B5C5D5E5F5F616162
626262636363636263636363636364646363636463636364
6464646565656666666767676768686968676A6B6B6B6C6C
6D6D6E6F6F6F707071717272727272727374767676747474
7273717273716E6B
68676766656463626261605F5E5D5C5B5A59585858575756
555353525251515152535354555657585A5B5C5D5E606061
616161616161616162626262626262626262626262626262
6363636464646565666666676768686969696A6B6B6C6C6C
6D6E6F707070717172727373737474757677797977767675
7575737474716E6B
686766656464626260605E5D5D5B5A595857565555545453
52504F4E4D4D4D4D4E4E4F505153545657595A5C5D5F5F60
606060606060606060616161616161616161616161616161
62626263636464646565666767686869696A6A6B6B6C6C6D
6E6F6F70717172737374747575757677787A7C7B79787878
7777757675726F6B
68676665646361615F5E5D5C5B5A59585655545352525150
4F4D4B4A48494849494A4B4D4E4F51535557595A5C5D5E5F
5F5F5F5F5F5F5F5F5F606060606060606060606060606060
61616262626363646465666667686869696A6B6B6B6C6C6D
6E6F707172727374757576767778797A7C7E7E7C7B7B7B7A
7A79787876726F6C
68676665636261605E5D5C5B5A58575655535251504F4E4D
4C4A484644444444454647494B4C4F51535658595A5C5D5E
5F5F5F5E5E5E5E5E5E5F5F5F5F5F5F5F5F5E5F5F5E5F5F5F
60606161626263636465666767686869696A6B6B6B6C6C6D
6E7071727373747576767778797B7D7E7F80807F7E7E7E7D
7C7A7A7A7773706C
686665646361605F5D5C5B59585756545351504F4D4C4B49
48464443413F3E3E40414345474A4C4F51545658595B5C5D
5E5E5E5E5D5D5D5D5D5E5E5E5E5E5E5E5E5E5E5E5E5E5F5F
5F606161626263646465666767686869696A6B6B6C6D6D6E
6F6F7273747475767777797B7D8081828283838281818080
7E7C7D7A7874706C
6766656362615F5E5C5B5A585755545251504E4D4B4A4846
4543413F3D3B39393C3C3E414447494D4F525557585A5B5D
5D5D5D5D5D5C5C5C5C5C5D5D5D5D5D5D5C5C5C5D5D5D5E5E
5E5F6060616262636465666667686869696B6B6C6D6D6E6F
6F70747374757677797B7D80828485858687858584838483
807F7E7C7874716D
6766656361605F5D5C5A5957565452514F4E4C4A49474543
413F3E3B3937343536383A3C4044474B4D51545658595B5C
5C5C5C5C5C5C5B5B5B5B5C5C5C5C5C5B5B5B5B5C5C5C5D5D
5D5E5F5F606162636365656667676869696B6B6C6D6E6F6F
707274747577787A7D7F8184868789898A8A878887868785
83827F7D7975716D
6766646261605E5C5B5957565452514F4D4B4A4846444240
3E3C3A3836333131303235373C4145494C50525557595A5C
5C5C5C5C5B5B5B5A5A5A5B5B5A5A5A5A5A5A5A5A5B5B5C5C
5C5D5E5E5F6061626364656666676869696A6B6C6D6E6F70
7172747577797B7F828386888A8B8C8D8D8D8A8B8B898A87
8584817D7975716D
67656462605F5D5C5A58565553514F4D4B4947464442403D
3B39373532302E2D2C2C3032373D43474B4F525557585A5B
5B5B5B5B5B5A5A5A5A5959595959595959595959595A5A5B
5B5C5C5D5E5F60616264656566676869696A6B6D6D6E7071
727475777A7D818386878A8C8D8F9090908F8E8E8E8D8C89
8886827E7A76716D
67656362605E5C5B59575553514F4D4C49474543423F3D3B
383634322F2D2A2927272A2E323840464B4E525557585A5B
5B5B5B5A5A5A59595958585858585858585858585858595A
5A5B5C5D5E5E5F6162636465666768696A6A6C6D6E6F7172
7476787B808385888A8B8D8F919293939392929291908D8C
8A87827E7A76726D
676563615F5E5C5A58565452504E4C4A484544413F3D3B38
3633312E2C2927262323252A2E343B444B4E525557595A5B
5B5B5A5A5959595858575757575757575757575757575858
595A5B5C5D5D5F6061636465666768696A6A6C6D6E707274
76787C818587888C8E8F9192939496969696969494918F8E
8B87837F7B76726D
676563615F5D5B59575553514E4C4A484644423F3D3B3836
33312E2B29262422201F21262B313840494F535658595B5B
5B5A5A5A5959585857565656565656565656565656565657
58595A5A5C5D5E5F61626465656768696A6B6C6E6F727476
797D8287898B8D909293949596979999999999979693918F
8C8784807B76726D
676563615F5C5A585654524F4D4B49474442403D3B383633
302E2B292623201E1D1B1E23272E363D454E55575A5B5B5C
5B5A5A595958575756565555555554545454545555555556
575758595B5C5D5F606263646567686A6B6C6E6F7173777A
7E83888B8D8F9194959697999A9B9C9D9C9C9B9998969390
8C8884807B77726D
676562605E5C5A575553504E4C4A474543403E3B39363331
2E2B292623201D1B1A181C20252C333A424B555B5B5C5C5C
5B5B5A595858575655555454545353535353535353545455
565657585A5B5C5E606163646567696A6C6E6F7173777A80
84888C8E9093959798999B9D9E9F9F9F9F9F9D9B9A989491
8D8984807B76726D
666462605D5B595754524F4D4B484643413E3C393734312E
2C292623201D1A1817161A1E242A3138414A545D5D5E5D5D
5C5B5A595857565554545353535252525252525252535354
54555657595A5C5E6061626466686A6C6D707174767C8085
898D90929496999B9C9D9EA0A1A1A2A2A2A19F9E9C999692
8D8984807B76726D
6664615F5D5B585653514E4C494744423F3C3A3735322F2C
292623201D1A17151314181C222930374049535C5F5F5E5D
5C5B5A585756555454535252515151515151515151525253
53545556585A5C5E6061626467696B6D6F7275787C818589
8D919395979A9C9D9FA0A1A3A4A4A5A5A4A3A1A09D9A9692
8D8985807B77726D
6663615F5C5A585552504D4B484543403E3B383533302D2A
2724211D1A1714121112171B22282F373F49525A62615F5E
5C5B59585756545353525151505050504F4F505050505152
5253545557595C5E5F606266686A6D6F7277797D8185898D
919497989B9DA0A1A3A4A5A6A7A8A8A7A6A5A3A19E9A9792
8D8985807B77726D
6663615E5C595754514F4C4A4744413F3C393633312E2B28
25211E1B1814120F0F11161B21272E37404850596462605E
5C5A595756555353525150504F4F4F4F4E4E4E4E4F505051
5152535456595C5E5E606367696C6F72777B7E8185898D90
95989A9C9EA1A3A4A6A6A8A9AAABABAAA8A7A5A29E9B9792
8E8985807B77726D
6663615E5C595653514E4B494643403D3A3734322F2C2926
221F1C1915120F0D0E10151A21272E37404750596562605E
5C5A59575554535251504F4F4E4E4D4D4D4D4D4D4E4E4F50
5051525456595C5D5E6165686B6E72777C808386898D9194
989B9DA0A2A4A6A6A8AAABADAEAEAEACABA9A6A29F9B9792
8E8984807B77726D
6663605D5B585553504D4A4844413E3C393633302D2A2623
201D1A16130F0D0B0D10141A20272F383F46505A6562605E
5C5A5856555352514F4F4E4D4D4D4C4C4C4C4C4C4D4D4E4F
4F50525356595B5C5F63666A6D72767B8085878A8D919497
9B9DA1A3A6A7A8A9ABADAEB0B1B1B0AEADAAA7A39F9B9793
8E8984807B77726D
6663605D5A5755524F4C494643403D3A3734312E2B282421
1E1B1714110D0A0A0C10141A212730373E46515B6563605E
5C5A5856545351504F4E4D4C4C4B4B4B4B4C4B4C4C4D4D4E
4F50515356595A5D6165686C71767A7F85898C8E9194979A
9DA0A4A6A9AAABACAEB0B1B3B4B3B2B0AEAAA7A4A09C9793
8E8984807B77726D
6663605D5A5754514E4B4845423F3C3936332F2C2926221F
1C1915120E0B08090C0F141B212830373F48525B6563605E
5C5957555352504F4E4D4C4B4B4B4A4A4B4B4B4B4B4C4D4D
4F50515356585B5E62666B6F74797E84898D909295979A9C
A0A3A7AAACADAEAFB1B2B4B6B6B6B4B2AFABA8A4A09C9793
8E8985807B77726D
65625F5C595654504D4A4744413E3B3734312E2B2824211D
1A1713100C0907090B10151C222931383F49535C6663615E
5C5957555351504E4D4C4B4A4A4949494A4A4A4A4B4B4C4D
4E4F515456585C6064696D72777D83888D919497999B9C9E
A2A6AAACAEB0B1B2B3B5B7B9B9B8B6B3B0ACA8A4A09C9793
8E8985807B77726D
65625F5C595653504D4A4643403D393633302C2926221F1C
1815110E0A0706080C10161D232B3138404A545D6663615E
5B59565452504F4D4C4B4A49494848494949494A4A4B4C4C
4E50525456595D62666B70747B81878C9094989B9C9EA0A1
A5A9ACAFB1B3B3B4B6B8BABCBBBAB7B4B0ADA9A5A09C9793
8E8985807B77726D
65625F5C5855524F4C4945423F3B3835312E2B2824211D1A
16130F0C080606080C11171E242C323A434D565E6763615E
5B58565452504E4D4B4A49484848474848484949494A4B4C
4E505255575A6064686D72777E868C8F93979B9EA0A2A3A4
A7ABAEB1B3B6B6B7B9BBBDBFBDBBB8B5B1AEA9A5A09C9893
8E8985807B77726D
65625F5B5855524E4B4844413E3A3733302D2926231F1B18
14110D0A060506080D12191F262D343D464F575F6764615E
5B58565452504E4D4B4A48484747474747484849494A4B4C
4E505356585C62666A6F757C838A8F92969A9EA2A4A5A6A7
AAADAFB3B6B8B8BABCBFC0C1BFBCB9B6B2AEAAA5A19C9893
8E8985807B77726D
65625E5B5855514E4A4743403D3936322F2B2824211D1A16
120F0C08050506090F141B22282F3640495159616764605D
5A585553514F4E4C4B4948474646464647474748494A4B4C
4E515457595E64686B727981868D9295989CA0A5A7A9A9AA
ACAEB1B5B9BABBBDBFC1C2C3C0BCBAB6B2AEAAA5A19C9893
8E8A85807B77726D
65625E5B5754504D4A46433F3B3835312D2A2623201C1814
110D0A060405070B10161D242A3239444C545C6466635F5C
59575452504F4D4C4A4948474646454646464748484A4B4D
4E5155595C6166696E757D85899095989B9FA3A8AAACADAD
AEB0B2B7BBBCBEC0C2C3C4C4C0BDBAB7B3AEAAA5A19C9893
8E8A85807B77726D
65615E5B5753504C4945423E3A3733302C2925211E1A1613
0F0C08050405080C121820262E343E485058606464615D5A
58555351504E4C4B4A494847464645454546464748494B4C
4F52555A6064696A707780888C92979B9DA2A6AAADAFB0B0
B0B1B5B9BDBEC1C3C4C5C7C5C1BFBBB7B3AFAAA5A19C9893
8E8A85807B77726D
65615E5A57534F4C4844413D3936322E2B2723201C181511
0D0A07040306090E141B22293138434C545D6162605E5B58
565452504F4D4C4B4A494847464645454445464648494B4C
4F52565C64666C6D737A828B90939A9DA0A4A8ACAFB1B3B2
B2B3B7BBBEC1C4C5C6C7C8C5C2C0BCB8B3AFAAA6A19C9893
8E8A85807C77726D
65615E5A56534F4B4744403C3834312D2926221E1B17130F
0C08050404070B10171E252D343D485059605F5E5D5B5856
5452504F4D4C4B4A4A484847474645454544454647484A4C
4F53575E66696F71757D858D93969B9FA2A6AAADB1B3B5B5
B5B5B8BDC0C3C6C7C8C9C9C7C4C0BCB8B3AFAAA6A19C9893
8E8A85807C77726D
65615D5A56524E4A47433F3B3734302C2824211D1915110D
0A07040405080D131921293138434C555C5E5C5B59585654
52504F4E4C4B4B4A4A494848474746464545454546484A4C
4F53595F686D70757880878F93989BA0A4A7ABAFB2B5B7B8
B8B7BABFC2C6C8C9CACBCBC8C4C1BCB8B4AFAAA6A19D9893
8F8A85807C77726D
65615D5955514D4A46423E3A36322F2B27231F1C1814100C
09060403060A0F151D252C353E4951595C5B5A5856555351
504F4E4D4B4A4A4A4A49494848474746464545454647494C
4F5359606A7072787D81898F949A9DA1A5A9ACB1B4B7B9BB
BBBBBCC0C4C7C9CCCDCDCCC8C5C1BDB9B4AFABA6A19D9893
8F8A85807C77726D
65615D5955514D4945413D3935312E2A26221E1A16120E0A
07050404070C12192129303A444E575A595857555452504F
4E4D4C4B4B4A4A4A4A4A4A4A49494847474646464647494B
4F5459616A72767B80858B8F949A9FA2A6A9ADB2B6B9BBBD
BEBEBEC2C6C9CBCECFCFCCC9C5C1BDB9B4AFABA6A29D9893
8F8A85807C77726D
65615D5955504D4944403C3935302C2824201C1915110D09
06050405090F151C252D35404A54595857565452514F4E4D
4D4C4B4B4A4A4A4A4A4B4B4B4B4A4A48484747464747484A
4E5359616A737A7D81888C91959BA0A3A7AAAFB3B8BABDBF
C0C1C1C4C7CACDD0D0D0CDCAC5C2BDB9B4B0ABA6A29D9894
8F8A85817C77726D
64605D5854504C4844403B38332F2B27231F1B17130F0B07
050404060B12192029313B454F585756555452504E4C4C4D
4C4C4B4B4A4A4A4A4B4C4D4D4D4C4B4A494847474748494A
4D5258606A747B80848A8E92979BA0A4A8ABAFB4B9BBBEC1
C3C4C4C5C9CBCED1D2D1CECAC6C2BEB9B4B0ABA7A29D9894
8F8A85817C77726D
64605C5854504C47433F3B37322E2A26221D1A15110D0906
040404080E151D242E37414B555957555452504D4C4B4C4E
4C4B4B4B4B4A4A4B4C4D4E4F4F4E4D4B4A4948484848494B
4D51576069737B83868A9093999DA0A5A9ACB0B5B9BDBFC3
C5C7C7C7CACDD0D3D4D1CECAC6C3BEB9B5B0ABA7A29D9894
8F8A85817C77726D
64605C58534F4B47423E3A36312D2925201C1814100C0705
0303060B11192129323C47515857565453504E4B4B4C4C4D
4C4B4B4B4A4A4B4C4E4E4F5051504F4D4B4A494849494A4C
4E51565E67737B84878B91959A9FA3A5A9ACB1B5BABEC1C4
C7C9C9C9CCCFD2D4D5D2CFCBC7C3BEBAB5B0ACA7A29D9994
8F8A85817C77726D
64605C58534F4B46423E3935302C28231F1B17120E0A0604
0304080D141D252E38434D5758575554524F4D4B4B4C4D4D
4C4C4C4B4B4B4D4E4F4F50515252504E4C4B4A49494A4B4C
4E51555C65717B83898D91979AA1A5A7A9AEB1B6BBBFC2C5
C9CBCCCCCDD1D3D6D6D3CFCBC7C3BFBAB5B0ACA7A29D9994
8F8A85807C77726D
64605C57534E4A46413D3834302B27221E1915110C080503
03060A1018212A343E49545857575554524F4F4C4C4E4E4E
4E4E4E4D4D4D4F50515353535453514F4D4B4B4A4A4A4B4D
4E51545A646F7A82898E91979CA1A7A9ABADB2B7BBC0C3C7
CBCDCECFCFD2D4D7D7D3CFCCC8C4BFBAB5B1ACA7A29D9994
8F8A85817C77726D
64605B57524E4A45413C38332F2A26211C18130F0B070402
03070D141D252F39444E5858585755545251504E4E4F4F4F
4F4F4F4E4F4F5051525353535352514F4D4C4B4B4A4B4C4D
4F515459626D7981898E92969EA2A9ACAEAFB4B7BBC0C4C8
CDCED1D1D1D4D6D9D7D4D0CCC9C4BFBAB6B1ACA7A29E9994
8F8A85817C77726D
64605B57524E4945403C37322E2924201B16120D09050302
04091018202A343F49545A5958575654535251504F4F4E4E
4E4D4E4E4E4E4F50515252525251504F4D4C4B4B4B4B4C4D
4F5154585F6B7780888E93979EA4AAAFB0B2B5B8BCC1C5C9
CDD1D4D3D3D5D7DBD8D4D1CDC9C4BFBAB6B1ACA7A29E9994
8F8A85817C77726D
64605B56524D4944403B36322D28231F1A15100C07030202
060C131C252F39434E595A5959585655545251504F4F4E4D
4D4C4D4D4D4D4F505152525251514F4E4D4C4C4B4B4B4C4D
4F5154585E69747F878D93989EA5AAB0B3B5B6BABDC2C6CB
CFD3D5D6D5D7D9DCD9D5D1CEC9C5C0BBB6B1ACA7A29E9994
8F8A85817C77726D
645F5B56524D48433F3A35312C27221D18140F0A05020104
080F171F29333E48525C5B5A5A585756545352504F4E4E4D
4C4C4C4C4C4D4F50505152525151504E4D4C4C4B4B4C4C4D
4F5154575D66717D868D93999EA5ABB1B5B8BABCBEC3C6CC
D0D5D7D8D8D9DCDCDAD6D2CFCAC5C0BBB6B1ACA7A39E9994
8F8A85817C77726D
645F5B56514D48433E3935302B26211C17120D0804020205
0B121A232E37424C575F5D5B5A595756555352514F4E4D4C
4B4B4B4C4C4D4E50515152525151504E4D4C4C4B4B4C4C4E
4F5154575C64707B858C93999FA4ACB2B8BBBCBEC0C4C8CE
D2D6D8DBDADBDEDCDBD7D3CFCAC5C0BBB6B1ACA8A39E9994
8F8A86817C77726D
645F5A56514C47423E39342F2A25201B16110C0702010307
0E161E27313C46505C5F5E5C5B5A5856555352514F4E4D4C
4B4B4A4B4C4D4F50515252525251504E4D4D4C4B4B4C4C4E
4F5153575C636D79838B9399A0A5ACB2BBBCBFC2C2C6C9CE
D3D7DADDDDDDDFDDDBD7D4CFCAC5C0BBB6B1ACA8A39E9994
8F8A86817C77726D
645F5A55514C47423D38332E29241F1A15100B050101040A
1119222B3640495460605F5D5C5A5957555452514F4D4C4D
4C4B4A4A4B4D4F4F515253535251504F4D4D4C4C4C4C4D4E
4F5153575B616A77828B939AA1A6ACB4BBBFC3C4C5C7CBCF
D4D9DDDFDFE0DEDEDBD9D5CFCAC5C0BBB6B1ACA8A39E9994
8F8A85817C77726D
645F5A55504B46413D37332E29241E19140F09040001060D
141D26303A434D596361605E5D5A595755545251504E4E4E
4C4B4A4A4C4E4F4F515353535251504F4E4D4C4C4C4C4D4E
4F5153575B616875818B939BA1A8ADB4BAC3C5C6C8C8CDD0
D6DBDFE1E2E1DFDFDDDAD5D0CAC5C0BBB6B1ACA8A39E9994
8F8A85817C77726E
645F5A55504B46413C37322D28231E18130E08030002080F
18212A343D46525E6462605E5D5B595755545351504F4E4E
4C4B4A4A4C4D4F4F515354535251504F4E4D4D4C4C4C4D4E
4F5153575B606774808B949BA1A9AEB5BCC6C7CACBCACED2
D7DCE0E3E4E3E1E1DFDAD5D0CAC5C0BBB6B1ACA8A39E9994
8F8A85817C77726D
645F5A55504B46413B36312C27221D17120D070200040B12
1C242D37404A56626463615F5D5B595756545352514F4F4E
4C4B4A4A4B4D4E4F515253535251504F4E4D4D4C4C4D4D4E
4F5153575B6066727F8B939CA2AAAFB7BEC7C9CCCDCDD0D4
D8DDE2E5E6E4E4E2DFDAD5D0CAC5C0BBB6B1ACA8A39E9994
8F8A85817C77726D
645F5A55504A45403B36312C27211C17110C060100060D16
1F28313A434E5A666463615F5D5B59575654535251504F4E
4C4B4A4A4B4D4E4F515353535251504F4E4E4D4D4D4D4E4F
505154575B6066707E8A939CA3AAB0B8BFC7CCCECFD0D0D5
D9DFE4E8E8E6E6E4DFDAD4CFCAC5C0BBB6B1ACA7A39E9994
8F8A85817C77726D
645F5A544F4A45403B36302B26211B16100B05000209101A
232C343D47535E686563605E5C5B59575654535251504F4E
4C4B4A4A4B4D4E50515253525151504F4E4E4E4D4D4D4E4F
505254575B60676F7D89939CA4ABB2B9C1C9CDD0D2D2D1D6
DBE1E6E9EAE8E8E4DFDAD4CFCAC5C0BBB6B1ACA7A29E9994
8F8A85817C77726D
645F59544F4A45403A35302A25201B15100A0500040B141E
262F38404D5863676462605E5C5A59575654535251504F4E
4C4B4A4A4B4D4E50515252515150504F4E4E4E4E4D4E4F50
515355575B61676F7C88939CA4ABB4BAC2CACFD1D3D4D2D7
DCE3E7ECECEAE9E4DFDAD4CFCAC5C0BBB6B1ACA7A29D9994
8F8A85817C77726D
635E59544F4A443F3A352F2A251F1A140F090401060E1821
29323B45515F656563615F5D5B5958575554535251504F4E
4D4B4A4A4B4D4E4F505151515150504F4F4E4E4E4E4F4F50
525356585B61686F7B88929CA5ACB5BCC3CBD1D2D4D5D4D8
DDE5E9EEEEECE9E4DFD9D4CFCAC5C0BBB6B1ACA7A29D9894
8F8A85817C77726D
645E59544F49443F39342F29241F19140E09020309111C24
2D363F4B5663636361605E5C5A585756555454535251504F
4D4C4B4A4B4D4E4F50505151504F4F4E4E4E4E4F4F505051
525456595C6168707A86919CA5ADB5BDC5CCD1D3D4D6D6D9
DFE7ECF0F0EDE9E4DED9D4CFCAC5C0BBB6B1ACA7A29D9894
8F8A85807C77726D
645E59544F49443F39342F29241E19130E0802060D151F27
303A444F5B6362615F5E5C5B59585756555454535251504F
4E4C4B4A4A4C4D4E4F5050504F4F4E4E4E4F4F4F50505152
5355575A5D6168707985919CA5AEB6BDC6CED1D3D5D7D8DB
E1E9EEF1F2EEE9E4DED9D4CFCAC5C0BBB6B1ACA7A29D9894
8F8A85807C77726D
635E59544E49443E39342E29231E18130D0803090F18222B
343D49545F61605F5E5C5B5958575655545454535352514F
4E4D4B4A4A4B4C4D4E4E4F4F4E4E4E4E4E4E4F5050515253
5456585B5E6268707984909BA6AFB7BEC6CFD1D4D6D8DBDC
E4EAEFF3F3EEE9E4DED9D4CFCAC5BFBAB5B0ACA7A29D9894
8F8A85807C77726D
635E59544E49433E38332E28231D18120C07050C121B242E
37414D595F5E5E5D5C5B5958565555545454545454535250
4F4E4C4A494A4B4C4D4D4E4E4D4D4D4D4E4E4F5051535354
5657595C5F63687079838F9BA6B0B7BFC7D0D2D4D7D9DDDE
E6ECF1F4F4EEE9E3DED9D4CFC9C4BFBAB5B0ABA6A29D9893
8F8A85807C77726D
635E59534E49433E38332D28221D17110C06080E151F2730
3A46515B5C5D5D5C5A595756555454535454555555545352
504E4C4A49494A4B4C4D4D4D4C4C4C4C4D4E4F5153545556
57595A5D6064697079828F9BA6B0B8C0C8D1D3D5D8DAE1E0
E8EFF3F5F4EEE9E3DED9D3CEC9C4BFBAB5B0ABA6A19D9893
8E8A85807B77726D
635E59534E48433E38332D27221C17110C050C1018212933
3D4A545B5B5C5C5A59575554535353535355565757565453
524F4D4A4848494A4B4C4C4C4B4A4A4B4D4E505254565657
595A5B5E61646A7079828E9BA6B1B9C1C9D1D4D6D9DCE4E3
EAF2F5F6F4EEE9E3DED8D3CEC9C4BFBAB5B0ABA6A19D9893
8E8A85807B77726D
635E58534E48433D38322D27221C16110C060E121B232C35
424D56585A5B5B5957555352515151525355585859585655
53504D4A484848494A4A4B4A4A49494A4C4F515355585959
5A5C5D5F62656A7179838E9AA6B2BAC2CAD2D5D7DBDFE7E5
ECF4F6F7F4EEE8E3DDD8D3CEC8C3BEB9B4B0ABA6A19C9893
8E8985807B77726D
635E58534E48433D38322D27211C16100A080E131D262F38
46505656595B5A58555351505152515254575A5A5B5A5857
55514E4A484748484947494A4A4948494D505254575A5B5B
5C5D5F6063666B727A838E99A6B2BBC4CBD3D6D9DDE1E9E8
EFF6F7F7F3EDE8E2DDD8D2CDC8C3BEB9B4AFAAA5A19C9793
8E8985807B77726D
635E58534D48433D38322C27211B16100A0B0F151E29323B
47535456595B595754514F505353505255595B5D5D5D5B59
56524F4B494747464747494C4B47474A4F515455585C5D5E
5E5F606264676C737B848E99A6B3BCC5CDD4D8DBE0E4EBEA
F2F7F7F8F3EDE7E2DCD7D2CDC8C3BEB9B4AFAAA5A09C9792
8E8984807B76726D
635E58534D48423D37322C26211B15100C0C0F17202C353E
49545456595A595653504F5054545155555C5D6060605E5B
58534F4C494746464648484B4A464A4A505257555A5E5F5F
6061616365686D747C858E9AA8B4BEC6CFD5D9DDE3E7EDEC
F5F8F9F8F2ECE7E1DCD7D1CCC7C2BDB8B3AFAAA5A09C9792
8D8984807B76726D
635E58534D48423D37322C26201A140E0D0C1119222D3741
4B535356595A59565351505255545357585F60636362605C
5854504D4A4846464648484A4A474B4B525458585D606161
62626364666A6E757D868F9BA9B4BFC8D1D6DBE0E5EAEFEF
F6F9FAF7F1EBE6E1DBD6D1CCC7C2BDB8B3AEA9A4A09B9692
8D89847F7B76726D
635E58534D48423D37312C26201A140D0E0E121A252F3843
4C5254575A5B5A58565453555656585B5D6163646463605D
5955514E4B4947464747494A4B4B4E505356595D5F616162
62636365676B70777F87919CAAB5BFCAD3D9DDE2E8ECF0F1
F7FAFBF6F0EBE5E0DAD5D0CBC6C1BCB7B2AEA9A49F9B9691
8D88847F7B76726D
635E58534D48423D37312C26201A140E0D0F131D27303944
4D5255585B5D5B5A5857565758595B5D606263656463605C
5955524F4C4A48474747494B4D4E505255585B5E5F606061
62636466696C71788089929EABB6C1CBD5DBDEE4EBEFF2F2
F8FCFAF5EFEAE4DFDAD4CFCAC5C0BBB7B2ADA8A49F9A9691
8D88847F7B76716D
635E58534D48423D37312B25201A140F090F161F29323A45
4D5256595D5E5D5C5B5A5959595A5B5D5F61636564625F5C
595553504D4B49474747494B4E50525456585A5C5D5E5F60
616265676A6D737A818A949FACB8C2CDD7DDE0E6EDF1F4F4
FAFCF9F3EEE9E3DED9D4CEC9C4C0BBB6B1ACA8A39F9A9591
8C88837F7A76716D
635E58534E48433D37312B252019140F081118222B343B46
4D53575A5E605F5E5D5C5B5A5A5A5B5E6164656563615E5B
585553504E4C4A4948484A4C4F5153545657595A5C5D5E5F
606365676A6F747A828B95A1ADB9C5D0D8DEE3E8EFF2F5F6
FAFCF8F2EDE7E2DDD8D3CEC9C4BFBAB5B1ACA7A39E9A9591
8C88837F7A76716D
635E59534E48433D37322C251F1912100A131B242C353D46
4D53585C6062615E5E5D5C5C5B5C60626365646362605D5A
585553514F4D4C4A4A4A4B4D4F515354555658595A5B5D5F
616466686B70767C848C97A3AEBAC7D2DAE0E5EAF1F3F5F8
FCFCF6F1ECE6E1DCD7D2CDC8C3BEB9B5B0ABA7A29E999590
8C87837E7A76716D
635E59534E49433D38322C262019110F0D161E262D363D46
4D53595E62646361605F5E5E5F61636363636261605E5C59
57555351504E4D4C4B4B4C4E4F515355555658595A5D5E60
626466696C71777D858D99A4AFBCC9D5DCE1E7ECF2F5F6FA
FEFBF5F0EAE5E0DBD6D1CCC7C2BDB8B4AFABA6A29D999490
8B87837E7A76716D
635E59544E49433E38322C262019110F121921272E363E46
4D545A5F646664636261616162636362626161605E5D5B59
57555452504F4E4D4D4D4D4E50515254545658595B5D5E60
626466696D73787E868F99A5B1BFCCD9DDE3EAEDF2F6F7FC
FFF9F4EEE9E4DFDAD4D0CBC6C1BCB8B3AEAAA5A19C98948F
8B87827E7A75716D
635E59544E49443E39332D27201A120F151C23282E363E46
4D545B6065676665646363626262626161605F5E5D5B5A58
56555352504F4E4E4D4D4E4E50505253545657585A5C5D5F
6264676A6E74797F87909BA7B4C1CEDCDFE5ECEEF3F8F8FE
FEF8F2EDE8E2DDD8D3CECAC5C0BBB7B2AEA9A5A09C98938F
8B86827E7A75716D
635E59544F4A443F3A342E28221B1410171D24292F373E46
4D555C61666867666564646363626161605F5E5D5C5A5957
5654535251504F4E4E4E4E4F5050515254555658595B5D5F
6164676A6F757A8088919DA9B5C3D1DEE1E7EDEFF3F9FAFF
FCF6F1EBE6E1DCD7D2CDC8C4BFBAB6B1ADA8A4A09B97938E
8A86827E7975716D
645F5A544F4A45403A352F29231D1611181E242A30373E46
4E555D626669686766656463636261605F5E5D5C5B5A5857
5554535251504F4F4F4F4F4F4F50515253555657595B5D5F
6164676B70757B8189939FAAB7C5D4E0E5E9EEF0F4F9FDFF
FAF4EFEAE4DFDAD5D1CCC7C2BEB9B5B0ACA8A39F9B96928E
8A86817D7975716D
645F5A55504B46413B36302B251F1912181E252B31373F46
4E555D6266696968676665646362615F5E5E5C5B5A595756
555452525150504F4F4F4F4F5050515253555657595B5D5F
6165686C71767C838B95A0ACBAC8D6E2E7EAF0F2F6FAFFFD
F8F2EDE8E3DED9D4CFCBC6C1BDB8B4AFABA7A29E9A96928D
8985817D7975716D
645F5A55504C47423C37322C27211B14191F262B31383F46
4E565D6266696969676665646261605F5E5D5C5A59585756
545352525150504F4F4F4F4F5051515253555657595B5D5F
6265686D72777D848D97A2AFBDCBD9E3E9ECF2F5F8FBFFFB
F5F0EBE6E1DCD7D2CEC9C5C0BCB7B3AEAAA6A29D9995918D
8985817D7975716D
645F5A56514C47433E38332E29231D161B20252B31383F47
4E565D6266686969686665636261605E5D5C5B5958575655
54535252515050504F4F4F505051525254555658595C5E60
6266696D72787F868F99A4B2C0CDDCE4EAEFF4F7FAFCFDF8
F3EEE9E4DFDAD5D1CCC8C3BFBAB6B2ADA9A5A19D9994908C
8884807C7874706D
645F5B56524D48443F3A35302B26201A1B1F242B31383F47
4E565D62656869686766646362605F5D5C5B5A5857565654
53535251515050504F4F505051515253545556585A5C5E61
63676A6E737A8088919BA7B5C3D0DFE5EBF0F7F9FBFDFAF5
F0EBE7E2DDD8D4CFCBC6C2BDB9B5B1ACA8A4A09C9894908C
8884807C7874706C
64605B57524E4945403B37322D28231F1A1F242B31383F47
4E565D61656768686765646261605E5D5C5A595857565554
53525251515050504F50505051525253555557585B5D5F61
64676B70757B8289939EAAB8C6D3E1E6ECF2F9FBFCFCF7F2
EEE9E4E0DBD6D2CDC9C5C0BCB8B3AFABA7A39F9B97938F8B
8783807C7874706C
64605C57534F4A46423D39342F2B26221D1F242B31383F46
4E555C606466676766646361605F5D5C5B5A585756555453
53525151515050505050505151525354555657595B5E6062
65686C71777D848C96A1AEBBC9D6E3E8EDF4FAFCFCF9F4F0
EBE7E2DDD9D4D0CCC7C3BFBAB6B2AEAAA6A29E9A96928F8B
87837F7B7874706C
64605C5854504B47433F3A36322E2925211F242B31373E45
4D555B6063656665656362615F5E5C5B5A58575655545353
525151515050505050505051525253545557585A5C5F6163
666A6E73797F868F9AA5B1BECBD8E5EAEFF6FAFCFBF6F2ED
E9E4E0DBD7D2CECAC5C1BDB9B5B1ADA9A5A19D9995928E8A
86837F7B7774706C
65615D5955514C4844403C3834302C292521252A30363D44
4C535A5F62646564636261605E5D5B5A5957565554535352
515150505050505050505151525354555658595B5D606265
686B70757B8289929DA8B4C1CDDAE7ECF0F6FAFBF9F4EFEB
E6E2DDD9D5D0CCC8C4C0BBB7B3B0ACA8A4A09C9895918D89
86827E7B7773706C
65615D5955514E4A46423E3A37332F2C2926272A2F353B42
4A52585D616363636261605E5D5C5A595856555453525251
515050504F4F5050505051525354555657595A5C5F616366
696D72777D858D96A1ACB8C4D0DDE9ECF1F7FAFAF6F1EDE8
E4DFDBD7D2CECAC6C2BEBAB6B2AEAAA6A39F9B9794908C89
85827E7A7773706C
65615D5A56524F4B4743403C3935322F2C2B292A2C323940
4850565C5F61626160605E5D5C5A59585755545352525150
504F4F4F4F4F50505050515253545556585A5C5E60626568
6B70747A8189919AA4AFBBC7D4E1E9ECF2F7F9F8F3EFEAE5
E1DDD9D4D0CCC8C4C0BCB8B4B0ADA9A5A19E9A96938F8C88
85817E7A7773706C
65615E5A5753504C4945423E3B3835322F2D2C2A292E363E
464E545A5D5F605F5F5E5D5C5A595857555453525151504F
4F4F4E4E4F4F4F505051525354555657595B5D5F6164676A
6D72777D858D959EA8B3BFCBD9E3E7ECF3F7F8F5F0ECE7E3
DEDAD6D2CECAC6C2BEBAB6B3AFABA8A4A09D9996928E8B87
84817D7A76736F6C
65625E5B5754514D4A4743403D3A373432302E2C292B353D
444C52575B5D5E5E5D5C5B5A595856555453525150504F4E
4E4E4E4E4E4F4F5051515254555657585A5C5E606365696C
70757B8189919AA3ACB7C3D0DBE2E7EDF3F6F6F2EDE9E4E0
DCD8D3CFCBC8C4C0BCB8B5B1ADAAA6A39F9C9894918E8A87
83807D7976736F6C
65625F5B5855524E4B4845423F3C393734322F2D292A333B
424A5055595B5C5C5C5B5A5958575554535251504F4E4E4D
4D4D4D4D4E4F5050515253545557585A5C5E606265686C6F
73787E858D959EA7B0BCC8D2DCE2E8EDF2F3F3EEEAE5E1DD
D9D5D1CDC9C5C2BEBAB6B3AFACA8A5A19E9A9793908D8986
837F7C7976726F6C
65625F5C595653504C494744413E3B393634312E2A2C3039
40474D5356595A5A5A595858565553525150504F4E4D4D4C
4C4C4C4D4E4F5050515253555658595B5D5F6264676A6E72
777D8289919AA2ABB5BFCCD3DCE2E9ECF0F1EFEAE6E2DEDA
D6D2CECAC7C3BFBCB8B5B1AEAAA7A3A09D9996928F8C8985
827F7C7975726F6C
6663605C595754514E4B484543403D3B383633312D2E2E37
3F454B50545758585858575655535251504F4E4E4D4C4C4B
4B4B4C4D4E4F50505153545557595B5D5F6164676A6E7276
7B81878E969EA7B0B9C4CED4DCE3E9EBEEEEEAE7E2DFDBD7
D3CFCBC8C4C1BDBAB6B3AFACA8A5A29E9B9894918E8B8885
817E7B7875726F6C
6663605D5A5754524F4C494744423F3D3A383633302E2F36
3D43484D51545657565655555352514F4E4D4D4C4C4B4B4B
4B4B4B4C4E4F505152545556585A5C5F6164676A6D71767A
7F858B929BA3ABB4BDC7CFD5DDE2E7EAEBEAE6E3DFDBD7D4
D0CCC9C5C2BEBBB7B4B1ADAAA7A4A09D9A9793908D8A8784
817E7B7875726F6C
6663605E5B585553504D4B484644413F3D3A383634323235
3B40454B4E5154555555545352504F4E4D4C4C4B4B4B4A4B
4B4B4B4D4E505152535556585A5C5F6164676A6D7175797E
848A90979FA7AEB7C0C9D0D6DDE2E6E8E9E6E2DFDBD8D4D0
CDC9C6C3BFBCB8B5B2AFABA8A5A29F9C9996928F8C898683
807D7A7774716E6C
6663615E5B595654514F4C4A484543413F3C3A3837353436
383D42484C4E525354545351504E4D4C4B4B4B4B4B4B4A4B
4B4B4C4D4F5152535557585A5D5F6264676A6D7174797E83
888E949BA3AAB2BAC3CBD1D7DDE1E3E6E5E2DEDBD7D4D1CD
CAC6C3C0BDB9B6B3B0ADA9A6A3A09D9A9794918E8B888582
807D7A7774716E6B
6664615F5C5A575552504E4B49474543413F3D3B39383737
363A3F45494D50515251514F4E4C4B4B4A4A4A4B4B4B4B4B
4B4C4D4F5052535657585A5C5F6264666A6D7174777D8287
8C93999FA6AEB6BDC5CCD2D7DBDEE2E4E1DDDAD7D4D0CDCA
C7C4C0BDBAB7B4B1AEAAA7A4A19E9C999693908D8A878482
7F7C797674716E6B
6664615F5D5A585653514F4D4B48464443413F3D3C3A3938
37383D41464A4D4E50504F4E4C4B4B4A4A4A4A4B4B4B4C4C
4C4D4E5052535557595A5D5F616465696C7074777B81868B
91979DA3AAB2B9C0C7CDD2D5D9DDE1E0DCD9D6D3D0CDCAC7
C4C1BDBAB7B4B1AEABA8A5A3A09D9A9794918F8C89868481
7E7B797673716E6B
666462605D5B59575452504E4C4A48464443413F3E3D3C3A
39383A3E43484A4D4E4E4D4C4A4A4A494A4A4A4B4B4C4D4D
4E4F50525455575A5B5D5F616365686C6E73777B80858A90
969CA1A8AFB5BDC2C8CCCFD4D8DCDFDBD8D5D2CFCCC9C6C4
C1BEBBB8B5B2AFACA9A6A3A19E9B989693908D8B88858380
7D7B787673706E6B
666462605E5C59575553514F4D4C4A4846454341403F3D3C
3B3A383B4045474A4D4D4C4B494949494A4B4B4B4C4E4E4F
505153545558595C5E60616365686B6E72777B7F84898E94
9AA0A6ACB2B8BEC2C7CACED5D7DDDBD7D4D1CECCC9C6C3C0
BDBAB8B5B2AFACAAA7A4A19F9C9A9794918F8C8A8784827F
7D7A787573706E6B
676462605E5C5A58565452514F4D4B4A4846454342413F3E
3D3C3A393E4345494B4C4B4A4848494A4B4B4B4C4E4F4F51
52535556585A5B5D60626466686B6E71767A7E83888D9298
9EA4A9AEB3B9BDC1C5CAD0D4D8D9D6D3D0CDCBC8C5C2C0BD
BAB7B5B2AFADAAA7A5A29F9D9A989593908D8B888683817E
7C7A777572706D6B
676563615F5D5B5957555452504E4D4B4A48474544434140
3F3D3C3A3C3F4347494A4B4A4847494A4C4C4C4D50505153
5456565A5B5C5E5F636467696B6E7175787D82878C91979C
A1A7ACB0B5B9BCC0C5CBD0D5D7D4D1CFCCC9C7C4C1BFBCBA
B7B4B2AFADAAA7A5A2A09D9B989694918F8C8A878582807E
7B79777472706D6B
676563615F5D5C5A5856555351504E4D4B4A484746444342
413F3E3D3C3C414547494B4A4847494B4C4E4E4F50525355
5759595D5E5F606266676A6C6E7175787C80858A8F959A9F
A4A8ACB0B3B6BCC1C6CCD0D5D2CFCDCAC8C5C3C0BEBBB9B6
B4B1AFACAAA7A5A2A09E9B999794928F8D8B888684817F7D
7B787674726F6D6B
67656362605E5C5B595756545351504E4D4B4A4948464544
4342403F3E3C3E4346494A4A49484A4D4E4F505152545657
5A5B5D5F61636465696A6D6F7174787B8083888D93989CA1
A5A9ABB0B2B6BEC3C8CCD1D1CDCBC8C6C4C1BFBDBAB8B5B3
B1AEACA9A7A5A2A09E9C99979592908E8C89878583807E7C
7A787673716F6D6B
67656462605F5D5B5A585755545251504E4D4C4A49484746
45444341403F3E414447494B4B4B4A4D4F5051535456585A
5C5E6062646768696B6D707174787B7E82868B9094989CA1
A4A8AAAFB3B9C0C4C8CDCDCBC9C6C4C2BFBDBBB9B7B4B2B0
ADABA9A7A4A2A09E9C99979593918F8C8A888684827F7D7B
79777573716F6D6B
67656462615F5E5C5B59585655545251504F4D4C4B4A4948
47464544434140404346494B4C4D4D4E5153545557585B5D
5F616365686A6C6D6F707273777B7D8184888C9094979A9F
A3A6ABB0B5BBC0C5C9CAC8C6C4C1BFBDBBB9B7B5B3B1AEAC
AAA8A6A4A2A09D9B99979593918F8D8B89878482807E7C7A
78767472706E6D6B
6766646361605E5D5C5A59575655545251504F4E4D4C4B4A
49484746454443424345494B4D4F5051525556585A5B5E60
626466686C6D6F7072737376797C7F8285888B8F92959A9E
A3A8ADB3B8BBC0C5C6C4C2C0BFBCBAB9B7B5B3B1AFADABA9
A7A5A3A19F9D9B99979593918F8D8B89878583817F7D7B7A
78767472706E6C6A
6766646362605F5E5C5B5A58575655545352504F4E4D4D4C
4B4A4948484746464546484B4D5053535457595B5D5F6163
64666A6B6E707171737475767A7C7E8183868A8E91969B9F
A4AAAFB5B8BBC0C2C0BEBDBBB9B8B6B4B3B1AFADACAAA8A5
A4A2A09E9C9A98979593918F8D8B8988868482807E7C7B79
77757372706E6C6A
676665636261605E5D5C5B595857565554535251504F4E4D
4D4C4B4B4A4A49484849494A4D51545657585C5E60626465
67696D6E7071727273757577797A7C7F82868A8E92979CA1
A6ABB0B4B9BABCBBBAB9B8B6B5B3B2B0AEADABAAA8A6A4A2
A09F9D9B9A98969492918F8D8B8A88868482817F7D7B7A78
767473716F6E6C6A
676665646261605F5E5D5C5A59585756555454535251504F
4F4E4D4D4C4C4C4B4B4B4C4B4F505458595B5E6061646567
696A6C6D6E7071717374747678797C8082878B9094999EA3
A6ABB0B4B6B5B6B5B4B4B2B1B0AEADACAAA9A7A6A4A3A19F
9D9C9A9897959392908E8D8B8988868483817F7D7C7A7977
757472716F6D6C6A
67666564636261605F5D5C5B5A5958585756555453525251
50504F4F4F4E4E4E4E4E4E4F505154585B5D5F6162646668
696B6C6D6E6F707071737475787A7D8184898C92979A9EA2
A6ABAEB0B0B0B0B0AFAEADACABAAA9A7A6A5A3A2A09F9D9C
9A9997969493918F8E8C8B898786848381807E7C7B797876
757372706F6D6C6A
68666564636261605F5E5D5C5B5B5A595857565655545353
525251515150505050515152535455595A5D606264656768
6A6B6D6D6E6E6F6F71737576787B7F83868B8E94979A9EA2
A5A8A9AAAAAAABAAAAA9A8A7A6A5A4A3A2A19F9E9D9C9A99
9796949392908E8D8B8A888786848281807E7D7B79787775
747371706E6D6B6A
6867666564636261605F5E5D5C5C5B5A5958585756565555
5454535353535252535354545557585A5B5F616264666769
6A6B6D6D6E6F6F70727475787A7C8185878B8F9397999D9F
A0A2A3A4A5A5A5A5A5A4A3A3A2A1A09F9E9D9C9A99989795
949392908F8D8C8A898886858482817F7E7D7B7A78777674
7372716F6E6D6B6A
686766656463626161605F5E5D5D5C5B5A5A595958575756
56555555555554555555565657585A5B5D5F61616465676A
6B6C6D6E6F6F7071727477797B7D8184878B8F939597989A
9C9D9E9F9FA0A0A0A09F9F9E9D9D9C9B9A99989796949392
91908E8D8C8A89888785848382807F7E7D7B7A7877767574
7271706F6D6C6B6A
68676665646463626161605F5E5E5D5C5C5B5A5A59595858
575757575756565757575858595A5B5D5E5F61626465686A
6B6D6E6E6F6F7071727577797B7D8084878A8D8F91939495
9798999A9A9B9B9B9B9A9A9A99989897969594939291908F
8E8D8B8A8988878684838281807E7D7C7B7A787776757473
72716F6E6D6C6B6A
6867666665646363626161605F5F5E5D5D5C5C5B5A5A5A59
595959585858585859595A5A5B5C5D5E5F6062636566686A
6B6C6D6E6F6F7071737577797B7D80828587898B8D8F9091
929394959696969696969695959494939291908F8E8E8D8C
8A8A8987868584838281807F7E7C7B7A7979777675747372
71706F6E6D6C6B6A
68676766656564636362616160605F5F5E5D5D5D5C5C5B5B
5B5A5A5A5A5A5A5A5B5B5B5C5C5D5E5F6062636465666869
6B6C6D6D6E6F707173747677797C7E80828486888A8B8C8D
8E8F9091919292929291919191908F8F8E8D8C8C8B8A8988
8786868584838281807F7E7D7C7A7A797877767574737271
706F6E6D6D6B6A6A
686767666665646463636262616160605F5F5E5E5D5D5D5C
5C5C5C5C5C5C5C5C5C5C5D5D5E5F60616162636465676869
6A6B6C6D6E6F707172737576787A7C7E7F81838586878889
8A8B8B8C8D8D8D8D8D8D8D8D8C8C8B8B8A89898887878685
8483838281807F7E7D7C7C7B7A7978777676757472727170
6F6F6E6D6C6B6A69
6868676666656564646363626262616160605F5F5F5F5E5E
5E5D5D5D5D5D5D5E5E5E5E5F606061626263646566676869
6A6B6C6D6D6E6F707172747576787A7B7D7E808182838585
868787888989898989898988888887878686858584838382
8180807F7E7E7D7C7B7A797878777675757473737171706F
6F6E6D6C6C6B6A69
68686767666665656464646363626262616161606060605F
5F5F5F5F5F5F5F5F5F5F6060616162626364656566676869
6A6B6B6C6D6E6E6F70717274757678797A7B7D7E7F808182
828383848484858585858484848483838282828181807F7F
7E7D7D7C7B7B7A7979787776767574747373727171706F6E
6E6D6D6C6B6A6A69
686867676766666565656464646363636262626261616160
606060606060606161616162626263636465656667676869
6A6A6B6C6D6D6E6E6F7071727374757777797A7B7C7C7D7E
7E7F7F80808080818080808080807F7F7F7E7E7D7D7D7C7C
7B7A7A7979787877767675747473737272717170706F6E6E
6D6D6C6B6B6A6A69
686868676767666666656565656464646363636363626262
626262626262626262626363636364646565666767686869
696A6B6B6C6C6D6E6F6F7071717273747576777878797A7A
7B7B7B7C7C7D7C7D7C7C7C7C7C7C7B7B7B7B7A7A7A797978
7877777776767575747373727272717170706F6F6E6E6D6D
6C6C6B6B6A6A6A69
686868686767676766666666656565656564646464646363
636363636363636363646464646465656666676768686869
696A6A6B6B6C6C6D6D6E6E6F707071727373747575767677
777778787878787878787878787878787777777776767575
75747474737373727271717070706F6F6E6E6E6E6D6D6C6C
6C6B6B6A6A6A6969
686868686867676767676666666666666665656565656565
656565656565656565656565656666666667676768686869
69696A6A6B6B6B6C6C6D6D6D6E6E6F707071717272727373
737474747474747474747474747474747474737373737272
72727171717070706F6F6F6F6E6E6E6D6D6D6D6C6C6C6B6B
6B6B6A6A6A6A6969
686868686868686867676767676767676767676666666666
666666666666666666666666666667676768686868686869
6969696A6A6A6B6B6B6B6B6C6C6C6D6D6E6E6E6E6F6F6F70
70707070707071707070717070707070707070706F6F6F6F
6F6F6E6E6E6E6E6D6D6D6D6D6C6C6C6B6C6B6B6B6B6B6A6A
6A6A6A6969696969
696868686868686868686868686868686868686767676767
676767676767676767676767676868686868686868696869
6969696969696A6A6A6A6A6A6A6A6B6B6B6C6B6B6C6C6C6C
6C6C6C6C6C6D6D6C6C6C6D6C6C6C6C6C6C6C6C6C6C6C6C6C
6C6C6C6B6B6B6B6B6B6B6B6B6B6B6A6A6A6A6A6A6A6A6A6A
6969696969696969
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[57]:=",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`004`3oool206UYJ@l0J6QX101WIfLF06IVIP80IFEU
0P1RHV8306IVIQH0IFEU3`1VIVH806MWI`80J6QX0P1WIfL606QXJ140IfMW101XJ6P406MWIad0J6QX
1P1YJFT206MWI`80IVIV3@1YJFTD06YZJP0306][J`1ZJVX0JVYZ0080Jf][401ZJVX:06][J`0306a/
K01ZJVX0JVYZ0080JFUY101/K6`206][J`80JVYZ0P1YJFTE0?ooo`004`3oool206UYJ@l0J6QX101W
IfLF06IVIP80IFEU0P1RHV8306IVIQH0IFEU3`1VIVH806MWI`80J6QX0P1WIfL606QXJ140IfMW101X
J6P406MWIad0J6QX1P1YJFT206MWI`80IVIV3@1YJFTD06YZJP0306][J`1ZJVX0JVYZ0080Jf][401Z
JVX:06][J`0306a/K01ZJVX0JVYZ0080JFUY101/K6`206][J`80JVYZ0P1YJFTE0?ooo`004`3oool8
06QXJ0H0IfMW1@1VIVH206EUI@X0I6AT301SHf<2069RHP80GemO0`1RHV8<065QH@X0HV9R101SHf<;
06ATI0H0IFEU201VIVH206MWIa<0IVIV101WIfL406IVIP80IfMW1P1VIVH?06MWI`P0J6QX101YJFT2
06MWI`80IVIV0P1XJ6P706UYJ@P0JVYZ201[Jf/206a/K080Jf][5@1/K6`406e]K@/0KVi^101/K6`2
06e]K@80KVi^0P1]KFd206][J`80JVYZ5@3oool001<0oooo201XJ6P606MWI`D0IVIV0P1UIFD:06AT
I0`0Hf=S0P1RHV8205mOG`<0HV9R301QHF4:069RHP@0Hf=S2`1TI6@606EUI@P0IVIV0P1WIfLC06IV
IP@0IfMW101VIVH206MWI`H0IVIV3`1WIfL806QXJ0@0JFUY0P1WIfL206IVIP80J6QX1`1YJFT806YZ
JPP0Jf][0P1/K6`206][JaD0K6a/101]KFd;06i^KP@0K6a/0P1]KFd206i^KP80KFe]0P1[Jf/206YZ
JQD0oooo000C0?ooo`H0J6QX101WIfL406IVIP<0IFEU0P1TI6@406=SH`80HV9R201QHF4:061PH080
GemO0`1MGEd205mOG`80GUiN201MGEd805iNGPH0GemO0P1PH602065QH@L0HV9R101SHf<806ATI1T0
IFEU2P1VIVH606EUI@/0IVIV201WIfL:06QXJ080IfMW0`1XJ6P406UYJ@@0JVYZ1P1[Jf/606a/K0X0
KFe]4@1^KVh206m_K`H0L71`101aLG42071`L00306m_K`1^KVh0KVi^0080KVi^0P1_Kfl2071`L080
KVi^0P1/K6`206YZJQD0oooo000C0?ooo`H0J6QX101WIfL406IVIP<0IFEU0P1TI6@406=SH`80HV9R
201QHF4:061PH080GemO0`1MGEd205mOG`80GUiN201MGEd805iNGPH0GemO0P1PH602065QH@L0HV9R
101SHf<806ATI1T0IFEU2P1VIVH606EUI@/0IVIV201WIfL:06QXJ080IfMW0`1XJ6P406UYJ@@0JVYZ
1P1[Jf/606a/K0X0KFe]4@1^KVh206m_K`H0L71`101aLG42071`L00306m_K`1^KVh0KVi^0080KVi^
0P1_Kfl2071`L080KVi^0P1/K6`206YZJQD0oooo000C0?ooo`@0J6QX101WIfL406IVIP80IFEU0`1T
I6@206=SH`80HV9R0P1QHF44061PH0@0GemO1P1NGUh605eMG@@0G5aL00<0FEUI05]KF`1KFe/00P1K
Fe/205YJFPH0FEUI1P1JFUX405]KF`@0G5aL0P1MGEd205iNGP<0GemO101PH602065QH@@0HV9R1P1S
Hf<G06ATI0H0IFEU101TI6@206EUI@H0I6AT2@1UIFD606IVIPP0IfMW2P1XJ6P00`1WIfL0JFUY06UY
J@0406YZJPH0Jf][101/K6`406e]K@H0KVi^1@1_Kfl>071`L080LG5a0P1bLW8807=cL`@0LW9b00<0
LG5a071`L01`L700101`L702075aL@80L71`0P1]KFd206][JaD0oooo000C0?ooo`@0J6QX101WIfL4
06IVIP80IFEU0`1TI6@206=SH`80HV9R0P1QHF44061PH0@0GemO1P1NGUh605eMG@@0G5aL00<0FEUI
05]KF`1KFe/00P1KFe/205YJFPH0FEUI1P1JFUX405]KF`@0G5aL0P1MGEd205iNGP<0GemO101PH602
065QH@@0HV9R1P1SHf<G06ATI0H0IFEU101TI6@206EUI@H0I6AT2@1UIFD606IVIPP0IfMW2P1XJ6P0
0`1WIfL0JFUY06UYJ@0406YZJPH0Jf][101/K6`406e]K@H0KVi^1@1_Kfl>071`L080LG5a0P1bLW88
07=cL`@0LW9b00<0LG5a071`L01`L700101`L702075aL@80L71`0P1]KFd206][JaD0oooo000C0?oo
o`@0J6QX0P1WIfL406IVIP80IFEU0P1TI6@306=SH`80HV9R0P1QHF42061PH080GemO0P1NGUh205eM
G@@0G5aL1P1KFe/605YJFP80FEUI00<0EeMG05IFEP1FEUH00P1GEeL405IFEP@0EEEE101FEUH405MG
E`@0F5QH0P1IFET205YJFP80Fe]K00<0G5aL05eMG@1MGEd00P1NGUh405mOG`@0HF5Q201RHV8806=S
H`80HV9R2`1SHf<406ATI0H0Hf=S0P1TI6@606=SH`L0I6AT1P1UIFD606IVIPP0IfMW101XJ6P206UY
J@0306QXJ01WIfL0IfMW0080JVYZ1P1[Jf/406a/K0@0KFe]0P1^KVh606m_K`@0L71`0`1aLG4<079b
LP80Lg=c0P1dM7@607IfMPH0M7Ad00<0LW9b07=cL`1cLg<00P1aLG42079bLP80Lg=c0P1aLG4206i^
KP80Jf][5@3oool001<0oooo101XJ6P206MWI`@0IVIV0P1UIFD206ATI0<0Hf=S0P1RHV82065QH@80
H61P0P1OGel205iNGP80GEeM101LG5`605]KF`H0FUYJ0P1IFET00`1GEeL0EUIF05IFEP0205MGE`@0
EUIF101EEED405IFEP@0EeMG101HF5P205UIF@80FUYJ0P1KFe/00`1LG5`0GEeM05eMG@0205iNGP@0
GemO101QHF48069RHPP0Hf=S0P1RHV8;06=SH`@0I6AT1P1SHf<206ATI0H0Hf=S1`1TI6@606EUI@H0
IVIV201WIfL406QXJ080JFUY00<0J6QX06MWI`1WIfL00P1ZJVX606][J`@0K6a/101]KFd206i^KPH0
Kfm_101`L703075aL@`0LW9b0P1cLg<207AdM0H0MWIf1P1dM7@00`1bLW80Lg=c07=cL`02075aL@80
LW9b0P1cLg<2075aL@80KVi^0P1[Jf/E0?ooo`004`3oool206QXJ0@0IfMW0P1VIVH206EUI@80I6AT
0P1SHf<3069RHP80HF5Q0P1PH60205mOG`80GUiN0P1MGEd205aLG080Fe]K0P1JFUX205UIF@H0F5QH
101GEeL205IFEP0305EEE@1CDe<0De=C0080De=C101BDU86055AD@80DU9B101CDe<205ADE080EEEE
0P1FEUH205MGE`80F5QH00<0FUYJ05]KF`1KFe/00P1LG5`205eMG@80GUiN101PH60B065QHAl0HV9R
1@1SHf<606ATI0@0IFEU1P1VIVH406MWI`@0J6QX1@1YJFT206YZJP@0Jf][1P1/K6`206e]K@80KVi^
0P1_Kfl6071`L0@0LG5a0`1bLW8607=cL`@0M7Ad0P1eMGD207IfMP80MgMg101iNGT207MgM`@0MWIf
1@1eMGD207=cL`@0M7Ad0P1aLG4206i^KP80Jf][5@3oool001<0oooo0P1XJ6P406MWI`80IVIV0P1U
IFD206ATI080Hf=S0`1RHV82065QH@80H61P0P1OGel205iNGP80GEeM0P1LG5`205]KF`80FUYJ0P1I
FET605QHF0@0EeMG0P1FEUH00`1EEED0De=C05=CD`0205=CD`@0DU9B1P1ADE42059BDP@0De=C0P1D
E5@205EEE@80EUIF0P1GEeL205QHF00305YJFP1KFe/0Fe]K0080G5aL0P1MGEd205iNGP@0H61P4P1Q
HF4O069RHPD0Hf=S1P1TI6@406EUI@H0IVIV101WIfL406QXJ0D0JFUY0P1ZJVX406][J`H0K6a/0P1]
KFd206i^KP80Kfm_1P1`L704075aL@<0LW9b1P1cLg<407AdM080MGEe0P1fMWH207MgM`@0NGUi0P1g
MgL407IfMPD0MGEe0P1cLg<407AdM080LG5a0P1^KVh206][JaD0oooo000C0?ooo`80J6QX0P1WIfL2
06IVIP80IFEU101TI6@4069RHP<0H61P0P1NGUh405eMG@80Fe]K0P1JFUX205UIF@80F5QH0P1GEeL2
05IFEP@0EEEE101DE5@205=CD`03059BDP1@D500D51@0080Cdm?0P1>CTh804e=C@@0CTi>0P1?Cdl2
051@D080DE5A0P1CDe<205ADE080EUIF00<0EeMG05UIF@1IFET00P1JFUX205aLG080GEeM101OGelC
061PH1h0HF5Q1@1RHV8406=SH`H0I6AT101UIFD206IVIP@0IfMW101XJ6P306UYJ@@0JVYZ101[Jf/4
06a/K080KFe]0P1^KVh406m_K`80L71`101aLG42079bLP<0Lg=c101dM7@607EeM@80MWIf0P1gMgL2
07QhN080NWYj0P1lO7`207]kN`80NGUi1P1hN7P307MgM`80MGEe0P1fMWH207EeM@80LW9b0P1_Kfl2
06][JaD0oooo000C0?ooo`80J6QX0P1WIfL206IVIP80IFEU101TI6@4069RHP<0H61P0P1NGUh405eM
G@80Fe]K0P1JFUX205UIF@80F5QH0P1GEeL205IFEP@0EEEE101DE5@205=CD`03059BDP1@D500D51@
0080Cdm?0P1>CTh804e=C@@0CTi>0P1?Cdl2051@D080DE5A0P1CDe<205ADE080EUIF00<0EeMG05UI
F@1IFET00P1JFUX205aLG080GEeM101OGelC061PH1h0HF5Q1@1RHV8406=SH`H0I6AT101UIFD206IV
IP@0IfMW101XJ6P306UYJ@@0JVYZ101[Jf/406a/K080KFe]0P1^KVh406m_K`80L71`101aLG42079b
LP<0Lg=c101dM7@607EeM@80MWIf0P1gMgL207QhN080NWYj0P1lO7`207]kN`80NGUi1P1hN7P307Mg
M`80MGEe0P1fMWH207EeM@80LW9b0P1_Kfl206][JaD0oooo000C0?ooo`80J6QX0P1WIfL206IVIP80
IFEU0P1TI6@206=SH`@0HF5Q00<0GemO05iNGP1NGUh00P1MGEd205aLG080Fe]K0P1JFUX205UIF@80
F5QH0P1FEUH205EEE@80E5AD0P1CDe<4059BDP80DE5A0P1@D5000`1?Cdl0CDe=04e=C@0204];B`80
BTY:0P18B4P204U9B@80B4Q81019BDT204Y:BP80Bd];0P1=CDd204i>CP80Cdm?0P1ADE4205=CD`03
05EEE@1GEeL0EeMG0080FEUI0P1JFUX205aLG080GEeM0P1NGUhC05mOGah0H61P0`1QHF46069RHP@0
Hf=S101TI6@206EUI@@0IVIV0P1WIfL406QXJ0<0JFUY0P1ZJVX606][J`@0K6a/0P1]KFd206i^KP80
Kfm_0P1`L702075aL@@0LW9b0P1cLg<207AdM0<0MGEe101fMWH207MgM`80N7Qh0P1iNGT207YjNP80
O7al101nOWh207alO0H0Ng]k0`1jNWX207UiN@@0N7Qh0P1fMWH2079bLP80Kfm_0P1/K6`E0?ooo`00
4`3oool206QXJ080IfMW0P1VIVH206EUI@80I6AT0P1SHf<4065QH@0305mOG`1NGUh0GUiN0080GEeM
0P1LG5`205]KF`80FUYJ0P1IFET205QHF080EUIF0P1EEED205ADE080De=C101BDU82055AD@80D51@
00<0Cdm?04e=C@1=CDd00P1;Bd/204Y:BP80B4Q80P19BDT204Q8B0@0BDU90P1:BTX204];B`80CDe=
0P1>CTh204m?C`80DE5A0P1CDe<00`1EEED0EeMG05MGE`0205UIF@80FUYJ0P1LG5`205eMG@80GUiN
4`1OGelN061PH0<0HF5Q1P1RHV8406=SH`@0I6AT0P1UIFD406IVIP80IfMW101XJ6P306UYJ@80JVYZ
1P1[Jf/406a/K080KFe]0P1^KVh206m_K`80L71`0P1aLG44079bLP80Lg=c0P1dM7@307EeM@@0MWIf
0P1gMgL207QhN080NGUi0P1jNWX207alO0@0OWin0P1lO7`607]kN`<0NWYj0P1iNGT407QhN080MWIf
0P1bLW8206m_K`80K6a/5@3oool001<0oooo0P1XJ6P206MWI`80IVIV0P1UIFD206=SH`80HV9R0P1Q
HF42061PH00305iNGP1MGEd0GEeM0080G5aL0P1KFe/205YJFP80F5QH0P1GEeL205IFEP80EEEE0P1C
De<2059BDP80DE5A0P1@D50204m?C`80CTi>0P1=CDd00`1<C4`0BTY:04Y:BP0204Q8B080ATI62014
A4@204E5A@80ATI60P17AdL204U9B@80Bd];0P1<C4`204m?C`80DE5A00<0De=C05IFEP1FEUH00P1H
F5P205UIF@80FUYJ0P1LG5`205eMG@80GUiN1P1OGel;05iNGQ00GemO0P1NGUh405mOG`80GUiN1P1O
Gel3061PH0@0HF5Q101RHV8406=SH`80I6AT0P1UIFD206IVIP@0IfMW101XJ6P306UYJ@80JVYZ1P1[
Jf/406a/K080KFe]0P1^KVh2071`L080LG5a0P1bLW8407=cL`80M7Ad0P1eMGD307IfMP80MgMg0P1h
N7P207UiN@80Ng]k0P1mOGd207inOP80Ogmo1020P80207moO`H0OWin0P1mOGd00`1lO7`0NWYj07Yj
NP0407YjNP80MgMg0P1cLg<2071`L080K6a/5@3oool001<0oooo0P1XJ6P206IVIP80IFEU0P1TI6@2
06=SH`80HF5Q0P1PH60205mOG`0305eMG@1LG5`0G5aL0080Fe]K0P1IFET205QHF080EeMG0P1FEUH2
05ADE080De=C0P1ADE42051@D080Cdm?0P1=CDd204a<C080Bd];0P19BDT00`18B4P0ATI604I6AP02
04A4A080@d=30P11@D4203lo?`@0?Shn0P10@4020451@@80@d=30P15ADD204M7A`80BTY:0P1<C4`2
04m?C`03055AD@1DE5@0E5AD0080EUIF0P1HF5P205UIF@80Fe]K0P1LG5`205eMG@P0GUiN2@1MGEdJ
05iNGPD0GemO0P1PH604065QH@@0HV9R0P1SHf<406ATI080IFEU0P1VIVH406MWI`@0J6QX0`1YJFT2
06YZJP@0Jf][0P1/K6`406e]K@80KVi^101_Kfl2079bLP80Lg=c101dM7@207EeM@80MWIf0`1gMgL2
07UiN@80Ng]k0P1mOGd20820P080PH611022PX8408>3P`80PX:21021PH440820P00307inOP1lO7`0
O7al0080OGem0P1jNWX207QhN080M7Ad0P1`L70206a/K1D0oooo000C0?ooo`80J6QX0P1VIVH206EU
I@80I6AT0P1SHf<2065QH@80H61P0P1OGel00`1MGEd0G5aL05aLG00205]KF`80FEUI0P1HF5P205MG
E`80EUIF0P1DE5@205=CD`80DE5A0P1@D50204m?C`80CDe=0P1<C4`204];B`80BDU900<0B4Q804I6
AP16ATH00P14A4@204=3@`80@D510P0o?cl403hn?P80@4100P11@D4204=3@`80ADE50P17AdL204Y:
BP80C4a<0P1?Cdl00`1ADE40E5AD05ADE00205IFEP80F5QH0P1IFET205]KF`80G5aL0P1MGEd805iN
GPT0GEeM6P1NGUh505mOG`80H61P101QHF44069RHP80Hf=S101TI6@206EUI@80IVIV101WIfL406QX
J0<0JFUY0P1ZJVX406][J`80K6a/101]KFd206i^KP@0Kfm_0P1bLW8207=cL`@0M7Ad0P1eMGD207If
MP<0MgMg0P1iNGT207]kN`80OGem0P20P8020861P@@0PX:21023Ph<208:2PP@0PH611020P8000`1n
OWh0O7al07alO00207emO@80NWYj0P1hN7P207AdM080L71`0P1/K6`E0?ooo`004`3oool206MWI`80
IVIV0P1UIFD206=SH`80HV9R0P1QHF4205mOG`80GUiN00<0G5aL05]KF`1KFe/00P1JFUX205QHF080
EeMG0P1EEED205ADE080DU9B0P1ADE42051@D080CTi>0P1=CDd204];B`80BTY:0P18B4P204I6AP03
04E5A@13@d<0@d=30080@D510P0o?cl203dm?@80>c/k100i>CT403`l?080?Shn0P11@D4204A4A080
AdM70P19BDT204e=C@0304m?C`1BDU80DU9B0080EEEE0P1GEeL205QHF080FUYJ0P1KFe/<05eMG@T0
G5aL301MGEd605aLG0H0GEeM1@1NGUh205mOG`@0H61P0P1QHF44069RHP80Hf=S0P1TI6@206EUI@@0
IVIV0P1WIfL406QXJ0<0JFUY101[Jf/206a/K0@0KFe]0P1^KVh406m_K`80L71`0P1dM7@207=cL`80
M7Ad0P1eMGD207IfMP80MgMg00<0NGUi07]kN`1kNg/00P1mOGd20820P080PX:20P24Q8@408F5Q@80
QXJ60P27QhL408F5Q@80Q8B40P23Ph<208B4Q080Ph>300<0P82007moO`1oOgl00P1nOWh207alO080
N7Qh0P1dM7@2075aL@80KFe]5@3oool001<0oooo0P1WIfL206IVIP80IFEU0P1SHf<2069RHP80HF5Q
0P1OGel205iNGP0305aLG01KFe/0Fe]K0080FUYJ0P1HF5P205MGE`80EEEE0P1DE5@2059BDP80DE5A
0P1@D50204i>CP80CDe=0P1;Bd/204Y:BP80B4Q80P16ATH00`15ADD0@d=304=3@`020451@@80?clo
0P0m?Cd203/k>`@0>CTi100l?3`203hn?P80@D510P14A4@204M7A`80BDU90P1=CDd00`1?Cdl0DU9B
059BDP0205EEE@80EeMG0P1HF5P205YJFP80Fe]K301MGEd905aLG0`0GEeM1P1LG5`605eMG@D0GUiN
0P1OGel4061PH080HF5Q101RHV8206=SH`80I6AT0P1UIFD406IVIP80IfMW101XJ6P306UYJ@@0Jf][
0P1/K6`406e]K@80KVi^101_Kfl2071`L080M7Ad0P1cLg<207AdM080MGEe0P1fMWH207MgM`0307Ui
N@1kNg/0Ng]k0080OGem0P20P80208:2PP80Q8B41025QHD208J6QP80QhN71025QHD208B4Q080Ph>3
0P24Q8@208>3P`030820P01oOgl0Ogmo0080OWin0P1lO7`207QhN080M7Ad0P1aLG4206e]KAD0oooo
000C0?ooo`80IfMW0P1VIVH206EUI@80Hf=S0P1QHF42061PH080GemO0P1MGEd00`1LG5`0FUYJ05YJ
FP0205UIF@80EeMG0P1FEUH205ADE080DU9B0P1ADE4204m?C`80CTi>0P1<C4`204Y:BP80BDU90P17
AdL204E5A@80@d=300<0@D5103lo?`0o?cl00P0n?Sh203/k>`80>CTi0P0g=cL203@d=080=CDe0P0f
=SH203Ph>080>SXj0P0l?3`20410@080A4A40P17AdL204];B`0304e=C@1ADE40DE5A0080E5AD0P1F
EUH205QHF080FEUI0P1KFe/>05aLG0L0Fe]K2P1LG5`805]KF`H0G5aL1@1MGEd205iNGP@0GemO0P1P
H602065QH@80HV9R101SHf<406EUI@80IVIV101WIfL206QXJ0<0JFUY101[Jf/206a/K080KFe]0P1^
KVh406m_K`80L71`0P1bLW8407AdM080MGEe0P1gMgL207QhN080NWYj00<0OGem07moO`1oOgl00P21
PH4208B4Q080QXJ60P27QhL408V9R@@0RXZ:0P27QhL208R8R080QhN70P26QXH208N7Q`80QHF500<0
Ph>308:2PP22PX800P1oOgl207emO@80NGUi0P1eMGD2075aL@80KFe]5@3oool001<0oooo0P1WIfL2
06IVIP80IFEU0P1SHf<2065QH@80H61P0P1OGel205eMG@0305aLG01JFUX0FUYJ0080FEUI0P1GEeL2
05IFEP80E5AD0P1BDU82055AD@80Cdm?0P1>CTh204a<C080BTY:0P19BDT204M7A`80ADE50P13@d<0
0`11@D40?clo03lo?`0203hn?P80>c/k0P0i>CT203Lg=`80=3@d0P0e=CD203Hf=P80>3Ph0P0j>SX2
03`l?080@4100P14A4@204M7A`80Bd];00<0CDe=055AD@1ADE400P1DE5@205IFEP80F5QH0P1IFET2
05]KF`h0G5aL1`1KFe/:05aLG0P0Fe]K1P1LG5`505eMG@80GUiN101OGel2061PH080HF5Q0P1RHV84
06=SH`@0IFEU0P1VIVH406MWI`80J6QX0`1YJFT406][J`80K6a/0P1]KFd206i^KP@0Kfm_0P1`L702
079bLP@0M7Ad0P1eMGD207MgM`80N7Qh0P1jNWX00`1mOGd0Ogmo07moO`020861P@80Q8B40P26QXH2
08N7Q`@0RHV9102:RXX208N7Q`80R8R80P27QhL208J6QP80QhN70P25QHD00`23Ph<0PX:208:2PP02
07moO`80OGem0P1iNGT207EeM@80LG5a0P1]KFdE0?ooo`004`3oool206MWI`80IVIV0P1TI6@2069R
HP80HF5Q0P1PH60205iNGP80G5aL00<0Fe]K05UIF@1IFET00P1GEeL205IFEP80E5AD0P1BDU82055A
D@80Cdm?0P1=CDd204];B`80BTY:0P18B4P204I6AP80A4A40P12@T820410@00303hn?P0l?3`0?3`l
0080>SXj0P0h>3P203Hf=P80<c<c100a<C42030`<080<S8b0P0e=CD203Lg=`80?3`l0P11@D4204E5
A@80BDU900<0C4a<051@D01@D5000P1BDU8205EEE@80EeMG0P1IFET205YJFPX0G5aL1P1KFe/505YJ
FP@0Fe]K401JFUX405]KF`D0G5aL0P1MGEd405iNGP80GemO0P1PH602065QH@80HV9R0P1SHf<206AT
I080IFEU101VIVH206MWI`80J6QX0`1YJFT206YZJP80Jf][0P1/K6`206e]K@80KVi^0P1_Kfl2071`
L080LG5a0P1bLW8207AdM080MGEe0P1gMgL207UiN@80Ng]k0P1oOgl00`22PX80Ph>308>3P`0208J6
QP80R8R80P2:RXX208^;R`80S8b<1P2=SHd208Z:RP@0Rh^;0P29RHT208Z:RP80QhN700<0QHF508B4
Q024Q8@00P21PH4207emO@80NGUi0P1eMGD2075aL@80KFe]5@3oool001<0oooo0P1WIfL206IVIP80
I6AT0P1RHV82065QH@80H61P0P1NGUh205aLG00305]KF`1IFET0FEUI0080EeMG0P1FEUH205ADE080
DU9B0P1ADE4204m?C`80CDe=0P1;Bd/204Y:BP80B4Q80P16ATH204A4A080@T920P10@4000`0n?Sh0
?3`l03`l?00203Xj>P80>3Ph0P0f=SH203<c<`@0<C4a0P0`<302038b<P80=CDe0P0g=cL203`l?080
@D510P15ADD204U9B@0304a<C01@D500D51@0080DU9B0P1EEED205MGE`80FEUI0P1JFUX:05aLG0H0
Fe]K1@1JFUX405]KFa00FUYJ101KFe/505aLG080GEeM101NGUh205mOG`80H61P0P1QHF42069RHP80
Hf=S0P1TI6@206EUI@@0IVIV0P1WIfL206QXJ0<0JFUY0P1ZJVX206][J`80K6a/0P1]KFd206i^KP80
Kfm_0P1`L702075aL@80LW9b0P1dM7@207EeM@80MgMg0P1iNGT207]kN`80Ogmo00<0PX:208>3P`23
Ph<00P26QXH208R8R080RXZ:0P2;Rh/208b<S0H0SHf=0P2:RXX408^;R`80RHV90P2:RXX208N7Q`03
08F5Q@24Q8@0Q8B40080PH610P1mOGd207UiN@80MGEe0P1aLG4206e]KAD0oooo000C0?ooo`80IfMW
0P1UIFD206ATI080HV9R0P1PH60205mOG`80GEeM0P1LG5`00`1JFUX0F5QH05QHF00205IFEP80EEEE
0P1CDe<2055AD@80Cdm?0P1=CDd204];B`80BDU90P17AdL204I6AP80A4A40P12@T820410@080?Cdm
00<0>c/k03Ti>@0i>CT00P0g=cL203De=@80<S8b0P0`<30202h^;P80;Bd]100/;2`2030`<080<S8b
0P0g=cL203dm?@80@d=30P17AdL00`1;Bd/0Cdm?04m?C`02059BDP80EEEE0P1GEeL205QHF080FUYJ
301KFe/705YJFQP0FEUI101JFUX305]KF`@0G5aL0P1MGEd205iNGP80GemO0P1PH602065QH@80HV9R
0P1TI6@406EUI@80IVIV0P1WIfL206QXJ0<0JFUY0P1ZJVX206][J`@0KFe]0P1^KVh2071`L080LG5a
0P1bLW8207AdM080MGEe0P1gMgL207YjNP80OGem0P21PH4208>3P`0308J6QP27QhL0QhN70080RXZ:
0P2<S8`208f=S@80Shn?1P2@T90208n?S`H0SXj>0P2=SHd208b<S080RHV900<0R8R808J6QP26QXH0
0P22PX8207inOP80NWYj0P1fMWH2075aL@80KFe]5@3oool001<0oooo0P1WIfL206EUI@80I6AT0P1R
HV82061PH080GemO0P1MGEd205aLG00305YJFP1HF5P0F5QH0080EUIF0P1EEED205=CD`80DE5A0P1?
Cdl204e=C@80Bd];0P19BDT204M7A`80ATI60P14A4@20492@P80@4100P0m?Cd00`0k>c/0>CTi03Ti
>@0203Lg=`80=CDe0P0b<S82030`<080;Rh^0P0];Bd402`/;080<30`0P0b<S8203Lg=`80?Cdm0P13
@d<204M7A`0304];B`1?Cdl0Cdm?0080DU9B0P1EEED205MGE`80F5QH0P1JFUX<05]KF`L0FUYJ601I
FET405YJFP<0Fe]K101LG5`205eMG@80GUiN0P1OGel2061PH080HF5Q0P1RHV8206ATI0@0IFEU0P1V
IVH206MWI`80J6QX0`1YJFT206YZJP80Jf][101]KFd206i^KP80L71`0P1aLG42079bLP80M7Ad0P1e
MGD207MgM`80NWYj0P1mOGd20861P@80Ph>300<0QXJ608N7Q`27QhL00P2:RXX208b<S080SHf=0P2?
Shl6092@T080Shn?1P2>SXh208f=S@80S8b<0P29RHT00`28R8P0QXJ608J6QP0208:2PP80OWin0P1j
NWX207IfMP80LG5a0P1]KFdE0?ooo`004`3oool206MWI`80IFEU0P1SHf<2069RHP80H61P0P1NGUh2
05aLG080Fe]K00<0FEUI05MGE`1GEeL00P1EEED205=CD`80DE5A0P1?Cdl204e=C@80C4a<0P19BDT2
04M7A`80ADE50P13@d<20492@P80?clo0P0m?Cd203/k>`0303Ph>00f=SH0=SHf0080=3@d0P0b<S82
02l_;`80;Bd]0P0Z:RX202TY:@@09bLW0P0Z:RX202h^;P80<S8b0P0h>3P20410@080ATI600<0Bd];
04i>CP1>CTh00P1BDU8205EEE@80EeMG0P1HF5P205YJFPP0Fe]K1P1JFUX505UIFAX0F5QH0P1IFET3
05YJFP80Fe]K0P1LG5`205eMG@@0GUiN0P1OGel2065QH@80HV9R0P1SHf<206ATI080IFEU0P1VIVH2
06MWI`80J6QX0P1YJFT306YZJP80K6a/0P1]KFd206i^KP80Kfm_0P1aLG42079bLP80M7Ad0P1fMWH2
07QhN080Ng]k0P20P80208>3P`80QHF50P28R8P00`2:RXX0Rh^;08^;R`0208f=S@80Shn?0P2ATI42
09:BTPH0Ti>C1P2BTY82096AT@80T92@0P2=SHd208b<S00308Z:RP27QhL0QhN70080PX:20P1nOWh2
07YjNP80MWIf0P1bLW8206e]KAD0oooo000C0?ooo`80IfMW0P1UIFD206=SH`80HV9R0P1PH60205iN
GP80G5aL0P1KFe/00`1IFET0EeMG05MGE`0205EEE@80De=C0P1ADE4204m?C`80CDe=0P1<C4`204U9
B@80AdM70P15ADD204=3@`80@T920P0o?cl203dm?@80>c/k00<0>3Ph03Hf=P0f=SH00P0d=3@2038b
<P80;bl_0P0];Bd202XZ:P80:BTY100W9bL202XZ:P80;Rh^0P0b<S8203Ph>080@4100P16ATH00`1;
Bd/0CTi>04i>CP02059BDP80EEEE0P1GEeL205QHF080FUYJ201KFe/605YJFPD0FEUI6P1HF5P205UI
F@<0FUYJ0P1KFe/205aLG080GEeM101NGUh205mOG`80HF5Q0P1RHV8206=SH`80I6AT0P1UIFD206IV
IP80IfMW0P1XJ6P206UYJ@<0JVYZ0P1/K6`206e]K@80KVi^0P1_Kfl2075aL@80LW9b0P1dM7@207If
MP80N7Qh0P1kNg/20820P080Ph>30P25QHD208R8R00308Z:RP2;Rh/0Rh^;0080SHf=0P2?Shl2096A
T@80TY:B1P2CTi<609:BTP80TI6A0P2@T90208f=S@80S8b<00<0RXZ:08N7Q`27QhL00P22PX8207in
OP80NWYj0P1fMWH2079bLP80KFe]5@3oool001<0oooo0P1WIfL206EUI@80Hf=S0P1QHF4205mOG`80
GUiN0P1LG5`205YJFP0305QHF01FEUH0EUIF0080E5AD0P1BDU82051@D080CTi>0P1<C4`204Y:BP80
B4Q80P15ADD204A4A080@D510P0o?cl203dm?@80>c/k0P0h>3P00`0f=SH0<c<c03<c<`02034a<@80
;Rh^0P0/;2`202TY:@809bLW0P0V9RH402<S8`809BDU0P0Z:RX202h^;P80=3@d0P0k>c/204A4A003
04];B`1>CTh0CTi>0080DU9B0P1EEED205MGE`80FEUI0P1JFUX605]KF`@0FUYJ1P1IFET305QHF1X0
EeMG101HF5P00`1IFET0FUYJ05YJFP0205]KF`80G5aL101MGEd205mOG`80H61P0P1QHF4206=SH`80
I6AT0P1UIFD206IVIP80IfMW0P1XJ6P206UYJ@<0JVYZ0P1/K6`206e]K@80KVi^0P1`L702079bLP80
M7Ad0P1fMWH207QhN080O7al0P21PH4208F5Q@80QhN70P28R8P208b<S00308j>SP2?Shl0Shn?0080
TI6A0P2BTY8209>CT`80U9BD2P2FUYH409BDU080TI6A0P2?Shl208j>SP0308^;R`27QhL0QhN70080
Ph>30P1oOgl207]kN`80MWIf0P1bLW8206e]KAD0oooo000C0?ooo`80IfMW0P1UIFD206=SH`80HF5Q
0P1OGel205iNGP80G5aL0P1JFUX00`1HF5P0EUIF05IFEP0205ADE080DU9B0P1@D50204i>CP80C4a<
0P1:BTX204Q8B080ADE50P14A4@20451@@80?clo0P0m?Cd203/k>`80>3Ph00<0=SHf03<c<`0c<c<0
0P0a<C4202h^;P80;2`/0P0Y:BT202LW9`809RHV100S8b<202DU9@80:RXZ0P0^;Rh203@d=080>c/k
0P14A4@00`1;Bd/0CTi>04i>CP02059BDP80EEEE0P1GEeL205UIF@80FUYJ1P1KFe/405YJFPH0FEUI
0`1HF5PJ05MGE`@0F5QH00<0FEUI05YJFP1JFUX00P1KFe/205aLG0@0GEeM0P1OGel2061PH080HF5Q
0P1SHf<206ATI080IFEU0P1VIVH206MWI`80J6QX0P1YJFT306YZJP80K6a/0P1]KFd206i^KP80L71`
0P1bLW8207AdM080MWIf0P1hN7P207alO080PH610P25QHD208N7Q`80R8R80P2<S8`00`2>SXh0Shn?
08n?S`02096AT@80TY:B0P2CTi<209BDU0X0UYJF102DU9@2096AT@80Shn?0P2>SXh00`2;Rh/0QhN7
08N7Q`0208>3P`80Ogmo0P1kNg/207IfMP80LW9b0P1]KFdE0?ooo`004`3oool206MWI`80IFEU0P1S
Hf<2065QH@80GemO0P1MGEd205]KF`80FEUI00<0EeMG05EEE@1EEED00P1CDe<2055AD@80CTi>0P1<
C4`204Y:BP80B4Q80P16ATH204A4A080@T920P0o?cl203dm?@80>c/k0P0h>3P203Hf=P0303<c<`0a
<C40<C4a0080;Rh^0P0[:b/202TY:@809RHV0P0T92@2028R8P80820P0P0O7al2024Q8@809RHV0P0[
:b/2034a<@80>3Ph0P10@4000`19BDT0Cdm?04m?C`0205=CD`80EUIF0P1HF5P205UIF@H0Fe]K1P1J
FUX405UIF@@0F5QH00<0EeMG05IFEP1FEUH06P1FEUH205MGE`0305QHF01IFET0FEUI00@0FUYJ0P1L
G5`205eMG@80GUiN0P1OGel2065QH@80HV9R0P1TI6@406EUI@80IfMW0P1XJ6P206UYJ@0306YZJP1[
Jf/0Jf][0080K6a/0P1^KVh206m_K`80LW9b0P1dM7@207IfMP80NGUi0P1mOGd208:2PP80QhN70P29
RHT208^;R`80SHf=0P2@T9000`2BTY80Ti>C09>CT`0209BDU080UIFE0P2FUYH209NGU`X0VIVI0P2G
UiL209JFUP80Ti>C0P2ATI4208n?S`0308b<S027QhL0QhN70080Q8B40P20P80207]kN`80MWIf0P1b
LW8206e]KAD0oooo000C0?ooo`80IfMW0P1UIFD206=SH`80HF5Q0P1OGel205eMG@80Fe]K0P1IFET0
0`1GEeL0EEEE05EEE@0205=CD`80DE5A0P1>CTh204a<C080BTY:0P18B4P204I6AP80A4A40P12@T82
03lo?`80?Cdm0P0k>c/203Ph>080=SHf00<0<c<c034a<@0a<C400P0^;Rh202/[:`80:BTY0P0V9RH2
02@T90808R8R0P0P820201lO7`808B4Q0P0V9RH202/[:`80<C4a0P0h>3P20410@00304U9B@1?Cdl0
Cdm?0080De=C0P1FEUH205QHF080FEUI1P1KFe/605YJFP@0FEUI101HF5P00`1GEeL0EUIF05IFEP0J
05IFEP80EeMG00<0F5QH05UIF@1IFET0101JFUX205aLG080GEeM0P1NGUh205mOG`80HF5Q0P1RHV82
06ATI0@0IFEU0P1WIfL206QXJ080JFUY00<0JVYZ06][J`1[Jf/00P1/K6`206i^KP80Kfm_0P1bLW82
07AdM080MWIf0P1iNGT207emO@80PX:20P27QhL208V9R@80Rh^;0P2=SHd2092@T00309:BTP2CTi<0
Ti>C0080U9BD0P2EUID209JFUP80UiNG2P2IVIT209NGU`80UYJF0P2CTi<2096AT@80Shn?00<0S8b<
08N7Q`27QhL00P24Q8@20820P080Ng]k0P1fMWH2079bLP80KFe]5@3oool001<0oooo0P1WIfL206EU
I@80Hf=S0P1QHF4205mOG`80G5aL0P1JFUX205QHF00305IFEP1DE5@0E5AD0080DU9B0P1?Cdl204e=
C@80Bd];0P19BDT204M7A`80A4A40P12@T820410@080?Cdm0P0k>c/203Ph>080=SHf0P0c<c<00`0`
<300;Rh^02h^;P0202/[:`80:BTY0P0V9RH202<S8`80820P0P0N7Qh201dM7@806a/K0P0N7Qh202<S
8`809bLW0P0^;Rh203Hf=P80?Cdm00<0ADE504i>CP1>CTh00P1EEED205MGE`80FUYJ101KFe/205aL
G080Fe]K101JFUX405UIF@80F5QH101GEeL305IFEPP0EEEE2P1DE5@805EEE@80EUIF0`1GEeL205QH
F080FEUI0P1KFe/205aLG080GEeM0P1OGel2061PH080HV9R0P1SHf<206ATI080IFEU0P1WIfL206QX
J080JVYZ00<0Jf][06a/K01/K6`00P1^KVh206m_K`80LG5a0P1cLg<207MgM`80NWYj0P1nOWh208>3
P`80R8R80P2;Rh/208f=S@80Shn?0P2ATI4209BDU00309FEU@2FUYH0UYJF0080UiNG0P2IVIT209ZJ
VP80Vi^K0P2LW9`209fMW@@0W9bL0P2KVi/209VIV@80V9RH0P2FUYH209>CT`80T92@00<0S8b<08R8
R028R8P00P24Q8@20820P080Ng]k0P1gMgL2079bLP80KFe]5@3oool001<0oooo0P1WIfL206EUI@80
Hf=S0P1QHF4205mOG`80G5aL0P1JFUX205QHF00305IFEP1DE5@0E5AD0080DU9B0P1?Cdl204e=C@80
Bd];0P19BDT204M7A`80A4A40P12@T820410@080?Cdm0P0k>c/203Ph>080=SHf0P0c<c<00`0`<300
;Rh^02h^;P0202/[:`80:BTY0P0V9RH202<S8`80820P0P0N7Qh201dM7@806a/K0P0N7Qh202<S8`80
9bLW0P0^;Rh203Hf=P80?Cdm00<0ADE504i>CP1>CTh00P1EEED205MGE`80FUYJ101KFe/205aLG080
Fe]K101JFUX405UIF@80F5QH101GEeL305IFEPP0EEEE2P1DE5@805EEE@80EUIF0`1GEeL205QHF080
FEUI0P1KFe/205aLG080GEeM0P1OGel2061PH080HV9R0P1SHf<206ATI080IFEU0P1WIfL206QXJ080
JVYZ00<0Jf][06a/K01/K6`00P1^KVh206m_K`80LG5a0P1cLg<207MgM`80NWYj0P1nOWh208>3P`80
R8R80P2;Rh/208f=S@80Shn?0P2ATI4209BDU00309FEU@2FUYH0UYJF0080UiNG0P2IVIT209ZJVP80
Vi^K0P2LW9`209fMW@@0W9bL0P2KVi/209VIV@80V9RH0P2FUYH209>CT`80T92@00<0S8b<08R8R028
R8P00P24Q8@20820P080Ng]k0P1gMgL2079bLP80KFe]5@3oool001<0oooo0P1WIfL206EUI@80HV9R
0P1PH60205iNGP80G5aL0P1JFUX205MGE`0305EEE@1CDe<0De=C0080D51@0P1>CTh204a<C080BTY:
0P17AdL204E5A@80@d=30P10@40203hn?P80>c/k0P0i>CT203Hf=P80<c<c0P0a<C400`0^;Rh0:b/[
02/[:`0202TY:@809RHV0P0S8b<2020P80807AdM0P0K6a/201XJ6P8061PH0P0L71`2020P80809BDU
0P0/;2`203<c<`80>SXj00<0@T9204];B`1;Bd/00P1EEED405]KF`H0G5aL101KFe/205YJFP80FEUI
101HF5P205MGE`80EUIF0`1EEED605ADE100De=C101DE5@205EEE@<0EUIF0P1GEeL205QHF080FUYJ
0P1KFe/205aLG080GUiN0P1PH602065QH@80Hf=S0P1TI6@206EUI@80IfMW0P1YJFT206YZJP0306a/
K01^KVh0KVi^0080Kfm_0P1aLG4207=cL`80MgMg0P1jNWX20820P080Q8B40P28R8P208b<S080SXj>
0P2@T90209>CT`80UIFE0P2GUiL00`2HV9P0VIVI09VIV@0209^KV`80WIfM0P2NWYh:09nOW`80WIfM
0P2KVi/209ZJVP80V9RH0P2DU9@2096AT@0308f=S@29RHT0RHV90080Q8B40P20P80207]kN`80MWIf
0P1bLW8206e]KAD0oooo000C0?ooo`80IfMW0P1UIFD2069RHP80H61P0P1NGUh205aLG080FUYJ0P1G
EeL00`1EEED0De=C05=CD`02051@D080CTi>0P1<C4`204Y:BP80AdM70P15ADD204=3@`80@4100P0n
?Sh203/k>`80>CTi0P0f=SH203<c<`80<C4a00<0;Rh^02/[:`0[:b/00P0Y:BT202HV9P808b<S0P0P
820201dM7@806a/K0P0J6QX201PH608071`L0P0P820202DU9@80;2`/0P0c<c<203Xj>P030492@P1;
Bd/0Bd];0080EEEE101KFe/605aLG0@0Fe]K0P1JFUX205UIF@@0F5QH0P1GEeL205IFEP<0EEEE1P1D
E5@@05=CD`@0E5AD0P1EEED305IFEP80EeMG0P1HF5P205YJFP80Fe]K0P1LG5`205iNGP80H61P0P1Q
HF4206=SH`80I6AT0P1UIFD206MWI`80JFUY0P1ZJVX00`1/K6`0KVi^06i^KP0206m_K`80LG5a0P1c
Lg<207MgM`80NWYj0P20P80208B4Q080R8R80P2<S8`208j>SP80T92@0P2CTi<209FEU@80UiNG00<0
V9RH09VIV@2IVIT00P2KVi/209fMW@80WYjN2P2OWil209fMW@80Vi^K0P2JVYX209RHV080U9BD0P2A
TI400`2=SHd0RHV908V9R@0208B4Q080P8200P1kNg/207IfMP80LW9b0P1]KFdE0?ooo`004`3oool2
06IVIP80I6AT0P1RHV82061PH080GEeM0P1KFe/205UIF@80EeMG00<0E5AD059BDP1BDU800P1?Cdl2
04e=C@80Bd];0P18B4P204I6AP80@d=30P11@D4203hn?P80?3`l0P0i>CT203Lg=`80=3@d0P0a<C42
02h^;P0302`/;00Y:BT0:BTY00809RHV0P0S8b<2020P80807AdM0P0J6QX201PH60805aLG0P0F5QH2
01XJ6P807QhN0P0T92@202XZ:P80<C4a0P0h>3P00`11@D40BTY:04Y:BP0205ADE0@0GEeM0P1NGUh4
05eMG@80G5aL0P1KFe/205YJFP80FEUI0P1HF5P205MGE`80EUIF0P1EEED305ADE0H0De=C401BDU84
05=CD`<0E5AD0P1EEED205IFEP80EeMG0P1IFET205YJFP80G5aL0P1NGUh2061PH080HF5Q0P1RHV82
06ATI080IVIV0P1XJ6P206YZJP80K6a/00<0KFe]071`L01`L7000P1aLG4207AdM080MWIf0P1lO7`2
0820P080QHF50P29RHT208f=S@80T92@0P2BTY8209BDU080UYJF0P2IVIT209^KV`0309bLW02MWId0
WIfM0080WYjN0P2PX:040:6QX@H0XZ:R0P2QXJ4209nOW`80WYjN0P2LW9`209VIV@80UYJF0P2BTY80
0`2=SHd0RHV908V9R@0208B4Q080P8200P1kNg/207IfMP80LW9b0P1]KFdE0?ooo`004`3oool206IV
IP80I6AT0P1RHV82061PH080GEeM0P1KFe/205UIF@80EeMG00<0E5AD059BDP1BDU800P1?Cdl204e=
C@80Bd];0P18B4P204I6AP80@d=30P11@D4203hn?P80?3`l0P0i>CT203Lg=`80=3@d0P0a<C4202h^
;P0302`/;00Y:BT0:BTY00809RHV0P0S8b<2020P80807AdM0P0J6QX201PH60805aLG0P0F5QH201XJ
6P807QhN0P0T92@202XZ:P80<C4a0P0h>3P00`11@D40BTY:04Y:BP0205ADE0@0GEeM0P1NGUh405eM
G@80G5aL0P1KFe/205YJFP80FEUI0P1HF5P205MGE`80EUIF0P1EEED305ADE0H0De=C401BDU8405=C
D`<0E5AD0P1EEED205IFEP80EeMG0P1IFET205YJFP80G5aL0P1NGUh2061PH080HF5Q0P1RHV8206AT
I080IVIV0P1XJ6P206YZJP80K6a/00<0KFe]071`L01`L7000P1aLG4207AdM080MWIf0P1lO7`20820
P080QHF50P29RHT208f=S@80T92@0P2BTY8209BDU080UYJF0P2IVIT209^KV`0309bLW02MWId0WIfM
0080WYjN0P2PX:040:6QX@H0XZ:R0P2QXJ4209nOW`80WYjN0P2LW9`209VIV@80UYJF0P2BTY800`2=
SHd0RHV908V9R@0208B4Q080P8200P1kNg/207IfMP80LW9b0P1]KFdE0?ooo`004`3oool206IVIP80
I6AT0P1QHF4205mOG`80GEeM0P1KFe/205QHF080EUIF00<0De=C055AD@1ADE400P1>CTh204a<C080
BDU90P17AdL204A4A080@T920P0o?cl203`l?080>SXj0P0g=cL203De=@80<S8b0P0_;bl202`/;003
02TY:@0V9RH09RHV00808b<S0P0P820201dM7@806QXJ0P0G5aL201DE5@804a<C0P0D51@201PH6080
71`L0P0R8R8202TY:@80<30`0P0g=cL00`10@400BDU904U9B@0205=CD`80G5aL101OGel205iNGP80
GEeM0P1LG5`205]KF`80FUYJ0P1HF5P205MGE`80EUIF0P1EEED305ADE080De=C101BDU8B055AD@@0
DU9B0`1CDe<205ADE080EEEE0P1FEUH205QHF080FUYJ0P1LG5`205iNGP80H61P0P1QHF42069RHP80
I6AT0P1WIfL206UYJ@80Jf][0P1]KFd00`1_Kfl0LW9b079bLP0207EeM@80N7Qh0P1lO7`20861P@80
QHF50P29RHT208f=S@80TI6A0P2CTi<209FEU@80UiNG0P2JVYX209bLW080WIfM00<0WinO0:2PX02P
X:000P2QXJ420:>SX`@0Y:BT102UYJD20:BTY080Xj>S0P2QXJ420:2PX080WIfM0P2JVYX209JFUP80
TY:B00<0SHf=08V9R@29RHT00P25QHD20820P080Ng]k0P1gMgL2079bLP80KFe]5@3oool001<0oooo
0P1VIVH206ATI080HF5Q0P1OGel205eMG@80Fe]K0P1HF5P205IFEP0305=CD`1ADE40DE5A0080CTi>
0P1<C4`204U9B@80AdM70P14A4@20492@P80?clo0P0l?3`203Xj>P80=cLg0P0e=CD2038b<P80;bl_
0P0/;2`00`0Y:BT09RHV02HV9P0202<S8`80820P0P0M7Ad201XJ6P805aLG0P0E5AD201<C4`8051@D
0P0H61P201`L70808R8R0P0Y:BT2030`<080=cLg00<0@41004U9B@19BDT00P1CDe<205aLG0@0GemO
0P1NGUh205eMG@80G5aL0P1KFe/205YJFP80F5QH0P1GEeL205IFEP80EEEE0`1DE5@205=CD`@0DU9B
4P1ADE44059BDP<0De=C0P1DE5@205EEE@80EUIF0P1HF5P205YJFP80G5aL0P1NGUh2061PH080HF5Q
0P1RHV8206ATI080IfMW0P1YJFT206][J`80KFe]00<0Kfm_079bLP1bLW800P1eMGD207QhN080O7al
0P21PH4208F5Q@80RHV90P2=SHd2096AT@80Ti>C0P2EUID209NGU`80VYZJ0P2LW9`209fMW@0309nO
W`2PX:00X:2P0080XJ6Q0P2SXj<40:BTY0@0YJFU0P2TY:@20:>SX`80XJ6Q0P2PX:0209fMW@80VYZJ
0P2FUYH209:BTP0308f=S@29RHT0RHV90080QHF50P20P80207]kN`80MgMg0P1bLW8206e]KAD0oooo
000C0?ooo`80IVIV0P1SHf<2065QH@80GemO0P1LG5`205YJFP80F5QH0P1EEED00`1BDU80D51@051@
D00204e=C@80Bd];0P18B4P204E5A@80@d=30P10@40203hn?P80>c/k0P0h>3P203De=@80<c<c0P0`
<30202d];@80:RXZ00<09bLW02@T900T92@00P0Q8B4201dM7@806QXJ0P0G5aL201@D50804Q8B0P0A
4A42018B4P805aLG0P0K6a/2028R8P80:2PX0P0_;bl203Lg=`0303lo?`19BDT0BDU90080DU9B0P1J
FUX2069RHP80HF5Q0P1OGel205iNGP80G5aL0P1KFe/205UIF@80F5QH0P1GEeL205IFEP80E5AD0`1C
De<2059BDP@0DE5A201@D50404m?C`P0D51@0P1ADE43059BDP80De=C0P1DE5@205EEE@80EeMG0P1I
FET205aLG080GUiN0P1OGel2061PH080HV9R0P1VIVH206QXJ080JVYZ0P1]KFd206m_K`03079bLP1g
MgL0MgMg0080NGUi0P1mOGd20861P@80QHF50P29RHT208f=S@80TI6A0P2DU9@209NGU`80V9RH0P2K
Vi/209fMW@80X:2P0P2QXJ400`2SXj<0Y:BT0:BTY0020:FUY@80YZJV0P2WYjL40:RXZ080YjNW0P2V
YZH20:FUY@80Xj>S0P2QXJ4209jNWP80VYZJ0P2GUiL209:BTP0308f=S@29RHT0RHV90080QHF50P20
P80207]kN`80MgMg0P1bLW8206e]KAD0oooo000C0?ooo`80IVIV0P1SHf<2065QH@80GemO0P1LG5`2
05YJFP80F5QH0P1EEED00`1BDU80D51@051@D00204e=C@80Bd];0P18B4P204E5A@80@d=30P10@402
03hn?P80>c/k0P0h>3P203De=@80<c<c0P0`<30202d];@80:RXZ00<09bLW02@T900T92@00P0Q8B42
01dM7@806QXJ0P0G5aL201@D50804Q8B0P0A4A42018B4P805aLG0P0K6a/2028R8P80:2PX0P0_;bl2
03Lg=`0303lo?`19BDT0BDU90080DU9B0P1JFUX2069RHP80HF5Q0P1OGel205iNGP80G5aL0P1KFe/2
05UIF@80F5QH0P1GEeL205IFEP80E5AD0`1CDe<2059BDP@0DE5A201@D50404m?C`P0D51@0P1ADE43
059BDP80De=C0P1DE5@205EEE@80EeMG0P1IFET205aLG080GUiN0P1OGel2061PH080HV9R0P1VIVH2
06QXJ080JVYZ0P1]KFd206m_K`03079bLP1gMgL0MgMg0080NGUi0P1mOGd20861P@80QHF50P29RHT2
08f=S@80TI6A0P2DU9@209NGU`80V9RH0P2KVi/209fMW@80X:2P0P2QXJ400`2SXj<0Y:BT0:BTY002
0:FUY@80YZJV0P2WYjL40:RXZ080YjNW0P2VYZH20:FUY@80Xj>S0P2QXJ4209jNWP80VYZJ0P2GUiL2
09:BTP0308f=S@29RHT0RHV90080QHF50P20P80207]kN`80MgMg0P1bLW8206e]KAD0oooo000C0?oo
o`80IVIV0P1SHf<2065QH@80GUiN0P1LG5`205UIF@80EeMG0P1DE5@00`1ADE40Cdm?04m?C`0204a<
C080BTY:0P17AdL204A4A080@D510P0o?cl203`l?080>CTi0P0f=SH203<c<`80<C4a0P0^;Rh202/[
:`80:2PX00<09BDU024Q8@0Q8B400P0N7Qh201/K6`8061PH0P0D51@2018B4P@03`l?0P0A4A4201HF
5P806a/K0P0Q8B4202LW9`80;Rh^0P0g=cL00`10@400B4Q804Q8B002051@D080FEUI0P1TI6@2069R
HP80H61P0P1NGUh205aLG080FUYJ0P1IFET205MGE`80EUIF0P1EEED405=CD`03059BDP1ADE40DE5A
00@0D51@201?Cdl804i>CP80Cdm?101@D503055AD@80DU9B0P1CDe<205ADE080EUIF0P1IFET205aL
G0@0GUiN0P1PH60206=SH`80IfMW0P1YJFT206a/K080Kfm_0P1bLW800`1gMgL0Ng]k07]kN`0207in
OP80PH610P25QHD208V9R@80SHf=0P2@T90209FEU@80V9RH0P2JVYX209bLW080WYjN0P2QXJ420:>S
X`80Y:BT0`2VYZH20:RXZ080ZJVY0P2ZZZX40:^[Z`80ZZZZ0P2XZ:P20:NWY`80YJFU0P2RXZ8209jN
WP80Vi^K0P2GUiL209:BTP0308j>SP29RHT0RHV90080QHF50P20P80207]kN`80MgMg0P1bLW8206e]
KAD0oooo000C0?ooo`80IVIV0P1SHf<2065QH@80GUiN0P1LG5`205UIF@80EeMG0P1DE5@00`1ADE40
Cdm?04m?C`0204a<C080BTY:0P17AdL204A4A080@D510P0o?cl203`l?080>CTi0P0f=SH203<c<`80
<C4a0P0^;Rh202/[:`80:2PX00<09BDU024Q8@0Q8B400P0N7Qh201/K6`8061PH0P0D51@2018B4P@0
3`l?0P0A4A4201HF5P806a/K0P0Q8B4202LW9`80;Rh^0P0g=cL00`10@400B4Q804Q8B002051@D080
FEUI0P1TI6@2069RHP80H61P0P1NGUh205aLG080FUYJ0P1IFET205MGE`80EUIF0P1EEED405=CD`03
059BDP1ADE40DE5A00@0D51@201?Cdl804i>CP80Cdm?101@D503055AD@80DU9B0P1CDe<205ADE080
EUIF0P1IFET205aLG0@0GUiN0P1PH60206=SH`80IfMW0P1YJFT206a/K080Kfm_0P1bLW800`1gMgL0
Ng]k07]kN`0207inOP80PH610P25QHD208V9R@80SHf=0P2@T90209FEU@80V9RH0P2JVYX209bLW080
WYjN0P2QXJ420:>SX`80Y:BT0`2VYZH20:RXZ080ZJVY0P2ZZZX40:^[Z`80ZZZZ0P2XZ:P20:NWY`80
YJFU0P2RXZ8209jNWP80Vi^K0P2GUiL209:BTP0308j>SP29RHT0RHV90080QHF50P20P80207]kN`80
MgMg0P1bLW8206e]KAD0oooo000C0?ooo`80IVIV0P1SHf<2065QH@80GUiN0P1LG5`205UIF@80EUIF
0P1CDe<00`1ADE40CTi>04i>CP0204];B`80BDU90P16ATH204=3@`80@4100P0m?Cd203Xj>P80=cLg
0P0d=3@2038b<P80;bl_0P0/;2`202TY:@809RHV00<08R8R01lO7`0O7al00P0L71`201TI6@805ADE
0P0B4Q8200l?3`803@d=0P0>3Ph2010@40805ADE0P0J6QX2024Q8@809bLW0P0^;Rh203Lg=`030410
@017AdL0AdM70080D51@0P1IFET206EUI@80HV9R0P1PH60205iNGP80G5aL0P1JFUX205UIF@80EeMG
0P1EEED205ADE080De=C0P1BDU800`1ADE40D51@051@D00404m?C`@0CTi>301=CDd404i>CP80Cdm?
0`1@D502055AD@80DU9B0P1DE5@205IFEP80FEUI0P1LG5`205eMG@80GUiN0P1QHF4206EUI@80J6QX
0P1[Jf/206i^KP80LW9b0P1gMgL00`1lO7`0P8200820P00208>3P`80QXJ60P29RHT208f=S@80TI6A
0P2DU9@209RHV080Vi^K0P2MWId20:2PX080XZ:R0P2TY:@40:JVYP030:RXZ02ZZZX0ZZZZ0080Zj^[
0P2][Jd60:j^[P80[:b/0P2[Zj/20:VYZ@80YZJV0P2RXZ8209nOW`80Vi^K0P2GUiL209:BTP0308j>
SP29RHT0RHV90080Q8B40P20P80207]kN`80MgMg0P1bLW8206e]KAD0oooo000C0?ooo`80IVIV0P1S
Hf<2065QH@80GUiN0P1LG5`205UIF@80EUIF0P1CDe<00`1ADE40CTi>04i>CP0204];B`80BDU90P16
ATH204=3@`80@4100P0m?Cd203Xj>P80=cLg0P0d=3@2038b<P80;bl_0P0/;2`202TY:@809RHV00<0
8R8R01lO7`0O7al00P0L71`201TI6@805ADE0P0B4Q8200l?3`803@d=0P0>3Ph2010@40805ADE0P0J
6QX2024Q8@809bLW0P0^;Rh203Lg=`030410@017AdL0AdM70080D51@0P1IFET206EUI@80HV9R0P1P
H60205iNGP80G5aL0P1JFUX205UIF@80EeMG0P1EEED205ADE080De=C0P1BDU800`1ADE40D51@051@
D00404m?C`@0CTi>301=CDd404i>CP80Cdm?0`1@D502055AD@80DU9B0P1DE5@205IFEP80FEUI0P1L
G5`205eMG@80GUiN0P1QHF4206EUI@80J6QX0P1[Jf/206i^KP80LW9b0P1gMgL00`1lO7`0P8200820
P00208>3P`80QXJ60P29RHT208f=S@80TI6A0P2DU9@209RHV080Vi^K0P2MWId20:2PX080XZ:R0P2T
Y:@40:JVYP030:RXZ02ZZZX0ZZZZ0080Zj^[0P2][Jd60:j^[P80[:b/0P2[Zj/20:VYZ@80YZJV0P2R
XZ8209nOW`80Vi^K0P2GUiL209:BTP0308j>SP29RHT0RHV90080Q8B40P20P80207]kN`80MgMg0P1b
LW8206e]KAD0oooo000C0?ooo`80IVIV0P1SHf<2061PH080GEeM0P1KFe/205QHF080EEEE0P1CDe<0
0`1@D500CDe=04e=C@0204Y:BP80B4Q80P14A4@20451@@80?Shn0P0l?3`203Ti>@80=SHf0P0c<c<2
030`<080;Bd]0P0Z:RX202HV9P808b<S00<0820P01dM7@0M7Ad00P0J6QX201HF5P804a<C0P0?3`l2
00d=3@802`/;0P0=3@d2010@408051@D0P0J6QX2020P80809bLW0P0_;bl203Ph>00303lo?`16ATH0
ATI60080D51@0P1JFUX206EUI@80HV9R0P1PH60205iNGP80G5aL0P1JFUX205QHF080EUIF0P1EEED2
05=CD`80DU9B0P1ADE4304m?C`80CTi>1P1=CDd<04a<C0@0CDe=0P1>CTh304m?C`80D51@0P1BDU82
05=CD`80EUIF0P1IFET205]KF`80G5aL0P1OGel206=SH`80IVIV0P1ZJVX206e]K@80LW9b0P1fMWH2
07]kN`030820P025QHD0QHF50080QhN70P2:RXX208f=S@80TI6A0P2DU9@209NGU`80Vi^K0P2MWId2
0:6QX@80Xj>S0P2VYZH20:NWY`80Z:RX0P2YZJT00`2[Zj/0[Jf]0:f][@020:j^[P80/;2`102a/K42
0;2`/080[Zj^0P2][Jd20:ZZZP80YjNW0P2SXj<209nOW`80Vi^K0P2GUiL209>CT`0308j>SP29RHT0
RHV90080Q8B40P20P80207]kN`80MgMg0P1bLW8206e]KAD0oooo000C0?ooo`80IVIV0P1SHf<2061P
H080GEeM0P1JFUX205MGE`80EEEE0P1BDU800`1?Cdl0C4a<04a<C00204U9B@80ATI60P13@d<20410
@080?Cdm0P0j>SX203Lg=`80=3@d0P0a<C4202h^;P80:b/[0P0X:2P202@T90808B4Q00<07QhN01/K
6`0K6a/00P0G5aL201@D50804A4A0P0=3@d400X:2P8030`<0P0@410201@D50806QXJ0P0Q8B4202LW
9`80<30`0P0g=cL00`0n?Sh0ATI604I6AP02055AD@80Fe]K0P1UIFD206=SH`80H61P0P1NGUh205aL
G080FUYJ0P1HF5P205IFEP80E5AD0P1CDe<2055AD@80D51@00<0Cdm?04i>CP1>CTh00P1=CDd404a<
C0P0Bd];0P1<C4`204];B`@0C4a<101=CDd204i>CP0304m?C`1@D500D51@0080DE5A0P1CDe<205IF
EP80FEUI0P1JFUX205eMG@80HF5Q0P1UIFD206QXJ080K6a/0P1aLG4207IfMP80NWYj0P1oOgl00`25
QHD0RHV908V9R@0208b<S080SXj>0P2ATI4209BDU080UiNG0P2JVYX209fMW@80X:2P0P2TY:@20:JV
YP80ZJVY0P2ZZZX20:^[Z`80[:b/00<0[Zj^0;2`/02`/;000P2a/K420;>c/`80];Bd0P2c/k<20;:b
/P80/;2`0P2^[Zh20:ZZZP80YjNW0P2TY:@20:2PX080W9bL0P2GUiL209>CT`0308j>SP29RHT0RHV9
0080Q8B40P20P80207]kN`80MgMg0P1bLW8206e]KAD0oooo000C0?ooo`80IVIV0P1SHf<2061PH080
GEeM0P1JFUX205MGE`80EEEE0P1BDU800`1?Cdl0C4a<04a<C00204U9B@80ATI60P13@d<20410@080
?Cdm0P0j>SX203Lg=`80=3@d0P0a<C4202h^;P80:b/[0P0X:2P202@T90808B4Q00<07QhN01/K6`0K
6a/00P0G5aL201@D50804A4A0P0=3@d400X:2P8030`<0P0@410201@D50806QXJ0P0Q8B4202LW9`80
<30`0P0g=cL00`0n?Sh0ATI604I6AP02055AD@80Fe]K0P1UIFD206=SH`80H61P0P1NGUh205aLG080
FUYJ0P1HF5P205IFEP80E5AD0P1CDe<2055AD@80D51@00<0Cdm?04i>CP1>CTh00P1=CDd404a<C0P0
Bd];0P1<C4`204];B`@0C4a<101=CDd204i>CP0304m?C`1@D500D51@0080DE5A0P1CDe<205IFEP80
FEUI0P1JFUX205eMG@80HF5Q0P1UIFD206QXJ080K6a/0P1aLG4207IfMP80NWYj0P1oOgl00`25QHD0
RHV908V9R@0208b<S080SXj>0P2ATI4209BDU080UiNG0P2JVYX209fMW@80X:2P0P2TY:@20:JVYP80
ZJVY0P2ZZZX20:^[Z`80[:b/00<0[Zj^0;2`/02`/;000P2a/K420;>c/`80];Bd0P2c/k<20;:b/P80
/;2`0P2^[Zh20:ZZZP80YjNW0P2TY:@20:2PX080W9bL0P2GUiL209>CT`0308j>SP29RHT0RHV90080
Q8B40P20P80207]kN`80MgMg0P1bLW8206e]KAD0oooo000C0?ooo`80IVIV0P1SHf<2061PH080GEeM
0P1JFUX205MGE`80E5AD0P1ADE400`1>CTh0Bd];04];B`0204Q8B080ADE50P12@T8203lo?`80?3`l
0P0i>CT203Hf=P80<c<c0P0_;bl202`/;080:BTY0P0V9RH2028R8P807alO00<071`L01TI6@0I6AT0
0P0E5AD2018B4P803Ph>0P0;2`/200P820802@T90P0<30`200l?3`8051@D0P0K6a/2024Q8@80:2PX
0P0`<30203Lg=`0303lo?`18B4P0B4Q80080DU9B0P1KFe/206EUI@80Hf=S0P1PH60205iNGP80G5aL
0P1IFET205MGE`80EEEE0P1CDe<2059BDP80D51@0P1?Cdl00`1>CTh0CDe=04e=C@0204a<C0H0Bd];
101:BTX:04];B`80C4a<101=CDd00`1?Cdl0D51@051@D002055AD@80De=C0P1FEUH205QHF080Fe]K
0P1NGUh2069RHP80IVIV0P1[Jf/206m_K`80M7Ad0P1iNGT207inOP80Q8B400<0RHV908f=S@2=SHd0
0P2@T90209:BTP80UIFE0P2GUiL209ZJVP80W9bL0P2PX:020:>SX`80YjNW0P2ZZZX20:b/[080[Jf]
0P2^[Zh20:n_[`030;6a/@2b/[80/[:b0080];Bd1P2f][H20;Bd]080/[:b0P2_[jl20:^[Z`80Z:RX
0P2TY:@20:2PX080W9bL0P2GUiL209>CT`0308j>SP29RHT0RHV90080QHF50P20P80207]kN`80MgMg
0P1bLW8206e]KAD0oooo000C0?ooo`80IVIV0P1SHf<2061PH080GEeM0P1JFUX205MGE`80E5AD0P1A
DE400`1>CTh0Bd];04];B`0204Q8B080ADE50P12@T8203lo?`80?3`l0P0i>CT203Hf=P80<c<c0P0_
;bl202`/;080:BTY0P0V9RH2028R8P807alO00<071`L01TI6@0I6AT00P0E5AD2018B4P803Ph>0P0;
2`/200P820802@T90P0<30`200l?3`8051@D0P0K6a/2024Q8@80:2PX0P0`<30203Lg=`0303lo?`18
B4P0B4Q80080DU9B0P1KFe/206EUI@80Hf=S0P1PH60205iNGP80G5aL0P1IFET205MGE`80EEEE0P1C
De<2059BDP80D51@0P1?Cdl00`1>CTh0CDe=04e=C@0204a<C0H0Bd];101:BTX:04];B`80C4a<101=
CDd00`1?Cdl0D51@051@D002055AD@80De=C0P1FEUH205QHF080Fe]K0P1NGUh2069RHP80IVIV0P1[
Jf/206m_K`80M7Ad0P1iNGT207inOP80Q8B400<0RHV908f=S@2=SHd00P2@T90209:BTP80UIFE0P2G
UiL209ZJVP80W9bL0P2PX:020:>SX`80YjNW0P2ZZZX20:b/[080[Jf]0P2^[Zh20:n_[`030;6a/@2b
/[80/[:b0080];Bd1P2f][H20;Bd]080/[:b0P2_[jl20:^[Z`80Z:RX0P2TY:@20:2PX080W9bL0P2G
UiL209>CT`0308j>SP29RHT0RHV90080QHF50P20P80207]kN`80MgMg0P1bLW8206e]KAD0oooo000C
0?ooo`80IFEU0P1RHV8205mOG`80G5aL0P1IFET205IFEP80E5AD0P1@D5000`1=CDd0BTY:04Y:BP02
04M7A`80A4A40P11@D4203hn?P80>c/k0P0g=cL203@d=080<C4a0P0^;Rh202/[:`80:2PX0P0T92@2
024Q8@807AdM00<06QXJ01LG5`0G5aL00P0C4a<2010@408030`<0P092@T200L71`802@T90P0;2`/2
010@40805ADE0P0L71`2028R8P80:BTY0P0a<C4203Ph>00303lo?`19BDT0BDU90080De=C0P1LG5`2
06IVIP80Hf=S0P1QHF4205iNGP80G5aL0P1IFET205MGE`80EEEE0P1CDe<2055AD@80D51@0P1>CTh0
0`1=CDd0C4a<04a<C00204];B`@0BTY:1P19BDT804Y:BP@0Bd];0P1<C4`204e=C@0304i>CP1?Cdl0
Cdm?0080DE5A0P1DE5@205IFEP80F5QH0P1LG5`2061PH080I6AT0P1YJFT206e]K@80LW9b0P1gMgL2
07emO@80Ph>30P28R8P00`2=SHd0TI6A096AT@0209BDU080UiNG0P2IVIT209^KV`80W9bL0P2NWYh2
0::RXP80YZJV0P2ZZZX20:b/[080[Zj^0P2`/;020;6a/@80/[:b00<0/k>c0;Fe]@2e]KD00P2g]kL4
0;Vi^@80^;Rh0P2f][H20;>c/`80/;2`0P2/[:`20:RXZ080Y:BT0P2PX:0209bLW080UiNG0P2CTi<0
0`2>SXh0RHV908V9R@0208F5Q@80P8200P1kNg/207MgM`80LW9b0P1]KFdE0?ooo`004`3oool206EU
I@80HV9R0P1OGel205aLG080FEUI0P1FEUH205ADE080D51@00<0CDe=04Y:BP1:BTX00P17AdL204A4
A080@D510P0n?Sh203/k>`80=cLg0P0d=3@2034a<@80;Rh^0P0[:b/202PX:08092@T0P0Q8B4201dM
7@0301XJ6P0G5aL05aLG00804a<C0P0@410200`<30802@T90P071`L200T92@802`/;0P0@410201DE
5@8071`L0P0R8R8202TY:@80<C4a0P0h>3P00`0o?cl0BDU904U9B@0205=CD`80G5aL0P1VIVH206=S
H`80HF5Q0P1NGUh205aLG080FEUI0P1GEeL205EEE@80De=C0P1ADE42051@D080CTi>00<0CDe=04a<
C01<C4`00P1;Bd/404Y:BPH0BDU9201:BTX404];B`80C4a<0P1=CDd00`1>CTh0Cdm?04m?C`02055A
D@80E5AD0P1FEUH205QHF080G5aL0P1PH60206ATI080JFUY0P1]KFd2079bLP80MgMg0P1mOGd208>3
P`80R8R800<0SHf=096AT@2ATI400P2DU9@209NGU`80VIVI0P2KVi/209bLW080WYjN0P2RXZ820:JV
YP80ZZZZ0P2/[:`20:j^[P80/;2`0P2a/K420;:b/P030;>c/`2e]KD0]KFe0080]kNg102i^KT20;Rh
^080][Jf0P2c/k<20;2`/080[:b/0P2XZ:P20:BTY080X:2P0P2LW9`209NGU`80Ti>C00<0SXj>08V9
R@29RHT00P25QHD20820P080Ng]k0P1gMgL2079bLP80KFe]5@3oool001<0oooo0P1UIFD2069RHP80
GemO0P1LG5`205UIF@80EUIF0P1CDe<2051@D00304e=C@1:BTX0BTY:0080ATI60P13@d<20410@080
?Cdm0P0i>CT203Hf=P80<c<c0P0`<30202`/;080:BTY0P0V9RH2028R8P807alO0P0L71`00`0H61P0
5ADE01DE5@02014A4@803Ph>0P0:2PX200L71`801PH60P0820P200`<3080410@0P0F5QH201dM7@80
8b<S0P0[:b/2034a<@80>3Ph00<0@41004Y:BP1:BTX00P1DE5@205eMG@80IVIV0P1SHf<2065QH@80
GUiN0P1KFe/205UIF@80EUIF0P1DE5@2059BDP80D51@0P1?Cdl204e=C@0304a<C01;Bd/0Bd];0080
BTY:1019BDT404Q8B0P0BDU9101:BTX204];B`@0C4a<00<0CTi>051@D01@D5000P1BDU8205ADE080
EUIF0P1IFET205eMG@80HV9R0P1VIVH206][J`80L71`0P1dM7@207]kN`80PH610P27QhL208b<S003
092@T02DU9@0U9BD0080V9RH0P2KVi/209bLW080WYjN0P2PX:020:6QX@80YJFU0P2YZJT20:b/[080
[jn_0P2a/K440;>c/`80];Bd00<0][Jf0;Rh^02h^;P00P2j^[X20;bl_080^k^k0P2j^[X20;Ng]`80
];Bd0P2`/;020:f][@80ZJVY0P2UYJD20:2PX080W9bL0P2GUiL209>CT`0308j>SP29RHT0RHV90080
QHF50P20P80207]kN`80MgMg0P1bLW8206e]KAD0oooo000C0?ooo`80IFEU0P1RHV8205mOG`80G5aL
0P1IFET205IFEP80De=C0P1@D5000`1=CDd0BTY:04Y:BP0204I6AP80@d=30P10@40203dm?@80>CTi
0P0f=SH203<c<`80<30`0P0/;2`202TY:@809RHV0P0R8R8201lO7`8071`L00<061PH01DE5@0E5AD0
0P0A4A4200h>3P802PX:0P071`L200H61P8020P80P0<30`2010@40805QHF0P0M7Ad202<S8`80:b/[
0P0a<C4203Ph>0030410@01:BTX0BTY:0080E5AD0P1MGEd206IVIP80Hf=S0P1QHF4205iNGP80Fe]K
0P1IFET205IFEP80E5AD0P1BDU82051@D080Cdm?0P1=CDd00`1<C4`0Bd];04];B`0204Y:BP@0BDU9
1018B4P804U9B@@0BTY:0P1;Bd/404a<C00304i>CP1@D500D51@0080DU9B0P1DE5@205IFEP80FEUI
0P1MGEd2069RHP80IVIV0P1[Jf/2071`L080M7Ad0P1kNg/20861P@80QhN70P2<S8`00`2@T900U9BD
09BDU00209RHV080Vi^K0P2LW9`209jNWP80X:2P0P2QXJ420:FUY@80ZJVY0P2/[:`20:n_[`80/K6a
102c/k<20;Bd]0030;Jf]P2h^;P0^;Rh0080^[Zj0P2l_;`20;^k^`80^[Zj0P2g]kL20;Bd]080/;2`
0P2][Jd20:VYZ@80YJFU0P2PX:0209bLW080UiNG0P2CTi<00`2>SXh0RHV908V9R@0208F5Q@80P820
0P1kNg/207MgM`80LW9b0P1]KFdE0?ooo`004`3oool206EUI@80HV9R0P1OGel205aLG080F5QH0P1E
EED2059BDP80Cdm?00<0C4a<04U9B@19BDT00P15ADD20492@P80?clo0P0k>c/203Ph>080=CDe0P0a
<C4202h^;P80:b/[0P0X:2P202@T90808B4Q0P0M7Ad201XJ6P0301HF5P0C4a<04a<C00803`l?0P0<
30`200P820@01PH60P0820P200`<30804A4A0P0G5aL201hN7P8092@T0P0/;2`2038b<P80>SXj00<0
@d=304e=C@1=CDd00P1FEUH205iNGP80IfMW0P1SHf<2065QH@80GUiN0P1KFe/205QHF080EUIF0P1D
E5@2059BDP80D51@0P1>CTh204e=C@0304];B`1:BTX0BTY:0080BDU91P18B4P204M7A`H0B4Q81P19
BDT204Y:BP80Bd];0P1<C4`00`1>CTh0D51@051@D002059BDP80EEEE0P1GEeL205YJFP80H61P0P1T
I6@206QXJ080KFe]0P1bLW8207MgM`80OWin0P26QXH208b<S080Shn?00<0Ti>C09NGU`2GUiL00P2K
Vi/209jNWP80X:2P0P2RXZ820:>SX`80Y:BT0P2WYjL20:^[Z`80[Zj^0P2a/K420;>c/`@0][Jf0P2g
]kL00`2i^KT0^k^k0;^k^`020;fm_@80_kno0P2m_Kd20;^k^`80^;Rh0P2e]KD20;6a/@80[Zj^0P2Y
ZJT20:FUY@80X:2P0P2LW9`209RHV080Ti>C00<0SXj>08V9R@29RHT00P25QHD20820P080Ng]k0P1g
MgL2079bLP80KFe]5@3oool001<0oooo0P1UIFD2069RHP80GemO0P1LG5`205QHF080EEEE0P1BDU82
04m?C`0304a<C019BDT0BDU90080ADE50P12@T8203lo?`80>c/k0P0h>3P203De=@80<C4a0P0^;Rh2
02/[:`80:2PX0P0T92@2024Q8@807AdM0P0J6QX00`0F5QH04a<C01<C4`0200l?3`8030`<0P0820P4
00H61P8020P80P0<30`2014A4@805aLG0P0N7Qh202@T9080;2`/0P0b<S8203Xj>P0304=3@`1=CDd0
CDe=0080EUIF0P1NGUh206MWI`80Hf=S0P1QHF4205iNGP80Fe]K0P1HF5P205IFEP80E5AD0P1BDU82
051@D080CTi>0P1=CDd00`1;Bd/0BTY:04Y:BP0204U9B@H0B4Q80P17AdL604Q8B0H0BDU90P1:BTX2
04];B`80C4a<00<0CTi>051@D01@D5000P1BDU8205EEE@80EeMG0P1JFUX2061PH080I6AT0P1XJ6P2
06e]K@80LW9b0P1gMgL207inOP80QXJ60P2<S8`208n?S`0309>CT`2GUiL0UiNG0080Vi^K0P2NWYh2
0:2PX080XZ:R0P2SXj<20:BTY080YjNW0P2[Zj/20:j^[P80/K6a0P2c/k<40;Jf]P80]kNg00<0^KVi
0;^k^`2k^k/00P2m_Kd20;no_`80_Kfm0P2k^k/20;Rh^080]KFe0P2a/K420:j^[P80ZJVY0P2UYJD2
0:2PX080W9bL0P2HV9P209>CT`0308j>SP29RHT0RHV90080QHF50P20P80207]kN`80MgMg0P1bLW82
06e]KAD0oooo000C0?ooo`80IFEU0P1RHV8205mOG`80Fe]K0P1HF5P205EEE@80DU9B0P1>CTh00`1;
Bd/0B4Q804Q8B00204A4A080@D510P0n?Sh203Xj>P80=cLg0P0c<c<2030`<080;Bd]0P0Y:BT202HV
9P808b<S0P0O7al201/K6`8061PH00<051@D014A4@0A4A400P0=3@d200X:2P801PH60P051@D200H6
1P8020P80P0=3@d2018B4P806ATI0P0O7al202HV9P80;Bd]0P0d=3@203dm?@0304I6AP1?Cdl0Cdm?
0080EeMG0P1OGel206MWI`80I6AT0P1QHF4205iNGP80Fe]K0P1HF5P205IFEP80E5AD0P1BDU82051@
D080CTi>0P1=CDd00`1;Bd/0BTY:04Y:BP0404Q8B0X0AdM71018B4P404U9B@80BTY:0P1;Bd/204a<
C00304i>CP1@D500D51@0080De=C0P1FEUH205QHF080G5aL0P1RHV8206IVIP80JVYZ0P1_Kfl207Ee
M@80O7al0P23Ph<208Z:RP80Shn?0P2BTY800`2FUYH0VYZJ09ZJVP0209jNWP80XZ:R0P2TY:@20:FU
Y@80YZJV0P2WYjL20:ZZZP80[Jf]0P2_[jl20;>c/`80][Jf102h^;P20;Zj^P030;bl_02o_kl0_kno
0080`<300P31`L420;no_`80_;bl0P2i^KT20;Jf]P80/[:b0P2^[Zh20:ZZZP80YJFU0P2QXJ4209bL
W080V9RH0P2CTi<00`2>SXh0RHV908V9R@0208F5Q@80P8200P1kNg/207MgM`80LW9b0P1]KFdE0?oo
o`004`3oool206EUI@80HV9R0P1OGel205]KF`80F5QH0P1EEED2059BDP80CTi>00<0Bd];04Q8B018
B4P00P14A4@20451@@80?Shn0P0j>SX203Lg=`80<c<c0P0`<30202d];@80:BTY0P0V9RH202<S8`80
7alO0P0K6a/201PH600301@D500A4A404A4A00803@d=0P0:2PX200H61P801@D50P061PH200P82080
3@d=0P0B4Q8201TI6@807alO0P0V9RH202d];@80=3@d0P0m?Cd00`16ATH0Cdm?04m?C`0205MGE`80
GemO0P1WIfL206ATI080HF5Q0P1NGUh205]KF`80F5QH0P1FEUH205ADE080DU9B0P1@D50204i>CP80
CDe=00<0Bd];04Y:BP1:BTX01018B4P:04M7A`@0B4Q81019BDT204Y:BP80Bd];0P1<C4`00`1>CTh0
D51@051@D00205=CD`80EUIF0P1HF5P205aLG080HV9R0P1VIVH206YZJP80Kfm_0P1eMGD207alO080
Ph>30P2:RXX208n?S`80TY:B00<0UYJF09ZJVP2JVYX00P2NWYh20::RXP80Y:BT0P2UYJD20:JVYP80
YjNW0P2ZZZX20:f][@80[jn_0P2c/k<20;Jf]P@0^;Rh0P2j^[X00`2l_;`0_kno0;no_`020<30`080
`L710P2o_kl20;bl_080^KVi0P2f][H20;:b/P80[Zj^0P2ZZZX20:FUY@80XJ6Q0P2LW9`209RHV080
Ti>C00<0SXj>08V9R@29RHT00P25QHD20820P080Ng]k0P1gMgL2079bLP80KFe]5@3oool001<0oooo
0P1UIFD2069RHP80GUiN0P1KFe/205QHF080EEEE0P1ADE4204i>CP0304Y:BP17AdL0AdM70080@d=3
0P10@40203dm?@80>CTi0P0f=SH2038b<P80;bl_0P0[:b/202PX:08092@T0P0Q8B4201dM7@806QXJ
0P0F5QH00`0B4Q803`l?00l?3`0200`<308020P810051@D200H61P802@T90P0?3`l201@D50806a/K
0P0R8R8202PX:080;bl_0P0f=SH20410@00304U9B@1ADE40DE5A0080FEUI0P1QHF4206MWI`80I6AT
0P1PH60205eMG@80FUYJ0P1HF5P205EEE@80De=C0P1ADE4204m?C`80CTi>0P1<C4`00`1;Bd/0BDU9
04U9B@0204Q8B080AdM72016ATH604M7A`80B4Q80P19BDT204Y:BP80Bd];0P1<C4`00`1>CTh0DE5A
055AD@0205ADE080EeMG0P1IFET205iNGP80I6AT0P1XJ6P206][J`80LW9b0P1iNGT20861P@80QXJ6
0P2=SHd209:BTP80UIFE00<0V9RH09bLW02LW9`00P2PX:020:FUY@80YjNW102YZJT20:ZZZP80[:b/
0P2^[Zh20;6a/@80]KFe0P2i^KT20;Zj^P80^k^k0P2m_Kd00`2o_kl0`L710<71`@020<;2`P80`l?3
0P30`<020;bl_080^[Zj0P2f][H20;:b/P80[Zj^0P2ZZZX20:FUY@80XJ6Q0P2LW9`209RHV080Ti>C
00<0SXj>08Z:RP2:RXX00P25QHD20820P080Ng]k0P1gMgL2079bLP80KFe]5@3oool001<0oooo0P1U
IFD2069RHP80GUiN0P1KFe/205QHF080EEEE0P1ADE4204i>CP0304Y:BP17AdL0AdM70080@d=30P10
@40203dm?@80>CTi0P0f=SH2038b<P80;bl_0P0[:b/202PX:08092@T0P0Q8B4201dM7@806QXJ0P0F
5QH00`0B4Q803`l?00l?3`0200`<308020P810051@D200H61P802@T90P0?3`l201@D50806a/K0P0R
8R8202PX:080;bl_0P0f=SH20410@00304U9B@1ADE40DE5A0080FEUI0P1QHF4206MWI`80I6AT0P1P
H60205eMG@80FUYJ0P1HF5P205EEE@80De=C0P1ADE4204m?C`80CTi>0P1<C4`00`1;Bd/0BDU904U9
B@0204Q8B080AdM72016ATH604M7A`80B4Q80P19BDT204Y:BP80Bd];0P1<C4`00`1>CTh0DE5A055A
D@0205ADE080EeMG0P1IFET205iNGP80I6AT0P1XJ6P206][J`80LW9b0P1iNGT20861P@80QXJ60P2=
SHd209:BTP80UIFE00<0V9RH09bLW02LW9`00P2PX:020:FUY@80YjNW102YZJT20:ZZZP80[:b/0P2^
[Zh20;6a/@80]KFe0P2i^KT20;Zj^P80^k^k0P2m_Kd00`2o_kl0`L710<71`@020<;2`P80`l?30P30
`<020;bl_080^[Zj0P2f][H20;:b/P80[Zj^0P2ZZZX20:FUY@80XJ6Q0P2LW9`209RHV080Ti>C00<0
SXj>08Z:RP2:RXX00P25QHD20820P080Ng]k0P1gMgL2079bLP80KFe]5@3oool001<0oooo0P1UIFD2
069RHP80GUiN0P1KFe/205MGE`80E5AD0P1@D50204e=C@0304Y:BP16ATH0ATI60080@d=30P0o?cl2
03/k>`80>3Ph0P0e=CD2034a<@80;Bd]0P0Z:RX202HV9P808b<S0P0P820201`L708061PH0P0D51@0
0`0A4A403@d=00d=3@0200X:2P801PH60P0410@200D51@801`L70P0;2`/2010@40805QHF0P0M7Ad2
02@T9080:RXZ0P0b<S8203Ti>@80A4A400<0C4a<05ADE01DE5@00P1LG5`206ATI080IVIV0P1SHf<2
05mOG`80G5aL0P1IFET205MGE`80E5AD0P1BDU82051@D080Cdm?0P1=CDd204a<C00304Y:BP19BDT0
BDU90080B4Q80P17AdL404I6AP80ADE51P16ATH204M7A`@0B4Q80P1:BTX204];B`80CDe=00<0CTi>
055AD@1ADE400P1EEED205UIF@80G5aL0P1QHF4206IVIP80JFUY0P1^KVh207EeM@80OGem0P25QHD2
08V9R@80T92@0P2EUID209RHV00309^KV`2OWil0WinO0080Xj>S0P2XZ:P20:ZZZP80[:b/102][Jd2
0:j^[P80/;2`0P2b/[820;Ng]`80^k^k0P2l_;`20;jn_P80`<3000<0`/;20<?3``33`l<01034a<@2
0<30`080_Kfm0P2j^[X20;Ng]`80/k>c0P2^[Zh20:ZZZP80YJFU0P2QXJ4209bLW080V9RH0P2CTi<0
0`2>SXh0RXZ:08Z:RP0208F5Q@80P8200P1kNg/207MgM`80LW9b0P1]KFdE0?ooo`004`3oool206EU
I@80HV9R0P1NGUh205]KF`80EeMG0P1DE5@2051@D080CDe=00<0BTY:04I6AP16ATH00P13@d<203lo
?`80>c/k0P0h>3P203De=@80<C4a0P0];Bd202XZ:P809RHV0P0S8b<2020P808071`L0P0H61P201@D
5003014A4@0=3@d03@d=00802PX:0P061PH200@410801@D50P071`L200/;2`80410@0P0F5QH201dM
7@8092@T0P0Z:RX2038b<P80>CTi0P14A4@00`1<C4`0E5AD05ADE00205aLG080I6AT0P1VIVH206=S
H`80GemO0P1LG5`205UIF@80EeMG0P1DE5@2059BDP80D51@0P1?Cdl204e=C@80C4a<00<0BTY:04U9
B@19BDT00P18B4P204M7A`@0ATI60P15ADD604I6AP80AdM71018B4P204Y:BP80Bd];0P1=CDd00`1>
CTh0DE5A055AD@0205EEE@80FEUI0P1LG5`2065QH@80IVIV0P1YJFT206i^KP80MGEe0P1mOGd208F5
Q@80RHV90P2@T90209FEU@80V9RH00<0Vi^K09nOW`2OWil00P2SXj<20:RXZ080ZZZZ0P2/[:`40:f]
[@80[Zj^0P2`/;020;:b/P80]kNg0P2k^k/20;bl_080_[jn0P30`<000`32`/80`l?30<?3``040<C4
a080`<300P2m_Kd20;Zj^P80]kNg0P2c/k<20:j^[P80ZZZZ0P2UYJD20:6QX@80W9bL0P2HV9P209>C
T`0308j>SP2:RXX0RXZ:0080QHF50P20P80207]kN`80MgMg0P1bLW8206e]KAD0oooo000C0?ooo`80
IFEU0P1QHF4205iNGP80Fe]K0P1GEeL205=CD`80D51@0P1<C4`00`19BDT0ADE504E5A@020492@P80
?Shn0P0j>SX203Lg=`80<c<c0P0`<30202`/;080:BTY0P0U9BD2024Q8@807QhN0P0J6QX201HF5P80
4a<C00<03`l?00`<300<30`00P0820P200D51@8010@40P051@D200P8208030`<0P0B4Q8201PH6080
820P0P0V9RH202h^;P80=3@d0P0n?Sh204Q8B003051@D01HF5P0F5QH0080H61P101TI6@2065QH@80
GEeM0P1JFUX205QHF080EEEE0P1CDe<2055AD@80D51@0P1>CTh204a<C080Bd];00<0BTY:04U9B@19
BDT00P18B4P204M7A`@0ATI61P15ADD404I6AP80AdM70P18B4P204U9B@80Bd];0P1<C4`00`1?Cdl0
DU9B059BDP0205EEE@80FUYJ0P1PH60206ATI080JFUY0P1ZJVX2071`L080MgMg0P20P80208R8R080
S8b<0P2BTY8209NGU`80Vi^K00<0WIfM0::RXP2RXZ800P2VYZH20:ZZZP80[Jf]0P2_[jl60;2`/080
/K6a0P2e]KD20;Vi^@80_Kfm0P2n_[h20<71`@80`l?300<0a<C40<G5a@35aLD00P37alL20<G5a@80
`L710P2o_kl20;^k^`80]kNg0P2c/k<20:n_[`80ZZZZ0P2UYJD20:6QX@80W9bL0P2HV9P209>CT`03
08j>SP2:RXX0RXZ:0080QHF50P20P80207]kN`80MgMg0P1bLW8206e]KAD0oooo000C0?ooo`80IFEU
0P1QHF4205iNGP80Fe]K0P1GEeL205=CD`80D51@0P1<C4`00`19BDT0ADE504E5A@020492@P80?Shn
0P0j>SX203Lg=`80<c<c0P0`<30202`/;080:BTY0P0U9BD2024Q8@807QhN0P0J6QX201HF5P804a<C
00<03`l?00`<300<30`00P0820P200D51@8010@40P051@D200P8208030`<0P0B4Q8201PH6080820P
0P0V9RH202h^;P80=3@d0P0n?Sh204Q8B003051@D01HF5P0F5QH0080H61P101TI6@2065QH@80GEeM
0P1JFUX205QHF080EEEE0P1CDe<2055AD@80D51@0P1>CTh204a<C080Bd];00<0BTY:04U9B@19BDT0
0P18B4P204M7A`@0ATI61P15ADD404I6AP80AdM70P18B4P204U9B@80Bd];0P1<C4`00`1?Cdl0DU9B
059BDP0205EEE@80FUYJ0P1PH60206ATI080JFUY0P1ZJVX2071`L080MgMg0P20P80208R8R080S8b<
0P2BTY8209NGU`80Vi^K00<0WIfM0::RXP2RXZ800P2VYZH20:ZZZP80[Jf]0P2_[jl60;2`/080/K6a
0P2e]KD20;Vi^@80_Kfm0P2n_[h20<71`@80`l?300<0a<C40<G5a@35aLD00P37alL20<G5a@80`L71
0P2o_kl20;^k^`80]kNg0P2c/k<20:n_[`80ZZZZ0P2UYJD20:6QX@80W9bL0P2HV9P209>CT`0308j>
SP2:RXX0RXZ:0080QHF50P20P80207]kN`80MgMg0P1bLW8206e]KAD0oooo000C0?ooo`80IFEU0P1Q
HF4205iNGP80FUYJ0P1GEeL205=CD`80Cdm?0P1<C4`00`18B4P0A4A404A4A0020451@@80?Cdm0P0i
>CT203Hf=P80<S8b0P0^;Rh202/[:`809bLW0P0S8b<2020P808071`L0P0H61P201DE5@804A4A00<0
3@d=00X:2P0:2PX00P071`L200@410800`<30P061PH200T92@803Ph>0P0D51@201/K6`808R8R0P0Y
:BT2034a<@80>3Ph0P13@d<204a<C00305ADE01MGEd0GEeM0080HF5Q0P1RHV82061PH080GUiN0P1K
Fe/205QHF080EUIF0P1DE5@2059BDP80D51@0P1?Cdl204e=C@80C4a<0P1;Bd/00`1:BTX0BDU904U9
B@0204Q8B080AdM71016ATH404E5A@80A4A40P15ADD404I6AP80B4Q80P19BDT204];B`80C4a<00<0
Cdm?059BDP1BDU800P1FEUH205aLG080I6AT0P1VIVH206a/K080KFe]0P1cLg<207YjNP80PX:20P2;
Rh/2092@T080Ti>C0P2JVYX209fMW@030:2PX02TY:@0Y:BT0080Z:RX0P2/[:`20:n_[`80/K6a0P2c
/k<40;:b/P80/k>c0P2g]kL20;^k^`80_[jn0P31`L420<C4a080aLG500<0a/K60<O7a`37alL00P38
b<P20<G5a@80`/;20P30`<020;bl_080^;Rh0P2c/k<20:n_[`80ZZZZ0P2VYZH20:6QX@80W9bL0P2H
V9P209>CT`0308j>SP2:RXX0RXZ:0080QHF50P20P80207alO080MgMg0P1bLW8206e]KAD0oooo000C
0?ooo`80IFEU0P1QHF4205iNGP80FUYJ0P1GEeL205=CD`80Cdm?0P1<C4`00`18B4P0A4A404A4A002
0451@@80?Cdm0P0i>CT203Hf=P80<S8b0P0^;Rh202/[:`809bLW0P0S8b<2020P808071`L0P0H61P2
01DE5@804A4A00<03@d=00X:2P0:2PX00P071`L200@410800`<30P061PH200T92@803Ph>0P0D51@2
01/K6`808R8R0P0Y:BT2034a<@80>3Ph0P13@d<204a<C00305ADE01MGEd0GEeM0080HF5Q0P1RHV82
061PH080GUiN0P1KFe/205QHF080EUIF0P1DE5@2059BDP80D51@0P1?Cdl204e=C@80C4a<0P1;Bd/0
0`1:BTX0BDU904U9B@0204Q8B080AdM71016ATH404E5A@80A4A40P15ADD404I6AP80B4Q80P19BDT2
04];B`80C4a<00<0Cdm?059BDP1BDU800P1FEUH205aLG080I6AT0P1VIVH206a/K080KFe]0P1cLg<2
07YjNP80PX:20P2;Rh/2092@T080Ti>C0P2JVYX209fMW@030:2PX02TY:@0Y:BT0080Z:RX0P2/[:`2
0:n_[`80/K6a0P2c/k<40;:b/P80/k>c0P2g]kL20;^k^`80_[jn0P31`L420<C4a080aLG500<0a/K6
0<O7a`37alL00P38b<P20<G5a@80`/;20P30`<020;bl_080^;Rh0P2c/k<20:n_[`80ZZZZ0P2VYZH2
0:6QX@80W9bL0P2HV9P209>CT`0308j>SP2:RXX0RXZ:0080QHF50P20P80207alO080MgMg0P1bLW82
06e]KAD0oooo000C0?ooo`80IFEU0P1QHF4205iNGP80FUYJ0P1FEUH205=CD`80Cdm?0P1;Bd/00`17
AdL0A4A404A4A0020410@080?3`l0P0h>3P203@d=080<C4a0P0];Bd202TY:@809RHV0P0R8R8201hN
7P806a/K0P0G5aL201<C4`803`l?00<030`<00P8200820P00P051@D400@410801`L70P0;2`/2010@
40805aLG0P0N7Qh202DU9@80;Bd]0P0d=3@203dm?@80B4Q80P1@D5000`1IFET0H61P061PH00205mO
G`80GUiN0P1MGEd205]KF`80F5QH0P1FEUH205ADE080DU9B0P1@D50204m?C`80CDe=0P1<C4`204];
B`<0BTY:1018B4P404M7A`80ATI61P15ADD204A4A080ADE50P16ATH204M7A`80B4Q80P1:BTX204a<
C00304m?C`1CDe<0De=C0080EeMG0P1NGUh206IVIP80JFUY0P1_Kfl2075aL@80MGEe0P1mOGd208F5
Q@80SHf=0P2CTi<209JFUP80Vi^K0P2OWil00`2RXZ80YZJV0:JVYP020:ZZZP80[Jf]0P2a/K420;>c
/`P0]KFe0P2h^;P20;fm_@80`<300P33`l<20<K6aP80alO700<0b<S80<W9b@39bLT00P39bLT20<O7
a`80a<C40P30`<020;bl_080^;Rh0P2c/k<20:n_[`80ZZZZ0P2VYZH20:6QX@80W9bL0P2HV9P209>C
T`0308j>SP2:RXX0RXZ:0080QHF50P20P80207alO080MgMg0P1bLW8206e]KAD0oooo000C0?ooo`80
IFEU0P1QHF4205iNGP80FUYJ0P1FEUH205=CD`80Cdm?0P1;Bd/00`17AdL0A4A404A4A0020410@080
?3`l0P0h>3P203@d=080<C4a0P0];Bd202TY:@809RHV0P0R8R8201hN7P806a/K0P0G5aL201<C4`80
3`l?00<030`<00P8200820P00P051@D400@410801`L70P0;2`/2010@40805aLG0P0N7Qh202DU9@80
;Bd]0P0d=3@203dm?@80B4Q80P1@D5000`1IFET0H61P061PH00205mOG`80GUiN0P1MGEd205]KF`80
F5QH0P1FEUH205ADE080DU9B0P1@D50204m?C`80CDe=0P1<C4`204];B`<0BTY:1018B4P404M7A`80
ATI61P15ADD204A4A080ADE50P16ATH204M7A`80B4Q80P1:BTX204a<C00304m?C`1CDe<0De=C0080
EeMG0P1NGUh206IVIP80JFUY0P1_Kfl2075aL@80MGEe0P1mOGd208F5Q@80SHf=0P2CTi<209JFUP80
Vi^K0P2OWil00`2RXZ80YZJV0:JVYP020:ZZZP80[Jf]0P2a/K420;>c/`P0]KFe0P2h^;P20;fm_@80
`<300P33`l<20<K6aP80alO700<0b<S80<W9b@39bLT00P39bLT20<O7a`80a<C40P30`<020;bl_080
^;Rh0P2c/k<20:n_[`80ZZZZ0P2VYZH20:6QX@80W9bL0P2HV9P209>CT`0308j>SP2:RXX0RXZ:0080
QHF50P20P80207alO080MgMg0P1bLW8206e]KAD0oooo000C0?ooo`80IFEU0P1QHF4205eMG@80FUYJ
0P1FEUH2059BDP80CTi>0P1:BTX00`17AdL0@d=304=3@`0203lo?`80>c/k0P0g=cL203@d=080<30`
0P0/;2`202PX:08092@T0P0Q8B4201dM7@806ATI0P0E5AD2014A4@803@d=00<02PX:00L71`071`L0
100410@200D51@8020P80P0=3@d201<C4`806ATI0P0Q8B4202TY:@80<C4a0P0h>3P204=3@`80C4a<
0P1EEED00`1LG5`0GUiN05iNGP0205aLG080Fe]K0P1IFET205QHF080EUIF0P1DE5@2059BDP80D51@
0P1?Cdl204i>CP80C4a<101;Bd/304Y:BP80BDU91018B4P404M7A`@0ATI62015ADD204I6AP80B4Q8
0P1:BTX204a<C00304m?C`1CDe<0De=C0080FEUI0P1OGel206QXJ080KFe]0P1`L70207EeM@80N7Qh
0P20P80208N7Q`80Shn?0P2CTi<209RHV080Vi^K0P2PX:000`2TY:@0YjNW0:NWY`020:^[Z`80[jn_
0P2b/[820;Fe]@80]kNg102h^;P20;Ng]`80^[Zj0P2o_kl20<;2`P80a/K60P38b<P20<W9b@030<[:
bP3;bl/0bl_;0080bl_;0P38b<P20<C4a080`L710P2l_;`20;Rh^080];Bd0P2_[jl20:ZZZP80YZJV
0P2QXJ4209fMW@80V9RH0P2CTi<00`2?Shl0RXZ:08Z:RP0208F5Q@80P8200P1lO7`207MgM`80LW9b
0P1]KFdE0?ooo`004`3oool206EUI@80HF5Q0P1MGEd205YJFP80EUIF0P1BDU8204i>CP80BTY:00<0
AdM704=3@`13@d<00P0o?cl203/k>`80=cLg0P0d=3@2030`<080;2`/0P0X:2P202@T90808B4Q0P0M
7Ad201TI6@805ADE0P0A4A4200d=3@0300X:2P071`L01`L700@010@40P051@D200P820803@d=0P0C
4a<201TI6@808B4Q0P0Y:BT2034a<@80>3Ph0P13@d<204a<C080EEEE00<0G5aL05iNGP1NGUh00P1L
G5`205]KF`80FEUI0P1HF5P205IFEP80E5AD0P1BDU82051@D080Cdm?0P1>CTh204a<C0@0Bd];0`1:
BTX204U9B@@0B4Q81017AdL404I6APP0ADE50P16ATH204Q8B080BTY:0P1<C4`00`1?Cdl0De=C05=C
D`0205UIF@80GemO0P1XJ6P206e]K@80L71`0P1eMGD207QhN080P8200P27QhL208n?S`80Ti>C0P2H
V9P209^KV`80X:2P00<0Y:BT0:NWY`2WYjL00P2[Zj/20:n_[`80/[:b0P2e]KD20;Ng]`@0^;Rh0P2g
]kL20;Zj^P80_kno0P32`/820<K6aP80b<S80P39bLT00`3:b/X0bl_;0<_;b`020<_;b`80b<S80P34
a<@20<71`@80_;bl0P2h^;P20;Bd]080[jn_0P2ZZZX20:JVYP80XJ6Q0P2MWId209RHV080Ti>C00<0
Shn?08Z:RP2:RXX00P25QHD20820P080O7al0P1gMgL2079bLP80KFe]5@3oool001<0oooo0P1UIFD2
065QH@80GEeM0P1IFET205EEE@80DE5A0P1=CDd204Y:BP0304I6AP12@T80@T920080?Shn0P0j>SX2
03Hf=P80<S8b0P0_;bl202/[:`809bLW0P0S8b<201lO7`8071`L0P0H61P201@D5080410@0P0<30`0
0`092@T01PH600H61P0200@410800`<30P061PH200X:2P803`l?0P0E5AD201dM7@809BDU0P0/;2`2
03De=@80?Shn0P19BDT2055AD@80FEUI00<0G5aL05]KF`1KFe/00P1JFUX205QHF080EUIF0P1EEED2
05=CD`80DE5A0P1@D50204m?C`80CTi>0P1=CDd204];B`L0BTY:1019BDT404Q8B0@0AdM71016ATH6
04E5A@80ATI60P17AdL204U9B@80C4a<00<0Cdm?05=CD`1CDe<00P1IFET2061PH080JVYZ0P1`L702
079bLP80N7Qh0P1mOGd20861P@80RHV90P2?Shl209BDU080VYZJ0P2MWId20:6QX@030:FUY@2YZJT0
ZJVY0080[:b/0P2a/K420;Bd]080]kNg0P2i^KT60;^k^`80_;bl0P30`<020<C4a080alO70P39bLT2
0<c<c0<0cLg=0P3<c<`20<S8b080aLG50P31`L420;fm_@80^KVi0P2d];@20:n_[`80Zj^[0P2VYZH2
0:6QX@80WIfM0P2HV9P209>CT`0308n?S`2:RXX0RXZ:0080QHF50P20P80207alO080MgMg0P1bLW82
06e]KAD0oooo000C0?ooo`80IFEU0P1QHF4205eMG@80FEUI0P1EEED2055AD@80CDe=0P1:BTX00`16
ATH0@T920492@P0203hn?P80>SXj0P0f=SH2038b<P80;bl_0P0[:b/202LW9`808b<S0P0O7al201`L
708061PH0P0D51@2010@408030`<00<02@T900H61P061PH00P0410@200<30`801PH60P0:2PX200l?
3`805ADE0P0M7Ad202DU9@80;2`/0P0e=CD203hn?P80BDU90P1ADE4205UIF@0305aLG01KFe/0Fe]K
0080FUYJ0P1HF5P205IFEP80EEEE0P1CDe<2055AD@80D51@0P1?Cdl204i>CP80CDe=0P1;Bd/704Y:
BP@0BDU91018B4P404M7A`@0ATI61P15ADD204I6AP80AdM70P19BDT204a<C00304m?C`1CDe<0De=C
0080FEUI0P1PH60206YZJP80L71`0P1bLW8207QhN080OGem0P21PH4208V9R@80Shn?0P2DU9@209ZJ
VP80WIfM0P2QXJ400`2UYJD0ZJVY0:VYZ@020:b/[080/K6a0P2d];@20;Ng]`80^KVi1P2k^k/20;bl
_080`<300P34a<@20<O7a`80bLW90P3<c<`30<g=c@80c<c<0P38b<P20<G5a@80`L710P2m_Kd20;Vi
^@80];Bd0P2_[jl20:^[Z`80YZJV0P2QXJ4209fMW@80V9RH0P2CTi<00`2?Shl0RXZ:08Z:RP0208F5
Q@80P8200P1lO7`207MgM`80LW9b0P1]KFdE0?ooo`004`3oool206EUI@80HF5Q0P1MGEd205UIF@80
EEEE0P1ADE4204e=C@80BDU900<0ADE50451@@11@D400P0m?Cd203Ti>@80=CDe0P0a<C4202h^;P80
:RXZ0P0V9RH2028R8P807QhN0P0J6QX201HF5P804Q8B0P0>3Ph200X:2P0300L71`051@D01@D500@0
10@40P071`L200`<30804Q8B0P0I6AT2024Q8@80:BTY0P0`<30203Xj>P80A4A40P1>CTh205MGE`80
FUYJ00<0FEUI05QHF01HF5P00P1GEeL205EEE@80E5AD0P1BDU82051@D080Cdm?0P1>CTh204e=C@80
C4a<101;Bd/=04Y:BP@0BDU90P18B4P404M7A`P0ATI60P17AdL204U9B@80Bd];00<0Cdm?05ADE01D
E5@00P1IFET2065QH@80JVYZ0P1bLW8207IfMP80Ng]k0P20P80208F5Q@80Rh^;0P2?Shl209BDU080
VYZJ0P2OWil20::RXP030:JVYP2YZJT0ZJVY0080[Jf]0P2b/[820;Jf]P80^KVi0P2k^k/20;fm_@H0
_[jn0P32`/820<K6aP80bLW90P3;bl/20<k>cP<0clo?0P3<c<`20<W9b@80aLG50P31`L420;fm_@80
^KVi0P2d];@20:n_[`80Zj^[0P2VYZH20::RXP80WIfM0P2HV9P209>CT`0308n?S`2:RXX0RXZ:0080
QHF50P20P80207alO080MgMg0P1bLW8206e]KAD0oooo000C0?ooo`80IFEU0P1QHF4205eMG@80FEUI
0P1EEED2055AD@80CDe=0P19BDT00`15ADD0@D510451@@0203dm?@80>CTi0P0e=CD2034a<@80;Rh^
0P0Z:RX202HV9P808R8R0P0N7Qh201XJ6P805QHF0P0B4Q8200h>3P802PX:00<01`L700D51@051@D0
100410@200L71`8030`<0P0B4Q8201TI6@808B4Q0P0Y:BT2030`<080>SXj0P14A4@204i>CP80EeMG
0P1JFUX00`1IFET0F5QH05QHF00205MGE`80EEEE0P1DE5@2059BDP80D51@0P1?Cdl204i>CP80CDe=
0P1<C4`404];B`d0BTY:1019BDT204Q8B0@0AdM72016ATH204M7A`80BDU90P1;Bd/00`1?Cdl0E5AD
05ADE00205UIF@80HF5Q0P1ZJVX2079bLP80MWIf0P1kNg/20820P080QHF50P2;Rh/208n?S`80U9BD
0P2JVYX209nOW`80XZ:R00<0YZJV0:VYZ@2YZJT00P2][Jd20;:b/P80][Jf0P2i^KT20;^k^`80_Kfm
1P2n_[h20<;2`P80a/K60P39bLT20<_;b`80c/k>0`3?cll20<c<c080bLW90P35aLD20<71`@80_Kfm
0P2i^KT20;Bd]080[jn_0P2[Zj/20:JVYP80XZ:R0P2MWId209RHV080Ti>C00<0Shn?08Z:RP2:RXX0
0P25QHD20820P080O7al0P1gMgL2079bLP80KFe]5@3oool001<0oooo0P1UIFD2065QH@80GEeM0P1I
FET205EEE@80D51@0P1=CDd204U9B@0304A4A010@400@4100080?3`l0P0i>CT203De=@80<30`0P0/
;2`202PX:08092@T0P0P820201`L70806ATI0P0E5AD2014A4@803@d=0P092@T00`061PH01@D500D5
1@0200@410801@D50P092@T200l?3`805ADE0P0L71`202DU9@80;Bd]0P0e=CD20410@080BTY:0P1D
E5@205UIF@80F5QH00<0EeMG05IFEP1FEUH00P1DE5@2059BDP80DE5A0P1?Cdl204i>CP@0CDe=0P1<
C4`404];B`T0BTY:201;Bd/404Y:BP@0B4Q81017AdL204I6AP@0AdM70P18B4P204Y:BP0304i>CP1C
De<0De=C0080FEUI0P1QHF4206YZJP80Lg=c0P1jNWX207emO@80PH610P28R8P208b<S080TI6A0P2E
UID209^KV`80X:2P0P2SXj<00`2WYjL0ZZZZ0:ZZZP020:n_[`80/k>c0P2h^;P20;Zj^P80_Kfm0P2o
_kl20<30`0@0`L710P34a<@20<O7a`80b/[:0P3=cLd50=3@d080cLg=0P3:b/X20<G5a@80`/;20P2m
_Kd20;Vi^@80];Bd0P2`/;020:^[Z`80YZJV0P2RXZ8209fMW@80V9RH0P2DU9@00`2?Shl0RXZ:08Z:
RP0208F5Q@80PH610P1lO7`207MgM`80LW9b0P1]KFdE0?ooo`004`3oool206EUI@80HF5Q0P1MGEd2
05UIF@80EEEE0P1@D50204e=C@80BDU900<0A4A40410@010@4000P0l?3`203Ti>@80=CDe0P0`<302
02`/;080:2PX0P0T92@2020P808071`L0P0I6AT201DE5@804A4A0P0=3@d200T92@0300H61P051@D0
1@D5008010@40P051@D200T92@803`l?0P0E5AD201`L70809BDU0P0];Bd203De=@80@4100P1:BTX2
05ADE080FEUI0P1HF5P00`1GEeL0EUIF05IFEP0205ADE080DU9B0P1ADE4204m?C`80CTi>101=CDd2
04a<C0@0Bd];2@1:BTX804];B`@0BTY:1018B4P404M7A`80ATI61017AdL204Q8B080BTY:00<0CTi>
05=CD`1CDe<00P1IFET2065QH@80JVYZ0P1cLg<207YjNP80OGem0P21PH4208R8R080S8b<0P2ATI42
09FEU@80Vi^K0P2PX:020:>SX`030:NWY`2ZZZX0ZZZZ0080[jn_0P2c/k<20;Rh^080^[Zj0P2m_Kd2
0;no_`80`<301031`L420<C4a080alO70P3:b/X20<g=c@D0d=3@0P3=cLd20<[:bP80aLG50P32`/82
0;fm_@80^KVi0P2d];@20;2`/080Zj^[0P2VYZH20::RXP80WIfM0P2HV9P209BDU00308n?S`2:RXX0
RXZ:0080QHF50P21PH4207alO080MgMg0P1bLW8206e]KAD0oooo000C0?ooo`80I6AT0P1PH60205eM
G@80F5QH0P1DE5@2051@D080C4a<0P18B4P00`14A4@0@4100410@00203/k>`80>3Ph0P0c<c<202l_
;`80:b/[0P0W9bL202<S8`807alO0P0K6a/201LG5`804a<C0P0?3`l200/;2`801`L700<01@D500@4
100410@00P0410@200H61P802`/;0P0B4Q8201TI6@80820P0P0Y:BT2034a<@80>c/k0P15ADD204m?
C`80F5QH0P1GEeL205IFEP0305EEE@1DE5@0E5AD0080DU9B0P1@D50204i>CP@0C4a<0P1=CDd404a<
C0@0Bd];201:BTX00`1;Bd/0C4a<04a<C00604e=C@80C4a<0P1;Bd/204Y:BP80BDU90P18B4P604M7
A`80B4Q80P19BDT204Y:BP0304e=C@1BDU80DU9B0080F5QH0P1PH60206YZJP80M7Ad0P1kNg/20820
P080Q8B40P2:RXX208j>SP80TY:B0P2GUiL209^KV`80X:2P0P2TY:@00`2XZ:P0Zj^[0:^[Z`020:n_
[`80];Bd0P2i^KT20;^k^`80_[jn0P31`L420<?3``@0a<C40P35aLD20<W9b@80bl_;0P3>c/h20=7A
d@030=;BdP3AdM40dM7A0080c/k>0P3:b/X20<K6aP80`/;20P2n_[h20;Vi^@80];Bd0P2`/;020:^[
Z`80YjNW0P2RXZ8209fMW@80V9RH0P2DU9@00`2?Shl0RXZ:08Z:RP0208F5Q@80PH610P1lO7`207Mg
M`80LW9b0P1]KFdE0?ooo`004`3oool206ATI080H61P0P1LG5`205QHF080E5AD0P1@D50204a<C080
AdM700<0@d=303lo?`0o?cl00P0k>c/203Lg=`80<S8b0P0^;Rh202XZ:P809RHV0P0R8R8201dM7@80
6QXJ0P0E5AD2014A4@803@d=0P092@T200H61PD010@40P0820P200h>3P805ADE0P0M7Ad202@T9080
;Rh^0P0g=cL20451@@80Bd];0P1EEED205UIF@80EeMG0P1EEED00`1DE5@0DU9B059BDP02051@D080
CDe=0P1<C4`204];B`80C4a<0P1>CTh204a<C0P0Bd];101:BTX204];B`0304a<C01=CDd0CDe=0080
CTi>101?Cdl204i>CP80CDe=0P1;Bd/204Y:BP80BDU92018B4P204U9B@80Bd];00<0CDe=055AD@1A
DE400P1GEeL2061PH080JFUY0P1cLg<207]kN`80Ph>30P26QXH208Z:RP80T92@0P2CTi<209VIV@80
WIfM0P2PX:020:FUY@030:VYZ@2/[:`0[:b/0080/;2`0P2e]KD20;Vi^@80_Kfm0P2o_kl20<?3``80
aLG51P37alL20<[:bP80cLg=0P3@d=020=?Cd`030=CDe03AdM40dM7A0080c/k>0P3:b/X20<K6aP80
`l?30P2n_[h20;Vi^@80]KFe0P2`/;020:^[Z`80YjNW0P2RXZ8209fMW@80V9RH0P2DU9@00`2?Shl0
RXZ:08Z:RP0208F5Q@80PH610P1lO7`207MgM`80LW9b0P1]KFdE0?ooo`004`3oool206ATI080H61P
0P1LG5`205QHF080E5AD0P1@D50204a<C080AdM700<0@d=303lo?`0o?cl00P0k>c/203Lg=`80<S8b
0P0^;Rh202XZ:P809RHV0P0R8R8201dM7@806QXJ0P0E5AD2014A4@803@d=0P092@T200H61PD010@4
0P0820P200h>3P805ADE0P0M7Ad202@T9080;Rh^0P0g=cL20451@@80Bd];0P1EEED205UIF@80EeMG
0P1EEED00`1DE5@0DU9B059BDP02051@D080CDe=0P1<C4`204];B`80C4a<0P1>CTh204a<C0P0Bd];
101:BTX204];B`0304a<C01=CDd0CDe=0080CTi>101?Cdl204i>CP80CDe=0P1;Bd/204Y:BP80BDU9
2018B4P204U9B@80Bd];00<0CDe=055AD@1ADE400P1GEeL2061PH080JFUY0P1cLg<207]kN`80Ph>3
0P26QXH208Z:RP80T92@0P2CTi<209VIV@80WIfM0P2PX:020:FUY@030:VYZ@2/[:`0[:b/0080/;2`
0P2e]KD20;Vi^@80_Kfm0P2o_kl20<?3``80aLG51P37alL20<[:bP80cLg=0P3@d=020=?Cd`030=CD
e03AdM40dM7A0080c/k>0P3:b/X20<K6aP80`l?30P2n_[h20;Vi^@80]KFe0P2`/;020:^[Z`80YjNW
0P2RXZ8209fMW@80V9RH0P2DU9@00`2?Shl0RXZ:08Z:RP0208F5Q@80PH610P1lO7`207MgM`80LW9b
0P1]KFdE0?ooo`004`3oool206ATI080H61P0P1LG5`205QHF080De=C0P1?Cdl204];B`80AdM700<0
@T9203hn?P0n?Sh00P0j>SX203Hf=P80<C4a0P0];Bd202TY:@809BDU0P0P820201`L708061PH0P0D
51@2010@408030`<0P071`L200D51@<00`<30P061PH200/;2`804A4A0P0I6AT2024Q8@80:BTY0P0b
<S8203`l?080AdM70P1ADE4205QHF080EeMG0P1FEUH205ADE00305=CD`1@D500D51@0080CTi>101;
Bd/404a<C080CDe=0P1<C4`604];B`@0BTY:0P1;Bd/204a<C0<0CTi>0P1?Cdl2051@D080DE5A0P1@
D50204m?C`80CDe=0P1;Bd/204Y:BP80BDU90P18B4P404U9B@80BTY:0P1<C4`00`1>CTh0DE5A055A
D@0205IFEP80GUiN0P1WIfL207=cL`80Ng]k0P24Q8@208N7Q`80Rh^;0P2ATI4209FEU@80VYZJ0P2O
Wil20:>SX`80YJFU00<0ZJVY0:b/[02/[:`00P2a/K420;Fe]@80^[Zj0P2n_[h20<71`@80a<C40P37
alL60<W9b@80c<c<0P3?cll20=;BdP80e=CD00<0eMGE0=;BdP3Bd]800P3?cll20<_;b`80alO70P33
`l<20;jn_P80^[Zj0P2e]KD20;2`/080[:b/0P2WYjL20::RXP80WIfM0P2IVIT209BDU00308n?S`2:
RXX0RXZ:0080QHF50P21PH4207alO080MgMg0P1bLW8206e]KAD0oooo000C0?ooo`80I6AT0P1PH602
05aLG080F5QH0P1CDe<204m?C`80Bd];0P17AdL00`12@T80?Shn03hn?P0203Xj>P80=SHf0P0a<C42
02d];@80:BTY0P0U9BD2020P808071`L0P0H61P201@D5080410@0P0<30`200L71`801@D50`030`<2
00H61P802`/;0P0A4A4201TI6@808B4Q0P0Y:BT2038b<P80?3`l0P17AdL2055AD@80F5QH0P1GEeL2
05IFEP80E5AD00<0De=C051@D01@D5000P1>CTh404];B`@0C4a<0P1=CDd204a<C0H0Bd];101:BTX2
04];B`80C4a<0`1>CTh204m?C`80D51@0P1ADE42051@D080Cdm?0P1=CDd204];B`80BTY:0P19BDT2
04Q8B0@0BDU90P1:BTX204a<C00304i>CP1ADE40DE5A0080EUIF0P1NGUh206MWI`80Lg=c0P1kNg/2
08B4Q080QhN70P2;Rh/2096AT@80UIFE0P2JVYX209nOW`80Xj>S0P2UYJD00`2YZJT0[:b/0:b/[002
0;6a/@80]KFe0P2j^[X20;jn_P80`L710P34a<@20<O7a`H0bLW90P3<c<`20<o?c`80d];B0P3De=@0
0`3EeMD0d];B0=;BdP020<o?c`80bl_;0P37alL20<?3``80_[jn0P2j^[X20;Fe]@80/;2`0P2/[:`2
0:NWY`80XZ:R0P2MWId209VIV@80U9BD00<0Shn?08Z:RP2:RXX00P25QHD20861P@80O7al0P1gMgL2
079bLP80KFe]5@3oool001<0oooo0P1TI6@2061PH080G5aL0P1HF5P205=CD`80Cdm?0P1;Bd/204I6
AP030492@P0n?Sh0?Shn0080>CTi0P0e=CD2030`<080;2`/0P0X:2P202<S8`807alO0P0K6a/201LG
5`804Q8B0P0>3Ph200X:2P801PH60P0410@00`030`<010@400@4100200P820803@d=0P0D51@201dM
7@809BDU0P0^;Rh203Ph>080@d=30P1=CDd205MGE`80F5QH0P1GEeL205EEE@80E5AD00<0DU9B04m?
C`1?Cdl00P1=CDd404];B`80C4a<101=CDd604a<C0H0Bd];0P1=CDd204i>CP<0Cdm?0P1@D502055A
D@@0DU9B0P1@D50204i>CP80C4a<0P1;Bd/204Y:BP@0BDU90P1:BTX204];B`80C4a<00<0CTi>055A
D@1ADE400P1EEED205aLG080IFEU0P1aLG4207]kN`80Ph>30P29RHT208f=S@80TI6A0P2GUiL209ZJ
VP80XJ6Q0P2UYJD20:NWY`030:VYZ@2^[Zh0[Zj^0080/K6a0P2f][H20;^k^`80_kno0P32`/820<G5
a@80bLW90P3;bl/40<c<c080cLg=0P3AdM420=?Cd`<0e]KF0P3Cdm<20<o?c`80bl_;0P37alL20<?3
``80_kno0P2j^[X20;Fe]@80/;2`0P2/[:`20:NWY`80XZ:R0P2MWId209VIV@80U9BD00<0Shn?08Z:
RP2:RXX00P25QHD20820P080O7al0P1gMgL2079bLP80KFe]5@3oool001<0oooo0P1TI6@2061PH080
G5aL0P1HF5P205=CD`80Cdm?0P1;Bd/204I6AP030492@P0n?Sh0?Shn0080>CTi0P0e=CD2030`<080
;2`/0P0X:2P202<S8`807alO0P0K6a/201LG5`804Q8B0P0>3Ph200X:2P801PH60P0410@00`030`<0
10@400@4100200P820803@d=0P0D51@201dM7@809BDU0P0^;Rh203Ph>080@d=30P1=CDd205MGE`80
F5QH0P1GEeL205EEE@80E5AD00<0DU9B04m?C`1?Cdl00P1=CDd404];B`80C4a<101=CDd604a<C0H0
Bd];0P1=CDd204i>CP<0Cdm?0P1@D502055AD@@0DU9B0P1@D50204i>CP80C4a<0P1;Bd/204Y:BP@0
BDU90P1:BTX204];B`80C4a<00<0CTi>055AD@1ADE400P1EEED205aLG080IFEU0P1aLG4207]kN`80
Ph>30P29RHT208f=S@80TI6A0P2GUiL209ZJVP80XJ6Q0P2UYJD20:NWY`030:VYZ@2^[Zh0[Zj^0080
/K6a0P2f][H20;^k^`80_kno0P32`/820<G5a@80bLW90P3;bl/40<c<c080cLg=0P3AdM420=?Cd`<0
e]KF0P3Cdm<20<o?c`80bl_;0P37alL20<?3``80_kno0P2j^[X20;Fe]@80/;2`0P2/[:`20:NWY`80
XZ:R0P2MWId209VIV@80U9BD00<0Shn?08Z:RP2:RXX00P25QHD20820P080O7al0P1gMgL2079bLP80
KFe]5@3oool001<0oooo0P1TI6@2061PH080G5aL0P1GEeL205=CD`80CTi>0P1:BTX204I6AP030451
@@0m?Cd0?Cdm0080>3Ph0P0d=3@2030`<080:b/[0P0W9bL2028R8P807QhN0P0I6AT201DE5@804A4A
0P0<30`200P820801@D50`030`<200H61P802PX:0P0@410201PH60808B4Q0P0Z:RX203@d=080?Shn
0P19BDT205ADE080F5QH101GEeL205EEE@80E5AD00<0DU9B04m?C`1?Cdl00P1?Cdl404a<C0`0CTi>
1P1=CDd204m?C`80D51@00<0DE5A05=CD`1CDe<0101CDe<205ADE080De=C0P1ADE4204m?C`80CDe=
101;Bd/604Y:BP80Bd];0P1=CDd00`1>CTh0DE5A055AD@0205ADE080FUYJ0P1TI6@206m_K`80NWYj
0P22PX8208V9R@80SXj>0P2ATI4209NGU`80W9bL0P2QXJ420:NWY`80ZJVY00<0Zj^[0:f][@2][Jd0
0P2b/[820;Ng]`80^k^k0P30`<020<?3``80alO70P3;bl/20<g=c@80c/k>103?cll20=;BdP80e=CD
0`3GemL20=?Cd`80clo?0P3<c<`20<S8b080a<C40P2o_kl20;Zj^P80]KFe0P2a/K420:b/[080YjNW
0P2RXZ8209fMW@80VIVI0P2DU9@00`2?Shl0RXZ:08Z:RP0208F5Q@80PH610P1lO7`207MgM`80LW9b
0P1]KFdE0?ooo`004`3oool206ATI080H61P0P1LG5`205MGE`80De=C0P1>CTh204Y:BP80ATI600<0
@D5103dm?@0m?Cd00P0h>3P203@d=080<30`0P0[:b/202LW9`808R8R0P0N7Qh201TI6@805ADE0P0A
4A4200`<308020P80P051@D300<30`801PH60P0:2PX2010@408061PH0P0Q8B4202XZ:P80=3@d0P0n
?Sh204U9B@80E5AD0P1HF5P405MGE`80EEEE0P1DE5@00`1BDU80Cdm?04m?C`0204m?C`@0C4a<301>
CTh604e=C@80Cdm?0P1@D5000`1ADE40De=C05=CD`0405=CD`80E5AD0P1CDe<2055AD@80Cdm?0P1=
CDd404];B`H0BTY:0P1;Bd/204e=C@0304i>CP1ADE40DE5A0080E5AD0P1JFUX206ATI080Kfm_0P1j
NWX208:2PP80RHV90P2>SXh2096AT@80UiNG0P2LW9`20:6QX@80YjNW0P2YZJT00`2[Zj/0[Jf]0:f]
[@020;:b/P80]kNg0P2k^k/20<30`080`l?30P37alL20<_;b`80cLg=0P3>c/h40<o?c`80d];B0P3D
e=@30=OGe`80dm?C0P3?cll20<c<c080b<S80P34a<@20;no_`80^[Zj0P2e]KD20;6a/@80[:b/0P2W
YjL20::RXP80WIfM0P2IVIT209BDU00308n?S`2:RXX0RXZ:0080QHF50P21PH4207alO080MgMg0P1b
LW8206e]KAD0oooo000C0?ooo`80I6AT0P1PH60205]KF`80EeMG0P1BDU8204i>CP80BTY:0P15ADD0
0`11@D40?3`l03`l?00203Ph>080<c<c0P0_;bl202XZ:P809RHV0P0Q8B4201`L708061PH0P0C4a<2
00l?3`802`/;0P071`L200@410800P8200<00`<300L71`071`L00P0=3@d201@D50807AdM0P0U9BD2
02l_;`80>CTi0P14A4@204i>CPH0F5QH0P1GEeL205EEE@80E5AD00<0DU9B055AD@1ADE400P1@D504
04i>CP`0Cdm?0P1>CTh404m?C`80D51@0P1ADE400`1BDU80De=C05=CD`0605=CD`80DU9B0P1ADE42
04m?C`80CDe=0P1<C4`404];B`80BTY:0P1;Bd/204a<C080CDe=00<0Cdm?055AD@1ADE400P1DE5@2
05UIF@80HV9R0P1]KFd207UiN@80PH610P29RHT208j>SP80TY:B0P2FUYH209jNWP80XZ:R0P2YZJT2
0:b/[0030:j^[P2_[jl0[jn_0080];Bd0P2g]kL20;^k^`80`<300P34a<@20<S8b080cLg=0P3>c/h6
0=7Ad@80e=CD0P3Fe]H20=WIf@030=OGe`3De=@0e=CD0080d=3@0P3<c<`20<W9b@80a<C40P2o_kl2
0;Zj^P80][Jf0P2a/K420:b/[080YjNW0P2RXZ8209jNWP80VIVI0P2DU9@00`2?Shl0RXZ:08Z:RP02
08F5Q@80PH610P1lO7`207MgM`80LW9b0P1]KFdE0?ooo`004`3oool206ATI080H61P0P1KFe/205MG
E`80DU9B0P1>CTh204Y:BP80ADE500<0@D5103`l?00l?3`00P0h>3P203<c<`80;bl_0P0Z:RX202HV
9P808B4Q0P0L71`201PH60804a<C0P0?3`l200/;2`801`L70P0410@200820P0300<30`071`L01`L7
00803@d=0P0D51@201dM7@809BDU0P0_;bl203Ti>@80A4A40P1>CTh605QHF080EeMG0P1EEED205AD
E003059BDP1ADE40DE5A0080D51@101>CTh<04m?C`80CTi>101?Cdl2051@D080DE5A00<0DU9B05=C
D`1CDe<01P1CDe<2059BDP80DE5A0P1?Cdl204e=C@80C4a<101;Bd/204Y:BP80Bd];0P1<C4`204e=
C@0304m?C`1ADE40DE5A0080E5AD0P1IFET2069RHP80KFe]0P1iNGT20861P@80RHV90P2>SXh209:B
TP80UYJF0P2NWYh20::RXP80ZJVY0P2/[:`00`2^[Zh0[jn_0:n_[`020;Bd]080]kNg0P2k^k/20<30
`080a<C40P38b<P20<g=c@80c/k>1P3AdM420=CDe080e]KF0P3IfMT00`3GemL0e=CD0=CDe0020=3@
d080c<c<0P39bLT20<C4a080_kno0P2j^[X20;Jf]P80/K6a0P2/[:`20:NWY`80XZ:R0P2NWYh209VI
V@80U9BD00<0Shn?08Z:RP2:RXX00P25QHD20861P@80O7al0P1gMgL2079bLP80KFe]5@3oool001<0
oooo0P1TI6@2061PH080Fe]K0P1GEeL2059BDP80CTi>0P19BDT204E5A@030410@00l?3`0?3`l0080
=cLg0P0b<S8202h^;P80:BTY0P0T92@2020P80806a/K0P0F5QH2018B4P803@d=0P092@T200D51@80
0`<30P020P800`0410@02@T900T92@02010@408061PH0P0P820202XZ:P80=3@d0P0o?cl204U9B@80
E5AD0P1JFUX205UIF@80F5QH0P1GEeL205IFEP80E5AD00<0De=C059BDP1BDU800P1ADE42051@D0@0
Cdm?1P1>CTh204e=C@P0CTi>0P1?Cdl2051@D003055AD@1BDU80DU9B00H0DU9B0P1ADE42051@D080
Cdm?0P1=CDd204a<C0P0Bd];0P1<C4`204e=C@0304m?C`1ADE40DE5A0080E5AD0P1HF5P205mOG`80
Jf][0P1gMgL20820P080R8R80P2>SXh209>CT`80UiNG0P2NWYh20:BTY080ZZZZ0P2_[jl00`2`/;00
/[:b0;:b/P020;Fe]@80^;Rh0P2l_;`20<71`@80aLG50P39bLT20<g=c@80dM7A0P3De=@40=?Cd`80
eMGE0P3GemL20=_Kf`030=SHf03De=@0e=CD0080dM7A0P3=cLd20<W9b@80a<C40P2o_kl20;Zj^P80
][Jf0P2a/K420:b/[080YjNW0P2RXZ8209jNWP80VIVI0P2DU9@00`2?Shl0RXZ:08Z:RP0208F5Q@80
PH610P1lO7`207MgM`80LW9b0P1]KFdE0?ooo`004`3oool206ATI080H61P0P1KFe/205MGE`80DU9B
0P1>CTh204U9B@80ADE500<0@41003`l?00l?3`00P0g=cL2038b<P80;Rh^0P0Y:BT202@T9080820P
0P0K6a/201HF5P804Q8B0P0=3@d200T92@801@D50P030`<200820P0300@410092@T02@T90080410@
0P0H61P2020P8080:RXZ0P0d=3@203lo?`80BDU90P1DE5@205YJFP80FEUI0P1HF5P205MGE`80EUIF
0P1DE5@00`1CDe<0DU9B059BDP02055AD@80D51@101?Cdl604i>CP80CDe=201>CTh204m?C`80D51@
00<0DE5A059BDP1BDU801P1BDU82055AD@80D51@0P1?Cdl204e=C@80C4a<201;Bd/204a<C080CDe=
00<0Cdm?055AD@1ADE400P1DE5@205QHF080GemO0P1[Jf/207MgM`80P8200P28R8P208j>SP80Ti>C
0P2GUiL209jNWP80Y:BT0P2ZZZX20:n_[`030;2`/02b/[80/[:b0080]KFe0P2h^;P20;bl_080`L71
0P35aLD20<W9b@80cLg=0P3AdM420=CDe0@0dm?C0P3EeMD20=OGe`80fm_K00<0f=SH0=CDe03De=@0
0P3AdM420<g=c@80bLW90P34a<@20;no_`80^[Zj0P2f][H20;6a/@80[:b/0P2WYjL20::RXP80WYjN
0P2IVIT209BDU00308n?S`2:RXX0RXZ:0080QHF50P21PH4207alO080MgMg0P1bLW8206e]KAD0oooo
000C0?ooo`80I6AT0P1PH60205]KF`80EUIF0P1BDU8204e=C@80BDU90P14A4@00`10@400>c/k03/k
>`0203Hf=P80<S8b0P0];Bd202PX:0808b<S0P0O7al201XJ6P805ADE0P0@410200`<30801`L70P03
0`<400820P0300H61P0<30`030`<00804a<C0P0L71`202DU9@80;bl_0P0i>CT204=3@`80CTi>0P1I
FET205YJFP@0FEUI0P1HF5P205IFEP80EEEE00<0E5AD059BDP1BDU800P1ADE42051@D0@0Cdm?0P1>
CTh404e=C@80C4a<201=CDd204m?C`80D51@00<0DE5A059BDP1BDU80101BDU84055AD@80Cdm?0P1>
CTh204e=C@@0C4a<1P1;Bd/204a<C080CDe=00<0Cdm?055AD@1ADE400P1DE5@205QHF080GUiN0P1Y
JFT207AdM080Ogmo0P27QhL208f=S@80Ti>C0P2HV9P209jNWP80YJFU0P2ZZZX20;2`/0030;>c/`2e
]KD0]KFe0080][Jf0P2j^[X20;fm_@80`/;20P36a/H20<_;b`80clo?0P3Cdm<20=GEe@80e]KF0P3E
eMD20=OGe`80fMWI0P3Lg=`00`3IfMT0eMGE0=GEe@020=7Ad@80c/k>0P39bLT20<G5a@80`<300P2k
^k/20;Jf]P80/K6a0P2/[:`20:NWY`80XZ:R0P2NWYh209VIV@80U9BD00<0Shn?08Z:RP2:RXX00P25
QHD20861P@80O7al0P1gMgL2079bLP80KFe]5@3oool001<0oooo0P1TI6@2061PH080Fe]K0P1FEUH2
059BDP80CDe=0P19BDT204A4A0030410@00k>c/0>c/k0080=SHf0P0b<S8202d];@80:2PX0P0S8b<2
01lO7`806QXJ0P0E5AD2010@408030`<0P071`L200<30`@00P8200<01PH600`<300<30`00P0C4a<2
01`L70809BDU0P0_;bl203Ti>@80@d=30P1>CTh205UIF@80FUYJ101IFET205QHF080EUIF0P1EEED0
0`1DE5@0DU9B059BDP02055AD@80D51@101?Cdl204i>CP@0CDe=0P1<C4`804e=C@80Cdm?0P1@D500
0`1ADE40DU9B059BDP04059BDP@0DE5A0P1?Cdl204i>CP80CDe=101<C4`604];B`80C4a<0P1=CDd0
0`1?Cdl0DE5A055AD@0205ADE080F5QH0P1NGUh206UYJ@80M7Ad0P1oOgl208N7Q`80SHf=0P2CTi<2
09RHV080WYjN0P2UYJD20:ZZZP80/;2`00<0/k>c0;Fe]@2e]KD00P2f][H20;Zj^P80_Kfm0P32`/82
0<K6aP80bl_;0P3?cll20=?Cd`80eMGE0P3Fe]H20=GEe@80emOG0P3IfMT20=cLg0030=WIf@3EeMD0
eMGE0080dM7A0P3>c/h20<W9b@80aLG50P30`<020;^k^`80][Jf0P2a/K420:b/[080YjNW0P2RXZ82
09jNWP80VIVI0P2DU9@00`2?Shl0RXZ:08Z:RP0208F5Q@80PH610P1lO7`207MgM`80LW9b0P1]KFdE
0?ooo`004`3oool206ATI080GemO0P1KFe/205IFEP80DU9B0P1=CDd204Q8B080@d=300<0?clo03Xj
>P0j>SX00P0e=CD2034a<@80;2`/0P0W9bL2028R8P807AdM0P0H61P201@D50803`l?0P0:2PX200D5
1@800P820P010@4200@4100300P8200?3`l03`l?00805aLG0P0O7al202TY:@80<c<c0P0n?Sh204Q8
B080DU9B0P1LG5`205]KF`@0FUYJ0P1HF5P205MGE`80EUIF00<0E5AD05=CD`1CDe<00P1BDU82051@
D080Cdm?101>CTh204e=C@X0C4a<0P1=CDd204m?C`<0D51@0P1ADE44059BDP@0DE5A0P1@D50204i>
CP80CDe=101<C4`404];B`@0C4a<0P1=CDd00`1?Cdl0DE5A055AD@0205ADE080EeMG0P1MGEd206IV
IP80LG5a0P1mOGd208J6QP80SHf=0P2CTi<209VIV@80WYjN0P2UYJD20:^[Z`80/K6a00<0]KFe0;Rh
^02h^;P00P2j^[X20;bl_080_[jn0P33`l<20<K6aP80c<c<0P3@d=020=GEe@80emOG103Hf=P20=WI
f@@0g=cL00<0f][J0=KFeP3Fe]H00P3Bd]820<o?c`80b/[:0P35aLD20<30`080^k^k0P2f][H20;6a
/@80[:b/0P2WYjL20:>SX`80WYjN0P2IVIT209BDU00308n?S`2:RXX0RXZ:0080QHF50P21PH4207al
O080MgMg0P1bLW8206e]KAD0oooo000C0?ooo`80I6AT0P1OGel205]KF`80EUIF0P1BDU8204e=C@80
B4Q80P13@d<00`0o?cl0>SXj03Xj>P0203De=@80<C4a0P0/;2`202LW9`808R8R0P0M7Ad201PH6080
51@D0P0?3`l200X:2P801@D50P020P8200410@8010@400<020P800l?3`0?3`l00P0G5aL201lO7`80
:BTY0P0c<c<203hn?P80B4Q80P1BDU8205aLG080Fe]K101JFUX205QHF080EeMG0P1FEUH00`1DE5@0
De=C05=CD`02059BDP80D51@0P1?Cdl404i>CP80CDe=2P1<C4`204e=C@80Cdm?0`1@D502055AD@@0
DU9B101ADE42051@D080CTi>0P1=CDd404a<C0@0Bd];101<C4`204e=C@0304m?C`1ADE40DE5A0080
E5AD0P1GEeL205eMG@80IVIV0P1aLG4207emO@80QXJ60P2=SHd209>CT`80VIVI0P2NWYh20:FUY@80
Zj^[0P2a/K400`2e]KD0^;Rh0;Rh^0020;Zj^P80_;bl0P2n_[h20<?3``80a/K60P3<c<`20=3@d080
eMGE0P3GemL40=SHf080fMWI103Lg=`00`3Jf]X0e]KF0=KFeP020=;BdP80clo?0P3:b/X20<G5a@80
`<300P2k^k/20;Jf]P80/K6a0P2/[:`20:NWY`80Xj>S0P2NWYh209VIV@80U9BD00<0Shn?08Z:RP2:
RXX00P25QHD20861P@80O7al0P1gMgL2079bLP80KFe]5@3oool001<0oooo0P1TI6@205mOG`80Fe]K
0P1FEUH2055AD@80CDe=0P18B4P204=3@`0303hn?P0i>CT0>CTi0080=CDe0P0`<30202/[:`809RHV
0P0Q8B4201`L70805aLG0P0B4Q8200d=3@8020P80P0410@400820P801@D500<02`/;018B4P0B4Q80
0P0J6QX202<S8`80;Rh^0P0g=cL20492@P80C4a<0P1GEeL205mOG`80GEeM0P1KFe/205YJFP80FEUI
0P1GEeL205IFEP0305EEE@1CDe<0De=C0080DU9B0P1ADE4204m?C`80CTi>0P1=CDd204a<C0H0Bd];
101<C4`204e=C@80CTi>0P1@D503055AD@@0DU9B101ADE42051@D080CTi>0P1=CDd404a<C0@0Bd];
101<C4`204i>CP0304m?C`1ADE40DE5A0080E5AD0P1GEeL205aLG080I6AT0P1`L70207]kN`80QHF5
0P2<S8`209>CT`80VIVI0P2OWil20:BTY080[:b/0P2b/[800`2h^;P0^k^k0;^k^`020;bl_080_[jn
0P30`<020<C4a080b<S80P3>c/h20=;BdP80e]KF0P3Hf=P20=_Kf`80f][J0P3Kfm/20=kNgP80g=cL
00<0fm_K0=OGe`3GemL00P3Cdm<20<o?c`80b/[:0P35aLD20<30`080^k^k0P2f][H20;6a/@80[:b/
0P2XZ:P20:>SX`80WYjN0P2IVIT209BDU00308n?S`2:RXX0RXZ:0080QXJ60P21PH4207alO080MgMg
0P1bLW8206e]KAD0oooo000C0?ooo`80I6AT0P1OGel205]KF`80EUIF0P1ADE4204e=C@80B4Q80P13
@d<00`0n?Sh0>CTi03Ti>@0203De=@80<30`0P0[:b/202HV9P808B4Q0P0L71`201LG5`804Q8B0P0=
3@d200P8208010@410020P8200D51@0300/;2`0B4Q804Q8B00806QXJ0P0S8b<202h^;P80=cLg0P12
@T8204a<C080EeMG0P1OGel205eMG@80Fe]K0P1JFUX205UIF@80EeMG0P1FEUH00`1EEED0De=C05=C
D`02059BDP80DE5A0P1?Cdl204i>CP80CDe=0P1<C4`604];B`@0C4a<0P1=CDd204i>CP80D51@0`1A
DE44059BDP@0DE5A0P1@D50204i>CP80CDe=101<C4`404];B`@0C4a<0P1>CTh00`1?Cdl0DE5A055A
D@0205ADE080EeMG0P1LG5`206ATI080L71`0P1kNg/208F5Q@80S8b<0P2CTi<209VIV@80WinO0P2T
Y:@20:b/[080/[:b00<0^;Rh0;^k^`2k^k/00P2l_;`20;jn_P80`<300P34a<@20<S8b080c/k>0P3B
d]820=KFeP80f=SH0P3Kfm/20=[JfP80fm_K0P3Ng]h20=cLg0030=_Kf`3GemL0emOG0080dm?C0P3?
cll20<[:bP80aLG50P30`<020;^k^`80][Jf0P2a/K420:b/[080Z:RX0P2SXj<209jNWP80VIVI0P2D
U9@00`2?Shl0RXZ:08Z:RP0208J6QP80PH610P1lO7`207MgM`80LW9b0P1]KFdE0?ooo`004`3oool2
06ATI080GemO0P1JFUX205IFEP80DE5A0P1<C4`204M7A`80@T9200<0?Shn03Ti>@0i>CT00P0d=3@2
02l_;`80:RXZ0P0U9BD2020P80806a/K0P0F5QH2014A4@8030`<0P071`L200820P800@410P030`<2
00L71`0300h>3P0F5QH05QHF00807QhN0P0W9bL2034a<@80?3`l0P16ATH2051@D080G5aL0P1OGel2
05iNGP80G5aL0P1KFe/205YJFP80F5QH0P1FEUH00`1EEED0De=C05=CD`02059BDP80DE5A0P1?Cdl2
04i>CP80CDe=0P1<C4`404];B`80BTY:0P1;Bd/204a<C080CDe=0P1?Cdl2051@D003055AD@1BDU80
DU9B00H0DU9B0P1ADE42051@D080CTi>101=CDd204a<C0@0Bd];101<C4`204i>CP0304m?C`1ADE40
DE5A0080De=C0P1GEeL205aLG080Hf=S0P1]KFd207UiN@80Ph>30P2;Rh/209>CT`80VIVI0P2PX:02
0:FUY@80[:b/0P2b/[800`2k^k/0_;bl0;bl_0020;no_`@0`/;20P36a/H20<W9b@80c/k>0P3Cdm<2
0=OGe`80f][J1P3MgMd20=oOg`80gMgM00<0fm_K0=OGe`3GemL00P3De=@20<o?c`80b/[:0P35aLD2
0<30`080^k^k0P2f][H20;6a/@80[:b/0P2XZ:P20:>SX`80WYjN0P2IVIT209BDU00308n?S`2:RXX0
RXZ:0080QXJ60P21PH4207alO080MgMg0P1bLW8206e]KAD0oooo000C0?ooo`80I6AT0P1OGel205YJ
FP80EUIF0P1ADE4204a<C080AdM70P12@T800`0n?Sh0>CTi03Ti>@0203@d=080;bl_0P0Z:RX202DU
9@80820P0P0K6a/201HF5P804A4A0P0<30`200L71`800P820P010@4200<30`801`L700<03Ph>01HF
5P0F5QH00P0N7Qh202LW9`80<C4a0P0l?3`204I6AP80D51@0P1LG5`205mOG`80GUiN0P1LG5`205]K
F`80FUYJ0P1HF5P205IFEP0305EEE@1CDe<0De=C0080DU9B0P1ADE4204m?C`80CTi>0P1=CDd204a<
C0@0Bd];0P1:BTX204];B`80C4a<0P1=CDd204m?C`80D51@00<0DE5A059BDP1BDU801P1BDU82055A
D@80D51@0P1>CTh404e=C@80C4a<101;Bd/404a<C080CTi>00<0Cdm?055AD@1ADE400P1CDe<205MG
E`80G5aL0P1SHf<206e]K@80NGUi0P23Ph<208^;R`80Ti>C0P2IVIT20:2PX080YJFU0P2/[:`20;:b
/P030;^k^`2l_;`0_;bl0080_kno1032`/820<K6aP80bLW90P3>c/h20=?Cd`80emOG0P3Jf]X60=gM
g@80gmoO0P3MgMd00`3Kfm/0emOG0=OGe`020=CDe080clo?0P3:b/X20<G5a@80`<300P2k^k/20;Jf
]P80/K6a0P2/[:`20:RXZ080Xj>S0P2NWYh209VIV@80U9BD00<0Shn?08Z:RP2:RXX00P26QXH20861
P@80O7al0P1gMgL2079bLP80KFe]5@3oool001<0oooo0P1TI6@205mOG`80FUYJ0P1EEED2055AD@80
C4a<0P17AdL20492@P0303dm?@0h>3P0>3Ph0080<c<c0P0^;Rh202TY:@8092@T0P0O7al201XJ6P80
5ADE0P0@410200/;2`801@D510010@4200@410802PX:00<04A4A01TI6@0I6AT00P0R8R8202/[:`80
=SHf0P10@40204U9B@80E5AD101PH60205mOG`80GEeM0P1LG5`205YJFP80FEUI0P1GEeL00`1EEED0
E5AD05ADE002059BDP80DE5A0P1?Cdl204e=C@80C4a<0P1=CDd204a<C080Bd];101:BTX204];B`80
CDe=101?Cdl00`1ADE40DU9B059BDP0405=CD`80DU9B0P1ADE42051@D080Cdm?101=CDd804a<C080
CDe=0P1>CTh00`1?Cdl0DE5A055AD@0205=CD`80EeMG0P1KFe/2065QH@80JVYZ0P1gMgL208:2PP80
Rh^;0P2CTi<209ZJVP80XJ6Q0P2VYZH20:b/[080];Bd00<0^k^k0;no_`2o_kl00P33`l<20<C4a080
aLG50P37alL20<_;b`80clo?0P3De=@20=WIf@80gMgM103Ogml20>3Ph0@0g]kN00<0fm_K0=WIf@3I
fMT00P3EeMD20<o?c`80b/[:0P35aLD20<30`080^k^k0P2f][H20;6a/@80[:b/0P2XZ:P20:>SX`80
WYjN0P2IVIT209BDU00308n?S`2:RXX0RXZ:0080QHF50P21PH4207alO080MgMg0P1bLW8206e]KAD0
oooo000C0?ooo`80I6AT0P1OGel205YJFP80EEEE0P1ADE4204a<C080AdM70P12@T800`0m?Cd0>3Ph
03Ph>00203<c<`80;Rh^0P0Y:BT202@T90807alO0P0J6QX201DE5@80410@0P0;2`/200D51@@00@41
0P0410@200X:2P03014A4@0I6AT06ATI00808R8R0P0[:b/203Hf=P80@4100P19BDT205ADE0@0H61P
0P1OGel205eMG@80G5aL0P1JFUX205UIF@80EeMG00<0EEEE05ADE01DE5@00P1BDU82055AD@80Cdm?
0P1=CDd204a<C080CDe=0P1<C4`204];B`@0BTY:0P1;Bd/204e=C@@0Cdm?00<0DE5A059BDP1BDU80
101CDe<2059BDP80DE5A0P1@D50204m?C`@0CDe=201<C4`204e=C@80CTi>00<0Cdm?055AD@1ADE40
0P1CDe<205MGE`80Fe]K0P1QHF4206YZJP80MgMg0P22PX8208^;R`80Ti>C0P2JVYX20:6QX@80YZJV
0P2/[:`20;Bd]0030;^k^`2o_kl0_kno0080`l?30P34a<@20<G5a@80alO70P3;bl/20<o?c`80e=CD
0P3IfMT20=gMg@@0gmoO0P3Ph>040=kNgP030=_Kf`3IfMT0fMWI0080eMGE0P3?cll20<[:bP80aLG5
0P30`<020;^k^`80][Jf0P2a/K420:b/[080Z:RX0P2SXj<209jNWP80VIVI0P2DU9@00`2?Shl0RXZ:
08Z:RP0208F5Q@80PH610P1lO7`207MgM`80LW9b0P1]KFdE0?ooo`004`3oool206ATI080GemO0P1J
FUX205EEE@80D51@0P1;Bd/204I6AP80@D5100<0?Cdm03Lg=`0g=cL00P0c<c<202h^;P80:BTY0P0T
92@201hN7P806ATI0P0D51@200l?3`802@T90P0410@2000000800@410P061PH200d=3@0301@D500M
7Ad07AdM00809RHV0P0`<30203Xj>P80@d=30P1=CDd205UIF@80Hf=S0P1QHF42061PH080GUiN0P1M
GEd205YJFP80FEUI0P1GEeL00`1EEED0E5AD05ADE002059BDP80DE5A0P1@D50604i>CP80C4a<0P1;
Bd/404Y:BP80C4a<0P1>CTh404m?C`03055AD@1CDe<0De=C00@0De=C0P1BDU82055AD@80D51@0P1?
Cdl204i>CP80CDe=201<C4`204e=C@80CTi>00<0Cdm?055AD@1ADE400P1CDe<205MGE`80Fe]K0P1Q
HF4206QXJ080MGEe0P21PH4208^;R`80Ti>C0P2KVi/20:6QX@80Z:RX0P2][Jd20;Bd]0030;Zj^P33
`l<0`l?30080aLG50P36a/H40<S8b080cLg=0P3@d=020=KFeP80fm_K0P3Ogml20>7Qh@80h^;R0P3Q
hN440=oOg`030=gMg@3Jf]X0f][J0080eMGE0P3@d=020<[:bP80aLG50P30`<020;^k^`80][Jf0P2a
/K420:b/[080Z:RX0P2SXj<209jNWP80VIVI0P2DU9@00`2?Shl0RXZ:08Z:RP0208F5Q@80PH610P1l
O7`207MgM`80LW9b0P1^KVhE0?ooo`004`3oool206ATI080GemO0P1JFUX205EEE@80D51@0P1;Bd/2
04I6AP80@D5100<0?Cdm03Lg=`0g=cL00P0c<c<202h^;P80:BTY0P0T92@201hN7P806ATI0P0D51@2
00l?3`802@T90P0410@2000000800@410P061PH200d=3@0301@D500M7Ad07AdM00809RHV0P0`<302
03Xj>P80@d=30P1=CDd205UIF@80Hf=S0P1QHF42061PH080GUiN0P1MGEd205YJFP80FEUI0P1GEeL0
0`1EEED0E5AD05ADE002059BDP80DE5A0P1@D50604i>CP80C4a<0P1;Bd/404Y:BP80C4a<0P1>CTh4
04m?C`03055AD@1CDe<0De=C00@0De=C0P1BDU82055AD@80D51@0P1?Cdl204i>CP80CDe=201<C4`2
04e=C@80CTi>00<0Cdm?055AD@1ADE400P1CDe<205MGE`80Fe]K0P1QHF4206QXJ080MGEe0P21PH42
08^;R`80Ti>C0P2KVi/20:6QX@80Z:RX0P2][Jd20;Bd]0030;Zj^P33`l<0`l?30080aLG50P36a/H4
0<S8b080cLg=0P3@d=020=KFeP80fm_K0P3Ogml20>7Qh@80h^;R0P3QhN440=oOg`030=gMg@3Jf]X0
f][J0080eMGE0P3@d=020<[:bP80aLG50P30`<020;^k^`80][Jf0P2a/K420:b/[080Z:RX0P2SXj<2
09jNWP80VIVI0P2DU9@00`2?Shl0RXZ:08Z:RP0208F5Q@80PH610P1lO7`207MgM`80LW9b0P1^KVhE
0?ooo`004`3oool206ATI080GemO0P1JFUX205EEE@80D51@0P1;Bd/204I6AP80@D5100<0?3`l03Lg
=`0g=cL00P0b<S8202d];@80:2PX0P0S8b<201hN7P8061PH0P0C4a<200h>3P8020P80P030`<20000
00800P820P0820P200l?3`0301PH600Q8B408B4Q0080:RXZ0P0d=3@203dm?@80ATI60P1BDU8205iN
GP80I6AT0P1RHV82061PH080GUiN0P1MGEd205]KF`80FEUI0P1GEeL00`1EEED0E5AD05ADE00205=C
D`80DE5A0P1@D50204m?C`@0CTi>0P1<C4`204];B`@0BTY:0P1<C4`204e=C@@0Cdm?00<0DE5A05=C
D`1CDe<00P1DE5@205=CD`80DU9B0P1ADE42051@D080Cdm?0P1>CTh404e=C@H0C4a<0P1=CDd204i>
CP0304m?C`1ADE40DE5A0080De=C0P1GEeL205]KF`80H61P0P1WIfL207AdM080P8200P2;Rh/209BD
U080Vi^K0P2QXJ420:VYZ@80[Zj^0P2e]KD00`2l_;`0a/K60<K6aP020<O7a`80b/[:0P3;bl/20<[:
bP80c/k>0P3Bd]820=OGe`80g=cL0P3Ph>020>?Sh`80i>CT0P3Shn<40>7Qh@030=oOg`3Jf]X0f][J
0080eMGE0P3@d=020<[:bP80aLG50P30`<020;^k^`80][Jf0P2a/K420:b/[080Z:RX0P2SXj<209jN
WP80VIVI0P2DU9@00`2?Shl0RXZ:08Z:RP0208F5Q@80PH610P1lO7`207MgM`80LW9b0P1]KFdE0?oo
o`004`3oool206ATI080GemO0P1JFUX205EEE@80D51@0P1;Bd/204I6AP80@D5100<0?3`l03Lg=`0g
=cL00P0b<S8202d];@80:2PX0P0S8b<201hN7P8061PH0P0C4a<200h>3P8020P80P030`<200000080
0P820P0820P200l?3`0301PH600Q8B408B4Q0080:RXZ0P0d=3@203dm?@80ATI60P1BDU8205iNGP80
I6AT0P1RHV82061PH080GUiN0P1MGEd205]KF`80FEUI0P1GEeL00`1EEED0E5AD05ADE00205=CD`80
DE5A0P1@D50204m?C`@0CTi>0P1<C4`204];B`@0BTY:0P1<C4`204e=C@@0Cdm?00<0DE5A05=CD`1C
De<00P1DE5@205=CD`80DU9B0P1ADE42051@D080Cdm?0P1>CTh404e=C@H0C4a<0P1=CDd204i>CP03
04m?C`1ADE40DE5A0080De=C0P1GEeL205]KF`80H61P0P1WIfL207AdM080P8200P2;Rh/209BDU080
Vi^K0P2QXJ420:VYZ@80[Zj^0P2e]KD00`2l_;`0a/K60<K6aP020<O7a`80b/[:0P3;bl/20<[:bP80
c/k>0P3Bd]820=OGe`80g=cL0P3Ph>020>?Sh`80i>CT0P3Shn<40>7Qh@030=oOg`3Jf]X0f][J0080
eMGE0P3@d=020<[:bP80aLG50P30`<020;^k^`80][Jf0P2a/K420:b/[080Z:RX0P2SXj<209jNWP80
VIVI0P2DU9@00`2?Shl0RXZ:08Z:RP0208F5Q@80PH610P1lO7`207MgM`80LW9b0P1]KFdE0?ooo`00
4`3oool206ATI080GemO0P1JFUX205EEE@80D51@0P1;Bd/204I6AP80@D5100<0>c/k03Hf=P0f=SH0
0P0a<C4202`/;0809bLW0P0R8R8201dM7@805aLG0P0B4Q8200d=3@801`L70P020P820000008010@4
0P0;2`/2018B4P0301`L700T92@092@T0080;Bd]0P0g=cL20410@080BTY:0P1FEUH2069RHP80I6AT
0P1SHf<2065QH@80GemO0P1MGEd205]KF`80FEUI0P1GEeL00`1FEUH0E5AD05ADE00205=CD`80DU9B
0P1ADE4404m?C`80CTi>0P1<C4`204];B`@0BTY:0P1;Bd/204e=C@80CTi>0P1?Cdl00`1ADE40DU9B
059BDP0405=CD`80DU9B0P1ADE42051@D080Cdm?0P1>CTh404e=C@@0C4a<101=CDd204i>CP0304m?
C`1ADE40DE5A0080De=C0P1GEeL205]KF`80H61P0P1VIVH2079bLP80Ogmo0P2;Rh/209>CT`80W9bL
0P2RXZ820:ZZZP80[jn_0P2g]kL00`2n_[h0alO70<O7a`020<W9b@80c<c<103=cLd20=3@d080e=CD
0P3Hf=P20=gMg@80h^;R0P3UiND20>KViP@0i>CT0P3Rh^800`3Ogml0f][J0=[JfP020=GEe@80d=3@
0P3:b/X20<G5a@80`<300P2k^k/20;Jf]P80/K6a0P2/[:`20:RXZ080Xj>S0P2NWYh209VIV@80U9BD
00<0Shn?08Z:RP2:RXX00P25QHD20861P@80O7al0P1gMgL2079bLP80KFe]5@3oool001<0oooo0P1T
I6@205mOG`80FUYJ0P1EEED2051@D080Bd];0P16ATH20451@@0303/k>`0f=SH0=SHf0080<C4a0P0/
;2`202LW9`808R8R0P0M7Ad201LG5`804Q8B0P0=3@d200L71`800P820P00000200@410802`/;0P0B
4Q800`0L71`092@T02@T900202d];@80=cLg0P10@40204Y:BP80EUIF0P1RHV8206ATI080Hf=S0P1Q
HF4205mOG`80GEeM0P1KFe/205UIF@80EeMG00<0EUIF05ADE01DE5@00P1CDe<2059BDP80DE5A101?
Cdl204i>CP80C4a<0P1;Bd/404Y:BP80Bd];0P1=CDd204i>CP80Cdm?00<0DE5A059BDP1BDU80101C
De<2059BDP80DE5A0P1@D50204m?C`80CTi>101=CDd404a<C0@0CDe=0P1>CTh00`1?Cdl0DE5A055A
D@0205=CD`80EeMG0P1KFe/2061PH080IVIV0P1bLW8207moO`80Rh^;0P2CTi<209bLW080XZ:R0P2Z
ZZX20:n_[`80]kNg00<0_[jn0<O7a`37alL00P39bLT20<c<c0@0cLg=0P3@d=020=CDe080f=SH0P3M
gMd20>;RhP80iNGU0P3Vi^H40>CTi080h^;R00<0gmoO0=[JfP3Jf]X00P3EeMD20=3@d080b/[:0P35
aLD20<30`080^k^k0P2f][H20;6a/@80[:b/0P2XZ:P20:>SX`80WYjN0P2IVIT209BDU00308n?S`2:
RXX0RXZ:0080QHF50P21PH4207alO080MgMg0P1bLW8206e]KAD0oooo000C0?ooo`80I6AT0P1OGel2
05YJFP80EEEE0P1@D50204Y:BP80ADE50P10@4000`0k>c/0=SHf03Hf=P02034a<@80;2`/0P0W9bL2
024Q8@8071`L0P0G5aL2014A4@8030`<0P061PH200410@8000000P061PH200d=3@805QHF00<07alO
02PX:00X:2P00P0a<C4203Xj>P80@d=30P1>CTh205YJFP80IVIV0P1TI6@206=SH`80HF5Q0P1OGel2
05eMG@80Fe]K0P1IFET205MGE`0305IFEP1DE5@0E5AD0080De=C0P1BDU82055AD@80D51@0P1?Cdl2
04i>CP80C4a<0P1;Bd/404Y:BP80Bd];0P1=CDd204i>CP80Cdm?00<0DE5A05=CD`1CDe<0101CDe<2
059BDP80DE5A0P1@D50204m?C`@0CTi>201=CDd204i>CP80Cdm?00<0D51@055AD@1ADE400P1DE5@2
05MGE`80Fe]K0P1PH60206IVIP80L71`0P1nOWh208Z:RP80Ti>C0P2LW9`20:>SX`80ZZZZ0P2`/;02
0;Rh^0030;no_`37alL0alO70080c<c<0P3>c/h20<o?c`@0d=3@0P3EeMD20=WIf@80gmoO0P3Ti>@4
0>SXj0@0i^KV0P3Ti>@00`3Ogml0f][J0=[JfP020=CDe080clo?0P3:b/X20<G5a@80`<300P2k^k/2
0;Jf]P80/K6a0P2/[:`20:NWY`80Xj>S0P2NWYh209VIV@80U9BD00<0Shn?08Z:RP2:RXX00P25QHD2
0861P@80O7al0P1gMgL2079bLP80KFe]5@3oool001<0oooo0P1TI6@205mOG`80FUYJ0P1EEED2051@
D080BTY:0P15ADD20410@00303/k>`0f=SH0=SHf0080<C4a0P0/;2`202LW9`808B4Q0P0L71`201LG
5`804A4A0P0<30`200H61P800@410P00000200H61P803@d=0P0F5QH00`0O7al0:2PX02PX:002034a
<@80>SXj0P13@d<204i>CP80FUYJ0P1VIVH206ATI080Hf=S0P1QHF4205mOG`80GEeM0P1KFe/205UI
F@80EeMG00<0EUIF05ADE01DE5@00P1CDe<2059BDP80DE5A0P1@D50204m?C`80CTi>0P1<C4`204];
B`@0BTY:0P1;Bd/204e=C@80CTi>0P1?Cdl00`1ADE40De=C05=CD`0405=CD`80DU9B0P1ADE42051@
D080Cdm?101>CTh804e=C@80CTi>0P1?Cdl00`1@D500DE5A055AD@0205ADE080EeMG0P1KFe/2061P
H080IVIV0P1`L70207inOP80RXZ:0P2CTi<209bLW080Xj>S0P2ZZZX20;2`/080^;Rh00<0_kno0<O7
a`37alL00P3<c<`20<k>cP80clo?103@d=020=GEe@80fMWI0P3Ogml20>CTi0@0j>SX103Vi^H20>CT
i0030=oOg`3Jf]X0f][J0080e=CD0P3?cll20<[:bP80aLG50P30`<020;^k^`80][Jf0P2a/K420:b/
[080YjNW0P2SXj<209jNWP80VIVI0P2DU9@00`2?Shl0RXZ:08Z:RP0208F5Q@80PH610P1lO7`207Mg
M`80LW9b0P1]KFdE0?ooo`004`3oool206ATI080GemO0P1JFUX205ADE080Cdm?0P1:BTX204E5A@80
@41000<0>c/k03Hf=P0f=SH00P0`<30202/[:`809RHV0P0Q8B4201/K6`805QHF0P0@410200/;2`80
1@D50P00000200820P802@T90P0@410201XJ6P0302<S8`0/;2`0;2`/0080=3@d0P0m?Cd204M7A`80
De=C0P1NGUh206QXJ080IFEU0P1SHf<2061PH080GUiN0P1LG5`205]KF`80FEUI0P1GEeL00`1FEUH0
E5AD05ADE00205=CD`80DU9B0P1ADE42051@D080Cdm?0P1>CTh204a<C080Bd];101:BTX204];B`80
CDe=0P1>CTh2051@D003055AD@1BDU80DU9B0080De=C0P1BDU84055AD@80D51@0P1?Cdl604i>CPH0
CDe=0P1>CTh204m?C`03051@D01BDU80DU9B0080E5AD0P1GEeL205]KF`80H61P0P1WIfL206m_K`80
OGem0P29RHT209>CT`80W9bL0P2TY:@20:^[Z`80/[:b0P2i^KT00`31`L40bLW90<W9b@020<g=c@80
d=3@103Bd]820=7Ad@80e]KF0P3Kfm/20>7Qh@80i^KV0P3YjNT20>[ZjP@0j>SX0P3Ti>@00`3Ogml0
f][J0=[JfP020=CDe080clo?0P3:b/X20<G5a@80`<300P2k^k/20;Jf]P80/K6a0P2/[:`20:NWY`80
XZ:R0P2NWYh209VIV@80U9BD00<0Shn?08Z:RP2:RXX00P25QHD20861P@80O7al0P1gMgL2079bLP80
KFe]5@3oool001<0oooo0P1TI6@205mOG`80FEUI0P1DE5@204m?C`80BTY:0P15ADD20410@00303Xj
>P0e=CD0=CDe0080<30`0P0Z:RX202DU9@80820P0P0K6a/201DE5@80410@0P0:2PX200D51@800000
0P0410@200/;2`8051@D0P0N7Qh00`0V9RH0;bl_02l_;`0203Ph>080@4100P1=CDd205QHF080Hf=S
0P1WIfL206ATI080HV9R0P1PH60205iNGP80G5aL0P1JFUX205UIF@80EeMG00<0EUIF05ADE01DE5@0
0P1CDe<2059BDP80DE5A0P1@D50204m?C`80CTi>0P1<C4`204];B`@0BTY:0P1;Bd/204e=C@80CTi>
0P1@D5000`1ADE40DU9B059BDP02059BDP@0DE5A101@D50204m?C`P0CTi>0P1=CDd204i>CP80Cdm?
0P1@D5000`1ADE40De=C05=CD`0205EEE@80EeMG0P1KFe/2065QH@80IfMW0P1_Kfl207alO080R8R8
0P2CTi<209bLW080Y:BT0P2[Zj/20;Bd]080^[Zj00<0`/;20<[:bP3:b/X00P3?cll20=7Ad@80dm?C
0P3De=@20=;BdP80emOG0P3Lg=`20>?Sh`80inOW103/k>`20>[ZjP80jNWY0P3Ti>@00`3Ogml0f][J
0=[JfP020=CDe080clo?0P3:b/X20<G5a@80`<300P2k^k/20;Jf]P80/K6a0P2/[:`20:NWY`80XZ:R
0P2MWId209VIV@80U9BD00<0Shn?08Z:RP2:RXX00P25QHD20861P@80O7al0P1gMgL2079bLP80KFe]
5@3oool001<0oooo0P1TI6@205mOG`80FEUI0P1DE5@204m?C`80BTY:0P15ADD20410@00303Xj>P0e
=CD0=CDe0080<30`0P0Z:RX202DU9@80820P0P0K6a/201DE5@80410@0P0:2PX200D51@8000000P04
10@200/;2`8051@D0P0N7Qh00`0V9RH0;bl_02l_;`0203Ph>080@4100P1=CDd205QHF080Hf=S0P1W
IfL206ATI080HV9R0P1PH60205iNGP80G5aL0P1JFUX205UIF@80EeMG00<0EUIF05ADE01DE5@00P1C
De<2059BDP80DE5A0P1@D50204m?C`80CTi>0P1<C4`204];B`@0BTY:0P1;Bd/204e=C@80CTi>0P1@
D5000`1ADE40DU9B059BDP02059BDP@0DE5A101@D50204m?C`P0CTi>0P1=CDd204i>CP80Cdm?0P1@
D5000`1ADE40De=C05=CD`0205EEE@80EeMG0P1KFe/2065QH@80IfMW0P1_Kfl207alO080R8R80P2C
Ti<209bLW080Y:BT0P2[Zj/20;Bd]080^[Zj00<0`/;20<[:bP3:b/X00P3?cll20=7Ad@80dm?C0P3D
e=@20=;BdP80emOG0P3Lg=`20>?Sh`80inOW103/k>`20>[ZjP80jNWY0P3Ti>@00`3Ogml0f][J0=[J
fP020=CDe080clo?0P3:b/X20<G5a@80`<300P2k^k/20;Jf]P80/K6a0P2/[:`20:NWY`80XZ:R0P2M
WId209VIV@80U9BD00<0Shn?08Z:RP2:RXX00P25QHD20861P@80O7al0P1gMgL2079bLP80KFe]5@3o
ool001<0oooo0P1SHf<205iNGP80FEUI0P1DE5@204m?C`80BTY:0P14A4@203lo?`0303Xj>P0e=CD0
=CDe0080;bl_0P0Z:RX202DU9@807alO0P0J6QX201@D50803`l?0P092@T200@410800@410P061PH2
00h>3P8061PH0P0Q8B400`0Y:BT0<S8b038b<P0203/k>`80ADE50P1ADE4205mOG`@0IFEU0P1SHf<2
065QH@80GemO0P1MGEd205]KF`80FEUI0P1HF5P205MGE`0305EEE@1DE5@0E5AD0080De=C0P1BDU82
055AD@80D51@0P1?Cdl204i>CP80CDe=0P1;Bd/404Y:BP80Bd];0P1=CDd204i>CP80Cdm?00<0D51@
055AD@1ADE401P1ADE44051@D0@0Cdm?201>CTh404m?C`80D51@00<0DU9B05=CD`1CDe<00P1FEUH2
05QHF080Fe]K0P1QHF4206QXJ080Kfm_0P1kNg/208R8R080TY:B0P2LW9`20:FUY@80[:b/0P2e]KD2
0;bl_0030<?3``3;bl/0bl_;0080dM7A0P3Bd]820=CDe080eMGE0P3De=@20=SHf080gMgM0P3UiND2
0>WYj@@0k^k^0P3/k>`20>WYj@80i>CT00<0gmoO0=WIf@3IfMT00P3De=@20<o?c`80b/[:0P35aLD2
0<30`080^k^k0P2f][H20;6a/@80[:b/0P2WYjL20::RXP80WIfM0P2HV9P209BDU00308n?S`2:RXX0
RXZ:0080QHF50P21PH4207alO080MgMg0P1bLW8206e]KAD0oooo000C0?ooo`80Hf=S0P1NGUh205UI
F@80E5AD0P1?Cdl204Y:BP80A4A40P0o?cl00`0j>SX0=CDe03De=@0202l_;`80:RXZ0P0U9BD201lO
7`806QXJ0P0D51@200l?3`802@T90P0410@200410@801PH60P0>3Ph201PH60808B4Q00<0:BTY038b
<P0b<S800P0k>c/204E5A@80DE5A0P1OGel406EUI@80Hf=S0P1QHF4205mOG`80GEeM0P1KFe/205UI
F@80F5QH0P1GEeL00`1EEED0E5AD05ADE00205=CD`80DU9B0P1ADE42051@D080Cdm?0P1>CTh204e=
C@80Bd];101:BTX204];B`80CDe=0P1>CTh204m?C`03051@D01ADE40DE5A00H0DE5A101@D50404m?
C`P0CTi>101?Cdl2051@D003059BDP1CDe<0De=C0080EUIF0P1HF5P205]KF`80HF5Q0P1XJ6P206m_
K`80Ng]k0P28R8P209:BTP80W9bL0P2UYJD20:b/[080]KFe0P2l_;`00`33`l<0bl_;0<_;b`020=7A
d@80d];B0P3De=@20=GEe@80e=CD0P3Hf=P20=gMg@80iNGU0P3YjNT40>k^kP80k>c/0P3YjNT20>CT
i0030=oOg`3IfMT0fMWI0080e=CD0P3?cll20<[:bP80aLG50P30`<020;^k^`80][Jf0P2a/K420:b/
[080YjNW0P2RXZ8209fMW@80V9RH0P2DU9@00`2?Shl0RXZ:08Z:RP0208F5Q@80PH610P1lO7`207Mg
M`80LW9b0P1]KFdE0?ooo`004`3oool206ATI080GUiN0P1IFET205ADE080Cdm?0P19BDT204A4A080
?clo00<0>CTi03@d=00d=3@00P0_;bl202TY:@8092@T0P0O7al201TI6@8051@D0P0>3Ph200T92@80
0P820P030`<200T92@804A4A0P0L71`202@T900302d];@0f=SH0=SHf0080?clo0P1;Bd/205IFEPH0
Hf=S0P1QHF42061PH080GUiN0P1LG5`205YJFP80F5QH0P1GEeL205IFEP0305EEE@1DE5@0E5AD0080
E5AD0P1CDe<2059BDP80DE5A0P1@D50204m?C`80CDe=0P1<C4`204];B`80BTY:0P1;Bd/204e=C@80
CTi>0P1?Cdl3051@D0@0DE5A0P1@D50404m?C`P0CTi>101?Cdl4051@D080DE5A00<0DU9B05ADE01D
E5@00P1FEUH205UIF@80G5aL0P1QHF4206QXJ080L71`0P1jNWX208J6QP80TI6A0P2LW9`20:FUY@80
[Jf]0P2e]KD20;fm_@030<G5a@3<c<`0c<c<0080dM7A0P3Cdm<20=CDe0@0e]KF0P3IfMT20=oOg`80
inOW0P3/k>`40?3`l080kNg]0P3YjNT20>CTi0030=kNgP3IfMT0fMWI0080e=CD0P3?cll20<[:bP80
aLG50P30`<020;^k^`80][Jf0P2a/K420:b/[080YjNW0P2RXZ8209fMW@80V9RH0P2DU9@00`2?Shl0
RXZ:08Z:RP0208F5Q@80P8200P1lO7`207MgM`80LW9b0P1]KFdE0?ooo`004`3oool206ATI080GUiN
0P1IFET205ADE080Cdm?0P19BDT204A4A080?clo00<0>CTi03@d=00d=3@00P0_;bl202TY:@8092@T
0P0O7al201TI6@8051@D0P0>3Ph200T92@800P820P030`<200T92@804A4A0P0L71`202@T900302d]
;@0f=SH0=SHf0080?clo0P1;Bd/205IFEPH0Hf=S0P1QHF42061PH080GUiN0P1LG5`205YJFP80F5QH
0P1GEeL205IFEP0305EEE@1DE5@0E5AD0080E5AD0P1CDe<2059BDP80DE5A0P1@D50204m?C`80CDe=
0P1<C4`204];B`80BTY:0P1;Bd/204e=C@80CTi>0P1?Cdl3051@D0@0DE5A0P1@D50404m?C`P0CTi>
101?Cdl4051@D080DE5A00<0DU9B05ADE01DE5@00P1FEUH205UIF@80G5aL0P1QHF4206QXJ080L71`
0P1jNWX208J6QP80TI6A0P2LW9`20:FUY@80[Jf]0P2e]KD20;fm_@030<G5a@3<c<`0c<c<0080dM7A
0P3Cdm<20=CDe0@0e]KF0P3IfMT20=oOg`80inOW0P3/k>`40?3`l080kNg]0P3YjNT20>CTi0030=kN
gP3IfMT0fMWI0080e=CD0P3?cll20<[:bP80aLG50P30`<020;^k^`80][Jf0P2a/K420:b/[080YjNW
0P2RXZ8209fMW@80V9RH0P2DU9@00`2?Shl0RXZ:08Z:RP0208F5Q@80P8200P1lO7`207MgM`80LW9b
0P1]KFdE0?ooo`004`3oool206ATI080GUiN0P1IFET205ADE080Cdm?0P19BDT204A4A080?clo00<0
>CTi03@d=00d=3@00P0_;bl202TY:@8092@T0P0N7Qh201TI6@804a<C0P0>3Ph200P820800P820P06
1PH200d=3@805ADE0P0O7al202LW9`03030`<00j>SX0>SXj0080A4A40P1?Cdl205]KF`80Hf=S0P1R
HV82065QH@80GemO0P1NGUh205aLG080Fe]K0P1IFET205QHF080EeMG0P1FEUH00`1EEED0E5AD05AD
E00205ADE080De=C0P1BDU82055AD@80D51@0P1?Cdl204i>CP80C4a<0P1;Bd/404Y:BP80C4a<0P1=
CDd204i>CP0304m?C`1@D500D51@00@0D51@101?Cdl604i>CPH0Cdm?101@D502055AD@80DU9B00<0
De=C05EEE@1EEED00P1GEeL205YJFP80GEeM0P1QHF4206QXJ080L71`0P1iNGT208F5Q@80TI6A0P2L
W9`20:FUY@80[Zj^0P2f][H20;fm_@030<K6aP3>c/h0c/k>0080dM7A0P3Cdm<20=GEe@80emOG0P3H
f=P20=_Kf`80hN7Q0P3YjNT20>k^kP80lO7a0P3bl_820>k^kP80jNWY0P3Ti>@00`3Ng]h0fMWI0=WI
f@020=CDe080clo?0P3:b/X20<G5a@80`<300P2k^k/20;Jf]P80/K6a0P2/[:`20:NWY`80XZ:R0P2M
WId209RHV080U9BD00<0Shn?08Z:RP2:RXX00P25QHD20820P080O7al0P1gMgL2079bLP80KFe]5@3o
ool001<0oooo0P1TI6@205iNGP80FEUI0P1DE5@204m?C`80BDU90P14A4@203lo?`0303Ti>@0d=3@0
=3@d0080;bl_0P0Y:BT202@T90807QhN0P0I6AT201<C4`803Ph>0P0820P200820P801PH60P0=3@d2
01DE5@807alO0P0W9bL00`0`<300>SXj03Xj>P0204A4A080Cdm?0P1KFe/206=SH`80HV9R0P1QHF42
05mOG`80GUiN0P1LG5`205]KF`80FEUI0P1HF5P205MGE`80EUIF00<0EEEE05ADE01DE5@00P1DE5@2
05=CD`80DU9B0P1ADE42051@D080Cdm?0P1>CTh204a<C080Bd];101:BTX204a<C080CDe=0P1>CTh0
0`1?Cdl0D51@051@D004051@D0@0Cdm?1P1>CTh604m?C`@0D51@0P1ADE42059BDP0305=CD`1EEED0
EEEE0080EeMG0P1JFUX205eMG@80HF5Q0P1XJ6P2071`L080NGUi0P25QHD2096AT@80W9bL0P2UYJD2
0:j^[P80][Jf0P2m_Kd00`36a/H0c/k>0<k>cP020=7Ad@80dm?C0P3EeMD20=OGe`80f=SH0P3Kfm/2
0>7Qh@80jNWY0P3^k^h20?7al@80l_;b0P3^k^h20>WYj@80i>CT00<0g]kN0=WIf@3IfMT00P3De=@2
0<o?c`80b/[:0P35aLD20<30`080^k^k0P2f][H20;6a/@80[:b/0P2WYjL20::RXP80WIfM0P2HV9P2
09BDU00308n?S`2:RXX0RXZ:0080QHF50P20P80207alO080MgMg0P1bLW8206e]KAD0oooo000C0?oo
o`80Hf=S0P1NGUh205UIF@80E5AD0P1>CTh204U9B@80A4A40P0n?Sh00`0i>CT0=3@d03@d=00202h^
;P80:BTY0P0S8b<201hN7P8061PH0P0C4a<200d=3@8020P80P030`<200T92@803`l?0P0H61P2028R
8P80:b/[00<0=3@d03dm?@0m?Cd00P19BDT205ADE080GemO0P1QHF42061PH080GemO0P1NGUh205aL
G080Fe]K0P1IFET205QHF080EeMG0P1FEUH205EEE@D0E5AD101CDe<2059BDP80DE5A0P1?Cdl204i>
CP80CDe=0P1;Bd/404Y:BP80Bd];0P1<C4`204e=C@<0CTi>101?Cdl<04i>CP80Cdm?101@D502055A
D@80DU9B0P1CDe<00`1DE5@0EUIF05IFEP0205QHF080Fe]K0P1NGUh2069RHP80J6QX0P1`L70207Ui
N@80Q8B40P2@T90209^KV`80YZJV0P2_[jl20;Ng]`80_[jn00<0a/K60<o?c`3?cll00P3AdM420=CD
e080e]KF0P3Hf=P20=_Kf`80g=cL0P3Ti>@20>[ZjP80kno_103clo<20>k^kP80jNWY0P3Ti>@00`3N
g]h0fMWI0=WIf@020=CDe080clo?0P3:b/X20<G5a@80_kno0P2j^[X20;Fe]@80/;2`0P2/[:`20:NW
Y`80XZ:R0P2MWId209RHV080U9BD00<0Shn?08Z:RP2:RXX00P25QHD20820P080O7al0P1gMgL2079b
LP80KFe]5@3oool001<0oooo0P1SHf<205iNGP80FEUI0P1DE5@204i>CP80BDU90P14A4@203hn?P03
03Ti>@0d=3@0=3@d0080;Rh^0P0Y:BT202<S8`807QhN0P0H61P201<C4`803@d=0P0820P200<30`80
2@T90P0?3`l201PH60808R8R0P0[:b/00`0d=3@0?Cdm03dm?@0204U9B@80E5AD0P1OGel2065QH@80
H61P0P1OGel205iNGP80G5aL0P1KFe/205UIF@80F5QH0P1GEeL205IFEP80EEEE1@1DE5@405=CD`80
DU9B0P1ADE4204m?C`80CTi>0P1=CDd204];B`@0BTY:0P1;Bd/204a<C080CDe=0`1>CTh404m?C``0
CTi>0P1?Cdl4051@D080DE5A0P1BDU8205=CD`0305ADE01FEUH0EUIF0080F5QH0P1KFe/205iNGP80
HV9R0P1XJ6P2071`L080NGUi0P24Q8@2092@T080Vi^K0P2VYZH20:n_[`80]kNg0P2n_[h00`36a/H0
clo?0<o?c`020=7Ad@80e=CD0P3Fe]H20=SHf080fm_K0P3Lg=`20>CTi080j^[Z0P3_knl40??cl`80
k^k^0P3YjNT20>CTi0030=kNgP3IfMT0fMWI0080e=CD0P3?cll20<[:bP80aLG50P2o_kl20;Zj^P80
]KFe0P2`/;020:b/[080YjNW0P2RXZ8209fMW@80V9RH0P2DU9@00`2?Shl0RXZ:08Z:RP0208F5Q@80
P8200P1lO7`207MgM`80LW9b0P1]KFdE0?ooo`004`3oool206=SH`80GUiN0P1IFET205ADE080CTi>
0P19BDT204=3@`80?Shn00<0>3Ph03<c<`0c<c<00P0^;Rh202PX:0808b<S0P0M7Ad201PH60804Q8B
0P0<30`200L71`801@D50P0<30`2018B4P806a/K0P0T92@202h^;P0303Lg=`11@D40@D510080CDe=
0P1IFET205mOG`@0GUiN0P1MGEd205aLG080Fe]K0P1IFET205QHF080EUIF101EEED;05ADE080De=C
0P1BDU82051@D080Cdm?0P1>CTh204a<C080BTY:0P19BDT204Y:BP80Bd];0P1<C4`304e=C@@0CTi>
201=CDd404i>CP80Cdm?0P1@D502055AD@@0De=C0P1DE5@00`1FEUH0EeMG05MGE`0205UIF@80G5aL
0P1OGel206=SH`80J6QX0P1`L70207UiN@80Ph>30P2?Shl209^KV`80YZJV0P2`/;020;Ng]`80_kno
00<0alO70=3@d03@d=000P3Bd]820=CDe080emOG0P3IfMT20=gMg@80g]kN0P3Vi^H20>c/k080lO7a
103dm?@20>k^kP80jNWY0P3Shn<00`3Ng]h0fMWI0=WIf@020=CDe080clo?0P39bLT20<C4a080_kno
0P2j^[X20;Fe]@80/;2`0P2[Zj/20:JVYP80XZ:R0P2MWId209RHV080Ti>C00<0Shn?08Z:RP2:RXX0
0P25QHD20820P080O7al0P1gMgL2079bLP80KFe]5@3oool001<0oooo0P1SHf<205iNGP80FEUI0P1D
E5@204i>CP80BDU90P13@d<203hn?P0303Ph>00c<c<0<c<c0080;Rh^0P0X:2P202<S8`807AdM0P0H
61P2018B4P8030`<0P071`L200D51@8030`<0P0B4Q8201/K6`8092@T0P0^;Rh00`0g=cL0@D510451
@@0204e=C@80FEUI0P1OGel405iNGP80GEeM0P1LG5`205]KF`80FEUI0P1HF5P205IFEP@0EEEE2`1D
E5@205=CD`80DU9B0P1@D50204m?C`80CTi>0P1<C4`204Y:BP80BDU90P1:BTX204];B`80C4a<0`1=
CDd404i>CPP0CDe=101>CTh204m?C`80D51@0P1ADE4405=CD`80E5AD00<0EUIF05MGE`1GEeL00P1I
FET205aLG080GemO0P1SHf<206QXJ080L71`0P1iNGT208>3P`80Shn?0P2KVi/20:JVYP80/;2`0P2g
]kL20;no_`030<O7a`3@d=00d=3@0080d];B0P3De=@20=OGe`80fMWI0P3MgMd20=kNgP80i^KV0P3/
k>`20?7al@@0m?Cd0P3^k^h20>WYj@80hn?S00<0g]kN0=WIf@3IfMT00P3De=@20<o?c`80bLW90P34
a<@20;no_`80^[Zj0P2e]KD20;2`/080Zj^[0P2VYZH20::RXP80WIfM0P2HV9P209>CT`0308n?S`2:
RXX0RXZ:0080QHF50P20P80207alO080MgMg0P1bLW8206e]KAD0oooo000C0?ooo`80Hf=S0P1NGUh2
05UIF@80De=C0P1>CTh204U9B@80@d=30P0n?Sh00`0h>3P0<c<c03<c<`0202d];@80:2PX0P0R8R82
01dM7@805aLG0P0A4A4200`<30801PH60P0820P200h>3P805ADE0P0O7al202LW9`80<30`00<0>SXj
04I6AP16ATH00P1ADE4205]KF`80G5aL101MGEd205aLG080FUYJ0P1IFET205MGE`80EUIF0P1EEED4
05ADE080De=C0`1DE5@605EEE@80E5AD0P1CDe<2059BDP80D51@0P1>CTh204a<C080BTY:1019BDT2
04Y:BP80Bd];00<0C4a<04e=C@1=CDd0101=CDd804a<C080CDe=0P1>CTh204m?C`80DE5A0P1CDe<2
05ADE080EEEE0P1FEUH00`1GEeL0FEUI05UIF@0205YJFP80GEeM0P1PH60206ATI080JFUY0P1`L702
07UiN@80PX:20P2?Shl209^KV`80YZJV0P2`/;020;Rh^080`<3000<0b<S80=7Ad@3AdM400P3Cdm<2
0=GEe@80f=SH0P3Jf]X20>7Qh@80h>3P0P3Xj>P20>o_k`80lo?c0P3emOD20?Cdm080k^k^0P3YjNT2
0>?Sh`030=kNgP3IfMT0fMWI0080dm?C0P3>c/h20<W9b@80a<C40P2o_kl20;Zj^P80]KFe0P2`/;02
0:^[Z`80YZJV0P2QXJ4209fMW@80V9RH0P2CTi<00`2>SXh0RXZ:08Z:RP0208F5Q@80P8200P1kNg/2
07MgM`80LW9b0P1]KFdE0?ooo`004`3oool206=SH`80GUiN0P1IFET205=CD`80CTi>0P19BDT204=3
@`80?Shn00<0>3Ph03<c<`0c<c<00P0];Bd202PX:0808R8R0P0M7Ad201LG5`804A4A0P0<30`200H6
1P8020P80P0>3Ph201DE5@807alO0P0W9bL2030`<00303Xj>P16ATH0ATI60080DE5A0P1KFe/205aL
G0@0GEeM0P1LG5`205YJFP80FEUI0P1GEeL205IFEP80EEEE101DE5@205=CD`<0E5AD1P1EEED205AD
E080De=C0P1BDU82051@D080CTi>0P1<C4`204Y:BP@0BDU90P1:BTX204];B`0304a<C01=CDd0CDe=
00@0CDe=201<C4`204e=C@80CTi>0P1?Cdl2055AD@80De=C0P1DE5@205EEE@80EUIF00<0EeMG05UI
F@1IFET00P1JFUX205eMG@80H61P0P1TI6@206UYJ@80L71`0P1iNGT208:2PP80Shn?0P2KVi/20:JV
YP80/;2`0P2h^;P20<30`0030<S8b03AdM40dM7A0080dm?C0P3EeMD20=SHf080f][J0P3QhN420>3P
h080j>SX0P3_knl20??cl`80mOGe0P3dm?@20>k^kP80jNWY0P3Shn<00`3Ng]h0fMWI0=WIf@020=?C
d`80c/k>0P39bLT20<C4a080_kno0P2j^[X20;Fe]@80/;2`0P2[Zj/20:JVYP80XJ6Q0P2MWId209RH
V080Ti>C00<0SXj>08Z:RP2:RXX00P25QHD20820P080Ng]k0P1gMgL2079bLP80KFe]5@3oool001<0
oooo0P1SHf<205iNGP80FEUI0P1CDe<204i>CP80B4Q80P13@d<203hn?P0303Ph>00c<c<0<c<c0080
;Bd]0P0W9bL2028R8P8071`L0P0G5aL2014A4@8030`<0P051@D200`<3080410@0P0H61P2024Q8@80
:BTY0P0c<c<00`0m?Cd0BTY:04Y:BP0205ADE0@0Fe]K101LG5`205YJFP80FEUI0P1GEeL205EEE@80
E5AD2@1CDe<205EEE@80EUIF101GEeL205IFEP80E5AD0P1CDe<2059BDP80Cdm?0P1=CDd204Y:BP@0
B4Q80P19BDT204Y:BP0304];B`1<C4`0C4a<00@0C4a<0P1;Bd/404Y:BP80Bd];0P1=CDd204i>CP80
D51@0P1BDU8205ADE0@0EUIF0P1GEeL00`1IFET0FUYJ05YJFP0205]KF`80GUiN0P1QHF4206ATI080
JVYZ0P1`L70207UiN@80PX:20P2>SXh209^KV`80YZJV0P2a/K420;Vi^@80`L7100<0bLW90=7Ad@3A
dM400P3De=@20=KFeP80fMWI0P3Lg=`20>CTi080hn?S0P3Zj^X20?;blP80mOGe0P3fm_H20?Cdm080
k^k^0P3YjNT20>?Sh`030=kNgP3Hf=P0f=SH0080dm?C0P3>c/h20<W9b@80a<C40P2o_kl20;Zj^P80
]KFe0P2`/;020:^[Z`80YZJV0P2QXJ4209fMW@80V9RH0P2CTi<00`2>SXh0RXZ:08Z:RP0208F5Q@80
P8200P1kNg/207MgM`80LW9b0P1]KFdE0?ooo`004`3oool206=SH`80GUiN0P1IFET205=CD`80CTi>
0P18B4P204=3@`80?Shn00<0>3Ph03<c<`0c<c<00P0];Bd202LW9`808R8R0P0L71`201LG5`804A4A
0P0<30`200D51@8030`<0P0@410201PH60808B4Q0P0Y:BT203<c<`0303dm?@1:BTX0BTY:0080E5AD
101KFe/405aLG080FUYJ0P1IFET205MGE`80EEEE0P1DE5@905=CD`80EEEE0P1FEUH405MGE`80EUIF
0P1DE5@205=CD`80DU9B0P1?Cdl204e=C@80BTY:1018B4P204U9B@80BTY:00<0Bd];04a<C01<C4`0
101<C4`204];B`@0BTY:0P1;Bd/204e=C@80CTi>0P1@D502059BDP80E5AD101FEUH205MGE`0305UI
F@1JFUX0FUYJ0080Fe]K0P1NGUh2065QH@80I6AT0P1ZJVX2071`L080NGUi0P22PX8208j>SP80Vi^K
0P2VYZH20;6a/@80^KVi0P31`L400`39bLT0dM7A0=7Ad@020=CDe080e]KF0P3IfMT20=cLg080i>CT
0P3Shn<20>[ZjP80l_;b0P3emOD20?KfmP80m?Cd0P3^k^h20>WYj@80hn?S00<0g]kN0=SHf03Hf=P0
0P3Cdm<20<k>cP80bLW90P34a<@20;no_`80^[Zj0P2e]KD20;2`/080Zj^[0P2VYZH20:6QX@80WIfM
0P2HV9P209>CT`0308j>SP2:RXX0RXZ:0080QHF50P20P80207]kN`80MgMg0P1bLW8206e]KAD0oooo
000C0?ooo`80Hf=S0P1NGUh205QHF080De=C0P1>CTh204Q8B080@d=30P0m?Cd00`0h>3P0<S8b038b
<P0202d];@809bLW0P0R8R8201`L70805QHF0P0A4A4200`<30801PH60P0>3Ph2018B4P806a/K0P0S
8b<202`/;080=CDe00<0@T9204e=C@1=CDd00P1FEUH205QHF080FUYJ101KFe/205UIF@80EeMG0P1E
EED205=CD`80DU9B1P1ADE42059BDP0305=CD`1EEED0EEEE00@0F5QH0P1IFET205QHF080EUIF0P1E
EED205=CD`80D51@0P1=CDd204Y:BPH0B4Q80P19BDT304Y:BP80Bd];101:BTX404U9B@80BTY:0P1<
C4`204m?C`80DE5A0P1CDe<205EEE@80F5QH101IFET00`1JFUX0G5aL05aLG00205eMG@80GemO0P1R
HV8206EUI@80JVYZ0P1aLG4207UiN@80Ph>30P2>SXh209ZJVP80YZJV0P2b/[820;Zj^P80`/;200<0
b/[:0=;BdP3Bd]800P3EeMD20=OGe`80fm_K0P3Ogml20>OWi`80iNGU0P3/k>`20?Cdm080m_Kf0P3g
moL20?Cdm080k^k^0P3Xj>P20>?Sh`030=gMg@3Hf=P0f=SH0080dm?C0P3>c/h20<S8b080`l?30P2n
_[h20;Vi^@80];Bd0P2`/;020:^[Z`80YZJV0P2QXJ4209bLW080V9RH0P2CTi<00`2>SXh0RHV908V9
R@0208F5Q@80P8200P1kNg/207MgM`80LW9b0P1]KFdE0?ooo`004`3oool206=SH`80GUiN0P1HF5P2
05=CD`80CTi>0P18B4P204=3@`80?Cdm00<0>3Ph038b<P0b<S800P0];Bd202LW9`808R8R0P0L71`2
01HF5P804A4A0P0<30`200H61P803Ph>0P0B4Q8201/K6`808b<S0P0/;2`203De=@030492@P1=CDd0
CDe=0080EUIF0P1HF5P205YJFP@0Fe]K0P1IFET205MGE`80EEEE0P1CDe<2059BDPH0DE5A0P1BDU80
0`1CDe<0EEEE05EEE@0405QHF080FEUI0P1HF5P205IFEP80EEEE0P1CDe<2051@D080CDe=0P1:BTX6
04Q8B080BDU90`1:BTX204];B`@0BTY:1019BDT204Y:BP80C4a<0P1?Cdl2055AD@80De=C0P1EEED2
05QHF0@0FEUI00<0FUYJ05aLG01LG5`00P1MGEd205mOG`80HV9R0P1UIFD206YZJP80LG5a0P1iNGT2
08>3P`80SXj>0P2JVYX20:JVYP80/[:b0P2j^[X20<;2`P030<[:bP3Bd]80d];B0080eMGE0P3GemL2
0=_Kf`80gmoO0P3WinL20>GUi@80k>c/0P3dm?@20?KfmP80moOg0P3dm?@20>k^kP80j>SX0P3Shn<0
0`3MgMd0f=SH0=SHf0020=?Cd`80c/k>0P38b<P20<?3``80_[jn0P2i^KT20;Bd]080/;2`0P2[Zj/2
0:JVYP80XJ6Q0P2LW9`209RHV080Ti>C00<0SXj>08V9R@29RHT00P25QHD20820P080Ng]k0P1gMgL2
079bLP80KFe]5@3oool001<0oooo0P1SHf<205iNGP80F5QH0P1CDe<204i>CP80B4Q80P13@d<203dm
?@0303Ph>00b<S80<S8b0080;Bd]0P0W9bL2024Q8@8071`L0P0F5QH2010@40802PX:0P0820P200h>
3P804a<C0P0M7Ad202HV9P80;bl_0P0h>3P00`16ATH0D51@051@D00405IFEP80FEUI0P1KFe/205YJ
FP80F5QH0P1EEED205=CD`80DE5A0P1@D502055AD@80DU9B0P1ADE42059BDP0305ADE01GEeL0EeMG
00@0FUYJ0P1KFe/205YJFP80F5QH0P1GEeL205EEE@80DE5A0P1>CTh204Y:BP80B4Q80P17AdL404Q8
B00304U9B@17AdL0AdM70080BDU9101:BTX204U9B@80B4Q80P19BDT204e=C@80D51@0P1BDU8205AD
E080EeMG0P1JFUX405]KF`0305aLG01MGEd0GEeM0080GemO0P1PH60206=SH`80IVIV0P1[Jf/2079b
LP80NWYj0P23Ph<208j>SP80VIVI0P2VYZH20;:b/P80^k^k0P34a<@00`3;bl/0dm?C0=?Cd`020=KF
eP80fMWI0P3MgMd20>7Qh@80jNWY0P3Xj>P20>o_k`80m_Kf103gmoL20??cl`80kNg]0P3Xj>P20>;R
hP030=gMg@3Hf=P0f=SH0080d];B0P3=cLd20<S8b080`l?30P2n_[h20;Vi^@80];Bd0P2_[jl20:ZZ
ZP80YJFU0P2QXJ4209bLW080UiNG0P2CTi<00`2>SXh0RHV908V9R@0208F5Q@80P8200P1kNg/207Mg
M`80LW9b0P1]KFdE0?ooo`004`3oool206=SH`80GUiN0P1HF5P205=CD`80CTi>0P18B4P204=3@`80
?Cdm00<0>3Ph038b<P0b<S800P0];Bd202LW9`808B4Q0P0L71`201HF5P80410@0P0:2PX200P82080
3Ph>0P0C4a<201dM7@809RHV0P0_;bl203Ph>00304I6AP1@D500D51@00@0EUIF0P1IFET205]KF`80
FUYJ0P1HF5P205EEE@80De=C0P1ADE42051@D080DE5A0P1BDU82055AD@80DU9B00<0E5AD05MGE`1G
EeL0101JFUX205]KF`80FUYJ0P1HF5P205MGE`80EEEE0P1ADE4204i>CP80BTY:0P18B4P204M7A`@0
B4Q800<0BDU904M7A`17AdL00P19BDT404Y:BP80BDU90P18B4P204U9B@80CDe=0P1@D502059BDP80
E5AD0P1GEeL205YJFP@0Fe]K00<0G5aL05eMG@1MGEd00P1OGel2061PH080Hf=S0P1VIVH206][J`80
LW9b0P1jNWX208>3P`80SXj>0P2IVIT20:JVYP80/[:b0P2k^k/20<C4a0030<_;b`3Cdm<0dm?C0080
e]KF0P3IfMT20=gMg@80hN7Q0P3YjNT20>SXj080kno_0P3fm_H40?Ogm`80lo?c0P3]kNd20>SXj080
h^;R00<0gMgM0=SHf03Hf=P00P3Bd]820<g=c@80b<S80P33`l<20;jn_P80^KVi0P2d];@20:n_[`80
ZZZZ0P2UYJD20:6QX@80W9bL0P2GUiL209>CT`0308j>SP29RHT0RHV90080QHF50P20P80207]kN`80
MgMg0P1bLW8206e]KAD0oooo000C0?ooo`80Hf=S0P1NGUh205QHF080De=C0P1=CDd204Q8B080@d=3
0P0m?Cd00`0h>3P0<S8b038b<P0202`/;0809bLW0P0Q8B4201/K6`805QHF0P0@410200X:2P802`/;
0P0?3`l201DE5@807QhN0P0Y:BT2038b<P80>c/k00<0AdM705=CD`1CDe<00P1DE5@205IFEP80FEUI
0P1KFe/205UIF@80EeMG0P1DE5@2055AD@80Cdm?0P1@D50405=CD`80D51@0P1BDU800`1EEED0FEUI
05UIF@0205]KF`H0GEeM0P1KFe/205UIF@80EUIF0P1BDU8204m?C`80Bd];0P19BDT404M7A`80ATI6
0`17AdL204U9B@80C4a<0P1;Bd/404M7A`80BTY:0P1?Cdl2055AD@80E5AD0P1EEED205QHF080G5aL
0P1MGEd305iNGP80GemO0P1PH602069RHP80I6AT0P1WIfL206a/K080Lg=c0P1kNg/208B4Q080SXj>
0P2IVIT20:JVYP80/k>c0P2l_;`20<G5a@030<g=c@3De=@0e=CD0080f=SH0P3Kfm/20>3Ph080i>CT
0P3[jn/20>[ZjP80l_;b103gmoL20?Shn080lo?c0P3]kNd20>OWi`80h^;R00<0g=cL0=OGe`3GemL0
0P3Bd]820<g=c@80b<S80P33`l<20;jn_P80^KVi0P2d];@20:n_[`80ZZZZ0P2UYJD20:2PX080W9bL
0P2GUiL209:BTP0308j>SP29RHT0RHV90080Q8B40P20P80207]kN`80MWIf0P1bLW8206e]KAD0oooo
000C0?ooo`80Hf=S0P1NGUh205QHF080De=C0P1=CDd204Q8B080@d=30P0m?Cd00`0h>3P0<S8b038b
<P0202`/;0809bLW0P0Q8B4201/K6`805QHF0P0@410200X:2P802`/;0P0?3`l201DE5@807QhN0P0Y
:BT2038b<P80>c/k00<0AdM705=CD`1CDe<00P1DE5@205IFEP80FEUI0P1KFe/205UIF@80EeMG0P1D
E5@2055AD@80Cdm?0P1@D50405=CD`80D51@0P1BDU800`1EEED0FEUI05UIF@0205]KF`H0GEeM0P1K
Fe/205UIF@80EUIF0P1BDU8204m?C`80Bd];0P19BDT404M7A`80ATI60`17AdL204U9B@80C4a<0P1;
Bd/404M7A`80BTY:0P1?Cdl2055AD@80E5AD0P1EEED205QHF080G5aL0P1MGEd305iNGP80GemO0P1P
H602069RHP80I6AT0P1WIfL206a/K080Lg=c0P1kNg/208B4Q080SXj>0P2IVIT20:JVYP80/k>c0P2l
_;`20<G5a@030<g=c@3De=@0e=CD0080f=SH0P3Kfm/20>3Ph080i>CT0P3[jn/20>[ZjP80l_;b103g
moL20?Shn080lo?c0P3]kNd20>OWi`80h^;R00<0g=cL0=OGe`3GemL00P3Bd]820<g=c@80b<S80P33
`l<20;jn_P80^KVi0P2d];@20:n_[`80ZZZZ0P2UYJD20:2PX080W9bL0P2GUiL209:BTP0308j>SP29
RHT0RHV90080Q8B40P20P80207]kN`80MWIf0P1bLW8206e]KAD0oooo000C0?ooo`80Hf=S0P1NGUh2
05QHF080De=C0P1=CDd204Q8B080@T920P0m?Cd00`0g=cL0<S8b038b<P0202`/;0809RHV0P0Q8B42
01/K6`805ADE0P0@410400`<30803`l?0P0G5aL2020P8080;2`/0P0e=CD203hn?P0304U9B@1DE5@0
E5AD0080E5AD0P1FEUH205UIF@80FUYJ0P1IFET205IFEP80De=C0P1@D50204m?C`80D51@101DE5@2
055AD@<0EEEE0P1LG5`205eMG@H0H61P0P1NGUh205]KF`80F5QH0P1CDe<204m?C`80C4a<0P19BDT2
04M7A`D0ATI61018B4P204];B`80BTY:0P16ATH404Y:BP80D51@0P1BDU8205MGE`80EEEE0P1JFUX2
05iNGP@0GemO00<0H61P065QH@1QHF400P1QHF4206=SH`80IFEU0P1XJ6P206e]K@80M7Ad0P1lO7`2
08F5Q@80SXj>0P2JVYX20:RXZ080];Bd0P2n_[h20<K6aP030<o?c`3EeMD0eMGE0080fMWI0P3MgMd2
0>?Sh`80inOW0P3]kNd20>c/k080mOGe0P3hn?P20?Win@80n?Sh0P3bl_820>c/k080inOW0P3QhN40
0`3Lg=`0emOG0=OGe`020=7Ad@80c<c<0P37alL20<;2`P80_Kfm0P2h^;P20;>c/`80[jn_0P2ZZZX2
0:FUY@80X:2P0P2LW9`209NGU`80TY:B00<0SHf=08V9R@29RHT00P24Q8@20820P080Ng]k0P1fMWH2
079bLP80KFe]5@3oool001<0oooo0P1SHf<205iNGP80F5QH0P1CDe<204e=C@80B4Q80P12@T8203dm
?@0303Lg=`0b<S80<S8b0080;2`/0P0V9RH2024Q8@806a/K0P0E5AD2010@40@030`<0P0?3`l201LG
5`80820P0P0/;2`203De=@80?Shn00<0BDU905ADE01DE5@00P1DE5@205IFEP80FEUI0P1JFUX205UI
F@80EUIF0P1CDe<2051@D080Cdm?0P1@D50405ADE080DE5A0`1EEED205aLG080GEeM1P1PH60205iN
GP80Fe]K0P1HF5P205=CD`80Cdm?0P1<C4`204U9B@80AdM71@16ATH404Q8B080Bd];0P1:BTX204I6
AP@0BTY:0P1@D502059BDP80EeMG0P1EEED205YJFP80GUiN101OGel00`1PH600HF5Q065QH@02065Q
H@80Hf=S0P1UIFD206QXJ080KFe]0P1dM7@207alO080QHF50P2>SXh209ZJVP80Z:RX0P2d];@20;jn
_P80a/K600<0clo?0=GEe@3EeMD00P3IfMT20=gMg@80hn?S0P3WinL20>g]k@80k>c/0P3emOD20?Sh
n080nOWi0P3hn?P20?;blP80k>c/0P3WinL20>7Qh@030=cLg03GemL0emOG0080dM7A0P3<c<`20<O7
a`80`/;20P2m_Kd20;Rh^080/k>c0P2_[jl20:ZZZP80YJFU0P2PX:0209bLW080UiNG0P2BTY800`2=
SHd0RHV908V9R@0208B4Q080P8200P1kNg/207IfMP80LW9b0P1]KFdE0?ooo`004`3oool206=SH`80
GUiN0P1HF5P205=CD`80CDe=0P18B4P20492@P80?Cdm00<0=cLg038b<P0b<S800P0/;2`202HV9P80
820P0P0J6QX201@D50803Ph>0P0=3@d200`<30804A4A0P0I6AT2028R8P80;Bd]0P0g=cL20451@@03
04];B`1CDe<0De=C0080De=C0P1FEUH205UIF@80FUYJ0P1IFET205IFEP80De=C0P1ADE42051@D080
DU9B0P1EEED205ADE080De=C0P1GEeL00`1HF5P0GemO05mOG`02061PH0@0Hf=S0P1RHV82061PH080
G5aL0P1HF5P205ADE080D51@0P1=CDd204Y:BP80B4Q81@16ATH404Q8B0@0BTY:0P17AdL404];B`80
DU9B0P1DE5@405QHF080GEeM0P1PH604065QH@<0HV9R0P1SHf<206ATI080IVIV0P1ZJVX206i^KP80
MGEe0P1mOGd208J6QP80Shn?0P2KVi/20:VYZ@80];Bd0P2o_kl20<S8b0030=7Ad@3Fe]H0e]KF0080
fm_K0P3Ph>020>GUi@80j^[Z103_knl20?KfmP80nOWi0P3jn_X20?Ogm`80lO7a0P3[jn/20>KViP80
hN7Q00<0fm_K0=KFeP3Fe]H00P3AdM420<c<c080alO70P32`/820;fm_@80^;Rh0P2c/k<20:j^[P80
ZJVY0P2TY:@20:2PX080Vi^K0P2FUYH209:BTP0308f=S@29RHT0RHV90080Q8B40P1oOgl207]kN`80
MWIf0P1bLW8206e]KAD0oooo000C0?ooo`80Hf=S0P1NGUh205QHF080De=C0P1=CDd204Q8B080@T92
0P0m?Cd00`0g=cL0<S8b038b<P0202`/;0809RHV0P0P820201XJ6P8051@D0P0>3Ph200d=3@8030`<
0P0A4A4201TI6@808R8R0P0];Bd203Lg=`80@D5100<0Bd];05=CD`1CDe<00P1CDe<205IFEP80FEUI
0P1JFUX205UIF@80EUIF0P1CDe<2055AD@80D51@0P1BDU8205EEE@80E5AD0P1CDe<205MGE`0305QH
F01OGel0GemO0080H61P101SHf<2069RHP80H61P0P1LG5`205QHF080E5AD0P1@D50204e=C@80BTY:
0P18B4P504I6AP@0B4Q8101:BTX204M7A`@0Bd];0P1BDU8205ADE0@0F5QH0P1MGEd2061PH0@0HF5Q
0`1RHV8206=SH`80I6AT0P1VIVH206YZJP80KVi^0P1eMGD207emO@80QXJ60P2?Shl209^KV`80ZJVY
0P2d];@20;no_`80b<S800<0dM7A0=KFeP3Fe]H00P3Kfm/20>3Ph080iNGU0P3Zj^X40>o_k`80m_Kf
0P3inOT20?[jnP80moOg0P3alO420>_[j`80i^KV0P3QhN400`3Kfm/0e]KF0=KFeP020=7Ad@80c<c<
0P37alL20<;2`P80_Kfm0P2h^;P20;>c/`80[Zj^0P2YZJT20:BTY080X:2P0P2KVi/209JFUP80TY:B
00<0SHf=08V9R@29RHT00P24Q8@207moO`80Ng]k0P1fMWH2079bLP80KFe]5@3oool001<0oooo0P1S
Hf<205iNGP80F5QH0P1CDe<204e=C@80B4Q80P12@T8203dm?@0303Lg=`0a<C40<C4a0080;2`/0P0V
9RH2020P80806QXJ0P0D51@200d=3@@03Ph>0P0B4Q8201XJ6P809BDU0P0_;bl203Ph>080@d=300<0
C4a<059BDP1BDU800P1DE5@205MGE`80FUYJ0P1KFe/205YJFP80F5QH0P1FEUH205ADE080De=C0P1E
EED405IFEP80F5QH0P1KFe/00`1MGEd0HF5Q065QH@0206=SH`@0I6AT0P1SHf<2061PH080GEeM0P1I
FET205EEE@80DE5A0P1>CTh204];B`80BDU90P17AdL204I6AP<0AdM70P19BDT204Y:BP@0Bd];0P1>
CTh2051@D080De=C0P1FEUH205UIF@80GEeM0P1OGel4065QH@<0HV9R101SHf<206EUI@80IfMW0P1[
Jf/2071`L080MgMg0P1oOgl208N7Q`80TI6A0P2LW9`20:ZZZP80]KFe0P2o_kl20<[:bP030=?Cd`3I
fMT0fMWI0080gMgM0P3Rh^820>SXj080k>c/0P3`l?020?7al@80moOg0P3jn_X20?_kn`80m_Kf0P3`
l?020>_[j`80iNGU0P3Ph>000`3Jf]X0eMGE0=GEe@020=3@d080bl_;0P36a/H20<71`@80_;bl0P2g
]kL20;:b/P80[Zj^0P2YZJT20:BTY080WinO0P2KVi/209JFUP80TI6A00<0SHf=08R8R028R8P00P24
Q8@207moO`80Ng]k0P1fMWH2079bLP80KFe]5@3oool001<0oooo0P1SHf<205iNGP80F5QH0P1CDe<2
04e=C@80B4Q80P12@T8203dm?@0303Lg=`0a<C40<C4a0080;2`/0P0V9RH2020P80806QXJ0P0D51@2
00d=3@@03Ph>0P0B4Q8201XJ6P809BDU0P0_;bl203Ph>080@d=300<0C4a<059BDP1BDU800P1DE5@2
05MGE`80FUYJ0P1KFe/205YJFP80F5QH0P1FEUH205ADE080De=C0P1EEED405IFEP80F5QH0P1KFe/0
0`1MGEd0HF5Q065QH@0206=SH`@0I6AT0P1SHf<2061PH080GEeM0P1IFET205EEE@80DE5A0P1>CTh2
04];B`80BDU90P17AdL204I6AP<0AdM70P19BDT204Y:BP@0Bd];0P1>CTh2051@D080De=C0P1FEUH2
05UIF@80GEeM0P1OGel4065QH@<0HV9R101SHf<206EUI@80IfMW0P1[Jf/2071`L080MgMg0P1oOgl2
08N7Q`80TI6A0P2LW9`20:ZZZP80]KFe0P2o_kl20<[:bP030=?Cd`3IfMT0fMWI0080gMgM0P3Rh^82
0>SXj080k>c/0P3`l?020?7al@80moOg0P3jn_X20?_kn`80m_Kf0P3`l?020>_[j`80iNGU0P3Ph>00
0`3Jf]X0eMGE0=GEe@020=3@d080bl_;0P36a/H20<71`@80_;bl0P2g]kL20;:b/P80[Zj^0P2YZJT2
0:BTY080WinO0P2KVi/209JFUP80TI6A00<0SHf=08R8R028R8P00P24Q8@207moO`80Ng]k0P1fMWH2
079bLP80KFe]5@3oool001<0oooo0P1SHf<205iNGP80F5QH0P1CDe<204e=C@80B4Q80P12@T8203dm
?@0303Lg=`0a<C40<C4a0080;2`/0P0V9RH2020P80806QXJ0P0D51@200h>3P803@d=0P0?3`l201<C
4`807AdM0P0W9bL2030`<080>CTi0P14A4@00`1=CDd0DU9B059BDP0205EEE@80F5QH0P1KFe/205eM
G@80Fe]K0P1JFUX205QHF080EeMG0P1FEUH205MGE`80F5QH0P1IFET205]KF`80GEeM00<0H61P069R
HP1RHV800P1SHf<206EUI@80I6AT0P1SHf<2061PH080G5aL0P1IFET205EEE@80DU9B0P1?Cdl204a<
C080BTY:0P18B4P504M7A`80BDU90P1;Bd/204e=C@80CTi>0P1@D502059BDP80EEEE0P1HF5P205]K
F`80GUiN0P1OGel4061PH080HF5Q00<0HV9R06=SH`1SHf<00P1TI6@206IVIP80JFUY0P1/K6`2075a
L@80N7Qh0P20P80208V9R@80TY:B0P2NWYh20:^[Z`80][Jf0P31`L420<_;b`030=GEe@3Kfm/0fm_K
0080g]kN0P3Ti>@20>_[j`80kno_103bl_820?Shn080o?cl0P3jn_X20?Gem@80kno_0P3Zj^X20>CT
i080gmoO00<0f][J0=CDe03De=@00P3?cll20<[:bP80aLG50P30`<020;^k^`80]kNg0P2b/[820:f]
[@80Z:RX0P2TY:@209nOW`80VYZJ0P2FUYH2096AT@0308f=S@28R8P0R8R80080Q8B40P1oOgl207]k
N`80MWIf0P1aLG4206e]KAD0oooo000C0?ooo`80Hf=S0P1NGUh205QHF080De=C0P1=CDd204Q8B080
@T920P0m?Cd00`0g=cL0<C4a034a<@0202`/;0809RHV0P0P820201XJ6P8051@D0P0>3Ph200d=3@80
3`l?0P0C4a<201dM7@809bLW0P0`<30203Ti>@80A4A400<0CDe=059BDP1BDU800P1EEED205QHF080
Fe]K0P1MGEd205]KF`80FUYJ0P1HF5P205MGE`80EUIF0P1GEeL205QHF080FEUI0P1KFe/205eMG@03
061PH01RHV80HV9R0080Hf=S0P1UIFD206ATI080Hf=S0P1PH60205aLG080FEUI0P1EEED2059BDP80
Cdm?0P1<C4`204Y:BP80B4Q81@17AdL204U9B@80Bd];0P1=CDd204i>CP80D51@0P1BDU8205EEE@80
F5QH0P1KFe/205iNGP80GemO101PH602065QH@03069RHP1SHf<0Hf=S0080I6AT0P1VIVH206UYJ@80
K6a/0P1aLG4207QhN080P8200P29RHT209:BTP80WYjN0P2[Zj/20;Jf]P80`L710P3;bl/00`3EeMD0
fm_K0=_Kf`020=kNgP80i>CT0P3[jn/20>o_k`@0l_;b0P3hn?P20?clo080n_[j0P3emOD20>o_k`80
j^[Z0P3Ti>@20=oOg`030=[JfP3De=@0e=CD0080clo?0P3:b/X20<G5a@80`<300P2k^k/20;Ng]`80
/[:b0P2][Jd20:RXZ080Y:BT0P2OWil209ZJVP80UYJF0P2ATI400`2=SHd0R8R808R8R00208B4Q080
Ogmo0P1kNg/207IfMP80LG5a0P1]KFdE0?ooo`004`3oool206=SH`80GUiN0P1HF5P205=CD`80CDe=
0P18B4P20492@P80?Cdm00<0=cLg034a<@0a<C400P0[:b/202DU9@80820P0P0J6QX201@D50803`l?
0P092@T200l?3`805QHF0P0O7al202TY:@80<S8b0P0j>SX204E5A@0304e=C@1BDU80DU9B0080EUIF
0P1IFET205eMG@80GUiN0P1MGEd205aLG080Fe]K0P1JFUX605UIF@80FUYJ0P1KFe/205eMG@0305mO
G`1QHF40HF5Q0080Hf=S0P1UIFD206ATI080HV9R0P1OGel205aLG080FEUI0P1EEED205=CD`80D51@
0P1=CDd204];B`80BDU91@17AdL204U9B@80Bd];0P1>CTh2051@D080DU9B0P1DE5@205IFEP80F5QH
0P1JFUX205aLG080GEeM0P1NGUh205mOG`80H61P00<0HF5Q069RHP1RHV800P1UIFD206MWI`80JVYZ
0P1]KFd207=cL`80NWYj0P21PH4208Z:RP80U9BD0P2OWil20:b/[080^;Rh0P32`/820<g=c@030=OG
e`3MgMd0gMgM0080h>3P0P3Vi^H20>g]k@80lO7a103dm?@20?[jnP80o?cl0P3inOT20??cl`80k^k^
0P3YjNT20>?Sh`80g]kN00<0fMWI0=CDe03De=@00P3>c/h20<W9b@80a<C40P30`<020;^k^`80][Jf
0P2a/K420:b/[080Z:RX0P2SXj<209nOW`80VYZJ0P2EUID2096AT@0308b<S028R8P0R8R80080Ph>3
0P1oOgl207YjNP80MWIf0P1aLG4206e]KAD0oooo000C0?ooo`80Hf=S0P1NGUh205QHF080De=C0P1>
CTh204Q8B080@d=30P0m?Cd00`0g=cL0<C4a034a<@0202/[:`809BDU0P0P820201TI6@8051@D0P0?
3`l200P820804A4A0P0H61P2028R8P80:b/[0P0d=3@203/k>`80ATI600<0CDe=05=CD`1CDe<00P1G
EeL205YJFP80GUiN0P1PH60205mOG`80GUiN0P1MGEd205aLG080Fe]K1P1JFUX205]KF`80GUiN00<0
HF5Q06ATI01TI6@0101UIFD206=SH`80HF5Q0P1NGUh205]KF`80F5QH0P1EEED205=CD`80D51@0P1>
CTh204a<C080BTY:0P19BDT304Q8B080BTY:0P1<C4`204m?C`80DE5A0P1CDe<205ADE080EUIF0P1G
EeL205UIF@80FUYJ0P1LG5`205eMG@80GUiN0P1OGel00`1PH600Hf=S06=SH`0206EUI@80IfMW0P1Z
JVX206m_K`80M7Ad0P1jNWX208:2PP80Rh^;0P2EUID20:6QX@80[Jf]0P2i^KT20<G5a@80d=3@00<0
f=SH0=kNgP3Ng]h00P3Shn<20>SXj080kno_0P3bl_820?Gem@80m_Kf0P3jn_X20?clo080n?Sh0P3b
l_820>g]k@80inOW0P3Rh^820=gMg@030=SHf03Cdm<0dm?C0080c/k>0P39bLT20<C4a080_kno0P2j
^[X20;Fe]@80/K6a0P2/[:`20:NWY`80Xj>S0P2NWYh209ZJVP80UIFE0P2ATI400`2<S8`0R8R808R8
R00208>3P`80Ogmo0P1jNWX207IfMP80LG5a0P1]KFdE0?ooo`004`3oool206=SH`80GUiN0P1HF5P2
05=CD`80CTi>0P18B4P204=3@`80?Cdm00<0=cLg034a<@0a<C400P0[:b/202DU9@80820P0P0I6AT2
01@D50803`l?0P0820P2014A4@8061PH0P0R8R8202/[:`80=3@d0P0k>c/204I6AP0304e=C@1CDe<0
De=C0080EeMG0P1JFUX205iNGP80H61P0P1OGel205iNGP80GEeM0P1LG5`205]KF`H0FUYJ0P1KFe/2
05iNGP03065QH@1TI6@0I6AT00@0IFEU0P1SHf<2065QH@80GUiN0P1KFe/205QHF080EEEE0P1CDe<2
051@D080CTi>0P1<C4`204Y:BP80BDU90`18B4P204Y:BP80C4a<0P1?Cdl2055AD@80De=C0P1DE5@2
05IFEP80EeMG0P1IFET205YJFP80G5aL0P1MGEd205iNGP80GemO00<0H61P06=SH`1SHf<00P1UIFD2
06MWI`80JVYZ0P1_Kfl207AdM080NWYj0P22PX8208^;R`80UIFE0P2QXJ420:f][@80^KVi0P35aLD2
0=3@d0030=SHf03Ng]h0g]kN0080hn?S0P3Xj>P20>o_k`80l_;b0P3emOD20?KfmP80n_[j0P3lo?`2
0?Shn080l_;b0P3]kNd20>OWi`80h^;R0P3MgMd00`3Hf=P0dm?C0=?Cd`020<k>cP80bLW90P34a<@2
0;no_`80^[Zj0P2e]KD20;6a/@80[:b/0P2WYjL20:>SX`80WYjN0P2JVYX209FEU@80TI6A00<0S8b<
08R8R028R8P00P23Ph<207moO`80NWYj0P1fMWH2075aL@80KFe]5@3oool001<0oooo0P1SHf<205iN
GP80FEUI0P1CDe<204i>CP80B4Q80P13@d<203dm?@0303Lg=`0b<S80<S8b0080;2`/0P0U9BD201lO
7`806ATI0P0B4Q82010@40802PX:0P0C4a<201/K6`8092@T0P0/;2`203De=@80?Cdm0P16ATH00`1=
CDd0De=C05=CD`0205QHF080G5aL0P1PH602069RHP80HF5Q101NGUh205eMG@@0G5aL0P1KFe/205aL
G080H61P0P1RHV800`1SHf<0IFEU06EUI@0206ATI080Hf=S0P1RHV82061PH080GEeM0P1JFUX205QH
F080EEEE0P1CDe<2055AD@80Cdm?0P1=CDd204a<C0D0BTY:0P1;Bd/204e=C@80Cdm?0P1ADE4205=C
D`80E5AD0P1EEED205IFEP80F5QH0P1IFET205YJFP80Fe]K0P1MGEd205mOG`03065QH@1TI6@0I6AT
0080IVIV0P1XJ6P206][J`80L71`0P1fMWH207alO080Q8B40P2<S8`209NGU`80Xj>S0P2^[Zh20;Zj
^P80alO70P3Bd]800`3Jf]X0h>3P0>3Ph0020>GUi@80j^[Z0P3alO420??cl`80mOGe0P3hn?P40?cl
o080m_Kf0P3alO420>c/k080i^KV0P3QhN420=cLg0030=OGe`3Bd]80d];B0080cLg=0P38b<P20<?3
``80_[jn0P2i^KT20;Fe]@80/;2`0P2[Zj/20:NWY`80XZ:R0P2NWYh209VIV@80UIFE0P2@T9000`2<
S8`0QhN708N7Q`0208>3P`80OWin0P1jNWX207IfMP80LG5a0P1]KFdE0?ooo`004`3oool206=SH`80
GUiN0P1IFET205=CD`80CTi>0P18B4P204=3@`80?Cdm00<0=cLg038b<P0b<S800P0/;2`202DU9@80
7alO0P0I6AT2018B4P80410@0P0:2PX201<C4`806a/K0P0T92@202`/;080=CDe0P0m?Cd204I6AP03
04e=C@1CDe<0De=C0080F5QH0P1LG5`2061PH080HV9R0P1QHF4405iNGP80GEeM101LG5`205]KF`80
G5aL0P1PH602069RHP0306=SH`1UIFD0IFEU0080I6AT0P1SHf<2069RHP80H61P0P1MGEd205YJFP80
F5QH0P1EEED205=CD`80DE5A0P1?Cdl204e=C@80C4a<1@1:BTX204];B`80CDe=0P1?Cdl2055AD@80
De=C0P1DE5@205EEE@80EUIF0P1HF5P205UIF@80FUYJ0P1KFe/205eMG@80GemO00<0HF5Q06ATI01T
I6@00P1VIVH206QXJ080Jf][0P1`L70207IfMP80O7al0P24Q8@208b<S080UiNG0P2SXj<20:j^[P80
^[Zj0P37alL20=;BdP030=[JfP3Ph>00h>3P0080iNGU0P3Zj^X20?7al@80lo?c0P3emOD20?Shn0@0
o?cl0P3fm_H20?7al@80k>c/0P3Vi^H20>7Qh@80g=cL00<0emOG0=;BdP3Bd]800P3=cLd20<S8b080
`l?30P2n_[h20;Vi^@80]KFe0P2`/;020:^[Z`80YjNW0P2RXZ8209jNWP80VIVI0P2EUID2092@T003
08b<S027QhL0QhN70080Ph>30P1nOWh207YjNP80MWIf0P1aLG4206e]KAD0oooo000C0?ooo`80Hf=S
0P1NGUh205UIF@80De=C0P1>CTh204U9B@80@d=30P0m?Cd00`0h>3P0<S8b038b<P0202`/;0809RHV
0P0P820201TI6@804A4A0P0?3`l200d=3@805QHF0P0N7Qh202HV9P80;Bd]0P0f=SH203dm?@80ATI6
00<0CDe=05=CD`1CDe<00P1IFET205iNGP80HV9R0P1TI6@206=SH`80HF5Q0P1PH60205mOG`@0GUiN
0P1OGel2065QH@L0Hf=S0P1RHV82065QH@80H61P0P1NGUh205aLG080FEUI0P1GEeL205EEE@80De=C
0P1ADE42051@D080CTi>0P1=CDd204a<C0<0Bd];0P1<C4`204i>CP80Cdm?0P1ADE4205=CD`@0EEEE
0P1FEUH205QHF080FEUI0P1JFUX205eMG@80GUiN0P1PH6000`1RHV80I6AT06ATI00206IVIP80JFUY
0P1/K6`2075aL@80MgMg0P1mOGd208F5Q@80SHf=0P2IVIT20:BTY080[jn_0P2l_;`20<W9b@80eMGE
00<0g=cL0>7Qh@3QhN400P3WinL20>c/k080l_;b0P3emOD20?KfmP80n_[j0P3no_h20?_kn`80mOGe
0P3`l?020>[ZjP80iNGU0P3Ph>020=_Kf`030=KFeP3AdM40dM7A0080c<c<0P37alL20<;2`P80_Kfm
0P2h^;P20;Bd]080[jn_0P2[Zj/20:JVYP80XZ:R0P2MWId209VIV@80U9BD0P2@T9000`2;Rh/0QhN7
08N7Q`0208>3P`80OWin0P1jNWX207IfMP80LG5a0P1]KFdE0?ooo`004`3oool206=SH`80GUiN0P1I
FET205=CD`80CTi>0P19BDT204=3@`80?Cdm00<0>3Ph038b<P0b<S800P0/;2`202HV9P80820P0P0I
6AT2014A4@803`l?0P0=3@d201HF5P807QhN0P0V9RH202d];@80=SHf0P0m?Cd204I6AP0304e=C@1C
De<0De=C0080FEUI0P1NGUh2069RHP80I6AT0P1SHf<2065QH@80H61P0P1OGel405iNGP80GemO0P1Q
HF4706=SH`80HV9R0P1QHF42061PH080GUiN0P1LG5`205UIF@80EeMG0P1EEED205=CD`80DE5A0P1@
D50204i>CP80CDe=0P1<C4`304];B`80C4a<0P1>CTh204m?C`80DE5A0P1CDe<405EEE@80EUIF0P1H
F5P205UIF@80FUYJ0P1MGEd205iNGP80H61P00<0HV9R06ATI01TI6@00P1VIVH206UYJ@80K6a/0P1a
LG4207MgM`80OGem0P25QHD208f=S@80VIVI0P2TY:@20:n_[`80_;bl0P39bLT20=GEe@030=cLg03Q
hN40hN7Q0080inOW0P3/k>`20?;blP80mOGe0P3fm_H20?[jnP80o_kn0P3kno/20?Gem@80l?3`0P3Z
j^X20>GUi@80h>3P0P3Kfm/00`3Fe]H0dM7A0=7Ad@020<c<c080alO70P32`/820;fm_@80^;Rh0P2d
];@20:n_[`80Zj^[0P2VYZH20::RXP80WIfM0P2IVIT209BDU080T92@00<0Rh^;08N7Q`27QhL00P23
Ph<207inOP80NWYj0P1fMWH2075aL@80KFe]5@3oool001<0oooo0P1SHf<205iNGP80FEUI0P1DE5@2
04i>CP80BDU90P13@d<203hn?P0303Ph>00b<S80<S8b0080;2`/0P0V9RH2020P80806ATI0P0A4A42
00l?3`804Q8B0P0I6AT2024Q8@809bLW0P0^;Rh203Hf=P80?Shn0P16ATH00`1=CDd0E5AD05ADE002
05YJFP80GemO0P1TI6@206IVIP80I6AT0P1SHf<2069RHPH0HF5Q0P1RHV8406=SH`<0HV9R101QHF42
061PH080GUiN0P1MGEd205]KF`80FEUI0P1GEeL205EEE@80E5AD0P1BDU82051@D080Cdm?0P1>CTh7
04e=C@80CTi>0P1@D502055AD@80DU9B101DE5@205IFEP80F5QH0P1IFET205]KF`80GEeM0P1NGUh2
061PH003069RHP1TI6@0I6AT0080IVIV0P1YJFT206e]K@80Lg=c0P1hN7P207inOP80QXJ60P2?Shl2
09VIV@80YJFU0P2a/K420;no_`80c<c<0P3IfMT00`3MgMd0hn?S0>?Sh`020>[ZjP80kNg]0P3bl_82
0?KfmP80moOg0P3lo?`20?ooo`80nOWi0P3dm?@20>k^kP80jNWY0P3Ti>@20=oOg`80f][J00<0e=CD
0=3@d03@d=000P3;bl/20<K6aP80`L710P2l_;`20;Rh^080/k>c0P2^[Zh20:ZZZP80YJFU0P2QXJ42
09bLW080V9RH0P2DU9@208n?S`0308^;R`27QhL0QhN70080PX:20P1nOWh207YjNP80MGEe0P1aLG42
06e]KAD0oooo000C0?ooo`80Hf=S0P1NGUh205UIF@80E5AD0P1>CTh204U9B@80@d=30P0n?Sh00`0h
>3P0<S8b038b<P0202`/;0809RHV0P0P820201TI6@804A4A0P0?3`l2018B4P806ATI0P0Q8B4202LW
9`80;Rh^0P0f=SH203hn?P80ATI600<0CDe=05ADE01DE5@00P1JFUX205mOG`80I6AT0P1VIVH206AT
I080Hf=S0P1RHV86065QH@80HV9R101SHf<3069RHP@0HF5Q0P1PH60205iNGP80GEeM0P1KFe/205UI
F@80EeMG0P1EEED205ADE080DU9B0P1@D50204m?C`80CTi>1`1=CDd204i>CP80D51@0P1ADE42059B
DP@0E5AD0P1FEUH205QHF080FEUI0P1KFe/205eMG@80GUiN0P1PH6000`1RHV80I6AT06ATI00206IV
IP80JFUY0P1]KFd207=cL`80N7Qh0P1nOWh208J6QP80Shn?0P2IVIT20:FUY@80/K6a0P2o_kl20<c<
c080fMWI00<0gMgM0>?Sh`3Shn<00P3Zj^X20>g]k@80l_;b0P3fm_H20?Ogm`80o?cl0P3oool20?Wi
n@80m?Cd0P3^k^h20>WYj@80i>CT0P3Ogml20=[JfP030=CDe03@d=00d=3@0080bl_;0P36a/H20<71
`@80_;bl0P2h^;P20;>c/`80[Zj^0P2ZZZX20:FUY@80XJ6Q0P2LW9`209RHV080U9BD0P2?Shl00`2;
Rh/0QhN708N7Q`0208:2PP80OWin0P1jNWX207EeM@80LG5a0P1]KFdE0?ooo`004`3oool206=SH`80
GUiN0P1IFET205ADE080CTi>0P19BDT204A4A080?Shn00<0>CTi03<c<`0c<c<00P0];Bd202LW9`80
820P0P0J6QX2018B4P803`l?0P0E5AD201`L70808b<S0P0X:2P202h^;P80=SHf0P0n?Sh204I6AP03
04e=C@1DE5@0E5AD0080Fe]K0P1PH60206EUI@80IfMW0P1VIVH206EUI@80I6AT101SHf<8069RHP<0
HF5Q0P1PH60205mOG`80GUiN0P1MGEd205]KF`80FUYJ0P1HF5P205IFEP80EEEE0P1CDe<2059BDP80
D51@0P1?Cdl404i>CP<0CDe=101>CTh4051@D080DU9B0P1CDe<205ADE080EUIF0P1GEeL205QHF080
FUYJ0P1LG5`205eMG@80GemO00<0HV9R06ATI01TI6@00P1WIfL206YZJP80KVi^0P1dM7@207UiN@80
Ogmo0P27QhL2092@T080Vi^K0P2WYjL20;Bd]080`L710P3>c/h20=cLg0030=oOg`3UiND0iNGU0080
k>c/0P3^k^h20??cl`@0n?Sh103no_h20?Shn080l_;b0P3]kNd20>SXj080h^;R0P3MgMd20=SHf003
0=?Cd`3>c/h0c/k>0080b/[:0P35aLD20<30`080^k^k0P2g]kL20;:b/P80[Zj^0P2YZJT20:FUY@80
X:2P0P2LW9`209RHV080Ti>C0P2?Shl00`2;Rh/0QXJ608J6QP0208:2PP80OWin0P1jNWX207EeM@80
LG5a0P1]KFdE0?ooo`004`3oool206=SH`80GUiN0P1IFET205ADE080CTi>0P19BDT204A4A080?Shn
00<0>CTi03<c<`0c<c<00P0];Bd202LW9`80820P0P0J6QX2018B4P803`l?0P0E5AD201`L70808b<S
0P0X:2P202h^;P80=SHf0P0n?Sh204I6AP0304e=C@1DE5@0E5AD0080Fe]K0P1PH60206EUI@80IfMW
0P1VIVH206EUI@80I6AT101SHf<8069RHP<0HF5Q0P1PH60205mOG`80GUiN0P1MGEd205]KF`80FUYJ
0P1HF5P205IFEP80EEEE0P1CDe<2059BDP80D51@0P1?Cdl404i>CP<0CDe=101>CTh4051@D080DU9B
0P1CDe<205ADE080EUIF0P1GEeL205QHF080FUYJ0P1LG5`205eMG@80GemO00<0HV9R06ATI01TI6@0
0P1WIfL206YZJP80KVi^0P1dM7@207UiN@80Ogmo0P27QhL2092@T080Vi^K0P2WYjL20;Bd]080`L71
0P3>c/h20=cLg0030=oOg`3UiND0iNGU0080k>c/0P3^k^h20??cl`@0n?Sh103no_h20?Shn080l_;b
0P3]kNd20>SXj080h^;R0P3MgMd20=SHf0030=?Cd`3>c/h0c/k>0080b/[:0P35aLD20<30`080^k^k
0P2g]kL20;:b/P80[Zj^0P2YZJT20:FUY@80X:2P0P2LW9`209RHV080Ti>C0P2?Shl00`2;Rh/0QXJ6
08J6QP0208:2PP80OWin0P1jNWX207EeM@80LG5a0P1]KFdE0?ooo`004`3oool206=SH`80GUiN0P1I
FET205ADE080Cdm?0P1:BTX204A4A080?clo00<0>SXj03@d=00d=3@00P0^;Rh202PX:0808R8R0P0K
6a/201@D5080410@0P0G5aL201dM7@8092@T0P0Y:BT202l_;`80=cLg0P0n?Sh204I6AP0304e=C@1E
EED0EEEE0080G5aL0P1QHF4206IVIP80J6QX0P1WIfL206IVIP80IFEU101TI6@406=SH`80HV9R101Q
HF400`1PH600GemO05mOG`0205iNGP80GEeM0P1LG5`205YJFP80FEUI0P1GEeL205IFEP80E5AD0P1C
De<2059BDP80DE5A0P1@D50204m?C`L0CTi>0P1?Cdl4051@D080DE5A0P1BDU8205ADE080EEEE0P1F
EUH205QHF080FEUI0P1KFe/205eMG@80GemO00<0HF5Q06ATI01TI6@00P1WIfL206YZJP80Kfm_0P1e
MGD207YjNP80P8200P28R8P2096AT@80WIfM0P2YZJT20;Fe]@80`l?30P3AdM420=kNgP030>7Qh@3W
inL0inOW0080kNg]0P3_knl20??cl`80nOWi0P3jn_X20?ooo`80o?cl0P3fm_H20?7al@80jn_[0P3V
i^H20>7Qh@80g=cL0P3GemL00`3Bd]80cLg=0<g=c@020<S8b080a<C40P2o_kl20;Zj^P80][Jf0P2a
/K420:f][@80Z:RX0P2TY:@20:2PX080Vi^K0P2GUiL209>CT`80SXj>00<0RXZ:08J6QP26QXH00P22
PX8207inOP80NGUi0P1eMGD2075aL@80KFe]5@3oool001<0oooo0P1SHf<205iNGP80FEUI0P1DE5@2
04m?C`80BTY:0P14A4@203lo?`0303Xj>P0d=3@0=3@d0080;Rh^0P0X:2P2028R8P806a/K0P0D51@2
010@40805aLG0P0M7Ad202@T9080:BTY0P0_;bl203Lg=`80?Shn0P16ATH00`1=CDd0EEEE05EEE@02
05aLG080HF5Q0P1VIVH206QXJ080IfMW0P1VIVH206EUI@@0I6AT101SHf<2069RHP@0HF5Q00<0H61P
05mOG`1OGel00P1NGUh205eMG@80G5aL0P1JFUX205UIF@80EeMG0P1FEUH205ADE080De=C0P1BDU82
055AD@80D51@0P1?Cdl704i>CP80Cdm?101@D502055AD@80DU9B0P1DE5@205EEE@80EUIF0P1HF5P2
05UIF@80Fe]K0P1MGEd205mOG`03065QH@1TI6@0I6AT0080IfMW0P1ZJVX206m_K`80MGEe0P1jNWX2
0820P080R8R80P2ATI4209fMW@80ZJVY0P2e]KD20<?3``80dM7A0P3Ng]h00`3QhN40inOW0>OWi`02
0>g]k@80kno_0P3clo<20?Win@80n_[j0P3oool20?clo080m_Kf0P3alO420>_[j`80i^KV0P3QhN42
0=cLg080emOG00<0d];B0<g=c@3=cLd00P38b<P20<C4a080_kno0P2j^[X20;Jf]P80/K6a0P2][Jd2
0:RXZ080Y:BT0P2PX:0209^KV`80UiNG0P2CTi<208j>SP0308Z:RP26QXH0QXJ60080PX:20P1nOWh2
07UiN@80MGEe0P1aLG4206e]KAD0oooo000C0?ooo`80I6AT0P1OGel205YJFP80E5AD0P1?Cdl204Y:
BP80ADE50P10@4000`0j>SX0=CDe03De=@0202l_;`80:BTY0P0S8b<201dM7@805QHF0P0A4A4201PH
60807QhN0P0T92@202XZ:P80<30`0P0g=cL203hn?P80ATI600<0CTi>05EEE@1EEED00P1MGEd2069R
HP80IVIV0P1YJFT206QXJ080IfMW0P1VIVH206EUI@80I6AT101SHf<2069RHP80HF5Q0P1PH6000`1O
Gel0GUiN05iNGP0205eMG@80G5aL0P1KFe/205YJFP80F5QH0P1GEeL205EEE@80E5AD0P1CDe<2059B
DP80DE5A0P1@D50=04m?C`80D51@0P1ADE42059BDP80De=C0P1EEED205IFEP80EeMG0P1IFET205]K
F`80GEeM0P1OGel00`1QHF40I6AT06ATI00206MWI`80Jf][0P1`L70207EeM@80Ng]k0P21PH4208V9
R@80Ti>C0P2OWil20:ZZZP80]kNg0P35aLD20=CDe080h>3P00<0iNGU0>WYj@3YjNT00P3^k^h20?3`
l080m?Cd0P3inOT20?gmo@80oooo0P3jn_X20?Cdm080kno_0P3Zj^X20>CTi080gmoO0P3Jf]X20=GE
e@030=7Ad@3<c<`0c<c<0080alO70P32`/820;jn_P80^KVi0P2e]KD20;2`/080[:b/0P2XZ:P20:>S
X`80WinO0P2KVi/209JFUP80TY:B0P2>SXh00`2:RXX0QXJ608J6QP020861P@80OGem0P1iNGT207Ee
M@80LG5a0P1]KFdE0?ooo`004`3oool206ATI080GemO0P1JFUX205ADE080Cdm?0P1:BTX204E5A@80
@41000<0>SXj03De=@0e=CD00P0_;bl202TY:@808b<S0P0M7Ad201HF5P804A4A0P0H61P201hN7P80
92@T0P0Z:RX2030`<080=cLg0P0n?Sh204I6AP0304i>CP1EEED0EEEE0080GEeM0P1RHV8206IVIP80
JFUY0P1XJ6P206MWI`80IVIV0P1UIFD206ATI0@0Hf=S0P1RHV82065QH@80H61P00<0GemO05iNGP1N
GUh00P1MGEd205aLG080Fe]K0P1JFUX205QHF080EeMG0P1EEED205ADE080De=C0P1BDU82055AD@80
D51@3@1?Cdl2051@D080DE5A0P1BDU8205=CD`80EEEE0P1FEUH205MGE`80FEUI0P1KFe/205eMG@80
GemO00<0HF5Q06ATI01TI6@00P1WIfL206][J`80L71`0P1eMGD207]kN`80PH610P29RHT209>CT`80
WinO0P2ZZZX20;Ng]`80aLG50P3De=@20>3Ph0030>GUi@3YjNT0jNWY0080k^k^0P3`l?020?Cdm080
nOWi0P3moOd20?ooo`80n_[j0P3dm?@20>o_k`80j^[Z0P3Ti>@20=oOg`80f][J0P3EeMD00`3AdM40
c<c<0<c<c0020<O7a`80`/;20P2n_[h20;Vi^@80]KFe0P2`/;020:b/[080Z:RX0P2SXj<209nOW`80
Vi^K0P2FUYH209:BTP80SXj>00<0RXZ:08J6QP26QXH00P21PH4207emO@80NGUi0P1eMGD2075aL@80
KFe]5@3oool001<0oooo0P1TI6@205mOG`80FUYJ0P1EEED2051@D080Bd];0P16ATH20451@@0303/k
>`0f=SH0=SHf0080<30`0P0[:b/202DU9@807alO0P0I6AT2018B4P8061PH0P0N7Qh202DU9@80:b/[
0P0a<C4203Lg=`80?clo0P16ATH00`1>CTh0EEEE05EEE@0205eMG@80HV9R0P1VIVH406UYJ@80J6QX
0P1WIfL206IVIP80IFEU0P1TI6@206=SH`80HV9R0P1QHF4205mOG`<0GUiN0P1LG5`205]KF`80FUYJ
0P1IFET205MGE`80EUIF0P1EEED205ADE0@0DU9B0P1ADE44051@D0T0Cdm?101@D502055AD@80DU9B
0P1CDe<205EEE@80EUIF0P1GEeL205UIF@80Fe]K0P1MGEd205mOG`03065QH@1UIFD0IFEU0080J6QX
0P1/K6`2075aL@80MWIf0P1lO7`208>3P`80Rh^;0P2EUID20:2PX080[:b/0P2j^[X20<S8b080e]KF
0P3Rh^800`3WinL0j^[Z0>[ZjP020?3`l080l_;b0P3fm_H20?[jnP80oooo0P3moOd20?Shn080l_;b
0P3]kNd20>SXj080hn?S0P3Ng]h20=WIf@80e=CD00<0clo?0<_;b`3;bl/00P36a/H20<71`@80_Kfm
0P2h^;P20;Bd]080[jn_0P2[Zj/20:NWY`80XZ:R0P2NWYh209ZJVP80UYJF0P2BTY8208f=S@0308V9
R@25QHD0QHF50080PH610P1mOGd207UiN@80MGEe0P1aLG4206e]KAD0oooo000C0?ooo`80I6AT0P1O
Gel205YJFP80EEEE0P1@D50204];B`80ATI60P11@D400`0k>c/0=SHf03Hf=P02030`<080:b/[0P0U
9BD201lO7`806ATI0P0B4Q8201PH60807QhN0P0U9BD202/[:`80<C4a0P0g=cL203lo?`80ATI600<0
CTi>05EEE@1EEED00P1MGEd2069RHP80IVIV101YJFT206QXJ080IfMW0P1VIVH206EUI@80I6AT0P1S
Hf<2069RHP80HF5Q0P1OGel305iNGP80G5aL0P1KFe/205YJFP80FEUI0P1GEeL205IFEP80EEEE0P1D
E5@4059BDP80DE5A101@D50904m?C`@0D51@0P1ADE42059BDP80De=C0P1EEED205IFEP80EeMG0P1I
FET205]KF`80GEeM0P1OGel00`1QHF40IFEU06EUI@0206QXJ080K6a/0P1aLG4207IfMP80O7al0P23
Ph<208^;R`80UIFE0P2PX:020:b/[080^[Zj0P38b<P20=KFeP80h^;R00<0inOW0>[ZjP3Zj^X00P3`
l?020?;blP80m_Kf0P3jn_X20?ooo`80oOgm0P3hn?P20?;blP80kNg]0P3Xj>P20>?Sh`80g]kN0P3I
fMT20=CDe0030<o?c`3;bl/0bl_;0080a/K60P31`L420;fm_@80^;Rh0P2d];@20:n_[`80Zj^[0P2W
YjL20::RXP80WYjN0P2JVYX209JFUP80TY:B0P2=SHd00`29RHT0QHF508F5Q@020861P@80OGem0P1i
NGT207EeM@80LG5a0P1]KFdE0?ooo`004`3oool206ATI080GemO0P1JFUX205EEE@80D51@0P1<C4`2
04M7A`80@T9200<0?3`l03Lg=`0g=cL00P0b<S8202`/;0809bLW0P0Q8B4201/K6`8051@D0P0I6AT2
01lO7`809RHV0P0[:b/2034a<@80>3Ph0P0o?cl204I6AP0304i>CP1FEUH0EUIF0080GEeM0P1RHV82
06IVIPH0JFUY0P1WIfL206IVIP80IFEU0P1TI6@2069RHP80HF5Q0P1PH60205mOG`0305iNGP1MGEd0
GEeM0080G5aL0P1JFUX205UIF@80F5QH0P1GEeL205IFEP80E5AD0P1CDe<4059BDP80DE5A101@D509
04m?C`80D51@101ADE42059BDP80De=C0P1EEED205IFEP80EeMG0P1IFET205]KF`80GEeM0P1OGel0
0`1RHV80IFEU06EUI@0206QXJ080KFe]0P1bLW8207MgM`80OGem0P24Q8@208f=S@80UiNG0P2RXZ82
0:n_[`80_Kfm0P3;bl/20=WIf@80hn?S00<0jNWY0>c/k03/k>`00P3bl_820?Gem@80n?Sh0P3kno/2
0?ooo`80no_k0P3emOD20?3`l080jn_[0P3Vi^H20>7Qh@80g=cL0P3GemL20=;BdP030<k>cP39bLT0
bLW90080aLG50P30`<020;bl_080]kNg0P2c/k<20:j^[P80ZZZZ0P2VYZH20::RXP80WIfM0P2IVIT2
09FEU@80TI6A0P2=SHd00`29RHT0QHF508F5Q@020861P@80OGem0P1iNGT207EeM@80LG5a0P1]KFdE
0?ooo`004`3oool206ATI080GemO0P1JFUX205EEE@80D51@0P1<C4`204M7A`80@T9200<0?3`l03Lg
=`0g=cL00P0b<S8202`/;0809bLW0P0Q8B4201/K6`8051@D0P0I6AT201lO7`809RHV0P0[:b/2034a
<@80>3Ph0P0o?cl204I6AP0304i>CP1FEUH0EUIF0080GEeM0P1RHV8206IVIPH0JFUY0P1WIfL206IV
IP80IFEU0P1TI6@2069RHP80HF5Q0P1PH60205mOG`0305iNGP1MGEd0GEeM0080G5aL0P1JFUX205UI
F@80F5QH0P1GEeL205IFEP80E5AD0P1CDe<4059BDP80DE5A101@D50904m?C`80D51@101ADE42059B
DP80De=C0P1EEED205IFEP80EeMG0P1IFET205]KF`80GEeM0P1OGel00`1RHV80IFEU06EUI@0206QX
J080KFe]0P1bLW8207MgM`80OGem0P24Q8@208f=S@80UiNG0P2RXZ820:n_[`80_Kfm0P3;bl/20=WI
f@80hn?S00<0jNWY0>c/k03/k>`00P3bl_820?Gem@80n?Sh0P3kno/20?ooo`80no_k0P3emOD20?3`
l080jn_[0P3Vi^H20>7Qh@80g=cL0P3GemL20=;BdP030<k>cP39bLT0bLW90080aLG50P30`<020;bl
_080]kNg0P2c/k<20:j^[P80ZZZZ0P2VYZH20::RXP80WIfM0P2IVIT209FEU@80TI6A0P2=SHd00`29
RHT0QHF508F5Q@020861P@80OGem0P1iNGT207EeM@80LG5a0P1]KFdE0?ooo`004`3oool206ATI080
GemO0P1JFUX205IFEP80DE5A0P1<C4`204M7A`80@d=300<0?Shn03Ph>00h>3P00P0c<c<202h^;P80
:BTY0P0S8b<201dM7@805QHF0P0K6a/2020P80809BDU0P0[:b/2034a<@80>3Ph0P0o?cl204M7A`03
04i>CP1FEUH0EUIF0080GEeM0P1RHV8206IVIP80J6QX101YJFT206QXJ080IVIV0P1UIFD206=SH`80
HV9R0P1QHF42061PH080GUiN00<0GEeM05aLG01LG5`00P1KFe/205UIF@80F5QH0P1GEeL205IFEP80
EEEE0P1DE5@205=CD`@0DU9B0P1ADE46051@D0D0Cdm?101@D502055AD@@0DU9B0P1DE5@205EEE@80
EUIF0P1HF5P205UIF@80G5aL0P1NGUh2061PH003069RHP1VIVH0IVIV0080JFUY0P1]KFd2079bLP80
N7Qh0P1oOgl208J6QP80Shn?0P2IVIT20:BTY080/[:b0P30`<020<g=c@80g=cL0P3Ti>@00`3Zj^X0
kno_0>o_k`020?Cdm080moOg0P3jn_X20?clo080oOgm0P3hn?P20??cl`80k^k^0P3YjNT20>CTi080
gmoO0P3Jf]X20=GEe@80dM7A00<0c<c<0<S8b038b<P00P33`l<20;no_`80^[Zj0P2f][H20;:b/P80
[Jf]0P2YZJT20:FUY@80XJ6Q0P2MWId209VIV@80U9BD0P2@T90208b<S00308R8R024Q8@0Q8B40080
P8200P1lO7`207QhN080M7Ad0P1`L70206e]KAD0oooo000C0?ooo`80I6AT0P1OGel205YJFP80EUIF
0P1ADE4204a<C080AdM70P13@d<00`0n?Sh0>3Ph03Ph>00203<c<`80;Rh^0P0Y:BT202<S8`807AdM
0P0F5QH201/K6`80820P0P0U9BD202/[:`80<C4a0P0h>3P203lo?`80AdM700<0CTi>05IFEP1FEUH0
0P1MGEd2069RHP80IVIV0P1XJ6P406UYJ@80J6QX0P1VIVH206EUI@80Hf=S0P1RHV82065QH@80H61P
0P1NGUh00`1MGEd0G5aL05aLG00205]KF`80FEUI0P1HF5P205MGE`80EUIF0P1EEED205ADE080De=C
101BDU82055AD@H0D51@1@1?Cdl4051@D080DE5A101BDU8205ADE080EEEE0P1FEUH205QHF080FEUI
0P1LG5`205iNGP80H61P00<0HV9R06IVIP1VIVH00P1YJFT206e]K@80LW9b0P1hN7P207moO`80QXJ6
0P2?Shl209VIV@80Y:BT0P2b/[820<30`080cLg=0P3Lg=`20>CTi0030>[ZjP3_knl0kno_0080m?Cd
0P3gmoL20?[jnP80o?cl0P3moOd20?Shn080lo?c0P3^k^h20>WYj@80i>CT0P3Ogml20=[JfP80eMGE
0P3AdM400`3<c<`0b<S80<S8b0020<?3``80_kno0P2j^[X20;Jf]P80/[:b0P2][Jd20:VYZ@80YJFU
0P2QXJ4209fMW@80VIVI0P2DU9@2092@T080S8b<00<0R8R808B4Q024Q8@00P20P80207alO080N7Qh
0P1dM7@2071`L080KFe]5@3oool001<0oooo0P1TI6@205mOG`80Fe]K0P1FEUH2059BDP80CDe=0P18
B4P204A4A00303lo?`0j>SX0>SXj0080=CDe0P0`<30202/[:`809RHV0P0P820201XJ6P806a/K0P0O
7al202@T9080:b/[0P0a<C4203Ph>080?clo0P17AdL00`1>CTh0EUIF05IFEP0205eMG@80HV9R0P1U
IFD206QXJ080JFUY0P1XJ6P206MWI`80IVIV0P1TI6@206=SH`80HV9R0P1PH60205mOG`80GEeM00<0
G5aL05]KF`1KFe/00P1JFUX205QHF080EeMG101FEUH205ADE0@0De=C0P1BDU84055AD@H0D51@0`1?
Cdl4051@D0@0DE5A0P1BDU8205=CD`80E5AD0P1EEED205IFEP80F5QH0P1JFUX205aLG080GUiN0P1Q
HF400`1SHf<0IfMW06MWI`0206YZJP80KVi^0P1cLg<207YjNP80P8200P28R8P2096AT@80Vi^K0P2W
YjL20;Fe]@80`l?30P3@d=020=oOg`80iNGU00<0jn_[0?3`l03`l?000P3gmoL20?Win@80no_k0P3m
oOd20?[jnP80mOGe0P3`l?020>_[j`80inOW0P3Rh^820=gMg@80f=SH0P3De=@20<o?c`030<_;b`36
a/H0a/K60080`/;20P2m_Kd20;Vi^@80]KFe0P2a/K420:b/[080Z:RX0P2TY:@20:2PX080W9bL0P2H
V9P209BDU080T92@0P2<S8`00`28R8P0Q8B408B4Q0020820P080O7al0P1hN7P207AdM080L71`0P1/
K6`E0?ooo`004`3oool206ATI080GemO0P1KFe/205IFEP80DU9B0P1=CDd204Q8B080A4A400<0?clo
03Xj>P0j>SX00P0e=CD2030`<080:b/[0P0V9RH2020P80806QXJ0P0K6a/201lO7`8092@T0P0[:b/2
034a<@80>3Ph0P0o?cl204M7A`0304i>CP1FEUH0EUIF0080GEeM0P1RHV8206EUI@80J6QX0P1YJFT2
06QXJ080IfMW0P1VIVH206ATI080Hf=S0P1RHV82061PH080GemO0P1MGEd00`1LG5`0Fe]K05]KF`02
05YJFP80F5QH0P1GEeL405IFEP80E5AD101CDe<2059BDP@0DE5A1P1@D50304m?C`@0D51@101ADE42
059BDP80De=C0P1DE5@205EEE@80EUIF0P1HF5P205YJFP80G5aL0P1NGUh2065QH@0306=SH`1WIfL0
IfMW0080JVYZ0P1^KVh207=cL`80NWYj0P20P80208R8R080TI6A0P2KVi/20:NWY`80]KFe0P33`l<2
0=3@d080gmoO0P3UiND00`3[jn/0l?3`0?3`l0020?Ogm`80nOWi0P3kno/20?gmo@80n_[j0P3emOD2
0?3`l080jn_[0P3WinL20>;RhP80gMgM0P3Hf=P20=CDe080clo?00<0bl_;0<K6aP36a/H00P32`/82
0;fm_@80^KVi0P2e]KD20;6a/@80[:b/0P2XZ:P20:BTY080X:2P0P2LW9`209RHV080U9BD0P2@T902
08b<S00308R8R024Q8@0Q8B40080P8200P1lO7`207QhN080M7Ad0P1`L70206a/K1D0oooo000C0?oo
o`80I6AT0P1PH60205]KF`80EeMG0P1BDU8204i>CP80BDU90P15ADD00`10@400>c/k03/k>`0203Lg
=`80<S8b0P0];Bd202PX:0808b<S0P0O7al201XJ6P807alO0P0T92@202/[:`80<C4a0P0h>3P203lo
?`80AdM700<0CTi>05IFEP1FEUH00P1MGEd2065QH@80IFEU0P1WIfL406QXJ080IfMW0P1UIFD206AT
I080HV9R0P1QHF42061PH080GUiN0P1MGEd00`1LG5`0FUYJ05YJFP0205UIF@80F5QH0P1GEeL205IF
EP80EEEE0P1DE5@205=CD`@0DU9B101ADE46051@D00304m?C`1@D500D51@00@0D51@0P1ADE44059B
DP80De=C101EEED205MGE`80F5QH0P1KFe/205eMG@80GemO0P1QHF400`1TI6@0IfMW06MWI`0206][
J`80L71`0P1eMGD207]kN`80PX:20P29RHT209>CT`80WYjN0P2ZZZX20;Rh^080a/K60P3Cdm<20>7Q
h@80i^KV00<0k>c/0?;blP3bl_800P3inOT20?_kn`@0o?cl0P3gmoL20?;blP80k^k^0P3YjNT20>CT
i080h>3P0P3Kfm/20=KFeP80d];B0P3=cLd00`39bLT0aLG50<G5a@020<30`080_;bl0P2h^;P20;>c
/`80[jn_0P2[Zj/20:NWY`80Xj>S0P2OWil209^KV`80UiNG0P2CTi<208n?S`80Rh^;00<0QhN708>3
P`23Ph<00P20P80207alO080N7Qh0P1dM7@2071`L080K6a/5@3oool001<0oooo0P1TI6@2061PH080
Fe]K0P1GEeL2059BDP80CTi>0P19BDT204E5A@030410@00k>c/0>c/k0080=cLg0P0b<S8202d];@80
:2PX0P0S8b<201lO7`806QXJ0P0O7al202@T9080:b/[0P0a<C4203Ph>080?clo0P17AdL00`1>CTh0
EUIF05IFEP0205eMG@80HF5Q0P1UIFD206MWI`@0J6QX0P1WIfL206EUI@80I6AT0P1RHV82065QH@80
H61P0P1NGUh205eMG@0305aLG01JFUX0FUYJ0080FEUI0P1HF5P205MGE`80EUIF0P1EEED205ADE080
De=C101BDU84055AD@H0D51@00<0Cdm?051@D01@D500101@D502055AD@@0DU9B0P1CDe<405EEE@80
EeMG0P1HF5P205]KF`80GEeM0P1OGel2065QH@0306ATI01WIfL0IfMW0080Jf][0P1`L70207EeM@80
Ng]k0P22PX8208V9R@80Ti>C0P2NWYh20:ZZZP80^;Rh0P36a/H20=?Cd`80hN7Q0P3Vi^H00`3/k>`0
l_;b0?;blP020?Win@80no_k103lo?`20?Ogm`80l_;b0P3^k^h20>WYj@80i>CT0P3Ph>020=_Kf`80
e]KF0P3Bd]820<g=c@030<W9b@35aLD0aLG50080`<300P2l_;`20;Rh^080/k>c0P2_[jl20:^[Z`80
YjNW0P2SXj<209nOW`80Vi^K0P2GUiL209>CT`80Shn?0P2;Rh/00`27QhL0Ph>308>3P`020820P080
O7al0P1hN7P207AdM080L71`0P1/K6`E0?ooo`004`3oool206ATI080H61P0P1LG5`205MGE`80De=C
0P1?Cdl204Y:BP80ATI600<0@T9203dm?@0m?Cd00P0i>CT203@d=080;bl_0P0[:b/202HV9P808R8R
0P0M7Ad201lO7`8092@T0P0[:b/2034a<@80>3Ph0P0o?cl204I6AP0304i>CP1EEED0EEEE0080G5aL
0P1PH60206ATI080IVIV101WIfL206IVIP80I6AT0P1SHf<2065QH@80H61P0P1OGel205eMG@80G5aL
00<0Fe]K05YJFP1JFUX00P1HF5P205MGE`80EUIF0P1EEED205ADE0@0De=C0P1BDU86055AD@/0D51@
101ADE42059BDP80De=C0P1DE5@205EEE@80EUIF0P1GEeL205UIF@80Fe]K0P1NGUh2061PH080HV9R
00<0IFEU06QXJ01XJ6P00P1/K6`2075aL@80MgMg0P1mOGd208B4Q080S8b<0P2FUYH20:6QX@80[Zj^
0P2k^k/20<W9b@80e]KF0P3Shn<20>SXj0030>g]k@3dm?@0m?Cd0080n_[j103lo?`20?Win@80m?Cd
0P3`l?020>_[j`80inOW0P3Rh^820=gMg@80fMWI0P3De=@20=3@d080c<c<00<0alO70<?3``33`l<0
0P2o_kl20;Zj^P80][Jf0P2b/[820:j^[P80ZZZZ0P2VYZH20::RXP80WYjN0P2JVYX209JFUP80TY:B
0P2?Shl208^;R`0308N7Q`23Ph<0Ph>30080Ogmo0P1kNg/207QhN080M7Ad0P1`L70206a/K1D0oooo
000C0?ooo`80I6AT0P1PH60205aLG080EeMG0P1CDe<204m?C`80BTY:0P16ATH00`12@T80?Cdm03dm
?@0203Ti>@80=3@d0P0_;bl202/[:`809RHV0P0R8R8201dM7@807alO0P0T92@202/[:`80<C4a0P0h
>3P203lo?`80ATI600<0CTi>05EEE@1EEED00P1LG5`2061PH080I6AT0P1VIVH406MWI`80IVIV0P1T
I6@206=SH`80HF5Q0P1PH60205mOG`80GEeM0P1LG5`00`1KFe/0FUYJ05YJFP0205QHF080EeMG0P1F
EUH205EEE@80E5AD101CDe<2059BDPH0DE5A2`1@D504055AD@80DU9B0P1CDe<205ADE080EEEE0P1F
EUH205MGE`80FEUI0P1KFe/205iNGP80H61P0P1RHV800`1UIFD0J6QX06QXJ00206a/K080LG5a0P1g
MgL207emO@80Q8B40P2<S8`209JFUP80XJ6Q0P2^[Zh20;^k^`80bLW90P3Fe]H20>?Sh`80j>SX00<0
kNg]0?Cdm03dm?@00P3jn_X40?clo080nOWi0P3dm?@20?3`l080jn_[0P3WinL20>;RhP80gMgM0P3I
fMT20=CDe080d=3@0P3<c<`00`37alL0`l?30<?3``020;no_`80^[Zj0P2f][H20;:b/P80[Zj^0P2Z
ZZX20:JVYP80XZ:R0P2NWYh209ZJVP80UYJF0P2BTY8208n?S`80Rh^;00<0QhN708>3P`23Ph<00P1o
Ogl207]kN`80N7Qh0P1dM7@2071`L080K6a/5@3oool001<0oooo0P1TI6@2061PH080G5aL0P1HF5P2
05ADE080D51@0P1;Bd/204M7A`0304=3@`0o?cl0?clo0080>SXj0P0f=SH2038b<P80;Rh^0P0Y:BT2
02DU9@808B4Q0P0O7al202@T9080:b/[0P0a<C4203Lg=`80?Shn0P15ADD00`1=CDd0EEEE05EEE@02
05]KF`80H61P0P1SHf<206EUI@80IVIV101UIFD206=SH`80HV9R0P1QHF4205mOG`80GUiN0P1LG5`2
05]KF`0305YJFP1HF5P0F5QH0080EeMG0P1FEUH205EEE@80E5AD101CDe<2059BDPH0DE5A3@1@D502
055AD@@0DU9B0P1CDe<205ADE080EEEE0P1GEeL205QHF080FUYJ0P1LG5`205mOG`80HF5Q0P1SHf<0
0`1VIVH0JVYZ06YZJP0206i^KP80Lg=c0P1iNGT207moO`80QXJ60P2?Shl209ZJVP80YJFU0P2a/K42
0;jn_P80bl_;0P3Hf=P20>GUi@80j^[Z00<0kno_0?KfmP3fm_H00P3jn_X20?clo080no_k0P3fm_H2
0?;blP80kNg]0P3YjNT20>CTi080h>3P0P3Kfm/20=OGe`80d];B0P3>c/h20<[:bP030<G5a@31`L40
`L710080_Kfm0P2i^KT20;Fe]@80/K6a0P2][Jd20:VYZ@80YJFU0P2QXJ4209fMW@80VIVI0P2EUID2
09:BTP80SXj>0P2:RXX00`26QXH0Ph>308>3P`0207moO`80Ng]k0P1gMgL207AdM080L71`0P1/K6`E
0?ooo`004`3oool206ATI080H61P0P1LG5`205QHF080E5AD0P1@D50204];B`80AdM700<0@d=303lo
?`0o?cl00P0j>SX203Hf=P80<S8b0P0^;Rh202TY:@809BDU0P0Q8B4201lO7`8092@T0P0[:b/2034a
<@80=cLg0P0n?Sh204E5A@0304e=C@1EEED0EEEE0080Fe]K0P1PH60206=SH`80IFEU0P1VIVH406EU
I@80Hf=S0P1RHV82065QH@80GemO0P1NGUh205aLG080Fe]K00<0FUYJ05QHF01HF5P00P1GEeL205IF
EP80EEEE0P1DE5@405=CD`80DU9B1P1ADE4=051@D080DE5A101BDU8205=CD`80E5AD0P1EEED205MG
E`80F5QH0P1JFUX205aLG080GemO0P1QHF4206=SH`0306IVIP1ZJVX0JVYZ0080KVi^0P1cLg<207Ui
N@80Ogmo0P26QXH208n?S`80VYZJ0P2UYJD20;6a/@80_[jn0P3;bl/20=SHf080iNGU0P3Zj^X00`3_
knl0m_Kf0?KfmP020?[jnP80o?cl0P3kno/20?KfmP80l_;b0P3]kNd20>WYj@80i>CT0P3Ph>020=_K
f`80emOG0P3Bd]820<k>cP80b/[:00<0aLG50<71`@31`L400P2m_Kd20;Vi^@80]KFe0P2a/K420:f]
[@80ZJVY0P2UYJD20:6QX@80WIfM0P2IVIT209FEU@80TY:B0P2>SXh208Z:RP0308J6QP23Ph<0Ph>3
0080Ogmo0P1kNg/207MgM`80M7Ad0P1`L70206a/K1D0oooo000C0?ooo`80IFEU0P1QHF4205eMG@80
FEUI0P1EEED2055AD@80C4a<0P18B4P00`14A4@0@4100410@00203`l?080>3Ph0P0d=3@2030`<080
;2`/0P0Y:BT202DU9@808B4Q0P0U9BD202XZ:P80<30`0P0f=SH203dm?@80A4A400<0C4a<05=CD`1C
De<00P1JFUX205mOG`80HV9R0P1TI6@206EUI@80I6AT0P1SHf<2069RHP80HF5Q0P1PH60205iNGP80
GEeM0P1KFe/205YJFP0305UIF@1GEeL0EeMG0080EUIF0P1EEED205ADE0@0De=C0P1BDU84055AD@l0
D51@101ADE42059BDP80De=C0P1DE5@205EEE@80EUIF0P1HF5P205UIF@80Fe]K0P1MGEd2061PH080
HV9R0P1UIFD00`1XJ6P0Jf][06][J`02071`L080MGEe0P1kNg/208:2PP80RHV90P2BTY8209fMW@80
Z:RX0P2d];@20<71`@80cLg=0P3Jf]X20>OWi`80k>c/00<0l?3`0?KfmP3fm_H00P3jn_X20?_kn`80
nOWi0P3dm?@20>o_k`80jn_[0P3Vi^H20>;RhP80gMgM0P3IfMT20=GEe@80d=3@0P3<c<`20<S8b003
0<C4a030`<00`<300080^k^k0P2g]kL20;>c/`80/;2`0P2/[:`20:RXZ080Y:BT0P2PX:0209bLW080
V9RH0P2EUID2096AT@80SHf=0P29RHT00`26QXH0PX:208:2PP0207inOP80Ng]k0P1gMgL207=cL`80
L71`0P1/K6`E0?ooo`004`3oool206EUI@80HF5Q0P1MGEd205UIF@80EEEE0P1ADE4204a<C080B4Q8
00<0A4A40410@010@4000P0l?3`203Ph>080=3@d0P0`<30202`/;080:BTY0P0U9BD2024Q8@809BDU
0P0Z:RX2030`<080=SHf0P0m?Cd204A4A00304a<C01CDe<0De=C0080FUYJ0P1OGel2069RHP80I6AT
0P1UIFD206ATI080Hf=S0P1RHV82065QH@80H61P0P1NGUh205eMG@80Fe]K0P1JFUX00`1IFET0EeMG
05MGE`0205IFEP80EEEE0P1DE5@405=CD`80DU9B101ADE4?051@D0@0DE5A0P1BDU8205=CD`80E5AD
0P1EEED205IFEP80F5QH0P1IFET205]KF`80GEeM0P1PH602069RHP80IFEU00<0J6QX06][J`1[Jf/0
0P1`L70207EeM@80Ng]k0P22PX8208V9R@80TY:B0P2MWId20:RXZ080];Bd0P31`L420<g=c@80f][J
0P3WinL20>c/k0030?3`l03fm_H0m_Kf0080n_[j0P3kno/20?Win@80m?Cd0P3_knl20>_[j`80i^KV
0P3Rh^820=gMg@80fMWI0P3EeMD20=3@d080c<c<0P38b<P00`34a<@0`<300<30`0020;^k^`80]kNg
0P2c/k<20;2`/080[:b/0P2XZ:P20:BTY080X:2P0P2LW9`209RHV080UIFE0P2ATI4208f=S@80RHV9
00<0QXJ608:2PP22PX800P1nOWh207]kN`80MgMg0P1cLg<2071`L080K6a/5@3oool001<0oooo0P1U
IFD2065QH@80GEeM0P1IFET205EEE@80DE5A0P1>CTh204Y:BP0304I6AP12@T80@T920080?Shn0P0j
>SX203Lg=`80<c<c0P0_;bl202`/;080:BTY0P0V9RH202LW9`80:RXZ0P0_;bl203De=@80>c/k0P12
@T800`1:BTX0DU9B059BDP0205QHF080GEeM0P1QHF4606=SH`80HV9R0P1QHF42061PH080GUiN0P1M
GEd205aLG080FUYJ0P1IFET00`1HF5P0EUIF05IFEP0205EEE@80E5AD0P1CDe<4059BDP@0DE5A1P1@
D50404m?C`L0D51@0P1ADE42059BDP80De=C0P1DE5@205EEE@80EUIF0P1GEeL205UIF@80FUYJ0P1L
G5`205mOG`80HF5Q0P1SHf<206IVIP0306UYJ@1]KFd0KFe]0080LW9b0P1gMgL207emO@80QHF50P2=
SHd209JFUP80XJ6Q0P2/[:`20;Rh^080a<C40P3@d=020=gMg@80jNWY0P3/k>`00`3alO40moOg0?Og
m`040?[jnP80m_Kf0P3alO420>g]k@80j>SX0P3Ti>@20=oOg`80fm_K0P3GemL20=;BdP80c/k>0P3:
b/X20<K6aP030<;2`P2n_[h0_[jn0080^[Zj0P2f][H20;:b/P80[Zj^0P2ZZZX20:JVYP80Xj>S0P2O
Wil209^KV`80UiNG0P2DU9@2092@T080S8b<0P29RHT00`25QHD0PX:208:2PP0207inOP80NWYj0P1g
MgL207=cL`80L71`0P1/K6`E0?ooo`004`3oool206EUI@80HF5Q0P1MGEd205YJFP80EUIF0P1BDU82
04m?C`80Bd];00<0AdM704=3@`13@d<00P10@40203`l?080>CTi0P0e=CD2038b<P80;bl_0P0/;2`2
02/[:`80:BTY0P0Z:RX202`/;080<S8b0P0i>CT20410@00304Q8B01@D500D51@0080EUIF0P1LG5`2
05mOG`80HF5Q0P1RHV82065QH@@0H61P0P1NGUh205eMG@80G5aL0P1JFUX205UIF@80F5QH00<0EeMG
05EEE@1EEED00P1DE5@205=CD`@0DU9B0P1ADE44051@D0X0Cdm?1`1@D502055AD@80DU9B0P1CDe<2
05ADE080EEEE0P1FEUH205QHF080FUYJ0P1LG5`205iNGP80H61P0P1RHV8206EUI@80J6QX00<0Jf][
071`L01`L7000P1dM7@207YjNP80PH610P29RHT2096AT@80VYZJ0P2TY:@20:n_[`80^k^k0P37alL2
0=CDe080hN7Q0P3YjNT20>c/k0030?;blP3gmoL0moOg0080nOWi0P3hn?P20??cl`80kno_0P3Zj^X2
0>GUi@80hN7Q0P3MgMd20=WIf@80e=CD0P3@d=020<c<c080b<S80P34a<@00`30`<00_;bl0;bl_002
0;Rh^080];Bd0P2`/;020:f][@80ZJVY0P2UYJD20:6QX@80WYjN0P2JVYX209JFUP80Ti>C0P2?Shl2
08b<S080R8R800<0QHF50861P@21PH400P1nOWh207YjNP80MgMg0P1cLg<2071`L080K6a/5@3oool0
01<0oooo0P1UIFD2065QH@80GEeM0P1JFUX205IFEP80DU9B0P1?Cdl204];B`0304M7A`13@d<0@d=3
0080@4100P0l?3`203Ti>@80=CDe0P0b<S8202l_;`80;2`/0P0[:b/202TY:@80:RXZ0P0/;2`2038b
<P80>CTi0P10@4000`18B4P0D51@051@D00205IFEP80G5aL0P1OGel2065QH@80HV9R0P1QHF44061P
H080GUiN0P1MGEd205aLG080FUYJ0P1IFET205QHF00305MGE`1EEED0EEEE0080E5AD0P1CDe<4059B
DP80DE5A101@D50:04m?C`L0D51@0P1ADE42059BDP80De=C0P1DE5@205EEE@80EUIF0P1HF5P205YJ
FP80G5aL0P1NGUh2061PH080HV9R0P1UIFD206QXJ00306][J`1`L700L71`0080M7Ad0P1jNWX20861
P@80RHV90P2ATI4209ZJVP80Y:BT0P2_[jl20;^k^`80alO70P3De=@20>7Qh@80jNWY0P3/k>`00`3b
l_80moOg0?Ogm`020?Win@80n?Sh0P3clo<20>o_k`80j^[Z0P3UiND20>7Qh@80gMgM0P3IfMT20=CD
e080d=3@0P3<c<`20<S8b080a<C400<0`<300;bl_02l_;`00P2h^;P20;Bd]080/;2`0P2][Jd20:VY
Z@80YJFU0P2QXJ4209jNWP80VYZJ0P2FUYH209>CT`80Shn?0P2<S8`208R8R00308F5Q@21PH40PH61
0080OWin0P1jNWX207MgM`80Lg=c0P1`L70206a/K1D0oooo000C0?ooo`80IFEU0P1QHF4205iNGP80
FUYJ0P1GEeL205=CD`80D51@0P1<C4`00`19BDT0ADE504E5A@020492@P80?Shn0P0k>c/203Ph>080
=CDe0P0b<S8202l_;`80;Bd]0P0/;2`202XZ:P80:BTY0P0^;Rh203Hf=P80?Shn00<0ATI604i>CP1>
CTh00P1DE5@205YJFP80GEeM0P1OGel2061PH0@0GemO0P1NGUh205eMG@80G5aL0P1JFUX205UIF@80
F5QH0P1GEeL00`1EEED0E5AD05ADE00205=CD`80DU9B101ADE42051@D0H0Cdm?101>CTh604m?C`<0
D51@0P1ADE42059BDP80De=C0P1DE5@205EEE@80EUIF0P1GEeL205UIF@80Fe]K0P1MGEd205mOG`80
HF5Q0P1TI6@206MWI`80JVYZ00<0KFe]079bLP1bLW800P1gMgL207emO@80QHF50P2=SHd209FEU@80
WYjN0P2XZ:P20;>c/`80_kno0P3;bl/20=WIf@80hn?S0P3WinL20>c/k0030??cl`3gmoL0moOg0080
n?Sh0P3emOD20?3`l080k>c/0P3WinL20>?Sh`80g]kN0P3Jf]X20=KFeP80d];B0P3>c/h20<[:bP80
a/K60P32`/800`2n_[h0^[Zj0;Zj^P020;Jf]P80/k>c0P2_[jl20:^[Z`80Z:RX0P2TY:@20:2PX080
WIfM0P2IVIT209JFUP80TY:B0P2>SXh208^;R`80QhN700<0Q8B40861P@21PH400P1mOGd207YjNP80
MWIf0P1cLg<206m_K`80K6a/5@3oool001<0oooo0P1UIFD2065QH@80GUiN0P1JFUX205MGE`80De=C
0P1@D50204a<C00304U9B@15ADD0ADE50080@T920P0n?Sh203/k>`80>3Ph0P0e=CD2038b<P80;bl_
0P0];Bd202`/;080:RXZ0P0Y:BT202h^;P80=SHf0P0n?Sh00`16ATH0CTi>04i>CP0205ADE080FUYJ
0P1MGEd205mOG`80H61P101OGel205iNGP80GEeM0P1LG5`205YJFP80FEUI0P1HF5P205MGE`0305EE
E@1DE5@0E5AD0080De=C0P1BDU84055AD@80D51@1P1?Cdl404i>CPH0Cdm?0`1@D502055AD@80DU9B
0P1CDe<205ADE080EEEE0P1FEUH205MGE`80FEUI0P1KFe/205eMG@80GemO0P1QHF4206ATI080IfMW
0P1ZJVX00`1]KFd0LW9b079bLP0207MgM`80OGem0P25QHD208f=S@80UIFE0P2NWYh20:RXZ080/k>c
0P2o_kl20<_;b`80fMWI0P3Shn<20>OWi`80k>c/00<0lo?c0?Ogm`3gmoL00P3hn?P20?Gem@80l?3`
0P3/k>`20>OWi`80hn?S0P3Ng]h20=[JfP80e]KF0P3Bd]820<k>cP80b/[:0P36a/H20<;2`P030;jn
_P2j^[X0^[Zj0080][Jf0P2c/k<20:n_[`80Zj^[0P2XZ:P20:BTY080X:2P0P2MWId209VIV@80UYJF
0P2BTY8208j>SP80Rh^;0P27QhL00`24Q8@0PH610861P@0207emO@80NWYj0P1fMWH207=cL`80Kfm_
0P1/K6`E0?ooo`004`3oool206EUI@80HV9R0P1NGUh205]KF`80EeMG0P1DE5@2055AD@80CDe=00<0
BTY:04M7A`17AdL00P13@d<20410@080?Cdm0P0j>SX203Lg=`80=3@d0P0b<S82030`<080;Rh^0P0/
;2`202TY:@80:b/[0P0e=CD203dm?@0304A4A01<C4`0C4a<0080DU9B0P1GEeL205]KF`80GEeM101N
GUh205eMG@80G5aL0P1KFe/205YJFP80FEUI0P1HF5P205IFEP80EEEE00<0E5AD05=CD`1CDe<00P1B
DU82055AD@@0D51@0P1?Cdl<04i>CP@0Cdm?0P1@D503055AD@80DU9B0P1DE5@205EEE@80EUIF0P1G
EeL205QHF080FUYJ0P1LG5`205iNGP80H61P0P1SHf<206EUI@80JFUY0P1/K6`00`1`L700MGEe07Ee
M@0207]kN`80PH610P29RHT2096AT@80VYZJ0P2SXj<20:b/[080]kNg0P33`l<20=3@d080fm_K0P3R
h^820>OWi`80kNg]00<0lo?c0?KfmP3fm_H00P3fm_H20?;blP80kNg]0P3YjNT20>CTi080h>3P0P3L
g=`20=SHf080dm?C0P3?cll20<_;b`80b<S80P34a<@20<30`0030;bl_02h^;P0^;Rh0080]KFe0P2a
/K420:f][@80ZZZZ0P2VYZH20:>SX`80WinO0P2LW9`209RHV080U9BD0P2ATI4208j>SP80RXZ:0P27
QhL00`23Ph<0P8200820P00207emO@80NGUi0P1fMWH207=cL`80Kfm_0P1/K6`E0?ooo`004`3oool2
06EUI@80HV9R0P1NGUh205]KF`80EeMG0P1DE5@2055AD@80CDe=00<0BTY:04M7A`17AdL00P13@d<2
0410@080?Cdm0P0j>SX203Lg=`80=3@d0P0b<S82030`<080;Rh^0P0/;2`202TY:@80:b/[0P0e=CD2
03dm?@0304A4A01<C4`0C4a<0080DU9B0P1GEeL205]KF`80GEeM101NGUh205eMG@80G5aL0P1KFe/2
05YJFP80FEUI0P1HF5P205IFEP80EEEE00<0E5AD05=CD`1CDe<00P1BDU82055AD@@0D51@0P1?Cdl<
04i>CP@0Cdm?0P1@D503055AD@80DU9B0P1DE5@205EEE@80EUIF0P1GEeL205QHF080FUYJ0P1LG5`2
05iNGP80H61P0P1SHf<206EUI@80JFUY0P1/K6`00`1`L700MGEe07EeM@0207]kN`80PH610P29RHT2
096AT@80VYZJ0P2SXj<20:b/[080]kNg0P33`l<20=3@d080fm_K0P3Rh^820>OWi`80kNg]00<0lo?c
0?KfmP3fm_H00P3fm_H20?;blP80kNg]0P3YjNT20>CTi080h>3P0P3Lg=`20=SHf080dm?C0P3?cll2
0<_;b`80b<S80P34a<@20<30`0030;bl_02h^;P0^;Rh0080]KFe0P2a/K420:f][@80ZZZZ0P2VYZH2
0:>SX`80WinO0P2LW9`209RHV080U9BD0P2ATI4208j>SP80RXZ:0P27QhL00`23Ph<0P8200820P002
07emO@80NGUi0P1fMWH207=cL`80Kfm_0P1/K6`E0?ooo`004`3oool206EUI@80HV9R0P1OGel205]K
F`80F5QH0P1EEED2059BDP80CTi>00<0Bd];04Q8B018B4P00P15ADD20492@P80?clo0P0l?3`203Ti
>@80=cLg0P0d=3@2038b<P80;bl_0P0];Bd202TY:@80:RXZ0P0c<c<203/k>`030492@P1:BTX0BTY:
0080D51@0P1EEED205UIF@80Fe]K1P1LG5`205]KF`80FUYJ0P1IFET205QHF080EeMG0P1EEED205AD
E00305=CD`1BDU80DU9B0080DE5A0P1@D50204m?C`@0CTi>2P1=CDd204i>CP80Cdm?101@D5000`1A
DE40DU9B059BDP0205=CD`80E5AD0P1EEED205MGE`80F5QH0P1JFUX205aLG080GUiN0P1PH602069R
HP80IFEU0P1XJ6P206a/K080Kfm_00<0Lg=c07QhN01hN7P00P1nOWh208F5Q@80SHf=0P2EUID209jN
WP80YjNW0P2`/;020;bl_080b<S80P3Bd]820=cLg080h^;R0P3Xj>P20>g]k@030?;blP3clo<0lo?c
0080lo?c0P3^k^h20>[ZjP80iNGU0P3QhN420=gMg@80fMWI0P3EeMD20=7Ad@80cLg=0P39bLT20<G5
a@80`/;20P2n_[h00`2j^[X0][Jf0;Jf]P020;>c/`80[jn_0P2/[:`20:RXZ080YJFU0P2QXJ4209jN
WP80VYZJ0P2GUiL209>CT`80T92@0P2=SHd208V9R@80QXJ600<0Ph>307moO`1oOgl00P1lO7`207Ui
N@80MWIf0P1bLW8206m_K`80K6a/5@3oool001<0oooo0P1UIFD2069RHP80GemO0P1KFe/205QHF080
EEEE0P1BDU8204i>CP0304];B`18B4P0B4Q80080ADE50P12@T8203lo?`80?3`l0P0i>CT203Lg=`80
=3@d0P0b<S8202l_;`80;Bd]0P0Y:BT202XZ:P80<c<c0P0k>c/00`12@T80BTY:04Y:BP02051@D080
EEEE0P1IFET205]KF`H0G5aL0P1KFe/205YJFP80FEUI0P1HF5P205MGE`80EEEE0P1DE5@00`1CDe<0
DU9B059BDP02055AD@80D51@0P1?Cdl404i>CPX0CDe=0P1>CTh204m?C`@0D51@00<0DE5A059BDP1B
DU800P1CDe<205ADE080EEEE0P1GEeL205QHF080FUYJ0P1LG5`205iNGP80H61P0P1RHV8206EUI@80
J6QX0P1/K6`206m_K`0307=cL`1hN7P0N7Qh0080OWin0P25QHD208f=S@80UIFE0P2NWYh20:NWY`80
/;2`0P2l_;`20<S8b080d];B0P3Lg=`20>;RhP80j>SX0P3]kNd00`3bl_80lo?c0??cl`020??cl`80
k^k^0P3Zj^X20>GUi@80hN7Q0P3MgMd20=WIf@80eMGE0P3AdM420<g=c@80bLW90P35aLD20<;2`P80
_[jn00<0^[Zj0;Jf]P2f][H00P2c/k<20:n_[`80[:b/0P2XZ:P20:FUY@80XJ6Q0P2NWYh209ZJVP80
UiNG0P2CTi<2092@T080SHf=0P29RHT208J6QP0308>3P`1oOgl0Ogmo0080O7al0P1iNGT207IfMP80
LW9b0P1_Kfl206a/K1D0oooo000C0?ooo`80IFEU0P1RHV8205mOG`80G5aL0P1IFET205IFEP80De=C
0P1@D5000`1<C4`0BDU904U9B@0204M7A`80A4A40P11@D4203hn?P80>c/k0P0i>CT203Hf=P80=3@d
0P0a<C4202h^;P80:RXZ0P0/;2`2030`<080>CTi00<0@41004M7A`17AdL00P1=CDd205=CD`80EUIF
0P1IFET605YJFP80FEUI101HF5P205IFEP80EEEE0P1CDe<2059BDP03055AD@1@D500D51@0080D51@
0P1?Cdl204i>CP@0CDe=201<C4`204e=C@80CTi>0P1?Cdl4051@D003055AD@1BDU80DU9B0080De=C
0P1EEED205IFEP80F5QH0P1IFET205]KF`80GEeM0P1OGel2069RHP80I6AT0P1WIfL206YZJP80KVi^
0P1bLW800`1gMgL0OGem07emO@0208:2PP80RHV90P2ATI4209ZJVP80XZ:R0P2[Zj/20;Fe]@80_kno
0P3<c<`20=?Cd`80g=cL0P3Rh^820>WYj@80k>c/00<0l?3`0?7al@3alO400P3_knl20>[ZjP80i^KV
0P3Rh^820=kNgP80f][J0P3Fe]H20=;BdP80c/k>0P3:b/X20<O7a`80`l?30P2o_kl20;bl_0030;Rh
^02e]KD0]KFe0080/K6a0P2^[Zh20:ZZZP80YjNW0P2SXj<20:2PX080WIfM0P2IVIT209JFUP80TY:B
0P2?Shl208b<S080RHV90P25QHD00`22PX80Ogmo07moO`0207alO080NGUi0P1eMGD2079bLP80Kfm_
0P1/K6`E0?ooo`004`3oool206EUI@80HV9R0P1OGel205aLG080FEUI0P1FEUH205=CD`80D51@00<0
C4a<04U9B@19BDT00P17AdL204A4A080@D510P0n?Sh203/k>`80>CTi0P0f=SH203@d=080<C4a0P0^
;Rh202XZ:P80;2`/0P0`<30203Ti>@030410@017AdL0AdM70080CDe=0P1CDe<205IFEP80FEUI1P1J
FUX205UIF@@0F5QH0P1FEUH205EEE@80De=C0P1BDU800`1ADE40D51@051@D002051@D080Cdm?0P1>
CTh404e=C@P0C4a<0P1=CDd204i>CP80Cdm?101@D5000`1ADE40DU9B059BDP0205=CD`80EEEE0P1F
EUH205QHF080FEUI0P1KFe/205eMG@80GemO0P1RHV8206ATI080IfMW0P1ZJVX206i^KP80LW9b00<0
MgMg07emO@1mOGd00P22PX8208V9R@80TI6A0P2JVYX20::RXP80Zj^[0P2e]KD20;no_`80c<c<0P3C
dm<20=cLg080h^;R0P3YjNT20>c/k0030?3`l03alO40lO7a0080kno_0P3Zj^X20>KViP80h^;R0P3N
g]h20=[JfP80e]KF0P3Bd]820<k>cP80b/[:0P37alL20<?3``80_kno0P2l_;`00`2h^;P0]KFe0;Fe
]@020;6a/@80[Zj^0P2ZZZX20:NWY`80Xj>S0P2PX:0209fMW@80VIVI0P2FUYH209:BTP80Shn?0P2<
S8`208V9R@80QHF500<0PX:207moO`1oOgl00P1lO7`207UiN@80MGEe0P1bLW8206m_K`80K6a/5@3o
ool001<0oooo0P1VIVH206=SH`80H61P0P1LG5`205UIF@80EeMG0P1DE5@2055AD@0304i>CP1;Bd/0
Bd];0080B4Q80P15ADD204=3@`80@4100P0m?Cd203/k>`80>3Ph0P0f=SH203<c<`80<C4a0P0];Bd4
02h^;P80=cLg00<0?clo04E5A@15ADD00P1;Bd/2051@D080E5AD0P1GEeL805QHF080EeMG0P1FEUH2
05EEE@80De=C0P1BDU82055AD@03051@D01?Cdl0Cdm?00@0CTi>0P1=CDd404a<C0H0Bd];0P1<C4`2
04e=C@80CTi>0P1?Cdl4051@D003055AD@1CDe<0De=C0080E5AD0P1EEED205MGE`80FEUI0P1KFe/2
05eMG@80GemO0P1QHF4206ATI080IfMW0P1ZJVX206i^KP80LW9b0P1fMWH00`1kNg/0PH610861P@02
08N7Q`80SXj>0P2FUYH209jNWP80YjNW0P2`/;020;Vi^@80a<C40P3>c/h20=CDe080g=cL0P3Shn<2
0>WYj@80jn_[0`3^k^h20>[ZjP80inOW0P3Rh^820=oOg`80fm_K0P3GemL20=?Cd`80clo?0P3;bl/2
0<S8b080a<C40P31`L420;fm_@80^[Zj00<0][Jf0;>c/`2c/k<00P2_[jl20:b/[080Z:RX0P2UYJD2
0::RXP80WYjN0P2KVi/209RHV080U9BD0P2ATI4208j>SP80Rh^;0P28R8P208F5Q@030861P@1nOWh0
OWin0080Ng]k0P1hN7P207EeM@80LW9b0P1_Kfl206a/K1D0oooo000C0?ooo`80IVIV0P1SHf<2061P
H080G5aL0P1IFET205MGE`80E5AD0P1ADE400`1>CTh0Bd];04];B`0204Q8B080ADE50P13@d<20410
@080?Cdm0P0k>c/203Ph>080=SHf0P0c<c<2034a<@80;Bd]100^;Rh203Lg=`0303lo?`15ADD0ADE5
0080Bd];0P1@D50205ADE080EeMG201HF5P205MGE`80EUIF0P1EEED205=CD`80DU9B0P1ADE400`1@
D500Cdm?04m?C`0404i>CP80CDe=101<C4`604];B`80C4a<0P1=CDd204i>CP80Cdm?101@D5000`1A
DE40De=C05=CD`0205ADE080EEEE0P1GEeL205UIF@80Fe]K0P1MGEd205mOG`80HF5Q0P1TI6@206MW
I`80JVYZ0P1^KVh2079bLP80MWIf00<0Ng]k0861P@21PH400P27QhL208j>SP80UYJF0P2NWYh20:NW
Y`80/;2`0P2i^KT20<C4a080c/k>0P3De=@20=cLg080hn?S0P3YjNT20>_[j`<0k^k^0P3Zj^X20>OW
i`80h^;R0P3Ogml20=_Kf`80emOG0P3Cdm<20<o?c`80bl_;0P38b<P20<C4a080`L710P2m_Kd20;Zj
^P030;Jf]P2c/k<0/k>c0080[jn_0P2/[:`20:RXZ080YJFU0P2RXZ8209jNWP80Vi^K0P2HV9P209BD
U080TI6A0P2>SXh208^;R`80R8R80P25QHD00`21PH40OWin07inOP0207]kN`80N7Qh0P1eMGD2079b
LP80Kfm_0P1/K6`E0?ooo`004`3oool206IVIP80Hf=S0P1PH60205eMG@80FUYJ0P1GEeL205ADE080
DU9B00<0Cdm?04a<C01<C4`00P19BDT204M7A`80A4A40P12@T8203lo?`80?Cdm0P0j>SX203Ph>080
=SHf0P0c<c<2030`<080;Rh^0P0_;bl203Hf=P0303dm?@13@d<0@d=30080B4Q80P1=CDd2055AD@80
E5AD0P1FEUH205MGE`@0EUIF101EEED205=CD`80DU9B0P1ADE4204m?C`0304i>CP1=CDd0CDe=0080
CDe=101<C4`<04];B`80C4a<0P1>CTh204m?C`80D51@0P1ADE400`1BDU80E5AD05ADE00205EEE@80
EUIF0P1HF5P205YJFP80G5aL0P1OGel2065QH@80I6AT0P1WIfL206YZJP80KFe]0P1aLG4207IfMP80
NWYj00<0Ogmo08F5Q@25QHD00P2;Rh/209:BTP80Vi^K0P2SXj<20:^[Z`80];Bd0P2m_Kd20<O7a`80
clo?0P3EeMD20=gMg@80h^;R0P3WinL20>[ZjP030>_[j`3Zj^X0j^[Z0080i^KV0P3Shn<20=oOg`80
fm_K0P3GemL20=CDe080d=3@0P3<c<`20<W9b@80aLG50P32`/820;jn_P80^k^k0P2g]kL00`2d];@0
/K6a0;6a/@020:f][@80ZZZZ0P2WYjL20:BTY080X:2P0P2MWId209ZJVP80UiNG0P2CTi<2092@T080
SHf=0P2:RXX208N7Q`80Q8B400<0PH6107inOP1nOWh00P1kNg/207QhN080MGEe0P1bLW8206m_K`80
K6a/5@3oool001<0oooo0P1VIVH206=SH`80H61P0P1MGEd205YJFP80EeMG0P1DE5@2059BDP0304m?
C`1<C4`0C4a<0080BDU90P17AdL204A4A080@T920P0o?cl203dm?@80>SXj0P0h>3P203Hf=P80<c<c
0P0`<30202h^;P80;bl_0P0f=SH00`0m?Cd0@d=304=3@`0204Q8B080CDe=0P1ADE4205ADE080EUIF
0P1GEeL405IFEP@0EEEE0P1CDe<2059BDP80DE5A0P1?Cdl00`1>CTh0CDe=04e=C@0204e=C@@0C4a<
301;Bd/204a<C080CTi>0P1?Cdl2051@D080DE5A00<0DU9B05ADE01DE5@00P1EEED205IFEP80F5QH
0P1JFUX205aLG080GemO0P1QHF4206ATI080IfMW0P1ZJVX206e]K@80LG5a0P1fMWH207YjNP0307mo
O`25QHD0QHF50080Rh^;0P2BTY8209^KV`80Xj>S0P2[Zj/20;Bd]080_Kfm0P37alL20<o?c`80eMGE
0P3MgMd20>;RhP80inOW0P3Zj^X00`3[jn/0j^[Z0>[ZjP020>KViP80hn?S0P3Ogml20=_Kf`80emOG
0P3De=@20=3@d080c<c<0P39bLT20<G5a@80`/;20P2n_[h20;^k^`80]kNg00<0];Bd0;6a/@2a/K40
0P2][Jd20:ZZZP80YjNW0P2TY:@20:2PX080WIfM0P2JVYX209NGU`80Ti>C0P2@T90208f=S@80RXZ:
0P27QhL208B4Q0030861P@1nOWh0OWin0080Ng]k0P1hN7P207EeM@80LW9b0P1_Kfl206a/K1D0oooo
000C0?ooo`80IVIV0P1SHf<2061PH080GUiN0P1KFe/205QHF080EEEE0P1CDe<00`1@D500CDe=04e=
C@0204];B`80B4Q80P16ATH204A4A080@D510P0o?cl203dm?@80>SXj0P0h>3P203Hf=P80=3@d100b
<S8203De=@0303/k>`10@400@4100080ADE50P1;Bd/204i>CP80DE5A0P1DE5@605EEE@80E5AD0P1C
De<2059BDP80D51@0P1?Cdl204i>CP0304e=C@1<C4`0C4a<0080C4a<1P1;Bd/204Y:BPP0Bd];0P1=
CDd204i>CP80D51@0P1ADE42059BDP0305=CD`1EEED0EEEE0080EUIF0P1HF5P205YJFP80G5aL0P1O
Gel2065QH@80I6AT0P1WIfL206YZJP80KFe]0P1aLG4207EeM@80NGUi0P1nOWh00`24Q8@0RXZ:08Z:
RP02092@T080UiNG0P2OWil20:NWY`80[Zj^0P2g]kL20<30`080bLW90P3@d=020=KFeP80gMgM0P3R
h^820>KViP80j>SX00<0jNWY0>KViP3Vi^H00P3Rh^820=oOg`80fm_K0P3Hf=P20=CDe080d=3@0P3=
cLd20<W9b@80a/K60P33`l<20;no_`80_;bl0P2h^;P20;Fe]@030;:b/P2_[jl0[jn_0080Zj^[0P2X
Z:P20:FUY@80XZ:R0P2OWil209bLW080VIVI0P2FUYH209:BTP80Shn?0P2<S8`208V9R@80QXJ60P23
Ph<00`20P800OGem07emO@0207YjNP80MgMg0P1dM7@2075aL@80KVi^0P1/K6`E0?ooo`004`3oool2
06IVIP80Hf=S0P1PH60205iNGP80Fe]K0P1HF5P205EEE@80De=C00<0D51@04e=C@1=CDd00P1;Bd/2
04Q8B080ATI60P14A4@20451@@80?clo0P0m?Cd203Xj>P80>3Ph0P0f=SH203@d=0@0<S8b0P0e=CD0
0`0k>c/0@4100410@00204E5A@80Bd];0P1>CTh2055AD@80E5AD1P1EEED205ADE080De=C0P1BDU82
051@D080Cdm?0P1>CTh00`1=CDd0C4a<04a<C00204a<C0H0Bd];0P1:BTX804];B`80CDe=0P1>CTh2
051@D080DE5A0P1BDU800`1CDe<0EEEE05EEE@0205IFEP80F5QH0P1JFUX205aLG080GemO0P1QHF42
06ATI080IfMW0P1ZJVX206e]K@80LG5a0P1eMGD207UiN@80OWin00<0Q8B408Z:RP2:RXX00P2@T902
09NGU`80WinO0P2WYjL20:j^[P80]kNg0P30`<020<W9b@80d=3@0P3Fe]H20=gMg@80h^;R0P3Vi^H2
0>SXj0030>WYj@3Vi^H0i^KV0080h^;R0P3Ogml20=_Kf`80f=SH0P3De=@20=3@d080cLg=0P39bLT2
0<K6aP80`l?30P2o_kl20;bl_080^;Rh0P2e]KD00`2b/[80[jn_0:n_[`020:^[Z`80Z:RX0P2UYJD2
0::RXP80WinO0P2LW9`209VIV@80UYJF0P2BTY8208n?S`80S8b<0P29RHT208J6QP80Ph>300<0P820
07emO@1mOGd00P1jNWX207MgM`80M7Ad0P1aLG4206i^KP80K6a/5@3oool001<0oooo0P1VIVH206=S
H`80HF5Q0P1NGUh205]KF`80FEUI0P1FEUH205ADE003055AD@1?Cdl0Cdm?0080C4a<0P1:BTX204Q8
B080ADE50P13@d<20451@@80?clo0P0l?3`203Xj>P80>3Ph0P0g=cL203De=@80=3@d0P0f=SH00`0h
>3P0?Cdm03dm?@020492@P80B4Q80P1<C4`204i>CP80DU9B0P1CDe<405ADE080De=C0P1ADE42051@
D080CTi>0P1=CDd204a<C0/0Bd];0P1:BTX604];B`80C4a<0P1=CDd204m?C`80DE5A0P1BDU8205=C
D`0305EEE@1GEeL0EeMG0080F5QH0P1JFUX205eMG@80GemO0P1RHV8206ATI080IfMW0P1ZJVX206e]
K@80LG5a0P1dM7@207UiN@80OWin0P23Ph<00`28R8P0SXj>08j>SP0209BDU080Vi^K0P2SXj<20:ZZ
ZP80/[:b0P2j^[X20<?3``80bl_;0P3AdM420=OGe`80gMgM0P3QhN420>?Sh`80i^KV00<0iNGU0>;R
hP3Rh^800P3Ng]h20=_Kf`80emOG0P3De=@20=7Ad@80cLg=0P3:b/X20<K6aP80`l?30P30`<020;fm
_@80^KVi0P2f][H20;>c/`030;2`/02][Jd0[Jf]0080ZJVY0P2VYZH20:>SX`80X:2P0P2MWId209ZJ
VP80UiNG0P2DU9@2096AT@80SXj>0P2;Rh/208R8R080QHF50P22PX800`20P800OGem07emO@0207Yj
NP80MgMg0P1dM7@2075aL@80KVi^0P1[Jf/E0?ooo`004`3oool206IVIP80Hf=S0P1QHF4205iNGP80
Fe]K0P1IFET205IFEP80E5AD00<0DE5A04m?C`1?Cdl00P1<C4`204Y:BP80B4Q80P15ADD204=3@`80
@D510P0o?cl203`l?080>SXj0P0h>3P203Lg=`80=CDe0P0d=3@203Hf=P0303Ph>00m?Cd0?Cdm0080
@T920P18B4P204a<C080CTi>0P1BDU8205=CD`@0E5AD0P1CDe<2055AD@80D51@0P1>CTh204e=C@80
C4a<2`1;Bd/204Y:BPH0Bd];0P1<C4`204e=C@80Cdm?0P1ADE42059BDP80De=C00<0EEEE05MGE`1G
EeL00P1HF5P205YJFP80GEeM0P1OGel2069RHP80I6AT0P1WIfL206YZJP80KFe]0P1aLG4207AdM080
NGUi0P1nOWh208>3P`0308R8R02>SXh0SXj>0080U9BD0P2KVi/20:>SX`80ZZZZ0P2b/[820;Zj^P80
`l?30P3;bl/20=7Ad@80emOG0P3MgMd20>7Qh@80hn?S0P3Vi^H00`3UiND0h^;R0>;RhP020=kNgP80
fm_K0P3GemL20=CDe080dM7A0P3=cLd20<[:bP80a/K60P33`l<20<30`080_Kfm0P2i^KT20;Jf]P80
/k>c00<0/;2`0:f][@2][Jd00P2YZJT20:JVYP80Xj>S0P2PX:0209fMW@80VYZJ0P2GUiL209BDU080
TI6A0P2>SXh208^;R`80R8R80P25QHD208:2PP030820P01mOGd0OGem0080NWYj0P1gMgL207AdM080
LG5a0P1^KVh206][JaD0oooo000C0?ooo`80IVIV0P1TI6@2065QH@80GemO0P1LG5`205YJFP80EeMG
0P1EEED00`1BDU80D51@051@D00204i>CP80Bd];0P19BDT204M7A`80ADE50P13@d<20451@@80?clo
0P0m?Cd203/k>`80>CTi0P0h>3P403Lg=`0303Hf=P0j>SX0>SXj0080?clo0P15ADD204U9B@80CDe=
0P1@D502055AD@80DU9B101ADE4204m?C`80CTi>0P1<C4`404];B`D0BTY:301;Bd/204a<C080CDe=
0P1?Cdl2051@D080DU9B0P1CDe<205IFEP0305MGE`1HF5P0F5QH0080FUYJ0P1LG5`205mOG`80HV9R
0P1TI6@206IVIP80JVYZ0P1]KFd2075aL@80M7Ad0P1gMgL207emO@80PX:20P27QhL00`2<S8`0Ti>C
09>CT`0209VIV@80WinO0P2VYZH20:j^[P80][Jf0P2m_Kd20<G5a@80c<c<0P3Bd]820=OGe`80fm_K
0P3Ng]h20>;RhP80i>CT00<0hN7Q0=gMg@3MgMd00P3Jf]X20=OGe`80e=CD0P3@d=020<g=c@80b/[:
0P37alL20<C4a080`<300P2m_Kd20;Zj^P80]kNg0P2d];@20;6a/@030:j^[P2ZZZX0ZZZZ0080YjNW
0P2TY:@20:6QX@80WYjN0P2LW9`209VIV@80UYJF0P2CTi<2092@T080SHf=0P2:RXX208N7Q`80Q8B4
0P22PX800`1oOgl0O7al07alO00207UiN@80MWIf0P1dM7@2075aL@80KVi^0P1[Jf/E0?ooo`004`3o
ool206IVIP80I6AT0P1QHF4205mOG`80G5aL0P1JFUX205MGE`80EEEE00<0DU9B051@D01@D5000P1>
CTh204];B`80BDU90P17AdL204E5A@80@d=30P11@D4203lo?`80?Cdm0P0k>c/203Ti>@80>3Ph100g
=cL00`0f=SH0>SXj03Xj>P0203lo?`80ADE50P19BDT204e=C@80D51@0P1ADE42059BDP@0DE5A0P1?
Cdl204i>CP80C4a<101;Bd/504Y:BP`0Bd];0P1<C4`204e=C@80Cdm?0P1@D502059BDP80De=C0P1F
EUH00`1GEeL0F5QH05QHF00205YJFP80G5aL0P1OGel2069RHP80I6AT0P1VIVH206YZJP80KFe]0P1a
LG4207AdM080MgMg0P1mOGd208:2PP80QhN700<0S8b<09>CT`2CTi<00P2IVIT209nOW`80YZJV0P2^
[Zh20;Jf]P80_Kfm0P35aLD20<c<c080d];B0P3GemL20=_Kf`80g]kN0P3Rh^820>CTi0030>7Qh@3M
gMd0gMgM0080f][J0P3GemL20=CDe080d=3@0P3=cLd20<[:bP80alO70P34a<@20<30`080_Kfm0P2j
^[X20;Ng]`80];Bd0P2a/K400`2^[Zh0ZZZZ0:ZZZP020:NWY`80Y:BT0P2QXJ4209jNWP80W9bL0P2I
VIT209JFUP80Ti>C0P2@T90208f=S@80RXZ:0P27QhL208B4Q080PX:200<0Ogmo07alO01lO7`00P1i
NGT207IfMP80M7Ad0P1aLG4206i^KP80Jf][5@3oool001<0oooo0P1VIVH206ATI080HF5Q0P1OGel2
05eMG@80FUYJ0P1HF5P205IFEP0305=CD`1ADE40DE5A0080Cdm?0P1=CDd204];B`80B4Q80P16ATH2
04A4A080@d=30P11@D4203lo?`80?Cdm0P0l?3`203Xj>P80>CTi0P0h>3P00`0g=cL0>3Ph03Ph>002
03dm?@80@D510P16ATH204Y:BP80CDe=0P1>CTh4051@D080Cdm?0P1>CTh204a<C0@0Bd];1`1:BTX6
04];B`H0C4a<0P1=CDd204i>CP80D51@0P1BDU8205=CD`80EEEE0P1GEeL00`1IFET0FUYJ05YJFP02
05eMG@80GemO0P1QHF4206ATI080IFEU0P1YJFT206a/K080L71`0P1dM7@207MgM`80Ng]k0P21PH42
08J6QP80Rh^;00<0TI6A09NGU`2GUiL00P2MWId20:>SX`80ZZZZ0P2b/[820;Vi^@80`<300P37alL2
0<g=c@80d];B0P3EeMD20=WIf@80gMgM0P3QhN420>3Ph0030=cLg03IfMT0fMWI0080e]KF0P3Cdm<2
0=3@d080cLg=0P3:b/X20<O7a`80a<C40P31`L420;fm_@80^[Zj0P2g]kL20;Bd]080/K6a0P2^[Zh0
0`2[Zj/0Z:RX0:RXZ0020:FUY@80Xj>S0P2PX:0209fMW@80VYZJ0P2GUiL209BDU080TI6A0P2?Shl2
08b<S080RHV90P26QXH208B4Q080PH6100<0OWin07]kN`1kNg/00P1iNGT207IfMP80Lg=c0P1aLG42
06i^KP80Jf][5@3oool001<0oooo0P1VIVH206ATI080HF5Q0P1OGel205eMG@80FUYJ0P1HF5P205IF
EP0305=CD`1ADE40DE5A0080Cdm?0P1=CDd204];B`80B4Q80P16ATH204A4A080@d=30P11@D4203lo
?`80?Cdm0P0l?3`203Xj>P80>CTi0P0h>3P00`0g=cL0>3Ph03Ph>00203dm?@80@D510P16ATH204Y:
BP80CDe=0P1>CTh4051@D080Cdm?0P1>CTh204a<C0@0Bd];1`1:BTX604];B`H0C4a<0P1=CDd204i>
CP80D51@0P1BDU8205=CD`80EEEE0P1GEeL00`1IFET0FUYJ05YJFP0205eMG@80GemO0P1QHF4206AT
I080IFEU0P1YJFT206a/K080L71`0P1dM7@207MgM`80Ng]k0P21PH4208J6QP80Rh^;00<0TI6A09NG
U`2GUiL00P2MWId20:>SX`80ZZZZ0P2b/[820;Vi^@80`<300P37alL20<g=c@80d];B0P3EeMD20=WI
f@80gMgM0P3QhN420>3Ph0030=cLg03IfMT0fMWI0080e]KF0P3Cdm<20=3@d080cLg=0P3:b/X20<O7
a`80a<C40P31`L420;fm_@80^[Zj0P2g]kL20;Bd]080/K6a0P2^[Zh00`2[Zj/0Z:RX0:RXZ0020:FU
Y@80Xj>S0P2PX:0209fMW@80VYZJ0P2GUiL209BDU080TI6A0P2?Shl208b<S080RHV90P26QXH208B4
Q080PH6100<0OWin07]kN`1kNg/00P1iNGT207IfMP80Lg=c0P1aLG4206i^KP80Jf][5@3oool001<0
oooo0P1VIVH206ATI080HV9R0P1PH60205eMG@80Fe]K0P1IFET205MGE`0305ADE01BDU80DU9B0080
D51@0P1>CTh204a<C080BTY:0P18B4P204I6AP80A4A40P13@d<20451@@80?clo0P0n?Sh203dm?@80
?3`l0P0j>SX00`0i>CT0>3Ph03Ph>00203Xj>P80?Shn0P13@d<204Q8B080BTY:0P1=CDd404i>CP80
CDe=0P1<C4`604Y:BP80BDU91@1:BTX404];B`80C4a<101=CDd204i>CP80Cdm?0P1@D502059BDP80
E5AD0P1EEED205MGE`80FUYJ00<0Fe]K05eMG@1MGEd00P1OGel2065QH@80Hf=S0P1UIFD206QXJ080
K6a/0P1^KVh207=cL`80MgMg0P1kNg/20820P080QHF50P2:RXX2092@T00309JFUP2LW9`0W9bL0080
XJ6Q0P2XZ:P20:n_[`80]KFe0P2m_Kd20<;2`P80b<S80P3<c<`20<o?c`80e=CD0P3Hf=P20=cLg080
gmoO0P3Kfm/00`3Hf=P0eMGE0=GEe@020=;BdP80clo?0P3<c<`20<W9b@80a/K60P34a<@20<71`@80
_[jn0P2k^k/20;Rh^080]KFe0P2b/[820:n_[`80[:b/00<0ZJVY0:JVYP2VYZH00P2SXj<20:6QX@80
WYjN0P2KVi/209RHV080UYJF0P2CTi<2092@T080SHf=0P2;Rh/208R8R080QHF50P23Ph<20820P003
07emO@1kNg/0Ng]k0080N7Qh0P1fMWH207=cL`80L71`0P1^KVh206][JaD0oooo000C0?ooo`80IVIV
0P1TI6@2069RHP80H61P0P1MGEd205]KF`80FEUI0P1GEeL00`1DE5@0DU9B059BDP02051@D080CTi>
0P1<C4`204Y:BP80B4Q80P16ATH204A4A080@d=30P11@D4203lo?`80?Shn0P0m?Cd203`l?080>SXj
00<0>CTi03Ph>00h>3P00P0j>SX203hn?P80@d=30P18B4P204Y:BP80CDe=101>CTh204e=C@80C4a<
1P1:BTX204U9B@D0BTY:101;Bd/204a<C0@0CDe=0P1>CTh204m?C`80D51@0P1BDU8205ADE080EEEE
0P1GEeL205YJFP0305]KF`1MGEd0GEeM0080GemO0P1QHF4206=SH`80IFEU0P1XJ6P206a/K080KVi^
0P1cLg<207MgM`80Ng]k0P20P80208F5Q@80RXZ:0P2@T9000`2FUYH0W9bL09bLW0020:6QX@80Z:RX
0P2_[jl20;Fe]@80_Kfm0P32`/820<S8b080c<c<0P3?cll20=CDe080f=SH0P3Lg=`20=oOg`80fm_K
00<0f=SH0=GEe@3EeMD00P3Bd]820<o?c`80c<c<0P39bLT20<K6aP80a<C40P31`L420;jn_P80^k^k
0P2h^;P20;Fe]@80/[:b0P2_[jl20:b/[0030:VYZ@2VYZH0YZJV0080Xj>S0P2QXJ4209jNWP80Vi^K
0P2HV9P209JFUP80Ti>C0P2@T90208f=S@80Rh^;0P28R8P208F5Q@80Ph>30P20P8000`1mOGd0Ng]k
07]kN`0207QhN080MWIf0P1cLg<2071`L080KVi^0P1[Jf/E0?ooo`004`3oool206IVIP80I6AT0P1R
HV82061PH080GUiN0P1LG5`205UIF@80EeMG00<0EEEE05=CD`1CDe<00P1ADE4204m?C`80CDe=0P1<
C4`204Y:BP80B4Q80P16ATH204E5A@80@d=30P11@D420410@080?clo0P0m?Cd203`l?00303/k>`0j
>SX0>SXj0080>3Ph0P0k>c/20410@080ADE50P17AdL204Y:BP@0CDe=0P1<C4`204];B`P0BDU900<0
BTY:04];B`1;Bd/0101;Bd/204a<C0@0CTi>0P1?Cdl2051@D080DE5A0P1CDe<205ADE080EEEE0P1H
F5P205UIF@80G5aL00<0GUiN061PH01PH6000P1QHF4206=SH`80IFEU0P1XJ6P206][J`80KVi^0P1b
LW8207MgM`80Ng]k0P1oOgl208B4Q080RHV90P2>SXh209BDU00309ZJVP2PX:00X:2P0080YZJV0P2/
[:`20;:b/P80^;Rh0P2n_[h20<;2`P80alO70P3:b/X20<k>cP80eMGE0P3GemL20=gMg@80fm_K0P3G
emL00`3De=@0dM7A0=7Ad@020<k>cP80c<c<0P39bLT20<K6aP80`l?30P30`<020;fm_@80^[Zj0P2h
^;P20;Fe]@80/[:b0P2_[jl20:b/[080ZZZZ00<0YjNW0:BTY02TY:@00P2QXJ4209nOW`80W9bL0P2J
VYX209NGU`80U9BD0P2ATI4208n?S`80S8b<0P2:RXX208N7Q`80Q8B40P22PX8207moO`0307emO@1j
NWX0NWYj0080N7Qh0P1eMGD207=cL`80L71`0P1^KVh206][JaD0oooo000C0?ooo`80IVIV0P1TI6@2
069RHP80H61P0P1NGUh205aLG080FEUI0P1GEeL00`1EEED0De=C05=CD`02055AD@80Cdm?0P1=CDd2
04a<C080BTY:0P18B4P204I6AP80ADE50P13@d<20451@@80@4100P0o?cl203dm?@80?3`l00<0>c/k
03Xj>P0j>SX00P0h>3P203/k>`80@4100P15ADD204M7A`80BTY:101=CDd204a<C080Bd];2019BDT0
0`1:BTX0Bd];04];B`0404];B`80C4a<101>CTh204m?C`80D51@0P1ADE4205=CD`80E5AD0P1EEED2
05QHF080FEUI0P1LG5`00`1NGUh0H61P061PH002065QH@80Hf=S0P1UIFD206QXJ080Jf][0P1^KVh2
079bLP80MgMg0P1kNg/207moO`80Q8B40P29RHT208j>SP80U9BD00<0VYZJ0:2PX02PX:000P2VYZH2
0:b/[080/[:b0P2h^;P20;jn_P80`/;20P37alL20<[:bP80c/k>0P3EeMD20=OGe`80gMgM0P3Kfm/2
0=OGe`030=CDe03AdM40dM7A0080c/k>0P3<c<`20<W9b@80a/K60P33`l<20<30`080_Kfm0P2j^[X2
0;Rh^080]KFe0P2b/[820:n_[`80[:b/0P2ZZZX00`2WYjL0Y:BT0:BTY0020:6QX@80WinO0P2LW9`2
09ZJVP80UiNG0P2DU9@2096AT@80Shn?0P2<S8`208Z:RP80QhN70P24Q8@208:2PP80Ogmo00<0OGem
07YjNP1jNWX00P1hN7P207EeM@80Lg=c0P1`L70206i^KP80Jf][5@3oool001<0oooo0P1WIfL206AT
I080HV9R0P1PH60205iNGP80G5aL0P1JFUX205QHF00305IFEP1DE5@0E5AD0080DU9B0P1ADE4204m?
C`80CDe=0P1;Bd/204Y:BP80B4Q80P16ATH204E5A@80@d=30P12@T820451@@80?clo0P0n?Sh00`0m
?Cd0?3`l03`l?00203Xj>P80>CTi0P0n?Sh204=3@`80ADE50P19BDT204];B`80C4a<0P1;Bd/204Y:
BP@0B4Q80P19BDT204Y:BPD0Bd];0P1<C4`204i>CP@0Cdm?0P1ADE42059BDP80De=C0P1EEED205IF
EP80F5QH0P1JFUX205]KF`80GEeM00<0H61P069RHP1RHV800P1TI6@206IVIP80J6QX0P1[Jf/206i^
KP80LG5a0P1fMWH207YjNP80OWin0P23Ph<208R8R080SHf=0P2BTY8209RHV00309jNWP2TY:@0Y:BT
0080ZJVY0P2^[Zh20;>c/`80^KVi0P2m_Kd20<71`@80aLG50P3:b/X20=3@d080e=CD0P3Hf=P20=WI
f@80e]KF0P3Cdm<00`3@d=00cLg=0<g=c@020<_;b`80b<S80P35aLD20<;2`P80`<300P2m_Kd20;Zj
^P80]kNg0P2e]KD20;:b/P80[jn_0P2][Jd20:ZZZP80YjNW00<0YJFU0::RXP2RXZ800P2OWil209fM
W@80VYZJ0P2HV9P209FEU@80Ti>C0P2@T90208f=S@80Rh^;0P28R8P208J6QP80Ph>30P21PH4207in
OP0307alO01jNWX0NWYj0080MgMg0P1eMGD2079bLP80L71`0P1]KFd206][JaD0oooo000C0?ooo`80
IfMW0P1TI6@2069RHP80H61P0P1NGUh205aLG080FUYJ0P1HF5P00`1FEUH0E5AD05ADE002059BDP80
DE5A0P1?Cdl204e=C@80Bd];0P1:BTX204Q8B080ATI60P15ADD204=3@`80@T920P11@D4203lo?`80
?Shn00<0?Cdm03`l?00l?3`00P0j>SX203Ti>@80?Shn0P13@d<204E5A@80BDU90P1;Bd/204a<C080
Bd];0P1:BTX404Q8B080BDU90P1:BTX504];B`80C4a<0P1>CTh404m?C`80DE5A0P1BDU8205=CD`80
EEEE0P1FEUH205QHF080FUYJ0P1KFe/205eMG@03061PH01RHV80HV9R0080I6AT0P1VIVH206QXJ080
Jf][0P1^KVh2075aL@80MWIf0P1jNWX207inOP80Ph>30P28R8P208f=S@80TY:B0P2HV9P00`2NWYh0
Y:BT0:BTY0020:VYZ@80[Zj^0P2c/k<20;Vi^@80_Kfm0P31`L420<G5a@80b/[:0P3@d=020=CDe080
f=SH0P3IfMT20=KFeP80dm?C00<0d=3@0<g=c@3=cLd00P3;bl/20<S8b080aLG50P32`/820<30`080
_Kfm0P2j^[X20;Ng]`80]KFe0P2b/[820:n_[`80[Jf]0P2ZZZX20:NWY`030:FUY@2RXZ80XZ:R0080
WinO0P2MWId209ZJVP80V9RH0P2EUID209>CT`80T92@0P2=SHd208^;R`80R8R80P26QXH208>3P`80
PH610P1nOWh00`1lO7`0NWYj07YjNP0207MgM`80MGEe0P1bLW82071`L080KFe]0P1[Jf/E0?ooo`00
4`3oool206MWI`80IFEU0P1SHf<2065QH@80GemO0P1MGEd205]KF`80FEUI00<0EeMG05EEE@1EEED0
0P1DE5@2059BDP80D51@0P1>CTh204e=C@80Bd];0P1:BTX204Q8B080AdM70P15ADD204A4A080@d=3
0P11@D420410@00303lo?`0m?Cd0?Cdm0080?3`l0P0j>SX203`l?080?clo0P13@d<204M7A`80BDU9
0P1:BTX204];B`80BTY:0P18B4P204M7A`80BDU90P1:BTX504a<C080CDe=101@D502055AD@80De=C
0P1DE5@405IFEP80FUYJ0P1KFe/205aLG080GUiN0P1OGel00`1SHf<0I6AT06ATI00206MWI`80JFUY
0P1[Jf/206i^KP80LG5a0P1eMGD207QhN080OGem0P22PX8208N7Q`80S8b<0P2ATI4209NGU`80W9bL
00<0XJ6Q0:NWY`2WYjL00P2/[:`20;2`/080]KFe0P2i^KT20;bl_080`<300P35aLD20<_;b`80d=3@
0P3EeMD20=OGe`80e=CD0P3AdM420<o?c`030<c<c039bLT0bLW90080alO70P34a<@20<71`@80_kno
0P2l_;`20;Zj^P80]kNg0P2d];@20;:b/P80[jn_0P2][Jd20:ZZZP80YjNW0P2UYJD00`2RXZ80X:2P
0:2PX00209fMW@80Vi^K0P2HV9P209JFUP80U9BD0P2ATI4208n?S`80S8b<0P2:RXX208N7Q`80QHF5
0P22PX820820P080OWin00<0Ng]k07UiN@1iNGT00P1gMgL207AdM080LW9b0P1`L70206e]K@80Jf][
5@3oool001<0oooo0P1WIfL206EUI@80Hf=S0P1QHF4205mOG`80GEeM0P1KFe/205UIF@0305MGE`1E
EED0EEEE0080E5AD0P1BDU82051@D080CTi>0P1=CDd204];B`80BTY:0P18B4P204M7A`80ADE50P14
A4@204=3@`80@D510P10@4000`0o?cl0?Cdm03dm?@0203`l?080>SXj0P0l?3`203lo?`80@d=30P17
AdL204U9B@80BTY:0P1;Bd/204Y:BP80B4Q80P17AdL204U9B@80BTY:1@1<C4`204e=C@@0D51@0P1A
DE4205=CD`80E5AD101FEUH205YJFP80Fe]K0P1LG5`205iNGP80GemO00<0Hf=S06ATI01TI6@00P1W
IfL206UYJ@80Jf][0P1^KVh2075aL@80MGEe0P1hN7P207emO@80PX:20P27QhL208b<S080TI6A0P2G
UiL209bLW0030:6QX@2WYjL0YjNW0080[:b/0P2`/;020;Fe]@80^KVi0P2l_;`20<30`080aLG50P3;
bl/20=3@d080eMGE0P3GemL20=CDe080dM7A0P3?cll00`3<c<`0bLW90<W9b@020<O7a`80a<C40P31
`L420;no_`80_;bl0P2j^[X20;Ng]`80];Bd0P2b/[820:n_[`80[Jf]0P2ZZZX20:NWY`80YJFU00<0
XZ:R0:2PX02PX:000P2MWId209^KV`80V9RH0P2FUYH209BDU080TI6A0P2?Shl208b<S080RXZ:0P27
QhL208F5Q@80PX:20P20P80207inOP0307]kN`1iNGT0NGUi0080MgMg0P1dM7@2079bLP80L71`0P1]
KFd206][JaD0oooo000C0?ooo`80IfMW0P1UIFD206=SH`80HF5Q0P1OGel205eMG@80G5aL0P1JFUX0
0`1HF5P0EUIF05IFEP0205EEE@80De=C0P1ADE42051@D080CTi>0P1=CDd204];B`80BTY:0P18B4P2
04M7A`80ATI60P14A4@204=3@`80@T9200<0@D5103lo?`0o?cl00P0n?Sh203dm?@@0?3`l0P11@D42
04E5A@80AdM70P19BDT204];B`80BTY:0P18B4P204M7A`80BDU90P1;Bd/00`1<C4`0CTi>04i>CP02
04i>CP80Cdm?0P1@D502059BDP80De=C0P1EEED205MGE`@0FEUI0P1MGEd205iNGP80GemO0P1PH602
069RHP0306IVIP1WIfL0IfMW0080JVYZ0P1/K6`206i^KP80LG5a0P1eMGD207QhN080O7al0P20P802
08F5Q@80RXZ:0P2?Shl209FEU@80VYZJ0P2OWil00`2TY:@0Z:RX0:RXZ0020:b/[080/;2`0P2c/k<2
0;Jf]P80_;bl0P31`L420<K6aP80c<c<0P3@d=020=GEe@80d];B0P3?cll20<g=c@80b/[:00<0b<S8
0<G5a@35aLD00P33`l<20<30`080_[jn0P2k^k/20;Vi^@80][Jf0P2d];@20;6a/@80[jn_0P2/[:`2
0:ZZZP80YjNW0P2UYJD20::RXP030:2PX02NWYh0WYjN0080Vi^K0P2IVIT209NGU`80U9BD0P2BTY82
08n?S`80SHf=0P2;Rh/208R8R080QXJ60P24Q8@20861P@80Ogmo0P1mOGd00`1kNg/0N7Qh07QhN002
07IfMP80M7Ad0P1bLW8206m_K`80KFe]0P1[Jf/E0?ooo`004`3oool206MWI`80IFEU0P1SHf<2069R
HP80H61P0P1NGUh205aLG080Fe]K00<0FEUI05MGE`1GEeL00P1FEUH205ADE080De=C0P1ADE42051@
D080CTi>0P1=CDd204];B`80BTY:0P19BDT204Q8B080ATI60P15ADD204A4A00304=3@`12@T80@T92
0080@4100P0o?cl203hn?P80?3`l0P0n?Sh204=3@`80ATI60P19BDT404Y:BP80BDU90P18B4P204Y:
BP80CDe=00<0CTi>04m?C`1?Cdl00P1@D502055AD@80DU9B0P1DE5@205IFEP80EeMG0P1JFUX205]K
F`80GEeM0P1OGel2065QH@80Hf=S0P1TI6@206EUI@0306UYJ@1ZJVX0JVYZ0080KFe]0P1_Kfl2075a
L@80M7Ad0P1hN7P207]kN`80P8200P23Ph<208R8R080SHf=0P2CTi<209RHV080W9bL0P2QXJ400`2U
YJD0ZJVY0:VYZ@020:^[Z`80/;2`0P2b/[820;Jf]P80_[jn0P33`l<20<S8b080c<c<103AdM420<g=
c@80bl_;0P38b<P20<K6aP030<C4a031`L40`L710080_kno0P2m_Kd20;Zj^P80^;Rh0P2e]KD20;>c
/`80/K6a0P2^[Zh20:b/[080ZJVY0P2WYjL20:FUY@80XZ:R0P2PX:000`2NWYh0W9bL09bLW00209VI
V@80UiNG0P2EUID209:BTP80T92@0P2>SXh208b<S080RHV90P27QhL208F5Q@80Ph>30P20P80207in
OP80O7al00<0NWYj07QhN01hN7P00P1fMWH207=cL`80LG5a0P1_Kfl206e]K@80Jf][5@3oool001<0
oooo0P1WIfL206EUI@80Hf=S0P1RHV82061PH080GUiN0P1LG5`205]KF`0305UIF@1GEeL0EeMG0080
EUIF0P1DE5@205=CD`80DE5A0P1@D50204i>CP80CDe=0P1;Bd/204Y:BP80BDU90P18B4P204I6AP80
ADE50P14A4@00`13@d<0@T920492@P020410@080?clo0P0n?Sh203`l?080?Shn0P13@d<204I6AP80
BDU9101:BTX204U9B@80B4Q80P1:BTX204e=C@0304i>CP1?Cdl0Cdm?0080D51@0P1ADE42059BDP80
E5AD0P1FEUH205MGE`80FUYJ0P1KFe/205eMG@80GemO0P1QHF4206=SH`80I6AT0P1UIFD00`1YJFT0
JVYZ06YZJP0206e]K@80Kfm_0P1aLG4207AdM080N7Qh0P1kNg/20820P080Ph>30P28R8P208f=S@80
Ti>C0P2HV9P209bLW080XJ6Q00<0YJFU0:VYZ@2YZJT00P2[Zj/20;2`/080/[:b0P2f][H20;jn_P80
`l?30P38b<P20<c<c0@0dM7A0P3=cLd20<_;b`80b<S80P36a/H00`34a<@0`L710<71`@020;no_`80
_Kfm0P2j^[X20;Rh^080]KFe0P2c/k<20;6a/@80[Zj^0P2/[:`20:VYZ@80YjNW0P2UYJD20::RXP80
X:2P00<0WYjN09bLW02LW9`00P2IVIT209NGU`80UIFE0P2BTY82092@T080SXj>0P2<S8`208V9R@80
QhN70P25QHD208>3P`80P8200P1nOWh207alO00307YjNP1hN7P0N7Qh0080MWIf0P1cLg<2075aL@80
Kfm_0P1]KFd206][JaD0oooo000C0?ooo`80IfMW0P1UIFD206ATI080HV9R0P1PH60205mOG`80GEeM
0P1KFe/00`1JFUX0F5QH05QHF00205MGE`80EEEE0P1DE5@2059BDP80DE5A0P1@D50204i>CP80CDe=
0P1<C4`204Y:BP80BDU90P18B4P204M7A`80ATI600<0ADE504A4A014A4@00P13@d<20451@@80@410
0P0o?cl203hn?P80@D510P14A4@204M7A`80BDU91P1;Bd/204Y:BP80CDe=00<0Cdm?051@D01@D500
0P1ADE4205=CD`80E5AD0P1FEUH205QHF080FUYJ0P1LG5`205iNGP80H61P0P1RHV8206ATI080IfMW
0P1XJ6P206UYJ@0306][J`1]KFd0KFe]0080L71`0P1aLG4207AdM080N7Qh0P1kNg/207inOP80PX:2
0P26QXH208^;R`80T92@0P2DU9@209RHV080W9bL0P2QXJ400`2TY:@0Z:RX0:RXZ0020:ZZZP80[jn_
0P2c/k<20;Vi^@80`<300P34a<@20<S8b0@0cLg=0P3;bl/20<W9b@80a/K60P34a<@20<;2`P030;no
_`2m_Kd0_Kfm0080^k^k0P2i^KT20;Ng]`80];Bd0P2b/[820;2`/080[Jf]0P2[Zj/20:VYZ@80YjNW
0P2TY:@20::RXP80X:2P0P2NWYh00`2LW9`0VIVI09VIV@0209NGU`80UIFE0P2CTi<2096AT@80Shn?
0P2<S8`208Z:RP80R8R80P26QXH208B4Q080PX:20P1oOgl207emO@80Ng]k00<0NGUi07MgM`1gMgL0
0P1eMGD207=cL`80LG5a0P1_Kfl206e]K@80Jf][5@3oool001<0oooo0P1WIfL206EUI@80I6AT0P1R
HV82061PH080GemO0P1MGEd205]KF`0305YJFP1HF5P0F5QH0080EeMG0P1EEED205ADE080DU9B0P1A
DE42051@D080CTi>0P1=CDd204a<C080BTY:0P19BDT204Q8B080AdM70P16ATH00`15ADD0A4A404A4
A00204=3@`80@D510P10@40203lo?`80?Shn0P11@D4204A4A080AdM70P19BDT604];B`80BTY:0P1=
CDd00`1?Cdl0D51@051@D002055AD@80De=C0P1DE5@205IFEP80F5QH0P1JFUX205aLG080GUiN0P1P
H602069RHP80I6AT0P1WIfL206QXJ080JFUY00<0Jf][06e]K@1]KFd00P1`L702075aL@80M7Ad0P1h
N7P207]kN`80OWin0P22PX8208J6QP80Rh^;0P2@T90209BDU080V9RH0P2LW9`20:6QX@030:BTY02X
Z:P0Z:RX0080ZZZZ0P2_[jl20;>c/`80^KVi0P30`<020<C4a080b<S8103=cLd20<_;b`80bLW90P36
a/H20<C4a080`/;200<0_kno0;fm_@2m_Kd00P2k^k/20;Vi^@80]kNg0P2d];@20;:b/P80/;2`0P2]
[Jd20:^[Z`80ZJVY0P2WYjL20:BTY080XZ:R0P2PX:0209jNWP0309bLW02IVIT0VIVI0080UiNG0P2E
UID209>CT`80TI6A0P2?Shl208b<S080RXZ:0P28R8P208J6QP80Q8B40P22PX8207moO`80OGem0P1k
Ng/00`1iNGT0MgMg07MgM`0207EeM@80Lg=c0P1aLG4206m_K`80KFe]0P1[Jf/E0?ooo`004`3oool2
06MWI`80IFEU0P1TI6@2069RHP80HF5Q0P1OGel205iNGP80G5aL00<0Fe]K05UIF@1IFET00P1HF5P2
05IFEP80EEEE0P1DE5@2059BDP80DE5A0P1@D50204m?C`80CDe=0P1<C4`204];B`80BTY:0P19BDT2
04Q8B00304M7A`16ATH0ATI60080ADE50P14A4@204=3@`80@D511010@40204=3@`80ATI60P19BDT2
04];B`80C4a<101=CDd204i>CP03055AD@1CDe<0De=C0080E5AD0P1EEED205MGE`80F5QH0P1KFe/2
05eMG@80GemO0P1QHF4206=SH`80IFEU0P1XJ6P206YZJP80K6a/0P1]KFd00`1_Kfl0L71`071`L002
079bLP80Lg=c0P1gMgL207]kN`80OGem0P21PH4208B4Q080R8R80P2<S8`2092@T080U9BD0P2GUiL2
09ZJVP80WinO00<0Xj>S0:JVYP2VYZH00P2[Zj/20;2`/080]KFe0P2k^k/20<30`080aLG50P39bLT2
0<[:bP80b<S80P36a/H20<C4a080`L710P2o_kl20;fm_@030;^k^`2i^KT0^KVi0080]kNg0P2e]KD2
0;>c/`80/K6a0P2^[Zh20:b/[080ZZZZ0P2XZ:P20:JVYP80Y:BT0P2RXZ820:2PX080WIfM0P2KVi/0
0`2IVIT0UiNG09NGU`0209FEU@80Ti>C0P2ATI4208n?S`80SHf=0P2;Rh/208V9R@80QhN70P24Q8@2
08:2PP80P8200P1nOWh207alO080NWYj00<0N7Qh07IfMP1fMWH00P1dM7@2079bLP80L71`0P1^KVh2
06e]K@80Jf][5@3oool001<0oooo0P1WIfL206EUI@80I6AT0P1RHV82065QH@80GemO0P1NGUh205aL
G00305]KF`1IFET0FEUI0080F5QH0P1FEUH205EEE@80E5AD0P1BDU82055AD@80D51@0P1?Cdl204e=
C@80C4a<0P1;Bd/204Y:BP80BDU90P18B4P00`17AdL0ATI604I6AP0204E5A@80A4A40P13@d<20451
@@@0@4100P13@d<204I6AP80BDU90P1;Bd/204a<C0@0CDe=0P1>CTh00`1ADE40De=C05=CD`0205AD
E080EEEE0P1GEeL205QHF080Fe]K0P1MGEd205mOG`80HF5Q0P1SHf<206EUI@80J6QX0P1ZJVX206a/
K080KFe]00<0Kfm_071`L01`L7000P1bLW8207=cL`80MgMg0P1kNg/207emO@80PH610P24Q8@208R8
R080S8b<0P2@T90209BDU080UiNG0P2JVYX209nOW`030:>SX`2VYZH0YZJV0080Zj^[0P2`/;020;Fe
]@80^k^k0P30`<020<G5a@80bLW90P3:b/X20<S8b080a/K60P34a<@20<71`@80_kno0P2m_Kd00`2k
^k/0^KVi0;Vi^@020;Ng]`80]KFe0P2c/k<20;6a/@80[Zj^0P2/[:`20:ZZZP80Z:RX0P2VYZH20:BT
Y080XZ:R0P2PX:0209fMW@80Vi^K00<0VIVI09NGU`2GUiL00P2EUID209>CT`80TI6A0P2?Shl208f=
S@80Rh^;0P29RHT208N7Q`80Q8B40P22PX820820P080OWin0P1lO7`207YjNP0307QhN01fMWH0MWIf
0080M7Ad0P1bLW82071`L080KVi^0P1]KFd206][JaD0oooo000C0?ooo`80IfMW0P1VIVH206ATI080
Hf=S0P1QHF42061PH080GUiN0P1MGEd00`1LG5`0FUYJ05YJFP0205UIF@80EeMG0P1FEUH205EEE@80
E5AD0P1BDU82055AD@80D51@0P1?Cdl204i>CP80CDe=0P1<C4`204];B`80BTY:00<0BDU904Q8B018
B4P00P17AdL204I6AP80ADE50P14A4@204=3@`80@T920P13@d<204E5A@80BDU90P1;Bd/204e=C@80
Cdm?0P1@D502055AD@03059BDP1EEED0EEEE0080EUIF0P1HF5P205YJFP80Fe]K0P1NGUh2061PH080
HV9R0P1TI6@206IVIP80J6QX0P1/K6`206e]K@80Kfm_0P1`L7000`1bLW80Lg=c07=cL`0207=cL`80
MWIf0P1iNGT207alO080Ogmo0P22PX8208F5Q@80R8R80P2;Rh/208n?S`80TY:B0P2EUID209ZJVP80
WYjN00<0Xj>S0:RXZ02XZ:P00P2][Jd20;>c/`80^;Rh0P2k^k/20<30`080aLG50P36a/H20<C4a080
`/;20P30`<020;no_`80_;bl0P2j^[X20;Vi^@030;Ng]`2e]KD0]KFe0080/k>c0P2a/K420:n_[`80
[Jf]0P2[Zj/20:VYZ@80YjNW0P2UYJD20:>SX`80XJ6Q0P2OWil209fMW@80Vi^K0P2IVIT00`2GUiL0
UIFE09FEU@0209>CT`80TI6A0P2?Shl208f=S@80Rh^;0P29RHT208N7Q`80QHF50P23Ph<20861P@80
Ogmo0P1mOGd207]kN`80NWYj00<0N7Qh07IfMP1fMWH00P1dM7@2079bLP80L71`0P1^KVh206a/K080
JVYZ5@3oool001<0oooo0P1WIfL206IVIP80I6AT0P1SHf<2065QH@80H61P0P1NGUh205eMG@0305aL
G01JFUX0FUYJ0080FEUI0P1GEeL205IFEP80EEEE0P1DE5@2059BDP80DE5A0P1@D50204m?C`80CTi>
0P1=CDd204a<C080Bd];0P1:BTX00`19BDT0B4Q804Q8B00204M7A`80ATI60P15ADD204A4A080@d=3
0P12@T8204=3@`80ADE50P19BDT204];B`80CDe=0P1?Cdl2051@D080DE5A00<0DU9B05EEE@1EEED0
0P1FEUH205QHF080FUYJ0P1KFe/205iNGP80H61P0P1RHV8206ATI080IVIV0P1XJ6P206a/K080KFe]
0P1_Kfl2071`L003079bLP1cLg<0Lg=c0080Lg=c0P1fMWH207UiN@80O7al0P1oOgl208:2PP80QHF5
0P28R8P208^;R`80Shn?0P2BTY8209FEU@80VYZJ0P2NWYh00`2SXj<0Z:RX0:RXZ0020:f][@80/k>c
0P2h^;P20;^k^`80`<300P35aLD20<K6aP80a<C40P32`/820<30`080_kno0P2l_;`20;Zj^P80^KVi
00<0]kNg0;Fe]@2e]KD00P2c/k<20;6a/@80[jn_0P2][Jd20:^[Z`80ZJVY0P2WYjL20:FUY@80Xj>S
0P2QXJ4209nOW`80WIfM0P2KVi/209VIV@0309NGU`2EUID0UIFE0080Ti>C0P2ATI4208n?S`80SHf=
0P2;Rh/208V9R@80QhN70P25QHD208>3P`80PH610P1oOgl207emO@80Ng]k0P1jNWX00`1hN7P0MWIf
07IfMP0207AdM080LW9b0P1`L70206i^KP80K6a/0P1ZJVXE0?ooo`004`3oool206MWI`80IVIV0P1T
I6@206=SH`80HV9R0P1PH60205mOG`80GUiN00<0G5aL05]KF`1KFe/00P1JFUX205QHF080EeMG0P1F
EUH205EEE@80E5AD0P1CDe<2059BDP80D51@0P1?Cdl204i>CP@0CDe=0P1<C4`00`1;Bd/0BTY:04Y:
BP0204U9B@@0B4Q80P17AdL404I6AP80ADE50P16ATH204Q8B080Bd];0P1=CDd2051@D0@0De=C00<0
E5AD05MGE`1GEeL00P1IFET205]KF`80GEeM0P1OGel2065QH@80Hf=S0P1TI6@206IVIP80JVYZ0P1[
Jf/206i^KP80L71`101aLG400`1cLg<0M7Ad07AdM00207EeM@80MWIf0P1jNWX207alO080OWin0P21
PH4208>3P`80QXJ60P2:RXX208j>SP80TI6A0P2FUYH209^KV`80WinO00<0Y:BT0:ZZZP2ZZZX00P2_
[jl20;Fe]@80^;Rh0P2k^k/20<30`080`/;20P30`<020;jn_P80_Kfm0P2k^k/20;Vi^@80^;Rh0P2f
][H20;Bd]0030;>c/`2a/K40/K6a0080[jn_0P2][Jd20:b/[080ZZZZ0P2XZ:P20:FUY@80Y:BT0P2R
XZ820:2PX080WYjN0P2LW9`209ZJVP80V9RH0P2GUiL00`2EUID0Ti>C09>CT`02096AT@80Shn?0P2=
SHd208^;R`80RHV90P28R8P208J6QP80Q8B40P22PX820820P080OWin0P1lO7`207]kN`80NGUi00<0
MgMg07EeM@1eMGD00P1cLg<2079bLP80L71`0P1^KVh206a/K080JVYZ5@3oool001<0oooo0P1WIfL2
06IVIP80I6AT0P1SHf<2069RHP80H61P0P1OGel205iNGP0305aLG01KFe/0Fe]K0080FUYJ0P1HF5P2
05MGE`80EUIF0P1EEED205ADE080De=C0P1BDU82051@D080Cdm?0P1>CTh404e=C@80C4a<00<0Bd];
04Y:BP1:BTX00P19BDT404Q8B080AdM71016ATH204E5A@80ATI60P18B4P204];B`80CDe=0P1@D504
05=CD`0305ADE01GEeL0EeMG0080FEUI0P1KFe/205eMG@80GemO0P1QHF4206=SH`80I6AT0P1VIVH2
06YZJP80Jf][0P1^KVh2071`L0@0LG5a00<0Lg=c07AdM01dM7@00P1eMGD207IfMP80NWYj0P1lO7`2
07inOP80PH610P23Ph<208J6QP80RXZ:0P2>SXh2096AT@80UYJF0P2KVi/209nOW`030:BTY02ZZZX0
ZZZZ0080[jn_0P2e]KD20;Rh^080^k^k0P30`<020<;2`P80`<300P2n_[h20;fm_@80^k^k0P2i^KT2
0;Rh^080][Jf0P2d];@00`2c/k<0/K6a0;6a/@020:n_[`80[Jf]0P2/[:`20:ZZZP80Z:RX0P2UYJD2
0:BTY080XZ:R0P2PX:0209jNWP80W9bL0P2JVYX209RHV080UiNG00<0UIFE09>CT`2CTi<00P2ATI42
08n?S`80SHf=0P2;Rh/208V9R@80R8R80P26QXH208B4Q080PX:20P20P80207inOP80O7al0P1kNg/2
07UiN@0307MgM`1eMGD0MGEe0080Lg=c0P1bLW82071`L080KVi^0P1/K6`206YZJQD0oooo000C0?oo
o`80IfMW0P1VIVH206EUI@80Hf=S0P1RHV82065QH@80H61P0P1NGUh00`1MGEd0G5aL05aLG00205]K
F`80FEUI0P1HF5P205MGE`80EUIF0P1EEED205ADE080De=C0P1BDU82055AD@80D51@0P1?Cdl204i>
CP<0CDe=0P1<C4`404];B`@0BTY:0P19BDT404Q8B0@0BDU90P1:BTX204e=C@80DE5A0P1DE5@205IF
EP0305MGE`1HF5P0F5QH0080G5aL0P1NGUh2061PH080HV9R0P1TI6@206EUI@80IfMW0P1YJFT206e]
K@80KVi^0P1`L702075aL@@0LW9b00<0Lg=c07EeM@1eMGD00P1eMGD207MgM`80NGUi0P1jNWX207al
O080Ogmo0P22PX8208J6QP80RXZ:0P2>SXh209:BTP80UiNG0P2LW9`20:6QX@030:JVYP2[Zj/0Zj^[
0080/;2`0P2d];@20;Vi^@80^[Zj0P2l_;`20;^k^`80^[Zj0P2i^KT20;Rh^080][Jf0P2e]KD20;>c
/`80/[:b0P2`/;000`2^[Zh0[Jf]0:f][@020:^[Z`80ZZZZ0P2XZ:P20:JVYP80Y:BT0P2RXZ820:2P
X080WinO0P2MWId209^KV`80VYZJ0P2HV9P209JFUP80U9BD00<0TY:B096AT@2ATI400P2?Shl208f=
S@80Rh^;0P2:RXX208R8R080QXJ60P24Q8@208:2PP80PH610P1oOgl207emO@80Ng]k0P1jNWX207Qh
N00307IfMP1dM7@0M7Ad0080Lg=c0P1aLG4206m_K`80KVi^0P1/K6`206YZJQD0oooo000C0?ooo`80
IfMW0P1VIVH206EUI@80Hf=S0P1RHV82065QH@80H61P0P1NGUh00`1MGEd0G5aL05aLG00205]KF`80
FEUI0P1HF5P205MGE`80EUIF0P1EEED205ADE080De=C0P1BDU82055AD@80D51@0P1?Cdl204i>CP<0
CDe=0P1<C4`404];B`@0BTY:0P19BDT404Q8B0@0BDU90P1:BTX204e=C@80DE5A0P1DE5@205IFEP03
05MGE`1HF5P0F5QH0080G5aL0P1NGUh2061PH080HV9R0P1TI6@206EUI@80IfMW0P1YJFT206e]K@80
KVi^0P1`L702075aL@@0LW9b00<0Lg=c07EeM@1eMGD00P1eMGD207MgM`80NGUi0P1jNWX207alO080
Ogmo0P22PX8208J6QP80RXZ:0P2>SXh209:BTP80UiNG0P2LW9`20:6QX@030:JVYP2[Zj/0Zj^[0080
/;2`0P2d];@20;Vi^@80^[Zj0P2l_;`20;^k^`80^[Zj0P2i^KT20;Rh^080][Jf0P2e]KD20;>c/`80
/[:b0P2`/;000`2^[Zh0[Jf]0:f][@020:^[Z`80ZZZZ0P2XZ:P20:JVYP80Y:BT0P2RXZ820:2PX080
WinO0P2MWId209^KV`80VYZJ0P2HV9P209JFUP80U9BD00<0TY:B096AT@2ATI400P2?Shl208f=S@80
Rh^;0P2:RXX208R8R080QXJ60P24Q8@208:2PP80PH610P1oOgl207emO@80Ng]k0P1jNWX207QhN003
07IfMP1dM7@0M7Ad0080Lg=c0P1aLG4206m_K`80KVi^0P1/K6`206YZJQD0oooo000C0?ooo`80IfMW
0P1VIVH206EUI@80I6AT0P1RHV82065QH@80H61P0P1OGel00`1NGUh0GEeM05eMG@0205aLG080FUYJ
0P1IFET205QHF080EeMG0P1FEUH205EEE@@0E5AD0P1CDe<2059BDP80DE5A0P1@D50304m?C`80CTi>
101=CDd604a<C0H0Bd];0P1<C4`204];B`80Cdm?0P1@D50205ADE080F5QH00<0FEUI05]KF`1KFe/0
0P1NGUh2061PH080HF5Q0P1TI6@206EUI@80IfMW0P1YJFT206YZJP80K6a/0P1]KFd206i^KP80L71`
101aLG400`1cLg<0M7Ad07AdM00207AdM080MWIf0P1hN7P207UiN@80O7al0P20P80208:2PP80QhN7
0P2;Rh/2092@T080U9BD0P2IVIT209jNWP80Xj>S00<0YZJV0:^[Z`2[Zj/00P2`/;020;Bd]080][Jf
0P2e]KD20;Jf]P80]KFe102d];@20;:b/P80/K6a0P2`/;020:j^[P80[Jf]0P2/[:`00`2ZZZX0ZJVY
0:VYZ@020:NWY`80YZJV0P2TY:@20:>SX`80XJ6Q0P2OWil209fMW@80W9bL0P2JVYX209RHV080UiNG
0P2EUID209>CT`80TY:B00<0T92@08j>SP2>SXh00P2=SHd208^;R`80RHV90P28R8P208J6QP80Q8B4
0P23Ph<20861P@80Ogmo0P1mOGd207alO080NWYj0P1iNGT207MgM`0307EeM@1dM7@0M7Ad0080LW9b
0P1aLG4206m_K`80KFe]0P1/K6`206YZJQD0oooo000C0?ooo`80IfMW0P1VIVH206EUI@80I6AT0P1R
HV82065QH@80H61P0P1OGel00`1NGUh0GEeM05eMG@0205aLG080FUYJ0P1IFET205QHF080EeMG0P1F
EUH205EEE@@0E5AD0P1CDe<2059BDP80DE5A0P1@D50304m?C`80CTi>101=CDd604a<C0H0Bd];0P1<
C4`204];B`80Cdm?0P1@D50205ADE080F5QH00<0FEUI05]KF`1KFe/00P1NGUh2061PH080HF5Q0P1T
I6@206EUI@80IfMW0P1YJFT206YZJP80K6a/0P1]KFd206i^KP80L71`101aLG400`1cLg<0M7Ad07Ad
M00207AdM080MWIf0P1hN7P207UiN@80O7al0P20P80208:2PP80QhN70P2;Rh/2092@T080U9BD0P2I
VIT209jNWP80Xj>S00<0YZJV0:^[Z`2[Zj/00P2`/;020;Bd]080][Jf0P2e]KD20;Jf]P80]KFe102d
];@20;:b/P80/K6a0P2`/;020:j^[P80[Jf]0P2/[:`00`2ZZZX0ZJVY0:VYZ@020:NWY`80YZJV0P2T
Y:@20:>SX`80XJ6Q0P2OWil209fMW@80W9bL0P2JVYX209RHV080UiNG0P2EUID209>CT`80TY:B00<0
T92@08j>SP2>SXh00P2=SHd208^;R`80RHV90P28R8P208J6QP80Q8B40P23Ph<20861P@80Ogmo0P1m
OGd207alO080NWYj0P1iNGT207MgM`0307EeM@1dM7@0M7Ad0080LW9b0P1aLG4206m_K`80KFe]0P1/
K6`206YZJQD0oooo000C0?ooo`80IfMW0P1VIVH206EUI@80I6AT0P1SHf<2069RHP80HF5Q0P1PH600
0`1OGel0GEeM05eMG@0205aLG080Fe]K0P1JFUX205UIF@@0F5QH0P1GEeL205IFEP80EEEE0P1DE5@2
05=CD`@0DU9B0P1ADE43051@D0H0Cdm?301>CTh204m?C`80D51@0P1ADE4205ADE080F5QH00<0Fe]K
05eMG@1MGEd00P1OGel2065QH@80HV9R0P1TI6@206IVIP80J6QX0P1YJFT206][J`80K6a/0P1]KFd2
06i^KP80Kfm_101`L7000`1aLG40Lg=c07=cL`0207AdM080MGEe0P1hN7P207YjNP80OGem0P21PH42
08B4Q080RHV90P2<S8`209:BTP80UiNG0P2JVYX209jNWP80XZ:R00<0YZJV0:^[Z`2[Zj/00P2^[Zh:
0;2`/080[jn_0P2^[Zh20:f][@80[:b/0P2[Zj/20:ZZZP80ZJVY0P2WYjL00`2VYZH0YJFU0:FUY@02
0:>SX`80XZ:R0P2PX:0209nOW`80WIfM0P2LW9`209ZJVP80VIVI0P2GUiL209JFUP80U9BD0P2CTi<2
096AT@80Shn?00<0SXj>08b<S02<S8`00P2;Rh/208V9R@80QhN70P26QXH208B4Q080Ph>30P21PH42
0820P080OWin0P1lO7`207]kN`80NGUi0P1hN7P207IfMP0307EeM@1cLg<0Lg=c0080LW9b0P1`L702
06m_K`80KFe]0P1/K6`206YZJQD0oooo000C0?ooo`80IfMW0P1VIVH206EUI@80I6AT0P1SHf<2069R
HP80HF5Q0P1PH6000`1OGel0GEeM05eMG@0205aLG080Fe]K0P1JFUX205UIF@@0F5QH0P1GEeL205IF
EP80EEEE0P1DE5@205=CD`@0DU9B0P1ADE43051@D0H0Cdm?301>CTh204m?C`80D51@0P1ADE4205AD
E080F5QH00<0Fe]K05eMG@1MGEd00P1OGel2065QH@80HV9R0P1TI6@206IVIP80J6QX0P1YJFT206][
J`80K6a/0P1]KFd206i^KP80Kfm_101`L7000`1aLG40Lg=c07=cL`0207AdM080MGEe0P1hN7P207Yj
NP80OGem0P21PH4208B4Q080RHV90P2<S8`209:BTP80UiNG0P2JVYX209jNWP80XZ:R00<0YZJV0:^[
Z`2[Zj/00P2^[Zh:0;2`/080[jn_0P2^[Zh20:f][@80[:b/0P2[Zj/20:ZZZP80ZJVY0P2WYjL00`2V
YZH0YJFU0:FUY@020:>SX`80XZ:R0P2PX:0209nOW`80WIfM0P2LW9`209ZJVP80VIVI0P2GUiL209JF
UP80U9BD0P2CTi<2096AT@80Shn?00<0SXj>08b<S02<S8`00P2;Rh/208V9R@80QhN70P26QXH208B4
Q080Ph>30P21PH420820P080OWin0P1lO7`207]kN`80NGUi0P1hN7P207IfMP0307EeM@1cLg<0Lg=c
0080LW9b0P1`L70206m_K`80KFe]0P1/K6`206YZJQD0oooo000C0?ooo`80J6QX0P1VIVH206EUI@80
I6AT0P1SHf<2069RHP80HF5Q0P1PH6000`1OGel0GUiN05iNGP0205eMG@80G5aL101KFe/205YJFP80
FEUI0P1HF5P205MGE`@0EUIF0P1EEED205ADE0@0De=C0`1BDU86055AD@P0D51@101ADE42059BDP80
De=C0P1DE5@205EEE@80FEUI00<0FUYJ05eMG@1MGEd00P1PH602069RHP80I6AT0P1UIFD206MWI`80
J6QX0P1ZJVX206][J`@0KFe]101^KVh406m_K`03075aL@1cLg<0Lg=c0080MGEe0P1fMWH207QhN080
Ng]k0P1oOgl208>3P`80QXJ60P2;Rh/208j>SP80U9BD0P2GUiL209ZJVP80WYjN0P2RXZ800`2UYJD0
Z:RX0:RXZ0020:VYZ@H0ZZZZ0P2[Zj/40:ZZZP80ZJVY0P2XZ:P20:NWY`80YZJV0P2UYJD20:BTY080
Xj>S00<0XZ:R0:6QX@2QXJ400P2OWil209jNWP80WIfM0P2LW9`209ZJVP80VIVI0P2GUiL209JFUP80
U9BD0P2CTi<209:BTP80T92@0P2>SXh208f=S@0308^;R`2:RXX0RXZ:0080R8R80P27QhL208J6QP80
Q8B40P22PX820861P@80P8200P1nOWh207emO@80Ng]k0P1iNGT207QhN080MgMg0P1eMGD00`1dM7@0
Lg=c07=cL`02075aL@80L71`0P1^KVh206e]K@80Jf][0P1ZJVXE0?ooo`004`3oool206QXJ080IVIV
0P1UIFD206ATI080Hf=S0P1RHV82065QH@80H61P00<0GemO05iNGP1NGUh00P1MGEd205aLG0@0Fe]K
0P1JFUX205UIF@80F5QH0P1GEeL405IFEP80EEEE0P1DE5@405=CD`<0DU9B1P1ADE48051@D0@0DE5A
0P1BDU8205=CD`80E5AD0P1EEED205UIF@0305YJFP1MGEd0GEeM0080H61P0P1RHV8206ATI080IFEU
0P1WIfL206QXJ080JVYZ0P1[Jf/406e]K@@0KVi^101_Kfl00`1aLG40Lg=c07=cL`0207EeM@80MWIf
0P1hN7P207]kN`80Ogmo0P23Ph<208J6QP80Rh^;0P2>SXh209BDU080UiNG0P2JVYX209jNWP80XZ:R
00<0YJFU0:RXZ02XZ:P00P2YZJT60:ZZZP80Zj^[102ZZZX20:VYZ@80Z:RX0P2WYjL20:JVYP80YJFU
0P2TY:@20:>SX`030::RXP2QXJ40XJ6Q0080WinO0P2NWYh209fMW@80W9bL0P2JVYX209VIV@80UiNG
0P2FUYH209BDU080Ti>C0P2BTY82092@T080SXj>0P2=SHd00`2;Rh/0RXZ:08Z:RP0208R8R080QhN7
0P26QXH208B4Q080PX:20P21PH420820P080OWin0P1mOGd207]kN`80NGUi0P1hN7P207MgM`80MGEe
00<0M7Ad07=cL`1cLg<00P1aLG42071`L080KVi^0P1]KFd206][J`80JVYZ5@3oool001<0oooo0P1X
J6P206MWI`80IVIV0P1UIFD206ATI080Hf=S0P1RHV82065QH@03061PH01OGel0GemO0080GUiN0P1M
GEd405aLG080Fe]K0P1JFUX205UIF@@0F5QH0P1GEeL405IFEP@0EEEE0`1DE5@805=CD`@0DU9B101C
De<405ADE080EEEE0P1GEeL205QHF080FUYJ00<0Fe]K05mOG`1OGel00P1QHF42069RHP80I6AT0P1V
IVH206MWI`80JFUY0P1ZJVX206][J`@0KFe]0P1^KVh406m_K`80L71`00<0LW9b07AdM01dM7@00P1e
MGD207QhN080NWYj0P1lO7`20861P@80QHF50P27QhL208^;R`80Shn?0P2CTi<209NGU`80VIVI0P2M
WId209nOW`030:2PX02RXZ80XZ:R0080Xj>S0P2TY:@:0:FUY@80Y:BT102SXj<20::RXP80XJ6Q0P2P
X:0209nOW`0309jNWP2MWId0WIfM0080W9bL0P2JVYX209VIV@80V9RH0P2GUiL209FEU@80U9BD0P2C
Ti<209:BTP80T92@0P2?Shl208f=S@80S8b<0P2:RXX00`29RHT0R8R808R8R00208J6QP80QHF50P24
Q8@208:2PP80PH610P1oOgl207inOP80OGem0P1kNg/207YjNP80N7Qh0P1gMgL207IfMP80M7Ad00<0
Lg=c079bLP1bLW800P1aLG4206m_K`80KVi^0P1]KFd206][J`80JVYZ5@3oool001<0oooo0P1XJ6P2
06MWI`80IVIV0P1UIFD206ATI080Hf=S0P1RHV82065QH@03061PH01OGel0GemO0080GUiN0P1MGEd4
05aLG080Fe]K0P1JFUX205UIF@@0F5QH0P1GEeL405IFEP@0EEEE0`1DE5@805=CD`@0DU9B101CDe<4
05ADE080EEEE0P1GEeL205QHF080FUYJ00<0Fe]K05mOG`1OGel00P1QHF42069RHP80I6AT0P1VIVH2
06MWI`80JFUY0P1ZJVX206][J`@0KFe]0P1^KVh406m_K`80L71`00<0LW9b07AdM01dM7@00P1eMGD2
07QhN080NWYj0P1lO7`20861P@80QHF50P27QhL208^;R`80Shn?0P2CTi<209NGU`80VIVI0P2MWId2
09nOW`030:2PX02RXZ80XZ:R0080Xj>S0P2TY:@:0:FUY@80Y:BT102SXj<20::RXP80XJ6Q0P2PX:02
09nOW`0309jNWP2MWId0WIfM0080W9bL0P2JVYX209VIV@80V9RH0P2GUiL209FEU@80U9BD0P2CTi<2
09:BTP80T92@0P2?Shl208f=S@80S8b<0P2:RXX00`29RHT0R8R808R8R00208J6QP80QHF50P24Q8@2
08:2PP80PH610P1oOgl207inOP80OGem0P1kNg/207YjNP80N7Qh0P1gMgL207IfMP80M7Ad00<0Lg=c
079bLP1bLW800P1aLG4206m_K`80KVi^0P1]KFd206][J`80JVYZ5@3oool001<0oooo0P1XJ6P206MW
I`80IVIV0P1UIFD206ATI080Hf=S0P1RHV83065QH@80H61P0P1OGel205iNGP@0GEeM0P1LG5`205]K
F`@0FUYJ101IFET205QHF0@0EeMG0`1FEUH:05EEE@80E5AD1P1EEED405IFEP80EeMG0P1HF5P205YJ
FP80Fe]K00<0GEeM05mOG`1OGel0101QHF4206ATI080IFEU0P1WIfL206YZJP80Jf][0P1/K6`206e]
K@80KVi^101_Kfl2071`L080LG5a00<0LW9b07AdM01dM7@00P1gMgL207UiN@80Ng]k0P1mOGd20861
P@80Q8B40P27QhL208^;R`80Shn?0P2CTi<209FEU@80UiNG0P2HV9P209ZJVP0309bLW02MWId0WIfM
0080WYjN102OWil80:2PX0@0WinO0P2NWYh409fMW@80W9bL0P2KVi/00`2JVYX0VIVI09VIV@0209RH
V080UiNG0P2FUYH209BDU080Ti>C0P2BTY82096AT@80T92@0P2>SXh208f=S@80S8b<0P2:RXX208V9
R@80R8R800<0QhN708F5Q@25QHD00P24Q8@208>3P`80PX:20P20P80207moO`80OWin0P1mOGd207]k
N`80NWYj0P1hN7P207MgM`80MWIf0P1eMGD207AdM003079bLP1aLG40LG5a0080L71`0P1_Kfl206e]
K@80K6a/0P1[Jf/206YZJQD0oooo000C0?ooo`80J6QX0P1WIfL206IVIP80IFEU0P1TI6@206=SH`80
HV9R0`1QHF42061PH080GemO0P1NGUh405eMG@80G5aL0P1KFe/405YJFP@0FEUI0P1HF5P405MGE`<0
EUIF2P1EEED205ADE0H0EEEE101FEUH205MGE`80F5QH0P1JFUX205]KF`0305eMG@1OGel0GemO00@0
HF5Q0P1TI6@206EUI@80IfMW0P1ZJVX206][J`80K6a/0P1]KFd206i^KP@0Kfm_0P1`L702075aL@03
079bLP1dM7@0M7Ad0080MgMg0P1iNGT207]kN`80OGem0P21PH4208B4Q080QhN70P2;Rh/208n?S`80
Ti>C0P2EUID209NGU`80V9RH0P2JVYX00`2LW9`0WIfM09fMW@0209jNWP@0WinO202PX:0409nOW`80
WYjN102MWId209bLW080Vi^K00<0VYZJ09VIV@2IVIT00P2HV9P209NGU`80UYJF0P2DU9@209>CT`80
TY:B0P2ATI42092@T080SXj>0P2=SHd208b<S080RXZ:0P29RHT208R8R00308N7Q`25QHD0QHF50080
Q8B40P23Ph<208:2PP80P8200P1oOgl207inOP80OGem0P1kNg/207YjNP80N7Qh0P1gMgL207IfMP80
MGEe0P1dM7@00`1bLW80LG5a075aL@02071`L080Kfm_0P1]KFd206a/K080Jf][0P1ZJVXE0?ooo`00
4`3oool206QXJ080IfMW0P1VIVH206EUI@@0I6AT0P1SHf<2069RHP<0HF5Q0P1PH60205mOG`@0GUiN
0P1MGEd405aLG080Fe]K101JFUX405UIF@@0F5QH2@1GEeL405IFEPH0EeMG101HF5P205UIF@80FUYJ
0P1KFe/205eMG@0305iNGP1OGel0GemO0080HF5Q0P1RHV8206ATI080IFEU0P1XJ6P206YZJP80Jf][
0P1]KFd406i^KP@0Kfm_0P1`L702075aL@03079bLP1eMGD0MGEe0080MgMg0P1iNGT207]kN`80OGem
0P20P80208B4Q080QhN70P2:RXX208f=S@80Shn?0P2ATI4209>CT`80U9BD0P2EUID00`2GUiL0V9RH
09RHV00209VIV@@0VYZJ202KVi/609ZJVP80VIVI102HV9P209NGU`0309JFUP2EUID0UIFE0080U9BD
0P2CTi<209:BTP80TI6A0P2@T90208n?S`80SXj>0P2=SHd208^;R`80RXZ:0P29RHT208R8R080QhN7
0P26QXH00`24Q8@0Ph>308>3P`0208:2PP80PH610P20P80207inOP80OGem0P1lO7`207]kN`80NWYj
0P1hN7P207MgM`80MWIf0P1eMGD207AdM080Lg=c00<0LW9b075aL@1aLG400P1_Kfl206i^KP80KFe]
0P1/K6`206][J`80JVYZ5@3oool001<0oooo0P1XJ6P206MWI`80IVIV0P1UIFD406ATI080Hf=S0P1R
HV83065QH@80H61P0P1OGel405iNGP80GEeM101LG5`205]KF`@0FUYJ101IFET405QHF0T0EeMG101F
EUH605MGE`@0F5QH0P1IFET205YJFP80Fe]K0P1MGEd00`1NGUh0GemO05mOG`02065QH@80HV9R0P1T
I6@206EUI@80J6QX0P1ZJVX206][J`80KFe]101^KVh406m_K`80L71`0P1aLG400`1bLW80MGEe07Ee
M@0207MgM`80NGUi0P1kNg/207emO@80P8200P24Q8@208N7Q`80RXZ:0P2=SHd208n?S`80TI6A0P2C
Ti<209BDU080UIFE00<0UiNG09RHV02HV9P00P2IVIT409ZJVPP0Vi^K1P2JVYX209VIV@@0V9RH0P2G
UiL00`2FUYH0UIFE09FEU@0209BDU080Ti>C0P2BTY82096AT@80T92@0P2?Shl208j>SP80SHf=0P2;
Rh/208Z:RP80RHV90P28R8P208N7Q`80QXJ600<0Q8B408>3P`23Ph<00P22PX820861P@80P8200P1n
OWh207emO@80O7al0P1kNg/207YjNP80N7Qh0P1gMgL207IfMP80MGEe0P1dM7@207=cL`03079bLP1a
LG40LG5a0080Kfm_0P1^KVh206e]K@80K6a/0P1[Jf/206YZJQD0oooo000C0?ooo`80J6QX0P1WIfL4
06IVIP80IFEU0P1TI6@406=SH`03069RHP1QHF40HF5Q0080HF5Q0P1PH60405mOG`80GUiN101MGEd4
05aLG080Fe]K1P1JFUX705UIF@X0F5QH101IFET405YJFP80Fe]K0P1LG5`205eMG@80GUiN00<0GemO
061PH01PH6000P1RHV8206=SH`80IFEU0P1VIVH206QXJ080JVYZ0P1[Jf/206a/K080KFe]0P1^KVh4
06m_K`80L71`0P1aLG400`1cLg<0MGEe07EeM@0207MgM`80NGUi0P1kNg/207emO@80P8200P22PX82
08F5Q@80QhN70P29RHT208^;R`80SHf=0P2?Shl2092@T080TI6A00<0TY:B09>CT`2CTi<00P2DU9@2
09FEU@h0UYJF102EUID409BDU080Ti>C00<0TY:B096AT@2ATI400P2@T90208n?S`@0SXj>0P2=SHd2
08b<S0@0RXZ:0P29RHT208N7Q`80QXJ60P25QHD208B4Q080Ph>300<0PX:20861P@21PH400P20P802
07moO`80OWin0P1lO7`207]kN`80NWYj101iNGT207MgM`80MWIf0P1eMGD207AdM080Lg=c0P1bLW80
0`1aLG40L71`071`L00206m_K`80KVi^0P1]KFd206a/K080Jf][0P1ZJVXE0?ooo`004`3oool206QX
J080IfMW101VIVH206EUI@80I6AT101SHf<00`1RHV80HF5Q065QH@02065QH@80H61P101OGel205iN
GP@0GEeM101LG5`205]KF`H0FUYJ1`1IFET:05QHF0@0FEUI101JFUX205]KF`80G5aL0P1MGEd205iN
GP0305mOG`1PH600H61P0080HV9R0P1SHf<206EUI@80IVIV0P1XJ6P206YZJP80Jf][0P1/K6`206e]
K@80KVi^101_Kfl2071`L080LG5a00<0Lg=c07EeM@1eMGD00P1gMgL207UiN@80Ng]k0P1mOGd20820
P080PX:20P25QHD208N7Q`80RHV90P2;Rh/208f=S@80Shn?0P2@T902096AT@0309:BTP2CTi<0Ti>C
0080U9BD0P2EUID>09JFUP@0UIFE102DU9@209>CT`0309:BTP2ATI40TI6A0080T92@0P2?Shl408j>
SP80SHf=0P2<S8`408Z:RP80RHV90P27QhL208J6QP80QHF50P24Q8@208>3P`0308:2PP21PH40PH61
0080P8200P1oOgl207inOP80O7al0P1kNg/207YjNP@0NGUi0P1gMgL207IfMP80MGEe0P1dM7@207=c
L`80LW9b00<0LG5a071`L01`L7000P1_Kfl206i^KP80KFe]0P1/K6`206][J`80JVYZ5@3oool001<0
oooo0P1XJ6P406MWI`80IVIV101UIFD206ATI0<0Hf=S0P1RHV84065QH@@0H61P101OGel205iNGPH0
GEeM101LG5`505]KF`h0FUYJ1P1KFe/405aLG080GEeM0P1NGUh205mOG`03061PH01RHV80HV9R0080
Hf=S0P1TI6@206EUI@80IVIV0P1XJ6P206UYJ@80Jf][0P1/K6`406e]K@80KVi^0P1_Kfl2071`L080
LG5a00<0Lg=c07AdM01dM7@00P1fMWH207MgM`80NGUi0P1lO7`207inOP80P8200P22PX8208B4Q080
QXJ60P28R8P208Z:RP80Rh^;0P2<S8`208f=S@0308j>SP2?Shl0Shn?0080T92@102ATI4809:BTPP0
TI6A0P2@T90408n?S`0308j>SP2=SHd0SHf=00@0S8b<0P2;Rh/208Z:RP80RHV90P28R8P208N7Q`@0
QXJ60P25QHD208B4Q080Ph>30P22PX820861P@030820P01oOgl0Ogmo0080OWin0P1mOGd207alO0@0
NWYj0P1iNGT207QhN080MgMg0P1fMWH207EeM@80M7Ad0P1cLg<2079bLP80LG5a00<0L71`06m_K`1_
Kfl00P1^KVh406e]K@80Jf][101ZJVXE0?ooo`004`3oool206QXJ0@0IfMW0P1VIVH406EUI@80I6AT
0`1SHf<2069RHP@0HF5Q101PH60405mOG`80GUiN1P1MGEd405aLG0D0Fe]K3P1JFUX605]KF`@0G5aL
0P1MGEd205iNGP80GemO00<0H61P069RHP1RHV800P1SHf<206ATI080IFEU0P1VIVH206QXJ080JFUY
0P1[Jf/206a/K0@0KFe]0P1^KVh206m_K`80L71`0P1aLG400`1cLg<0M7Ad07AdM00207IfMP80MgMg
0P1iNGT207alO080OWin0P20P80208:2PP80Q8B40P26QXH208R8R080RXZ:0P2;Rh/208b<S080SHf=
00<0SXj>08n?S`2?Shl00P2@T904096AT@P0TY:B202ATI42092@T0@0Shn?00<0SXj>08f=S@2=SHd0
102<S8`208^;R`80RXZ:0P29RHT208R8R080QhN71026QXH208F5Q@80Q8B40P23Ph<208:2PP80PH61
00<0P82007moO`1oOgl00P1nOWh207emO@80O7al101jNWX207UiN@80N7Qh0P1gMgL207IfMP80MGEe
0P1dM7@207=cL`80LW9b0P1aLG400`1`L700Kfm_06m_K`0206i^KP@0KFe]0P1[Jf/406YZJQD0oooo
000C0?ooo`80J6QX101WIfL406IVIP80IFEU101TI6@306=SH`@0HV9R101QHF44061PH0@0GemO101N
GUh605eMGAD0G5aL101MGEd205iNGP80GemO0P1PH603065QH@80HV9R0P1SHf<206ATI080IFEU0P1W
IfL206QXJ080JFUY0P1ZJVX206][J`80K6a/0P1]KFd206i^KP80Kfm_0P1`L702075aL@03079bLP1c
Lg<0Lg=c0080MGEe0P1fMWH207QhN080NWYj0P1lO7`207inOP80Ogmo0P21PH4208>3P`80QHF50P26
QXH208N7Q`80R8R80P29RHT00`2:RXX0Rh^;08^;R`0208^;R`80S8b<402=SHd408b<S0@0Rh^;00<0
RXZ:08V9R@29RHT00P29RHT208R8R0@0QhN70P26QXH208F5Q@80Q8B41023Ph<208:2PP80PH610P20
P80207moO`80OWin00<0OGem07alO01lO7`00P1lO7`207]kN`80NWYj0P1iNGT207QhN080MgMg101f
MWH207EeM@80M7Ad101bLW82075aL@80L71`0`1_Kfl206i^KP80KFe]0P1/K6`206][J`80JVYZ0P1Y
JFTE0?ooo`004`3oool206QXJ0@0IfMW101VIVH206EUI@@0I6AT0`1SHf<4069RHP@0HF5Q101PH604
05mOG`@0GUiN1P1MGEdE05aLG0@0GEeM0P1NGUh205mOG`80H61P0`1QHF42069RHP80Hf=S0P1TI6@2
06EUI@80IfMW0P1XJ6P206UYJ@80JVYZ0P1[Jf/206a/K080KFe]0P1^KVh206m_K`80L71`0P1aLG40
0`1bLW80Lg=c07=cL`0207EeM@80MWIf0P1hN7P207YjNP80O7al0P1nOWh207moO`80PH610P23Ph<2
08F5Q@80QXJ60P27QhL208R8R080RHV900<0RXZ:08^;R`2;Rh/00P2;Rh/208b<S100SHf=102<S8`4
08^;R`0308Z:RP29RHT0RHV90080RHV90P28R8P408N7Q`80QXJ60P25QHD208B4Q0@0Ph>30P22PX82
0861P@80P8200P1oOgl207inOP0307emO@1lO7`0O7al0080O7al0P1kNg/207YjNP80NGUi0P1hN7P2
07MgM`@0MWIf0P1eMGD207AdM0@0LW9b0P1aLG42071`L0<0Kfm_0P1^KVh206e]K@80K6a/0P1[Jf/2
06YZJP80JFUY5@3oool001<0oooo101XJ6P206MWI`@0IVIV101UIFD306ATI0@0Hf=S1P1RHV84065Q
H@@0H61P201OGel505iNGP`0GEeM201NGUh205mOG`@0H61P0P1QHF43069RHP80Hf=S0P1TI6@206EU
I@80IVIV0P1WIfL206QXJ080JFUY0P1ZJVX206][J`80K6a/101]KFd206i^KP80Kfm_0P1`L7000`1a
LG40LW9b079bLP0207AdM080MGEe0P1fMWH207QhN080NWYj0P1kNg/207emO@80OWin0P20P8020861
P@80PX:20P23Ph<408F5Q@0308J6QP27QhL0QhN70080QhN70P28R8P>08V9R@H0R8R81027QhL308J6
QP@0QHF50P24Q8@408>3P`80PX:20P21PH440820P080Ogmo101nOWh207emO@80O7al00<0Ng]k07Yj
NP1jNWX00P1iNGT407QhN080MgMg0P1fMWH407EeM@80M7Ad101cLg<4075aL@80L71`0`1_Kfl206i^
KP80KFe]101/K6`206][J`80JVYZ0P1YJFTE0?ooo`004`3oool406QXJ0@0IfMW101VIVH406EUI@D0
I6AT101SHf<6069RHPH0HF5Q201PH60E05mOG`@0H61P101QHF44069RHP0306=SH`1TI6@0I6AT00@0
IFEU0P1VIVH206MWI`80J6QX0P1YJFT206YZJP@0Jf][0P1/K6`206e]K@@0KVi^0P1_Kfl00`1`L700
LG5a075aL@02079bLP80M7Ad0P1eMGD207IfMP80N7Qh0P1iNGT207YjNP80Ng]k0P1mOGd207inOP80
Ogmo0P20P8020861P@<0PX:21023Ph<608B4Q0P0QHF52024Q8@408>3P`D0PX:21021PH420820P0@0
Ogmo0P1nOWh407emO@80O7al101kNg/207YjNP<0NGUi0P1hN7P207MgM`@0MWIf0P1eMGD407AdM0@0
Lg=c0P1bLW84075aL@80L71`0P1_Kfl306i^KP@0KFe]0P1/K6`206][J`@0JVYZ0P1YJFTE0?ooo`00
4`3oool406QXJ0@0IfMW101VIVH406EUI@D0I6AT101SHf<6069RHPH0HF5Q201PH60E05mOG`@0H61P
101QHF44069RHP0306=SH`1TI6@0I6AT00@0IFEU0P1VIVH206MWI`80J6QX0P1YJFT206YZJP@0Jf][
0P1/K6`206e]K@@0KVi^0P1_Kfl00`1`L700LG5a075aL@02079bLP80M7Ad0P1eMGD207IfMP80N7Qh
0P1iNGT207YjNP80Ng]k0P1mOGd207inOP80Ogmo0P20P8020861P@<0PX:21023Ph<608B4Q0P0QHF5
2024Q8@408>3P`D0PX:21021PH420820P0@0Ogmo0P1nOWh407emO@80O7al101kNg/207YjNP<0NGUi
0P1hN7P207MgM`@0MWIf0P1eMGD407AdM0@0Lg=c0P1bLW84075aL@80L71`0P1_Kfl306i^KP@0KFe]
0P1/K6`206][J`@0JVYZ0P1YJFTE0?ooo`004`3oool406QXJ0H0IfMW101VIVH506EUI@H0I6AT1P1S
Hf<8069RHPH0HF5Q3`1PH608065QH@H0HV9R101SHf<00`1TI6@0IFEU06EUI@0206EUI@80IVIV101W
IfL206QXJ080JFUY101ZJVX206][J`80K6a/101]KFd406i^KP0306m_K`1`L700L71`0080LG5a0P1b
LW8207=cL`80M7Ad0P1eMGD407MgM`80NGUi0P1jNWX207]kN`@0O7al0P1mOGd307inOP@0Ogmo2020
P8020861P@`0P8201@1oOgl407inOPH0OGem101lO7`207]kN`@0NWYj101iNGT407QhN080MgMg0`1f
MWH207EeM@@0M7Ad101cLg<4079bLP@0LG5a101`L70206m_K`@0KVi^0`1]KFd206a/K0@0Jf][101Z
JVX206UYJAD0oooo000C0?ooo`@0J6QX1P1WIfL406IVIPD0IFEU1P1TI6@606=SH`P0HV9R1P1QHF4?
061PH0P0HF5Q1P1RHV8406=SH`0306ATI01UIFD0IFEU0080IFEU0P1VIVH406MWI`80J6QX0P1YJFT4
06YZJP80Jf][0P1/K6`406e]K@@0KVi^00<0Kfm_071`L01`L7000P1aLG42079bLP80Lg=c0P1dM7@2
07EeM@@0MgMg0P1iNGT207YjNP80Ng]k101lO7`207emO@<0OWin101oOgl80820P080PH613020P805
07moO`@0OWin1P1mOGd407alO080Ng]k101jNWX407UiN@@0N7Qh0P1gMgL307IfMP80MGEe101dM7@4
07=cL`@0LW9b101aLG44071`L080Kfm_101^KVh306e]K@80K6a/101[Jf/406YZJP80JFUY5@3oool0
01<0oooo1P1XJ6P606MWI`D0IVIV201UIFD606ATI0X0Hf=S6@1RHV8806=SH`@0I6AT0`1UIFD206IV
IP@0IfMW101XJ6P406UYJ@80JVYZ101[Jf/406a/K080KFe]0P1^KVh306m_K`80L71`101aLG42079b
LP80Lg=c0P1dM7@207EeM@80MWIf0P1gMgL407QhN080NGUi101jNWX507]kN`@0O7al0P1mOGd207al
O080OGem301lO7`707]kN`H0NWYj101iNGT407QhN0H0MgMg101fMWH407EeM@0307AdM01cLg<0Lg=c
0080Lg=c1P1bLW84075aL@@0L71`101_Kfl406i^KP@0KFe]0`1/K6`406][J`H0JVYZ0P1YJFTE0?oo
o`004`3oool606QXJ0H0IfMW1@1VIVH806EUI@H0I6AT2P1SHf<I069RHPP0Hf=S101TI6@306EUI@80
IVIV101WIfL406QXJ0@0JFUY0P1ZJVX406][J`@0K6a/0P1]KFd206i^KP<0Kfm_0P1`L704075aL@80
LW9b0P1cLg<207AdM080MGEe0P1fMWH207MgM`@0N7Qh0P1iNGT407YjNPD0Ng]k101lO7`207emO@80
O7al0P1mOGd<07alO0L0Ng]k1P1jNWX407UiN@@0N7Qh1P1gMgL407IfMP@0MGEe00<0M7Ad07=cL`1c
Lg<00P1cLg<6079bLP@0LG5a101`L70406m_K`@0KVi^101]KFd306a/K0@0Jf][1P1ZJVX206UYJAD0
oooo000C0?ooo`P0J6QX201WIfL706IVIPX0IFEU2P1TI6@E06=SH`X0I6AT101UIFD306IVIP@0IfMW
1P1XJ6P406UYJ@@0JVYZ101[Jf/406a/K0<0KFe]101^KVh206m_K`@0L71`0P1aLG42079bLP@0Lg=c
0P1dM7@407EeM@@0MWIf1@1gMgLL07QhN0L0MgMg101fMWH607EeM@H0M7Ad1P1cLg<3079bLP@0LG5a
1P1`L70406m_K`P0KVi^101]KFd506a/K0@0Jf][1P1ZJVX406UYJAD0oooo000C0?ooo`P0J6QX201W
IfL706IVIPX0IFEU2P1TI6@E06=SH`X0I6AT101UIFD306IVIP@0IfMW1P1XJ6P406UYJ@@0JVYZ101[
Jf/406a/K0<0KFe]101^KVh206m_K`@0L71`0P1aLG42079bLP@0Lg=c0P1dM7@407EeM@@0MWIf1@1g
MgLL07QhN0L0MgMg101fMWH607EeM@H0M7Ad1P1cLg<3079bLP@0LG5a1P1`L70406m_K`P0KVi^101]
KFd506a/K0@0Jf][1P1ZJVX406UYJAD0oooo000C0?ooo`X0J6QX2@1WIfL>06IVIRL0IFEU1`1VIVH6
06MWI`H0J6QX1P1YJFT406YZJPH0Jf][0`1/K6`606e]K@@0KVi^0P1_Kfl4071`L0@0LG5a1P1bLW85
07=cLb40M7Ad201cLg<8079bLPH0LG5a1P1`L70706m_K`H0KVi^201]KFd606a/K0L0Jf][201ZJVX4
06UYJAD0oooo000C0?ooo`X0J6QX2@1WIfL>06IVIRL0IFEU1`1VIVH606MWI`H0J6QX1P1YJFT406YZ
JPH0Jf][0`1/K6`606e]K@@0KVi^0P1_Kfl4071`L0@0LG5a1P1bLW8507=cLb40M7Ad201cLg<8079b
LPH0LG5a1P1`L70706m_K`H0KVi^201]KFd606a/K0L0Jf][201ZJVX406UYJAD0oooo000C0?oooa00
J6QX5@1WIfLU06IVIPD0IfMW301XJ6P806UYJ@H0JVYZ2@1[Jf/606a/K0@0KFe]201^KVh606m_K`d0
L71`0P1aLG46071`L080LG5a4@1`L70<06m_K`X0KVi^2@1]KFd606a/K080Jf][0P1/K6`:06][J`T0
JVYZ2P1YJFTE0?ooo`004`3oool@06QXJ1D0IfMW9@1VIVH506MWI``0J6QX201YJFT606YZJPT0Jf][
1P1/K6`406e]K@P0KVi^1P1_Kfl=071`L080LG5a1P1`L702075aLA40L71`301_Kfl:06i^KPT0KFe]
1P1/K6`206][J`80K6a/2P1[Jf/906YZJPX0JFUY5@3oool001<0oooo0P1YJFTS06QXJ2<0IfMW3`1X
J6P206UYJ@80J6QX3P1YJFT?06YZJPH0Jf][0P1/K6`406][Ja40K6a/101]KFd606a/K080KFe]7`1/
K6`E06][Ja@0JVYZ3`1YJFTE0?ooo`004`3oool206UYJB<0J6QX8`1WIfL?06QXJ080JFUY0P1XJ6P>
06UYJ@l0JVYZ1P1[Jf/206a/K0@0Jf][4@1/K6`406e]K@H0K6a/0P1]KFdO06a/K1D0Jf][501ZJVX?
06UYJAD0oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o
0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o
0?ooob40oooo002E0?ooo`900000R@3oool009L0oooo00=000000?ooo`3oool0QP3oool007h0oooo
0T0000040?ooo`03@000003oool0oooo00@0oooo0d0000020?ooo`9000000`3oool3@00000D0oooo
00=000000?ooo`3oool0P03oool007h0oooo00=000000?oood0000000P3oool00d000000oooo@000
00040?ooo`06@000003oool0oooo@000003ooom00000103oool014000000oooo0?oood0000280?oo
o`00OP3oool00d000000oooo@00000020?ooo`03@000003ooom0000000@0oooo00E000000?ooo`3o
oom000000?ooo`03@0000080oooo00A000000?ooo`3ooom00000R03oool007h0oooo0T0000030?oo
o`03@000003ooom0000000D0oooo0d000000103ooom00000@000040000030?ooo`=00000R03oool0
07h0oooo00=000000?ooo`3oool00P3oool00d000000oooo@00000070?ooo`03@000003oool0oooo
0900oooo001o0?ooo`9000000`3oool00d000000oooo0?ooo`050?ooo`900000TP3oool00?l0oooo
8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo
8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.0250052, -0.0250052, 
  0.00365857, 0.00365857}, {{6.8125, 280.125}, {280.125, 
  6.8125}} -> {-10.161, -6.11446, 0.516914, 0.516914}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0238095 0.952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0238095 0.97619 0.97619 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00751202 0.0192308 0.00751202 [
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(120) show
81.000000 12.812500 moveto
(deg) show
99.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(.) show
105.000000 12.812500 moveto
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
128 string
128 128 8 [128 0 0 128 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
4F4F4F4F4F4F4F4F4F4F4F4F505050504F4F4F4F4F4F4E4D
4F4E4E4D4D4D4C4C4C4C4B4B4B4B4B4B4B4B4B4B4B4B4B4B
4B4B4B4B4B4B4B4B4B4B4B4B4B4B4B4C4C4B4C4C4C4C4C4B
4B4B4B4B4B4B4B4B4B4B4B4B4B4B4B4C4C4C4C4C4C4C4C4C
4C4C4C4C4C4C4C4C4D4C4D4D4D4D4D4E4E4F4F5050505151
515050505050504F
4F4F4F4E4F4F4F4F4F4F5050515150504F4F4F4E4E4D4D4D
4F4D4C4C4B4A494948484747474746464646464646464747
484847474747474747474747474748484848484848484848
484848484747474747474747464748484849484949494949
4949494A4A494A4A4A4A4A4A4B4B4C4C4D4E4F5151525253
535150515151504F
4F4F4F4F4F4F4F4F4F4F505051515150504F4F4E4D4D4D4E
4D4B4B4A4947474645444343434242414142424242434344
444444444444444343434343444444454545454545444444
444444444444444443434343424345484645454546474646
46464646474747474748484949494A4B4C4D4F5152535353
5252525252515150
4F4F4F4F4F4F4F4F4F4F4F4F50515251504F4F4E4D4D4C4C
4D4C4A484746444341403F3F3E3E3D3D3D3D3D3E3E404041
414242414141414040404040404041414141414141404040
4040404040404040403F3F3F3F3F40424343424343434344
434344444444444445454646474748494B4D4F5153535353
5252525353525150
4F4F4F4F4E4E4E4E4E4E4E4F4F50505151504F4E4E4D4C4C
4B4A4947454341403E3D3B3A39393939393939393B3C3D3E
3F3F403F3F3E3E3D3D3D3D3D3D3D3D3D3C3C3C3C3C3C3C3C
3C3C3C3C3C3C3C3C3C3C3B3C3C3C3C3D3E3F403F40404040
404040414141414242424344444546484A4C4E5152525252
5253535454545251
4F4F4F4E4E4E4E4E4D4D4D4D4E4F4F4F50504F4E4D4D4C4A
4949484543413F3D3A39373635343333333435363738393B
3C3C3D3D3D3C3B3B3B3B3A3A3A3A3A393939393837373737
37373737373737373737373738383839393B3D3C3C3C3C3C
3C3C3C3D3D3E3E3E3F40404142434445474A4D4F4F4F5050
5153535556545251
4F4F4F4E4E4E4D4D4D4D4C4D4D4D4D4D4E4E4E4E4D4C4B4A
48474543403D3B3937343231302F2F2E2F30313233353637
38393A3A3A3A393939383837373636363635353433333333
333232333333333333333333343434353536383939383737
37383839393A3A3B3C3C3D3E3F40424446494D4D4E4E5051
5253545656545251
4F4F4E4E4D4D4D4C4C4C4B4B4B4B4B4B4B4B4B4C4B4A4948
464442403C3A373532302E2C2B2A2A2B2C2D2E2F30313234
3536363737373737363636363534343332323130302F2F2F
2F2E2E2E2E2E2E2F2F2F2F2F303031313132323333333333
333434353536373838393A3B3C3E4144474B4C4C4D4E5152
5354555656545251
4F4F4E4E4D4D4C4B4B4B4B4A4A4A49494949494949484746
4442403E3C3934302E2B29282726272728292B2C2D2E2F30
3132333434353535353534343333333231302F2E2D2D2C2C
2C2B2B2B2B2B2B2B2B2C2C2D2D2E2E2E2E2E2E2E2F30302F
2F30303132323334343537383A3E42474A4B4D4E50515355
5656575756545351
4F4E4E4D4C4C4B4B4A4A4949494848474746464645444341
403E3B393735302B292624222222222223242627292A2C2D
2E2F30313131323232323232313131302F2F2E2E2D2D2C2B
2B2B2A2A2A2A2A2A2A2B2B2B2B2B2C2C2C2C2C2C2D2D2E2F
2F2D2D2E2F2F3030313133363B4146494C4E4F5052545556
5757585857555351
4E4E4D4D4C4B4A4A4A494948484746454544434342413F3E
3C393735322F2C2824201E1D1C1C1D1E1F2122242627292A
2B2C2D2E2E2F2F303030302F2F2E2E2D2D2C2B2B2B2A2A29
292828282827272727282828282828282929292A2A2A2B2B
2D2F312E2D2D2D2E3034393D4145484B4D51525254555759
595A5B5958555351
4F4E4D4C4C4B4A4A4948484746454444434241403F3D3C3A
383633312E2B2826211D1A17151617181A1C1E2022242628
292A2B2B2C2C2C2D2D2D2D2C2C2C2B2A2A29292827272626
262525242424242424242424242425252526262627272828
292A2B2C2E302F31363A3E4246484A4D5053525456585A5B
5B5D5C5B59565452
4E4E4D4C4B4A4949484746454544434241403E3D3C3A3836
3432302E2B2825221F1A16120F0F111315181A1D1F212425
27282829292A2A2A2B2B2B2A292928282727262525242322
222221212120202020212121212122222222222323242425
262728292A2D32383C4044474A4D5052545556585A5B5D5D
5E5E5D5C59575552
4E4D4C4B4B4A494847464544434241403F3D3C3A39373533
312F2D2A2724221F1C17130F0D0A0A0D101316191C1F2123
24262627272828282828282726262525242423222221201F
1F1E1E1E1D1D1D1D1D1D1D1D1D1E1E1F1F1F1F2020212223
2425272A2E34393E4246484B4F5154555758595C5E5F6060
60605E5C5A575452
4E4D4C4B4A4948474645444342403F3E3C3B393836343230
2E2C2A2724211E1B1713100D0B0906070B0F13171A1D1F21
23242525252626262626252524242322212120201F1E1D1C
1C1B1B1A1A19191919191A1A1A1B1B1B1C1C1D1D1D1E2021
2326292E353A3E42474B4E51535557585A5C5F6163636262
63615F5C5A575552
4E4D4C4B4A49474645444342403F3D3C3A3938363432302D
2B292624211E1A1714110E0C0A080706080C1014181B1E20
222223242424242424242323222120201F1E1D1D1C1B1A19
191817171716161616161616171718181819191A1B1C1E21
23272C333B3F43474B4F535657585B5D5F61636466666566
64625F5D5B585552
4E4D4C4B4A484746454341403F3D3C3A39373533322F2D2B
282623201D1A1714110E0B0A0808080806080D12161A1D1F
20212222232323232222222120201F1E1D1C1B1A19181717
161514141313131313131313141415151617191A1B1D1F22
262C343B3F43484D505355585B5E60626465676767676868
6663605E5B585552
4E4D4C4B494847454442403F3D3C3A39373533312F2D2B29
2623211E1B1714100D0A09090808090909080B11161A1D1F
20212222222222222121201F1E1E1D1C1B1A191817161514
141312111010101011111111111213141516181A1C1E2227
2D353C4144474C505355585C5F626567686A6A6B6B6B6B69
6765625F5C595652
4E4D4B4A494746444341403E3C3B39373634312F2D2B2926
24211E1B1815110E0B08080808090A0B0B0D0D11171B1D1F
2021222222222121201F1F1E1D1C1B1A1918171614141312
11100F0F0E0E0D0E0E0E0E0F0F1011131416181A1D22272E
353B4144484C5054575B5E616467696B6C6D6D6E6E6D6B6A
6865625F5C585552
4E4D4B494846454442403E3D3C3A37353432302D2B292624
211F1C1915120F0B08060607080A0C0D0E111418191C1F20
21222222222121201F1E1D1D1C1B1A191816151412121110
0F0E0D0C0C0B0B0C0D0D0D0D0D0F101214171A1E23292F36
3B4045484C5054575B5E6164676A6C6E6F707071706F6E6B
6966625F5C595652
4E4C4B4947464443413F3E3C3A38373432302D2B29272422
1F1C1916130F0C0905040607090B0D0F121518191B1F2122
232323222221201F1E1E1D1C1A1918171615141211100F0E
0D0C0B0A0A0A0A0B0C0B0A0B0D0F1113161A1E232A31373C
42474A4D5054585A5D606467696C6F717272737372716F6C
6965625F5C595652
4E4C4A4947464442413F3D3B39373533312E2C2A27252220
1D1A1714100D0A0604040507090C0E1115191B1D20222324
242423222221201F1E1D1C1B1918171615131211100F0E0C
0B0A0A0908090A0A0A090A0D0E101214191F242A30363B40
45494D5154575B5E6264686A6D7073737475757573716F6C
6966635F5C595652
4D4C4A4947454342403E3C3A383634312F2D2B282623211E
1B1815120F0B080403030507090C0F13181C1E2025262625
252524232322201F1E1C1B1A19171615131211100E0D0C0B
0A0908080808090907080A0D0F1115191F262B31363B3F44
494D5154595D606265676A6D707375767778787674716F6C
6966625F5C595652
4D4C4A48464442413F3D3B39373532302E2B292724221F1C
191613100C090603030306080B0E11161A1D202429292928
27272625242221201E1C1B1A181615141311100F0E0D0C0B
0A08080708080807080A0C0F11151920262C32383C41464A
4E5154585D616365686B6E71747778797A7A787674716F6B
6966625F5C595652
4D4B4A48464442403E3C3A383533312F2C2A282522201D1A
1714110D0A070402030406090C1014191B1E22272C2C2B2A
29292826242322201E1D1B19181615141211100F0E0C0B0B
0A09080809090908090C0E11151A20252C32373D42474A4D
5154585C606367696C6F727477797A7B7C7B797774726F6C
6966625F5C595552
4D4B49474543413F3D3B39373432302D2B292623211E1B18
15120F0C090603010204070A0E11161A1C20262B302F2E2D
2C2B292827252321201E1C1A191715141312100F0E0D0C0B
0A0A09090A0A090A0C0F12151A1F242A31373D42474B4F51
54585C5F6366696B6F7274787A7B7D7D7C7A787775726F6C
6966625F5C595652
4D4B49474542403E3C3A383633312E2C292724211F1C1916
13100D0A070401010204070B0F13181C20242A2F33323130
2F2D2C2A2927252321201E1C1A181615141211100F0E0D0C
0B0A0A0B0B0B0C0E1013161B20242A31373C41464B4F5356
595C5F6366696C6F7273767A7C7E7E7E7C7B797775726F6C
6966625F5C595652
4D4B48464442403E3C39373432302D2B282522201D1B1815
120F0C08050200010305090E11161B1F22282D3237363533
32302F2D2B2928262422201E1C1A181615131211100F0E0D
0C0C0C0D0D0D0E1115181C20242A31373C41464B5054585A
5D606466696C6F717376797D7F80807F7D7B797775726F6C
6965625F5C595652
4D4B494644423F3D3B393634312F2C292724211F1C191613
100D0A070401000103070A0F14191D21262D33373B3A3938
363432302E2D2B29272523211F1D1B19171614131211100F
0E0E0E0F10111316191D2023282F363D42464A4E53575B5F
6265686A6C6F717375797D808182817F7E7C7A7874716F6C
6865625F5C595652
4D4B484644413F3D3B383533302E2B282523201D1A181511
0E0C08050200000204080D12171C20262C33393D413F3E3C
3A38363433312F2D2B29262422201E1C1A19171514131211
111212131415181C1E21242930373E4245494D52575B5F61
65696B6D6F727376797C8083848381807E7D7A7875726F6B
6865625F5C595552
4D4A484543413E3C3A3734322F2D2A2724221F1C19161310
0D0A070401000002060A10151A1F242B32393F4346454341
3F3C3A39373533312F2D2B29262422201E1C1A1917161515
14141517181A1E2123262B31383F43474B4E52565A5E6164
686B6D6F7275777A7D818385858482817F7D7A7875726F6B
6865625F5C595652
4C4A484543413E3C393734312E2C292624211E1B1815120F
0B08060300000104080D13191E2429313940454A4D4B4845
43403E3C3A3836353332302E2C29272523201E1C1B1A1919
19191A1B1D212526292D323A3F43484B4F52565A5E616569
6B6D6F717477797D8083858786848382807D7A7774716E6B
6865625F5C595552
4D4A484543413E3B393633312E2B282522201D1A1714110D
0A070501000002060B0F151B22282F3940474D52534F4B47
44423F3E3C3A39373634333231302D2B28262422201F1E1D
1D1D1E2023282C2D30343A4045494D5053575A5E6164686B
6D6F717577797C808385878786848382807D7A7774716E6B
6865625F5C595653
4C4A484543403D3B383533302D2A2724211F1C1916130F0C
09060301000104080D131A20262D3640474F575A56504C48
4542403E3C3A393837363535343333312E2C292726242322
21222325292E3234373B40464B4F5255585C5F6265686B6E
70717477797B7F828486898886868582807D7A7774716E6B
6865625F5C585552
4D4A484542403D3A3734322F2C292623211E1B1815120E0B
080502000002060A0F161D242B333D464E595D5A544F4B47
44423F3D3B3A3938383837373636363534322F2D2B292827
2627282B3033383C4044484C505457595C5F6265676A6C6F
717477797C7E82848688898888878582807D7A7774716E6B
6865625F5C595652
4D4A4745423F3D3A3734312E2B282623201D1A1714100D0A
070401000104080D131A21283039444C565B5956524E4A46
43403E3D3B393838383737383838383838373634312F2D2C
2C2C2E31353A3E41464A4F54575A5D5E606264676A6C6E71
7476787B7E81848688898A8A89878582807D7A7774716E6B
6865625F5C595552
4C4A4744423F3C393634312E2B2825221F1C1915120F0B08
0503010102060A10161E252D36414B545B5B5854504C4844
413E3C3B39383837373839393A3A3B3B3B3B3B3938353332
313133353A3E42474D5356585A5C5E60636567696B6E7073
76787B7E81848587898B8C8B89878582807D7A7774716E6B
6865625F5C585552
4D4A4744423F3C393633302D2A2725211E1B1814110E0B07
0402010103070C131A232A333D49535B5D5956524E4A4642
3F3D3B39383736363737383A3B3C3D3E3E3E3E3E3E3C3938
3737383B3E41464B50555A5E5E6062646567696B6E717375
777B7F81838687898C8D8E8C8A878583807D7A7774726E6B
6865625F5C595652
4D4A4744413E3C393633302D2A2724211D1A1613100D0906
0301010105090F161E272F39444F5A5D5B5854504C484441
3E3C3A38373636373738393B3D3E4040414141424242413F
3D3D3D3F4245494F53595E6062636567696A6C6F71737577
7A7E80848788898B8D8E8D8C8A888583807D7A7774716E6B
6865625F5C595652
4C494744413E3B3936332F2D292623201C1916120F0B0805
03010103070C131A232C35414C585E5B5956534F4B474341
3F3D3C3A39393838393A3B3D3F4142434444454545454544
4242424345484C50545A5E626668686A6B6D6F7173747779
7B7F828587898B8D8E8F8D8C8A888683807D7A7875726F6C
6965625F5C595552
4C494744413E3B3835322F2C2925221F1C1815110E0A0704
02010104080F161F28313C47525A5B5A5855524E4A464342
4140403F3E3D3C3B3B3C3E40424445464748484848484849
49474747494B4E52585B5F63666A6C6C6D6F70727476787A
7D808385888A8C8F908F8E8C8A888683807D7B7875726F6C
6966625F5C595552
4C494643413E3B3835322E2B2825211E1B1714110D090603
010001050B121A232D37434E5A5E5B5A5855524D4A49494A
4946454444424242434343444647494A4A4B4B4B4B4C4C4D
4E4E4C4C4D4E4F53585B5E61656A6D6F707072757677797C
7E818486888A8D8F91918F8D8B898683807E7B7875726F6C
6965625F5C595652
4C494643403D3A3734312E2B2824211E1A1713100C080401
000002070E151E28323D49555C5C5C5A585653504E4E4D4B
4949494745454647484949494A4C4D4D4E4E4E4E4E4F4F50
5152515150515356575A5E6165686D707173757577797B7D
7F8285878A8D8F9092918F8D8B898684817E7B7875726F6C
6966635F5C595652
4C494643403D3A3734312E2B2824211D1A16130F0B070401
0002050A111A232D3844505B5E5C5C5B5957555353525252
51504F4F4E4D4E4F4E4F5050505051515151505151515253
5354545353555556585C5D6063676B70737576777A7B7C7E
818486898C8F909293918F8D8C898784817E7B7875726F6C
6966625F5C595652
4C494643403D3A3734312E2B2724211D1916120E0A060301
0103070D161F28333F4A575D5C5C5C5C5B5B5D5D5D5E5D5C
5C5B5B5A5A5B5C5B5C5D5E5E5D5B57555453535354545455
55565657575757595A5B5E606266696E727577797B7C7E80
8385878A8C8F91949492908E8C8A8784817F7C7975726F6C
6966625F5C595652
4C494643403D3B3734312E2B2724201D1915110D09060301
02050B121A232D38434F585B5C5C5C5D5D5E5F6164666666
6564636364646464636361605F5D5A585756565655565656
57585859595A5B5B5B5C5D5F6265686C7175797B7C7D7F82
8485888B8D9091949492918F8D8B8885827F7C7976736F6C
696663605C595652
4C494743403D3A3734312E2B2723201C1915110D09050202
03080E151E27323D48545B5B5C5D5D5E5E5F606162636464
636261616160616161616160605E5C5B5A59585857575758
5859595A5A5C5D5D5E5F606162666A6D7075797B7D808182
84878B8D8E919396959391908E8B8885827F7C797673706D
696663605C595652
4C494643403D3A3734312E2A2724201C1815110D09050302
060C131A232D37414B565A5B5C5D5E5E5F5F606161616261
61605F5F5F5F5F6060616161605F5E5D5B5B5A5A5959595A
5A5A5B5B5D5E5D5D5E5E5F616567696C7074777B7F818385
878A8C8E90929596959492908E8B8986837F7C7A7673706D
6966635F5C595653
4C494644413E3B3734312E2A2724201C1915110C08050406
0A10171F28313B454F575A5C5D5E5E5F5F60606060606060
5F5E5D5D5D5D5E5F5F60606160605F5F5E5D5C5B5B5B5B5B
5B5B5B5C5D5E5F60606162646667696D7073797D7F828487
8A8D8E9092949798979594928F8C898683807D7A7773706D
696663605D595652
4C494744413E3A3734312D2A2723201C1815110C08050508
0D141B242D374049545B5B5D5E5E5F5F6060606060605F5E
5E5D5C5C5C5C5D5E5F5F60606161605F5E5E5E5D5D5D5C5D
5D5D5D5D5E5F60616162636567696C6E7277797D80848689
8B8E909395979A9897969593908D8A8683807D7A7774706D
6A6763605C595652
4C494744413E3A3734312E2A2723201D1915110D0907070B
10171F28313A444D585D5D5E5F5F5F60606060605F5F5E5E
5E5E5D5D5C5C5D5E5E5F60616161616060605F5F5F5E5E5E
5E5E5E5F60606060626365676A6C6F7174767A7F8385888B
8D8F9195979A9B9998969593908D8A8784817E7A7774716D
6A6763605D595652
4C494643403D3A3734312E2A2724201D1915110D09080A0F
151C242D373F47505A5D5E5F5F60606060606060605E5E5F
61605F5E5D5E5F5E5F606162626261616160606060606060
60606060616262646466676A6C6F717476787E818487898B
8E919497999B9B9B9A999794918E8B8784817E7B7774716E
6A6763605D595652
4C494643403D3B3834312E2B2724201D1915110D0A0A0E14
1A222A323B434C565E5F6060616060606060606060616363
626161626464636362626263636262616161616161616161
616162636364646667696B6D6F717477787D818387898C8E
919497999A9B9B9C9C9C9895928E8B8885817E7B7874716E
6A6764605D595653
4D4A4744413E3B3835312E2B2824211D1916120E0C0D1117
1E272F383F47515B61616161616161616060606060616263
626262626363636364646464636362626261616162626263
63636364656666696B6D6F717375777A7D8284878A8B8E91
9496999B9D9E9FA09F9C9996928F8C8885827E7B7875716E
6A6764605D5A5653
4C4A4744413E3B3835322F2B2825211E1A16130F0D10161D
242C343C434C566064636362626161606060606060616162
616161616262626364656564636362626262626262636364
6565656667686A6C6E71717477797B7E8286888B8D8F9194
96989B9EA0A0A1A2A19D9A9693908C8985827F7C7875716E
6B6764605D5A5653
4C494744413E3B3835322F2C2825221E1B17130F0F141920
2831384047505A6364646362626160606060606060606060
606060606061626364656564636362626262626363636465
66676768696B6D6F717376787A7D7F8386898C8E90939495
989B9EA2A3A2A4A4A19E9A9793908D8A86837F7C7975726E
6B6764605D5A5653
4C494744413E3B393633302D2926221F1C18151213181E27
2F363D444D576167666564636160605F5F5F5F5F5F5F6060
605F5F606162636364656463636262616162626263646565
6668696A6B6D6F717577787A7D7F83878A8E909294959698
9A9DA0A3A5A7A8A6A29F9B9895918E8A8783807C7975726E
6B6864615D5A5653
4D4A4744413F3C393633302D2A2723201C191614171C242C
333A424B555F696C6866646261605F5F5E5E5E5E5F5F5F60
606060606162636364646363626161616161616262646566
67686A6B6D6F717477797B7E8183868A8D9194959697979A
9CA0A3A7A8A9A9A6A39F9C9995928E8B8784807D7976726F
6B6864615D5A5653
4C4A4744423F3C393633302D2A2724211D1A16151A202830
383F47505B686E6B68666362605F5E5D5D5D5D5D5E5F5F60
6060606061626262626262616160605F5F60606162646566
68696B6D6E7073767A7D7F8183868A8D909497979898999C
9EA3A6A9ABABAAA7A3A09D9996928F8B8884807D7976726F
6B6865615D5A5653
4D4A4745423F3D3A3734312E2B2825221F1B16171D242D34
3C444D57626B6B6A676462615F5D5C5C5C5C5C5C5D5E5E5F
5F606060606161616160605F5F5E5E5E5E5E5F6061636466
67696B6D6F7174767A7D7F8285888C8F93979999999A9B9E
A1A6AAACADADABA7A4A19D9A96938F8C8885817E7A76736F
6C6865615D5A5653
4D4A484542403D3A3735322F2C2926231F1C1A1D23293239
4149525C676C6A686563615F5D5B5B5A5A5A5B5B5C5D5E5F
5F5F5F60606060605F5F5E5D5C5C5B5B5B5C5D5E5F616365
67696B6D6F7274777A7D8083868A8D9194989A9A9B9D9FA1
A5AAACAEB0AEABA8A5A19E9A9793908C8985817E7A777370
6C6965615E5A5653
4D4A484542403D3B383532302D2A2724211E1C21272F353C
444D57626B6C696664615F5D5B5A5958575859595B5C5D5E
5F6060605F5F5F5E5D5D5C5B5A5A5959595A5A5C5E606264
67696B6E707376787B7E8184888B8F92959A9B9C9D9EA0A3
A7ACAFB1B2B0ACA9A6A29F9B9894908D8986827E7B777370
6C6965615E5A5653
4D4A484643403E3B383633302D2B2824211D1D242A323A41
48515B666B686664625F5D5B59575655555657585A5C5D5E
5F6060605F5F5E5D5C5B5A59585756565656585A5C5E6164
66696B6E707376797C7E8285898D9094989B9C9D9F9FA2A5
AAAFB3B5B4B1AEAAA7A3A09C9895918D8A86827F7B777470
6C6965625E5A5653
4D4B484643413E3C393734312E2B2826231F22292E353C43
4B555E6566656462605E5B5956555453535456575A5C5D5F
606161605F5E5D5C5B5A5A5857555353535455585A5D6063
65686B6E707376797C7F83868A8E9296999D9E9FA0A2A6A9
AEB2B6B8B7B3AFABA8A4A09D9995918E8A86837F7B787470
6D6965625E5A5753
4D4B484644413F3D3A3735322F2C29272421252A31383E46
4E596266636362605E5B595654525151525255575A5C5E60
61626261605F5E5D5B5A58575553525151515355585C5F62
65686B6D707376797D8184888B8F93979B9EA0A1A2A5ABAD
B2B6B9BAB8B4B0ADA9A5A19D9996928E8B87837F7C787471
6D6965625E5A5753
4D4B49474442403D3B383633302E2B282625292C32394148
525B61616162615F5D5A575452504F4F505255585B5E6062
6364636362605F5D5C5A58565453514F4F515356585C5F62
65686B6D707376797D82868A8D9195999DA0A2A3A6AAB0B1
B5BABBBBBAB6B2AEAAA6A29E9A97938F8B8783807C787571
6D6966625E5A5753
4D4B49474542403E3B393734322F2C2925252B2E343B434B
555E62606161605E5C595552525454525154585A5C606365
666666656463625F5D58565657565351535456575A5D6063
67696B6E7073767A7E82878A8E93979BA0A3A5A7ABAEB3B5
BABFBFBEBBB7B3AFABA7A39F9B97938F8B8884807C787571
6D6966625E5A5753
4D4B49474543413F3D3A383532302D2A282A2D32373E464D
555C5F606162605E5C59565558595757595B5D6063656668
6969686767666462605F5E5E5D5856585A5A5C5D5E616366
696B6D6F7174777B7F83868A90969A9EA2A6A8ABAFB3B7B8
BEC1C1C1BDB8B4B0ACA8A4A09C9894908C8884807D797571
6D6A66625E5A5753
4D4C4A48464442403D3B393634312E2C2C2D2E3339414850
585E5D5E6061615F5D5B5A595A5B5B6060636567696B6D6E
6D6C6B6B6A6A6867656464625E5C5E5D5F6063626468696A
6C6D6F707275787C8085898E94989CA1A6A9ABAFB4B7BBBC
C1C3C4C3BEBAB5B1ADA9A4A09C9894908C8985817D797571
6D6A66625E5A5753
4D4C4A48464442403E3C3A3735322F2A292C31363D444A51
585C5C5E6162636262626264646161646970717374757473
71706F6E6E6D6D6C6B6A6867666364666A6A6A6C70717070
707071737476797D82878C92989DA0A4A9ADB0B3B7BCC0C1
C5C6C7C4BFBBB6B2AEA9A5A19D9995918D8985817D797571
6D6A66625E5B5753
4E4C4A49474543413F3D3B393634312D2C2E31373F454B51
575B5C5F62646566686A6D6F6F70727577797B7D7D7B7977
757372717171717170706F6E6D707476767777797B7A7876
7575747577797C8085898F949A9FA3A8ADB1B4B8BCC0C4C5
C8C9C9C5C1BCB7B3AEAAA6A29D9995918D8985817D797672
6E6A66625E5B5753
4E4C4B4948464442413F3C3A38353332312F323940464C53
585A5C5F626567696C6F73777A7C7E8082828181807E7C7A
77767574747473737373747577787B7E81838483817F7D7A
797777787A7C7F83878B90969CA2A8ACB1B5B8BCC1C4C7C8
CBCDCCC7C2BDB8B4AFABA6A29E9A96918D8985817D7A7672
6E6A66625E5B5753
4E4C4B4A4847454442403E3C393735333031363D434A4F54
585B5D606467696B6D7074777A7C7D7E7F80818383817E7C
7A7876767676777777757576787B7F8183848382807E7C7B
79797A7B7C7F82868A8E93999FA4AAB0B5B8BCC0C4C7CACB
CECFCCC7C2BEB9B4B0ABA7A39E9A96928E8A86827E7A7672
6E6A66625E5B5753
4E4D4C4A494846454342403E3B39363432373C42484E5257
5A5C5F6266696B6D6E71737678797C8084878A8985827F7C
7A7978777778797A7C7D7D7C7C7C7D7F8080807F7E7D7C7B
7B7C7D7E7F8285898C90969CA2A8AFB6BABEC0C4C7CACBCD
D0D0CDC8C3BEBAB5B0ACA7A39F9A96928E8A86827E7A7672
6E6A66625F5B5753
4E4D4C4B4A4948464543413F3D3B3635363C42494D515559
5C5E6165696C6E6F70717375777C83898C8C8A8885827F7C
7A79787878797A7B7E8184868684817F7E7D7D7D7C7C7C7D
7F8081828385888C90949AA0A6ABB1B8BEC1C4C8CBCDCECE
D2D2CDC9C4BFBAB5B1ACA8A39F9B96928E8A86827E7A7672
6E6A66625F5B5753
4E4D4D4C4B4A494846454442403D39373841484E5256595C
5F6265686C6F71747778797B808589898988878582807E7C
7A79797979797A7C7E80838588898A898784828181828383
8383838486898C8F92979DA1A7ADB5BDC2C5C9CCCFD0D1D3
D6D3CEC9C4BFBBB6B1ADA8A49F9B97928E8A86827E7A7672
6E6A66625F5B5753
4E4E4D4C4C4B4A494847464543413F3E41474E52565A5D60
6365696C6F727375787B7F828485868685858382807E7C7B
797978787878797B7C7F8183858686868788898887868585
85858586888B8F92969A9FA4ABB3BBC3C6CACED0D2D4D5D8
D9D4CFCAC5C0BBB6B2ADA8A4A09B97938E8A86827E7A7672
6E6A66625F5B5753
4F4E4E4D4D4C4B4B4A4A494846454342464C5255595D6063
66686C6E72747577797B7E80828383828282807F7E7C7B7A
787877777778797A7B7D7E80828383848485858585858585
858687898B8D9094999EA3A9B0B8BFC7CBCED2D3D5D7D8DC
DBD5D0CBC6C0BCB7B2ADA9A4A09B97938F8A86827E7A7672
6E6A66625F5B5753
4F4F4E4E4E4D4D4D4C4C4B4B4A4949494D5154575C606366
686B6F71747677787A7B7D7E7F808080807F7E7D7C7A7978
7777767676767778797A7C7D7F8081818283838484858586
8687898A8C9092969A9EA6ADB3BAC2CACED2D6D7D9DBDCDF
DCD6D1CBC6C1BCB7B2ADA9A4A09B97938F8A86827E7A7672
6E6A66625F5B5753
4F4F4F4F4F4E4E4E4E4E4E4E4E4E4E4E5154575A5E626568
6C6F7375777878797B7C7D7D7E7E7E7E7D7C7B7A79787776
767574747475767678797A7B7C7D7E7F8081828383848586
8687898B8E9194979CA2A9AFB6BEC6CDD1D6D9DBDDDFE1E2
DDD7D1CCC6C1BCB7B2AEA9A4A09B97938F8A86827E7A7672
6E6A66625F5B5753
4F4F4F5050505050505051515152525256595C606265686C
6F727578797A7A7B7B7C7C7C7D7D7C7C7B7A797877767574
7473737373747475767778797A7C7D7D7E7F808182848586
87898A8D9093969A9FA5ABB1BAC2CAD1D4D7DBDFE2E4E6E3
DDD7D1CCC6C1BCB7B2AEA9A4A09B97938F8A86827E7A7672
6E6A66625F5B5753
4F5050505151515252535354555556575B5E616365686B6E
7275787A7B7B7C7C7C7C7B7B7B7B7A7A7978777675747373
727171717272737374757677797A7B7C7E7F808182838586
87898C8E9194989CA2A8AEB6BEC6CFD5D7DBDFE3E7E9EAE4
DDD7D1CCC6C1BCB7B2AEA9A4A09B97938E8A86827E7A7672
6E6A66625E5B5753
50505051525253535455565758595B5B60636466686B6E71
73767A7C7D7D7D7D7C7C7B7B7A7A79787777757473727171
7070707070707172737374757778797A7C7D7E7F81838586
888B8D8F92969A9EA5ABB1BAC3CCD4D9DCDEE3E6E8EBEAE3
DDD7D1CCC6C1BCB7B2ADA9A4A09B97928E8A86827E7A7672
6E6A66625E5B5753
50505152525354555657585A5B5D5F63666567696B6E7173
777A7C7E7F7F7E7E7D7C7B7A79787776757473727170706F
6E6E6E6E6E6F6F7070717274757678797B7C7D7F81838587
898C8E9194999DA2A8AEB6BFC8D0D9DDE0E3E7EAEBECE8E2
DCD6D1CBC6C1BCB7B2ADA8A49F9B97928E8A86827E7A7672
6E6A66625E5B5753
505152535354555658595A5C5E60636667696C6D70727476
797C7E7F80807F7E7D7B7A797877757474737271706F6E6D
6D6C6C6C6C6D6D6E6E6F7172737576787A7B7D7E80828587
8A8C8F93979B9FA4ABB2BBC4CCD4DDE1E4E7EBEDEEECE7E1
DCD6D0CBC6C0BBB6B1ADA8A39F9B96928E8A85817D797572
6E6A66625E5A5753
5051525354555758595B5D5E616366696C7071737576787A
7B7D7F808181807E7D7B7A78777674737271706E6D6D6C6B
6B6A6A6A6A6B6B6C6C6E6F707173747678797C7E80828587
8A8D9194999EA3A9B0B8C1C9D2D9E1E5E8ECEFF0F0ECE6E0
DBD5D0CAC5C0BBB6B1ACA8A39F9A96928D8985817D797571
6D6A66625E5A5753
50515254555658595B5C5E616366696C71737678797B7C7D
7E8081828281807E7C7A797776747371706F6D6C6B6A6A69
68686868686869696A6B6C6E6F71737476787B7D80828588
8B8E92969BA0A6ADB5BDC6CFD7DEE4E8ECF0F2F2F0EBE5E0
DAD4CFCAC4BFBAB5B0ACA7A39E9A95918D8985817D797571
6D6966625E5A5753
505253545657595A5C5E606265686B6F73777C7E7F7F7F80
818282828281807E7C7A7876747371706E6D6B6A69686867
666666666666666768696A6C6D6F717375777A7C7F828588
8B8F93989DA3AAB2BAC3CBD3DBE2E9ECEFF2F4F3F0EAE4DF
D9D4CEC9C4BEB9B5B0ABA6A29E9995918D8884807C797571
6D6965625E5A5753
5152535556585A5B5D5F6164676A6D71767D838484838282
8283838382807F7D7B7977757371706E6C6B6A6968676665
64646363636364656667686A6B6D6F717376797C7F828589
8C90959AA0A7AFB7C0C8D1D8E0EAF0F1F3F5F5F4EFE9E3DE
D8D3CDC8C3BEB9B4AFAAA6A19D9994908C8884807C787470
6D6965625E5A5653
5152545557595A5C5E606365686B6E72777C828685838283
8384838382807F7C7A78767472706E6D6B69686765646363
6261616161616263636466686A6C6E707375787C7F828689
8E93989DA4ACB4BCC5CDD6DFE8F1F4F4F6F8F7F4EEE8E2DD
D7D2CCC7C2BDB8B3AEAAA5A19C9894908B8783807C787470
6C6965615E5A5653
5152545657595B5D5F616466696C6F73777B7F8283838283
8484848482817E7C7A777573716F6D6B6968666563626160
5F5E5E5E5E5F5F6061626466686A6C6F7275787B7E82868B
90949AA1A9B1BAC2CBD3DCE6F1F6F6F7FAFBF9F4EDE7E1DB
D6D0CBC6C1BCB7B2ADA9A4A09B97938F8B87837F7B777470
6C6865615E5A5653
51535456585A5C5E606265676A6D7073777A7E8081828385
8585858482807E7C79777472706E6C6A6866646361605F5E
5D5C5C5B5C5C5D5E5F61636467696B6E7174777B7F82878C
91979EA6AEB6BFC9D1D9E3EEF4F6F9FBFDFCF9F3ECE6E0DA
D5CFCAC4BFBAB6B1ACA8A39F9B96928E8A86827E7B77736F
6C6865615D5A5653
51535456585A5C5E606365686B6D7174777A7D7F80828584
8586858482807D7B797674726F6D6B68666462615F5E5D5C
5B5A5959595A5B5C5D5F61636567696C7073777B7F84898E
949BA2AAB2BBC4CCD6E1EBF2F7FAFCFEFFFCF8F2EBE5DED9
D3CEC8C3BEB9B4B0ABA7A29E9A95918D8986827E7A76736F
6B6864615D5A5653
51535557585A5D5F616366686B6E7174777A7D7F81848586
8786858482807D7B787673716F6C6A676563615F5E5C5B5A
595857575858595B5C5D5F616365686C6F73777B80858B91
98A0A7AFB7C0C9D3DCE5F0F6F9FBFEFFFFFDF7EFE9E3DDD7
D1CCC7C2BDB8B3AEAAA5A19D9994908D8985817D7976726F
6B6764605D595653
51535557595B5D5F616466696B6E7174777A7D8083878789
8A89878583817E7B797673716E6C696764625F5D5C5A5958
57575657575858595A5C5E606265686C7074787D83888E95
9CA4ACB4BEC7D0D9E2EBF2F6FAFDFFFFFEFAF4EDE7E1DBD5
CFCAC5C0BBB6B1ADA8A4A09B97938F8C8884807C7975726E
6B6764605D595653
51535557595B5D5F626466696C6E7174777A7E8185888B8E
8D8C8A8784817E7C797774716F6C696663615E5D5B5A5857
57575657575758595B5D5E616366696D71757A80858C9399
A0A9B1BAC4CDD4DCE5EDF2F6FBFDFFFEFCF8F1EBE4DED8D3
CDC8C3BEB9B5B0ABA7A39F9A96928E8B87837F7C7875716E
6A6763605D595652
51535557595B5D5F626466696C6E7174777A7E81858B8F91
918E8C8A87837F7C7A787673706C686563605E5C5B5B5A59
58585858595A5B5C5D5F616366696D7074797E838990979F
A7AFB7BFC8D0D8E0E7EFF5F9FCFEFEFCF9F4EEE8E2DCD6D0
CBC6C1BCB7B3AEAAA6A19D9995918D8A86827F7B7774706D
6A6663605C595652
51535557595B5D5F626467696C6E7174777A7E81858A9095
95928E8B888582807D7A7773706C69666361605F5E5C5C5C
5B5B5B5C5D5E5F60626566696C6F73767A7E83898E939AA3
AAB3BBC4CCD3DBE5ECF1F5F9FCFDFBFBF7F1EBE5DFD9D3CE
C9C4BFBAB6B1ADA8A4A09C9894908C8885817D7A7773706C
6966635F5C595652
51535557595B5D5F626467696C6E7174777A7D8185898D91
9292918F8B8987827F7A7774706D6A6866646261605F5F5F
5F5F606162636567696B6E717376797C81858A8F949AA1A8
B0B8C0C8D0D8E0E7EEF3F7FAFAF9FAF9F3EDE7E2DCD6D1CC
C7C2BDB8B3AFABA6A29E9A96928F8B8784807D7976726F6C
6965625F5C595552
51535557595B5D60626467696C6E7174777A7D8084888B8F
9394928F8C898683807D7A76726F6C6A6867666564636364
6465666768696B6D6F7174777A7D7E82858A8F949AA1A7AD
B5BDC4CCD4DCE4EBF1F5F6F6F6F7F8F5EFE9E4DED8D3CEC9
C4BFBAB6B1ADA9A4A09C9995918D8A86837F7C7875726E6B
6865625F5B585552
51535557595B5D60626466696B6E717376797C8083868A8D
909494918E8C888683807C7975716F6D6C6B6B6A6969696A
6A6B6C6E7071727476787C7E808284898C8F959BA1A8B0B7
BEC5CCD4DBE2EAEEF1F2F1F2F5F7F7F1EBE6E0DBD5D0CBC6
C1BDB8B3AFABA7A39F9B97938F8C8885817E7B7774716E6B
6764615E5B585552
51535557595B5D5F626466696B6D707376787B7F8285888B
8E9091918E8B888583817E7B7875737170706F6F6F6F6F70
72727577777A7D7D7F818285878A8D90949A9FA4AAB1B7BD
C4CBD3DBE1E7EAECEFEFF1F5F6F7F3EDE7E2DCD7D2CDC8C3
BEBAB5B1ADA9A4A09D9995918E8A8784807D7A7673706D6A
6764615E5B585552
51535557595B5D5F616466686B6D707275787B7E8184878A
8C8F929191908D898683817E7C7977767675757575767678
797B7C7D80828486888A8C8F9194989BA0A3A7ACB3B9BFC5
CDD4D9DEE2E6E9E9EAEEF3F6F8F6EFE9E3DED9D4CECAC5C0
BCB7B3AEAAA6A29E9A9793908C8985827F7C7875726F6C69
6663605D5B585552
51535557595B5D5F616365686A6C6F7174777A7C7F828588
8B8E909495908E8C8A868482807E7D7C7C7B7B7C7C7D7D7F
808284888A8C8D8F9394979A9C9FA2A6A9ADB2B7BBC1C8CE
D4D9DDE1E5E7E7E9ECF0F3F6F7F1EBE5DFDAD5D0CBC6C1BD
B8B4B0ACA7A3A09C9895918E8A8784817D7A7774716E6B68
6663605D5A575552
51535557595B5D5F61636567696C6E717376797B7E818487
898C8F929696918D8B898886858382838383838484848687
898C8E919396999B9C9FA3A5A7AAAEB2B5B9BDC1C6CBD0D5
DADDDFE1E2E2E5EAEFF2F5F6F1ECE6E1DBD6D1CCC7C3BEB9
B5B1ADA9A5A19D9A96938F8C8985827F7C797673706D6A68
65625F5D5A575552
51535557585A5C5E60626467696B6D707275777A7D808285
888B8E91949696938F8D8B8989898989898A898A8B8C8D90
9294979A9CA0A3A7AAABACAFB2B6BABDC2C6CACED2D6D8DA
DCDFE0E0E1E4E9EDF1F5F7F4EDE7E1DCD7D2CDC8C3BFBAB6
B2AEAAA6A29E9B9794918D8A8784817E7B7774726F6C6A67
64615F5C5A575452
51535556585A5C5E60626466686A6D6F717476797C7E8184
87898C8F9296999996928F8D8D8F90909091929394959798
9B9EA0A2A6AAADB1B4B7B9BBBDC1C4C7CACED2D5D8D9DADC
DCDCDDE0E3E9EEF1F3F6F5EEE8E2DCD7D2CDC8C3BFBBB7B2
AEAAA6A39F9C9895918E8B8885827F7C797673716E6B6966
63615E5C59575452
51535456585A5C5E5F616365676A6C6E707375787A7D7F82
85888B8E9195999B9B9997969595979999999B9C9FA0A2A3
A5A7AAACB0B3B6B9BDC1C3C3C6C9CBCED1D4D6D8D9D9D9D9
DADBDDE2E8EEF0F3F7F4EDE7E1DCD7D2CDC8C3BFBBB7B2AF
ABA7A3A09C9995928F8C898683807D7A7775726F6D6A6865
63605E5B59565452
5153545658595B5D5F61636567696B6D6F727476797B7E80
8386898C8F93979B9F9E9D9C9B9B9C9FA1A2A2A5A7AAADAE
AFB0B3B5B9BBBEC1C4C7CACCCFD1D1D3D4D6D6D7D6D6D8DB
DDE0E6EBEFF0F3F6F3EDE7E1DBD6D1CCC7C3BEBAB6B3AFAB
A7A3A09C999693908C898684817E7B797673716E6C696764
62605D5B58565451
5152545657595B5D5E60626466686A6C6E707375777A7C7F
8184878A8E9195999EA3A3A09E9EA1A3A6A9ABADB0B3B6B9
BBBCBEC0C2C4C5C5C6C6C9CBCECFD0D0D0D0D1D3D5D9DCDF
E3E7ECEFF1F2F5F3EBE5E0DAD5D0CBC7C2BEBAB6B2AEAAA6
A3A09C999693908D8A8784817F7C797774726F6D6A686663
615F5D5A58565451
5152545557595A5C5E5F61636567696B6D6F717376787A7D
808285888C8F93979B9FA4A5A4A4A4A5A9ACB0B3B6B9BCBD
C1C5C9CACBCAC9C8C9C9C8C9CACAC9CBCDCFD1D5D8DDE1E5
EAEDEFF0F4F5F0EAE4DED9D4CFCAC6C1BDB9B5B1ADAAA6A3
9F9C999693908D8A8784827F7D7A787573706E6C69676562
605E5C5A58565351
5152545557585A5B5D5F60626466686A6C6E70727476797B
7E808386898D9094989CA0A6ABA9A7A8A9ACB0B4B6B8BABD
C0C1C2C3C4C5C6C6C6C5C5C5C6C7C9CCCED1D5D8DDE3E7EB
ECEEF0F3F1EBE6E1DCD7D2CDC9C4C0BCB8B4B0ACA9A5A29F
9C999693908D8A8785827F7D7A787673716F6D6A68666462
5F5D5B5957555351
515253555658595B5C5E6061636567686A6C6E7072747779
7B7E8184878A8D9194989DA1A6ABADACACADAEB0B2B5B8BA
BCBDBFC0C1C1C1C1C1C2C3C4C5C6C9CCD0D6D9DEE2E5E8E9
EBEFEFECE7E2DDD9D4CFCBC6C2BEBAB6B2AFABA7A4A19E9B
9895928F8C8A8784827F7D7A787674716F6D6B6967656361
5F5D5B5957555351
505253555657595A5C5D5F6062646567696B6D6F70727577
797C7E818486898D9094989CA1A6ACB0B0AEAEAFB1B3B4B6
B7B9BABBBCBDBCBCBDBFC1C4C7C8CCD1D5D9DDE1E3E4E6EA
EBE9E5E1DDD8D4D0CCC7C3BFBBB7B4B0ADA9A6A29F9C9996
93918E8C898684817F7C7A787673716F6E6C696765636160
5E5C5A5856555351
505253545657585A5B5C5E5F6162646667696B6D6F717375
77797C7E818386898D9094989CA0A4A9ADB1B3B1AFAFB0B1
B4B6B7B8BABBBCBEBFC1C2C5CACDD1D4D6D8DADEE1E4E5E3
E0DDDAD7D3CFCBC7C3BFBCB8B4B1ADAAA6A3A09D9A979492
8F8D8A888583817E7C7A777573716F6D6B6967666462605F
5D5B595756545351
50525354555658595A5C5D5E606163646667696B6C6E7072
7477797B7E808386898C8F93969A9EA2A6A9ABAEB1B0AFB0
B1B1B3B5B6B8BABDBFC1C3C6C8CACDCED1D5D9DBDAD9D8D6
D4D2CFCCC8C5C2BEBBB7B4B0ADAAA7A4A19E9B989592908D
8B888683817F7C7A79777573716F6D6B6967656462615F5D
5C5A595756545251
50515354555657585A5B5C5D5F606163646667696B6C6E70
727476787A7D7F8285888B8E9194989B9EA1A3A6A8ABAEB0
B1B1B2B2B3B4B5B6B7BBBEC0C2C5C9CDCFD0D0CFCECDCCCB
C9C7C4C2BFBCB9B6B3AFACA9A6A3A19E9B989593908E8B89
878482807D7B7978767472706E6D6B696766646261605E5C
5B59585755545251
5051525354555758595A5B5C5E5F606163646667686A6C6E
6F71737577797C7E818386898C8F9194979A9C9FA1A3A6A7
A9AAABACADAEB0B3B5B7BABCBEC0C1C2C3C4C4C4C3C2C1BF
BDBBB9B7B5B3B0ADABA8A5A29F9D9A9895928F8D8B898684
82807E7C7A78767473716F6D6C6A6867656463615F5E5D5B
5A59575654535250
505152535455565758595A5B5C5D5F60616264656768696B
6D6E70727476787A7C7F818486898B8E90939597999B9D9F
A0A1A3A4A5A6A8AAACAEB0B1B3B4B6B7B8B8B8B8B8B7B6B4
B3B1AFADABA9A7A4A29F9D9B989593918F8C8A8886848280
7E7C7A7876757371706E6C6B69686665636261605E5D5B5A
5958575554535150
50515253535455565758595A5B5C5D5E6061626364666768
6A6B6D6F70727476787A7C7F818386888A8C8D9091939597
98999A9C9D9EA0A1A3A4A6A7A9AAABACACADADADACABABAA
A8A7A5A3A2A09D9B9A979593918F8D8A88868583817F7D7B
7977767473716F6E6D6B6A686665646361605F5D5C5B5A59
5857565553525250
5051515253545555565758595A5B5C5D5E5F606162636466
67686A6B6D6E7072747577797B7D7F81828486888A8C8D8E
8F919293949597989A9B9C9D9EA0A1A1A2A2A2A2A1A1A09F
9E9D9B9A99979593918F8E8B8987868482807F7D7C7A7876
757372706F6D6C6B69686765646362605F5E5D5C5B5A5958
5756555453525150
50505152535354555556575859595A5B5C5D5E5F60616263
64656768696B6C6E6F7172747677797B7C7E7F8183848586
8889898A8C8D8E8F90929394959596979797979797969594
949392918F8D8C8B8987858382817F7D7C7A797776757372
706F6D6C6A6968676665636261605F5E5D5D5C5B5A595857
5655545352525150
505051515253535455555657575859595A5B5C5D5E5F5F60
61626364666768696B6C6D6F707273747677797A7B7C7D7E
7F80818283848586878888898A8B8C8C8D8D8D8D8C8C8B8A
8A89888786858482817F7E7C7B7A787776747371706F6E6C
6B6A696867666564636261605F5E5D5C5C5B5A5958575756
5554545352515050
5050515152525353545455555657575858595A5B5B5C5D5D
5E5F6061626364656667696A6B6C6D6E6F70727374757677
777879797A7B7C7D7E7E7F80808181828282838282818181
807F7E7D7D7C7A7978777675747271706F6E6D6C6B6A6868
67666464636261605F5E5D5D5C5B5B5A5958585757565555
5454535251515150
505050515152525253535454555556565757585859595A5A
5B5C5D5D5E5F60616263646465666768696A6B6C6D6E6E6F
6F7070717272737474757676777777787878787878787776
7675757474737271706F6E6D6D6C6B6A6968676766656463
626161605F5E5D5C5C5B5B5A5A5958585756565655555454
535352525151504F
4F5050505151515252525353535454545555565657575758
5859595A5A5B5C5C5D5E5E5F606161626364646565666667
67686868696A6A6B6B6B6C6C6D6D6D6E6E6E6E6E6D6D6D6C
6C6C6C6B6B6A6968686767666564646363626261605F5F5E
5D5D5D5C5B5A5A5959585857575756565555545454535353
525252515151504F
4F5050505050515151515152525252535353545454555555
55555656575758585959595A5A5A5B5B5C5C5D5D5E5E5E5F
5F5F60606061616162626263636363636464646363636363
6262626161616160605F5F5E5D5D5D5C5C5B5B5B5B5A5A59
595858575757575656555555545454535353535252525251
5151505050504F4F
4F4F4F505050505050505050515151515151525252525252
525253535353535354545454545555555656565757575757
575758585858585859595959595959595A5A595959595959
595958585858585858575757565656565555555555555454
545453535353535252525252525252515151515151515151
50505050504F4F4F
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[57]:=",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`004`3ooolG04m?C`P0D51@301?Cdl204i>CP80CDe=
00<0Cdm?04i>CP1>CTh00P1>CTh604e=C@P0C4a<>01;Bd/404a<C080Bd];2P1<C4`O04];Bb40C4a<
00<0CDe=04a<C01<C4`02P1=CDd404i>CP@0Cdm?1P1@D505055AD@`0D51@0P1?CdlE0?ooo`004`3o
oolG04m?C`P0D51@301?Cdl204i>CP80CDe=00<0Cdm?04i>CP1>CTh00P1>CTh604e=C@P0C4a<>01;
Bd/404a<C080Bd];2P1<C4`O04];Bb40C4a<00<0CDe=04a<C01<C4`02P1=CDd404i>CP@0Cdm?1P1@
D505055AD@`0D51@0P1?CdlE0?ooo`004`3oool604m?C`80CTi>2`1?Cdl4051@D0@0DE5A101@D506
04m?C`@0CTi>1P1=CDd00`1?Cdl0CDe=04e=C@0404a<C080Bd];0P1:BTX404U9B@@0B4Q82017AdL?
04I6AP@0AdM71018B4PG04M7Aa/0B4Q84017AdL204I6AP80AdM71@18B4P204U9B@80B4Q84019BDT4
04Y:BP80BDU92`1:BTX404];B`@0C4a<0P1=CDd204i>CP80Cdm?101ADE44059BDP<0De=C0P1ADE42
051@D0H0DE5A0P1@D50204m?CaD0oooo000C0?ooo`H0Cdm?0P1>CTh;04m?C`@0D51@101ADE44051@
D0H0Cdm?101>CTh604e=C@0304m?C`1=CDd0CDe=00@0C4a<0P1;Bd/204Y:BP@0BDU91018B4P804M7
A`l0ATI61017AdL404Q8B1L0AdM76`18B4P@04M7A`80ATI60P17AdL504Q8B080BDU90P18B4P@04U9
B@@0BTY:0P19BDT;04Y:BP@0Bd];101<C4`204e=C@80CTi>0P1?Cdl4055AD@@0DU9B0`1CDe<2055A
D@80D51@1P1ADE42051@D080Cdm?5@3oool001<0oooo4`1?Cdl4051@D0H0DE5A101@D50404m?C`80
CTi>1P1=CDd204i>CP0304e=C@1;Bd/0Bd];0080Bd];0P1:BTX204U9B@@0AdM70P16ATH204E5A@80
A4A41P13@d<40492@P<0@D512012@T8404=3@a00A4A42@13@d<604A4A0`0ADE55@14A4@804=3@`80
@T920P13@d<204E5A@80B4Q800<0ATI604E5A@15ADD01015ADD204I6AP80AdM73016ATH904M7A`@0
B4Q81P19BDT204Y:BP80Bd];0P1<C4`204e=C@80Cdm?0P1ADE42059BDPH0De=C2@1BDU84055AD@80
D51@5@3oool001<0oooo4`1?Cdl4051@D0H0DE5A101@D50404m?C`80CTi>1P1=CDd204i>CP0304e=
C@1;Bd/0Bd];0080Bd];0P1:BTX204U9B@@0AdM70P16ATH204E5A@80A4A41P13@d<40492@P<0@D51
2012@T8404=3@a00A4A42@13@d<604A4A0`0ADE55@14A4@804=3@`80@T920P13@d<204E5A@80B4Q8
00<0ATI604E5A@15ADD01015ADD204I6AP80AdM73016ATH904M7A`@0B4Q81P19BDT204Y:BP80Bd];
0P1<C4`204e=C@80Cdm?0P1ADE42059BDPH0De=C2@1BDU84055AD@80D51@5@3oool001<0oooo5`1?
Cdl2051@D080DE5A0P1BDU82055AD@80D51@101?Cdl204i>CP@0CDe=101<C4`00`1=CDd0C4a<04a<
C00204Y:BP80B4Q80P17AdL204I6AP80A4A40P13@d<20451@@80@410100o?cl403hn?PT0?Cdm100n
?Sh40410@0@0@D511012@T880451@@d0@4103P11@D4G0410@0X0?clo0P10@4020492@P<0@d=30P12
@T8804=3@`80A4A41013@d<<04A4A0<0ADE51016ATH404M7A`80B4Q80P19BDT204];B`80CDe=0P1?
Cdl2055AD@P0De=C1@1BDU8405=CD`80DU9B0P1ADE42051@D1D0oooo000C0?oooaL0Cdm?0P1@D502
055AD@80DU9B0P1ADE42051@D0@0Cdm?0P1>CTh404e=C@@0C4a<00<0CDe=04a<C01<C4`00P1:BTX2
04Q8B080AdM70P16ATH204A4A080@d=30P11@D420410@0@0?clo100n?Sh903dm?@@0?Shn1010@404
0451@@@0@T922011@D4=0410@0h0@D515`10@40:03lo?`80@4100P12@T8304=3@`80@T922013@d<2
04A4A0@0@d=33014A4@304E5A@@0ATI61017AdL204Q8B080BDU90P1;Bd/204e=C@80Cdm?0P1ADE48
05=CD`D0DU9B101CDe<2059BDP80DE5A0P1@D50E0?ooo`004`3oool804m?C`d0CTi>101?Cdl4051@
D0@0DE5A0P1@D50204m?C`@0CTi>0P1=CDd404a<C00304];B`1:BTX0BTY:0080BDU90P17AdL204E5
A@80@d=30P11@D420410@080?Shn0P0m?Cd203/k>`80>SXj3`0i>CT203/k>`80?3`l0P0m?Cd203hn
?P@0?clo0P10@40403lo?`@0?Shn4@0m?CdS03`l?080>c/k200l?3`203dm?@0303hn?P0o?cl0?clo
0080@4100P0o?cl>0410@0P0@D511@12@T8204=3@`@0A4A40P15ADD204I6AP80B4Q80P1:BTX204a<
C080CTi>0P1ADE49059BDP@0De=C1P1DE5@2059BDP80DE5A5@3oool001<0oooo201?Cdl=04i>CP@0
Cdm?101@D504055AD@80D51@0P1?Cdl404i>CP80CDe=101<C4`00`1;Bd/0BTY:04Y:BP0204U9B@80
AdM70P15ADD204=3@`80@D510P10@40203hn?P80?Cdm0P0k>c/203Xj>Pl0>CTi0P0k>c/203`l?080
?Cdm0P0n?Sh403lo?`80@410100o?cl403hn?Q40?Cdm8`0l?3`203/k>`P0?3`l0P0m?Cd00`0n?Sh0
?clo03lo?`020410@080?clo3P10@4080451@@D0@T920P13@d<404A4A080ADE50P16ATH204Q8B080
BTY:0P1<C4`204i>CP80DE5A2@1BDU8405=CD`H0E5AD0P1BDU82055ADAD0oooo000C0?ooo`H0Cdm?
2P1>CTh704e=C@80CTi>1P1?Cdl4051@D080Cdm?0P1>CTh404e=C@80C4a<0P1:BTX304U9B@80B4Q8
0P15ADD204=3@`80@D510P0o?cl203dm?@80>SXj0P0i>CT203Lg=`80=SHf0P0e=CD203@d=0D0<c<c
0P0d=3@203De=@80=SHf0P0g=cL203Ph>080>CTi0P0k>c/403`l?0H0?Cdm0P0l?3`703/k>`X0>SXj
200i>CT203Ph>1l0=cLg1P0h>3P303Ti>@80>c/k0P0m?Cd@03`l?0@0?Cdm1P0n?Sh00`0o?cl0@410
0410@0020410@080@D510P12@T8204=3@`80A4A40P15ADD204M7A`80BTY:0P1=CDd604m?C`@0D51@
00<0DE5A05=CD`1CDe<00P1CDe<205EEE@80EUIF0P1DE5@2059BDP80DE5A5@3oool001<0oooo1P1?
Cdl:04i>CPL0CDe=0P1>CTh604m?C`@0D51@0P1?Cdl204i>CP@0CDe=0P1<C4`204Y:BP<0BDU90P18
B4P204E5A@80@d=30P11@D4203lo?`80?Cdm0P0j>SX203Ti>@80=cLg0P0f=SH203De=@80=3@d1@0c
<c<203@d=080=CDe0P0f=SH203Lg=`80>3Ph0P0i>CT203/k>`@0?3`l1P0m?Cd203`l?0L0>c/k2P0j
>SX803Ti>@80>3Ph7`0g=cL603Ph>0<0>CTi0P0k>c/203dm?A00?3`l100m?Cd603hn?P0303lo?`10
@400@4100080@4100P11@D420492@P80@d=30P14A4@204E5A@80AdM70P1:BTX204e=C@H0Cdm?101@
D5000`1ADE40De=C05=CD`0205=CD`80EEEE0P1FEUH205ADE080DU9B0P1ADE4E0?ooo`004`3oool6
04m?C`H0CTi>1`1=CDd204a<C0X0CDe=201>CTh204e=C@80C4a<0P1;Bd/204Y:BP0304Q8B017AdL0
AdM70080ADE50P13@d<20410@080?Cdm0P0k>c/203Ti>@80=cLg0P0d=3@2038b<P80<C4a0P0`<304
02l_;`80;Rh^00<0;bl_030`<00`<3000P0a<C42038b<P80<c<c0P0e=CD203Hf=P80=cLg0P0h>3P2
03Ti>@P0>SXj1@0i>CT403Ph>0@0=cLg200f=SH403De=@80=3@d2@0c<c<4038b<Q80<c<c1P0d=3@3
03De=@80=SHf0P0h>3P403Ti>@80>3Ph1P0g=cL403Ph>0@0>CTi100j>SX203/k>`<0?3`l0P0m?Cd2
03hn?P80?clo0P10@4020492@P80A4A40P16ATH204U9B@@0CDe=101>CTh2051@D080DE5A00<0DU9B
05=CD`1CDe<00P1DE5@405IFEP80E5AD0P1BDU82055ADAD0oooo000C0?ooo`H0Cdm?1P1>CTh704e=
C@80C4a<2P1=CDd804i>CP80CDe=0P1<C4`204];B`80BTY:00<0B4Q804M7A`17AdL00P15ADD204=3
@`80@4100P0m?Cd203/k>`80>CTi0P0g=cL203@d=080<S8b0P0a<C42030`<0@0;bl_0P0^;Rh00`0_
;bl0<30`030`<002034a<@80<S8b0P0c<c<203De=@80=SHf0P0g=cL203Ph>080>CTi200j>SX503Ti
>@@0>3Ph100g=cL803Hf=P@0=CDe0P0d=3@903<c<`@0<S8b4P0c<c<603@d=0<0=CDe0P0f=SH203Ph
>0@0>CTi0P0h>3P603Lg=`@0>3Ph100i>CT403Xj>P80>c/k0`0l?3`203dm?@80?Shn0P0o?cl20410
@080@T920P14A4@204I6AP80BDU9101=CDd404i>CP80D51@0P1ADE400`1BDU80De=C05=CD`0205AD
E0@0EUIF0P1DE5@2059BDP80DE5A5@3oool001<0oooo101?Cdl404i>CPH0CDe=1@1<C4`B04];B`80
C4a<0P1;Bd/204Y:BP80BDU90P18B4P00`16ATH0A4A404A4A0020492@P80@4100P0l?3`203Xj>P80
=cLg0P0e=CD2038b<P80<30`0P0^;Rh202`/;080:b/[100Z:RX202/[:`0302`/;00];Bd0;Bd]0080
;Rh^0P0_;bl2030`<080<C4a0P0b<S8203@d=080=CDe100f=SH:03Lg=`L0=SHf0P0e=CD403@d=080
<c<c100b<S82034a<@@0<30`1`0_;bl<02h^;PX0;bl_100`<305034a<@@0<S8b300c<c<403@d=0@0
=CDe0P0f=SH203Lg=`<0>3Ph0P0i>CT203Xj>P80>c/k0P0l?3`203hn?P80@D510P14A4@204M7A`80
Bd];101<C4`204e=C@80CTi>0P1ADE42059BDP0305=CD`1DE5@0E5AD0080EEEE101FEUH205ADE080
DU9B0P1ADE4E0?ooo`004`3oool404m?C`@0CTi>1P1=CDd504a<C180Bd];0P1<C4`204];B`80BTY:
0P19BDT204Q8B00304I6AP14A4@0A4A40080@T920P10@40203`l?080>SXj0P0g=cL203De=@80<S8b
0P0`<30202h^;P80;2`/0P0[:b/402XZ:P80:b/[00<0;2`/02d];@0];Bd00P0^;Rh202l_;`80<30`
0P0a<C42038b<P80=3@d0P0e=CD403Hf=PX0=cLg1`0f=SH203De=@@0=3@d0P0c<c<4038b<P80<C4a
100`<30702l_;``0;Rh^2P0_;bl4030`<0D0<C4a100b<S8<03<c<`@0=3@d100e=CD203Hf=P80=cLg
0`0h>3P203Ti>@80>SXj0P0k>c/203`l?080?Shn0P11@D4204A4A080AdM70P1;Bd/404a<C080CDe=
0P1>CTh2055AD@80DU9B00<0De=C05ADE01DE5@00P1EEED405IFEP80E5AD0P1BDU82055ADAD0oooo
000C0?ooo`@0Cdm?101>CTh404e=C@80C4a<1`1;Bd/604Y:BPh0BDU90P18B4P204M7A`80ATI600<0
A4A40492@P12@T800P10@40203hn?P80?3`l0P0i>CT203@d=080<30`0P0^;Rh202/[:`80:BTY0P0X
:2P202LW9`809RHV100W9bL00`0X:2P0:BTY02TY:@0202/[:`80;2`/0P0];Bd202h^;P80;bl_0P0`
<302034a<@80<S8b0P0c<c<403@d=0T0=CDe100d=3@603<c<`80<S8b0P0a<C42030`<080;bl_0P0^
;Rh402d];@D0;2`/400[:b/402`/;0@0;Bd]3@0^;Rh202l_;`@0<30`100_;bl4030`<080<C4a100b
<S8203<c<`<0=3@d0P0e=CD203Lg=`80>3Ph0P0j>SX203hn?P80@T920P17AdL204Y:BP80Bd];0P1=
CDd204i>CP80D51@0P1ADE4205=CD`80EEEE0`1FEUH405MGE`80EUIF0P1DE5@205=CD`80DE5A5@3o
ool001<0oooo0P1?Cdl404i>CP80CDe=101<C4`404];B`<0BTY:1P19BDT404Q8B0@0AdM71P16ATH2
04E5A@80A4A40P13@d<20451@@030410@00n?Sh0?Shn0080>c/k0P0i>CT203Lg=`80=CDe0P0`<302
02/[:`80:BTY0P0V9RH202@T90X08R8R00<08b<S02@T900T92@00P0V9RH202LW9`80:BTY0P0Z:RX2
02`/;080;Bd]0P0^;Rh202l_;`80<30`1P0a<C4;038b<PH0<C4a0P0`<30402l_;`@0;Rh^100];Bd2
02`/;0D0:b/[3P0Z:RX:02/[:`/0;2`/100];Bd202h^;P@0;bl_100];Bd202h^;P@0;bl_100`<303
034a<@80<c<c0P0f=SH203/k>`80@D510P16ATH204U9B@80C4a<0P1>CTh204m?C`80D51@0P1BDU82
05ADE080EEEE0P1FEUH305MGE`@0F5QH0P1GEeL205EEE@80De=C0P1ADE4E0?ooo`004`3oool204m?
C`@0CTi>0P1=CDd404a<C0@0Bd];0`1:BTX604U9B@@0B4Q81017AdL604I6AP80ADE50P14A4@204=3
@`80@D5100<0@41003hn?P0n?Sh00P0k>c/203Ti>@80=cLg0P0e=CD2030`<080:b/[0P0Y:BT202HV
9P8092@T2P0R8R800`0S8b<092@T02@T900202HV9P809bLW0P0Y:BT202XZ:P80;2`/0P0];Bd202h^
;P80;bl_0P0`<306034a<@/0<S8b1P0a<C42030`<0@0;bl_100^;Rh402d];@80;2`/1@0[:b/>02XZ
:PX0:b/[2`0/;2`402d];@80;Rh^100_;bl402d];@80;Rh^100_;bl4030`<0<0<C4a0P0c<c<203Hf
=P80>c/k0P11@D4204I6AP80BDU90P1<C4`204i>CP80Cdm?0P1@D502059BDP80E5AD0P1EEED205IF
EP<0EeMG101HF5P205MGE`80EEEE0P1CDe<2055ADAD0oooo000C0?ooo`@0CTi>101=CDd204a<C080
Bd];1@1:BTX404U9B@@0B4Q80P17AdL204I6AP@0ADE50P14A4@404=3@`80@T920P11@D4203lo?`80
?Shn00<0?3`l03Ti>@0i>CT00P0g=cL203De=@80<S8b0P0_;bl202`/;080:2PX0P0T92@2020P8080
7QhN0P0M7Ad401`L70807AdM0P0N7Qh00`0O7al08B4Q024Q8@02028R8P8092@T0P0V9RH202LW9`80
:BTY0P0Z:RX202/[:`80;2`/0P0];Bd402h^;P@0;bl_1`0`<30402l_;`@0;Rh^100];Bd202`/;0H0
:b/[100Z:RX302TY:@P0:2PX200W9bL>02PX:0D0:BTY1P0Z:RX402/[:`80;Bd]0P0_;bl2034a<@80
;Rh^1P0];Bd202h^;P03030`<00d=3@0=3@d0080>CTi0P0m?Cd20451@@80ADE50P18B4P204];B`80
CDe=0P1ADE44059BDP80E5AD0P1EEED205MGE`<0FEUI0P1JFUX205]KF`80FEUI0P1HF5P205EEE@80
De=C0P1ADE4E0?ooo`004`3oool404i>CP@0CDe=0P1<C4`204];B`D0BTY:1019BDT404Q8B080AdM7
0P16ATH404E5A@80A4A41013@d<20492@P80@D510P0o?cl203hn?P0303`l?00i>CT0>CTi0080=cLg
0P0e=CD2038b<P80;bl_0P0/;2`202PX:08092@T0P0P820201hN7P807AdM100L71`201dM7@807QhN
00<07alO024Q8@0Q8B400P0R8R8202@T90809RHV0P0W9bL202TY:@80:RXZ0P0[:b/202`/;080;Bd]
100^;Rh402l_;`L0<30`100_;bl402h^;P@0;Bd]0P0/;2`602/[:`@0:RXZ0`0Y:BT802PX:0P09bLW
3P0X:2P502TY:@H0:RXZ100[:b/202d];@80;bl_0P0a<C4202h^;PH0;Bd]0P0^;Rh00`0`<300=3@d
03@d=00203Ti>@80?Cdm0P11@D4204E5A@80B4Q80P1;Bd/204e=C@80DE5A101BDU8205ADE080EEEE
0P1GEeL305UIF@80FUYJ0P1KFe/205UIF@80F5QH0P1EEED205=CD`80DE5A5@3oool001<0oooo0P1?
Cdl204i>CP80CDe=101<C4`204];B`@0BTY:00<0BDU904Q8B018B4P00P18B4P204M7A`80ATI60P15
ADD404A4A080@d=30P12@T820451@@80@4100P0o?cl203dm?@80?3`l0P0j>SX00`0h>3P0=SHf03Hf
=P0203<c<`80<C4a0P0^;Rh202/[:`80:2PX0P0V9RH2024Q8@807AdM0P0J6QX201LG5`805ADE0P0F
5QH201LG5`8061PH00<06QXJ01`L700L71`00P0N7Qh2020P80808R8R0P0T92@202HV9P80:2PX0P0Y
:BT202XZ:P@0:b/[1P0/;2`702d];@H0;2`/0P0[:b/402XZ:P@0:BTY0P0X:2P402LW9`D09RHV100U
9BDF02@T90D09BDU1P0V9RH402LW9`@0:2PX0P0Y:BT202XZ:P80:b/[0P0/;2`202h^;P80<30`0P0_
;bl2034a<@0303Hf=P0j>SX0>SXj0080?Shn0P12@T8204I6AP80B4Q80P1:BTX204e=C@80D51@0P1C
De<2059BDP80E5AD0P1FEUH205QHF080FUYJ0`1KFe/205eMG@80G5aL0P1KFe/205UIF@80EUIF0P1D
E5@2059BDQD0oooo000C0?ooo`80Cdm?0P1>CTh204e=C@@0C4a<0P1;Bd/404Y:BP0304U9B@18B4P0
B4Q80080B4Q80P17AdL204I6AP80ADE51014A4@204=3@`80@T920P11@D420410@080?clo0P0m?Cd2
03`l?080>SXj00<0>3Ph03Hf=P0f=SH00P0c<c<2034a<@80;Rh^0P0[:b/202PX:0809RHV0P0Q8B42
01dM7@806QXJ0P0G5aL201DE5@805QHF0P0G5aL201PH600301XJ6P0L71`071`L00807QhN0P0P8202
028R8P8092@T0P0V9RH202PX:080:BTY0P0Z:RX402/[:`H0;2`/1`0];Bd602`/;080:b/[100Z:RX4
02TY:@80:2PX100W9bL502HV9P@09BDU5P0T92@502DU9@H09RHV100W9bL402PX:080:BTY0P0Z:RX2
02/[:`80;2`/0P0^;Rh2030`<080;bl_0P0a<C400`0f=SH0>SXj03Xj>P0203hn?P80@T920P16ATH2
04Q8B080BTY:0P1=CDd2051@D080De=C0P1BDU8205ADE080EUIF0P1HF5P205YJFP<0Fe]K0P1MGEd2
05aLG080Fe]K0P1IFET205IFEP80E5AD0P1BDU8E0?ooo`004`3oool404i>CP80CDe=0P1<C4`204];
B`80BTY:1019BDT00`18B4P0AdM704M7A`0204I6AP@0ADE50P14A4@204=3@`80@T920P11@D420410
@080?Shn0P0m?Cd203`l?080>SXj0P0h>3P203Hf=P0303@d=00b<S80<S8b0080<30`0P0^;Rh202/[
:`80:2PX0P0U9BD2028R8P807alO0P0J6QX201HF5P804Q8B100?3`l2014A4@804a<C00<05ADE01PH
600H61P00P0J6QX201dM7@807alO0P0Q8B4202@T90809BDU0P0W9bL402PX:0@0:BTY1P0Z:RX502/[
:`80:RXZ100Y:BT402PX:0@09bLW0P0V9RH402DU9@8092@T0P0S8b<5028R8PH08B4Q200P820:024Q
8@T08R8R100S8b<402@T90809BDU0P0V9RH202LW9`80:2PX0P0Y:BT202XZ:P80;Bd]0P0b<S8203Ph
>00303`l?010@400@4100080A4A40P17AdL204Y:BP80CDe=0P1@D502059BDP80E5AD0P1EEED205IF
EP80F5QH0P1JFUX205]KF`@0GEeM0`1NGUh205eMG@80G5aL0P1IFET205MGE`80EEEE0P1BDU8E0?oo
o`004`3oool404i>CP80CDe=0P1<C4`204];B`80BTY:1019BDT00`18B4P0AdM704M7A`0204I6AP@0
ADE50P14A4@204=3@`80@T920P11@D420410@080?Shn0P0m?Cd203`l?080>SXj0P0h>3P203Hf=P03
03@d=00b<S80<S8b0080<30`0P0^;Rh202/[:`80:2PX0P0U9BD2028R8P807alO0P0J6QX201HF5P80
4Q8B100?3`l2014A4@804a<C00<05ADE01PH600H61P00P0J6QX201dM7@807alO0P0Q8B4202@T9080
9BDU0P0W9bL402PX:0@0:BTY1P0Z:RX502/[:`80:RXZ100Y:BT402PX:0@09bLW0P0V9RH402DU9@80
92@T0P0S8b<5028R8PH08B4Q200P820:024Q8@T08R8R100S8b<402@T90809BDU0P0V9RH202LW9`80
:2PX0P0Y:BT202XZ:P80;Bd]0P0b<S8203Ph>00303`l?010@400@4100080A4A40P17AdL204Y:BP80
CDe=0P1@D502059BDP80E5AD0P1EEED205IFEP80F5QH0P1JFUX205]KF`@0GEeM0`1NGUh205eMG@80
G5aL0P1IFET205MGE`80EEEE0P1BDU8E0?ooo`004`3oool204i>CP80CDe=0P1<C4`404];B`80BTY:
0P19BDT204Q8B00304M7A`16ATH0ATI60080ADE50P14A4@204=3@`80@T920P11@D420410@080?clo
0P0m?Cd203`l?080>SXj0P0i>CT203Lg=`80=CDe0P0c<c<00`0a<C40;bl_02l_;`0202d];@80:RXZ
0P0W9bL202@T90808R8R0P0O7al201`L70805aLG0P0C4a<200l?3`803@d=100:2PX200d=3@03010@
400C4a<04a<C00805QHF0P0I6AT201`L70807alO0P0Q8B4202<S8`8092@T100V9RH402LW9`/0:2PX
0P0W9bL402HV9P@09BDU100T92@202<S8`@08R8R0P0Q8B42020P80<07alO1P0N7QhB01dM7@@07QhN
1`0O7al4020P80808B4Q0P0R8R8202<S8`8092@T0P0U9BD202LW9`80:RXZ0P0^;Rh203@d=080>CTi
0P0n?Sh00`12@T80ATI604I6AP0204Q8B080Bd];0P1?Cdl2055AD@80E5AD0P1EEED205MGE`80F5QH
0P1IFET205aLG080GUiN0P1OGel7061PH080GUiN0P1LG5`205YJFP80EeMG0P1DE5@2059BDQD0oooo
000C0?ooo`80CTi>0P1=CDd204a<C0@0Bd];0P1:BTX204U9B@80B4Q800<0AdM704I6AP16ATH00P15
ADD204A4A080@d=30P12@T820451@@80@4100P0o?cl203dm?@80?3`l0P0j>SX203Ti>@80=cLg0P0e
=CD203<c<`03034a<@0_;bl0;bl_0080;Bd]0P0Z:RX202LW9`8092@T0P0R8R8201lO7`8071`L0P0G
5aL201<C4`803`l?0P0=3@d400X:2P803@d=00<0410@01<C4`0C4a<00P0F5QH201TI6@8071`L0P0O
7al2024Q8@808b<S0P0T92@402HV9P@09bLW2`0X:2P202LW9`@09RHV100U9BD402@T90808b<S100R
8R82024Q8@80820P0`0O7al601hN7Q807AdM100N7Qh701lO7`@0820P0P0Q8B42028R8P808b<S0P0T
92@202DU9@809bLW0P0Z:RX202h^;P80=3@d0P0i>CT203hn?P030492@P16ATH0ATI60080B4Q80P1;
Bd/204m?C`80DE5A0P1DE5@205EEE@80EeMG0P1HF5P205UIF@80G5aL0P1NGUh205mOG`L0H61P0P1N
GUh205aLG080FUYJ0P1GEeL205ADE080DU9B5@3oool001<0oooo0P1>CTh204e=C@80C4a<0P1;Bd/2
04Y:BP80BDU90P18B4P204M7A`0304I6AP15ADD0ADE50080A4A40P13@d<20492@P80@4100P0o?cl2
03hn?P80?3`l0P0k>c/203Ti>@80>3Ph0P0f=SH203@d=080<S8b0P0`<3000`0^;Rh0;2`/02`/;002
02XZ:P809bLW0P0T92@2024Q8@807QhN0P0K6a/201LG5`804a<C0P0@410200d=3@802`/;0P092@T2
00H61P801`L700<02`/;00l?3`0?3`l00P0C4a<201LG5`806QXJ0P0M7Ad201lO7`808B4Q0P0S8b<2
02@T90H09BDU2@0V9RH402DU9@@092@T0P0S8b<2028R8P@08B4Q100P820201lO7`807QhN0P0M7Ad3
01`L70@06a/K100J6QX:01TI6@H06QXJ1P0K6a/301`L70H07AdM0P0N7Qh2020P80808B4Q0P0S8b<2
02HV9P80:BTY0P0^;Rh203De=@80>SXj0P0n?Sh20492@P0304M7A`1;Bd/0Bd];0080CTi>0P1ADE42
05=CD`80EEEE0P1GEeL205QHF080FUYJ0P1LG5`205mOG`80HF5Q101SHf<4069RHP0306=SH`1QHF40
HF5Q0080GemO0P1LG5`205YJFP80EeMG0P1EEED2059BDQD0oooo000C0?ooo`80CTi>0P1=CDd204a<
C080Bd];0P1:BTX204U9B@80B4Q80P17AdL00`16ATH0ADE504E5A@0204A4A080@d=30P12@T820410
@080?clo0P0n?Sh203`l?080>c/k0P0i>CT203Ph>080=SHf0P0d=3@2038b<P80<30`00<0;Rh^02`/
;00/;2`00P0Z:RX202LW9`8092@T0P0Q8B4201hN7P806a/K0P0G5aL201<C4`80410@0P0=3@d200/;
2`802@T90P061PH200L71`0300/;2`0?3`l03`l?00804a<C0P0G5aL201XJ6P807AdM0P0O7al2024Q
8@808b<S0P0T92@602DU9@T09RHV100U9BD402@T90808b<S0P0R8R84024Q8@@0820P0P0O7al201hN
7P807AdM0`0L71`401/K6`@06QXJ2P0I6AT601XJ6PH06a/K0`0L71`601dM7@807QhN0P0P8202024Q
8@808b<S0P0V9RH202TY:@80;Rh^0P0e=CD203Xj>P80?Shn0P12@T800`17AdL0Bd];04];B`0204i>
CP80DE5A0P1CDe<205EEE@80EeMG0P1HF5P205YJFP80G5aL0P1OGel2065QH@@0Hf=S101RHV800`1S
Hf<0HF5Q065QH@0205mOG`80G5aL0P1JFUX205MGE`80EEEE0P1BDU8E0?ooo`004`3oool204i>CP80
CDe=0P1<C4`204];B`80BTY:0P19BDT204M7A`80ATI600<0ADE504A4A014A4@00P13@d<20492@P80
@4100P0o?cl203dm?@80?3`l0P0j>SX203Ti>@80>3Ph0P0f=SH203@d=080<S8b0P0`<30202d];@03
02/[:`0Y:BT0:BTY00809RHV0P0T92@2024Q8@807QhN0P0J6QX201LG5`8051@D0P0A4A4200h>3P80
30`<0P0:2PX200P820801`L70P061PH00`0820P030`<00`<3002010@408051@D0P0H61P201/K6`80
7QhN0P0P8204028R8P808b<S3@0T92@402<S8`808R8R0P0Q8B44020P80807alO0P0N7Qh401dM7@80
71`L0P0K6a/201XJ6P<06ATI0P0H61P601LG5`h05QHF100G5aL501PH60@06ATI0P0J6QX201/K6`80
71`L0P0N7Qh2024Q8@808b<S0P0W9bL202`/;080<c<c0P0k>c/203lo?`80@d=30P17AdL00`1;Bd/0
Cdm?04m?C`0205=CD`80EUIF0P1GEeL205QHF080Fe]K0P1MGEd205mOG`80HF5Q0P1SHf<206ATI0@0
IVIV0P1UIFD206IVIP0306ATI01RHV80HV9R0080GemO0P1MGEd205]KF`80F5QH0P1EEED2059BDQD0
oooo000C0?ooo`80CTi>0P1=CDd204a<C080Bd];0P1:BTX204U9B@80AdM70P16ATH00`15ADD0A4A4
04A4A00204=3@`80@T920P10@40203lo?`80?Cdm0P0l?3`203Xj>P80>CTi0P0h>3P203Hf=P80=3@d
0P0b<S82030`<080;Bd]00<0:b/[02TY:@0Y:BT00P0V9RH202@T90808B4Q0P0N7Qh201XJ6P805aLG
0P0D51@2014A4@803Ph>0P0<30`200X:2P8020P80P071`L200H61P0300P8200<30`030`<0080410@
0P0D51@201PH60806a/K0P0N7Qh2020P80@08R8R0P0S8b<=02@T90@08b<S0P0R8R82024Q8@@0820P
0P0O7al201hN7P@07AdM0P0L71`201/K6`806QXJ0`0I6AT201PH60H05aLG3P0F5QH401LG5`D061PH
100I6AT201XJ6P806a/K0P0L71`201hN7P808B4Q0P0S8b<202LW9`80;2`/0P0c<c<203/k>`80?clo
0P13@d<204M7A`0304];B`1?Cdl0Cdm?0080De=C0P1FEUH205MGE`80F5QH0P1KFe/205eMG@80GemO
0P1QHF4206=SH`80I6AT101VIVH206EUI@80IVIV00<0I6AT069RHP1RHV800P1OGel205eMG@80Fe]K
0P1HF5P205EEE@80DU9B5@3oool001<0oooo0P1>CTh204e=C@80C4a<0P1;Bd/204Y:BP80B4Q80P17
AdL204I6AP0304E5A@13@d<0@d=30080@D510P10@40203lo?`80?Cdm0P0l?3`203Xj>P80>CTi0P0g
=cL203De=@80<c<c0P0b<S8202l_;`80;Bd]0P0[:b/00`0X:2P09RHV02HV9P0202<S8`80820P0P0M
7Ad201XJ6P805aLG0P0D51@2014A4@803Ph>0P0;2`/200X:2PP020P800<01PH600P8200820P00P0=
3@d2018B4P805QHF0P0J6QX201dM7@807alO0P0P8202024Q8@@08R8R200S8b<5028R8P808B4Q100P
820201lO7`807QhN0P0M7Ad201`L70806a/K0P0J6QX201TI6@8061PH100G5aL00`0F5QH05ADE01DE
5@0401@D51004a<C100D51@401DE5@0301HF5P0G5aL05aLG00806ATI0P0J6QX201/K6`807AdM0P0O
7al2028R8P809RHV0P0/;2`203@d=080>c/k0P0o?cl204=3@`80B4Q80P1=CDd00`1@D500De=C05=C
D`0205EEE@80F5QH0P1KFe/205iNGP80H61P0P1RHV8206ATI080IFEU201WIfL406QXJ00306IVIP1S
Hf<0Hf=S0080H61P0P1NGUh205]KF`80F5QH0P1EEED2059BDQD0oooo000C0?ooo`80CTi>0P1=CDd2
04a<C080Bd];0P1:BTX204Q8B080AdM70P16ATH00`15ADD0@d=304=3@`020451@@80@4100P0o?cl2
03dm?@80?3`l0P0j>SX203Ti>@80=cLg0P0e=CD203<c<`80<S8b0P0_;bl202d];@80:b/[00<0:2PX
02HV9P0V9RH00P0S8b<2020P80807AdM0P0J6QX201LG5`8051@D0P0A4A4200h>3P802`/;0P0:2PX8
00P8200300H61P0820P020P800803@d=0P0B4Q8201HF5P806QXJ0P0M7Ad201lO7`80820P0P0Q8B44
028R8PP08b<S1@0R8R82024Q8@@0820P0P0O7al201hN7P807AdM0P0L71`201/K6`806QXJ0P0I6AT2
01PH60@05aLG00<05QHF01DE5@0E5AD0100D51@@01<C4`@051@D100E5AD00`0F5QH05aLG01LG5`02
01TI6@806QXJ0P0K6a/201dM7@807alO0P0R8R8202HV9P80;2`/0P0d=3@203/k>`80?clo0P13@d<2
04Q8B080CDe=00<0D51@05=CD`1CDe<00P1EEED205QHF080Fe]K0P1NGUh2061PH080HV9R0P1TI6@2
06EUI@P0IfMW101XJ6P00`1VIVH0Hf=S06=SH`02061PH080GUiN0P1KFe/205QHF080EEEE0P1BDU8E
0?ooo`004`3oool204i>CP80CDe=0P1<C4`204];B`80BDU90P18B4P204M7A`80ADE500<0A4A40492
@P12@T800P10@40203lo?`80?Cdm0P0l?3`203Xj>P80>CTi0P0g=cL203De=@80<c<c0P0a<C4202l_
;`80;Bd]0P0[:b/202TY:@0302HV9P0S8b<08b<S00808B4Q0P0N7Qh201/K6`805aLG0P0D51@2010@
40803@d=0P0:2PX400T92@@020P81@092@T200P820802`/;0P0A4A4201HF5P806QXJ0P0M7Ad201lO
7`80820P0P0Q8B4<028R8P<08B4Q0P0P820201lO7`@07QhN0P0M7Ad201`L70806a/K0P0J6QX201TI
6@8061PH0P0G5aL201HF5P805ADE0`0D51@201<C4`804Q8B0P0A4A48010@40X04A4A0P0B4Q8201<C
4`8051@D00<05ADE01HF5P0F5QH00P0H61P201XJ6P8071`L0P0N7Qh2028R8P809bLW0P0];Bd203De
=@80?3`l0P11@D4204A4A080AdM70P1<C4`2051@D00305=CD`1EEED0EEEE0080F5QH0P1LG5`205mO
G`80HV9R0P1UIFD206MWI`80J6QX101ZJVX806][J`80JFUY00<0IfMW06EUI@1UIFD00P1RHV8205mO
G`80G5aL0P1IFET205IFEP80DU9B5@3oool001<0oooo0P1>CTh204e=C@80C4a<0P1;Bd/204U9B@80
B4Q80P17AdL204E5A@0304A4A012@T80@T920080@4100P0o?cl203dm?@80?3`l0P0j>SX203Ti>@80
=cLg0P0e=CD203<c<`80<C4a0P0_;bl202d];@80:b/[0P0Y:BT00`0V9RH08b<S02<S8`02024Q8@80
7QhN0P0K6a/201LG5`8051@D0P0@410200d=3@802PX:10092@T400P820D02@T90P0820P200/;2`80
4A4A0P0F5QH201XJ6P807AdM0P0O7al2020P80808B4Q300R8R83024Q8@80820P0P0O7al401hN7P80
7AdM0P0L71`201/K6`806QXJ0P0I6AT201PH60805aLG0P0F5QH201DE5@<051@D0P0C4a<2018B4P80
4A4A200@410:014A4@804Q8B0P0C4a<201@D500301DE5@0F5QH05QHF008061PH0P0J6QX201`L7080
7QhN0P0R8R8202LW9`80;Bd]0P0e=CD203`l?080@D510P14A4@204M7A`80C4a<0P1@D5000`1CDe<0
EEEE05EEE@0205QHF080G5aL0P1OGel2069RHP80IFEU0P1WIfL206QXJ0@0JVYZ201[Jf/206UYJ@03
06MWI`1UIFD0IFEU0080HV9R0P1OGel205aLG080FEUI0P1FEUH2059BDQD0oooo000C0?ooo`80CTi>
0P1=CDd204];B`80BTY:0P19BDT204M7A`80ATI60P14A4@00`13@d<0@D510451@@020410@080?Shn
0P0l?3`203/k>`80>CTi0P0g=cL203Hf=P80=3@d0P0a<C4202l_;`80;Bd]0P0[:b/202TY:@809RHV
00<092@T024Q8@0Q8B400P0N7Qh201/K6`8061PH0P0E5AD2014A4@803Ph>0P0;2`/800P820802@T9
0P0:2PX300/;2`@03@d=0P0A4A4201LG5`806a/K0P0M7Ad201lO7`80820P0P0Q8B48028R8P@08B4Q
00<0820P01lO7`0O7al00P0O7al201hN7P807AdM0P0L71`201/K6`806QXJ0P0I6AT201PH60805aLG
0P0F5QH401@D50804a<C0P0B4Q800`0A4A40410@010@400400l?3`@03Ph>0P0=3@d800h>3P@03`l?
0P0@4102014A4@804a<C00<051@D01HF5P0F5QH00P0H61P201XJ6P807AdM0P0R8R8202LW9`80;Rh^
0P0e=CD203/k>`80@D510P14A4@204Q8B080C4a<0P1@D50205ADE00305MGE`1KFe/0Fe]K0080GUiN
0P1QHF4206ATI080IfMW0P1YJFT206][J`80K6a/101]KFd406i^KP80KFe]0P1[Jf/206YZJP0306QX
J01UIFD0IFEU0080HV9R0P1OGel205aLG080F5QH0P1EEED2059BDQD0oooo000C0?ooo`80CTi>0P1=
CDd204];B`80BTY:0P19BDT204M7A`80ATI60P14A4@00`13@d<0@D510451@@020410@080?Shn0P0l
?3`203/k>`80>CTi0P0g=cL203Hf=P80=3@d0P0a<C4202l_;`80;Bd]0P0[:b/202TY:@809RHV00<0
92@T024Q8@0Q8B400P0N7Qh201/K6`8061PH0P0E5AD2014A4@803Ph>0P0;2`/800P820802@T90P0:
2PX300/;2`@03@d=0P0A4A4201LG5`806a/K0P0M7Ad201lO7`80820P0P0Q8B48028R8P@08B4Q00<0
820P01lO7`0O7al00P0O7al201hN7P807AdM0P0L71`201/K6`806QXJ0P0I6AT201PH60805aLG0P0F
5QH401@D50804a<C0P0B4Q800`0A4A40410@010@400400l?3`@03Ph>0P0=3@d800h>3P@03`l?0P0@
4102014A4@804a<C00<051@D01HF5P0F5QH00P0H61P201XJ6P807AdM0P0R8R8202LW9`80;Rh^0P0e
=CD203/k>`80@D510P14A4@204Q8B080C4a<0P1@D50205ADE00305MGE`1KFe/0Fe]K0080GUiN0P1Q
HF4206ATI080IfMW0P1YJFT206][J`80K6a/101]KFd406i^KP80KFe]0P1[Jf/206YZJP0306QXJ01U
IFD0IFEU0080HV9R0P1OGel205aLG080F5QH0P1EEED2059BDQD0oooo000C0?ooo`80CTi>0P1=CDd2
04];B`80BDU90P18B4P204I6AP80ADE50P14A4@00`12@T80@4100410@00203hn?P80?Cdm0P0l?3`2
03Xj>P80=cLg0P0e=CD203@d=080<S8b0P0`<30202d];@80:b/[0P0Y:BT202HV9P8092@T00<08B4Q
01lO7`0O7al00P0L71`201TI6@805ADE0P0B4Q8200l?3`802`/;0P0820P400H61P801`L70P0820P2
00X:2P8030`<0P0=3@d00`0>3Ph04A4A014A4@0201@D508061PH0P0I6AT201`L70807alO0P0P8202
024Q8@P08R8R100Q8B42020P800301lO7`0N7Qh07QhN00@07AdM0P0L71`201/K6`806QXJ0P0I6AT2
01PH60805QHF0P0E5AD201@D50@04Q8B0P0A4A42010@400300l?3`0>3Ph03Ph>00803@d=100<30`4
00/;2`8030`<2P0=3@d200l?3`80410@0P0B4Q800`0D51@05aLG01LG5`0201XJ6P807QhN0P0S8b<2
02TY:@80;bl_0P0f=SH203/k>`80@4100P15ADD204Q8B080C4a<0P1@D50205ADE080EeMG00<0Fe]K
05iNGP1NGUh00P1QHF4206ATI080IfMW0P1ZJVX206a/K080KVi^0P1_Kfl4071`L080LG5a0P1`L702
06m_K`80KVi^0P1[Jf/00`1YJFT0IVIV06IVIP02069RHP80GemO0P1LG5`205UIF@80EUIF0P1BDU8E
0?ooo`004`3oool204i>CP80CDe=0P1;Bd/204U9B@80B4Q80P16ATH204E5A@80A4A400<0@T920410
@010@4000P0n?Sh203dm?@80?3`l0P0j>SX203Lg=`80=CDe0P0d=3@2038b<P80<30`0P0];Bd202/[
:`80:BTY0P0V9RH202@T9003024Q8@0O7al07alO008071`L0P0I6AT201DE5@804Q8B0P0?3`l200/;
2`8020P810061PH200L71`8020P80P0:2PX200`<30803@d=00<03Ph>014A4@0A4A400P0D51@201PH
60806ATI0P0L71`201lO7`80820P0P0Q8B48028R8P@08B4Q0P0P82000`0O7al07QhN01hN7P0401dM
7@8071`L0P0K6a/201XJ6P806ATI0P0H61P201HF5P805ADE0P0D51@4018B4P804A4A0P0@41000`0?
3`l03Ph>00h>3P0200d=3@@030`<100;2`/200`<30X03@d=0P0?3`l2010@40804Q8B00<051@D01LG
5`0G5aL00P0J6QX201hN7P808b<S0P0Y:BT202l_;`80=SHf0P0k>c/20410@080ADE50P18B4P204a<
C080D51@0P1DE5@205MGE`0305]KF`1NGUh0GUiN0080HF5Q0P1TI6@206MWI`80JVYZ0P1/K6`206i^
KP80Kfm_101`L702075aL@80L71`0P1_Kfl206i^KP80Jf][00<0JFUY06IVIP1VIVH00P1RHV8205mO
G`80G5aL0P1IFET205IFEP80DU9B5@3oool001<0oooo0P1>CTh204a<C080Bd];0P19BDT204M7A`80
ATI60P14A4@204=3@`030451@@0o?cl0?clo0080?Shn0P0l?3`203Xj>P80>3Ph0P0g=cL203@d=080
<S8b0P0`<30202d];@80:b/[0P0Y:BT202LW9`8092@T0P0R8R800`0O7al071`L01`L700201TI6@80
5QHF0P0C4a<200l?3`8030`<0P092@T200D51@8010@40P061PH200L71`802@T90P0;2`/200d=3@80
3`l?00<04Q8B01DE5@0E5AD00P0H61P201TI6@806a/K0P0O7al2024Q8@808R8R1P0S8b<4028R8P80
8B4Q0P0P820201lO7`<07QhN0P0M7Ad201`L70806QXJ0P0I6AT201PH60805aLG0P0F5QH201DE5@80
51@D0P0B4Q82014A4@80410@0P0?3`l200h>3P0300d=3@0<30`030`<00802`/;200:2PX200/;2`80
30`<0P0;2`/200X:2P802`/;0P0=3@d200l?3`804A4A0P0C4a<00`0F5QH06QXJ01XJ6P0201hN7P80
8b<S0P0Z:RX2034a<@80=cLg0P0l?3`20492@P80AdM70P1:BTX204e=C@80D51@0P1DE5@205QHF080
FUYJ00<0GEeM061PH01PH6000P1TI6@206MWI`80JFUY0P1/K6`206m_K`80LG5a101bLW8407=cL`80
LW9b0P1aLG4206m_K`80K6a/00<0JFUY06EUI@1UIFD00P1RHV8205mOG`80G5aL0P1IFET205IFEP80
DU9B5@3oool001<0oooo0P1>CTh204a<C080Bd];0P19BDT204M7A`80ATI60P14A4@204=3@`030451
@@0o?cl0?clo0080?Shn0P0l?3`203Xj>P80>3Ph0P0g=cL203@d=080<S8b0P0`<30202d];@80:b/[
0P0Y:BT202LW9`8092@T0P0R8R800`0O7al071`L01`L700201TI6@805QHF0P0C4a<200l?3`8030`<
0P092@T200D51@8010@40P061PH200L71`802@T90P0;2`/200d=3@803`l?00<04Q8B01DE5@0E5AD0
0P0H61P201TI6@806a/K0P0O7al2024Q8@808R8R1P0S8b<4028R8P808B4Q0P0P820201lO7`<07QhN
0P0M7Ad201`L70806QXJ0P0I6AT201PH60805aLG0P0F5QH201DE5@8051@D0P0B4Q82014A4@80410@
0P0?3`l200h>3P0300d=3@0<30`030`<00802`/;200:2PX200/;2`8030`<0P0;2`/200X:2P802`/;
0P0=3@d200l?3`804A4A0P0C4a<00`0F5QH06QXJ01XJ6P0201hN7P808b<S0P0Z:RX2034a<@80=cLg
0P0l?3`20492@P80AdM70P1:BTX204e=C@80D51@0P1DE5@205QHF080FUYJ00<0GEeM061PH01PH600
0P1TI6@206MWI`80JFUY0P1/K6`206m_K`80LG5a101bLW8407=cL`80LW9b0P1aLG4206m_K`80K6a/
00<0JFUY06EUI@1UIFD00P1RHV8205mOG`80G5aL0P1IFET205IFEP80DU9B5@3oool001<0oooo0P1>
CTh204a<C080BTY:0P19BDT204M7A`80ATI60P14A4@20492@P030451@@0o?cl0?clo0080?Cdm0P0k
>c/203Ti>@80=cLg0P0e=CD203<c<`80<C4a0P0^;Rh202`/;080:RXZ0P0W9bL202DU9@808R8R0P0P
82000`0M7Ad06QXJ01XJ6P0201LG5`8051@D0P0@410200d=3@802PX:0P061PH400@410801@D50P07
1`L200T92@8030`<0P0>3Ph2014A4@0301DE5@0I6AT06ATI00806a/K0P0M7Ad2020P80808R8R0P0S
8b<602@T90808b<S100R8R82024Q8@80820P0P0O7al00`0N7Qh07AdM01dM7@0201`L70806a/K0P0I
6AT201PH60805aLG0P0F5QH201DE5@804a<C0P0B4Q82014A4@80410@0P0?3`l200h>3P8030`<00<0
2`/;00X:2P0:2PX00P0:2PX200T92@8020P80P092@T600X:2P802@T90P0:2PX200d=3@803Ph>0P0@
4102018B4P8051@D00<06ATI01lO7`0O7al00P0T92@202XZ:P80<30`0P0f=SH203/k>`80@4100P15
ADD204U9B@80CDe=0P1ADE4205ADE080EeMG0P1KFe/205iNGP03069RHP1TI6@0I6AT0080J6QX0P1Z
JVX206e]K@80L71`101cLg<207AdM0H0MGEe0P1cLg<2075aL@80Kfm_0P1/K6`00`1YJFT0IVIV06IV
IP0206=SH`80GemO0P1LG5`205UIF@80EUIF0P1BDU8E0?ooo`004`3oool204i>CP80C4a<0P1:BTX2
04U9B@80AdM70P16ATH204A4A080@T9200<0@D5103lo?`0o?cl00P0m?Cd203/k>`80>CTi0P0g=cL2
03De=@80<c<c0P0a<C4202h^;P80;2`/0P0Z:RX202LW9`809BDU0P0R8R82020P800301dM7@0J6QX0
6QXJ00805aLG0P0D51@2010@40803@d=0P0:2PX200H61P@010@40P051@D200L71`802@T90P0<30`2
00h>3P804A4A00<05ADE01TI6@0I6AT00P0K6a/201dM7@80820P0P0R8R8202<S8`H092@T0P0S8b<4
028R8P808B4Q0P0P820201lO7`0301hN7P0M7Ad07AdM008071`L0P0K6a/201TI6@8061PH0P0G5aL2
01HF5P805ADE0P0C4a<2018B4P804A4A0P0@410200l?3`803Ph>0P0<30`00`0;2`/02PX:00X:2P02
00X:2P802@T90P0820P200T92@H02PX:0P092@T200X:2P803@d=0P0>3Ph2010@40804Q8B0P0D51@0
0`0I6AT07alO01lO7`0202@T9080:RXZ0P0`<30203Hf=P80>c/k0P10@40204E5A@80BDU90P1=CDd2
055AD@80E5AD0P1GEeL205]KF`80GUiN00<0HV9R06ATI01TI6@00P1XJ6P206YZJP80KFe]0P1`L704
07=cL`80M7Ad1P1eMGD207=cL`80LG5a0P1_Kfl206a/K00306UYJ@1VIVH0IVIV0080Hf=S0P1OGel2
05aLG080FEUI0P1FEUH2059BDQD0oooo000C0?ooo`80CDe=0P1<C4`204Y:BP80BDU90P17AdL204E5
A@80@d=30P12@T800`10@400?Shn03hn?P0203`l?080>SXj0P0h>3P203Hf=P80=3@d0P0a<C4202l_
;`80;Bd]0P0[:b/202PX:0809RHV0P0S8b<2024Q8@807QhN00<06a/K01PH600H61P00P0E5AD2018B
4P803`l?0P0;2`/200P8208010@410030`<200D51@801`L70P092@T200`<30803`l?0P0C4a<00`0H
61P071`L01`L700201hN7P80820P0P0U9BD402HV9PH09BDU0P0T92@402<S8`808R8R0P0P820201lO
7`0301hN7P0L71`071`L00806a/K0P0J6QX201TI6@805aLG0P0F5QH201DE5@804a<C0P0B4Q82014A
4@80410@0P0>3Ph200d=3@8030`<0P0;2`/00`0:2PX02@T900T92@0800P820@02@T90P071`L200P8
20802PX:0P0=3@d200l?3`804A4A0P0E5AD201TI6@0301lO7`0V9RH09RHV0080:b/[0P0a<C4203Hf
=P80>c/k0P0o?cl204A4A080BDU90P1=CDd2055AD@80E5AD0P1IFET205eMG@80H61P0P1RHV800`1U
IFD0IfMW06MWI`0206YZJP80KFe]0P1`L70207=cL`80MGEe0P1fMWH207MgM`@0N7Qh0P1fMWH207Ad
M080LG5a0P1_Kfl206a/K00306UYJ@1VIVH0IVIV0080HV9R0P1OGel205aLG080FEUI0P1FEUH2059B
DQD0oooo000C0?ooo`80CDe=0P1<C4`204Y:BP80BDU90P17AdL204E5A@80@d=30P12@T800`10@400
?Shn03hn?P0203`l?080>SXj0P0h>3P203Hf=P80=3@d0P0a<C4202l_;`80;Bd]0P0[:b/202PX:080
9RHV0P0S8b<2024Q8@807QhN00<06a/K01PH600H61P00P0E5AD2018B4P803`l?0P0;2`/200P82080
10@410030`<200D51@801`L70P092@T200`<30803`l?0P0C4a<00`0H61P071`L01`L700201hN7P80
820P0P0U9BD402HV9PH09BDU0P0T92@402<S8`808R8R0P0P820201lO7`0301hN7P0L71`071`L0080
6a/K0P0J6QX201TI6@805aLG0P0F5QH201DE5@804a<C0P0B4Q82014A4@80410@0P0>3Ph200d=3@80
30`<0P0;2`/00`0:2PX02@T900T92@0800P820@02@T90P071`L200P820802PX:0P0=3@d200l?3`80
4A4A0P0E5AD201TI6@0301lO7`0V9RH09RHV0080:b/[0P0a<C4203Hf=P80>c/k0P0o?cl204A4A080
BDU90P1=CDd2055AD@80E5AD0P1IFET205eMG@80H61P0P1RHV800`1UIFD0IfMW06MWI`0206YZJP80
KFe]0P1`L70207=cL`80MGEe0P1fMWH207MgM`@0N7Qh0P1fMWH207AdM080LG5a0P1_Kfl206a/K003
06UYJ@1VIVH0IVIV0080HV9R0P1OGel205aLG080FEUI0P1FEUH2059BDQD0oooo000C0?ooo`80CDe=
0P1<C4`204Y:BP80B4Q80P16ATH204A4A080@T920P11@D400`0o?cl0?Cdm03dm?@0203/k>`80>CTi
0P0g=cL203De=@80<S8b0P0`<30202h^;P80:b/[0P0Y:BT202LW9`8092@T0P0R8R8201lO7`8071`L
00<06ATI01HF5P0F5QH00P0C4a<2010@408030`<0P092@T200H61PH00`<30P061PH200P820802`/;
0P0>3Ph2014A4@805QHF00<06QXJ01dM7@0M7Ad00P0P820202@T90H0:BTY0P0X:2P402LW9`809RHV
0P0U9BD202@T90808R8R0P0Q8B42020P800301hN7P0L71`071`L00806a/K0P0J6QX201PH60805QHF
0P0E5AD201@D50804a<C0P0A4A42010@40803`l?0P0>3Ph200d=3@8030`<0P0;2`/00`0:2PX020P8
00P8200200P820801`L71P0820P200L71`8020P80P0:2PX200`<30803`l?0P0A4A4201DE5@806ATI
0P0P82000`0V9RH0;2`/02`/;002038b<P80>3Ph0P0l?3`20451@@80ATI60P1:BTX204i>CP80DE5A
0P1DE5@205QHF080GEeM0P1QHF4206=SH`80IFEU00<0J6QX06][J`1[Jf/00P1^KVh2075aL@80M7Ad
0P1gMgL207QhN080NGUi101jNWX207QhN080MWIf0P1dM7@2075aL@80Kfm_0P1[Jf/00`1YJFT0IVIV
06IVIP02069RHP80GemO0P1LG5`205UIF@80EUIF0P1BDU8E0?ooo`004`3oool204e=C@80C4a<0P1:
BTX204Q8B080ATI60P14A4@20492@P80@D5100<0?clo03dm?@0m?Cd00P0k>c/203Ti>@80=cLg0P0e
=CD2038b<P80<30`0P0^;Rh202/[:`80:BTY0P0W9bL202@T90808R8R0P0O7al201`L700301TI6@0F
5QH05QHF00804a<C0P0@410200`<30802@T90P061PH600<30`801PH60P0820P200/;2`803Ph>0P0A
4A4201HF5P0301XJ6P0M7Ad07AdM0080820P0P0T92@602TY:@80:2PX100W9bL202HV9P809BDU0P0T
92@2028R8P808B4Q0P0P82000`0N7Qh071`L01`L700201/K6`806QXJ0P0H61P201HF5P805ADE0P0D
51@201<C4`804A4A0P0@410200l?3`803Ph>0P0=3@d200`<30802`/;00<02PX:00P8200820P00P08
20P200L71`H020P80P071`L200P820802PX:0P0<30`200l?3`804A4A0P0E5AD201TI6@80820P00<0
9RHV02`/;00/;2`00P0b<S8203Ph>080?3`l0P11@D4204I6AP80BTY:0P1>CTh2055AD@80E5AD0P1H
F5P205eMG@80HF5Q0P1SHf<206EUI@0306QXJ01[Jf/0Jf][0080KVi^0P1aLG4207AdM080MgMg0P1h
N7P207UiN@@0NWYj0P1hN7P207IfMP80M7Ad0P1aLG4206m_K`80Jf][00<0JFUY06IVIP1VIVH00P1R
HV8205mOG`80G5aL0P1IFET205IFEP80DU9B5@3oool001<0oooo0P1=CDd204];B`80BTY:0P18B4P2
04I6AP80A4A40P12@T820410@00303hn?P0l?3`0?3`l0080>SXj0P0h>3P203De=@80<c<c0P0a<C42
02l_;`80;2`/0P0Z:RX202PX:0809BDU0P0R8R82020P80807AdM0P0J6QX00`0G5aL051@D01@D5002
014A4@803@d=0P0:2PX200L71`8010@40P020P8200<30`8010@40P061PH200T92@8030`<0P0@4102
01@D50806ATI00<06a/K01hN7P0N7Qh00P0R8R8202LW9`@0;2`/0P0[:b/202XZ:P@0:BTY0P0X:2P2
02HV9P8092@T0P0S8b<2028R8P80820P00<07QhN01dM7@0M7Ad00P0K6a/201TI6@8061PH0P0F5QH2
01DE5@8051@D0P0B4Q82014A4@80410@0P0?3`l200h>3P8030`<100;2`/00`0:2PX02@T900T92@04
00P820H02@T90P0820P200T92@8030`<0P0>3Ph2014A4@805ADE0P0J6QX2020P80809BDU00<0;2`/
038b<P0b<S800P0g=cL203dm?@80@T920P17AdL204Y:BP80CDe=0P1ADE4205ADE080F5QH0P1LG5`2
061PH080Hf=S0P1WIfL206UYJ@0306a/K01_Kfl0Kfm_0080LW9b0P1dM7@207MgM`80NGUi0P1jNWX2
07]kN`80O7al0P1kNg/207UiN@80MgMg0P1dM7@2079bLP80Kfm_0P1/K6`00`1YJFT0IVIV06IVIP02
069RHP80GemO0P1LG5`205UIF@80EEEE0P1BDU8E0?ooo`004`3oool204e=C@80Bd];0P19BDT204M7
A`80ADE50P13@d<20451@@80?clo00<0?Cdm03/k>`0k>c/00P0i>CT203Lg=`80=3@d0P0b<S82030`
<080;Bd]0P0[:b/202TY:@809RHV0P0S8b<2024Q8@807QhN0P0K6a/201PH600301DE5@0B4Q804Q8B
00803`l?0P0<30`200T92@801PH60P030`<200410@800P820P0410@200L71`802PX:0P0>3Ph2014A
4@805QHF0P0J6QX00`0L71`0820P020P800202HV9P80:b/[0P0`<30202l_;`80;Rh^0P0];Bd202`/
;080:b/[0P0Y:BT202PX:0809bLW0P0U9BD202<S8`808B4Q00<0820P01hN7P0N7Qh00P0L71`201XJ
6P806ATI0P0G5aL201DE5@8051@D0P0C4a<2018B4P80410@0P0?3`l200h>3P803@d=0P0<30`200/;
2`<02PX:10092@T400X:2P802@T90P0:2PX200`<30803`l?0P0B4Q8201DE5@806QXJ0P0O7al202@T
9080:RXZ00<0<C4a03Lg=`0g=cL00P0m?Cd20492@P80AdM70P1;Bd/204m?C`80DE5A0P1DE5@205QH
F080G5aL0P1OGel206=SH`80IVIV0P1YJFT206][J`0306m_K`1bLW80LW9b0080M7Ad0P1hN7P207Yj
NP80Ng]k101mOGd207alO080NWYj0P1hN7P207MgM`80MGEe0P1bLW8206m_K`80K6a/00<0JFUY06IV
IP1VIVH00P1RHV8205mOG`80G5aL0P1IFET205IFEP80DU9B5@3oool001<0oooo0P1=CDd204];B`80
BDU90P17AdL204E5A@80@d=30P11@D4203lo?`0303dm?@0k>c/0>c/k0080>CTi0P0g=cL203@d=080
<S8b0P0`<30202d];@80:b/[0P0Y:BT202HV9P808b<S0P0Q8B4201hN7P806a/K0P0H61P00`0E5AD0
4Q8B018B4P0200l?3`8030`<0P092@T200H61P800`<30P010@4200820P8010@40P071`L200X:2P80
3Ph>0P0A4A4201HF5P806QXJ00<071`L020P800P82000P0V9RH202/[:`80<30`0P0_;bl202h^;P80
;Bd]0P0/;2`202/[:`80:BTY0P0X:2P202LW9`809BDU0P0S8b<2024Q8@03020P800N7Qh07QhN0080
71`L0P0J6QX201TI6@805aLG0P0E5AD201@D50804a<C0P0B4Q82010@40803`l?0P0>3Ph200d=3@80
30`<0P0;2`/300X:2P@02@T9100:2PX200T92@802PX:0P0<30`200l?3`804Q8B0P0E5AD201XJ6P80
7alO0P0T92@202XZ:P03034a<@0g=cL0=cLg0080?Cdm0P12@T8204M7A`80Bd];0P1?Cdl2055AD@80
E5AD0P1HF5P205aLG080GemO0P1SHf<206IVIP80JFUY0P1[Jf/00`1_Kfl0LW9b079bLP0207AdM080
N7Qh0P1jNWX207]kN`@0OGem0P1lO7`207YjNP80N7Qh0P1gMgL207EeM@80LW9b0P1_Kfl206a/K003
06UYJ@1VIVH0IVIV0080HV9R0P1OGel205aLG080FEUI0P1FEUH2059BDQD0oooo000C0?ooo`80CDe=
0P1;Bd/204U9B@80AdM70P15ADD20492@P80@4100P0n?Sh00`0l?3`0>SXj03Xj>P0203Ph>080=SHf
0P0c<c<2034a<@80;Rh^0P0/;2`202TY:@809bLW0P0T92@2024Q8@807alO0P0L71`201TI6@805QHF
00<04a<C010@400@41000P0=3@d200X:2P801`L70P0410@400410@800P820P0410@200L71`802`/;
0P0?3`l201<C4`8061PH0P0L71`00`0P820092@T02@T900202XZ:P80;bl_0P0c<c<2038b<P80<C4a
0P0`<30202l_;`80;Bd]0P0/;2`202XZ:P80:BTY0P0W9bL202DU9@808b<S00<08B4Q020P800P8200
0P0N7Qh201`L70806QXJ0P0H61P201HF5P805ADE0P0D51@2018B4P804A4A0P0@410200l?3`803Ph>
0P0=3@d200`<300300/;2`0:2PX02PX:00802PX:1P0;2`/200`<30803Ph>0P0@410201<C4`805QHF
0P0K6a/2020P808092@T0P0Z:RX2034a<@0303Lg=`0l?3`0?3`l0080@D510P16ATH204];B`80Cdm?
0P1CDe<205IFEP80FEUI0P1LG5`205mOG`80Hf=S0P1VIVH206UYJ@80K6a/0P1_Kfl00`1bLW80Lg=c
07=cL`0207IfMP80NWYj0P1lO7`607inOP80O7al0P1kNg/207UiN@80MgMg0P1eMGD2079bLP80Kfm_
0P1/K6`00`1YJFT0IVIV06IVIP02069RHP80GemO0P1LG5`205UIF@80EUIF0P1BDU8E0?ooo`004`3o
ool204e=C@80Bd];0P19BDT204M7A`80ADE50P12@T820410@080?Shn00<0?3`l03Xj>P0j>SX00P0h
>3P203Hf=P80<c<c0P0a<C4202h^;P80;2`/0P0Y:BT202LW9`8092@T0P0Q8B4201lO7`8071`L0P0I
6AT201HF5P0301<C4`0@4100410@00803@d=0P0:2PX200L71`8010@410010@4200820P8010@40P07
1`L200/;2`803`l?0P0C4a<201PH608071`L00<0820P02@T900T92@00P0Z:RX202l_;`80<c<c0P0b
<S82034a<@80<30`0P0_;bl202d];@80;2`/0P0Z:RX202TY:@809bLW0P0U9BD202<S8`03024Q8@0P
8200820P00807QhN0P0L71`201XJ6P8061PH0P0F5QH201DE5@8051@D0P0B4Q82014A4@80410@0P0?
3`l200h>3P803@d=0P0<30`00`0;2`/02PX:00X:2P0200X:2PH02`/;0P0<30`200h>3P80410@0P0C
4a<201HF5P806a/K0P0P820202@T9080:RXZ0P0a<C400`0g=cL0?3`l03`l?0020451@@80ATI60P1;
Bd/204m?C`80De=C0P1FEUH205UIF@80G5aL0P1OGel206=SH`80IVIV0P1YJFT206a/K080Kfm_00<0
LW9b07=cL`1cLg<00P1fMWH207YjNP80O7al1P1nOWh207alO080Ng]k0P1iNGT207MgM`80MGEe0P1b
LW8206m_K`80K6a/00<0JFUY06IVIP1VIVH00P1RHV8205mOG`80G5aL0P1IFET205IFEP80DU9B5@3o
ool001<0oooo0P1=CDd204];B`80B4Q80P16ATH204A4A080@T920P10@40203hn?P0303`l?00i>CT0
>CTi0080=cLg0P0d=3@2038b<P80<30`0P0];Bd202/[:`80:2PX0P0U9BD2028R8P80820P0P0M7Ad2
01/K6`8061PH0P0E5AD00`0B4Q803`l?00l?3`0200`<308020P80P051@D200820P8000000P010@42
00<30`801@D50P092@T200h>3P804A4A0P0F5QH201/K6`807alO00<08R8R02PX:00X:2P00P0];Bd2
038b<P80=cLg0P0f=SH203De=@80<c<c0P0b<S82030`<080;bl_0P0];Bd202/[:`80:BTY0P0X:2P2
02HV9P0302@T900R8R808R8R0080820P0P0N7Qh201`L70806QXJ0P0H61P201HF5P805ADE0P0C4a<2
018B4P804A4A0P0@410200l?3`803Ph>0P0=3@d500`<30H03@d=0P0>3Ph2014A4@805ADE0P0H61P2
01`L7080820P0P0T92@202XZ:P80<C4a0P0g=cL00`0l?3`0@D510451@@0204I6AP80Bd];0P1@D502
05ADE080F5QH0P1JFUX205eMG@80H61P0P1TI6@206IVIP80JFUY0P1/K6`206m_K`80LG5a00<0Lg=c
07IfMP1fMWH00P1iNGT207emO@80Ogmo1020P80207moO`80OGem0P1kNg/207UiN@80MgMg0P1eMGD2
079bLP80Kfm_0P1/K6`00`1YJFT0IFEU06EUI@02069RHP80GemO0P1LG5`205UIF@80EUIF0P1BDU8E
0?ooo`004`3oool204e=C@80Bd];0P18B4P204I6AP80A4A40P12@T820410@080?Shn00<0?3`l03Ti
>@0i>CT00P0g=cL203@d=080<S8b0P0`<30202d];@80:b/[0P0X:2P202DU9@808R8R0P0P820201dM
7@806a/K0P0H61P201DE5@03018B4P0?3`l03`l?008030`<0P0820P200D51@800P820P0000020041
0@800`<30P051@D200T92@803Ph>0P0A4A4201HF5P806a/K0P0O7al00`0R8R80:2PX02PX:00202d]
;@80<S8b0P0g=cL203Hf=P80=CDe0P0c<c<2038b<P80<30`0P0_;bl202d];@80:b/[0P0Y:BT202PX
:0809RHV00<092@T028R8P0R8R800P0P820201hN7P8071`L0P0J6QX201PH60805QHF0P0E5AD201<C
4`804Q8B0P0A4A42010@40803`l?0P0>3Ph200d=3@D030`<1P0=3@d200h>3P804A4A0P0E5AD201PH
608071`L0P0P820202@T9080:RXZ0P0a<C4203Lg=`0303`l?011@D40@D510080ATI60P1;Bd/2051@
D080E5AD0P1HF5P205YJFP80GEeM0P1PH60206ATI080IVIV0P1YJFT206a/K080Kfm_0P1aLG400`1c
Lg<0MWIf07IfMP0207UiN@80OGem0P1oOgl40820P080Ogmo0P1mOGd207]kN`80NGUi0P1gMgL207Ee
M@80LW9b0P1_Kfl206a/K00306UYJ@1UIFD0IFEU0080HV9R0P1OGel205aLG080FEUI0P1FEUH2059B
DQD0oooo000C0?ooo`80CDe=0P1;Bd/204U9B@80ATI60P14A4@20492@P80?clo0P0m?Cd00`0k>c/0
>CTi03Ti>@0203Hf=P80=3@d0P0a<C4202l_;`80;2`/0P0Y:BT202LW9`8092@T0P0Q8B4201lO7`80
71`L0P0I6AT201HF5P804a<C00<0410@00d=3@0=3@d00P0:2PX200L71`8010@40P010@4200000080
0@410P030`<200L71`802PX:0P0?3`l201@D50806ATI0P0M7Ad2024Q8@0302HV9P0];Bd0;Bd]0080
<c<c0P0g=cL203/k>`80>SXj0P0i>CT203Ph>080=SHf0P0d=3@2038b<P80<30`0P0^;Rh202d];@80
:b/[0P0Y:BT00`0W9bL09BDU02DU9@0202<S8`808B4Q0P0O7al201dM7@806a/K0P0I6AT201LG5`80
5QHF0P0D51@201<C4`804Q8B0P0A4A42010@40803`l?1@0>3Ph200l?3`80410@0P0A4A4201<C4`80
5QHF0P0I6AT201dM7@80820P0P0S8b<202PX:080;bl_0P0f=SH203dm?@030492@P16ATH0ATI60080
BTY:0P1>CTh205=CD`80EeMG0P1KFe/205mOG`80HV9R0P1UIFD206QXJ080JVYZ0P1/K6`206m_K`80
LG5a0P1cLg<00`1eMGD0NGUi07UiN@0207emO@80P8200P21PH4208:2PP80PH610P1oOgl207inOP80
O7al0P1jNWX207QhN080M7Ad0P1aLG4206m_K`80K6a/00<0J6QX06EUI@1UIFD00P1RHV8205mOG`80
G5aL0P1IFET205IFEP80DU9B5@3oool001<0oooo0P1=CDd204];B`80BDU90P16ATH204A4A080@T92
0P0o?cl203dm?@0303/k>`0i>CT0>CTi0080=SHf0P0d=3@2034a<@80;bl_0P0/;2`202TY:@809bLW
0P0T92@2024Q8@807alO0P0L71`201TI6@805QHF0P0C4a<00`0@41003@d=00d=3@0200X:2P801`L7
0P0410@200410@8000000P010@4200<30`801`L70P0:2PX200l?3`8051@D0P0I6AT201dM7@808B4Q
00<09RHV02d];@0];Bd00P0c<c<203Lg=`80>c/k0P0j>SX203Ti>@80>3Ph0P0f=SH203@d=080<S8b
0P0`<30202h^;P80;Bd]0P0[:b/202TY:@0302LW9`0U9BD09BDU00808b<S0P0Q8B4201lO7`807AdM
0P0K6a/201TI6@805aLG0P0F5QH201@D50804a<C0P0B4Q82014A4@80410@0P0?3`l500h>3P803`l?
0P0@4102014A4@804a<C0P0F5QH201TI6@807AdM0P0P820202<S8`80:2PX0P0_;bl203Hf=P80?Cdm
00<0@T9204I6AP16ATH00P1:BTX204i>CP80De=C0P1GEeL205]KF`80GemO0P1RHV8206EUI@80J6QX
0P1ZJVX206a/K080Kfm_0P1aLG4207=cL`0307EeM@1iNGT0NGUi0080OGem0P20P8020861P@80PX:2
0P21PH4207moO`80OWin0P1lO7`207YjNP80N7Qh0P1dM7@2075aL@80Kfm_0P1/K6`00`1XJ6P0IFEU
06EUI@02069RHP80GemO0P1LG5`205UIF@80EUIF0P1BDU8E0?ooo`004`3oool204e=C@80Bd];0P18
B4P204I6AP80A4A40P11@D4203lo?`80?Cdm00<0>c/k03Ph>00h>3P00P0e=CD203<c<`80<30`0P0^
;Rh202/[:`80:2PX0P0U9BD202<S8`80820P0P0M7Ad201XJ6P8061PH0P0E5AD2014A4@0300h>3P0<
30`030`<008020P80P051@D200820P@000000P020P8200@4108020P80P0=3@d2018B4P805aLG0P0L
71`2020P80809RHV00<0;2`/03<c<`0c<c<00P0i>CT203dm?@80@D510P0o?cl203hn?P80?3`l0P0j
>SX203Ph>080=SHf0P0d=3@203<c<`80<C4a0P0_;bl202d];@0302/[:`0Y:BT0:BTY00809RHV0P0T
92@2028R8P80820P0P0N7Qh201`L70806QXJ0P0I6AT201LG5`805ADE0P0D51@201<C4`804Q8B0`0A
4A44018B4P804a<C0P0D51@201DE5@8061PH0P0L71`201hN7P808B4Q0P0T92@202TY:@80<30`0P0g
=cL203hn?P80@T9200<0ADE504U9B@19BDT00P1=CDd2059BDP80EeMG0P1KFe/205mOG`80HF5Q0P1U
IFD206UYJ@80Jf][0P1]KFd206m_K`80LW9b0P1cLg<207IfMP0307UiN@1lO7`0O7al0080P8200P23
Ph<208B4Q080Ph>30P21PH420820P080OWin0P1mOGd207YjNP80N7Qh0P1eMGD2079bLP80Kfm_0P1[
Jf/00`1XJ6P0IFEU06EUI@02069RHP80GemO0P1LG5`205UIF@80EEEE0P1BDU8E0?ooo`004`3oool2
04e=C@80Bd];0P18B4P204I6AP80A4A40P11@D4203lo?`80?Cdm00<0>c/k03Ph>00h>3P00P0e=CD2
03<c<`80<30`0P0^;Rh202/[:`80:2PX0P0U9BD202<S8`80820P0P0M7Ad201XJ6P8061PH0P0E5AD2
014A4@0300h>3P0<30`030`<008020P80P051@D200820P@000000P020P8200@4108020P80P0=3@d2
018B4P805aLG0P0L71`2020P80809RHV00<0;2`/03<c<`0c<c<00P0i>CT203dm?@80@D510P0o?cl2
03hn?P80?3`l0P0j>SX203Ph>080=SHf0P0d=3@203<c<`80<C4a0P0_;bl202d];@0302/[:`0Y:BT0
:BTY00809RHV0P0T92@2028R8P80820P0P0N7Qh201`L70806QXJ0P0I6AT201LG5`805ADE0P0D51@2
01<C4`804Q8B0`0A4A44018B4P804a<C0P0D51@201DE5@8061PH0P0L71`201hN7P808B4Q0P0T92@2
02TY:@80<30`0P0g=cL203hn?P80@T9200<0ADE504U9B@19BDT00P1=CDd2059BDP80EeMG0P1KFe/2
05mOG`80HF5Q0P1UIFD206UYJ@80Jf][0P1]KFd206m_K`80LW9b0P1cLg<207IfMP0307UiN@1lO7`0
O7al0080P8200P23Ph<208B4Q080Ph>30P21PH420820P080OWin0P1mOGd207YjNP80N7Qh0P1eMGD2
079bLP80Kfm_0P1[Jf/00`1XJ6P0IFEU06EUI@02069RHP80GemO0P1LG5`205UIF@80EEEE0P1BDU8E
0?ooo`004`3oool204e=C@80BTY:0P18B4P204E5A@80@d=30P11@D4203hn?P80?3`l00<0>SXj03Lg
=`0g=cL00P0d=3@2038b<P80;bl_0P0];Bd202XZ:P809bLW0P0T92@2028R8P807alO0P0L71`201TI
6@805QHF0P0C4a<2010@400300d=3@0:2PX02PX:00801`L70P0410@200410@@000000P020P8200H6
1P802PX:0P0@410201DE5@806QXJ0P0O7al202@T9080:b/[00<0<S8b03Ti>@0i>CT00P0o?cl204=3
@`80ATI60P15ADD204=3@`80@D510P0o?cl203`l?080>SXj0P0i>CT203Lg=`80=CDe0P0c<c<2034a
<@0302l_;`0];Bd0;Bd]0080:b/[0P0Y:BT202HV9P8092@T0P0R8R82020P80807QhN0P0L71`201XJ
6P806ATI0P0G5aL201HF5P@05ADE0`0D51@201DE5@805aLG0P0H61P201XJ6P807QhN0P0Q8B4202<S
8`809RHV0P0[:b/2034a<@80>3Ph0P0o?cl204=3@`80AdM700<0Bd];04i>CP1>CTh00P1BDU8205IF
EP80FUYJ0P1NGUh2065QH@80I6AT0P1XJ6P206][J`80KFe]0P1_Kfl2079bLP80MGEe0P1gMgL207Yj
NP0307emO@21PH40PH610080Ph>31025QHD208B4Q080PX:20P21PH4207moO`80OGem0P1jNWX207Qh
N080MGEe0P1bLW8206m_K`80Jf][00<0J6QX06EUI@1UIFD00P1RHV8205mOG`80G5aL0P1IFET205IF
EP80DU9B5@3oool001<0oooo0P1=CDd204Y:BP80B4Q80P15ADD204=3@`80@D510P0n?Sh203`l?003
03Xj>P0g=cL0=cLg0080=3@d0P0b<S8202l_;`80;Bd]0P0Z:RX202LW9`8092@T0P0R8R8201lO7`80
71`L0P0I6AT201HF5P804a<C0P0@41000`0=3@d02PX:00X:2P0200L71`8010@40P010@4400000080
0P820P061PH200X:2P80410@0P0E5AD201XJ6P807alO0P0T92@202/[:`03038b<P0i>CT0>CTi0080
?clo0P13@d<204I6AP80ADE50P13@d<20451@@80?clo0P0l?3`203Xj>P80>CTi0P0g=cL203De=@80
<c<c0P0a<C400`0_;bl0;Bd]02d];@0202/[:`80:BTY0P0V9RH202@T90808R8R0P0P820201hN7P80
71`L0P0J6QX201TI6@805aLG0P0F5QH401DE5@<051@D0P0E5AD201LG5`8061PH0P0J6QX201hN7P80
8B4Q0P0S8b<202HV9P80:b/[0P0a<C4203Ph>080?clo0P13@d<204M7A`0304];B`1>CTh0CTi>0080
DU9B0P1FEUH205YJFP80GUiN0P1QHF4206ATI080J6QX0P1[Jf/206e]K@80Kfm_0P1bLW8207EeM@80
MgMg0P1jNWX00`1mOGd0PH610861P@0208>3P`@0QHF50P24Q8@208:2PP80PH610P1oOgl207emO@80
NWYj0P1hN7P207EeM@80LW9b0P1_Kfl206][J`0306QXJ01UIFD0IFEU0080HV9R0P1OGel205aLG080
FEUI0P1FEUH2059BDQD0oooo000C0?ooo`80C4a<0P1:BTX204Q8B080ADE50P13@d<20451@@80?Shn
0P0l?3`00`0i>CT0=cLg03Lg=`0203@d=080<C4a0P0^;Rh202`/;080:BTY0P0V9RH202@T90808B4Q
0P0N7Qh201/K6`8061PH0P0E5AD2018B4P803`l?00<02`/;00P8200820P00P061PH200<30`@00000
0P010@4200@4108020P80P0=3@d201<C4`806ATI0P0N7Qh202@T9080:BTY0P0a<C400`0i>CT0@410
0410@00204E5A@80BTY:0P1=CDd204];B`80B4Q80P15ADD204=3@`80@4100P0n?Sh203`l?080>SXj
0P0h>3P203Hf=P80=CDe00<0<c<c038b<P0b<S800P0`<30202h^;P80;2`/0P0Y:BT202LW9`809BDU
0P0S8b<2020P80807QhN0P0L71`201/K6`806QXJ1`0I6AT201XJ6P806a/K0P0M7Ad2024Q8@809BDU
0P0V9RH202TY:@80;Bd]0P0b<S8203Xj>P80?clo0P13@d<204Q8B080Bd];00<0Cdm?059BDP1BDU80
0P1FEUH205YJFP80GUiN0P1QHF4206EUI@80JFUY0P1[Jf/206e]K@80Kfm_0P1aLG4207AdM080MgMg
0P1iNGT207emO@030820P023Ph<0Ph>30080QHF50P27QhL208J6QP80Q8B40P23Ph<208:2PP80P820
0P1mOGd207YjNP80MgMg0P1dM7@2075aL@80KVi^0P1[Jf/00`1XJ6P0IFEU06EUI@02069RHP80GemO
0P1LG5`205UIF@80EEEE0P1BDU8E0?ooo`004`3oool204a<C080BTY:0P18B4P204E5A@80@d=30P11
@D4203hn?P80?3`l00<0>CTi03Lg=`0g=cL00P0d=3@2034a<@80;Rh^0P0/;2`202TY:@809RHV0P0T
92@2024Q8@807QhN0P0K6a/201PH60805ADE0P0B4Q8200l?3`0300/;2`0820P020P800801PH60P03
0`<4000000800@410P0410@200P820803@d=0P0C4a<201TI6@807QhN0P0T92@202TY:@80<C4a00<0
>CTi0410@010@4000P15ADD204Y:BP80CDe=0P1;Bd/204Q8B080ADE50P13@d<20410@080?Shn0P0l
?3`203Xj>P80>3Ph0P0f=SH203De=@0303<c<`0b<S80<S8b0080<30`0P0^;Rh202`/;080:BTY0P0W
9bL202DU9@808b<S0P0P820201hN7P8071`L0P0K6a/201XJ6PL06ATI0P0J6QX201/K6`807AdM0P0Q
8B4202DU9@809RHV0P0Y:BT202d];@80<S8b0P0j>SX203lo?`80@d=30P18B4P204];B`0304m?C`1B
DU80DU9B0080EUIF0P1JFUX205iNGP80HF5Q0P1UIFD206UYJ@80Jf][0P1]KFd206m_K`80LG5a0P1d
M7@207MgM`80NGUi0P1mOGd00`20P800Ph>308>3P`0208F5Q@80QhN70P26QXH208B4Q080Ph>30P22
PX820820P080OGem0P1jNWX207MgM`80M7Ad0P1aLG4206i^KP80Jf][00<0J6QX06EUI@1UIFD00P1R
HV8205mOG`80G5aL0P1IFET205EEE@80DU9B5@3oool001<0oooo0P1=CDd204Y:BP80B4Q80P15ADD2
04=3@`80@D510P0n?Sh203/k>`0303Ti>@0f=SH0=SHf0080<c<c0P0a<C4202h^;P80:b/[0P0X:2P2
02DU9@808R8R0P0P820201dM7@806QXJ0P0G5aL201@D50804A4A0P0=3@d00`0:2PX01`L700L71`02
00D51@800@411000000200820P801PH60P0;2`/200l?3`805ADE0P0K6a/2028R8P80:2PX0P0_;bl2
03Ti>@030410@017AdL0AdM70080CDe=0P1BDU8205=CD`80Cdm?0P1;Bd/204M7A`80A4A40P12@T82
03lo?`80?Shn0P0l?3`203Xj>P80>CTi0P0g=cL00`0f=SH0=3@d03@d=00203<c<`80<S8b0P0a<C42
030`<080;Bd]0P0[:b/202PX:0809RHV0P0T92@2028R8P80820P0P0O7al201hN7PD07AdM0P0N7Qh2
020P80808b<S0P0X:2P202`/;080;Bd]0P0`<30203@d=080>SXj0P10@40204E5A@80BDU90P1=CDd2
051@D00305=CD`1GEeL0EeMG0080FUYJ0P1NGUh2065QH@80I6AT0P1XJ6P206][J`80KFe]0P1_Kfl2
075aL@80MGEe0P1gMgL207UiN@80O7al0P20P8000`23Ph<0QHF508F5Q@0408N7Q`80QXJ60P24Q8@2
08>3P`80PX:20P20P80207emO@80NWYj0P1gMgL207AdM080LG5a0P1^KVh206][J`0306QXJ01UIFD0
IFEU0080HV9R0P1OGel205aLG080FEUI0P1FEUH205=CDaD0oooo000C0?ooo`80CDe=0P1:BTX204Q8
B080ADE50P13@d<20451@@80?Shn0P0k>c/00`0i>CT0=SHf03Hf=P0203<c<`80<C4a0P0^;Rh202/[
:`80:2PX0P0U9BD2028R8P80820P0P0M7Ad201XJ6P805aLG0P0D51@2014A4@803@d=00<02PX:00L7
1`071`L00P051@D200410@@000000P020P8200H61P802`/;0P0?3`l201DE5@806a/K0P0R8R8202PX
:080;bl_0P0i>CT00`10@400AdM704M7A`0204e=C@80DU9B0P1CDe<204m?C`80Bd];0P17AdL204A4
A080@T920P0o?cl203hn?P80?3`l0P0j>SX203Ti>@80=cLg00<0=SHf03@d=00d=3@00P0c<c<2038b
<P80<C4a0P0`<30202d];@80:b/[0P0X:2P202HV9P8092@T0P0R8R82020P80807alO0P0N7Qh501dM
7@807QhN0P0P820202<S8`80:2PX0P0/;2`202d];@80<30`0P0d=3@203Xj>P80@4100P15ADD204U9
B@80CDe=0P1@D5000`1CDe<0EeMG05MGE`0205YJFP80GUiN0P1QHF4206ATI080J6QX0P1[Jf/206e]
K@80Kfm_0P1aLG4207EeM@80MgMg0P1iNGT207alO080P82000<0Ph>308F5Q@25QHD01027QhL208J6
QP80Q8B40P23Ph<208:2PP80P8200P1mOGd207YjNP80MgMg0P1dM7@2075aL@80KVi^0P1[Jf/00`1X
J6P0IFEU06EUI@02069RHP80GemO0P1LG5`205UIF@80EUIF0P1CDe<E0?ooo`004`3oool204a<C080
BTY:0P18B4P204E5A@80@d=30P10@40203dm?@80>c/k00<0>3Ph03De=@0e=CD00P0c<c<2030`<080
;Bd]0P0Z:RX202LW9`8092@T0P0Q8B4201lO7`8071`L0P0I6AT201HF5P804a<C0P0?3`l200`<3003
00T92@061PH01PH600800`<30P010@42000000800@410P0410@200P820803@d=0P0C4a<201XJ6P80
820P0P0V9RH202d];@80=SHf0P10@4000`17AdL0Cdm?04m?C`0205MGE`80FUYJ0P1FEUH2051@D080
C4a<0P18B4P204E5A@80@T920P10@40203hn?P80?3`l0P0j>SX203Ti>@80>3Ph00<0=cLg03Hf=P0f
=SH0100e=CD203@d=0@0<c<c0P0a<C4202h^;P80;2`/0P0Y:BT202LW9`809RHV0P0T92@202<S8`80
8R8R00<08B4Q028R8P0R8R800P0S8b<202DU9@80:BTY0P0^;Rh2038b<P80=3@d0P0g=cL203/k>`80
@4100P16ATH204];B`80Cdm?0P1BDU8205EEE@0305QHF01LG5`0G5aL0080GemO0P1RHV8206EUI@80
J6QX0P1[Jf/206i^KP80L71`0P1aLG4207AdM080MgMg0P1iNGT207]kN`80Ogmo0P22PX800`24Q8@0
QXJ608J6QP0208V9R@80R8R81026QXH208F5Q@80PX:20P20P80207emO@80NWYj0P1gMgL207AdM080
LG5a0P1^KVh206][J`0306QXJ01UIFD0IFEU0080HV9R0P1OGel205aLG080F5QH0P1EEED2059BDQD0
oooo000C0?ooo`80C4a<0P1:BTX204Q8B080ADE50P13@d<20410@080?Cdm0P0k>c/00`0h>3P0=CDe
03De=@0203<c<`80<30`0P0];Bd202XZ:P809bLW0P0T92@2024Q8@807alO0P0L71`201TI6@805QHF
0P0C4a<200l?3`8030`<00<02@T900H61P061PH00P030`<200410@8000000P010@4200@4108020P8
0P0=3@d201<C4`806QXJ0P0P820202HV9P80;Bd]0P0f=SH20410@00304M7A`1?Cdl0Cdm?0080EeMG
0P1JFUX205IFEP80D51@0P1<C4`204Q8B080ADE50P12@T820410@080?Shn0P0l?3`203Xj>P80>CTi
0P0h>3P00`0g=cL0=SHf03Hf=P0403De=@80=3@d100c<c<2034a<@80;Rh^0P0/;2`202TY:@809bLW
0P0V9RH202@T90808b<S0P0R8R800`0Q8B408R8R028R8P0202<S8`809BDU0P0Y:BT202h^;P80<S8b
0P0d=3@203Lg=`80>c/k0P10@40204I6AP80Bd];0P1?Cdl2059BDP80EEEE00<0F5QH05aLG01LG5`0
0P1OGel2069RHP80IFEU0P1XJ6P206][J`80KVi^0P1`L702075aL@80M7Ad0P1gMgL207UiN@80Ng]k
0P1oOgl208:2PP0308B4Q026QXH0QXJ60080RHV90P28R8P408J6QP80QHF50P22PX820820P080OGem
0P1jNWX207MgM`80M7Ad0P1aLG4206i^KP80Jf][00<0J6QX06EUI@1UIFD00P1RHV8205mOG`80G5aL
0P1HF5P205EEE@80DU9B5@3oool001<0oooo0P1=CDd204Y:BP80B4Q80P15ADD20492@P80@4100P0m
?Cd203Xj>P0303Lg=`0d=3@0=3@d0080<S8b0P0_;bl202`/;080:BTY0P0V9RH202<S8`808B4Q0P0N
7Qh201/K6`8061PH0P0E5AD2018B4P803Ph>0P0;2`/00`0820P01@D500D51@0200820P@000000P02
0P8200H61P802PX:0P0?3`l201HF5P807AdM0P0T92@202/[:`80<c<c0P0m?Cd204I6AP0304i>CP1I
FET0FEUI0080GEeM0P1JFUX205ADE080Cdm?0P1;Bd/204M7A`80A4A40P12@T8203lo?`80?Cdm0P0k
>c/203Xj>P80>CTi1@0h>3P403Lg=`H0=SHf0P0e=CD203@d=080<S8b0P0_;bl202d];@80:b/[0P0Y
:BT202PX:0809bLW00<09RHV02LW9`0W9bL00P0X:2P202/[:`80<30`0P0c<c<203Ph>080?3`l0P10
@40204A4A080B4Q80P1<C4`2051@D080E5AD0P1GEeL205UIF@0305aLG01OGel0GemO0080HV9R0P1U
IFD206MWI`80JVYZ0P1/K6`206m_K`80LG5a0P1dM7@207MgM`80NGUi0P1lO7`207inOP80PX:20P24
Q8@00`26QXH0R8R808R8R00208V9R@@0R8R80P27QhL208F5Q@80PX:20P20P80207emO@80NWYj0P1g
MgL207AdM080LG5a0P1^KVh206][J`0306QXJ01UIFD0IFEU0080HV9R0P1OGel205aLG080FEUI0P1F
EUH2059BDQD0oooo000C0?ooo`80CDe=0P1:BTX204Q8B080ADE50P12@T820410@080?Cdm0P0j>SX0
0`0g=cL0=3@d03@d=002038b<P80;bl_0P0/;2`202TY:@809RHV0P0S8b<2024Q8@807QhN0P0K6a/2
01PH60805ADE0P0B4Q8200h>3P802`/;00<020P800D51@051@D00P020P84000000800P820P061PH2
00X:2P803`l?0P0F5QH201dM7@8092@T0P0[:b/203<c<`80?Cdm0P16ATH00`1>CTh0FEUI05UIF@02
05eMG@80FUYJ0P1DE5@204m?C`80Bd];0P17AdL204A4A080@T920P0o?cl203dm?@80>c/k0P0j>SX2
03Ti>@D0>3Ph100g=cL603Hf=P80=CDe0P0d=3@2038b<P80;bl_0P0];Bd202/[:`80:BTY0P0X:2P2
02LW9`0302HV9P0W9bL09bLW0080:2PX0P0[:b/2030`<080<c<c0P0h>3P203`l?080@4100P14A4@2
04Q8B080C4a<0P1@D50205ADE080EeMG0P1IFET00`1LG5`0GemO05mOG`02069RHP80IFEU0P1WIfL2
06YZJP80K6a/0P1_Kfl2075aL@80M7Ad0P1gMgL207UiN@80O7al0P1nOWh208:2PP80Q8B400<0QXJ6
08R8R028R8P00P29RHT408R8R080QhN70P25QHD208:2PP80P8200P1mOGd207YjNP80MgMg0P1dM7@2
075aL@80KVi^0P1[Jf/00`1XJ6P0IFEU06EUI@02069RHP80GemO0P1LG5`205UIF@80EUIF0P1BDU8E
0?ooo`004`3oool204e=C@80BTY:0P17AdL204E5A@80@T920P0o?cl203dm?@80>SXj00<0=cLg03@d
=00d=3@00P0a<C4202h^;P80:b/[0P0X:2P202HV9P808b<S0P0P820201dM7@806QXJ0P0G5aL201@D
5080410@0P0=3@d200X:2P0300L71`0410@010@400800@410P00000200410@8010@40P0820P200d=
3@804a<C0P0J6QX2024Q8@80:2PX0P0`<30203Ti>@80A4A40P1<C4`00`1FEUH0Fe]K05]KF`0205UI
F@80EUIF0P1BDU8204i>CP80BTY:0P16ATH204=3@`80@4100P0n?Sh203dm?@80>c/k0P0i>CT503Ph
>0@0=cLg300h>3P203Lg=`80=SHf0P0d=3@2034a<@80;bl_0P0];Bd502`/;080;Rh^0P0a<C4203De
=@80>SXj0P0n?Sh20451@@80ATI60P1:BTX204m?C`80E5AD0P1GEeL205YJFP80GEeM0P1NGUh00`1P
H600HV9R069RHP0206ATI080IfMW0P1ZJVX206a/K080KVi^0P1aLG4207AdM080MWIf0P1hN7P207]k
N`80OWin0P21PH4208B4Q080QXJ600<0R8R808V9R@29RHT0102:RXX208V9R@80QhN70P25QHD208:2
PP80P8200P1mOGd207YjNP80MgMg0P1dM7@2075aL@80KVi^0P1[Jf/00`1XJ6P0IFEU06EUI@02069R
HP80GemO0P1LG5`205UIF@80EEEE0P1BDU8E0?ooo`004`3oool204e=C@80BTY:0P17AdL204E5A@80
@T920P0o?cl203dm?@80>SXj00<0=cLg03@d=00d=3@00P0a<C4202h^;P80:b/[0P0X:2P202HV9P80
8b<S0P0P820201dM7@806QXJ0P0G5aL201@D5080410@0P0=3@d200X:2P0300L71`0410@010@40080
0@410P00000200410@8010@40P0820P200d=3@804a<C0P0J6QX2024Q8@80:2PX0P0`<30203Ti>@80
A4A40P1<C4`00`1FEUH0Fe]K05]KF`0205UIF@80EUIF0P1BDU8204i>CP80BTY:0P16ATH204=3@`80
@4100P0n?Sh203dm?@80>c/k0P0i>CT503Ph>0@0=cLg300h>3P203Lg=`80=SHf0P0d=3@2034a<@80
;bl_0P0];Bd502`/;080;Rh^0P0a<C4203De=@80>SXj0P0n?Sh20451@@80ATI60P1:BTX204m?C`80
E5AD0P1GEeL205YJFP80GEeM0P1NGUh00`1PH600HV9R069RHP0206ATI080IfMW0P1ZJVX206a/K080
KVi^0P1aLG4207AdM080MWIf0P1hN7P207]kN`80OWin0P21PH4208B4Q080QXJ600<0R8R808V9R@29
RHT0102:RXX208V9R@80QhN70P25QHD208:2PP80P8200P1mOGd207YjNP80MgMg0P1dM7@2075aL@80
KVi^0P1[Jf/00`1XJ6P0IFEU06EUI@02069RHP80GemO0P1LG5`205UIF@80EEEE0P1BDU8E0?ooo`00
4`3oool204a<C080BTY:0P17AdL204A4A080@T920P0o?cl203`l?080>CTi00<0=SHf03@d=00d=3@0
0P0a<C4202h^;P80:b/[0P0X:2P202DU9@808R8R0P0O7al201`L70806ATI0P0E5AD2018B4P803`l?
0P0;2`/200P8200300D51@030`<00`<300@00@410P020P8200H61P802PX:0P0@410201HF5P807QhN
0P0U9BD202d];@80=SHf0P11@D4204];B`80E5AD0`1KFe/205QHF080E5AD0P1@D50204a<C080B4Q8
0P14A4@20451@@80?Shn0P0l?3`203/k>`80>CTi100h>3P303Lg=`80>3Ph100i>CT403Xj>PX0>c/k
0P0i>CT203Ph>080=CDe0P0c<c<2038b<P<0<C4a0P0c<c<203De=@80>SXj0P0n?Sh20492@P80AdM7
0P1=CDd205=CD`80EUIF0P1HF5P205YJFP80G5aL0P1NGUh2061PH00306=SH`1UIFD0IFEU0080IfMW
0P1YJFT206][J`80KVi^0P1`L70207=cL`80MWIf0P1hN7P207]kN`80OWin0P21PH4208B4Q080QHF5
0P27QhL00`29RHT0Rh^;08^;R`0208b<S080Rh^;0P29RHT208N7Q`80QHF50P22PX820820P080OGem
0P1jNWX207MgM`80M7Ad0P1aLG4206i^KP80Jf][00<0J6QX06EUI@1UIFD00P1RHV8205mOG`80G5aL
0P1HF5P205EEE@80DU9B5@3oool001<0oooo0P1<C4`204Y:BP80AdM70P14A4@20492@P80?clo0P0l
?3`203Ti>@0303Hf=P0d=3@0=3@d0080<C4a0P0^;Rh202/[:`80:2PX0P0U9BD2028R8P807alO0P0L
71`201TI6@805ADE0P0B4Q8200l?3`802`/;0P0820P00`051@D00`<300<30`0400410@800P820P06
1PH200X:2P80410@0P0F5QH201hN7P809BDU0P0];Bd203Hf=P80@D510P1;Bd/205ADE0<0Fe]K0P1H
F5P205ADE080D51@0P1<C4`204Q8B080A4A40P11@D4203hn?P80?3`l0P0k>c/203Ti>@@0>3Ph0`0g
=cL203Ph>0@0>CTi100j>SX:03/k>`80>CTi0P0h>3P203De=@80<c<c0P0b<S83034a<@80<c<c0P0e
=CD203Xj>P80?Shn0P12@T8204M7A`80CDe=0P1CDe<205IFEP80F5QH0P1JFUX205aLG080GUiN0P1P
H6000`1SHf<0IFEU06EUI@0206MWI`80JFUY0P1[Jf/206i^KP80L71`0P1cLg<207IfMP80N7Qh0P1k
Ng/207inOP80PH610P24Q8@208F5Q@80QhN700<0RHV908^;R`2;Rh/00P2<S8`208^;R`80RHV90P27
QhL208F5Q@80PX:20P20P80207emO@80NWYj0P1gMgL207AdM080LG5a0P1^KVh206][J`0306QXJ01U
IFD0IFEU0080HV9R0P1OGel205aLG080F5QH0P1EEED2059BDQD0oooo000C0?ooo`80CDe=0P1:BTX2
04M7A`80A4A40P12@T8203lo?`80?3`l0P0i>CT00`0f=SH0<c<c03<c<`02030`<080;Bd]0P0Z:RX2
02LW9`809BDU0P0Q8B4201hN7P806a/K0P0H61P201@D50804A4A0P0>3Ph200/;2`801`L700<010@4
00820P020P8010010@4200<30`801`L70P0<30`201<C4`806QXJ0P0S8b<202XZ:P80<c<c0P0m?Cd2
04U9B@80De=C0P1KFe/00`1MGEd0FEUI05UIF@0205IFEP80DU9B0P1>CTh204Y:BP80ATI60P12@T82
03lo?`80?Cdm0P0k>c/203Ti>@80>3Ph0P0g=cL403Hf=P<0=cLg0P0h>3P203Xj>P80>c/k0P0l?3`2
03dm?@`0?Shn0P0l?3`203Ti>@80>3Ph0`0g=cL203Ph>080>c/k0P0n?Sh20451@@80ATI60P1;Bd/2
051@D080EEEE0P1JFUX405iNGP80H61P0P1RHV8206ATI00306EUI@1WIfL0IfMW0080JFUY0P1[Jf/2
06i^KP80LG5a0P1cLg<207EeM@80MgMg0P1kNg/207moO`80PH610P23Ph<208J6QP80QhN70P29RHT0
0`2<S8`0SHf=08f=S@0208j>SP80S8b<0P2:RXX208N7Q`80QHF50P23Ph<20820P080OGem0P1jNWX2
07MgM`80M7Ad0P1bLW8206i^KP80Jf][00<0J6QX06EUI@1UIFD00P1RHV8205mOG`80G5aL0P1IFET2
05IFEP80DU9B5@3oool001<0oooo0P1=CDd204Y:BP80AdM70P14A4@20492@P80?clo0P0l?3`203Ti
>@0303Hf=P0c<c<0<c<c0080<30`0P0];Bd202XZ:P809bLW0P0U9BD2024Q8@807QhN0P0K6a/201PH
608051@D0P0A4A4200h>3P802`/;0P071`L00`0410@00P8200820P0400410@800`<30P071`L200`<
30804a<C0P0J6QX202<S8`80:RXZ0P0c<c<203dm?@80BDU90P1CDe<205]KF`0305eMG@1IFET0FEUI
0080EUIF0P1BDU8204i>CP80BTY:0P16ATH20492@P80?clo0P0m?Cd203/k>`80>CTi0P0h>3P203Lg
=`@0=SHf0`0g=cL203Ph>080>SXj0P0k>c/203`l?080?Cdm300n?Sh203`l?080>CTi0P0h>3P303Lg
=`80>3Ph0P0k>c/203hn?P80@D510P16ATH204];B`80D51@0P1EEED205YJFP@0GUiN0P1PH602069R
HP80I6AT00<0IFEU06MWI`1WIfL00P1YJFT206][J`80KVi^0P1aLG4207=cL`80MGEe0P1gMgL207]k
N`80Ogmo0P21PH4208>3P`80QXJ60P27QhL208V9R@0308b<S02=SHd0SHf=0080SXj>0P2<S8`208Z:
RP80QhN70P25QHD208>3P`80P8200P1mOGd207YjNP80MgMg0P1dM7@2079bLP80KVi^0P1[Jf/00`1X
J6P0IFEU06EUI@02069RHP80GemO0P1LG5`205UIF@80EUIF0P1BDU8E0?ooo`004`3oool204e=C@80
BTY:0P17AdL204A4A080@D510P0n?Sh203`l?080>CTi00<0=SHf03<c<`0c<c<00P0`<30202d];@80
:RXZ0P0W9bL202@T90808B4Q0P0M7Ad201XJ6P805QHF0P0C4a<2010@40803@d=0P092@T200H61P03
00<30`010@400@4100@00@410P051@D200T92@803`l?0P0F5QH201hN7P809bLW0P0_;bl203Ti>@80
A4A40P1?Cdl205YJFP80GEeM00<0Fe]K05QHF01HF5P00P1DE5@2051@D080C4a<0P18B4P204A4A080
@D510P0n?Sh203`l?080>SXj0P0h>3P203Lg=`@0=SHf0`0g=cL203Ph>080>CTi0P0k>c/203dm?@80
?Shn1010@4060451@@H0@T920P11@D4203lo?`D0?Cdm0P0o?cl20492@P80ADE50P19BDT204m?C`80
De=C0P1IFET205iNGP80H61P0P1RHV8206=SH`80IFEU0P1WIfL00`1YJFT0JVYZ06YZJP0206a/K080
Kfm_0P1aLG4207=cL`80MGEe0P1gMgL207YjNP80OWin0P20P80208B4Q080QhN70P28R8P208V9R@80
Rh^;00<0SHf=08j>SP2>SXh00P2=SHd208b<S080RXZ:0P28R8P208F5Q@80Ph>30P20P80207emO@80
NWYj0P1gMgL207AdM080LG5a0P1^KVh206][J`0306QXJ01UIFD0IFEU0080HV9R0P1OGel205aLG080
FEUI0P1FEUH2059BDQD0oooo000C0?ooo`80CDe=0P1:BTX204M7A`80A4A40P11@D4203hn?P80?3`l
0P0i>CT00`0f=SH0<c<c03<c<`02030`<080;Bd]0P0Z:RX202LW9`8092@T0P0Q8B4201dM7@806QXJ
0P0F5QH201<C4`80410@0P0=3@d200T92@801PH600<00`<300410@010@4010010@4200D51@802@T9
0P0?3`l201HF5P807QhN0P0W9bL202l_;`80>CTi0P14A4@204m?C`80FUYJ0P1MGEd00`1KFe/0F5QH
05QHF00205ADE080D51@0P1<C4`204Q8B080A4A40P11@D4203hn?P80?3`l0P0j>SX203Ph>080=cLg
100f=SH303Lg=`80>3Ph0P0i>CT203/k>`80?Cdm0P0n?Sh40410@0H0@D511P12@T820451@@80?clo
1@0m?Cd203lo?`80@T920P15ADD204U9B@80Cdm?0P1CDe<205UIF@80GUiN0P1PH602069RHP80Hf=S
0P1UIFD206MWI`0306UYJ@1ZJVX0JVYZ0080K6a/0P1_Kfl2075aL@80Lg=c0P1eMGD207MgM`80NWYj
0P1nOWh20820P080Q8B40P27QhL208R8R080RHV90P2;Rh/00`2=SHd0SXj>08j>SP0208f=S@80S8b<
0P2:RXX208R8R080QHF50P23Ph<20820P080OGem0P1jNWX207MgM`80M7Ad0P1aLG4206i^KP80Jf][
00<0J6QX06EUI@1UIFD00P1RHV8205mOG`80G5aL0P1IFET205IFEP80DU9B5@3oool001<0oooo0P1<
C4`204U9B@80AdM70P14A4@20451@@80?Shn0P0k>c/203Ti>@0303Hf=P0c<c<0<c<c0080;bl_0P0]
;Bd202TY:@809RHV0P0S8b<2020P808071`L0P0I6AT201HF5P804Q8B0P0?3`l200/;2`8020P80P05
1@D00`030`<00@4100410@0200410@800`<30P071`L200`<30804a<C0P0J6QX202<S8`80;2`/0P0e
=CD20451@@80C4a<0P1HF5P205iNGP80Fe]K00<0FEUI05IFEP1FEUH00P1CDe<204m?C`80Bd];0P17
AdL204=3@`80@D510P0o?cl203dm?@80?3`l0P0j>SX403Ti>@@0>3Ph00<0>CTi03Xj>P0j>SX00P0k
>c/203dm?@80?clo0P11@D420492@P80@d=31014A4@:04E5A@80A4A41@12@T8204=3@`80ADE50P18
B4P204a<C080D51@0P1DE5@205YJFP80GUiN0P1RHV8206IVIP@0J6QX0P1ZJVX00`1[Jf/0KFe]06e]
K@0206m_K`80LG5a0P1cLg<207AdM080MgMg0P1iNGT207]kN`80Ogmo0P22PX8208F5Q@80QhN70P29
RHT208^;R`80SHf=00<0SXj>08n?S`2?Shl00P2=SHd208b<S080RXZ:0P28R8P208J6QP80Ph>30P20
P80207emO@80NWYj0P1hN7P207EeM@80LW9b0P1_Kfl206a/K00306UYJ@1UIFD0IFEU0080HV9R0P1O
Gel205aLG080FEUI0P1EEED2059BDQD0oooo000C0?ooo`80C4a<0P19BDT204M7A`80A4A40P11@D42
03hn?P80>c/k0P0i>CT00`0f=SH0<c<c03<c<`0202l_;`80;Bd]0P0Y:BT202HV9P808b<S0P0P8202
01`L70806ATI0P0F5QH2018B4P803`l?0P0;2`/200P820801@D500<00`<300410@010@400P010@42
00<30`801`L70P0<30`201<C4`806QXJ0P0S8b<202`/;080=CDe0P11@D4204a<C080F5QH0P1NGUh2
05]KF`0305UIF@1FEUH0EUIF0080De=C0P1?Cdl204];B`80AdM70P13@d<20451@@80?clo0P0m?Cd2
03`l?080>SXj100i>CT403Ph>00303Ti>@0j>SX0>SXj0080>c/k0P0m?Cd203lo?`80@D510P12@T82
04=3@`@0A4A42P15ADD204A4A0D0@T920P13@d<204E5A@80B4Q80P1<C4`2051@D080E5AD0P1JFUX2
05iNGP80HV9R0P1VIVH406QXJ080JVYZ00<0Jf][06e]K@1]KFd00P1_Kfl2075aL@80Lg=c0P1dM7@2
07MgM`80NGUi0P1kNg/207moO`80PX:20P25QHD208N7Q`80RHV90P2;Rh/208f=S@0308j>SP2?Shl0
Shn?0080SHf=0P2<S8`208Z:RP80R8R80P26QXH208>3P`80P8200P1mOGd207YjNP80N7Qh0P1eMGD2
079bLP80Kfm_0P1/K6`00`1YJFT0IFEU06EUI@02069RHP80GemO0P1LG5`205UIF@80EEEE0P1BDU8E
0?ooo`004`3oool204a<C080BDU90P17AdL204A4A080@D510P0n?Sh203/k>`80>3Ph00<0=CDe038b
<P0b<S800P0_;bl202`/;080:BTY0P0U9BD2028R8P807alO0P0L71`201PH60805ADE0P0A4A4200h>
3P802PX:0P071`L200@4100300820P010@400@4100800@410P0410@200P820803`l?0P0F5QH201lO
7`80:2PX0P0a<C4203`l?080AdM70P1BDU8205YJFP80Fe]K0P1JFUX00`1HF5P0EEEE05EEE@02059B
DP80CTi>0P1:BTX204I6AP80@d=30P12@T820451@@@0@4100P0o?cl203hn?P80?Cdm0P0l?3`303/k
>`80?3`l0P0n?Sh20410@080@T920P14A4@204E5A@80ATI60P17AdL<04Q8B0<0BDU91P17AdL204U9
B@80Bd];0P1>CTh2059BDP80F5QH0P1KFe/205mOG`80Hf=S0P1VIVH206YZJP@0K6a/00<0KFe]06m_
K`1_Kfl00P1`L702079bLP80M7Ad0P1fMWH207QhN080NWYj0P1mOGd20820P080Ph>30P25QHD208R8
R080RXZ:0P2<S8`208n?S`03092@T02?Shl0Shn?0080SXj>0P2<S8`208Z:RP80R8R80P26QXH208>3
P`80P8200P1mOGd207]kN`80N7Qh0P1eMGD2079bLP80Kfm_0P1/K6`00`1YJFT0IVIV06IVIP02069R
HP80GemO0P1LG5`205UIF@80EEEE0P1BDU8E0?ooo`004`3oool204a<C080BDU90P16ATH204=3@`80
@D510P0n?Sh203/k>`80>3Ph00<0=CDe038b<P0b<S800P0^;Rh202/[:`80:2PX0P0U9BD2024Q8@80
7QhN0P0K6a/201LG5`8051@D0P0A4A4200d=3@802@T90P061PH200<30`0300410@00000000000080
0@410P051@D200/;2`804Q8B0P0J6QX202<S8`80;Bd]0P0g=cL204=3@`80CTi>0P1JFUX205iNGP80
Fe]K0P1JFUX00`1HF5P0EEEE05EEE@02059BDP80CDe=0P1:BTX404U9B@80BTY:0P19BDT204I6AP80
ADE51014A4@60492@PD0@d=30P14A4@204I6AP80AdM70P19BDT404Y:BPP0Bd];101<C4`204e=C@<0
CTi>101<C4`204e=C@80CTi>0P1?Cdl205=CD`80F5QH0P1KFe/205iNGP80HF5Q0P1UIFD206YZJP80
KFe]0P1_Kfl3071`L080LW9b0P1eMGD207IfMP80MgMg0P1iNGT207alO080OWin0P21PH4208B4Q080
QXJ60P28R8P208Z:RP80SHf=0P2?Shl3096AT@80Shn?0P2=SHd208^;R`80RHV90P26QXH208>3P`80
P8200P1nOWh207]kN`80N7Qh0P1eMGD2079bLP80Kfm_0P1/K6`00`1YJFT0IFEU06EUI@02069RHP80
GemO0P1LG5`205UIF@80EUIF0P1BDU8E0?ooo`004`3oool204a<C080BDU90P16ATH204=3@`80@D51
0P0n?Sh203/k>`80>3Ph00<0=CDe038b<P0b<S800P0^;Rh202/[:`80:2PX0P0U9BD2024Q8@807QhN
0P0K6a/201LG5`8051@D0P0A4A4200d=3@802@T90P061PH200<30`0300410@000000000000800@41
0P051@D200/;2`804Q8B0P0J6QX202<S8`80;Bd]0P0g=cL204=3@`80CTi>0P1JFUX205iNGP80Fe]K
0P1JFUX00`1HF5P0EEEE05EEE@02059BDP80CDe=0P1:BTX404U9B@80BTY:0P19BDT204I6AP80ADE5
1014A4@60492@PD0@d=30P14A4@204I6AP80AdM70P19BDT404Y:BPP0Bd];101<C4`204e=C@<0CTi>
101<C4`204e=C@80CTi>0P1?Cdl205=CD`80F5QH0P1KFe/205iNGP80HF5Q0P1UIFD206YZJP80KFe]
0P1_Kfl3071`L080LW9b0P1eMGD207IfMP80MgMg0P1iNGT207alO080OWin0P21PH4208B4Q080QXJ6
0P28R8P208Z:RP80SHf=0P2?Shl3096AT@80Shn?0P2=SHd208^;R`80RHV90P26QXH208>3P`80P820
0P1nOWh207]kN`80N7Qh0P1eMGD2079bLP80Kfm_0P1/K6`00`1YJFT0IFEU06EUI@02069RHP80GemO
0P1LG5`205UIF@80EUIF0P1BDU8E0?ooo`004`3oool204a<C080BDU90P16ATH204=3@`80@4100P0m
?Cd203Xj>P80=cLg00<0=3@d034a<@0a<C400P0^;Rh202/[:`80:2PX0P0T92@2024Q8@807QhN0P0J
6QX201LG5`804a<C0P0@410200`<308020P80P0410@200410@<000000P020P8200L71`803Ph>0P0E
5AD201hN7P80:2PX0P0b<S8203dm?@80BDU90P1EEED605aLG080FUYJ00<0F5QH05IFEP1FEUH00P1C
De<2051@D0@0CTi>0P1=CDd204];B`H0BDU90P17AdL404E5A@80ATI60P17AdL00`18B4P0BDU904U9
B@0404U9B@80BTY:0P1<C4`404e=C@X0CTi>101?Cdl2051@D003055AD@1BDU80DU9B00@0DE5A0P1@
D502055AD@80De=C0P1FEUH205MGE`80FUYJ0P1NGUh2065QH@80IFEU0P1XJ6P206e]K@80L71`00<0
LG5a07=cL`1cLg<0101eMGD207MgM`80NGUi0P1kNg/207emO@80Ogmo0P22PX8208F5Q@80QhN70P2:
RXX208f=S@80Shn?0P2@T9000`2BTY80TI6A096AT@0208n?S`80SHf=0P2;Rh/208V9R@80QXJ60P24
Q8@20861P@80OWin0P1kNg/207QhN080MGEe0P1bLW8206m_K`80K6a/00<0JFUY06IVIP1VIVH00P1S
Hf<205mOG`80G5aL0P1IFET205IFEP80DU9B5@3oool001<0oooo0P1<C4`204U9B@80ATI60P13@d<2
0410@080?Cdm0P0j>SX203Lg=`0303@d=00a<C40<C4a0080;Rh^0P0[:b/202PX:08092@T0P0Q8B42
01hN7P806QXJ0P0G5aL201<C4`80410@0P0<30`200P8208010@40P010@43000000800P820P071`L2
00h>3P805ADE0P0N7Qh202PX:080<S8b0P0m?Cd204U9B@80EEEE1P1LG5`205YJFP0305QHF01FEUH0
EUIF0080De=C0P1@D50404i>CP80CDe=0P1;Bd/604U9B@80AdM71015ADD204I6AP80AdM700<0B4Q8
04U9B@19BDT01019BDT204Y:BP80C4a<101=CDd:04i>CP@0Cdm?0P1@D5000`1ADE40DU9B059BDP04
055AD@80D51@0P1ADE4205=CD`80EUIF0P1GEeL205YJFP80GUiN0P1QHF4206EUI@80J6QX0P1]KFd2
071`L003075aL@1cLg<0Lg=c00@0MGEe0P1gMgL207UiN@80Ng]k0P1mOGd207moO`80PX:20P25QHD2
08N7Q`80RXZ:0P2=SHd208n?S`80T92@00<0TY:B096AT@2ATI400P2?Shl208f=S@80Rh^;0P29RHT2
08J6QP80Q8B40P21PH4207inOP80Ng]k0P1hN7P207EeM@80LW9b0P1_Kfl206a/K00306UYJ@1VIVH0
IVIV0080Hf=S0P1OGel205aLG080FEUI0P1FEUH2059BDQD0oooo000C0?ooo`80C4a<0P19BDT204I6
AP80@d=30P10@40203dm?@80>SXj0P0g=cL00`0d=3@0<C4a034a<@0202h^;P80:b/[0P0X:2P202@T
90808B4Q0P0M7Ad201XJ6P805QHF0P0C4a<200l?3`802`/;0P071`L200@410800@4100<000000082
0P020P800P051@D200X:2P804A4A0P0J6QX202<S8`80;Bd]0P0h>3P204A4A080D51@0P1KFe/205iN
GP@0G5aL0P1KFe/00`1IFET0EeMG05MGE`0205EEE@@0De=C1P1BDU82055AD@80D51@101?Cdl204i>
CP80CDe=0P1>CTh204m?C`0304i>CP1?Cdl0Cdm?00P0D51@201ADE42051@D0H0DE5A0P1BDU8305=C
D`@0E5AD101CDe<405EEE@80EUIF0P1HF5P205aLG080GEeM0P1PH60206=SH`80IfMW0P1[Jf/2071`
L00307=cL`1eMGD0MGEe0080MWIf0P1gMgL207YjNP80Ng]k0P1lO7`207inOP80PH610P24Q8@208J6
QP80RHV90P2<S8`208n?S`80T92@0P2BTY800`2CTi<0TI6A096AT@0208n?S`80SHf=0P2<S8`208V9
R@80QhN70P24Q8@20861P@80OWin0P1kNg/207QhN080MGEe0P1bLW8206m_K`80K6a/00<0JFUY06IV
IP1VIVH00P1RHV8205mOG`80G5aL0P1IFET205IFEP80DU9B5@3oool001<0oooo0P1<C4`204U9B@80
ATI60P13@d<20410@080?Cdm0P0j>SX203Lg=`0303@d=00a<C40<C4a0080;Rh^0P0[:b/202PX:080
92@T0P0Q8B4201dM7@806QXJ0P0F5QH201<C4`803`l?0P0;2`/200L71`8010@40P010@400`000000
0P8200820P0200D51@802PX:0P0A4A4201XJ6P808b<S0P0];Bd203Ph>080A4A40P1@D50205]KF`80
GUiN101LG5`205]KF`0305UIF@1GEeL0EeMG0080EEEE101CDe<6059BDP80DE5A0P1@D50404m?C`80
CTi>0P1=CDd204i>CP80Cdm?00<0CTi>04m?C`1?Cdl0201@D508055AD@80D51@1P1ADE42059BDP<0
De=C101DE5@405=CD`@0EEEE0P1FEUH205QHF080G5aL0P1MGEd2061PH080Hf=S0P1WIfL206][J`80
L71`00<0Lg=c07EeM@1eMGD00P1fMWH207MgM`80NWYj0P1kNg/207alO080OWin0P21PH4208B4Q080
QXJ60P29RHT208b<S080Shn?0P2@T90209:BTP0309>CT`2ATI40TI6A0080Shn?0P2=SHd208b<S080
RHV90P27QhL208B4Q080PH610P1nOWh207]kN`80N7Qh0P1eMGD2079bLP80Kfm_0P1/K6`00`1YJFT0
IVIV06IVIP02069RHP80GemO0P1LG5`205UIF@80EUIF0P1BDU8E0?ooo`004`3oool204a<C080BDU9
0P16ATH204=3@`80@4100P0m?Cd203Xj>P80=cLg00<0=3@d034a<@0a<C400P0^;Rh202/[:`809bLW
0P0T92@2024Q8@807AdM0P0I6AT201HF5P804Q8B0P0>3Ph200X:2P801PH60P030`<300410@800`<3
0P071`L200d=3@805QHF0P0O7al202PX:080<c<c0P0o?cl204Y:BP80EeMG0P1MGEd805aLG0<0Fe]K
1P1MGEd205iNGP80GEeM101LG5`405]KF`@0FUYJ0P1KFe/205aLG080Fe]K00<0G5aL05eMG@1MGEd0
101NGUh205eMG@80Fe]K0P1GEeL205EEE@80E5AD1P1CDe<605ADE0<0EEEE101FEUH805MGE`80FEUI
0P1JFUX205]KF`80GUiN0P1PH602069RHP80IVIV0P1YJFT206i^KP03079bLP1eMGD0MGEe0080MgMg
0P1iNGT207]kN`80O7al0P1nOWh20820P080Ph>30P25QHD208N7Q`80RXZ:0P2<S8`208n?S`80TI6A
0`2DU9@209:BTP80T92@0P2>SXh208b<S080RXZ:0P27QhL208B4Q080PH610P1oOgl207alO080NGUi
0P1eMGD2079bLP80Kfm_0P1/K6`00`1YJFT0IVIV06IVIP02069RHP80GemO0P1LG5`205UIF@80EUIF
0P1BDU8E0?ooo`004`3oool204a<C080BDU90P16ATH204=3@`80@4100P0m?Cd203Xj>P80=cLg00<0
=3@d034a<@0a<C400P0^;Rh202/[:`809bLW0P0T92@2024Q8@807AdM0P0I6AT201HF5P804Q8B0P0>
3Ph200X:2P801PH60P030`<300410@800`<30P071`L200d=3@805QHF0P0O7al202PX:080<c<c0P0o
?cl204Y:BP80EeMG0P1MGEd805aLG0<0Fe]K1P1MGEd205iNGP80GEeM101LG5`405]KF`@0FUYJ0P1K
Fe/205aLG080Fe]K00<0G5aL05eMG@1MGEd0101NGUh205eMG@80Fe]K0P1GEeL205EEE@80E5AD1P1C
De<605ADE0<0EEEE101FEUH805MGE`80FEUI0P1JFUX205]KF`80GUiN0P1PH602069RHP80IVIV0P1Y
JFT206i^KP03079bLP1eMGD0MGEe0080MgMg0P1iNGT207]kN`80O7al0P1nOWh20820P080Ph>30P25
QHD208N7Q`80RXZ:0P2<S8`208n?S`80TI6A0`2DU9@209:BTP80T92@0P2>SXh208b<S080RXZ:0P27
QhL208B4Q080PH610P1oOgl207alO080NGUi0P1eMGD2079bLP80Kfm_0P1/K6`00`1YJFT0IVIV06IV
IP02069RHP80GemO0P1LG5`205UIF@80EUIF0P1BDU8E0?ooo`004`3oool204a<C080BDU90P16ATH2
04=3@`80@4100P0m?Cd203/k>`80=cLg00<0=3@d034a<@0a<C400P0^;Rh202/[:`809bLW0P0T92@2
020P80807AdM0P0I6AT201DE5@804A4A0P0=3@d200T92@801PH60P030`<200410@0300820P051@D0
1@D500802`/;0P0B4Q8201XJ6P808b<S0P0];Bd203Ph>080@d=30P1?Cdl205QHF080Fe]K1P1LG5`3
05eMG@80GUiN0P1OGel2065QH@80I6AT1P1VIVH206EUI@80I6AT101SHf<806ATI0<0Hf=S0P1QHF42
061PH080GemO0P1MGEd205YJFP80F5QH0P1GEeL605IFEP80EEEE1P1FEUH00`1GEeL0F5QH05QHF002
05QHF0@0FEUI0P1JFUX605]KF`80G5aL0P1MGEd205mOG`80HV9R0P1UIFD206QXJ080K6a/00<0LG5a
07EeM@1eMGD00P1iNGT207]kN`80O7al0P1mOGd207moO`80PX:20P24Q8@208F5Q@80R8R80P2;Rh/2
08f=S@80T92@0P2ATI4309BDU080TY:B0P2ATI4208n?S`80SHf=0P2;Rh/208R8R080QHF50P22PX82
07moO`80O7al0P1iNGT207IfMP80Lg=c0P1_Kfl206a/K00306UYJ@1VIVH0IVIV0080Hf=S0P1PH602
05aLG080FEUI0P1FEUH2059BDQD0oooo000C0?ooo`80C4a<0P19BDT204I6AP80@d=30P10@40203dm
?@80>c/k0P0g=cL00`0d=3@0<C4a034a<@0202h^;P80:b/[0P0W9bL202@T9080820P0P0M7Ad201TI
6@805ADE0P0A4A4200d=3@802@T90P061PH200<30`800@4100<00P8200D51@051@D00P0;2`/2018B
4P806QXJ0P0S8b<202d];@80>3Ph0P13@d<204m?C`80F5QH0P1KFe/605aLG0<0GEeM0P1NGUh205mO
G`80HF5Q0P1TI6@606IVIP80IFEU0P1TI6@406=SH`P0I6AT0`1SHf<2065QH@80H61P0P1OGel205eM
G@80FUYJ0P1HF5P205MGE`H0EUIF0P1EEED605IFEP0305MGE`1HF5P0F5QH0080F5QH101IFET205YJ
FPH0Fe]K0P1LG5`205eMG@80GemO0P1RHV8206EUI@80J6QX0P1/K6`00`1aLG40MGEe07EeM@0207Ui
N@80Ng]k0P1lO7`207emO@80Ogmo0P22PX8208B4Q080QHF50P28R8P208^;R`80SHf=0P2@T902096A
T@<0U9BD0P2BTY82096AT@80Shn?0P2=SHd208^;R`80R8R80P25QHD208:2PP80Ogmo0P1lO7`207Ui
N@80MWIf0P1cLg<206m_K`80K6a/00<0JFUY06IVIP1VIVH00P1SHf<2061PH080G5aL0P1IFET205IF
EP80DU9B5@3oool001<0oooo0P1<C4`204U9B@80AdM70P13@d<20410@080?Cdm0P0j>SX203Lg=`03
03@d=00a<C40<C4a0080;Rh^0P0[:b/202LW9`808b<S0P0P820201`L70806ATI0P0E5AD2014A4@80
3@d=0P092@T200D51@@00P8200<00`<300P8200820P00P0>3Ph201DE5@807QhN0P0W9bL2038b<P80
?Cdm0P18B4P205ADE0@0Fe]K0P1LG5`405eMG@<0GUiN0P1OGel2061PH080HF5Q0P1RHV8206=SH`@0
I6AT0P1SHf<2069RHPH0HF5Q0P1PH609065QH@@0H61P0P1NGUh205aLG080Fe]K0P1JFUX205UIF@@0
F5QH1P1GEeL305QHF0@0FEUI101JFUX205aLG0@0GEeM0P1NGUh205mOG`80H61P0P1QHF42069RHP80
IVIV0P1ZJVX206e]K@03071`L01eMGD0MGEe0080NGUi0P1kNg/207emO@80P8200P21PH4208:2PP80
Q8B40P27QhL208^;R`80SHf=0P2>SXh2096AT@80Ti>C0P2FUYH00`2EUID0Ti>C09>CT`02096AT@80
T92@0P2>SXh208^;R`80R8R80P25QHD208:2PP80Ogmo0P1lO7`207UiN@80MWIf0P1cLg<2071`L080
KFe]00<0JFUY06IVIP1VIVH00P1SHf<2061PH080G5aL0P1IFET205IFEP80DU9B5@3oool001<0oooo
0P1<C4`204U9B@80AdM70P13@d<20410@080?Cdm0P0j>SX203Lg=`0303@d=00a<C40<C4a0080;Rh^
0P0[:b/202LW9`808b<S0P0P820201`L70806ATI0P0E5AD2014A4@803@d=0P092@T200D51@@00P82
00<00`<300P8200820P00P0>3Ph201DE5@807QhN0P0W9bL2038b<P80?Cdm0P18B4P205ADE0@0Fe]K
0P1LG5`405eMG@<0GUiN0P1OGel2061PH080HF5Q0P1RHV8206=SH`@0I6AT0P1SHf<2069RHPH0HF5Q
0P1PH609065QH@@0H61P0P1NGUh205aLG080Fe]K0P1JFUX205UIF@@0F5QH1P1GEeL305QHF0@0FEUI
101JFUX205aLG0@0GEeM0P1NGUh205mOG`80H61P0P1QHF42069RHP80IVIV0P1ZJVX206e]K@03071`
L01eMGD0MGEe0080NGUi0P1kNg/207emO@80P8200P21PH4208:2PP80Q8B40P27QhL208^;R`80SHf=
0P2>SXh2096AT@80Ti>C0P2FUYH00`2EUID0Ti>C09>CT`02096AT@80T92@0P2>SXh208^;R`80R8R8
0P25QHD208:2PP80Ogmo0P1lO7`207UiN@80MWIf0P1cLg<2071`L080KFe]00<0JFUY06IVIP1VIVH0
0P1SHf<2061PH080G5aL0P1IFET205IFEP80DU9B5@3oool001<0oooo0P1<C4`204U9B@80ATI60P13
@d<20410@080?Cdm0P0j>SX203Lg=`0303@d=00a<C40<C4a0080;Rh^0P0Z:RX202LW9`8092@T0P0P
820201`L708061PH0P0E5AD2014A4@803@d=0P092@T200D51@800`<30P020P800`061PH030`<00`<
300201<C4`806QXJ0P0S8b<202d];@80=cLg0P11@D4204];B`80EUIF0P1JFUX205]KF`80G5aL0P1M
GEd405iNGP<0GemO0P1PH606065QH@80HV9R101QHF42061PH0X0GemO0`1PH606065QH@80H61P0P1O
Gel205iNGP80GEeM101KFe/405YJFPH0FEUI1@1JFUX405]KF`80GEeM0P1NGUh405eMG@@0GUiN0P1O
Gel2065QH@80IFEU0P1WIfL206UYJ@80K6a/00<0L71`07AdM01dM7@00P1gMgL207]kN`80Ogmo0P21
PH4208>3P`80QHF50P27QhL208Z:RP80S8b<0P2>SXh2092@T080TY:B0P2EUID209JFUP0309FEU@2D
U9@0U9BD0080TY:B0P2@T90208j>SP80Rh^;0P29RHT208J6QP80Ph>30P1oOgl207alO080NWYj0P1f
MWH207=cL`80L71`0P1]KFd00`1YJFT0IVIV06IVIP0206=SH`80GemO0P1LG5`205UIF@80EUIF0P1C
De<E0?ooo`004`3oool204a<C080BDU90P16ATH204=3@`80@4100P0m?Cd203Xj>P80=cLg00<0=3@d
034a<@0a<C400P0^;Rh202XZ:P809bLW0P0T92@2020P808071`L0P0H61P201DE5@804A4A0P0=3@d2
00T92@801@D50P030`<200820P0300H61P0<30`030`<00804a<C0P0J6QX202<S8`80;Bd]0P0g=cL2
0451@@80Bd];0P1FEUH205YJFP80Fe]K0P1LG5`205eMG@@0GUiN0`1OGel2061PH0H0HF5Q0P1RHV84
065QH@80H61P2P1OGel3061PH0H0HF5Q0P1PH60205mOG`80GUiN0P1MGEd405]KF`@0FUYJ1P1IFET5
05YJFP@0Fe]K0P1MGEd205iNGP@0GEeM101NGUh205mOG`80HF5Q0P1UIFD206MWI`80JFUY0P1/K6`0
0`1`L700M7Ad07AdM00207MgM`80Ng]k0P1oOgl20861P@80Ph>30P25QHD208N7Q`80RXZ:0P2<S8`2
08j>SP80T92@0P2BTY8209FEU@80UYJF00<0UIFE09BDU02DU9@00P2BTY82092@T080SXj>0P2;Rh/2
08V9R@80QXJ60P23Ph<207moO`80O7al0P1jNWX207IfMP80Lg=c0P1`L70206e]K@0306UYJ@1VIVH0
IVIV0080Hf=S0P1OGel205aLG080FEUI0P1FEUH205=CDaD0oooo000C0?ooo`80C4a<0P19BDT204I6
AP80A4A40P11@D4203hn?P80>c/k0P0g=cL00`0d=3@0<C4a034a<@0202h^;P80:RXZ0P0W9bL202@T
9080820P0P0L71`201TI6@805ADE0P0A4A4200`<308020P80P051@D200@410801PH600<02PX:010@
400@41000P0G5aL201lO7`80:2PX0P0a<C4203/k>`80ADE50P1?Cdl205MGE`80FUYJ0P1LG5`205eM
G@@0GUiN0`1OGel>061PH080GemO0P1NGUh805eMG@80GUiN0`1OGel4061PH080HF5Q101PH60405mO
G`80GUiN0P1MGEd205aLG0l0Fe]K0P1LG5`205eMG@80GUiN0P1OGel4061PH080HF5Q0P1RHV8206AT
I080IVIV0P1WIfL206UYJ@80KFe]00<0L71`07=cL`1cLg<00P1iNGT207emO@80Ogmo0P22PX8208B4
Q080QhN70P2:RXX208f=S@80SXj>0P2@T90209:BTP80U9BD0P2GUiL209RHV00309NGU`2EUID0UIFE
0080U9BD0P2BTY8208n?S`80S8b<0P29RHT208J6QP80Ph>30P20P80207emO@80NWYj0P1gMgL207=c
L`80L71`0P1]KFd00`1YJFT0IVIV06IVIP0206=SH`80H61P0P1MGEd205UIF@80EUIF0P1BDU8E0?oo
o`004`3oool204a<C080BDU90P16ATH204A4A080@D510P0n?Sh203/k>`80=cLg00<0=3@d034a<@0a
<C400P0^;Rh202XZ:P809bLW0P0T92@2020P808071`L0P0I6AT201DE5@804A4A0P0<30`200P82080
1@D50P0410@200H61P0300X:2P0@4100410@00805aLG0P0O7al202PX:080<C4a0P0k>c/204E5A@80
Cdm?0P1GEeL205YJFP80G5aL0P1MGEd405iNGP<0GemO3P1PH60205mOG`80GUiN201MGEd205iNGP<0
GemO101PH602065QH@@0H61P101OGel205iNGP80GEeM0P1LG5`?05]KF`80G5aL0P1MGEd205iNGP80
GemO101PH602065QH@80HV9R0P1TI6@206IVIP80IfMW0P1YJFT206e]K@03071`L01cLg<0Lg=c0080
NGUi0P1mOGd207moO`80PX:20P24Q8@208N7Q`80RXZ:0P2=SHd208j>SP80T92@0P2BTY8209BDU080
UiNG0P2HV9P00`2GUiL0UIFE09FEU@0209BDU080TY:B0P2?Shl208b<S080RHV90P26QXH208>3P`80
P8200P1mOGd207YjNP80MgMg0P1cLg<2071`L080KFe]00<0JFUY06IVIP1VIVH00P1SHf<2061PH080
GEeM0P1IFET205IFEP80DU9B5@3oool001<0oooo0P1<C4`204U9B@80AdM70P14A4@20451@@80?Shn
0P0j>SX203Lg=`0303@d=00a<C40<C4a0080;Bd]0P0Z:RX202LW9`808b<S0P0P820201`L708061PH
0P0E5AD2014A4@8030`<0P0820P400D51@8020P800<03@d=01@D500D51@00P0K6a/202@T9080;Bd]
0P0g=cL20410@080BDU90P1DE5@405]KF`80GEeM101NGUh405mOG`/0H61P0P1OGel405iNGP80GEeM
201LG5`205eMG@80GUiN0`1OGel4061PH0@0HF5Q0P1PH60205mOG`H0GUiN1P1MGEd205aLG0T0GEeM
0P1NGUh205mOG`80H61P101QHF42069RHP80Hf=S0P1UIFD206MWI`80JFUY0P1/K6`206i^KP03079b
LP1gMgL0MgMg0080NGUi0P1mOGd20820P080Q8B40P26QXH208V9R@80Rh^;0P2>SXh2092@T080Ti>C
0P2EUID209NGU`80VYZJ0P2HV9P00`2GUiL0UYJF09JFUP0209FEU@80Ti>C0P2@T90208f=S@80RXZ:
0P26QXH208>3P`80P8200P1mOGd207YjNP80MgMg0P1dM7@2071`L080KFe]00<0JVYZ06MWI`1WIfL0
0P1SHf<2061PH080G5aL0P1IFET205IFEP80DU9B5@3oool001<0oooo0P1<C4`204U9B@80AdM70P14
A4@20451@@80?Shn0P0j>SX203Lg=`0303@d=00a<C40<C4a0080;Bd]0P0Z:RX202LW9`808b<S0P0P
820201`L708061PH0P0E5AD2014A4@8030`<0P0820P400D51@8020P800<03@d=01@D500D51@00P0K
6a/202@T9080;Bd]0P0g=cL20410@080BDU90P1DE5@405]KF`80GEeM101NGUh405mOG`/0H61P0P1O
Gel405iNGP80GEeM201LG5`205eMG@80GUiN0`1OGel4061PH0@0HF5Q0P1PH60205mOG`H0GUiN1P1M
GEd205aLG0T0GEeM0P1NGUh205mOG`80H61P101QHF42069RHP80Hf=S0P1UIFD206MWI`80JFUY0P1/
K6`206i^KP03079bLP1gMgL0MgMg0080NGUi0P1mOGd20820P080Q8B40P26QXH208V9R@80Rh^;0P2>
SXh2092@T080Ti>C0P2EUID209NGU`80VYZJ0P2HV9P00`2GUiL0UYJF09JFUP0209FEU@80Ti>C0P2@
T90208f=S@80RXZ:0P26QXH208>3P`80P8200P1mOGd207YjNP80MgMg0P1dM7@2071`L080KFe]00<0
JVYZ06MWI`1WIfL00P1SHf<2061PH080G5aL0P1IFET205IFEP80DU9B5@3oool001<0oooo0P1<C4`2
04U9B@80AdM70P14A4@20451@@80?Shn0P0j>SX203Lg=`0303@d=00a<C40<C4a0080;Rh^0P0Z:RX2
02LW9`808b<S0P0P820201dM7@806ATI0P0E5AD2014A4@803@d=0P092@T400L71`802`/;00<0410@
01LG5`0G5aL00P0O7al202PX:080<C4a0P0j>SX204A4A080CDe=0P1HF5P405eMG@80GUiN1P1OGel9
061PH0@0GemO201NGUh405eMG@@0G5aL0P1MGEd305iNGP80GemO0P1PH608065QH@H0H61P1P1OGel;
05iNGP80GemO201PH602069RHP80Hf=S0P1UIFD206MWI`80JVYZ0P1/K6`206m_K`80LG5a00<0M7Ad
07IfMP1fMWH00P1jNWX207moO`80Ph>30P25QHD208R8R080Rh^;0P2=SHd208n?S`80TI6A0P2EUID2
09NGU`80VYZJ0P2KVi/209VIV@0309RHV02FUYH0UYJF0080UIFE0P2CTi<2092@T080SHf=0P2:RXX2
08N7Q`80Q8B40P21PH4207inOP80NWYj0P1gMgL207AdM080LG5a0P1]KFd00`1ZJVX0IfMW06MWI`02
06=SH`80H61P0P1MGEd205UIF@80EUIF0P1BDU8E0?ooo`004`3oool204a<C080BDU90P17AdL204A4
A080@D510P0n?Sh203Xj>P80=cLg00<0=3@d034a<@0a<C400P0^;Rh202XZ:P809bLW0P0S8b<2020P
80807AdM0P0I6AT201DE5@804A4A0P0=3@d200T92@@01`L70P0;2`/00`0@41005aLG01LG5`0201lO
7`80:2PX0P0a<C4203Xj>P80A4A40P1=CDd205QHF0@0GEeM0P1NGUh605mOG`T0H61P101OGel805iN
GP@0GEeM101LG5`205eMG@<0GUiN0P1OGel2061PH0P0HF5Q1P1PH60605mOG`/0GUiN0P1OGel8061P
H080HV9R0P1SHf<206EUI@80IfMW0P1ZJVX206a/K080Kfm_0P1aLG400`1dM7@0MWIf07IfMP0207Yj
NP80Ogmo0P23Ph<208F5Q@80R8R80P2;Rh/208f=S@80Shn?0P2ATI4209FEU@80UiNG0P2JVYX209^K
V`80VIVI00<0V9RH09JFUP2FUYH00P2EUID209>CT`80T92@0P2=SHd208Z:RP80QhN70P24Q8@20861
P@80OWin0P1jNWX207MgM`80M7Ad0P1aLG4206e]K@0306YZJP1WIfL0IfMW0080Hf=S0P1PH60205eM
G@80FEUI0P1FEUH2059BDQD0oooo000C0?ooo`80C4a<0P19BDT204I6AP80@d=30P10@40203dm?@80
>SXj0P0g=cL00`0d=3@0<C4a034a<@0202h^;P80:RXZ0P0W9bL202@T9080820P0P0M7Ad201TI6@80
5ADE0P0A4A4200d=3@802@T90P0820P200X:2P803`l?00<05ADE01`L700L71`00P0T92@202d];@80
=cLg0P0o?cl204M7A`80D51@0P1JFUX205eMG@80GUiN101OGel?061PH0@0GUiN0P1OGel2065QH@80
H61P0P1OGel205iNGP80GEeM0P1NGUh205mOG`80GUiN00<0GemO061PH01PH6000P1QHF46069RHPH0
HF5Q5@1PH602065QH@@0HV9R101TI6@206IVIP80IfMW0P1ZJVX206a/K080Kfm_0P1aLG4207AdM003
07IfMP1hN7P0N7Qh0080OWin0P21PH4208B4Q080QhN70P29RHT208^;R`80SXj>0P2ATI4209BDU080
UiNG0P2IVIT609^KV`0309ZJVP2IVIT0VIVI0080UiNG0P2DU9@2096AT@80SXj>0P2;Rh/208N7Q`80
Q8B40P21PH4207inOP80Ng]k0P1gMgL207AdM080LG5a0P1^KVh00`1ZJVX0IfMW06MWI`0206=SH`80
H61P0P1MGEd205UIF@80EUIF0P1BDU8E0?ooo`004`3oool204a<C080BDU90P16ATH204=3@`80@410
0P0m?Cd203Xj>P80=cLg00<0=3@d034a<@0a<C400P0^;Rh202XZ:P809bLW0P0T92@2020P80807AdM
0P0I6AT201DE5@804A4A0P0=3@d200T92@8020P80P0:2PX200l?3`0301DE5@0L71`071`L008092@T
0P0];Bd203Lg=`80?clo0P17AdL2051@D080FUYJ0P1MGEd205iNGP@0GemO3`1PH60405iNGP80GemO
0P1QHF42061PH080GemO0P1NGUh205eMG@80GUiN0P1OGel205iNGP0305mOG`1PH600H61P0080HF5Q
1P1RHV86065QHAD0H61P0P1QHF44069RHP@0I6AT0P1VIVH206MWI`80JVYZ0P1/K6`206m_K`80LG5a
0P1dM7@00`1fMWH0N7Qh07QhN00207inOP80PH610P24Q8@208N7Q`80RHV90P2;Rh/208j>SP80TI6A
0P2DU9@209NGU`80VIVI1P2KVi/00`2JVYX0VIVI09VIV@0209NGU`80U9BD0P2ATI4208j>SP80Rh^;
0P27QhL208B4Q080PH610P1nOWh207]kN`80MgMg0P1dM7@2075aL@80KVi^00<0JVYZ06MWI`1WIfL0
0P1SHf<2061PH080GEeM0P1IFET205IFEP80DU9B5@3oool001<0oooo0P1<C4`204U9B@80ATI60P13
@d<20410@080?Cdm0P0k>c/203Ph>00303@d=00a<C40<C4a0080;Rh^0P0[:b/202LW9`8092@T0P0P
820201dM7@806ATI0P0E5AD2014A4@803@d=100:2PX200h>3P8051@D00<06QXJ028R8P0R8R800P0Z
:RX2038b<P80>c/k0P13@d<204a<C080EUIF0P1NGUh205mOG`@0H61P0P1QHF4?061PH080HF5Q101S
Hf<2069RHP@0HF5Q0P1RHV8406ATI0@0Hf=S1@1RHV8406=SH`@0HV9R5@1QHF42069RHP@0Hf=S101T
I6@206IVIP80IfMW0P1YJFT206][J`80KFe]0P1_Kfl2075aL@80M7Ad0P1gMgL00`1hN7P0OGem07em
O@020861P@80Ph>30P27QhL208V9R@80S8b<0P2>SXh2096AT@80U9BD0P2GUiL209VIV@80VYZJ102K
Vi/509bLW080V9RH0P2EUID209:BTP80SXj>0P2;Rh/208R8R080QHF50P21PH4207inOP80Ng]k0P1h
N7P207AdM080LG5a0P1^KVh00`1ZJVX0IfMW06MWI`0206ATI080H61P0P1MGEd205UIF@80EUIF0P1C
De<E0?ooo`004`3oool204a<C080BDU90P16ATH204=3@`80@4100P0m?Cd203/k>`80>3Ph00<0=3@d
034a<@0a<C400P0^;Rh202/[:`809bLW0P0T92@2020P80807AdM0P0I6AT201DE5@804A4A0P0=3@d4
00X:2P803Ph>0P0D51@00`0J6QX08R8R028R8P0202XZ:P80<S8b0P0k>c/204=3@`80C4a<0P1FEUH2
05iNGP80GemO101PH602065QH@l0H61P0P1QHF4406=SH`80HV9R101QHF42069RHP@0I6AT101SHf<5
069RHP@0Hf=S101RHV8E065QH@80HV9R101SHf<406ATI080IVIV0P1WIfL206UYJ@80Jf][0P1]KFd2
06m_K`80LG5a0P1dM7@207MgM`0307QhN01mOGd0OGem0080PH610P23Ph<208N7Q`80RHV90P2<S8`2
08j>SP80TI6A0P2DU9@209NGU`80VIVI0P2JVYX409^KV`D0W9bL0P2HV9P209FEU@80TY:B0P2>SXh2
08^;R`80R8R80P25QHD20861P@80OWin0P1kNg/207QhN080M7Ad0P1aLG4206i^KP0306YZJP1WIfL0
IfMW0080I6AT0P1PH60205eMG@80FEUI0P1FEUH205=CDaD0oooo000C0?ooo`80CDe=0P1:BTX204M7
A`80A4A40P11@D4203hn?P80>c/k0P0h>3P00`0e=CD0<C4a034a<@0202h^;P80:b/[0P0X:2P202@T
90808B4Q0P0M7Ad201TI6@805QHF0P0B4Q8200h>3P8030`<0P0=3@d2014A4@805aLG00<07QhN02LW
9`0W9bL00P0_;bl203Ph>080?clo0P17AdL2055AD@80Fe]K401QHF49061PH080HF5Q0P1RHV8206=S
H`P0HV9R201SHf<706ATI0@0Hf=S1P1RHV86065QH@H0HV9R1`1SHf<206ATI080IFEU101VIVH206UY
J@80Jf][0P1]KFd206m_K`80LG5a0P1cLg<207EeM@80MgMg0P1jNWX00`1mOGd0PX:208:2PP0208B4
Q080QhN70P2:RXX208^;R`80SXj>0P2ATI4209BDU080UYJF0P2IVIT209^KV`80WIfM0P2NWYh209nO
W`80X:2P00<0WinO09bLW02LW9`00P2IVIT209JFUP80TY:B0P2?Shl208b<S080R8R80P25QHD208:2
PP80OWin0P1kNg/207QhN080MGEe0P1aLG4206i^KP0306YZJP1WIfL0IfMW0080I6AT0P1PH60205eM
G@80FUYJ0P1FEUH205=CDaD0oooo000C0?ooo`80CDe=0P1:BTX204M7A`80A4A40P11@D4203hn?P80
>c/k0P0h>3P00`0e=CD0<C4a034a<@0202h^;P80:b/[0P0X:2P202@T90808B4Q0P0M7Ad201TI6@80
5QHF0P0B4Q8200h>3P8030`<0P0=3@d2014A4@805aLG00<07QhN02LW9`0W9bL00P0_;bl203Ph>080
?clo0P17AdL2055AD@80Fe]K401QHF49061PH080HF5Q0P1RHV8206=SH`P0HV9R201SHf<706ATI0@0
Hf=S1P1RHV86065QH@H0HV9R1`1SHf<206ATI080IFEU101VIVH206UYJ@80Jf][0P1]KFd206m_K`80
LG5a0P1cLg<207EeM@80MgMg0P1jNWX00`1mOGd0PX:208:2PP0208B4Q080QhN70P2:RXX208^;R`80
SXj>0P2ATI4209BDU080UYJF0P2IVIT209^KV`80WIfM0P2NWYh209nOW`80X:2P00<0WinO09bLW02L
W9`00P2IVIT209JFUP80TY:B0P2?Shl208b<S080R8R80P25QHD208:2PP80OWin0P1kNg/207QhN080
MGEe0P1aLG4206i^KP0306YZJP1WIfL0IfMW0080I6AT0P1PH60205eMG@80FUYJ0P1FEUH205=CDaD0
oooo000C0?ooo`80C4a<0P1:BTX204M7A`80A4A40P11@D4203hn?P80>c/k0P0h>3P00`0e=CD0<S8b
038b<P0202l_;`80:b/[0P0X:2P202DU9@808B4Q0P0N7Qh201XJ6P805QHF0P0C4a<200l?3`803@d=
0P0@410201HF5P807AdM00<092@T02`/;00/;2`00P0d=3@203`l?080@d=30P1<C4`205IFEP80H61P
0P1TI6@406=SH`@0HV9R101QHF4;061PH0@0HF5Q0P1RHV88065QH@H0HV9R0P1SHf<00`1TI6@0IFEU
06EUI@0206EUI@80I6AT101SHf<>069RHP@0Hf=S0P1TI6@506EUI@80IVIV0P1WIfL206QXJ080JVYZ
0P1/K6`206i^KP@0LG5a0P1dM7@207MgM`80NGUi0P1kNg/207inOP0308:2PP26QXH0QXJ60080R8R8
0P2;Rh/208f=S@80Shn?0P2ATI4209BDU080UYJF0P2HV9P209^KV`80WYjN102PX:020:6QX@80XZ:R
00<0XJ6Q09fMW@2MWId00P2JVYX209JFUP80Ti>C0P2@T90208b<S080RHV90P25QHD208:2PP80Ogmo
0P1lO7`207QhN080MGEe0P1aLG4206i^KP0306][J`1WIfL0IfMW0080I6AT0P1PH60205eMG@80FUYJ
0P1FEUH205=CDaD0oooo000C0?ooo`80C4a<0P1:BTX204M7A`80A4A40P11@D4203hn?P80>c/k0P0h
>3P00`0e=CD0<S8b038b<P0202l_;`80:b/[0P0X:2P202DU9@808B4Q0P0N7Qh201XJ6P805QHF0P0C
4a<200l?3`803@d=0P0@410201HF5P807AdM00<092@T02`/;00/;2`00P0d=3@203`l?080@d=30P1<
C4`205IFEP80H61P0P1TI6@406=SH`@0HV9R101QHF4;061PH0@0HF5Q0P1RHV88065QH@H0HV9R0P1S
Hf<00`1TI6@0IFEU06EUI@0206EUI@80I6AT101SHf<>069RHP@0Hf=S0P1TI6@506EUI@80IVIV0P1W
IfL206QXJ080JVYZ0P1/K6`206i^KP@0LG5a0P1dM7@207MgM`80NGUi0P1kNg/207inOP0308:2PP26
QXH0QXJ60080R8R80P2;Rh/208f=S@80Shn?0P2ATI4209BDU080UYJF0P2HV9P209^KV`80WYjN102P
X:020:6QX@80XZ:R00<0XJ6Q09fMW@2MWId00P2JVYX209JFUP80Ti>C0P2@T90208b<S080RHV90P25
QHD208:2PP80Ogmo0P1lO7`207QhN080MGEe0P1aLG4206i^KP0306][J`1WIfL0IfMW0080I6AT0P1P
H60205eMG@80FUYJ0P1FEUH205=CDaD0oooo000C0?ooo`80C4a<0P19BDT204M7A`80A4A40P11@D42
03hn?P80>c/k0P0h>3P00`0e=CD0<S8b038b<P0202l_;`80;2`/0P0X:2P202DU9@808R8R0P0N7Qh2
01/K6`805aLG0P0C4a<400l?3`8051@D0P0I6AT2020P800302PX:00a<C40<C4a0080>3Ph0P10@402
04M7A`80D51@0P1JFUX206=SH`@0I6AT0P1SHf<4069RHP80HF5Q7@1PH602065QH@80HV9R0P1SHf<0
0`1TI6@0IFEU06EUI@0206EUI@80I6AT101SHf<:069RHPH0Hf=S0P1TI6@206EUI@0306IVIP1WIfL0
IfMW0080IfMW0P1XJ6P206UYJ@80Jf][0P1]KFd206m_K`80LG5a0P1cLg<207IfMP80N7Qh0P1jNWX2
07emO@80Ogmo0P23Ph<00`26QXH0RHV908V9R@0208b<S080SXj>0P2@T90209>CT`80U9BD0P2EUID2
09RHV080Vi^K0P2NWYh20::RXP80Xj>S0P2RXZ840:BTY0030:6QX@2NWYh0WYjN0080VYZJ0P2GUiL2
09>CT`80T92@0P2=SHd208Z:RP80QXJ60P23Ph<207moO`80O7al0P1iNGT207EeM@80LW9b0P1^KVh0
0`1[Jf/0IfMW06MWI`0206ATI080H61P0P1MGEd205YJFP80EUIF0P1CDe<E0?ooo`004`3oool204a<
C080BDU90P17AdL204A4A080@D510P0n?Sh203/k>`80>3Ph00<0=CDe038b<P0b<S800P0_;bl202`/
;080:2PX0P0U9BD2028R8P807QhN0P0K6a/201LG5`804a<C100?3`l201@D50806ATI0P0P82000`0X
:2P0<C4a034a<@0203Ph>080@4100P17AdL2051@D080FUYJ0P1SHf<406ATI080Hf=S101RHV82065Q
HAd0H61P0P1QHF42069RHP80Hf=S00<0I6AT06EUI@1UIFD00P1UIFD206ATI0@0Hf=S2P1RHV8606=S
H`80I6AT0P1UIFD00`1VIVH0IfMW06MWI`0206MWI`80J6QX0P1YJFT206][J`80KFe]0P1_Kfl2075a
L@80Lg=c0P1fMWH207QhN080NWYj0P1mOGd207moO`80Ph>300<0QXJ608V9R@29RHT00P2<S8`208j>
SP80T92@0P2CTi<209BDU080UIFE0P2HV9P209^KV`80WYjN0P2RXZ820:>SX`80XZ:R102TY:@00`2Q
XJ40WYjN09jNWP0209ZJVP80UiNG0P2CTi<2092@T080SHf=0P2:RXX208J6QP80Ph>30P1oOgl207al
O080NGUi0P1eMGD2079bLP80KVi^00<0Jf][06MWI`1WIfL00P1TI6@2061PH080GEeM0P1JFUX205IF
EP80De=C5@3oool001<0oooo0P1<C4`204U9B@80AdM70P14A4@20451@@80?Shn0P0k>c/203Ti>@03
03Hf=P0c<c<0<c<c0080<30`0P0];Bd202TY:@809RHV0P0R8R8201lO7`8071`L0P0H61P201DE5@80
4Q8B0P0C4a<201PH60807QhN0P0W9bL00`0_;bl0=SHf03Hf=P0203dm?@80A4A40P1=CDd205MGE`80
HF5Q0P1WIfL206IVIP80IFEU0P1TI6@206=SH`80HF5Q101PH60=05mOG`H0H61P101OGel2061PH080
HF5Q0P1RHV8406=SH`0306ATI01UIFD0IFEU0080I6AT101SHf<4069RHP@0HF5Q1P1RHV8206=SH`80
I6AT101UIFD00`1VIVH0J6QX06QXJ00206UYJ@80JVYZ0P1[Jf/206e]K@80Kfm_0P1aLG4207EeM@80
MgMg0P1hN7P207YjNP80OGem0P1oOgl208>3P`80QhN700<0RXZ:08j>SP2>SXh00P2@T90209:BTP80
U9BD0P2EUID209JFUP80V9RH0P2JVYX209fMW@80X:2P0P2SXj<20:FUY@80YjNW0P2XZ:P20:JVYP03
0::RXP2OWil0WinO0080Vi^K0P2HV9P209FEU@80TI6A0P2>SXh208Z:RP80QhN70P23Ph<20820P080
O7al0P1iNGT207EeM@80LW9b0P1^KVh00`1[Jf/0J6QX06QXJ00206ATI080HF5Q0P1MGEd205YJFP80
EUIF0P1CDe<E0?ooo`004`3oool204e=C@80BTY:0P17AdL204A4A080@D510P0o?cl203`l?080>CTi
00<0=SHf03<c<`0c<c<00P0`<30202d];@80:RXZ0P0W9bL202<S8`80820P0P0L71`201TI6@805QHF
0P0D51@201LG5`8071`L0P0T92@202`/;00303<c<`0j>SX0>SXj0080@T920P1;Bd/205EEE@80GemO
0P1YJFT206a/K080J6QX0P1VIVH206ATI080HV9R0P1QHF42061PH0@0GemO1`1NGUh605mOG`X0H61P
0P1QHF42069RHP@0Hf=S0`1TI6@406=SH`80HV9R301QHF44069RHP80I6AT0P1UIFD206IVIP0306MW
I`1XJ6P0J6QX0080JVYZ0P1[Jf/206e]K@80Kfm_0P1aLG4207AdM080MgMg0P1iNGT207]kN`80OWin
0P21PH4208>3P`80QXJ60P2:RXX00`2=SHd0TI6A096AT@0209BDU080UIFE0P2FUYH409NGU`80VYZJ
0P2LW9`20:2PX080Xj>S0P2WYjL20:RXZ0@0ZJVY0P2VYZH00`2SXj<0WinO09nOW`0209bLW080VIVI
0P2EUID209:BTP80SXj>0P2;Rh/208N7Q`80Q8B40P20P80207emO@80NGUi0P1fMWH2079bLP80Kfm_
00<0Jf][06QXJ01XJ6P00P1TI6@2065QH@80GEeM0P1JFUX205IFEP80De=C5@3oool001<0oooo0P1=
CDd204Y:BP80AdM70P14A4@20451@@80?clo0P0l?3`203Ti>@0303Hf=P0c<c<0<c<c0080<30`0P0]
;Bd202XZ:P809bLW0P0S8b<2020P808071`L0P0I6AT201HF5P8051@D0P0G5aL201`L708092@T0P0/
;2`00`0c<c<0>SXj03Xj>P020492@P80Bd];0P1EEED205mOG`80JFUY0P1/K6`206QXJ080IVIV0P1T
I6@2069RHP80HF5Q0P1PH60405mOG`L0GUiN1P1OGel:061PH080HF5Q0P1RHV8406=SH`<0I6AT101S
Hf<2069RHP`0HF5Q101RHV8206ATI080IFEU0P1VIVH00`1WIfL0J6QX06QXJ00206YZJP80Jf][0P1]
KFd206m_K`80LG5a0P1dM7@207MgM`80NGUi0P1kNg/207inOP80PH610P23Ph<208J6QP80RXZ:00<0
SHf=096AT@2ATI400P2DU9@209FEU@80UYJF102GUiL209ZJVP80W9bL0P2PX:020:>SX`80YjNW0P2X
Z:P40:VYZ@80YZJV00<0Xj>S09nOW`2OWil00P2LW9`209VIV@80UIFE0P2BTY8208j>SP80Rh^;0P27
QhL208B4Q080P8200P1mOGd207UiN@80MWIf0P1bLW8206m_K`0306][J`1XJ6P0J6QX0080I6AT0P1Q
HF4205eMG@80FUYJ0P1FEUH205=CDaD0oooo000C0?ooo`80C4a<0P1:BTX204M7A`80A4A40P12@T82
03lo?`80?3`l0P0i>CT00`0f=SH0<c<c03<c<`02030`<080;Bd]0P0Z:RX202LW9`8092@T0P0Q8B42
01dM7@806QXJ0P0F5QH201DE5@806QXJ0P0P820202PX:080<30`00<0>3Ph03lo?`0o?cl00P17AdL2
051@D080Fe]K0P1XJ6P206i^KP80Jf][0P1XJ6P206IVIP80Hf=S0P1RHV82061PH080GemO0P1NGUh9
05eMG@80GUiN101OGel:061PH080HF5Q2`1RHV84065QH@@0H61P101OGel4061PH080HF5Q0P1RHV82
06ATI080IFEU0P1VIVH00`1XJ6P0JFUY06UYJ@0206][J`80KFe]0P1^KVh2071`L080Lg=c0P1fMWH2
07YjNP80OGem0P1oOgl20861P@80Ph>30P26QXH208Z:RP80SHf=00<0T92@09BDU02DU9@0102GUiL4
09RHV080VIVI0P2LW9`209jNWP80Xj>S0P2VYZH20:VYZ@@0Zj^[0P2ZZZX20:NWY`030:>SX`2PX:00
X:2P0080WIfM0P2IVIT209JFUP80TY:B0P2?Shl208^;R`80R8R80P24Q8@20820P080OGem0P1iNGT2
07IfMP80LW9b0P1_Kfl00`1[Jf/0J6QX06QXJ00206EUI@80HF5Q0P1MGEd205YJFP80EUIF0P1CDe<E
0?ooo`004`3oool204a<C080BTY:0P17AdL204A4A080@T920P0o?cl203`l?080>CTi00<0=SHf03<c
<`0c<c<00P0`<30202d];@80:RXZ0P0W9bL202@T90808B4Q0P0M7Ad201XJ6P805QHF0P0E5AD201XJ
6P80820P0P0X:2P2030`<00303Ph>00o?cl0?clo0080AdM70P1@D50205]KF`80J6QX0P1^KVh206][
J`80J6QX0P1VIVH206=SH`80HV9R0P1PH60205mOG`80GUiN2@1MGEd205iNGP@0GemO2P1PH602065Q
H@/0HV9R101QHF44061PH0@0GemO101PH602065QH@80HV9R0P1TI6@206EUI@80IVIV00<0J6QX06UY
J@1YJFT00P1[Jf/206e]K@80KVi^0P1`L70207=cL`80MWIf0P1jNWX207emO@80Ogmo0P21PH4208>3
P`80QXJ60P2:RXX208f=S@03092@T02DU9@0U9BD00@0UiNG102HV9P209VIV@80W9bL0P2NWYh20:>S
X`80YZJV0P2YZJT40:^[Z`80ZZZZ0P2WYjL00`2SXj<0X:2P0:2PX00209fMW@80VIVI0P2FUYH209:B
TP80Shn?0P2;Rh/208R8R080Q8B40P20P80207emO@80NGUi0P1fMWH2079bLP80Kfm_00<0Jf][06QX
J01XJ6P00P1UIFD2065QH@80GEeM0P1JFUX205IFEP80De=C5@3oool001<0oooo0P1=CDd204Y:BP80
AdM70P15ADD20492@P80?clo0P0m?Cd203Xj>P0303Lg=`0d=3@0=3@d0080<C4a0P0^;Rh202/[:`80
:2PX0P0U9BD2028R8P807alO0P0K6a/201HF5P805aLG0P0M7Ad202@T9080;Bd]0P0d=3@00`0l?3`0
A4A404A4A00204e=C@80EeMG0P1RHV8406][J`80JVYZ0P1WIfL206ATI080HV9R0P1QHF4205mOG`80
GEeM2`1LG5`205eMG@@0GUiN101OGel8061PH0L0HF5Q101PH60405mOG`X0GUiN0P1OGel2061PH080
HF5Q0P1SHf<206ATI080IVIV00<0IfMW06UYJ@1YJFT00P1[Jf/206e]K@80Kfm_0P1aLG4207AdM080
MWIf0P1jNWX207emO@80Ogmo0P22PX8208F5Q@80R8R80P2<S8`208n?S`0309>CT`2GUiL0UiNG00H0
VIVI0P2JVYX209^KV`80WYjN0P2QXJ420:JVYP80ZZZZ0P2/[:`40:f][@80Zj^[0P2WYjL00`2TY:@0
XJ6Q0:6QX@0209fMW@80VYZJ0P2FUYH209>CT`80Shn?0P2<S8`208R8R080QHF50P21PH4207inOP80
NWYj0P1fMWH207=cL`80Kfm_00<0K6a/06QXJ01XJ6P00P1UIFD2065QH@80GEeM0P1JFUX205IFEP80
De=C5@3oool001<0oooo0P1=CDd204Y:BP80AdM70P15ADD20492@P80?clo0P0m?Cd203Xj>P0303Lg
=`0d=3@0=3@d0080<C4a0P0^;Rh202/[:`80:2PX0P0U9BD2028R8P807alO0P0K6a/201HF5P805aLG
0P0M7Ad202@T9080;Bd]0P0d=3@00`0l?3`0A4A404A4A00204e=C@80EeMG0P1RHV8406][J`80JVYZ
0P1WIfL206ATI080HV9R0P1QHF4205mOG`80GEeM2`1LG5`205eMG@@0GUiN101OGel8061PH0L0HF5Q
101PH60405mOG`X0GUiN0P1OGel2061PH080HF5Q0P1SHf<206ATI080IVIV00<0IfMW06UYJ@1YJFT0
0P1[Jf/206e]K@80Kfm_0P1aLG4207AdM080MWIf0P1jNWX207emO@80Ogmo0P22PX8208F5Q@80R8R8
0P2<S8`208n?S`0309>CT`2GUiL0UiNG00H0VIVI0P2JVYX209^KV`80WYjN0P2QXJ420:JVYP80ZZZZ
0P2/[:`40:f][@80Zj^[0P2WYjL00`2TY:@0XJ6Q0:6QX@0209fMW@80VYZJ0P2FUYH209>CT`80Shn?
0P2<S8`208R8R080QHF50P21PH4207inOP80NWYj0P1fMWH207=cL`80Kfm_00<0K6a/06QXJ01XJ6P0
0P1UIFD2065QH@80GEeM0P1JFUX205IFEP80De=C5@3oool001<0oooo0P1=CDd204Y:BP80B4Q80P15
ADD20492@P80@4100P0m?Cd203Xj>P0303Lg=`0e=CD0=CDe0080<S8b0P0_;bl202`/;080:BTY0P0V
9RH202<S8`807alO0P0L71`201XJ6P807AdM0P0S8b<202TY:@80<S8b0P0i>CT00`11@D40BDU904U9
B@02059BDP80G5aL0P1WIfL206a/K080JVYZ0P1XJ6P206EUI@80Hf=S0P1QHF4205mOG`80GEeM101K
Fe/505YJFP@0Fe]K0P1LG5`205eMG@80GUiN201OGel:061PH0<0GemO0P1NGUh205eMG@@0G5aL1P1K
Fe/205aLG080GEeM0P1NGUh205mOG`80HF5Q0P1SHf<206EUI@0306MWI`1YJFT0JFUY0080Jf][0P1]
KFd206m_K`80LW9b0P1dM7@207MgM`80NWYj0P1mOGd20820P080Ph>30P26QXH208Z:RP80SHf=0P2A
TI400`2DU9@0V9RH09RHV00409ZJVP80Vi^K0P2MWId209nOW`80XJ6Q0P2UYJD20:ZZZP80[:b/0P2^
[Zh20;2`/080[Zj^0P2[Zj/20:RXZ0030:FUY@2QXJ40XJ6Q0080WYjN0P2JVYX209NGU`80Ti>C0P2@
T90208b<S080RHV90P25QHD20861P@80OWin0P1jNWX207MgM`80Lg=c0P1`L7000`1/K6`0JFUY06UY
J@0206EUI@80HF5Q0P1NGUh205YJFP80EUIF0P1CDe<E0?ooo`004`3oool204e=C@80BTY:0P18B4P2
04E5A@80@T920P10@40203dm?@80>SXj00<0=cLg03De=@0e=CD00P0b<S8202l_;`80;2`/0P0Y:BT2
02HV9P808b<S0P0O7al201`L70806QXJ0P0M7Ad202<S8`80:BTY0P0b<S8203Ti>@030451@@19BDT0
BDU90080DU9B0P1LG5`206MWI`80K6a/0P1ZJVX206QXJ080IFEU0P1SHf<2065QH@80GemO0P1MGEd4
05]KF`D0FUYJ101KFe/205aLG080GEeM0P1NGUh805mOG`X0H61P0`1OGel205iNGP80GEeM101LG5`6
05]KF`80G5aL0P1MGEd205iNGP80GemO0P1QHF4206=SH`80IFEU00<0IfMW06UYJ@1YJFT00P1[Jf/2
06e]K@80Kfm_0P1bLW8207AdM080MgMg0P1jNWX207emO@80P8200P23Ph<208J6QP80RXZ:0P2=SHd2
096AT@0309BDU02HV9P0V9RH00@0VYZJ0P2KVi/209fMW@80WinO0P2QXJ420:FUY@80ZZZZ0P2/[:`2
0:j^[P80/;2`0P2^[Zh20:^[Z`80Z:RX00<0YJFU0:6QX@2QXJ400P2NWYh209ZJVP80UiNG0P2CTi<2
092@T080S8b<0P29RHT208F5Q@80PH610P1nOWh207YjNP80MgMg0P1cLg<2071`L00306a/K01YJFT0
JFUY0080IFEU0P1QHF4205iNGP80FUYJ0P1FEUH205=CDaD0oooo000C0?ooo`80CDe=0P1:BTX204Q8
B080ADE50P12@T820410@080?Cdm0P0k>c/00`0h>3P0=CDe03De=@02038b<P80<30`0P0];Bd202XZ
:P809bLW0P0T92@2024Q8@807QhN0P0L71`2024Q8@809bLW0P0_;bl203De=@80?3`l00<0A4A404e=
C@1=CDd00P1GEeL2069RHP80Jf][0P1/K6`206UYJ@80IVIV0P1TI6@2065QH@80GemO0P1MGEd205]K
F`80FUYJ0P1IFET205QHF00305MGE`1HF5P0F5QH00@0FEUI0P1KFe/205aLG080GEeM0P1NGUh205mO
G`H0H61P1P1OGel205iNGP<0GEeM0P1LG5`205]KF`@0FUYJ1P1IFET405YJFP80G5aL0P1NGUh2061P
H080HV9R0P1TI6@00`1WIfL0JFUY06UYJ@0206][J`80KVi^0P1`L70207=cL`80MWIf0P1hN7P207]k
N`80OWin0P21PH4208B4Q080R8R80P2;Rh/208n?S`80TY:B00<0UIFE09ZJVP2JVYX00P2KVi/209bL
W080WIfM0P2NWYh20:2PX080Xj>S0P2WYjL20:b/[080[jn_0P2a/K420;:b/P80/;2`0P2/[:`20:VY
Z@030:JVYP2RXZ80XZ:R0080WinO0P2KVi/209RHV080U9BD0P2@T90208f=S@80RHV90P26QXH208:2
PP80OWin0P1kNg/207MgM`80Lg=c0P1`L7000`1/K6`0JFUY06UYJ@0206EUI@80HF5Q0P1NGUh205YJ
FP80EUIF0P1CDe<E0?ooo`004`3oool204e=C@80BTY:0P18B4P204E5A@80@T920P10@40203dm?@80
>c/k00<0>3Ph03De=@0e=CD00P0b<S82030`<080;Bd]0P0Z:RX202LW9`8092@T0P0Q8B4201hN7P80
71`L0P0Q8B4202LW9`80;bl_0P0e=CD203`l?00304A4A01=CDd0CDe=0080EeMG0P1RHV8206][J`80
K6a/0P1YJFT206IVIP80I6AT0P1QHF4205mOG`80GEeM0P1KFe/205YJFP80FEUI0P1HF5P00`1GEeL0
F5QH05QHF00405UIF@80Fe]K0P1LG5`205eMG@80GUiN0P1OGel6061PH0H0GemO0P1NGUh305eMG@80
G5aL0P1KFe/405YJFPH0FEUI101JFUX205aLG080GUiN0P1PH602069RHP80I6AT00<0IfMW06UYJ@1Y
JFT00P1[Jf/206i^KP80L71`0P1cLg<207IfMP80N7Qh0P1kNg/207inOP80PH610P24Q8@208R8R080
Rh^;0P2?Shl209:BTP0309FEU@2JVYX0VYZJ0080Vi^K0P2LW9`209fMW@80WYjN0P2PX:020:>SX`80
YjNW0P2/[:`20:n_[`80/K6a0P2b/[820;2`/080[:b/0P2YZJT00`2VYZH0XZ:R0::RXP0209nOW`80
Vi^K0P2HV9P209BDU080T92@0P2=SHd208V9R@80QXJ60P22PX8207inOP80Ng]k0P1gMgL207=cL`80
L71`00<0K6a/06UYJ@1YJFT00P1UIFD2065QH@80GUiN0P1JFUX205IFEP80De=C5@3oool001<0oooo
0P1=CDd204Y:BP80B4Q80P16ATH204=3@`80@4100P0n?Sh203/k>`0303Ph>00f=SH0=SHf0080<c<c
0P0`<30202d];@80:b/[0P0X:2P202@T90808B4Q100M7Ad202@T9080:RXZ0P0b<S8203Xj>P80@D51
00<0B4Q8055AD@1ADE400P1KFe/206IVIP80Jf][0P1XJ6P206IVIP80I6AT0P1RHV8205mOG`80GEeM
0P1KFe/205UIF@80EeMG0P1FEUH305EEE@80EUIF0P1GEeL205QHF080FUYJ0P1LG5`205eMG@80GUiN
0P1OGel6061PH0@0GemO0P1NGUh205eMG@0305aLG01KFe/0Fe]K0080FUYJ0P1IFET205QHF080EeMG
201FEUH205QHF080FUYJ0P1LG5`205iNGP80HF5Q0P1TI6@00`1VIVH0JFUY06UYJ@0206][J`80KVi^
0P1`L70207=cL`80MWIf0P1iNGT207alO080OWin0P22PX8208F5Q@80RHV90P2=SHd2092@T080U9BD
00<0V9RH09^KV`2KVi/00P2LW9`209fMW@@0WinO0P2RXZ820:FUY@80ZZZZ0P2_[jl20;>c/`80]KFe
0P2d];@20;6a/@80[Zj^0P2ZZZX00`2WYjL0Xj>S0:>SX`020:2PX080W9bL0P2HV9P209FEU@80TI6A
0P2=SHd208Z:RP80QXJ60P22PX8207moO`80Ng]k0P1gMgL207AdM080L71`00<0K6a/06UYJ@1YJFT0
0P1UIFD2069RHP80GUiN0P1JFUX205IFEP80De=C5@3oool001<0oooo0P1=CDd204Y:BP80B4Q80P16
ATH204=3@`80@4100P0n?Sh203/k>`0303Ph>00f=SH0=SHf0080<c<c0P0`<30202d];@80:b/[0P0X
:2P202@T90808B4Q100M7Ad202@T9080:RXZ0P0b<S8203Xj>P80@D5100<0B4Q8055AD@1ADE400P1K
Fe/206IVIP80Jf][0P1XJ6P206IVIP80I6AT0P1RHV8205mOG`80GEeM0P1KFe/205UIF@80EeMG0P1F
EUH305EEE@80EUIF0P1GEeL205QHF080FUYJ0P1LG5`205eMG@80GUiN0P1OGel6061PH0@0GemO0P1N
GUh205eMG@0305aLG01KFe/0Fe]K0080FUYJ0P1IFET205QHF080EeMG201FEUH205QHF080FUYJ0P1L
G5`205iNGP80HF5Q0P1TI6@00`1VIVH0JFUY06UYJ@0206][J`80KVi^0P1`L70207=cL`80MWIf0P1i
NGT207alO080OWin0P22PX8208F5Q@80RHV90P2=SHd2092@T080U9BD00<0V9RH09^KV`2KVi/00P2L
W9`209fMW@@0WinO0P2RXZ820:FUY@80ZZZZ0P2_[jl20;>c/`80]KFe0P2d];@20;6a/@80[Zj^0P2Z
ZZX00`2WYjL0Xj>S0:>SX`020:2PX080W9bL0P2HV9P209FEU@80TI6A0P2=SHd208Z:RP80QXJ60P22
PX8207moO`80Ng]k0P1gMgL207AdM080L71`00<0K6a/06UYJ@1YJFT00P1UIFD2069RHP80GUiN0P1J
FUX205IFEP80De=C5@3oool001<0oooo0P1=CDd204];B`80B4Q80P16ATH204=3@`80@D510P0n?Sh2
03`l?00303Ti>@0g=cL0=cLg0080=3@d0P0a<C4202h^;P80:b/[0P0X:2P202HV9P808b<S0P0O7al2
028R8P80:BTY0P0^;Rh203De=@80?3`l0P13@d<00`1;Bd/0EEEE05EEE@0205iNGP80IFEU0P1VIVH2
06EUI@80I6AT0P1RHV82061PH080GUiN0P1KFe/205UIF@80EUIF0P1EEED205ADE0<0De=C0P1DE5@2
05IFEP80EeMG0P1JFUX205aLG080GEeM0P1OGel2061PH0@0HF5Q0P1PH60205mOG`80GUiN0P1MGEd2
05aLG00305]KF`1JFUX0FUYJ0080FUYJ0P1HF5P205MGE`80EEEE1P1CDe<205ADE080EEEE0P1HF5P2
05YJFP80GEeM0P1PH60206=SH`0306EUI@1XJ6P0J6QX0080Jf][0P1^KVh2071`L080Lg=c0P1fMWH2
07UiN@80O7al0P1oOgl208>3P`80QXJ60P2:RXX208j>SP80TY:B0P2FUYH00`2IVIT0WIfM09fMW@02
09jNWP80WinO0P2PX:020::RXP80YZJV0P2YZJT20:j^[P80/[:b0P2f][H20;Rh^080]kNg0P2c/k<2
0:n_[`80Zj^[00<0Z:RX0:BTY02TY:@00P2PX:0209fMW@80VIVI0P2EUID2096AT@80SXj>0P2:RXX2
08J6QP80Ph>30P1oOgl207]kN`80N7Qh0P1dM7@2071`L00306e]K@1YJFT0JFUY0080IFEU0P1RHV82
05iNGP80FUYJ0P1GEeL205=CDaD0oooo000C0?ooo`80CDe=0P1;Bd/204Q8B080ATI60P13@d<20451
@@80?Shn0P0l?3`00`0i>CT0=cLg03Lg=`0203@d=080<C4a0P0^;Rh202/[:`80:2PX0P0V9RH202<S
8`807alO0P0R8R8202TY:@80;Rh^0P0e=CD203`l?080@d=300<0Bd];05EEE@1EEED00P1NGUh206EU
I@80IVIV0P1UIFD206ATI080HV9R0P1PH60205iNGP80Fe]K0P1IFET205IFEP80EEEE0P1DE5@305=C
D`80E5AD0P1FEUH205MGE`80FUYJ0P1LG5`205eMG@80GemO0P1PH604065QH@80H61P0P1OGel205iN
GP80GEeM0P1LG5`00`1KFe/0FUYJ05YJFP0205YJFP80F5QH0P1GEeL205EEE@H0De=C0P1DE5@205EE
E@80F5QH0P1JFUX205eMG@80H61P0P1SHf<00`1UIFD0J6QX06QXJ00206][J`80KVi^0P1`L70207=c
L`80MWIf0P1iNGT207alO080Ogmo0P23Ph<208J6QP80RXZ:0P2>SXh209:BTP80UYJF00<0VIVI09fM
W@2MWId00P2NWYh209nOW`80X:2P0P2RXZ820:JVYP80ZJVY0P2^[Zh20;:b/P80][Jf0P2h^;P20;Ng
]`80/k>c0P2_[jl20:^[Z`030:RXZ02TY:@0Y:BT0080X:2P0P2MWId209VIV@80UIFE0P2ATI4208j>
SP80RXZ:0P26QXH208>3P`80Ogmo0P1kNg/207QhN080M7Ad0P1`L7000`1]KFd0JFUY06UYJ@0206EU
I@80HV9R0P1NGUh205YJFP80EeMG0P1CDe<E0?ooo`004`3oool204e=C@80Bd];0P18B4P204I6AP80
A4A40P11@D4203lo?`80?Cdm00<0>SXj03Lg=`0g=cL00P0e=CD2038b<P80;bl_0P0/;2`202TY:@80
9bLW0P0T92@2024Q8@809BDU0P0Z:RX2034a<@80>3Ph0P0n?Sh204I6AP0304i>CP1IFET0FEUI0080
HV9R0P1VIVH406=SH`80HV9R0P1PH60205iNGP80Fe]K0P1IFET205IFEP80E5AD0P1BDU84055AD@<0
DU9B0P1EEED205MGE`80FUYJ0P1LG5`205iNGP80H61P0P1QHF44069RHP80HF5Q0P1PH60205mOG`80
GUiN0P1MGEd00`1KFe/0FUYJ05YJFP0205QHF080EeMG0P1EEED205=CD`80DU9B1P1ADE4205=CD`80
EEEE0P1HF5P205aLG080GemO0P1RHV800`1UIFD0J6QX06QXJ00206][J`80KFe]0P1`L70207=cL`80
MWIf0P1iNGT207emO@80PH610P24Q8@208R8R080Rh^;0P2?Shl209>CT`80UiNG00<0Vi^K09jNWP2N
WYh00P2PX:020:6QX@80XZ:R0P2UYJD20:^[Z`80[Jf]0P2b/[820;Jf]P80^KVi0P2j^[X20;Rh^080
];Bd0P2`/;020:f][@030:VYZ@2UYJD0YJFU0080XJ6Q0P2MWId209VIV@80UYJF0P2BTY8208j>SP80
Rh^;0P27QhL208>3P`80Ogmo0P1lO7`207QhN080M7Ad0P1aLG400`1]KFd0JFUY06UYJ@0206EUI@80
HV9R0P1NGUh205YJFP80EeMG0P1CDe<E0?ooo`004`3oool204e=C@80Bd];0P18B4P204I6AP80A4A4
0P11@D4203lo?`80?Cdm00<0>SXj03Lg=`0g=cL00P0e=CD2038b<P80;bl_0P0/;2`202TY:@809bLW
0P0T92@2024Q8@809BDU0P0Z:RX2034a<@80>3Ph0P0n?Sh204I6AP0304i>CP1IFET0FEUI0080HV9R
0P1VIVH406=SH`80HV9R0P1PH60205iNGP80Fe]K0P1IFET205IFEP80E5AD0P1BDU84055AD@<0DU9B
0P1EEED205MGE`80FUYJ0P1LG5`205iNGP80H61P0P1QHF44069RHP80HF5Q0P1PH60205mOG`80GUiN
0P1MGEd00`1KFe/0FUYJ05YJFP0205QHF080EeMG0P1EEED205=CD`80DU9B1P1ADE4205=CD`80EEEE
0P1HF5P205aLG080GemO0P1RHV800`1UIFD0J6QX06QXJ00206][J`80KFe]0P1`L70207=cL`80MWIf
0P1iNGT207emO@80PH610P24Q8@208R8R080Rh^;0P2?Shl209>CT`80UiNG00<0Vi^K09jNWP2NWYh0
0P2PX:020:6QX@80XZ:R0P2UYJD20:^[Z`80[Jf]0P2b/[820;Jf]P80^KVi0P2j^[X20;Rh^080];Bd
0P2`/;020:f][@030:VYZ@2UYJD0YJFU0080XJ6Q0P2MWId209VIV@80UYJF0P2BTY8208j>SP80Rh^;
0P27QhL208>3P`80Ogmo0P1lO7`207QhN080M7Ad0P1aLG400`1]KFd0JFUY06UYJ@0206EUI@80HV9R
0P1NGUh205YJFP80EeMG0P1CDe<E0?ooo`004`3oool204e=C@80Bd];0P19BDT204M7A`80A4A40P12
@T820410@080?Cdm00<0>c/k03Ph>00h>3P00P0f=SH203<c<`80<30`0P0^;Rh202/[:`80:2PX0P0V
9RH202DU9@80:BTY0P0/;2`2038b<P80>CTi0P11@D4204Q8B003059BDP1KFe/0Fe]K00H0HF5Q0P1R
HV82065QH@80GemO0P1MGEd205YJFP80EeMG0P1DE5@2059BDP80D51@101?Cdl00`1@D500DU9B059B
DP0205EEE@80F5QH0P1KFe/205iNGP80H61P0P1RHV8206=SH`80I6AT101SHf<2069RHP80H61P0P1O
Gel205eMG@0305aLG01JFUX0FUYJ0080F5QH0P1FEUH205ADE080De=C0P1ADE4404m?C`80DE5A0P1C
De<205IFEP80F5QH0P1LG5`205mOG`80HV9R00<0IFEU06QXJ01XJ6P00P1[Jf/206e]K@80L71`0P1c
Lg<207IfMP80NGUi0P1mOGd208:2PP80QXJ60P2:RXX208f=S@80TI6A0P2EUID209VIV@0309fMW@2P
X:00X:2P0080XZ:R0P2SXj<20:JVYP80ZZZZ0P2`/;020;6a/@80]KFe0P2j^[X40;^k^`80^[Zj0P2f
][H20;:b/P80[Zj^00<0ZZZZ0:JVYP2VYZH00P2RXZ8209jNWP80VYZJ0P2GUiL209>CT`80Shn?0P2;
Rh/208N7Q`80Ph>30P20P80207alO080N7Qh0P1eMGD2075aL@0306e]K@1YJFT0JFUY0080IVIV0P1R
HV8205iNGP80FUYJ0P1GEeL205=CDaD0oooo000C0?ooo`80CDe=0P1;Bd/204U9B@80AdM70P14A4@2
0492@P80@4100P0m?Cd00`0k>c/0>3Ph03Ph>00203Hf=P80<c<c0P0`<30202h^;P80:b/[0P0X:2P2
02HV9P809BDU0P0Y:BT202`/;080<S8b0P0i>CT20451@@80B4Q800<0DU9B05]KF`1KFe/01P1QHF42
069RHP80HF5Q0P1OGel205eMG@80FUYJ0P1GEeL205ADE080DU9B0P1@D50404m?C`03051@D01BDU80
DU9B0080EEEE0P1HF5P205]KF`80GUiN0P1PH602069RHP80Hf=S0P1TI6@406=SH`80HV9R0P1PH602
05mOG`80GEeM00<0G5aL05YJFP1JFUX00P1HF5P205IFEP80E5AD0P1CDe<2055AD@@0Cdm?0P1ADE42
05=CD`80EUIF0P1HF5P205aLG080GemO0P1RHV800`1UIFD0J6QX06QXJ00206][J`80KFe]0P1`L702
07=cL`80MWIf0P1iNGT207emO@80PX:20P26QXH208Z:RP80SHf=0P2ATI4209FEU@80VIVI00<0WIfM
0:2PX02PX:000P2RXZ820:>SX`80YZJV0P2ZZZX20;2`/080/K6a0P2e]KD20;Zj^P@0^k^k0P2j^[X2
0;Jf]P80/[:b0P2^[Zh00`2ZZZX0YZJV0:JVYP020::RXP80WYjN0P2JVYX209NGU`80Ti>C0P2?Shl2
08^;R`80QhN70P23Ph<20820P080O7al0P1hN7P207EeM@80LG5a00<0KFe]06UYJ@1YJFT00P1VIVH2
069RHP80GUiN0P1JFUX205MGE`80De=C5@3oool001<0oooo0P1=CDd204];B`80BDU90P17AdL204E5
A@80@T920P10@40203hn?P0303/k>`0i>CT0>CTi0080=cLg0P0d=3@2038b<P80;bl_0P0/;2`202TY
:@@09BDU0P0[:b/202h^;P80=3@d0P0k>c/204=3@`80Bd];00<0EEEE05iNGP1NGUh00P1RHV82061P
H0@0HF5Q0P1PH60205iNGP80G5aL0P1IFET205EEE@@0DU9B101DE5@2059BDP03055AD@1DE5@0E5AD
0080F5QH0P1JFUX205aLG080H61P0P1SHf<206EUI@H0IVIV0P1UIFD206ATI080Hf=S0P1RHV8205mO
G`0305eMG@1HF5P0F5QH00@0EUIF0P1GEeL205IFEP80De=C0P1ADE4205=CD`80E5AD0P1FEUH205MG
E`80FUYJ0P1MGEd2061PH080Hf=S00<0IfMW06UYJ@1YJFT00P1[Jf/206i^KP80L71`0P1cLg<207If
MP80NWYj0P1nOWh208:2PP80QhN70P2:RXX208j>SP80Ti>C0P2GUiL209^KV`030:2PX02SXj<0Xj>S
0080YJFU0P2WYjL20:^[Z`80[Zj^0P2c/k<20;Fe]@80^[Zj102o_kl20;jn_P80^k^k0P2g]kL20;>c
/`80[jn_00<0Zj^[0:NWY`2WYjL00P2SXj<209nOW`80Vi^K0P2GUiL209>CT`80Shn?0P2;Rh/208R8
R080Q8B40P20P80207alO080N7Qh0P1eMGD2075aL@0306e]K@1YJFT0JFUY0080IVIV0P1RHV8205iN
GP80FUYJ0P1GEeL205=CDaD0oooo000C0?ooo`80CDe=0P1;Bd/204U9B@80AdM70P15ADD20492@P80
@4100P0n?Sh00`0k>c/0>CTi03Ti>@0203Lg=`80=3@d0P0b<S8202l_;`80;2`/0P0Y:BT402DU9@80
:b/[0P0^;Rh203@d=080>c/k0P13@d<204];B`0305EEE@1NGUh0GUiN0080HV9R0P1PH604065QH@80
H61P0P1NGUh205aLG080FEUI0P1EEED4059BDP@0E5AD0P1BDU800`1ADE40E5AD05ADE00205QHF080
FUYJ0P1LG5`2061PH080Hf=S0P1UIFD606IVIP80IFEU0P1TI6@206=SH`80HV9R0P1OGel00`1MGEd0
F5QH05QHF00405IFEP80EeMG0P1FEUH205=CD`80DE5A0P1CDe<205ADE080EUIF0P1GEeL205YJFP80
GEeM0P1PH60206=SH`0306MWI`1YJFT0JFUY0080Jf][0P1^KVh2071`L080Lg=c0P1fMWH207YjNP80
OWin0P22PX8208N7Q`80RXZ:0P2>SXh209>CT`80UiNG0P2KVi/00`2PX:00Xj>S0:>SX`020:FUY@80
YjNW0P2[Zj/20:j^[P80/k>c0P2e]KD20;Zj^P@0_kno0P2n_[h20;^k^`80]kNg0P2c/k<20:n_[`03
0:^[Z`2WYjL0YjNW0080Xj>S0P2OWil209^KV`80UiNG0P2CTi<208n?S`80Rh^;0P28R8P208B4Q080
P8200P1lO7`207QhN080MGEe0P1aLG400`1]KFd0JFUY06UYJ@0206IVIP80HV9R0P1NGUh205YJFP80
EeMG0P1CDe<E0?ooo`004`3oool204e=C@80Bd];0P19BDT204M7A`80ADE50P13@d<20451@@80?clo
00<0?Cdm03Xj>P0j>SX00P0h>3P203De=@80<S8b0P0`<30202d];@80:RXZ0P0X:2P202XZ:P80;Bd]
0P0b<S8203Lg=`80?Shn0P16ATH204e=C@0305EEE@1LG5`0G5aL0080GemO0P1PH602065QH@80HV9R
0P1PH60205iNGP80G5aL0P1IFET205IFEP80EEEE0P1HF5P205UIF@@0EeMG00<0FEUI05]KF`1KFe/0
0P1MGEd2061PH080Hf=S0P1UIFD206IVIP80J6QX101YJFT206QXJ0@0IfMW0P1VIVH206ATI080HV9R
00<0H61P05mOG`1OGel0101NGUh205eMG@80F5QH0P1FEUH205QHF0@0FUYJ0P1LG5`205eMG@80GUiN
0P1QHF4206=SH`80IVIV00<0JFUY06][J`1[Jf/00P1]KFd206m_K`80LG5a0P1dM7@207MgM`80Ng]k
0P1oOgl208>3P`80QXJ60P2:RXX2092@T080UYJF0P2JVYX209jNWP030::RXP2VYZH0YZJV0080Z:RX
0P2[Zj/20:n_[`80/k>c0P2g]kL20;Rh^080_[jn1P31`L420;fm_@80^;Rh0P2d];@20;2`/0030:b/
[02XZ:P0Z:RX0080Y:BT0P2PX:0209bLW080V9RH0P2DU9@2092@T080S8b<0P28R8P208B4Q080P820
0P1mOGd207UiN@80MGEe0P1aLG400`1]KFd0JVYZ06YZJP0206IVIP80HV9R0P1NGUh205YJFP80EeMG
0P1CDe<E0?ooo`004`3oool204e=C@80Bd];0P19BDT204M7A`80ADE50P13@d<20451@@80?clo00<0
?Cdm03Xj>P0j>SX00P0h>3P203De=@80<S8b0P0`<30202d];@80:RXZ0P0X:2P202XZ:P80;Bd]0P0b
<S8203Lg=`80?Shn0P16ATH204e=C@0305EEE@1LG5`0G5aL0080GemO0P1PH602065QH@80HV9R0P1P
H60205iNGP80G5aL0P1IFET205IFEP80EEEE0P1HF5P205UIF@@0EeMG00<0FEUI05]KF`1KFe/00P1M
GEd2061PH080Hf=S0P1UIFD206IVIP80J6QX101YJFT206QXJ0@0IfMW0P1VIVH206ATI080HV9R00<0
H61P05mOG`1OGel0101NGUh205eMG@80F5QH0P1FEUH205QHF0@0FUYJ0P1LG5`205eMG@80GUiN0P1Q
HF4206=SH`80IVIV00<0JFUY06][J`1[Jf/00P1]KFd206m_K`80LG5a0P1dM7@207MgM`80Ng]k0P1o
Ogl208>3P`80QXJ60P2:RXX2092@T080UYJF0P2JVYX209jNWP030::RXP2VYZH0YZJV0080Z:RX0P2[
Zj/20:n_[`80/k>c0P2g]kL20;Rh^080_[jn1P31`L420;fm_@80^;Rh0P2d];@20;2`/0030:b/[02X
Z:P0Z:RX0080Y:BT0P2PX:0209bLW080V9RH0P2DU9@2092@T080S8b<0P28R8P208B4Q080P8200P1m
OGd207UiN@80MGEe0P1aLG400`1]KFd0JVYZ06YZJP0206IVIP80HV9R0P1NGUh205YJFP80EeMG0P1C
De<E0?ooo`004`3oool204e=C@80C4a<0P1:BTX204Q8B080ATI60P14A4@20492@P80@41000<0?Cdm
03/k>`0k>c/00P0i>CT203Hf=P80=3@d0P0a<C4202h^;P@0;2`/0P0];Bd202h^;P80<c<c0P0i>CT2
0451@@80B4Q80P1@D5000`1HF5P0GUiN05iNGP0205eMG@80GUiN0P1PH604065QH@80GemO0P1MGEd2
05]KF`80FUYJ0P1IFET205YJFP@0Fe]K0`1PH60206=SH`80IFEU0P1WIfL206UYJ@80Jf][0P1]KFd2
06i^KP80KFe]0P1/K6`406][J`@0JVYZ0P1XJ6P206MWI`0306EUI@1TI6@0I6AT0080I6AT0P1RHV82
05iNGP80G5aL0P1NGUh205eMG@80GemO0P1PH60206=SH`80HV9R0P1TI6@206QXJ080JFUY0P1ZJVX0
0`1/K6`0KFe]06e]K@0206m_K`80L71`0P1bLW8207EeM@80N7Qh0P1lO7`20820P080QHF50P29RHT2
08j>SP80U9BD0P2HV9P209bLW080XJ6Q00<0YZJV0:VYZ@2YZJT00P2[Zj/20:n_[`80];Bd0P2g]kL2
0;^k^`80_;bl0P31`L420<?3``80a<C40P33`l<20;jn_P80^[Zj0P2e]KD20;6a/@030:f][@2YZJT0
ZJVY0080Y:BT0P2PX:0209bLW080V9RH0P2DU9@2092@T080S8b<0P29RHT208F5Q@80PH610P1mOGd2
07UiN@80MGEe0P1aLG400`1]KFd0JVYZ06YZJP0206IVIP80HV9R0P1NGUh205YJFP80EeMG0P1CDe<E
0?ooo`004`3oool204e=C@80C4a<0P1:BTX204Q8B080ATI60P14A4@20492@P80@41000<0?Cdm03/k
>`0k>c/00P0i>CT203Hf=P80=3@d0P0a<C4202h^;P@0;2`/0P0];Bd202h^;P80<c<c0P0i>CT20451
@@80B4Q80P1@D5000`1HF5P0GUiN05iNGP0205eMG@80GUiN0P1PH604065QH@80GemO0P1MGEd205]K
F`80FUYJ0P1IFET205YJFP@0Fe]K0`1PH60206=SH`80IFEU0P1WIfL206UYJ@80Jf][0P1]KFd206i^
KP80KFe]0P1/K6`406][J`@0JVYZ0P1XJ6P206MWI`0306EUI@1TI6@0I6AT0080I6AT0P1RHV8205iN
GP80G5aL0P1NGUh205eMG@80GemO0P1PH60206=SH`80HV9R0P1TI6@206QXJ080JFUY0P1ZJVX00`1/
K6`0KFe]06e]K@0206m_K`80L71`0P1bLW8207EeM@80N7Qh0P1lO7`20820P080QHF50P29RHT208j>
SP80U9BD0P2HV9P209bLW080XJ6Q00<0YZJV0:VYZ@2YZJT00P2[Zj/20:n_[`80];Bd0P2g]kL20;^k
^`80_;bl0P31`L420<?3``80a<C40P33`l<20;jn_P80^[Zj0P2e]KD20;6a/@030:f][@2YZJT0ZJVY
0080Y:BT0P2PX:0209bLW080V9RH0P2DU9@2092@T080S8b<0P29RHT208F5Q@80PH610P1mOGd207Ui
N@80MGEe0P1aLG400`1]KFd0JVYZ06YZJP0206IVIP80HV9R0P1NGUh205YJFP80EeMG0P1CDe<E0?oo
o`004`3oool204e=C@80C4a<0P1:BTX204Q8B080ATI60P14A4@20492@P80@41000<0?Shn03`l?00l
?3`00P0j>SX203Lg=`80=CDe0P0b<S8202l_;`80:RXZ0P0Y:BT202`/;080<C4a0P0f=SH203dm?@80
A4A40P1:BTX2055AD@0305QHF01LG5`0G5aL0080G5aL0P1NGUh2065QH@80HV9R0P1SHf<8069RHP@0
I6AT101QHF4206ATI00306UYJ@1`L700L71`0080LG5a0P1cLg<207AdM080MGEe0P1dM7@207=cL`80
LG5a0P1`L70206m_K`@0KVi^101]KFd206a/K00306][J`1ZJVX0JVYZ0080J6QX0P1WIfL206IVIP80
Hf=S0P1TI6@206IVIPH0JVYZ0P1/K6`2071`L080LG5a1`1`L702075aL@80Lg=c0P1dM7@207IfMP80
NGUi0P1mOGd208:2PP80QhN70P2<S8`209:BTP80V9RH0P2MWId20:2PX080Y:BT00<0ZJVY0:f][@2]
[Jd00P2`/;020;>c/`80]kNg0P2l_;`20<30`080`L710P35aLD20<K6aP80alO70P34a<@20;no_`80
^k^k0P2f][H20;:b/P030:j^[P2YZJT0ZJVY0080YJFU0P2QXJ4209fMW@80VIVI0P2EUID2096AT@80
SHf=0P29RHT208F5Q@80PH610P1mOGd207UiN@80MGEe0P1aLG400`1]KFd0JVYZ06YZJP0206IVIP80
HV9R0P1NGUh205]KF`80EeMG0P1CDe<E0?ooo`004`3oool204e=C@80C4a<0P1:BTX204Q8B080ATI6
0P14A4@20492@P80@41000<0?Shn03`l?00l?3`00P0j>SX203Lg=`80=CDe0P0b<S8202l_;`80:RXZ
0P0Y:BT202`/;080<C4a0P0f=SH203dm?@80A4A40P1:BTX2055AD@0305QHF01LG5`0G5aL0080G5aL
0P1NGUh2065QH@80HV9R0P1SHf<8069RHP@0I6AT101QHF4206ATI00306UYJ@1`L700L71`0080LG5a
0P1cLg<207AdM080MGEe0P1dM7@207=cL`80LG5a0P1`L70206m_K`@0KVi^101]KFd206a/K00306][
J`1ZJVX0JVYZ0080J6QX0P1WIfL206IVIP80Hf=S0P1TI6@206IVIPH0JVYZ0P1/K6`2071`L080LG5a
1`1`L702075aL@80Lg=c0P1dM7@207IfMP80NGUi0P1mOGd208:2PP80QhN70P2<S8`209:BTP80V9RH
0P2MWId20:2PX080Y:BT00<0ZJVY0:f][@2][Jd00P2`/;020;>c/`80]kNg0P2l_;`20<30`080`L71
0P35aLD20<K6aP80alO70P34a<@20;no_`80^k^k0P2f][H20;:b/P030:j^[P2YZJT0ZJVY0080YJFU
0P2QXJ4209fMW@80VIVI0P2EUID2096AT@80SHf=0P29RHT208F5Q@80PH610P1mOGd207UiN@80MGEe
0P1aLG400`1]KFd0JVYZ06YZJP0206IVIP80HV9R0P1NGUh205]KF`80EeMG0P1CDe<E0?ooo`004`3o
ool204i>CP80C4a<0P1:BTX204U9B@80AdM70P15ADD204=3@`80@D5100<0?clo03dm?@0m?Cd00P0k
>c/203Ti>@80=SHf0P0d=3@2034a<@80;Bd]0P0/;2`202h^;P80<C4a0P0g=cL203lo?`80ADE50P1;
Bd/2055AD@0305MGE`1KFe/0Fe]K0080G5aL0P1OGel2069RHP80I6AT0P1UIFD206IVIP80J6QX0P1Z
JVX206e]K@@0Kfm_0P1`L702079bLP80MGEe00<0MgMg07UiN@1iNGT00P1kNg/407emO@80Ng]k0P1i
NGT207MgM`80MGEe0P1cLg<2079bLPX0LG5a0`1`L70206m_K`80KVi^0P1]KFd2071`L080M7Ad101f
MWH407MgM`80NGUi0P1kNg/207YjNP80N7Qh0P1fMWH307EeM@80M7Ad0P1eMGD207MgM`80NGUi0P1l
O7`20820P080QHF50P29RHT208n?S`80U9BD0P2JVYX209nOW`80Xj>S0P2XZ:P00`2][Jd0/K6a0;6a
/@020;Bd]080^;Rh0P2l_;`20<30`080a<C40P35aLD20<S8b0@0bLW90P35aLD20<71`@80_;bl0P2g
]kL20;>c/`030:j^[P2ZZZX0ZZZZ0080YZJV0P2RXZ8209fMW@80VIVI0P2EUID2096AT@80SHf=0P29
RHT208F5Q@80PH610P1mOGd207UiN@80MWIf0P1bLW800`1^KVh0JVYZ06YZJP0206IVIP80HV9R0P1N
GUh205]KF`80EeMG0P1CDe<E0?ooo`004`3oool204i>CP80C4a<0P1:BTX204U9B@80AdM70P15ADD2
04=3@`80@D5100<0?clo03dm?@0m?Cd00P0k>c/203Ti>@80=SHf0P0d=3@2034a<@80;Bd]0P0/;2`2
02h^;P80<C4a0P0g=cL203lo?`80ADE50P1;Bd/2055AD@0305MGE`1KFe/0Fe]K0080G5aL0P1OGel2
069RHP80I6AT0P1UIFD206IVIP80J6QX0P1ZJVX206e]K@@0Kfm_0P1`L702079bLP80MGEe00<0MgMg
07UiN@1iNGT00P1kNg/407emO@80Ng]k0P1iNGT207MgM`80MGEe0P1cLg<2079bLPX0LG5a0`1`L702
06m_K`80KVi^0P1]KFd2071`L080M7Ad101fMWH407MgM`80NGUi0P1kNg/207YjNP80N7Qh0P1fMWH3
07EeM@80M7Ad0P1eMGD207MgM`80NGUi0P1lO7`20820P080QHF50P29RHT208n?S`80U9BD0P2JVYX2
09nOW`80Xj>S0P2XZ:P00`2][Jd0/K6a0;6a/@020;Bd]080^;Rh0P2l_;`20<30`080a<C40P35aLD2
0<S8b0@0bLW90P35aLD20<71`@80_;bl0P2g]kL20;>c/`030:j^[P2ZZZX0ZZZZ0080YZJV0P2RXZ82
09fMW@80VIVI0P2EUID2096AT@80SHf=0P29RHT208F5Q@80PH610P1mOGd207UiN@80MWIf0P1bLW80
0`1^KVh0JVYZ06YZJP0206IVIP80HV9R0P1NGUh205]KF`80EeMG0P1CDe<E0?ooo`004`3oool204i>
CP80C4a<0P1;Bd/204U9B@80B4Q80P16ATH204A4A080@T9200<0@D5103lo?`0o?cl00P0l?3`203Xj
>P80>3Ph0P0e=CD203<c<`80<S8b0P0a<C4202l_;`80<S8b0P0i>CT20410@080ATI60P1<C4`205=C
D`0305QHF01JFUX0FUYJ0080G5aL0P1OGel2069RHP80IFEU0P1WIfL206UYJ@80K6a/0P1_Kfl207=c
L`80MgMg0P1jNWX207alO080OWin0P20P80308:2PP@0PH610P20P80207inOP80O7al0P1jNWX207Mg
M`80MWIf0P1eMGD607AdM0L0Lg=c0P1dM7@207EeM@80MgMg0P1hN7P207]kN`80OWin0P21PH4208>3
P`80Q8B40P23Ph<20861P@80Ogmo0P1mOGd207YjNP0307UiN@1gMgL0MgMg0080MgMg0P1hN7P207Yj
NP80O7al0P1oOgl208>3P`80QhN70P2;Rh/2092@T080UYJF0P2LW9`20::RXP80Z:RX0P2/[:`00`2a
/K40]KFe0;Fe]@020;Rh^080_;bl0P31`L420<C4a080alO70P38b<P20<_;b`80cLg=0P3<c<`20<O7
a`80`/;20P2m_Kd20;Rh^080];Bd00<0[jn_0:^[Z`2[Zj/00P2VYZH20::RXP80WYjN0P2JVYX209JF
UP80TI6A0P2=SHd208V9R@80QHF50P21PH4207emO@80NWYj0P1fMWH2079bLP0306i^KP1ZJVX0JVYZ
0080IVIV0P1RHV8205iNGP80Fe]K0P1GEeL205=CDaD0oooo000C0?ooo`80CTi>0P1<C4`204];B`80
BDU90P18B4P204I6AP80A4A40P12@T800`11@D40?clo03lo?`0203`l?080>SXj0P0h>3P203De=@80
<c<c0P0b<S82034a<@80;bl_0P0b<S8203Ti>@80@4100P16ATH204a<C080De=C00<0F5QH05YJFP1J
FUX00P1LG5`205mOG`80HV9R0P1UIFD206MWI`80JFUY0P1/K6`206m_K`80Lg=c0P1gMgL207YjNP80
O7al0P1nOWh20820P0<0PX:21021PH420820P080OWin0P1lO7`207YjNP80MgMg0P1fMWH207EeM@H0
M7Ad1`1cLg<207AdM080MGEe0P1gMgL207QhN080Ng]k0P1nOWh20861P@80Ph>30P24Q8@208>3P`80
PH610P1oOgl207emO@80NWYj00<0NGUi07MgM`1gMgL00P1gMgL207QhN080NWYj0P1lO7`207moO`80
Ph>30P27QhL208^;R`80T92@0P2FUYH209bLW080XZ:R0P2XZ:P20:b/[0030;6a/@2e]KD0]KFe0080
^;Rh0P2l_;`20<71`@80a<C40P37alL20<S8b080bl_;0P3=cLd20<c<c080alO70P32`/820;fm_@80
^;Rh0P2d];@00`2_[jl0Zj^[0:^[Z`020:JVYP80XZ:R0P2NWYh209ZJVP80UYJF0P2ATI4208f=S@80
RHV90P25QHD20861P@80OGem0P1jNWX207IfMP80LW9b00<0KVi^06YZJP1ZJVX00P1VIVH2069RHP80
GUiN0P1KFe/205MGE`80De=C5@3oool001<0oooo0P1>CTh204a<C080Bd];0P1:BTX204Q8B080AdM7
0P15ADD204A4A0030492@P10@400@4100080?Shn0P0l?3`203Ti>@80=cLg0P0e=CD203<c<`80<30`
0P0a<C4203Hf=P80?Cdm0P13@d<204Y:BP80Cdm?0P1DE5@00`1HF5P0Fe]K05]KF`0205eMG@80H61P
0P1TI6@206MWI`80JFUY0P1[Jf/206e]K@80L71`0P1dM7@207MgM`80NWYj0P1lO7`207emO@80OWin
00<0Ogmo0820P020P8000P21PH4408>3P`80PH610P1nOWh207alO080NWYj0P1hN7P807IfMPD0MgMg
101eMGD207IfMP80N7Qh0P1kNg/207moO`80PH610P23Ph<208B4Q080Ph>30P22PX820820P080OWin
0P1lO7`207]kN`<0NGUi0P1jNWX207]kN`80O7al0P1oOgl208:2PP80QXJ60P2:RXX208j>SP80Ti>C
0P2IVIT209nOW`80Y:BT0P2ZZZX20;2`/0030;Fe]@2h^;P0^;Rh0080_;bl0P30`<020<C4a080alO7
0P3:b/X20<_;b`80c/k>0P3?cll20<c<c080alO70P32`/820;jn_P80^KVi0P2d];@00`2`/;00Zj^[
0:^[Z`020:NWY`80Xj>S0P2NWYh209ZJVP80UYJF0P2BTY8208j>SP80RXZ:0P26QXH208:2PP80OWin
0P1jNWX207IfMP80LW9b00<0KVi^06YZJP1ZJVX00P1VIVH2069RHP80GUiN0P1KFe/205MGE`80De=C
5@3oool001<0oooo0P1>CTh204e=C@80C4a<0P1:BTX204U9B@80B4Q80P16ATH204E5A@0304=3@`12
@T80@T920080@4100P0n?Sh203/k>`80>CTi0P0f=SH203@d=080<S8b0P0g=cL203`l?080@T920P18
B4P204i>CP80DU9B0P1GEeL00`1JFUX0G5aL05aLG00205mOG`80HV9R0P1VIVH206UYJ@80Jf][0P1]
KFd206i^KP80LG5a0P1cLg<207IfMP80N7Qh0P1iNGT207alO080P82000<0Q8B408N7Q`27QhL00P2:
RXX208V9R@80QHF50P22PX8207moO`80O7al0P1jNWX207UiN@80N7Qh101gMgL207QhN080NGUi0P1j
NWX00`1lO7`0OGem07emO@0207emO@H0O7al0P1mOGd207moO`H0P8200P1oOgl207inOP80OGem0P1l
O7`307]kN`80O7al0P1mOGd207inOP80Ogmo0P22PX8208F5Q@80RHV90P2<S8`2092@T080UYJF0P2L
W9`20::RXP80Z:RX0P2_[jl20;Jf]P030;Zj^P2n_[h0_[jn0080`<300P34a<@20<O7a`80b/[:0P3;
bl/20<g=c@@0d=3@0P3=cLd20<S8b080`l?30P2n_[h20;Zj^P80]KFe00<0/;2`0:b/[02/[:`00P2W
YjL20:>SX`80WinO0P2JVYX209JFUP80TY:B0P2>SXh208Z:RP80QXJ60P22PX8207inOP80NWYj0P1f
MWH2079bLP0306i^KP1ZJVX0JVYZ0080IVIV0P1RHV8205mOG`80Fe]K0P1GEeL205=CDaD0oooo000C
0?ooo`80CTi>0P1=CDd204a<C080BTY:0P19BDT204Q8B080ATI60P15ADD00`13@d<0@T920492@P02
0410@080?Shn0P0k>c/203Ti>@80=SHf0P0d=3@2038b<P80=cLg0P0l?3`20492@P80B4Q80P1>CTh2
059BDP80EeMG00<0FUYJ05aLG01LG5`00P1OGel2069RHP80IVIV0P1YJFT206][J`80KFe]0P1^KVh2
075aL@80Lg=c0P1fMWH207QhN080NGUi0P1lO7`20820P00308B4Q027QhL0QhN70080RXZ:0P29RHT2
08F5Q@80PX:20P1oOgl207alO080NWYj0P1iNGT207QhN0@0MgMg0P1hN7P207UiN@80NWYj00<0O7al
07emO@1mOGd00P1mOGd607alO080OGem0P1oOgl60820P080Ogmo0P1nOWh207emO@80O7al0`1kNg/2
07alO080OGem0P1nOWh207moO`80PX:20P25QHD208V9R@80S8b<0P2@T90209JFUP80W9bL0P2RXZ82
0:RXZ080[jn_0P2f][H00`2j^[X0_[jn0;jn_P020<30`080a<C40P37alL20<[:bP80bl_;0P3=cLd4
0=3@d080cLg=0P38b<P20<?3``80_[jn0P2j^[X20;Fe]@030;2`/02/[:`0[:b/0080YjNW0P2SXj<2
09nOW`80VYZJ0P2FUYH209:BTP80SXj>0P2:RXX208J6QP80PX:20P1nOWh207YjNP80MWIf0P1bLW80
0`1^KVh0JVYZ06YZJP0206IVIP80HV9R0P1OGel205]KF`80EeMG0P1CDe<E0?ooo`004`3oool204i>
CP80CDe=0P1<C4`204];B`80BTY:0P19BDT204Q8B080ATI600<0ADE504=3@`13@d<00P11@D4203lo
?`80?Cdm0P0k>c/203Hf=P80=CDe0P0f=SH203`l?080@T920P19BDT204e=C@80DE5A0P1EEED205UI
F@0305aLG01NGUh0GUiN0080HF5Q0P1UIFD206UYJ@80K6a/0P1^KVh206m_K`80L71`0P1aLG4207=c
L`80MGEe0P1gMgL207alO080Ph>30P29RHT308b<S080RXZ:0P28R8P208F5Q@80PX:20P1oOgl207al
O080NWYj0P1iNGT607QhN080NGUi0P1jNWX207]kN`0307inOP21PH40PH610080Q8B41026QXH208B4
Q080PH610P1oOgl207inOPH0OGem1P1lO7`207emO@0307moO`20P800P8200080PH610P22PX8208>3
P`80QHF50P28R8P208b<S080T92@0P2DU9@209ZJVP80X:2P0P2VYZH20:^[Z`80/K6a0P2h^;P00`2n
_[h0`L710<71`@020<C4a080b<S80P3;bl/20<g=c@@0c/k>103Bd]820<g=c@80bLW90P34a<@20;no
_`80^[Zj0P2e]KD00`2a/K40[:b/0:b/[0020:RXZ080Xj>S0P2OWil209^KV`80UYJF0P2BTY8208j>
SP80RXZ:0P26QXH208:2PP80OWin0P1jNWX207IfMP80LW9b00<0KVi^06YZJP1ZJVX00P1VIVH2069R
HP80GemO0P1KFe/205MGE`80De=C5@3oool001<0oooo0P1>CTh204e=C@80C4a<0P1;Bd/204Y:BP80
BDU90P18B4P204I6AP0304E5A@13@d<0@d=30080@D510P0o?cl203dm?@80>c/k0P0f=SH203De=@80
=SHf0P0l?3`20492@P80BDU90P1=CDd2055AD@80EEEE0P1IFET00`1LG5`0GUiN05iNGP02065QH@80
IFEU0P1YJFT206a/K080KVi^0P1_Kfl2071`L080LG5a0P1cLg<207EeM@80MgMg0P1lO7`208>3P`80
RHV90`2<S8`208Z:RP80R8R80P25QHD208:2PP80Ogmo0P1lO7`207YjNP80NGUi1P1hN7P207UiN@80
NWYj0P1kNg/00`1nOWh0PH610861P@0208B4Q0@0QXJ60P24Q8@20861P@80Ogmo0P1nOWh607emO@H0
O7al0P1mOGd00`1oOgl0P8200820P0020861P@80PX:20P23Ph<208F5Q@80R8R80P2<S8`2092@T080
U9BD0P2JVYX20:2PX080YZJV0P2[Zj/20;6a/@80^;Rh00<0_[jn0<71`@31`L400P34a<@20<S8b080
bl_;0P3=cLd40<k>cP@0d];B0P3=cLd20<W9b@80a<C40P2o_kl20;Zj^P80]KFe00<0/K6a0:b/[02/
[:`00P2XZ:P20:>SX`80WinO0P2KVi/209JFUP80TY:B0P2>SXh208Z:RP80QXJ60P22PX8207inOP80
NWYj0P1fMWH2079bLP0306i^KP1ZJVX0JVYZ0080IVIV0P1RHV8205mOG`80Fe]K0P1GEeL205=CDaD0
oooo000C0?ooo`80CTi>101=CDd204a<C080Bd];0P1:BTX204U9B@80B4Q800<0ATI604E5A@15ADD0
0P14A4@20492@P80@4100P0m?Cd203Ti>@80=cLg0P0h>3P20451@@80B4Q80P1>CTh2059BDP80EUIF
0P1IFET205aLG00305mOG`1RHV80HV9R0080IFEU0P1XJ6P206a/K080Kfm_0P1aLG4207AdM080MgMg
0P1hN7P207UiN@80Ng]k0P20P80208F5Q@D0RHV90P28R8P208N7Q`80QHF50P22PX820820P080OWin
0P1lO7`207YjNPX0NGUi0P1jNWX207alO00307inOP20P800P8200080Ph>30P25QHD208R8R080RHV9
0P2:RXX208V9R@80QhN70P24Q8@208:2PP@0PH610P22PX8908>3P`80Q8B40P26QXH208V9R@80S8b<
0P2?Shl209:BTP80UiNG0P2MWId20:6QX@80YjNW0P2][Jd20;Fe]@80_Kfm00<0`/;20<G5a@35aLD0
0P39bLT20<c<c080clo?0P3@d=020=7Ad@80dm?C0P3Fe]H20=?Cd`80c/k>0P39bLT20<C4a080_kno
0P2k^k/20;Jf]P030;6a/@2][Jd0[Jf]0080Z:RX0P2TY:@209nOW`80Vi^K0P2GUiL209:BTP80SXj>
0P2:RXX208J6QP80PX:20P1nOWh207YjNP80MWIf0P1bLW800`1^KVh0JVYZ06YZJP0206IVIP80HV9R
0P1OGel205]KF`80EeMG0P1CDe<E0?ooo`004`3oool204i>CP@0CDe=0P1<C4`204];B`80BTY:0P19
BDT204Q8B00304I6AP15ADD0ADE50080A4A40P12@T820410@080?Cdm0P0i>CT203Lg=`80>3Ph0P11
@D4204Q8B080CTi>0P1BDU8205IFEP80FEUI0P1LG5`00`1OGel0HV9R069RHP0206EUI@80J6QX0P1/
K6`206m_K`80LG5a0P1dM7@207MgM`80N7Qh0P1iNGT207]kN`80P8200P25QHD508V9R@80R8R80P27
QhL208F5Q@80PX:20P20P80207inOP80O7al0P1jNWX:07UiN@80NWYj0P1lO7`00`1nOWh0P8200820
P00208>3P`80QHF50P28R8P208V9R@80RXZ:0P29RHT208N7Q`80Q8B40P22PX840861P@80PX:22@23
Ph<208B4Q080QXJ60P29RHT208b<S080Shn?0P2BTY8209NGU`80WIfM0P2QXJ420:NWY`80[Jf]0P2e
]KD20;fm_@030<;2`P35aLD0aLG50080bLW90P3<c<`20<o?c`80d=3@0P3AdM420=?Cd`80e]KF0P3C
dm<20<k>cP80bLW90P34a<@20;no_`80^k^k0P2f][H00`2a/K40[Jf]0:f][@020:RXZ080Y:BT0P2O
Wil209^KV`80UiNG0P2BTY8208j>SP80RXZ:0P26QXH208:2PP80OWin0P1jNWX207IfMP80LW9b00<0
KVi^06YZJP1ZJVX00P1VIVH2069RHP80GemO0P1KFe/205MGE`80De=C5@3oool001<0oooo101>CTh2
04e=C@@0C4a<0P1;Bd/204Y:BP80BDU900<0B4Q804M7A`17AdL00P16ATH204E5A@80@d=30P11@D42
03lo?`80?Shn0P11@D4204M7A`80CTi>0P1BDU8205IFEP80FUYJ0P1MGEd2061PH00306=SH`1UIFD0
IFEU0080JFUY0P1/K6`206m_K`80LW9b0P1cLg<207EeM@80N7Qh0P1kNg/207moO`80PX:20P24Q8@2
08F5Q@@0QXJ60`25QHD208>3P`80PX:20P20P80207inOP80O7al0P1kNg/407UiN@P0N7Qh0P1iNGT2
07]kN`0307alO01oOgl0Ogmo0080PH610P23Ph<208F5Q@H0QXJ60P27QhL208R8R080RHV90P28R8P2
08N7Q`80QXJ62@25QHD208J6QP80R8R80P2;Rh/208n?S`80TY:B0P2FUYH209ZJVP80WinO0P2TY:@2
0:^[Z`80/k>c0P2k^k/20<?3``030<K6aP3:b/X0b/[:0080c/k>0P3@d=020=;BdP80e=CD0P3EeMD2
0=SHf080fMWI0P3De=@20<o?c`80b/[:0P35aLD20<30`080^k^k0P2f][H00`2b/[80[Jf]0:f][@02
0:RXZ080Y:BT0P2PX:0209^KV`80UiNG0P2CTi<208j>SP80RXZ:0P26QXH208:2PP80OWin0P1jNWX2
07IfMP80LW9b00<0KVi^06YZJP1ZJVX00P1VIVH2069RHP80GemO0P1KFe/205MGE`80De=C5@3oool0
01<0oooo101>CTh204e=C@@0C4a<0P1;Bd/204Y:BP80BDU900<0B4Q804M7A`17AdL00P16ATH204E5
A@80@d=30P11@D4203lo?`80?Shn0P11@D4204M7A`80CTi>0P1BDU8205IFEP80FUYJ0P1MGEd2061P
H00306=SH`1UIFD0IFEU0080JFUY0P1/K6`206m_K`80LW9b0P1cLg<207EeM@80N7Qh0P1kNg/207mo
O`80PX:20P24Q8@208F5Q@@0QXJ60`25QHD208>3P`80PX:20P20P80207inOP80O7al0P1kNg/407Ui
N@P0N7Qh0P1iNGT207]kN`0307alO01oOgl0Ogmo0080PH610P23Ph<208F5Q@H0QXJ60P27QhL208R8
R080RHV90P28R8P208N7Q`80QXJ62@25QHD208J6QP80R8R80P2;Rh/208n?S`80TY:B0P2FUYH209ZJ
VP80WinO0P2TY:@20:^[Z`80/k>c0P2k^k/20<?3``030<K6aP3:b/X0b/[:0080c/k>0P3@d=020=;B
dP80e=CD0P3EeMD20=SHf080fMWI0P3De=@20<o?c`80b/[:0P35aLD20<30`080^k^k0P2f][H00`2b
/[80[Jf]0:f][@020:RXZ080Y:BT0P2PX:0209^KV`80UiNG0P2CTi<208j>SP80RXZ:0P26QXH208:2
PP80OWin0P1jNWX207IfMP80LW9b00<0KVi^06YZJP1ZJVX00P1VIVH2069RHP80GemO0P1KFe/205MG
E`80De=C5@3oool001<0oooo0P1?Cdl404i>CP@0CDe=0P1<C4`404];B`<0BTY:0P19BDT204Q8B080
ATI60P15ADD204=3@`80@T920P16ATH204a<C080DU9B0P1EEED205UIF@80GEeM0P1PH60206=SH`03
06IVIP1XJ6P0J6QX0080K6a/0P1^KVh2079bLP80M7Ad0P1eMGD207MgM`80NGUi0P1kNg/207inOP80
P8200P22PX8408>3P`D0PX:20P20P80207moO`80OWin0P1lO7`207]kN`80NWYj101hN7P607MgM`80
N7Qh0P1iNGT207YjNP0307]kN`1mOGd0OGem0080OWin0P20P80208:2PP@0Ph>31024Q8@?08F5Q@80
QXJ60P27QhL208V9R@80Rh^;0P2=SHd2092@T080U9BD0P2IVIT209jNWP80Xj>S0P2YZJT20;2`/080
^;Rh0P2o_kl20<O7a`030<_;b`3>c/h0c/k>0080d];B0P3Cdm<20=GEe@80emOG0P3Hf=P20=cLg080
fm_K0P3EeMD20=3@d080bl_;0P36a/H20<30`080_;bl0P2g]kL00`2b/[80[Jf]0:f][@020:VYZ@80
Y:BT0P2PX:0209^KV`80UiNG0P2CTi<208n?S`80RXZ:0P26QXH208:2PP80OWin0P1jNWX207IfMP80
LW9b00<0KVi^06YZJP1ZJVX00P1VIVH2069RHP80GemO0P1KFe/205MGE`80De=C5@3oool001<0oooo
0P1?Cdl404i>CP@0CDe=0P1<C4`404];B`<0BTY:0P19BDT204Q8B080ATI60P15ADD204=3@`80@T92
0P16ATH204a<C080DU9B0P1EEED205UIF@80GEeM0P1PH60206=SH`0306IVIP1XJ6P0J6QX0080K6a/
0P1^KVh2079bLP80M7Ad0P1eMGD207MgM`80NGUi0P1kNg/207inOP80P8200P22PX8408>3P`D0PX:2
0P20P80207moO`80OWin0P1lO7`207]kN`80NWYj101hN7P607MgM`80N7Qh0P1iNGT207YjNP0307]k
N`1mOGd0OGem0080OWin0P20P80208:2PP@0Ph>31024Q8@?08F5Q@80QXJ60P27QhL208V9R@80Rh^;
0P2=SHd2092@T080U9BD0P2IVIT209jNWP80Xj>S0P2YZJT20;2`/080^;Rh0P2o_kl20<O7a`030<_;
b`3>c/h0c/k>0080d];B0P3Cdm<20=GEe@80emOG0P3Hf=P20=cLg080fm_K0P3EeMD20=3@d080bl_;
0P36a/H20<30`080_;bl0P2g]kL00`2b/[80[Jf]0:f][@020:VYZ@80Y:BT0P2PX:0209^KV`80UiNG
0P2CTi<208n?S`80RXZ:0P26QXH208:2PP80OWin0P1jNWX207IfMP80LW9b00<0KVi^06YZJP1ZJVX0
0P1VIVH2069RHP80GemO0P1KFe/205MGE`80De=C5@3oool001<0oooo101?Cdl604i>CPH0CDe=0`1<
C4`404];B`80BTY:1P19BDT204e=C@80DE5A0P1DE5@205MGE`80G5aL0P1PH60206=SH`80IVIV00<0
J6QX06][J`1[Jf/00P1_Kfl2075aL@80M7Ad0P1fMWH207MgM`80N7Qh0P1jNWX207]kN`80OGem0P1n
OWh207moO`L0P8200P1oOgl207inOP80OGem0P1lO7`207YjNP80NGUi0P1hN7P407MgM`P0MWIf0P1g
MgL207QhN00307UiN@1jNWX0NWYj0080O7al0P1mOGd207moO`80P8201021PH4208:2PP@0Ph>31024
Q8@408F5Q@<0QXJ60P27QhL208V9R@80RXZ:0P2<S8`2092@T080TY:B0P2FUYH209ZJVP80WYjN0P2V
YZH20:f][@80/k>c0P2j^[X20<;2`P80b/[:00<0c/k>0=;BdP3Bd]800P3Fe]H20=OGe`80fMWI0P3K
fm/20=cLg080gmoO0P3Lg=`20=KFeP80dM7A0P3;bl/20<K6aP80`L710P2l_;`20;Ng]`030;:b/P2]
[Jd0[Jf]0080ZJVY0P2TY:@20:2PX080Vi^K0P2GUiL209>CT`80Shn?0P2:RXX208J6QP80PX:20P1n
OWh207YjNP80MWIf0P1bLW800`1^KVh0JVYZ06YZJP0206IVIP80HV9R0P1OGel205]KF`80EeMG0P1C
De<E0?ooo`004`3oool404m?C`H0CTi>1P1=CDd304a<C0@0Bd];0P1:BTX604U9B@80CDe=0P1ADE42
05ADE080EeMG0P1LG5`2061PH080Hf=S0P1VIVH00`1XJ6P0Jf][06][J`0206m_K`80LG5a0P1dM7@2
07IfMP80MgMg0P1hN7P207YjNP80Ng]k0P1mOGd207inOP80Ogmo1`20P80207moO`80OWin0P1mOGd2
07alO080NWYj0P1iNGT207QhN0@0MgMg201fMWH207MgM`80N7Qh00<0NGUi07YjNP1jNWX00P1lO7`2
07emO@80Ogmo0P20P8040861P@80PX:21023Ph<408B4Q0@0QHF50`26QXH208N7Q`80RHV90P2:RXX2
08b<S080T92@0P2BTY8209JFUP80VYZJ0P2NWYh20:JVYP80[Jf]0P2c/k<20;Zj^P80`/;20P3:b/X0
0`3>c/h0d];B0=;BdP020=KFeP80emOG0P3IfMT20=_Kf`80g=cL0P3Ogml20=cLg080e]KF0P3AdM42
0<_;b`80a/K60P31`L420;bl_080]kNg00<0/[:b0:f][@2][Jd00P2YZJT20:BTY080X:2P0P2KVi/2
09NGU`80Ti>C0P2?Shl208Z:RP80QXJ60P22PX8207inOP80NWYj0P1fMWH2079bLP0306i^KP1ZJVX0
JVYZ0080IVIV0P1RHV8205mOG`80Fe]K0P1GEeL205=CDaD0oooo000C0?ooo`X0Cdm?5@1>CTh2055A
D@80E5AD0P1GEeL205YJFP80GUiN0P1RHV8206EUI@80J6QX00<0K6a/06m_K`1_Kfl00P1cLg<207Ee
M@80MgMg101hN7P207UiN@80Ng]k0P1lO7`407emO@P0OWin00<0OGem07alO01lO7`00P1kNg/207Yj
NP80NGUi0P1hN7P207MgM`@0MWIf0P1eMGD607AdM080MGEe101fMWH00`1hN7P0NGUi07UiN@0207Yj
NP80Ng]k0P1lO7`207emO@80OWin0P1oOgl20820P080PH610P22PX8408>3P`80Q8B40P25QHD308J6
QP80QhN70P29RHT208^;R`80SXj>0P2ATI4209BDU080UiNG0P2LW9`20::RXP80ZJVY0P2_[jl20;Jf
]P80_[jn0P36a/H20<g=c@030=7Ad@3Fe]H0e]KF0080fMWI0P3Kfm/20=gMg@80gmoO0P3QhN420>;R
hP80gMgM0P3GemL20=7Ad@80c<c<0P36a/H20<71`@80_;bl0P2g]kL00`2b/[80[Zj^0:j^[P020:VY
Z@80Y:BT0P2PX:0209^KV`80UiNG0P2CTi<208n?S`80RXZ:0P26QXH208:2PP80OWin0P1jNWX207If
MP80LW9b00<0KVi^06YZJP1ZJVX00P1VIVH2069RHP80GemO0P1KFe/205MGE`80De=C5@3oool001<0
oooo2P1?CdlE04i>CP80DE5A0P1DE5@205MGE`80FUYJ0P1NGUh2069RHP80IFEU0P1XJ6P00`1/K6`0
Kfm_06m_K`0207=cL`80MGEe0P1gMgL407QhN080NGUi0P1kNg/207alO0@0OGem201nOWh00`1mOGd0
O7al07alO00207]kN`80NWYj0P1iNGT207QhN080MgMg101fMWH207EeM@H0M7Ad0P1eMGD407IfMP03
07QhN01iNGT0NGUi0080NWYj0P1kNg/207alO080OGem0P1nOWh207moO`80P8200P21PH4208:2PP@0
Ph>30P24Q8@208F5Q@<0QXJ60P27QhL208V9R@80Rh^;0P2>SXh2096AT@80U9BD0P2GUiL209bLW080
XZ:R0P2YZJT20:n_[`80][Jf0P2n_[h20<K6aP80cLg=00<0dM7A0=KFeP3Fe]H00P3IfMT20=_Kf`80
gMgM0P3Ogml20>7Qh@80h^;R0P3MgMd20=OGe`80dM7A0P3<c<`20<K6aP80`L710P2l_;`20;Ng]`03
0;:b/P2^[Zh0[Zj^0080ZJVY0P2TY:@20:2PX080Vi^K0P2GUiL209>CT`80Shn?0P2:RXX208J6QP80
PX:20P1nOWh207YjNP80MWIf0P1bLW800`1^KVh0JVYZ06YZJP0206IVIP80HV9R0P1OGel205]KF`80
EeMG0P1CDe<E0?ooo`004`3oool604m?C`d0D51@1P1ADE46059BDP80EUIF0P1IFET205aLG080H61P
0P1RHV8206EUI@80J6QX0P1/K6`00`1_Kfl0LW9b079bLP0207EeM@80N7Qh0P1iNGT407YjNP@0Ng]k
1P1lO7`407emO@@0O7al00<0Ng]k07YjNP1jNWX00P1iNGT207QhN080MgMg0P1fMWH207EeM@@0M7Ad
201cLg<407AdM080MGEe00<0MWIf07MgM`1gMgL00P1hN7P207UiN@80NWYj0P1lO7`407emO@80OWin
0P1oOgl20820P080PH610P22PX8208B4Q080QHF50P26QXH00`27QhL0RHV908V9R@0208Z:RP80SHf=
0P2@T90209>CT`80UYJF0P2JVYX209nOW`80YJFU0P2[Zj/20;6a/@80^[Zj0P32`/820<[:bP80dM7A
00<0e=CD0=OGe`3GemL00P3Kfm/20=oOg`80h^;R0P3Ti>@20>KViP80hn?S0P3MgMd20=OGe`80dM7A
0P3<c<`20<K6aP80`L710P2l_;`20;Ng]`030;:b/P2^[Zh0[Zj^0080ZJVY0P2TY:@20:2PX080Vi^K
0P2GUiL209>CT`80Shn?0P2:RXX208J6QP80PX:20P1nOWh207YjNP80MWIf0P1bLW800`1^KVh0JVYZ
06YZJP0206IVIP80HV9R0P1OGel205]KF`80EeMG0P1CDe<E0?ooo`004`3oool604m?C`d0D51@1P1A
DE46059BDP80EUIF0P1IFET205aLG080H61P0P1RHV8206EUI@80J6QX0P1/K6`00`1_Kfl0LW9b079b
LP0207EeM@80N7Qh0P1iNGT407YjNP@0Ng]k1P1lO7`407emO@@0O7al00<0Ng]k07YjNP1jNWX00P1i
NGT207QhN080MgMg0P1fMWH207EeM@@0M7Ad201cLg<407AdM080MGEe00<0MWIf07MgM`1gMgL00P1h
N7P207UiN@80NWYj0P1lO7`407emO@80OWin0P1oOgl20820P080PH610P22PX8208B4Q080QHF50P26
QXH00`27QhL0RHV908V9R@0208Z:RP80SHf=0P2@T90209>CT`80UYJF0P2JVYX209nOW`80YJFU0P2[
Zj/20;6a/@80^[Zj0P32`/820<[:bP80dM7A00<0e=CD0=OGe`3GemL00P3Kfm/20=oOg`80h^;R0P3T
i>@20>KViP80hn?S0P3MgMd20=OGe`80dM7A0P3<c<`20<K6aP80`L710P2l_;`20;Ng]`030;:b/P2^
[Zh0[Zj^0080ZJVY0P2TY:@20:2PX080Vi^K0P2GUiL209>CT`80Shn?0P2:RXX208J6QP80PX:20P1n
OWh207YjNP80MWIf0P1bLW800`1^KVh0JVYZ06YZJP0206IVIP80HV9R0P1OGel205]KF`80EeMG0P1C
De<E0?ooo`004`3oool204m?C`H0D51@1P1ADE43059BDP@0De=C0P1DE5@405EEE@80EUIF0P1GEeL2
05]KF`80GUiN0P1QHF4206=SH`80IFEU0P1XJ6P206][J`80KVi^00<0LW9b07EeM@1eMGD00P1hN7P2
07YjNP@0Ng]k201lO7`807]kN`@0NWYj00<0NGUi07QhN01hN7P00P1gMgL207IfMP80MGEe0P1dM7@4
07=cL`80LW9b1P1aLG44079bLP@0Lg=c00<0M7Ad07EeM@1eMGD00P1fMWH207MgM`80NGUi0P1jNWX2
07]kN`80O7al0P1nOWh207moO`80P8200P21PH4208:2PP80Ph>30P25QHD208J6QP0308N7Q`29RHT0
RHV90080S8b<0P2>SXh2096AT@80U9BD0P2HV9P209bLW080XZ:R0P2XZ:P20:j^[P80][Jf0P2n_[h2
0<K6aP80clo?0P3EeMD00`3GemL0fm_K0=_Kf`020=oOg`80hn?S0P3WinL20>WYj@80j^[Z0P3Ti>@2
0=gMg@80emOG0P3AdM420<c<c080a/K60P31`L420;bl_080]kNg00<0/[:b0:j^[P2^[Zh00P2YZJT2
0:BTY080X:2P0P2KVi/209NGU`80Ti>C0P2>SXh208Z:RP80QXJ60P22PX8207inOP80NWYj0P1fMWH2
079bLP0306i^KP1ZJVX0JVYZ0080IVIV0P1RHV8205iNGP80Fe]K0P1GEeL205=CDaD0oooo000C0?oo
o`80Cdm?1P1@D506055AD@<0DU9B101CDe<205ADE0@0EEEE0P1FEUH205MGE`80Fe]K0P1NGUh2065Q
H@80Hf=S0P1UIFD206QXJ080Jf][0P1^KVh00`1bLW80MGEe07EeM@0207QhN080NWYj101kNg/807al
O0P0Ng]k101jNWX00`1iNGT0N7Qh07QhN00207MgM`80MWIf0P1eMGD207AdM0@0Lg=c0P1bLW86075a
L@@0LW9b101cLg<00`1dM7@0MGEe07EeM@0207IfMP80MgMg0P1iNGT207YjNP80Ng]k0P1lO7`207in
OP80Ogmo0P20P8020861P@80PX:20P23Ph<208F5Q@80QXJ600<0QhN708V9R@29RHT00P2<S8`208j>
SP80TI6A0P2DU9@209RHV080W9bL0P2RXZ820:RXZ080[Zj^0P2f][H20;jn_P80a/K60P3?cll20=GE
e@030=OGe`3Kfm/0fm_K0080gmoO0P3Shn<20>OWi`80jNWY0P3Zj^X20>CTi080gMgM0P3GemL20=7A
d@80c<c<0P36a/H20<71`@80_;bl0P2g]kL00`2b/[80[Zj^0:j^[P020:VYZ@80Y:BT0P2PX:0209^K
V`80UiNG0P2CTi<208j>SP80RXZ:0P26QXH208:2PP80OWin0P1jNWX207IfMP80LW9b00<0KVi^06YZ
JP1ZJVX00P1VIVH2069RHP80GUiN0P1KFe/205MGE`80De=C5@3oool001<0oooo1P1@D502055AD@@0
DU9B101CDe<00`1DE5@0EEEE05EEE@0205IFEP80EeMG0P1HF5P205UIF@@0Fe]K0P1PH60206=SH`80
I6AT0P1VIVH206QXJ080Jf][0P1^KVh2075aL@0307=cL`1fMWH0MWIf0080NWYj0P1lO7`807emO@@0
O7al101kNg/407YjNP80NGUi0P1hN7P307MgM`80MGEe0P1dM7@207=cL`80LW9b101aLG4<071`L080
LG5a0P1bLW8307=cL`80M7Ad0P1eMGD207MgM`80N7Qh0P1iNGT207YjNP80O7al0P1mOGd207inOP80
Ogmo0P21PH4208>3P`80QHF50P26QXH00`28R8P0Rh^;08^;R`0208f=S@80Shn?0P2BTY8209JFUP80
VYZJ0P2NWYh20:FUY@80Zj^[0P2a/K420;Zj^P80`l?30P3<c<`20=CDe080fMWI00<0g=cL0=kNgP3N
g]h00P3Shn<20>KViP80j>SX0P3[jn/20>[ZjP80hn?S0P3MgMd20=OGe`80dM7A0P3<c<`20<K6aP80
`L710P2l_;`20;Ng]`030;:b/P2][Jd0[Jf]0080ZJVY0P2TY:@20:2PX080Vi^K0P2GUiL209:BTP80
SXj>0P2:RXX208J6QP80PX:20P1nOWh207YjNP80MWIf0P1bLW800`1^KVh0JVYZ06YZJP0206IVIP80
HV9R0P1NGUh205]KF`80EeMG0P1CDe<E0?ooo`004`3oool6051@D080DE5A101BDU8405=CD`0305AD
E01EEED0EEEE0080EUIF0P1GEeL205QHF080FEUI101KFe/2061PH080Hf=S0P1TI6@206IVIP80J6QX
0P1[Jf/206i^KP80LG5a00<0Lg=c07IfMP1fMWH00P1jNWX207alO0P0OGem101lO7`407]kN`@0NWYj
0P1iNGT207QhN0<0MgMg0P1eMGD207AdM080Lg=c0P1bLW84075aL@`0L71`0P1aLG42079bLP<0Lg=c
0P1dM7@207EeM@80MgMg0P1hN7P207UiN@80NWYj0P1lO7`207emO@80OWin0P1oOgl20861P@80Ph>3
0P25QHD208J6QP0308R8R02;Rh/0Rh^;0080SHf=0P2?Shl209:BTP80UYJF0P2JVYX209jNWP80YJFU
0P2[Zj/20;6a/@80^[Zj0P33`l<20<c<c080e=CD0P3IfMT00`3Lg=`0g]kN0=kNgP020>?Sh`80i^KV
0P3Xj>P20>_[j`80j^[Z0P3Shn<20=gMg@80emOG0P3AdM420<c<c080a/K60P31`L420;bl_080]kNg
00<0/[:b0:f][@2][Jd00P2YZJT20:BTY080X:2P0P2KVi/209NGU`80TY:B0P2>SXh208Z:RP80QXJ6
0P22PX8207inOP80NWYj0P1fMWH2079bLP0306i^KP1ZJVX0JVYZ0080IVIV0P1RHV8205iNGP80Fe]K
0P1GEeL205=CDaD0oooo000C0?ooo`@0D51@0P1ADE44059BDP80De=C0P1DE5@205EEE@0305IFEP1G
EeL0EeMG0080F5QH0P1JFUX205]KF`80GEeM0P1OGel206=SH`80IVIV0P1UIFD206MWI`80JFUY0P1[
Jf/206i^KP80LG5a0P1cLg<00`1gMgL0NWYj07YjNP0207alO080OWin101oOgl407inOP80OGem0P1l
O7`207]kN`80NWYj0P1iNGT207QhN080MgMg0P1fMWH00`1eMGD0M7Ad07AdM00207=cL`80LW9b0P1a
LG44071`L080Kfm_2P1^KVh406m_K`<0L71`0P1aLG42079bLP80M7Ad0P1eMGD207IfMP80N7Qh0P1i
NGT207]kN`80O7al0P1mOGd207moO`80PH610P23Ph<208F5Q@80QhN700<0RHV908b<S02<S8`00P2>
SXh2096AT@80U9BD0P2IVIT209fMW@80XZ:R0P2XZ:P20:j^[P80][Jf0P2o_kl20<S8b080d=3@0P3I
fMT20=gMg@030>3Ph03Shn<0hn?S0080inOW0P3Zj^X20>_[j`80k>c/0P3Xj>P20>;RhP80g=cL0P3F
e]H20=7Ad@80bl_;0P36a/H20<71`@80_;bl0P2g]kL00`2b/[80[Jf]0:f][@020:RXZ080Y:BT0P2O
Wil209^KV`80UiNG0P2BTY8208j>SP80RXZ:0P26QXH208:2PP80OWin0P1jNWX207IfMP80LW9b00<0
KVi^06YZJP1ZJVX00P1VIVH2069RHP80GUiN0P1KFe/205MGE`80De=C5@3oool001<0oooo101@D502
055AD@@0DU9B0P1CDe<205ADE080EEEE00<0EUIF05MGE`1GEeL00P1HF5P205YJFP80Fe]K0P1MGEd2
05mOG`80Hf=S0P1VIVH206EUI@80IfMW0P1YJFT206][J`80KVi^0P1aLG4207=cL`0307MgM`1jNWX0
NWYj0080O7al0P1nOWh407moO`@0OWin0P1mOGd207alO080Ng]k0P1jNWX207UiN@80N7Qh0P1gMgL2
07IfMP0307EeM@1dM7@0M7Ad0080Lg=c0P1bLW82075aL@@0L71`0P1_Kfl:06i^KP@0Kfm_0`1`L702
075aL@80LW9b0P1dM7@207EeM@80MWIf0P1hN7P207UiN@80Ng]k0P1lO7`207emO@80Ogmo0P21PH42
08>3P`80QHF50P27QhL00`29RHT0S8b<08b<S00208j>SP80TI6A0P2DU9@209VIV@80WIfM0P2RXZ82
0:RXZ080[Zj^0P2f][H20;no_`80b<S80P3@d=020=WIf@80gMgM00<0h>3P0>?Sh`3Shn<00P3WinL2
0>[ZjP80jn_[0P3/k>`20>SXj080h^;R0P3Lg=`20=KFeP80dM7A0P3;bl/20<K6aP80`L710P2l_;`2
0;Ng]`030;:b/P2][Jd0[Jf]0080Z:RX0P2TY:@209nOW`80Vi^K0P2GUiL209:BTP80SXj>0P2:RXX2
08J6QP80PX:20P1nOWh207YjNP80MWIf0P1bLW800`1^KVh0JVYZ06YZJP0206IVIP80HV9R0P1NGUh2
05]KF`80EeMG0P1CDe<E0?ooo`004`3oool2051@D080DE5A0P1BDU8405=CD`80E5AD0P1EEED205IF
EP0305QHF01IFET0FEUI0080FUYJ0P1LG5`205iNGP80H61P0P1SHf<206IVIP80IfMW0P1YJFT206a/
K080KFe]0P1`L702079bLP80M7Ad0P1fMWH00`1iNGT0O7al07alO00207inOP80Ogmo1020P80207mo
O`80OWin0P1mOGd207]kN`80NWYj0P1iNGT207QhN080MgMg0P1eMGD307AdM080Lg=c0P1bLW82075a
L@80L71`0P1_Kfl206i^KP@0KFe]201/K6`406e]K@<0KVi^0P1_Kfl2075aL@80LW9b0P1cLg<207Ee
M@80MWIf0P1hN7P207YjNP80Ng]k0P1mOGd207inOP80P8200P22PX8208F5Q@80QhN700<0RXZ:08b<
S02<S8`00P2?Shl209>CT`80UiNG0P2KVi/209nOW`80Y:BT0P2[Zj/20;:b/P80^k^k0P34a<@20<c<
c080e=CD0P3MgMd20>7Qh@030>CTi03WinL0inOW0080jn_[0P3]kNd20>k^kP80k>c/0P3WinL20>7Q
h@80g=cL0P3Fe]H20=3@d080bl_;0P36a/H20<30`080^k^k0P2f][H00`2a/K40[Jf]0:f][@020:RX
Z080Xj>S0P2OWil209^KV`80UYJF0P2BTY8208j>SP80RXZ:0P25QHD20861P@80OGem0P1iNGT207Ee
M@80LW9b00<0KVi^06YZJP1ZJVX00P1VIVH2069RHP80GUiN0P1JFUX205MGE`80De=C5@3oool001<0
oooo0P1@D502055AD@80DU9B101CDe<205ADE080EEEE0P1FEUH00`1HF5P0FEUI05UIF@0205YJFP80
G5aL0P1NGUh2061PH080Hf=S0P1VIVH206MWI`80JFUY0P1/K6`206e]K@80L71`0P1bLW8207AdM080
MWIf00<0NGUi07alO01lO7`00P1nOWh207moO`@0P8200P1oOgl207inOP80OGem0P1kNg/207YjNP80
NGUi0P1hN7P207MgM`80MGEe0`1dM7@207=cL`80LW9b0P1aLG42071`L080Kfm_0P1^KVh406e]K@P0
K6a/101]KFd306i^KP80Kfm_0P1aLG42079bLP80Lg=c0P1eMGD207IfMP80N7Qh0P1jNWX207]kN`80
OGem0P1nOWh20820P080PX:20P25QHD208N7Q`0308Z:RP2<S8`0S8b<0080Shn?0P2CTi<209NGU`80
Vi^K0P2OWil20:BTY080Zj^[0P2b/[820;^k^`80a<C40P3<c<`20=CDe080gMgM0P3QhN400`3Ti>@0
inOW0>OWi`020>_[j`80kNg]0P3^k^h20>c/k080inOW0P3QhN420=cLg080e]KF0P3@d=020<_;b`80
a/K60P30`<020;^k^`80][Jf00<0/K6a0:f][@2][Jd00P2XZ:P20:>SX`80WinO0P2KVi/209JFUP80
TY:B0P2>SXh208Z:RP80QHF50P21PH4207emO@80NGUi0P1eMGD2079bLP0306i^KP1ZJVX0JVYZ0080
IVIV0P1RHV8205iNGP80FUYJ0P1GEeL205=CDaD0oooo000C0?ooo`80D51@0P1ADE42059BDP80De=C
0P1DE5@205EEE@80EeMG0P1HF5P00`1IFET0Fe]K05]KF`0205eMG@80GUiN0P1QHF4206=SH`80IVIV
0P1YJFT206a/K080L71`0P1aLG4207=cL`80MGEe0P1fMWH207QhN080NWYj00<0Ng]k07emO@1mOGd0
0P1oOgl20820P0@0PH610P20P80207inOP80OGem0P1kNg/207YjNP80N7Qh0P1gMgL207IfMP80M7Ad
0P1cLg<00`1bLW80LG5a075aL@02071`L080KVi^101]KFd206a/K0@0Jf][201ZJVX406][J`<0K6a/
0P1^KVh206m_K`80L71`0P1aLG4207=cL`80M7Ad0P1fMWH207QhN080NGUi0P1lO7`207inOP80P820
0P22PX8208F5Q@80QhN700<0RXZ:08f=S@2=SHd00P2ATI4209BDU080VIVI0P2NWYh20:>SX`80ZJVY
0P2`/;020;Rh^080`L710P39bLT20=;BdP80fMWI0P3QhN420>GUi@030>SXj03/k>`0k>c/0080kno_
103`l?020>c/k080i^KV0P3Ph>020=_Kf`80eMGE0P3@d=020<[:bP80aLG50P30`<020;^k^`80][Jf
00<0/K6a0:b/[02/[:`00P2XZ:P20:>SX`80WinO0P2JVYX209JFUP80TY:B0P2=SHd208V9R@80QHF5
0P21PH4207emO@80NGUi0P1eMGD2075aL@0306e]K@1ZJVX0JVYZ0080IVIV0P1RHV8205iNGP80FUYJ
0P1GEeL205=CDaD0oooo000C0?ooo`80D51@0P1ADE42059BDP80De=C0P1DE5@205EEE@80EeMG0P1H
F5P00`1IFET0Fe]K05]KF`0205eMG@80GUiN0P1QHF4206=SH`80IVIV0P1YJFT206a/K080L71`0P1a
LG4207=cL`80MGEe0P1fMWH207QhN080NWYj00<0Ng]k07emO@1mOGd00P1oOgl20820P0@0PH610P20
P80207inOP80OGem0P1kNg/207YjNP80N7Qh0P1gMgL207IfMP80M7Ad0P1cLg<00`1bLW80LG5a075a
L@02071`L080KVi^101]KFd206a/K0@0Jf][201ZJVX406][J`<0K6a/0P1^KVh206m_K`80L71`0P1a
LG4207=cL`80M7Ad0P1fMWH207QhN080NGUi0P1lO7`207inOP80P8200P22PX8208F5Q@80QhN700<0
RXZ:08f=S@2=SHd00P2ATI4209BDU080VIVI0P2NWYh20:>SX`80ZJVY0P2`/;020;Rh^080`L710P39
bLT20=;BdP80fMWI0P3QhN420>GUi@030>SXj03/k>`0k>c/0080kno_103`l?020>c/k080i^KV0P3P
h>020=_Kf`80eMGE0P3@d=020<[:bP80aLG50P30`<020;^k^`80][Jf00<0/K6a0:b/[02/[:`00P2X
Z:P20:>SX`80WinO0P2JVYX209JFUP80TY:B0P2=SHd208V9R@80QHF50P21PH4207emO@80NGUi0P1e
MGD2075aL@0306e]K@1ZJVX0JVYZ0080IVIV0P1RHV8205iNGP80FUYJ0P1GEeL205=CDaD0oooo000C
0?ooo`80D51@0P1ADE42059BDP80E5AD0P1EEED205IFEP80F5QH0P1IFET00`1KFe/0G5aL05aLG002
05iNGP80HF5Q0P1SHf<206IVIP80JFUY0P1/K6`2075aL@80Lg=c0P1fMWH207QhN080NGUi0P1kNg/2
07alO080OGem00<0OWin0820P020P8000P21PH4408:2PP80PH610P20P80207inOP80O7al0P1jNWX2
07UiN@80MgMg0P1fMWH207AdM080Lg=c0P1aLG400`1`L700Kfm_06m_K`0206e]K@80K6a/0P1[Jf/4
06YZJP80JFUY301XJ6P406UYJ@0306YZJP1[Jf/0Jf][0080K6a/0P1^KVh206m_K`80LG5a0P1cLg<2
07AdM080MWIf0P1hN7P207]kN`80OGem0P20P80208:2PP80QHF50P28R8P00`2;Rh/0SXj>08j>SP02
09:BTP80UYJF0P2KVi/20:2PX080YZJV0P2][Jd20;Fe]@80_Kfm0P36a/H20<o?c`80emOG0P3Ng]h2
0>CTi080j>SX00<0k>c/0?3`l03`l?00103bl_820?3`l080jn_[0P3UiND20>3Ph080f][J0P3De=@2
0<o?c`80b/[:0P34a<@20;no_`80^[Zj0P2e]KD00`2`/;00[:b/0:b/[0020:NWY`80Xj>S0P2NWYh2
09ZJVP80UIFE0P2ATI4208f=S@80RHV90P25QHD20861P@80OGem0P1iNGT207EeM@80LG5a00<0KFe]
06UYJ@1YJFT00P1VIVH2069RHP80GUiN0P1JFUX205MGE`80De=C5@3oool001<0oooo0P1@D502055A
D@80DU9B0P1DE5@205EEE@80EUIF0P1HF5P205UIF@0305]KF`1LG5`0G5aL0080GUiN0P1QHF4206=S
H`80IVIV0P1YJFT206a/K080LG5a0P1cLg<207IfMP80N7Qh0P1iNGT207]kN`80O7al0P1mOGd00`1n
OWh0P8200820P0020861P@@0PX:20P21PH420820P080OWin0P1lO7`207YjNP80NGUi0P1gMgL207If
MP80M7Ad0P1cLg<2075aL@03071`L01_Kfl0Kfm_0080KFe]0P1/K6`206][J`@0JVYZ0P1YJFT<06QX
J0@0JFUY00<0JVYZ06][J`1[Jf/00P1/K6`206i^KP80Kfm_0P1aLG4207=cL`80M7Ad0P1fMWH207Qh
N080Ng]k0P1mOGd20820P080PX:20P25QHD208R8R00308^;R`2>SXh0SXj>0080TY:B0P2FUYH209^K
V`80X:2P0P2VYZH20:f][@80]KFe0P2m_Kd20<K6aP80clo?0P3GemL20=kNgP80i>CT0P3Xj>P00`3/
k>`0l?3`0?3`l0040?;blP80l?3`0P3[jn/20>GUi@80h>3P0P3Jf]X20=CDe080clo?0P3:b/X20<C4
a080_kno0P2j^[X20;Fe]@030;2`/02/[:`0[:b/0080YjNW0P2SXj<209jNWP80VYZJ0P2EUID2096A
T@80SHf=0P29RHT208F5Q@80PH610P1mOGd207UiN@80MGEe0P1aLG400`1]KFd0JFUY06UYJ@0206IV
IP80HV9R0P1NGUh205YJFP80EeMG0P1CDe<E0?ooo`004`3oool2051@D080DU9B0P1CDe<205ADE080
EUIF0P1GEeL205UIF@80FUYJ00<0G5aL05iNGP1NGUh00P1PH602069RHP80IFEU0P1XJ6P206][J`80
Kfm_0P1cLg<207MgM`80O7al0P1nOWh607moO`80P82000<0PH6108:2PP22PX801P22PX820861P@80
P8200P1nOWh207alO080NWYj0P1hN7P207IfMP80M7Ad0P1cLg<2075aL@80L71`00<0KVi^06e]K@1]
KFd00P1[Jf/206YZJP80JFUY101XJ6P206MWI`h0IVIV0P1WIfL00`1XJ6P0JFUY06UYJ@0206YZJP80
K6a/0P1]KFd206m_K`80LG5a0P1cLg<207EeM@80MgMg0P1jNWX207alO080Ogmo0P22PX8208F5Q@80
R8R800<0Rh^;08n?S`2?Shl00P2CTi<209RHV080WIfM0P2SXj<20:ZZZP80/[:b0P2j^[X20<?3``80
bl_;0P3Cdm<20=_Kf`80h^;R0P3YjNT20>c/k0030>o_k`3bl_80l_;b0080m?Cd0P3clo<20?3`l080
j^[Z0P3Ti>@20=oOg`80fMWI0P3De=@20<k>cP80bLW90P34a<@20;jn_P80^KVi0P2e]KD00`2`/;00
Zj^[0:^[Z`020:JVYP80XZ:R0P2NWYh209VIV@80UIFE0P2ATI4208f=S@80R8R80P24Q8@20820P080
O7al0P1iNGT207EeM@80LG5a00<0KFe]06UYJ@1YJFT00P1UIFD2069RHP80GUiN0P1JFUX205MGE`80
De=C5@3oool001<0oooo0P1@D502059BDP80De=C0P1DE5@205IFEP80EeMG0P1IFET205YJFP0305aL
G01NGUh0GUiN0080H61P0P1RHV8206EUI@80J6QX0P1[Jf/206m_K`80Lg=c0P1gMgL207alO080OWin
1P1oOgl20820P0030861P@22PX80PX:200H0PX:20P21PH420820P080OWin0P1lO7`207YjNP80N7Qh
0P1fMWH207AdM080Lg=c0P1aLG42071`L00306i^KP1]KFd0KFe]0080Jf][0P1ZJVX206UYJ@@0J6QX
0P1WIfL>06IVIP80IfMW00<0J6QX06UYJ@1YJFT00P1ZJVX206a/K080KFe]0P1_Kfl2075aL@80Lg=c
0P1eMGD207MgM`80NWYj0P1lO7`207moO`80PX:20P25QHD208R8R00308^;R`2?Shl0Shn?0080Ti>C
0P2HV9P209fMW@80Xj>S0P2ZZZX20;:b/P80^[Zj0P33`l<20<_;b`80dm?C0P3Kfm/20>;RhP80jNWY
0P3/k>`00`3_knl0l_;b0?;blP020?Cdm080lo?c0P3`l?020>[ZjP80i>CT0P3Ogml20=WIf@80e=CD
0P3>c/h20<W9b@80a<C40P2n_[h20;Vi^@80]KFe00<0/;2`0:^[Z`2[Zj/00P2VYZH20::RXP80WYjN
0P2IVIT209FEU@80TI6A0P2=SHd208R8R080Q8B40P20P80207alO080NGUi0P1eMGD2075aL@0306e]
K@1YJFT0JFUY0080IFEU0P1RHV8205iNGP80FUYJ0P1GEeL205=CDaD0oooo000C0?ooo`80DE5A0P1B
DU8205=CD`80EEEE0P1FEUH205QHF080FUYJ0P1KFe/00`1MGEd0GemO05mOG`02065QH@80I6AT0P1W
IfL206YZJP80KFe]0P1aLG4207IfMP80OGem0P23Ph<408B4Q080Ph>31@22PX8608>3P`80PX:20P20
P80207moO`80OGem0P1kNg/207UiN@80MgMg0P1eMGD207=cL`80LG5a0P1`L70206i^KP0306a/K01[
Jf/0Jf][0080JVYZ0P1YJFT206QXJ080IfMW0P1VIVH206EUI@@0I6AT201SHf<206ATI080IFEU00<0
IVIV06MWI`1WIfL00P1XJ6P206YZJP80Jf][0P1]KFd206m_K`80LG5a0P1cLg<207IfMP80NGUi0P1l
O7`207moO`80PX:20P25QHD208V9R@0308b<S02@T900T92@0080UIFE0P2JVYX20:2PX080YjNW0P2_
[jl20;Ng]`80`<300P38b<P20=7Ad@80f=SH0P3Ph>020>[ZjP80l?3`0P3alO400`3clo<0mOGe0?Ge
m@020?Gem@80m?Cd0P3_knl20>WYj@80hn?S0P3Ng]h20=SHf080dm?C0P3=cLd20<S8b080`l?30P2n
_[h20;Vi^@80];Bd00<0[jn_0:ZZZP2ZZZX00P2VYZH20:6QX@80WIfM0P2IVIT209BDU080T92@0P2<
S8`208R8R080Q8B40P20P80207alO080N7Qh0P1dM7@2071`L00306e]K@1YJFT0JFUY0080IFEU0P1R
HV8205iNGP80FUYJ0P1FEUH205=CDaD0oooo000C0?ooo`80DE5A0P1BDU8205ADE080EEEE0P1GEeL2
05UIF@80FUYJ0P1LG5`00`1NGUh0H61P061PH00206=SH`80IFEU0P1XJ6P206][J`80KVi^0P1bLW82
07MgM`80O7al0P22PX8208J6QP80QHF50P23Ph<208:2PP<0Ph>30P24Q8@408>3P`80PX:20P20P802
07moO`80O7al0P1jNWX207QhN080MWIf0P1dM7@2079bLP80L71`0P1^KVh206e]K@0306][J`1YJFT0
JFUY0080J6QX0P1WIfL206EUI@80I6AT101SHf<2069RHPX0HF5Q0P1RHV8306=SH`80I6AT0P1VIVH2
06QXJ080JVYZ0P1/K6`206i^KP80L71`0P1cLg<207EeM@80N7Qh0P1lO7`207moO`80PX:20P26QXH2
08V9R@0308j>SP2CTi<0Ti>C0080V9RH0P2MWId20:BTY080[:b/0P2d];@20;bl_080aLG50P3=cLd2
0=KFeP80gmoO0P3Xj>P20?7al@@0m?Cd00<0m_Kf0?Shn03hn?P00P3gmoL20?Cdm080k^k^0P3Xj>P2
0>;RhP80gMgM0P3GemL20=;BdP80c<c<0P37alL20<;2`P80_Kfm0P2h^;P20;>c/`030:j^[P2ZZZX0
ZZZZ0080YJFU0P2QXJ4209bLW080V9RH0P2DU9@2092@T080Rh^;0P27QhL208>3P`80P8200P1lO7`2
07QhN080M7Ad0P1`L7000`1/K6`0JFUY06UYJ@0206EUI@80HF5Q0P1NGUh205YJFP80EUIF0P1CDe<E
0?ooo`004`3oool2055AD@80DU9B0P1DE5@205EEE@80EeMG0P1IFET205YJFP80G5aL00<0GUiN061P
H01PH6000P1SHf<206EUI@80J6QX0P1[Jf/206i^KP80LW9b0P1gMgL207alO080PX:20P26QXH208F5
Q@80Ph>30P22PX8308>3P`80Q8B41023Ph<208:2PP80P8200P1oOgl207alO080NWYj0P1hN7P207If
MP80M7Ad0P1bLW82071`L080KVi^0P1]KFd00`1[Jf/0JFUY06UYJ@0206QXJ080IfMW0P1UIFD206AT
I0@0Hf=S0P1RHV8:065QH@80HV9R0`1SHf<206ATI080IVIV0P1XJ6P206YZJP80K6a/0P1^KVh2071`
L080Lg=c0P1eMGD207QhN080O7al0P1oOgl208:2PP80QXJ60P29RHT00`2>SXh0Ti>C09>CT`0209RH
V080WIfM0P2TY:@20:b/[080];Bd0P2l_;`20<G5a@80cLg=0P3Fe]H20=oOg`80j>SX0P3alO440?Cd
m0030?KfmP3hn?P0n?Sh0080moOg0P3dm?@20>k^kP80j>SX0P3Rh^820=gMg@80emOG0P3Bd]820<c<
c080alO70P32`/820;fm_@80^;Rh0P2c/k<00`2^[Zh0ZZZZ0:ZZZP020:FUY@80XJ6Q0P2LW9`209RH
V080U9BD0P2@T90208^;R`80QhN70P23Ph<20820P080O7al0P1hN7P207AdM080L71`00<0K6a/06UY
J@1YJFT00P1UIFD2065QH@80GUiN0P1JFUX205IFEP80De=C5@3oool001<0oooo0P1ADE42059BDP80
E5AD0P1FEUH205MGE`80FEUI0P1KFe/205eMG@0305mOG`1QHF40HF5Q0080I6AT0P1VIVH206UYJ@80
K6a/0P1_Kfl207=cL`80MgMg0P1kNg/207moO`80PX:21023Ph<208:2PP80Ph>31`24Q8@208:2PP80
PH610P1nOWh207alO080NWYj0P1gMgL207EeM@80Lg=c0P1aLG4206m_K`80KFe]0P1[Jf/00`1YJFT0
J6QX06QXJ00206IVIP80IFEU0P1SHf<2069RHP80HF5Q0P1PH60205mOG`P0GUiN101OGel2061PH003
065QH@1RHV80HV9R0080I6AT0P1VIVH206QXJ080JVYZ0P1/K6`206m_K`80LW9b0P1eMGD207QhN080
Ng]k0P1nOWh208:2PP80QXJ60P2;Rh/00`2@T900U9BD09BDU00209ZJVP80XJ6Q0P2YZJT20;6a/@80
^[Zj0P32`/820<_;b`80dm?C0P3Lg=`20>KViP80lO7a103fm_H20?Ogm`030?[jnP3kno/0no_k0080
nOWi0P3dm?@20>g]k@80inOW0P3QhN420=_Kf`80e]KF0P3@d=020<_;b`80a/K60P31`L420;bl_080
]kNg0P2b/[800`2][Jd0ZJVY0:VYZ@020:BTY080X:2P0P2KVi/209NGU`80Ti>C0P2?Shl208^;R`80
QhN70P23Ph<207moO`80Ng]k0P1gMgL207AdM080L71`00<0K6a/06QXJ01XJ6P00P1UIFD2065QH@80
GUiN0P1JFUX205IFEP80De=C5@3oool001<0oooo0P1ADE42059BDP80E5AD0P1FEUH205MGE`80FEUI
0P1KFe/205eMG@0305mOG`1QHF40HF5Q0080I6AT0P1VIVH206UYJ@80K6a/0P1_Kfl207=cL`80MgMg
0P1kNg/207moO`80PX:21023Ph<208:2PP80Ph>31`24Q8@208:2PP80PH610P1nOWh207alO080NWYj
0P1gMgL207EeM@80Lg=c0P1aLG4206m_K`80KFe]0P1[Jf/00`1YJFT0J6QX06QXJ00206IVIP80IFEU
0P1SHf<2069RHP80HF5Q0P1PH60205mOG`P0GUiN101OGel2061PH003065QH@1RHV80HV9R0080I6AT
0P1VIVH206QXJ080JVYZ0P1/K6`206m_K`80LW9b0P1eMGD207QhN080Ng]k0P1nOWh208:2PP80QXJ6
0P2;Rh/00`2@T900U9BD09BDU00209ZJVP80XJ6Q0P2YZJT20;6a/@80^[Zj0P32`/820<_;b`80dm?C
0P3Lg=`20>KViP80lO7a103fm_H20?Ogm`030?[jnP3kno/0no_k0080nOWi0P3dm?@20>g]k@80inOW
0P3QhN420=_Kf`80e]KF0P3@d=020<_;b`80a/K60P31`L420;bl_080]kNg0P2b/[800`2][Jd0ZJVY
0:VYZ@020:BTY080X:2P0P2KVi/209NGU`80Ti>C0P2?Shl208^;R`80QhN70P23Ph<207moO`80Ng]k
0P1gMgL207AdM080L71`00<0K6a/06QXJ01XJ6P00P1UIFD2065QH@80GUiN0P1JFUX205IFEP80De=C
5@3oool001<0oooo0P1ADE4205=CD`80E5AD0P1FEUH205QHF080FUYJ0P1LG5`205iNGP03061PH01R
HV80HV9R0080IFEU0P1WIfL206YZJP80KFe]0P1`L70207=cL`80MgMg0P1jNWX207inOP80P8200P21
PH4208:2PP80Ph>31`25QHD208B4Q080PX:20P20P80207inOP80O7al0P1iNGT207MgM`80M7Ad0P1b
LW82071`L080KVi^0P1/K6`206YZJP0306QXJ01VIVH0IVIV0080I6AT0P1SHf<2065QH@80H61P0P1O
Gel205iNGP80GEeM101LG5`205]KF`@0G5aL0P1MGEd205iNGP0305mOG`1QHF40HF5Q0080Hf=S0P1T
I6@206MWI`80JFUY0P1[Jf/206i^KP80LG5a0P1dM7@207MgM`80Ng]k0P1oOgl208:2PP80QhN70P2<
S8`00`2ATI40UiNG09NGU`0209jNWP80YZJV0P2^[Zh20;Jf]P80_kno0P39bLT20=7Ad@80fMWI0P3S
hn<20>k^kP80m?Cd0P3fm_H20?Win@80no_k00<0oOgm0?clo03lo?`00P3inOT20??cl`80k>c/0P3V
i^H20>3Ph080f][J0P3EeMD20<o?c`80b/[:0P34a<@20;no_`80^[Zj0P2f][H20;6a/@030:b/[02X
Z:P0Z:RX0080Xj>S0P2OWil209^KV`80UYJF0P2BTY8208j>SP80RXZ:0P26QXH208:2PP80OWin0P1k
Ng/207MgM`80Lg=c0P1_Kfl00`1/K6`0J6QX06QXJ00206EUI@80HF5Q0P1MGEd205YJFP80EUIF0P1C
De<E0?ooo`004`3oool2055AD@80De=C0P1DE5@205IFEP80F5QH0P1JFUX205aLG080GUiN00<0H61P
069RHP1RHV800P1UIFD206MWI`80JVYZ0P1]KFd2071`L080Lg=c0P1gMgL207YjNP80OWin0P20P802
0861P@80PX:20P23Ph<708F5Q@80Q8B40P22PX820820P080OWin0P1lO7`207UiN@80MgMg0P1dM7@2
079bLP80L71`0P1^KVh206a/K080JVYZ00<0J6QX06IVIP1VIVH00P1TI6@206=SH`80HF5Q0P1PH602
05mOG`80GUiN0P1MGEd405aLG080Fe]K101LG5`205eMG@80GUiN00<0GemO065QH@1QHF400P1SHf<2
06ATI080IfMW0P1YJFT206][J`80KVi^0P1aLG4207AdM080MgMg0P1kNg/207moO`80PX:20P27QhL2
08b<S003096AT@2GUiL0UiNG0080WYjN0P2VYZH20:j^[P80][Jf0P2o_kl20<W9b@80dM7A0P3IfMT2
0>?Sh`80k^k^0P3dm?@20?KfmP80nOWi0P3kno/00`3moOd0o?cl0?clo0020?Win@80lo?c0P3/k>`2
0>KViP80h>3P0P3Jf]X20=GEe@80clo?0P3:b/X20<C4a080_kno0P2j^[X20;Jf]P80/K6a00<0[:b/
0:RXZ02XZ:P00P2SXj<209nOW`80Vi^K0P2FUYH209:BTP80SXj>0P2:RXX208J6QP80PX:20P1nOWh2
07]kN`80MgMg0P1cLg<206m_K`0306a/K01XJ6P0J6QX0080IFEU0P1QHF4205eMG@80FUYJ0P1FEUH2
05=CDaD0oooo000C0?ooo`80DE5A0P1CDe<205ADE080EUIF0P1HF5P205YJFP80G5aL0P1NGUh00`1P
H600Hf=S06=SH`0206EUI@80J6QX0P1[Jf/206e]K@80LG5a0P1dM7@207MgM`80NWYj0P1mOGd207mo
O`80P8200P22PX8208F5Q@80Q8B400<0QHF508J6QP26QXH00P25QHD208B4Q080PX:20P20P80207em
O@80Ng]k0P1iNGT207IfMP80M7Ad0P1bLW8206m_K`80KFe]0P1[Jf/206QXJ00306IVIP1TI6@0I6AT
0080HV9R0P1QHF4205mOG`80GUiN0P1MGEd205aLG080Fe]K0P1JFUX605UIF@80FUYJ0P1KFe/205aL
G00305eMG@1OGel0GemO0080HF5Q0P1SHf<206EUI@80IfMW0P1YJFT206a/K080L71`0P1cLg<207Mg
M`80Ng]k0P1oOgl208B4Q080RHV90P2>SXh00`2DU9@0Vi^K09^KV`020::RXP80ZZZZ0P2b/[820;^k
^`80a<C40P3<c<`20=KFeP80hN7Q0P3[jn/20?;blP80moOg0P3jn_X20?clo080o_kn00<0oooo0?cl
o03lo?`00P3hn?P20?;blP80jn_[0P3UiND20=kNgP80fMWI0P3Cdm<20<k>cP80b<S80P33`l<20;jn
_P80^KVi0P2d];@20;2`/0030:^[Z`2WYjL0YjNW0080XZ:R0P2NWYh209ZJVP80UIFE0P2ATI4208f=
S@80RHV90P26QXH208:2PP80OWin0P1jNWX207IfMP80Lg=c0P1_Kfl00`1[Jf/0J6QX06QXJ00206AT
I080HF5Q0P1MGEd205YJFP80EUIF0P1CDe<E0?ooo`004`3oool2055AD@80De=C0P1DE5@205IFEP80
F5QH0P1JFUX205aLG080GUiN00<0H61P06=SH`1SHf<00P1UIFD206QXJ080Jf][0P1]KFd2075aL@80
M7Ad0P1gMgL207YjNP80OGem0P1oOgl20820P080PX:20P25QHD208B4Q00308F5Q@26QXH0QXJ60080
QHF50P24Q8@208:2PP80P8200P1mOGd207]kN`80NGUi0P1fMWH207AdM080LW9b0P1_Kfl206e]K@80
Jf][0P1XJ6P00`1VIVH0I6AT06ATI002069RHP80HF5Q0P1OGel205iNGP80GEeM0P1LG5`205]KF`80
FUYJ1P1IFET205YJFP80Fe]K0P1LG5`00`1MGEd0GemO05mOG`02065QH@80Hf=S0P1UIFD206MWI`80
JFUY0P1/K6`2071`L080Lg=c0P1gMgL207]kN`80Ogmo0P24Q8@208V9R@80SXj>00<0U9BD09^KV`2K
Vi/00P2RXZ820:ZZZP80/[:b0P2k^k/20<C4a080c<c<0P3Fe]H20>7Qh@80jn_[0P3bl_820?Ogm`80
n_[j0P3lo?`20?knoP030?ooo`3lo?`0o?cl0080n?Sh0P3bl_820>_[j`80iNGU0P3Ng]h20=WIf@80
dm?C0P3>c/h20<S8b080`l?30P2n_[h20;Vi^@80];Bd0P2`/;000`2[Zj/0YjNW0:NWY`020::RXP80
WYjN0P2JVYX209FEU@80TI6A0P2=SHd208V9R@80QXJ60P22PX8207inOP80NWYj0P1fMWH207=cL`80
Kfm_00<0Jf][06QXJ01XJ6P00P1TI6@2065QH@80GEeM0P1JFUX205IFEP80De=C5@3oool001<0oooo
0P1ADE4205=CD`80EEEE0P1GEeL205QHF080FUYJ0P1MGEd205mOG`03065QH@1SHf<0Hf=S0080IVIV
0P1XJ6P206][J`80KVi^0P1aLG4207AdM080MgMg0P1jNWX207emO@80Ogmo0P21PH4208B4Q080QHF5
0P26QXH00`27QhL0QXJ608J6QP0208F5Q@80Q8B40P22PX820820P080OGem0P1kNg/207QhN080MWIf
0P1cLg<2075aL@80Kfm_0P1/K6`206YZJP80IfMW00<0IFEU06=SH`1SHf<00P1QHF4205mOG`80GUiN
0P1LG5`205]KF`80FUYJ0P1IFET205QHF0@0EeMG101HF5P205UIF@80Fe]K00<0G5aL05eMG@1MGEd0
0P1OGel2065QH@80Hf=S0P1UIFD206QXJ080K6a/0P1_Kfl207=cL`80MgMg0P1kNg/20820P080QHF5
0P2;Rh/2096AT@0309RHV02PX:00X:2P0080YjNW0P2_[jl20;Ng]`80`<300P39bLT20=?Cd`80g=cL
0P3UiND20?3`l080m_Kf0P3inOT20?_kn`80o_kn0`3oool20?gmo@80moOg0P3_knl20>WYj@80hn?S
0P3MgMd20=OGe`80dM7A0P3<c<`20<O7a`80`/;20P2m_Kd20;Rh^080/k>c0P2^[Zh00`2ZZZX0YJFU
0:FUY@020:6QX@80WIfM0P2IVIT209BDU080T92@0P2=SHd208V9R@80QHF50P21PH4207emO@80NGUi
0P1fMWH2079bLP80Kfm_00<0Jf][06MWI`1WIfL00P1TI6@2061PH080GEeM0P1IFET205IFEP80De=C
5@3oool001<0oooo0P1ADE4205=CD`80EEEE0P1GEeL205QHF080FUYJ0P1MGEd205mOG`03065QH@1S
Hf<0Hf=S0080IVIV0P1XJ6P206][J`80KVi^0P1aLG4207AdM080MgMg0P1jNWX207emO@80Ogmo0P21
PH4208B4Q080QHF50P26QXH00`27QhL0QXJ608J6QP0208F5Q@80Q8B40P22PX820820P080OGem0P1k
Ng/207QhN080MWIf0P1cLg<2075aL@80Kfm_0P1/K6`206YZJP80IfMW00<0IFEU06=SH`1SHf<00P1Q
HF4205mOG`80GUiN0P1LG5`205]KF`80FUYJ0P1IFET205QHF0@0EeMG101HF5P205UIF@80Fe]K00<0
G5aL05eMG@1MGEd00P1OGel2065QH@80Hf=S0P1UIFD206QXJ080K6a/0P1_Kfl207=cL`80MgMg0P1k
Ng/20820P080QHF50P2;Rh/2096AT@0309RHV02PX:00X:2P0080YjNW0P2_[jl20;Ng]`80`<300P39
bLT20=?Cd`80g=cL0P3UiND20?3`l080m_Kf0P3inOT20?_kn`80o_kn0`3oool20?gmo@80moOg0P3_
knl20>WYj@80hn?S0P3MgMd20=OGe`80dM7A0P3<c<`20<O7a`80`/;20P2m_Kd20;Rh^080/k>c0P2^
[Zh00`2ZZZX0YJFU0:FUY@020:6QX@80WIfM0P2IVIT209BDU080T92@0P2=SHd208V9R@80QHF50P21
PH4207emO@80NGUi0P1fMWH2079bLP80Kfm_00<0Jf][06MWI`1WIfL00P1TI6@2061PH080GEeM0P1I
FET205IFEP80De=C5@3oool001<0oooo0P1ADE4205=CD`80EEEE0P1GEeL205UIF@80Fe]K0P1MGEd2
05mOG`03065QH@1TI6@0I6AT0080IVIV0P1YJFT206][J`80KVi^0P1aLG4207AdM080MgMg0P1jNWX2
07emO@80P8200P23Ph<408N7Q`80RHV900<0RXZ:08V9R@29RHT00P27QhL208F5Q@80Ph>30P21PH42
07inOP80Ng]k0P1iNGT207IfMP80Lg=c0P1aLG4206i^KP80K6a/0P1YJFT206MWI`0306ATI01RHV80
HV9R0080GemO0P1MGEd205aLG080FUYJ0P1IFET205QHF0@0EeMG0P1FEUH405MGE`@0F5QH0P1IFET0
0`1JFUX0G5aL05aLG00205iNGP80H61P0P1RHV8206EUI@80J6QX0P1/K6`2071`L080M7Ad0P1hN7P2
07emO@80Ph>30P28R8P208j>SP80UIFE00<0W9bL0:BTY02TY:@00P2/[:`20;Bd]080_[jn0P37alL2
0=3@d080fMWI0P3Rh^820>_[j`80l_;b0P3fm_H20?[jnP80oOgm103oool00`3no_h0n_[j0?[jnP02
0?Cdm080kNg]0P3WinL20>7Qh@80fm_K0P3EeMD20<o?c`80b/[:0P35aLD20<30`080^k^k0P2f][H2
0;6a/@80[Jf]00<0Z:RX0:BTY02TY:@00P2PX:0209^KV`80UiNG0P2CTi<208n?S`80S8b<0P28R8P2
08B4Q080P8200P1lO7`207UiN@80MGEe0P1bLW8206i^KP0306][J`1WIfL0IfMW0080I6AT0P1PH602
05eMG@80FEUI0P1FEUH205=CDaD0oooo000C0?ooo`80DE5A0P1CDe<205EEE@80EeMG0P1IFET205]K
F`80GEeM0P1OGel00`1QHF40I6AT06ATI00206IVIP80JFUY0P1[Jf/206i^KP80LG5a0P1dM7@207Mg
M`80NWYj0P1mOGd20820P080Ph>31027QhL208V9R@0308Z:RP29RHT0RHV90080QhN70P25QHD208>3
P`80PH610P1nOWh207]kN`80NGUi0P1fMWH207=cL`80LG5a0P1^KVh206a/K080JFUY0P1WIfL00`1T
I6@0HV9R069RHP0205mOG`80GEeM0P1LG5`205YJFP80FEUI0P1HF5P405MGE`80EUIF101GEeL405QH
F080FEUI00<0FUYJ05aLG01LG5`00P1NGUh2061PH080HV9R0P1UIFD206QXJ080K6a/0P1`L70207Ad
M080N7Qh0P1mOGd208>3P`80R8R80P2>SXh209FEU@0309bLW02TY:@0Y:BT0080[:b/0P2d];@20;jn
_P80alO70P3@d=020=WIf@80h^;R0P3[jn/20?;blP80m_Kf0P3jn_X20?gmo@@0oooo00<0o_kn0?[j
nP3jn_X00P3dm?@20>g]k@80inOW0P3QhN420=_Kf`80eMGE0P3?cll20<[:bP80aLG50P30`<020;^k
^`80][Jf0P2a/K420:f][@030:RXZ02TY:@0Y:BT0080X:2P0P2KVi/209NGU`80Ti>C0P2?Shl208b<
S080R8R80P24Q8@20820P080O7al0P1iNGT207EeM@80LW9b0P1^KVh00`1[Jf/0IfMW06MWI`0206AT
I080H61P0P1MGEd205UIF@80EUIF0P1CDe<E0?ooo`004`3oool2055AD@80De=C0P1EEED205MGE`80
FEUI0P1KFe/205eMG@80GemO00<0HV9R06ATI01TI6@00P1VIVH206UYJ@80K6a/0P1^KVh2075aL@80
M7Ad0P1gMgL207YjNP80OWin0P21PH4208F5Q@80R8R80P2;Rh/208j>SP0308f=S@2<S8`0S8b<0080
RXZ:0P27QhL208B4Q080PH610P1nOWh207alO080NGUi0P1gMgL207AdM080LG5a0P1_Kfl206a/K080
JFUY0P1VIVH00`1SHf<0HF5Q065QH@0205iNGP80GEeM0P1KFe/205YJFP80F5QH1P1GEeL205IFEPH0
EeMG0P1HF5P205UIF@0305]KF`1MGEd0GEeM0080GUiN0P1QHF4206=SH`80IVIV0P1YJFT206e]K@80
LG5a0P1eMGD207YjNP80P8200P25QHD208b<S080Ti>C0P2IVIT00`2PX:00ZJVY0:VYZ@020;6a/@80
^[Zj0P34a<@20<g=c@80e=CD0P3Lg=`20>GUi@80kNg]0P3bl_820?KfmP80no_k0P3moOd20?ooo`80
o_kn00<0o?cl0?Shn03hn?P00P3alO420>_[j`80i>CT0P3Ng]h20=SHf080dm?C0P3=cLd20<S8b080
`l?30P2n_[h20;Vi^@80]KFe0P2`/;020:^[Z`030:NWY`2SXj<0Xj>S0080WinO0P2JVYX209JFUP80
TY:B0P2>SXh208^;R`80QhN70P23Ph<207moO`80O7al0P1hN7P207EeM@80LG5a0P1^KVh00`1ZJVX0
IfMW06MWI`0206=SH`80H61P0P1MGEd205UIF@80EUIF0P1BDU8E0?ooo`004`3oool2055AD@80De=C
0P1EEED205MGE`80FEUI0P1KFe/205eMG@80GemO00<0HV9R06ATI01TI6@00P1VIVH206UYJ@80K6a/
0P1^KVh2075aL@80M7Ad0P1gMgL207YjNP80OWin0P21PH4208F5Q@80R8R80P2;Rh/208j>SP0308f=
S@2<S8`0S8b<0080RXZ:0P27QhL208B4Q080PH610P1nOWh207alO080NGUi0P1gMgL207AdM080LG5a
0P1_Kfl206a/K080JFUY0P1VIVH00`1SHf<0HF5Q065QH@0205iNGP80GEeM0P1KFe/205YJFP80F5QH
1P1GEeL205IFEPH0EeMG0P1HF5P205UIF@0305]KF`1MGEd0GEeM0080GUiN0P1QHF4206=SH`80IVIV
0P1YJFT206e]K@80LG5a0P1eMGD207YjNP80P8200P25QHD208b<S080Ti>C0P2IVIT00`2PX:00ZJVY
0:VYZ@020;6a/@80^[Zj0P34a<@20<g=c@80e=CD0P3Lg=`20>GUi@80kNg]0P3bl_820?KfmP80no_k
0P3moOd20?ooo`80o_kn00<0o?cl0?Shn03hn?P00P3alO420>_[j`80i>CT0P3Ng]h20=SHf080dm?C
0P3=cLd20<S8b080`l?30P2n_[h20;Vi^@80]KFe0P2`/;020:^[Z`030:NWY`2SXj<0Xj>S0080WinO
0P2JVYX209JFUP80TY:B0P2>SXh208^;R`80QhN70P23Ph<207moO`80O7al0P1hN7P207EeM@80LG5a
0P1^KVh00`1ZJVX0IfMW06MWI`0206=SH`80H61P0P1MGEd205UIF@80EUIF0P1BDU8E0?ooo`004`3o
ool2055AD@80De=C0P1EEED205MGE`80FEUI0P1KFe/205eMG@80GemO00<0HV9R06ATI01TI6@00P1V
IVH206UYJ@80K6a/0P1^KVh2075aL@80M7Ad0P1gMgL207YjNP80OWin0P21PH4208F5Q@80Rh^;0P2?
Shl3096AT@80SXj>0P2<S8`208Z:RP80QhN70P23Ph<207moO`80O7al0P1jNWX207QhN080MWIf0P1c
Lg<2071`L080K6a/0P1XJ6P206EUI@0306=SH`1PH600H61P0080GUiN0P1LG5`405]KF`80FUYJ0P1I
FET805QHF080FEUI0P1JFUX205]KF`80G5aL00<0GEeM05mOG`1OGel00P1QHF4206=SH`80IVIV0P1Y
JFT206e]K@80L71`0P1dM7@207UiN@80OWin0P23Ph<208V9R@80T92@0P2GUiL209nOW`030:NWY`2_
[jl0[jn_0080]kNg0P2o_kl20<S8b080d=3@0P3Hf=P20>3Ph080inOW0P3_knl20?Gem@80nOWi0P3l
o?`40?knoP80o?cl00<0nOWi0?Cdm03dm?@00P3^k^h20>SXj080h^;R0P3Lg=`20=KFeP80d=3@0P3;
bl/20<K6aP80`L710P2l_;`20;Ng]`80/k>c0P2^[Zh20:ZZZP030:JVYP2QXJ40XJ6Q0080WIfM0P2I
VIT209FEU@80TI6A0P2=SHd208Z:RP80QXJ60P22PX8207moO`80Ng]k0P1gMgL207AdM080L71`0P1]
KFd00`1ZJVX0IVIV06IVIP0206=SH`80H61P0P1LG5`205UIF@80EUIF0P1BDU8E0?ooo`004`3oool2
055AD@80De=C0P1EEED205MGE`80FEUI0P1KFe/205eMG@80GemO00<0HV9R06ATI01TI6@00P1VIVH2
06UYJ@80K6a/0P1^KVh2075aL@80M7Ad0P1gMgL207YjNP80OWin0P21PH4208F5Q@80Rh^;0P2?Shl3
096AT@80SXj>0P2<S8`208Z:RP80QhN70P23Ph<207moO`80O7al0P1jNWX207QhN080MWIf0P1cLg<2
071`L080K6a/0P1XJ6P206EUI@0306=SH`1PH600H61P0080GUiN0P1LG5`405]KF`80FUYJ0P1IFET8
05QHF080FEUI0P1JFUX205]KF`80G5aL00<0GEeM05mOG`1OGel00P1QHF4206=SH`80IVIV0P1YJFT2
06e]K@80L71`0P1dM7@207UiN@80OWin0P23Ph<208V9R@80T92@0P2GUiL209nOW`030:NWY`2_[jl0
[jn_0080]kNg0P2o_kl20<S8b080d=3@0P3Hf=P20>3Ph080inOW0P3_knl20?Gem@80nOWi0P3lo?`4
0?knoP80o?cl00<0nOWi0?Cdm03dm?@00P3^k^h20>SXj080h^;R0P3Lg=`20=KFeP80d=3@0P3;bl/2
0<K6aP80`L710P2l_;`20;Ng]`80/k>c0P2^[Zh20:ZZZP030:JVYP2QXJ40XJ6Q0080WIfM0P2IVIT2
09FEU@80TI6A0P2=SHd208Z:RP80QXJ60P22PX8207moO`80Ng]k0P1gMgL207AdM080L71`0P1]KFd0
0`1ZJVX0IVIV06IVIP0206=SH`80H61P0P1LG5`205UIF@80EUIF0P1BDU8E0?ooo`004`3oool2055A
D@80De=C0P1EEED205MGE`80FEUI0P1KFe/205eMG@80GemO00<0HV9R06ATI01TI6@00P1WIfL206UY
J@80K6a/0P1^KVh2075aL@80M7Ad0P1gMgL207YjNP80OWin0P21PH4208F5Q@80RXZ:0P2@T90309FE
U@80TY:B0P2>SXh208^;R`80R8R80P25QHD208:2PP80P8200P1mOGd207YjNP80MgMg0P1cLg<2071`
L080K6a/0P1YJFT206IVIP0306=SH`1QHF40HF5Q0080H61P0P1OGel205iNGPH0G5aL1P1KFe/205aL
G080GEeM0P1NGUh205mOG`80H61P00<0HV9R06EUI@1UIFD00P1VIVH206UYJ@80K6a/0P1_Kfl207=c
L`80MWIf0P1jNWX207inOP80Ph>30P29RHT208j>SP80Ti>C0P2JVYX20:>SX`030:ZZZP2c/k<0/k>c
0080^k^k0P34a<@20<c<c080dm?C0P3Kfm/20>GUi@80k>c/0P3alO420?Gem@80nOWi0P3lo?`20?gm
o@@0no_k00<0moOg0?7al@3alO400P3[jn/20>GUi@80gmoO0P3IfMT20=?Cd`80c/k>0P39bLT20<C4
a080_kno0P2j^[X20;Jf]P80/K6a0P2][Jd20:RXZ0030:BTY02PX:00X:2P0080W9bL0P2HV9P209BD
U080T92@0P2<S8`208R8R080QHF50P21PH4207emO@80NWYj0P1gMgL207=cL`80L71`0P1/K6`00`1Y
JFT0IVIV06IVIP0206=SH`80GemO0P1LG5`205UIF@80EUIF0P1BDU8E0?ooo`004`3oool2055AD@80
De=C0P1EEED205MGE`80FEUI0P1KFe/205eMG@80GemO00<0HV9R06ATI01TI6@00P1WIfL206UYJ@80
K6a/0P1^KVh2075aL@80M7Ad0P1gMgL207YjNP80OWin0P21PH4208F5Q@80RXZ:0P2@T90309FEU@80
TY:B0P2>SXh208^;R`80R8R80P25QHD208:2PP80P8200P1mOGd207YjNP80MgMg0P1cLg<2071`L080
K6a/0P1YJFT206IVIP0306=SH`1QHF40HF5Q0080H61P0P1OGel205iNGPH0G5aL1P1KFe/205aLG080
GEeM0P1NGUh205mOG`80H61P00<0HV9R06EUI@1UIFD00P1VIVH206UYJ@80K6a/0P1_Kfl207=cL`80
MWIf0P1jNWX207inOP80Ph>30P29RHT208j>SP80Ti>C0P2JVYX20:>SX`030:ZZZP2c/k<0/k>c0080
^k^k0P34a<@20<c<c080dm?C0P3Kfm/20>GUi@80k>c/0P3alO420?Gem@80nOWi0P3lo?`20?gmo@@0
no_k00<0moOg0?7al@3alO400P3[jn/20>GUi@80gmoO0P3IfMT20=?Cd`80c/k>0P39bLT20<C4a080
_kno0P2j^[X20;Jf]P80/K6a0P2][Jd20:RXZ0030:BTY02PX:00X:2P0080W9bL0P2HV9P209BDU080
T92@0P2<S8`208R8R080QHF50P21PH4207emO@80NWYj0P1gMgL207=cL`80L71`0P1/K6`00`1YJFT0
IVIV06IVIP0206=SH`80GemO0P1LG5`205UIF@80EUIF0P1BDU8E0?ooo`004`3oool2055AD@80De=C
0P1EEED205MGE`80FEUI0P1KFe/205eMG@80GemO00<0HV9R06ATI01TI6@00P1WIfL206UYJ@80K6a/
0P1^KVh2075aL@80M7Ad0P1gMgL207YjNP80OGem0P21PH4208F5Q@80RHV90P2=SHd2096AT@<0TY:B
0P2ATI4208n?S`80Rh^;0P29RHT208N7Q`80PX:20P1oOgl207YjNP80MgMg0P1dM7@2071`L080KFe]
0P1ZJVX206QXJ00306IVIP1TI6@0I6AT0080HV9R0P1QHF42061PH0X0GemO0P1PH602065QH@80HV9R
0P1SHf<206EUI@80IfMW00<0JFUY06][J`1[Jf/00P1^KVh2075aL@80Lg=c0P1fMWH207UiN@80O7al
0P21PH4208F5Q@80RXZ:0P2?Shl209BDU080VYZJ0P2QXJ420:RXZ0030;2`/02h^;P0^;Rh0080`<30
0P38b<P20=3@d080f=SH0P3Ph>020>OWi`80k^k^0P3clo<20?Ogm`@0n_[j0P3inOT20?[jnP80nOWi
00<0lo?c0>g]k@3]kNd00P3WinL20>;RhP80g=cL0P3Fe]H20=7Ad@80c<c<0P37alL20<;2`P80_Kfm
0P2h^;P20;>c/`80[jn_0P2[Zj/20:JVYP030::RXP2NWYh0WYjN0080VYZJ0P2FUYH209:BTP80Shn?
0P2;Rh/208N7Q`80Q8B40P20P80207emO@80NGUi0P1fMWH2079bLP80Kfm_0P1/K6`00`1YJFT0IFEU
06EUI@02069RHP80GemO0P1LG5`205UIF@80EEEE0P1BDU8E0?ooo`004`3oool2055AD@80De=C0P1E
EED205MGE`80FEUI0P1KFe/205eMG@80GemO00<0HV9R06ATI01TI6@00P1WIfL206UYJ@80K6a/0P1^
KVh2075aL@80M7Ad0P1gMgL207YjNP80OGem0P21PH4208F5Q@80RHV90P2=SHd2096AT@<0TY:B0P2A
TI4208n?S`80Rh^;0P29RHT208N7Q`80PX:20P1oOgl207YjNP80MgMg0P1dM7@2071`L080KFe]0P1Z
JVX206QXJ00306IVIP1TI6@0I6AT0080HV9R0P1QHF42061PH0X0GemO0P1PH602065QH@80HV9R0P1S
Hf<206EUI@80IfMW00<0JFUY06][J`1[Jf/00P1^KVh2075aL@80Lg=c0P1fMWH207UiN@80O7al0P21
PH4208F5Q@80RXZ:0P2?Shl209BDU080VYZJ0P2QXJ420:RXZ0030;2`/02h^;P0^;Rh0080`<300P38
b<P20=3@d080f=SH0P3Ph>020>OWi`80k^k^0P3clo<20?Ogm`@0n_[j0P3inOT20?[jnP80nOWi00<0
lo?c0>g]k@3]kNd00P3WinL20>;RhP80g=cL0P3Fe]H20=7Ad@80c<c<0P37alL20<;2`P80_Kfm0P2h
^;P20;>c/`80[jn_0P2[Zj/20:JVYP030::RXP2NWYh0WYjN0080VYZJ0P2FUYH209:BTP80Shn?0P2;
Rh/208N7Q`80Q8B40P20P80207emO@80NGUi0P1fMWH2079bLP80Kfm_0P1/K6`00`1YJFT0IFEU06EU
I@02069RHP80GemO0P1LG5`205UIF@80EEEE0P1BDU8E0?ooo`004`3oool2055AD@80De=C0P1EEED2
05MGE`80FEUI0P1KFe/205eMG@80H61P00<0HV9R06ATI01TI6@00P1WIfL206UYJ@80K6a/0P1^KVh2
075aL@80M7Ad0P1gMgL207YjNP80OGem0P20P80208B4Q080R8R80P2;Rh/208n?S`0309>CT`2DU9@0
U9BD0080TY:B0P2?Shl208b<S080RHV90P26QXH208>3P`80P8200P1mOGd207YjNP80MWIf0P1bLW82
06m_K`80K6a/0P1ZJVX00`1XJ6P0IfMW06MWI`0206IVIP80IFEU0P1TI6@406=SH`@0I6AT0P1UIFD2
06IVIP80IfMW0P1XJ6P206UYJ@80Jf][0P1]KFd00`1_Kfl0LG5a075aL@0207AdM080MgMg0P1jNWX2
07emO@80OWin0P22PX8208F5Q@80RXZ:0P2?Shl209BDU080VYZJ0P2QXJ420:NWY`80[Jf]00<0]KFe
0;fm_@2m_Kd00P34a<@20<c<c080e=CD0P3Lg=`20>CTi080jn_[0P3alO420?Gem@H0m_Kf0P3gmoL2
0?Shn080mOGe00<0kno_0>WYj@3YjNT00P3Ti>@20=kNgP80f=SH0P3Cdm<20<k>cP80bLW90P34a<@2
0;no_`80^[Zj0P2f][H20;6a/@80[Jf]0P2YZJT20:BTY0030:2PX02LW9`0W9bL0080VIVI0P2EUID2
096AT@80SHf=0P2:RXX208J6QP80Ph>30P1oOgl207alO080N7Qh0P1eMGD2079bLP80KVi^0P1[Jf/0
0`1XJ6P0IFEU06EUI@02069RHP80GemO0P1KFe/205QHF080EEEE0P1BDU8E0?ooo`004`3oool2055A
D@80De=C0P1EEED205MGE`80FEUI0P1KFe/205eMG@80H61P00<0HV9R06ATI01TI6@00P1WIfL206UY
J@80K6a/0P1^KVh2075aL@80M7Ad0P1gMgL207YjNP80OGem0P20P80208B4Q080R8R80P2;Rh/208n?
S`0309>CT`2DU9@0U9BD0080TY:B0P2?Shl208b<S080RHV90P26QXH208>3P`80P8200P1mOGd207Yj
NP80MWIf0P1bLW8206m_K`80K6a/0P1ZJVX00`1XJ6P0IfMW06MWI`0206IVIP80IFEU0P1TI6@406=S
H`@0I6AT0P1UIFD206IVIP80IfMW0P1XJ6P206UYJ@80Jf][0P1]KFd00`1_Kfl0LG5a075aL@0207Ad
M080MgMg0P1jNWX207emO@80OWin0P22PX8208F5Q@80RXZ:0P2?Shl209BDU080VYZJ0P2QXJ420:NW
Y`80[Jf]00<0]KFe0;fm_@2m_Kd00P34a<@20<c<c080e=CD0P3Lg=`20>CTi080jn_[0P3alO420?Ge
m@H0m_Kf0P3gmoL20?Shn080mOGe00<0kno_0>WYj@3YjNT00P3Ti>@20=kNgP80f=SH0P3Cdm<20<k>
cP80bLW90P34a<@20;no_`80^[Zj0P2f][H20;6a/@80[Jf]0P2YZJT20:BTY0030:2PX02LW9`0W9bL
0080VIVI0P2EUID2096AT@80SHf=0P2:RXX208J6QP80Ph>30P1oOgl207alO080N7Qh0P1eMGD2079b
LP80KVi^0P1[Jf/00`1XJ6P0IFEU06EUI@02069RHP80GemO0P1KFe/205QHF080EEEE0P1BDU8E0?oo
o`004`3oool2055AD@80De=C0P1EEED205MGE`80FEUI0P1KFe/205eMG@80H61P00<0HV9R06ATI01T
I6@00P1VIVH206UYJ@80Jf][0P1^KVh2075aL@80Lg=c0P1fMWH207UiN@80O7al0P20P80208>3P`80
QXJ60P2:RXX208f=S@03092@T02DU9@0U9BD0080U9BD0P2ATI4208j>SP80S8b<0P28R8P208J6QP80
Ph>30P20P80207alO080NGUi0P1eMGD2075aL@80Kfm_0P1]KFd00`1/K6`0Jf][06][J`0206][J`80
JVYZ1P1YJFT406YZJP80Jf][0P1/K6`206i^KP80L71`0P1aLG42079bLP80M7Ad00<0MWIf07QhN01h
N7P00P1lO7`207inOP80P8200P22PX8208B4Q080RHV90P2<S8`208n?S`80UIFE0P2KVi/20:6QX@80
Z:RX0P2`/;020;Ng]`030;jn_P35aLD0aLG50080c<c<0P3De=@20=_Kf`80h^;R0P3Zj^X20>k^kP80
lO7a0P3bl_820?7al@80l_;b0P3emOD40?Ogm`80lO7a00<0jn_[0>KViP3Vi^H00P3Ph>020=_Kf`80
eMGE0P3@d=020<_;b`80a/K60P31`L420;fm_@80^;Rh0P2c/k<20:n_[`80Zj^[0P2WYjL20:>SX`03
09nOW`2KVi/0Vi^K0080UiNG0P2CTi<208n?S`80S8b<0P28R8P208F5Q@80PH610P1nOWh207]kN`80
MgMg0P1dM7@2075aL@80KVi^0P1[Jf/00`1WIfL0I6AT06ATI002065QH@80GUiN0P1KFe/205QHF080
EEEE0P1BDU8E0?ooo`004`3oool2055AD@80De=C0P1EEED205MGE`80FEUI0P1KFe/205eMG@80H61P
00<0HV9R06ATI01TI6@00P1VIVH206UYJ@80Jf][0P1^KVh2075aL@80Lg=c0P1fMWH207UiN@80O7al
0P20P80208>3P`80QXJ60P2:RXX208f=S@03092@T02DU9@0U9BD0080U9BD0P2ATI4208j>SP80S8b<
0P28R8P208J6QP80Ph>30P20P80207alO080NGUi0P1eMGD2075aL@80Kfm_0P1]KFd00`1/K6`0Jf][
06][J`0206][J`80JVYZ1P1YJFT406YZJP80Jf][0P1/K6`206i^KP80L71`0P1aLG42079bLP80M7Ad
00<0MWIf07QhN01hN7P00P1lO7`207inOP80P8200P22PX8208B4Q080RHV90P2<S8`208n?S`80UIFE
0P2KVi/20:6QX@80Z:RX0P2`/;020;Ng]`030;jn_P35aLD0aLG50080c<c<0P3De=@20=_Kf`80h^;R
0P3Zj^X20>k^kP80lO7a0P3bl_820?7al@80l_;b0P3emOD40?Ogm`80lO7a00<0jn_[0>KViP3Vi^H0
0P3Ph>020=_Kf`80eMGE0P3@d=020<_;b`80a/K60P31`L420;fm_@80^;Rh0P2c/k<20:n_[`80Zj^[
0P2WYjL20:>SX`0309nOW`2KVi/0Vi^K0080UiNG0P2CTi<208n?S`80S8b<0P28R8P208F5Q@80PH61
0P1nOWh207]kN`80MgMg0P1dM7@2075aL@80KVi^0P1[Jf/00`1WIfL0I6AT06ATI002065QH@80GUiN
0P1KFe/205QHF080EEEE0P1BDU8E0?ooo`004`3oool2055AD@80De=C0P1EEED205MGE`80FEUI0P1K
Fe/205eMG@80GemO00<0HV9R06ATI01TI6@00P1VIVH206UYJ@80Jf][0P1]KFd2071`L080Lg=c0P1f
MWH207QhN080Ng]k0P1oOgl208:2PP80QHF50P28R8P208^;R`0308j>SP2@T900T92@00@0TI6A0P2>
SXh208^;R`80R8R80P25QHD208>3P`80PH610P1nOWh207]kN`80N7Qh0P1eMGD207=cL`80LG5a0`1`
L70:06m_K`80L71`101bLW8207EeM@@0MgMg0P1jNWX407emO@0307moO`21PH40PH610080PX:20P25
QHD208N7Q`80RXZ:0P2=SHd2092@T080U9BD0P2JVYX209nOW`80Y:BT0P2ZZZX20;6a/@80]kNg0P2m
_Kd00`34a<@0bl_;0<_;b`020=?Cd`80fm_K0P3QhN420>OWi`80j^[Z0P3/k>`40>o_k`80lO7a0P3e
mOD20?KfmP80moOg0P3clo<20>g]k@030>OWi`3Rh^80h^;R0080g=cL0P3GemL20=;BdP80cLg=0P38
b<P20<?3``80_[jn0P2j^[X20;Fe]@80/K6a0P2][Jd20:VYZ@80Y:BT0P2PX:000`2MWId0VIVI09VI
V@0209FEU@80TI6A0P2>SXh208Z:RP80QhN70P24Q8@20820P080OGem0P1jNWX207IfMP80Lg=c0P1`
L70206e]K@80JVYZ00<0IfMW06ATI01TI6@00P1QHF4205iNGP80Fe]K0P1HF5P205EEE@80DU9B5@3o
ool001<0oooo0P1ADE4205=CD`80EEEE0P1GEeL205UIF@80Fe]K0P1MGEd205mOG`03069RHP1TI6@0
I6AT0080IVIV0P1YJFT206][J`80KFe]0P1`L70207=cL`80MWIf0P1hN7P207]kN`80Ogmo0P22PX82
08F5Q@80R8R80P2;Rh/00`2>SXh0T92@092@T004096AT@80SXj>0P2;Rh/208R8R080QHF50P23Ph<2
0861P@80OWin0P1kNg/207QhN080MGEe0P1cLg<2075aL@<0L71`2P1_Kfl2071`L0@0LW9b0P1eMGD4
07MgM`80NWYj101mOGd00`1oOgl0PH610861P@0208:2PP80QHF50P27QhL208Z:RP80SHf=0P2@T902
09BDU080VYZJ0P2OWil20:BTY080ZZZZ0P2a/K420;Ng]`80_Kfm00<0a<C40<_;b`3;bl/00P3Cdm<2
0=_Kf`80hN7Q0P3WinL20>[ZjP80k>c/103_knl20?7al@80mOGe0P3fm_H20?Ogm`80lo?c0P3]kNd0
0`3WinL0h^;R0>;RhP020=cLg080emOG0P3Bd]820<g=c@80b<S80P33`l<20;jn_P80^[Zj0P2e]KD2
0;6a/@80[Jf]0P2YZJT20:BTY080X:2P00<0WIfM09VIV@2IVIT00P2EUID2096AT@80SXj>0P2:RXX2
08N7Q`80Q8B40P20P80207emO@80NWYj0P1fMWH207=cL`80L71`0P1]KFd206YZJP0306MWI`1TI6@0
I6AT0080HF5Q0P1NGUh205]KF`80F5QH0P1EEED2059BDQD0oooo000C0?ooo`80DE5A0P1CDe<205EE
E@80EeMG0P1IFET205]KF`80GEeM0P1OGel00`1QHF40I6AT06ATI00206IVIP80J6QX0P1[Jf/206e]
K@80L71`0P1bLW8207EeM@80N7Qh0P1kNg/207inOP80PH610P24Q8@208N7Q`80RXZ:00<0S8b<08n?
S`2?Shl00P2BTY84096AT@80T92@0P2=SHd208V9R@80QXJ60P23Ph<20861P@80OWin0P1lO7`207Ui
N@80MgMg0`1fMWH807EeM@@0MWIf0P1hN7P207UiN@80Ng]k0P1lO7`207emO@80P8200P22PX8208B4
Q080QXJ600<0R8R808Z:RP2:RXX00P2<S8`208n?S`80TI6A0P2DU9@209RHV080Vi^K0P2PX:020:>S
X`80YjNW0P2/[:`20;>c/`80^KVi0P2o_kl20<G5a@030<g=c@3De=@0e=CD0080fMWI0P3Ng]h20>;R
hP80i^KV103YjNT20>[ZjP80k^k^0P3clo<20?KfmP80n?Sh0P3fm_H20>o_k`80jNWY00<0hn?S0=kN
gP3Ng]h00P3IfMT20=CDe080c/k>0P3:b/X20<G5a@80`<300P2l_;`20;Ng]`80/k>c0P2^[Zh20:ZZ
ZP80YZJV0P2RXZ8209jNWP0309ZJVP2GUiL0UiNG0080Ti>C0P2@T90208b<S080RHV90P25QHD208:2
PP80Ogmo0P1lO7`207QhN080MGEe0P1bLW8206m_K`80K6a/0P1YJFT00`1VIVH0Hf=S06=SH`02061P
H080GEeM0P1KFe/205QHF080EEEE0P1BDU8E0?ooo`004`3oool2055AD@80De=C0P1EEED205MGE`80
FEUI0P1KFe/205eMG@80GemO00<0HF5Q06ATI01TI6@00P1VIVH206QXJ080Jf][0P1]KFd2071`L080
LW9b0P1eMGD207QhN080Ng]k0P1nOWh20861P@80Q8B40P27QhL208Z:RP0308b<S02?Shl0Shn?0080
TY:B102ATI42092@T080SHf=0P29RHT208J6QP80Ph>30P21PH4207inOP80O7al0P1iNGT207MgM`<0
MWIf201eMGD407IfMP80N7Qh0P1iNGT207]kN`80O7al0P1mOGd20820P080PX:20P24Q8@208J6QP03
08R8R02:RXX0RXZ:0080S8b<0P2?Shl2096AT@80U9BD0P2HV9P209^KV`80X:2P0P2SXj<20:NWY`80
[:b/0P2c/k<20;Vi^@80_kno0P35aLD00`3=cLd0e=CD0=CDe0020=WIf@80g]kN0P3Rh^820>KViP@0
jNWY0P3Zj^X20>k^kP80lo?c0P3fm_H20?Shn080m_Kf0P3_knl20>WYj@030>?Sh`3Ng]h0g]kN0080
fMWI0P3De=@20<k>cP80b/[:0P35aLD20<30`080_;bl0P2g]kL20;>c/`80[Zj^0P2ZZZX20:JVYP80
XZ:R0P2NWYh00`2JVYX0UiNG09NGU`0209>CT`80T92@0P2<S8`208V9R@80QHF50P22PX8207moO`80
O7al0P1hN7P207EeM@80LW9b0P1_Kfl206a/K080JFUY00<0IVIV06=SH`1SHf<00P1PH60205eMG@80
Fe]K0P1HF5P205EEE@80DU9B5@3oool001<0oooo0P1ADE4205=CD`80EEEE0P1GEeL205UIF@80Fe]K
0P1MGEd205mOG`03065QH@1SHf<0Hf=S0080IFEU0P1XJ6P206YZJP80K6a/0P1_Kfl2075aL@80M7Ad
0P1gMgL207YjNP80O7al0P1oOgl208:2PP80QHF50P28R8P00`2;Rh/0SXj>08j>SP02092@T080U9BD
0P2EUID2092@T080SXj>0P2<S8`208Z:RP80QXJ60P24Q8@208:2PP80P8200P1nOWh207emO@<0O7al
101kNg/407alO0@0OGem0P1oOgl20820P080PX:20P24Q8@208R8R080RXZ:0P2<S8`208f=S@80Shn?
00<0Ti>C09BDU02DU9@00P2GUiL209ZJVP80W9bL0P2OWil20::RXP80YZJV0P2YZJT20:f][@80/[:b
0P2g]kL20;^k^`80`L710P38b<P20<k>cP030=CDe03IfMT0fMWI0080gMgM0P3QhN420>GUi@@0inOW
0P3YjNT20>c/k080l?3`0P3clo<20?KfmP80moOg0P3alO420>_[j`80iNGU00<0gmoO0=[JfP3Jf]X0
0P3EeMD20=3@d080bl_;0P36a/H20<71`@80_Kfm0P2h^;P20;Bd]080/;2`0P2/[:`20:NWY`80Xj>S
0P2PX:0209bLW00309RHV02EUID0UIFE0080TI6A0P2>SXh208Z:RP80QhN70P24Q8@20861P@80OGem
0P1jNWX207MgM`80M7Ad0P1aLG4206i^KP80Jf][0P1XJ6P00`1VIVH0Hf=S06=SH`02061PH080GEeM
0P1JFUX205MGE`80EEEE0P1BDU8E0?ooo`004`3oool2055AD@80De=C0P1EEED205MGE`80FEUI0P1K
Fe/205eMG@80GemO00<0HF5Q06=SH`1SHf<00P1UIFD206QXJ080JVYZ0P1/K6`206m_K`80LG5a0P1d
M7@207MgM`80NWYj0P1lO7`207moO`80PX:20P25QHD208R8R00308^;R`2>SXh0SXj>0080T92@0P2D
U9@209FEU@80T92@0P2>SXh208b<S080RXZ:0P26QXH208B4Q080PX:20P20P80207inOP80OGem0`1l
O7`407]kN`@0O7al101mOGd207moO`80P8200P22PX8208B4Q080R8R80P2:RXX208b<S080SHf=0P2?
Shl00`2CTi<0U9BD09BDU00209NGU`80VYZJ0P2LW9`209nOW`80XZ:R0P2VYZH20:VYZ@80[Jf]0P2b
/[820;Ng]`80^k^k0P31`L420<S8b080c/k>00<0e=CD0=WIf@3IfMT00P3MgMd20>7Qh@80iNGU103W
inL20>WYj@80k>c/0P3`l?020??cl`80m_Kf0P3gmoL20?7al@80jn_[0P3UiND00`3Ogml0f][J0=[J
fP020=GEe@80d=3@0P3;bl/20<K6aP80`L710P2m_Kd20;Rh^080];Bd0P2`/;020:b/[080YjNW0P2S
Xj<20:2PX080W9bL00<0V9RH09FEU@2EUID00P2ATI4208j>SP80RXZ:0P27QhL208B4Q080PH610P1m
OGd207YjNP80MgMg0P1dM7@2075aL@80KVi^0P1[Jf/206QXJ00306IVIP1SHf<0Hf=S0080H61P0P1M
GEd205YJFP80EeMG0P1EEED2059BDQD0oooo000C0?ooo`80DE5A0P1CDe<205EEE@80EeMG0P1IFET2
05]KF`80GEeM0P1OGel00`1QHF40Hf=S06=SH`0206EUI@80IfMW0P1YJFT206a/K080KVi^0P1aLG42
07=cL`80MWIf0P1iNGT207]kN`80OWin0P21PH4208B4Q080QhN700<0RHV908b<S02<S8`00P2?Shl2
09:BTP@0UYJF0P2ATI4208f=S@80Rh^;0P29RHT208R8R080QXJ60P25QHD208>3P`80PX:21`23Ph<6
08B4Q080QXJ60P27QhL208V9R@80S8b<0P2>SXh2096AT@80Ti>C0P2FUYH209VIV@80Vi^K00<0W9bL
09nOW`2OWil00P2SXj<20:FUY@80YjNW0P2ZZZX20:j^[P80/[:b0P2e]KD20;Vi^@80_Kfm0P31`L42
0<K6aP80bl_;0P3@d=020=GEe@030=[JfP3MgMd0gMgM0080gmoO0P3QhN440>;RhP80iNGU0P3Zj^X2
0>o_k`80l_;b0P3emOD20?KfmP80lO7a0P3/k>`20>KViP80hN7Q00<0fm_K0=KFeP3Fe]H00P3AdM42
0<c<c080alO70P33`l<20;jn_P80^KVi0P2e]KD20;6a/@80[Jf]0P2YZJT20:FUY@80XJ6Q0P2MWId2
09ZJVP0309JFUP2CTi<0Ti>C0080Shn?0P2<S8`208V9R@80QHF50P22PX8207moO`80O7al0P1iNGT2
07IfMP80Lg=c0P1`L70206e]K@80JVYZ0P1XJ6P00`1UIFD0HV9R069RHP0205mOG`80GEeM0P1JFUX2
05MGE`80EEEE0P1BDU8E0?ooo`004`3oool2055AD@80De=C0P1EEED205MGE`80F5QH0P1JFUX205aL
G080GUiN00<0H61P069RHP1RHV800P1TI6@206MWI`80JFUY0P1[Jf/206e]K@80L71`0P1bLW8207Ee
M@80MgMg0P1jNWX207emO@80P8200P22PX8208F5Q@0308R8R02;Rh/0Rh^;0080SXj>0P2ATI4209BD
U0@0UYJF0P2CTi<208n?S`80SHf=0P2;Rh/;08V9R@80RXZ:0P29RHT208Z:RP80Rh^;0P2<S8`208f=
S@80T92@0P2BTY8209BDU080UiNG0P2JVYX209bLW080X:2P0P2SXj<20:NWY`030:ZZZP2[Zj/0Zj^[
0080[:b/0P2_[jl20;:b/P80][Jf0P2j^[X20;fm_@80`/;20P36a/H20<[:bP80c/k>0P3Bd]820=KF
eP80f=SH0P3Jf]X00`3Lg=`0gmoO0=oOg`040>3Ph080hN7Q0P3Ti>@20>WYj@80kNg]0P3alO420?Ge
m@80moOg0P3dm?@20>g]k@80inOW0P3QhN420=cLg0030=OGe`3Bd]80d];B0080cLg=0P38b<P20<?3
``80_kno0P2j^[X20;Jf]P80/[:b0P2^[Zh20:ZZZP80YZJV0P2RXZ8209jNWP80Vi^K0P2GUiL00`2D
U9@0TI6A096AT@0208f=S@80RXZ:0P27QhL208B4Q080PH610P1nOWh207]kN`80MgMg0P1dM7@2079b
LP80Kfm_0P1/K6`206YZJP80IfMW00<0I6AT065QH@1QHF400P1OGel205aLG080FUYJ0P1GEeL205AD
E080DU9B5@3oool001<0oooo0P1ADE4205=CD`80EEEE0P1GEeL205QHF080FUYJ0P1LG5`205iNGP03
061PH01RHV80HV9R0080I6AT0P1WIfL206UYJ@80Jf][0P1]KFd2071`L080LW9b0P1eMGD207MgM`80
NWYj0P1mOGd20820P080PX:20P25QHD00`28R8P0Rh^;08^;R`0208j>SP80TI6A0P2DU9@409JFUP80
Ti>C0P2?Shl208f=S@80Rh^;2`29RHT208Z:RP80RHV90P2:RXX208^;R`80S8b<0P2=SHd2092@T080
TY:B0P2DU9@209NGU`80VYZJ0P2LW9`20:2PX080Xj>S0P2WYjL00`2ZZZX0Zj^[0:^[Z`020:b/[080
[jn_0P2b/[820;Jf]P80^[Zj0P2m_Kd20<;2`P80a/K60P3:b/X20<k>cP80d];B0P3Fe]H20=SHf080
f][J00<0g=cL0=oOg`3Ogml0103Ph>020>7Qh@80i>CT0P3YjNT20>g]k@80lO7a0P3emOD20?Ogm`80
m?Cd0P3]kNd20>OWi`80hN7Q0P3Lg=`00`3GemL0d];B0=;BdP020<g=c@80b<S80P33`l<20;no_`80
^[Zj0P2f][H20;:b/P80[Zj^0P2ZZZX20:JVYP80XZ:R0P2NWYh209^KV`80UiNG00<0U9BD096AT@2A
TI400P2=SHd208Z:RP80QhN70P24Q8@20861P@80OWin0P1kNg/207MgM`80M7Ad0P1bLW8206m_K`80
K6a/0P1ZJVX206MWI`0306ATI01QHF40HF5Q0080GemO0P1LG5`205YJFP80EeMG0P1DE5@2059BDQD0
oooo000C0?ooo`80DE5A0P1CDe<205EEE@80EUIF0P1HF5P205YJFP80G5aL0P1NGUh00`1PH600HV9R
069RHP0206ATI080IVIV0P1XJ6P206YZJP80KFe]0P1_Kfl2075aL@80M7Ad0P1fMWH207UiN@80O7al
0P1nOWh20861P@80Q8B400<0QhN708V9R@29RHT00P2<S8`208n?S`80TY:B0P2FUYH409VIV@80UYJF
0P2BTY8208n?S`@0SHf=0P2?Shl5092@T080TI6A0P2BTY8209>CT`80U9BD0P2EUID209NGU`80V9RH
0P2KVi/209jNWP80X:2P0P2RXZ820:JVYP80ZZZZ0P2][Jd20;6a/@030;Bd]02g]kL0]kNg0080^KVi
0P2k^k/20;fm_@80`L710P34a<@20<O7a`80b/[:0P3>c/h20=;BdP80eMGE0P3Hf=P20=WIf@80f][J
1@3Lg=`20=gMg@80h>3P0P3Shn<20>WYj@80k^k^0P3alO420??cl`80m_Kf0P3emOD20>k^kP80j>SX
0P3Rh^820=cLg080emOG00<0d];B0<g=c@3=cLd00P38b<P20<?3``80_kno0P2k^k/20;Ng]`80/[:b
0P2^[Zh20:ZZZP80YZJV0P2SXj<209nOW`80W9bL0P2HV9P209FEU@03096AT@2>SXh0SXj>0080Rh^;
0P28R8P208F5Q@80PX:20P1oOgl207alO080NGUi0P1fMWH207=cL`80LG5a0P1^KVh206][J`80JFUY
0P1VIVH00`1SHf<0HF5Q065QH@0205iNGP80G5aL0P1IFET205MGE`80E5AD0P1BDU8E0?ooo`004`3o
ool2055AD@80De=C0P1EEED205IFEP80F5QH0P1JFUX205aLG080GUiN00<0H61P069RHP1RHV800P1T
I6@206IVIP80J6QX0P1ZJVX206e]K@80Kfm_0P1aLG4207AdM080MWIf0P1iNGT207alO080OWin0P21
PH4208B4Q00308N7Q`29RHT0RHV90080S8b<0P2?Shl209:BTP80UYJF102IVIT209JFUP80TY:B0P2?
Shl408f=S@80Shn?1@2@T902096AT@80TY:B0P2CTi<209BDU080UIFE0P2GUiL209RHV080Vi^K0P2N
WYh20:2PX080XZ:R0P2VYZH20:ZZZP80[Jf]0P2a/K400`2d];@0]kNg0;Ng]`020;Vi^@80^k^k0P2m
_Kd20<71`@80a<C40P37alL20<[:bP80c/k>0P3Bd]820=GEe@80f=SH0P3IfMT20=[JfPD0g=cL0P3M
gMd20>3Ph080hn?S0P3YjNT20>k^kP80lO7a0P3clo<20?KfmP80mOGe0P3^k^h20>SXj080h^;R0P3L
g=`20=OGe`030=;BdP3=cLd0cLg=0080b<S80P33`l<20;no_`80^k^k0P2g]kL20;:b/P80[Zj^0P2Z
ZZX20:JVYP80Xj>S0P2OWil209bLW080V9RH0P2EUID00`2ATI40SXj>08j>SP0208^;R`80R8R80P25
QHD208:2PP80Ogmo0P1lO7`207UiN@80MWIf0P1cLg<2075aL@80KVi^0P1[Jf/206UYJ@80IVIV00<0
Hf=S065QH@1QHF400P1NGUh205aLG080FEUI0P1GEeL205ADE080DU9B5@3oool001<0oooo0P1ADE42
05=CD`80E5AD0P1FEUH205QHF080FUYJ0P1LG5`205iNGP0305mOG`1QHF40HF5Q0080Hf=S0P1UIFD2
06MWI`80JVYZ0P1/K6`206i^KP80L71`0P1cLg<207EeM@80N7Qh0P1jNWX207emO@80Ogmo0P22PX80
0`25QHD0R8R808R8R00208^;R`80SXj>0P2ATI4209FEU@80VIVI102KVi/209VIV@80UiNG0P2FUYH4
09FEU@80UiNG1@2IVIT209^KV`80W9bL0P2OWil20:2PX080XZ:R0P2SXj<20:FUY@80YjNW0P2ZZZX2
0:b/[080/;2`0P2c/k<20;Jf]P80^KVi00<0_Kfm0<71`@31`L401033`l<20<K6aP80bLW90P3;bl/2
0<k>cP80dM7A0P3De=@20=KFeP80f=SH203IfMT00`3Jf]X0fm_K0=_Kf`020=gMg@80h^;R0P3Xj>P2
0>k^kP80l?3`0P3clo<20?Ogm`80m?Cd0P3]kNd20>OWi`80hN7Q0P3Lg=`20=OGe`80d];B00<0cLg=
0<S8b038b<P00P33`l<20;no_`80^k^k0P2g]kL20;:b/P80[jn_0P2[Zj/20:NWY`80Xj>S0P2PX:02
09bLW080VIVI0P2EUID209:BTP0308n?S`2<S8`0S8b<0080RHV90P26QXH208>3P`80P8200P1mOGd2
07YjNP80MgMg0P1eMGD2079bLP80Kfm_0P1]KFd206YZJP80J6QX0P1UIFD00`1SHf<0H61P061PH002
05iNGP80Fe]K0P1IFET205IFEP80E5AD0P1BDU8E0?ooo`004`3oool2055AD@80De=C0P1DE5@205IF
EP80F5QH0P1JFUX205aLG080GUiN00<0GemO065QH@1QHF400P1SHf<206EUI@80IfMW0P1ZJVX206a/
K080KVi^0P1`L70207=cL`80MGEe0P1hN7P207YjNP80OGem0P1oOgl208:2PP0308F5Q@28R8P0R8R8
0080Rh^;0P2>SXh2096AT@80UIFE0P2IVIT409^KV`80VIVI0P2GUiL209JFUP@0UIFE0P2GUiL509VI
V@80Vi^K0P2LW9`209nOW`80X:2P0P2RXZ820:>SX`80YJFU0P2WYjL20:ZZZP80[:b/0P2`/;020;>c
/`80][Jf0P2i^KT00`2m_Kd0`L710<71`@040<?3``80a/K60P39bLT20<_;b`80c/k>0P3AdM420=CD
e080e]KF0P3Hf=P80=WIf@030=[JfP3Kfm/0fm_K0080gMgM0P3Rh^820>SXj080k^k^0P3`l?020??c
l`80moOg0P3dm?@20>g]k@80inOW0P3QhN420=cLg080emOG0P3Bd]800`3=cLd0b<S80<S8b0020<?3
``80_kno0P2k^k/20;Ng]`80/[:b0P2_[jl20:^[Z`80YjNW0P2SXj<20:2PX080W9bL0P2IVIT209FE
U@80TY:B00<0Shn?08b<S02<S8`00P29RHT208J6QP80Ph>30P20P80207emO@80NWYj0P1gMgL207Ee
M@80LW9b0P1_Kfl206e]K@80JVYZ0P1XJ6P206EUI@0306=SH`1PH600H61P0080GUiN0P1KFe/205UI
F@80EUIF0P1DE5@2059BDQD0oooo000C0?ooo`80DE5A0P1CDe<205ADE080EUIF0P1HF5P205UIF@80
Fe]K0P1MGEd00`1OGel0HF5Q065QH@0206=SH`80IFEU0P1WIfL206UYJ@80Jf][0P1]KFd206m_K`80
LW9b0P1dM7@207IfMP80NGUi0P1kNg/207inOP80P82000<0Ph>308J6QP26QXH00P29RHT208b<S080
Shn?0P2CTi<209NGU`80Vi^K0P2OWil209jNWP80WIfM0P2LW9`409^KV`80W9bL0P2OWil00`2QXJ40
XZ:R0::RXP020::RXP80YJFU0P2WYjL20:ZZZP80[Jf]0P2^[Zh20:n_[`80/;2`0P2c/k<20;Fe]@80
^KVi0P2k^k/20;jn_P80`L7100<0a<C40<O7a`37alL00P3:b/X20<c<c080clo?103AdM420=?Cd`80
e=CD103Fe]H20=OGe`@0e]KF0P3Hf=P20=_Kf`030=gMg@3Ph>00h>3P0080i^KV0P3[jn/20>o_k`80
l?3`0P3clo<20?KfmP80lo?c0P3]kNd20>OWi`80hN7Q0P3Kfm/20=KFeP80dM7A0P3<c<`00`37alL0
`l?30<?3``020;jn_P80^[Zj0P2f][H20;>c/`80[jn_0P2[Zj/20:NWY`80Xj>S0P2PX:0209bLW080
VIVI0P2FUYH209>CT`80T92@00<0S8b<08V9R@29RHT00P26QXH208B4Q080PH610P1nOWh207]kN`80
NGUi0P1fMWH207=cL`80LG5a0P1^KVh206a/K080JFUY0P1WIfL206ATI003069RHP1PH600H61P0080
GEeM0P1KFe/205QHF080EUIF0P1DE5@2055ADAD0oooo000C0?ooo`80DE5A0P1CDe<205ADE080EUIF
0P1HF5P205UIF@80Fe]K0P1MGEd00`1OGel0HF5Q065QH@0206=SH`80IFEU0P1WIfL206UYJ@80Jf][
0P1]KFd206m_K`80LW9b0P1dM7@207IfMP80NGUi0P1kNg/207inOP80P82000<0Ph>308J6QP26QXH0
0P29RHT208b<S080Shn?0P2CTi<209NGU`80Vi^K0P2OWil209jNWP80WIfM0P2LW9`409^KV`80W9bL
0P2OWil00`2QXJ40XZ:R0::RXP020::RXP80YJFU0P2WYjL20:ZZZP80[Jf]0P2^[Zh20:n_[`80/;2`
0P2c/k<20;Fe]@80^KVi0P2k^k/20;jn_P80`L7100<0a<C40<O7a`37alL00P3:b/X20<c<c080clo?
103AdM420=?Cd`80e=CD103Fe]H20=OGe`@0e]KF0P3Hf=P20=_Kf`030=gMg@3Ph>00h>3P0080i^KV
0P3[jn/20>o_k`80l?3`0P3clo<20?KfmP80lo?c0P3]kNd20>OWi`80hN7Q0P3Kfm/20=KFeP80dM7A
0P3<c<`00`37alL0`l?30<?3``020;jn_P80^[Zj0P2f][H20;>c/`80[jn_0P2[Zj/20:NWY`80Xj>S
0P2PX:0209bLW080VIVI0P2FUYH209>CT`80T92@00<0S8b<08V9R@29RHT00P26QXH208B4Q080PH61
0P1nOWh207]kN`80NGUi0P1fMWH207=cL`80LG5a0P1^KVh206a/K080JFUY0P1WIfL206ATI003069R
HP1PH600H61P0080GEeM0P1KFe/205QHF080EUIF0P1DE5@2055ADAD0oooo000C0?ooo`80DE5A0P1B
DU8205ADE080EUIF0P1GEeL205UIF@80Fe]K0P1MGEd00`1NGUh0H61P061PH002069RHP80I6AT0P1V
IVH206QXJ080JVYZ0P1/K6`206i^KP80L71`0P1cLg<207EeM@80MgMg0P1jNWX207alO080Ogmo00<0
PH6108B4Q024Q8@00P27QhL208Z:RP80SXj>0P2ATI4209FEU@80VIVI0P2NWYh40:>SX`80X:2P102N
WYh20:6QX@80Xj>S00<0YZJV0:VYZ@2YZJT00P2[Zj/20:f][@80/;2`0P2c/k<20;Jf]P80^KVi0P2k
^k/20;bl_080_[jn0P30`<020<;2`P80a<C41035aLD30<K6aP80bLW90P3;bl/20<k>cP80clo?203@
d=020=7Ad@80dm?C0P3EeMD20=WIf@80g=cL0P3Ogml00`3Shn<0inOW0>OWi`020>c/k080kno_0P3a
lO420?;blP80mOGe0P3clo<20>_[j`80iNGU0P3Ph>020=[JfP80eMGE0P3@d=020<_;b`80alO700<0
`/;20;jn_P2n_[h00P2j^[X20;Jf]P80/[:b0P2^[Zh20:ZZZP80YZJV0P2SXj<20:2PX080W9bL0P2I
VIT209JFUP80Ti>C0P2@T90208f=S@0308Z:RP27QhL0QhN70080Q8B40P21PH4207moO`80O7al0P1i
NGT207MgM`80M7Ad0P1bLW8206m_K`80KFe]0P1ZJVX206QXJ080IVIV0P1SHf<00`1QHF40GemO05mO
G`0205eMG@80FUYJ0P1HF5P205IFEP80E5AD0P1ADE4E0?ooo`004`3oool2055AD@80DU9B0P1DE5@2
05IFEP80EeMG0P1IFET205]KF`80GEeM00<0GUiN061PH01PH6000P1RHV8206ATI080IVIV0P1XJ6P2
06YZJP80K6a/0P1^KVh2071`L080Lg=c0P1eMGD207MgM`80NWYj0P1lO7`207moO`030861P@24Q8@0
Q8B40080QhN70P2:RXX208j>SP80TI6A0P2EUID209VIV@80WYjN102SXj<20:2PX0@0WYjN0P2QXJ42
0:>SX`030:JVYP2YZJT0ZJVY0080Zj^[0P2][Jd20;2`/080/k>c0P2f][H20;Vi^@80^k^k0P2l_;`2
0;jn_P80`<300P32`/820<C4a0@0aLG50`36a/H20<W9b@80bl_;0P3>c/h20<o?c`P0d=3@0P3AdM42
0=?Cd`80eMGE0P3IfMT20=cLg080gmoO00<0hn?S0>OWi`3WinL00P3/k>`20>o_k`80lO7a0P3bl_82
0?Gem@80lo?c0P3[jn/20>GUi@80h>3P0P3Jf]X20=GEe@80d=3@0P3;bl/20<O7a`030<;2`P2n_[h0
_[jn0080^[Zj0P2f][H20;:b/P80[Zj^0P2ZZZX20:JVYP80Xj>S0P2PX:0209bLW080VIVI0P2FUYH2
09>CT`80T92@0P2=SHd00`2:RXX0QhN708N7Q`0208B4Q080PH610P1oOgl207alO080NGUi0P1gMgL2
07AdM080LW9b0P1_Kfl206e]K@80JVYZ0P1XJ6P206IVIP80Hf=S00<0HF5Q05mOG`1OGel00P1MGEd2
05YJFP80F5QH0P1FEUH205ADE080DE5A5@3oool001<0oooo0P1ADE42059BDP80E5AD0P1EEED205MG
E`80FEUI0P1JFUX205aLG00305iNGP1OGel0GemO0080HF5Q0P1SHf<206EUI@80IfMW0P1YJFT206][
J`80KFe]0P1_Kfl2075aL@80Lg=c0P1fMWH207QhN080NWYj0P1mOGd00`20P800PX:208:2PP0208F5
Q@80R8R80P2<S8`208n?S`80Ti>C0P2GUiL209^KV`80WinO0P2TY:@20:FUY@H0Y:BT0P2UYJD00`2Y
ZJT0[:b/0:b/[0020;2`/080/k>c0P2f][H20;Vi^@80_;bl0P2m_Kd20<71`@80aLG50P39bLT20<[:
bP80bl_;0P3:b/X20<W9b@80b<S80`39bLT20<S8b080bLW9103:b/X20<W9b@80bl_;0P3=cLd20<o?
c`80dM7A0P3EeMD20=SHf080gMgM0P3QhN420>GUi@030>[ZjP3]kNd0kNg]0080kno_0P3`l?020?Cd
m080mOGe0P3`l?020>[ZjP80i>CT0P3Ng]h20=WIf@80e=CD0P3?cll20<[:bP80a/K60P31`L400`2m
_Kd0^KVi0;Vi^@020;Fe]@80/K6a0P2][Jd20:ZZZP80YZJV0P2SXj<209nOW`80W9bL0P2IVIT209JF
UP80Ti>C0P2@T90208f=S@80RXZ:00<0QhN708B4Q024Q8@00P22PX8207moO`80OGem0P1jNWX207Qh
N080MGEe0P1cLg<2071`L080KVi^0P1/K6`206UYJ@80IfMW0P1UIFD2069RHP03061PH01NGUh0GUiN
0080G5aL0P1JFUX205QHF080EUIF0P1CDe<2055ADAD0oooo000C0?ooo`80DE5A0P1BDU8205ADE080
EEEE0P1GEeL205UIF@80FUYJ0P1LG5`00`1NGUh0GemO05mOG`02065QH@80Hf=S0P1UIFD206MWI`80
JFUY0P1[Jf/206e]K@80Kfm_0P1aLG4207=cL`80MWIf0P1hN7P207YjNP80OGem00<0P82008:2PP22
PX800P25QHD208R8R080S8b<0P2?Shl209>CT`80UiNG0P2KVi/209nOW`80Y:BT0P2UYJD60:BTY080
YJFU00<0ZJVY0:b/[02/[:`00P2`/;020;>c/`80][Jf0P2i^KT20;bl_080_Kfm0P31`L420<G5a@80
bLW90P3:b/X20<_;b`80b/[:0P39bLT20<S8b0<0bLW90P38b<P20<W9b@@0b/[:0P39bLT20<_;b`80
cLg=0P3?cll20=7Ad@80eMGE0P3Hf=P20=gMg@80hN7Q0P3UiND00`3Zj^X0kNg]0>g]k@020>o_k`80
l?3`0P3dm?@20?Gem@80l?3`0P3Zj^X20>CTi080g]kN0P3IfMT20=CDe080clo?0P3:b/X20<K6aP80
`L7100<0_Kfm0;Vi^@2i^KT00P2e]KD20;6a/@80[Jf]0P2ZZZX20:JVYP80Xj>S0P2OWil209bLW080
VIVI0P2FUYH209>CT`80T92@0P2=SHd208Z:RP0308N7Q`24Q8@0Q8B40080PX:20P1oOgl207emO@80
NWYj0P1hN7P207EeM@80Lg=c0P1`L70206i^KP80K6a/0P1YJFT206MWI`80IFEU0P1RHV800`1PH600
GUiN05iNGP0205aLG080FUYJ0P1HF5P205IFEP80De=C0P1ADE4E0?ooo`004`3oool2055AD@80DU9B
0P1DE5@205EEE@80EeMG0P1HF5P205YJFP80Fe]K00<0GEeM05mOG`1OGel00P1PH602069RHP80I6AT
0P1VIVH206QXJ080JVYZ0P1/K6`206i^KP80L71`0P1bLW8207AdM080MWIf0P1iNGT207]kN`0307in
OP20P800P8200080Ph>30P26QXH208V9R@80SHf=0P2@T90209BDU080V9RH0P2LW9`20:2PX080YZJV
0P2[Zj/20:VYZ@80YjNW0P2XZ:P00`2YZJT0[:b/0:b/[0020;2`/080];Bd0P2f][H20;Rh^080^[Zj
0P2m_Kd20<30`080`L710P32`/820<?3``80a<C40P35aLD50<K6aPH0aLG50P36a/H20<O7a`80bLW9
0P3<c<`20<k>cP80dM7A0P3EeMD20=SHf080gMgM0P3Shn<20>OWi`80jn_[00<0k>c/0>k^kP3^k^h0
0P3`l?020??cl`80lO7a0P3[jn/20>KViP80hN7Q0P3Lg=`20=OGe`80d];B0P3=cLd20<W9b@80a<C4
0P30`<020;bl_0030;Rh^02d];@0];Bd0080/;2`0P2/[:`20:VYZ@80YJFU0P2RXZ8209nOW`80W9bL
0P2IVIT209JFUP80Ti>C0P2@T90208f=S@80RXZ:0P27QhL00`25QHD0PX:208:2PP0207moO`80OGem
0P1jNWX207QhN080MWIf0P1cLg<2075aL@80Kfm_0P1]KFd206YZJP80J6QX0P1VIVH206ATI080HV9R
00<0GemO05eMG@1MGEd00P1KFe/205UIF@80EeMG0P1EEED205=CD`80DE5A5@3oool001<0oooo0P1A
DE42059BDP80E5AD0P1EEED205MGE`80F5QH0P1JFUX205]KF`0305eMG@1OGel0GemO0080H61P0P1R
HV8206ATI080IVIV0P1XJ6P206YZJP80K6a/0P1^KVh2071`L080LW9b0P1dM7@207IfMP80NGUi0P1k
Ng/00`1nOWh0P8200820P00208>3P`80QXJ60P29RHT208f=S@80T92@0P2DU9@209RHV080W9bL0P2P
X:020:JVYP80Zj^[0P2YZJT20:NWY`80Z:RX00<0ZJVY0:b/[02/[:`00P2`/;020;Bd]080][Jf0P2h
^;P20;Zj^P80_Kfm0P30`<020<71`@80`/;20P33`l<20<C4a080aLG51@36a/H60<G5a@80a/K60P37
alL20<W9b@80c<c<0P3>c/h20=7Ad@80eMGE0P3Hf=P20=gMg@80hn?S0P3WinL20>_[j`030>c/k03^
k^h0k^k^0080l?3`0P3clo<20?7al@80jn_[0P3Vi^H20>7Qh@80g=cL0P3GemL20=;BdP80cLg=0P39
bLT20<C4a080`<300P2l_;`00`2h^;P0];Bd0;Bd]0020;2`/080[:b/0P2YZJT20:FUY@80XZ:R0P2O
Wil209bLW080VIVI0P2FUYH209>CT`80T92@0P2=SHd208Z:RP80QhN700<0QHF508:2PP22PX800P1o
Ogl207emO@80NWYj0P1hN7P207IfMP80Lg=c0P1aLG4206m_K`80KFe]0P1ZJVX206QXJ080IVIV0P1T
I6@2069RHP0305mOG`1MGEd0GEeM0080Fe]K0P1IFET205MGE`80EEEE0P1CDe<2055ADAD0oooo000C
0?ooo`80DE5A0P1BDU8205=CD`80EEEE0P1FEUH205QHF080FEUI0P1KFe/00`1LG5`0GUiN05iNGP02
061PH080HF5Q0P1SHf<206EUI@80IfMW0P1XJ6P206YZJP80K6a/0P1^KVh2071`L080LW9b0P1dM7@2
07MgM`80NGUi00<0Ng]k07inOP1nOWh00P21PH4208B4Q080QhN70P2:RXX208f=S@80TI6A0P2DU9@2
09RHV080WIfM0P2QXJ420:JVYP80Zj^[0P2][Jd30:b/[080[Jf]0P2^[Zh20;2`/080/[:b0P2e]KD2
0;Rh^080^[Zj0P2l_;`20;fm_@80_kno0P30`<090<71`@80`/;20P33`l<20<C4a080aLG50P36a/H2
0<W9b@80c<c<0P3@d=020=KFeP80fMWI0P3Ng]h20>;RhP80iNGU0P3Xj>P20>WYj@030>_[j`3_knl0
kno_0080kno_0P3/k>`20>OWi`80h^;R0P3MgMd20=WIf@80e=CD0P3?cll20<_;b`80a/K60P32`/82
0;jn_P80^[Zj0P2f][H00`2b/[80[jn_0:n_[`020:^[Z`80YjNW0P2TY:@20:6QX@80WYjN0P2KVi/2
09RHV080UIFE0P2BTY8208n?S`80S8b<0P2:RXX208N7Q`80Q8B400<0PX:207moO`1oOgl00P1mOGd2
07YjNP80N7Qh0P1fMWH207AdM080LG5a0P1_Kfl206e]K@80Jf][0P1YJFT206MWI`80IFEU0P1SHf<2
065QH@0305mOG`1MGEd0GEeM0080Fe]K0P1IFET205MGE`80EEEE0P1CDe<2055ADAD0oooo000C0?oo
o`80DE5A0P1BDU8205=CD`80EEEE0P1FEUH205QHF080FEUI0P1KFe/00`1LG5`0GUiN05iNGP02061P
H080HF5Q0P1SHf<206EUI@80IfMW0P1XJ6P206YZJP80K6a/0P1^KVh2071`L080LW9b0P1dM7@207Mg
M`80NGUi00<0Ng]k07inOP1nOWh00P21PH4208B4Q080QhN70P2:RXX208f=S@80TI6A0P2DU9@209RH
V080WIfM0P2QXJ420:JVYP80Zj^[0P2][Jd30:b/[080[Jf]0P2^[Zh20;2`/080/[:b0P2e]KD20;Rh
^080^[Zj0P2l_;`20;fm_@80_kno0P30`<090<71`@80`/;20P33`l<20<C4a080aLG50P36a/H20<W9
b@80c<c<0P3@d=020=KFeP80fMWI0P3Ng]h20>;RhP80iNGU0P3Xj>P20>WYj@030>_[j`3_knl0kno_
0080kno_0P3/k>`20>OWi`80h^;R0P3MgMd20=WIf@80e=CD0P3?cll20<_;b`80a/K60P32`/820;jn
_P80^[Zj0P2f][H00`2b/[80[jn_0:n_[`020:^[Z`80YjNW0P2TY:@20:6QX@80WYjN0P2KVi/209RH
V080UIFE0P2BTY8208n?S`80S8b<0P2:RXX208N7Q`80Q8B400<0PX:207moO`1oOgl00P1mOGd207Yj
NP80N7Qh0P1fMWH207AdM080LG5a0P1_Kfl206e]K@80Jf][0P1YJFT206MWI`80IFEU0P1SHf<2065Q
H@0305mOG`1MGEd0GEeM0080Fe]K0P1IFET205MGE`80EEEE0P1CDe<2055ADAD0oooo000C0?ooo`80
D51@0P1BDU8205=CD`80EEEE0P1FEUH205MGE`80FEUI0P1JFUX00`1LG5`0GEeM05eMG@0205mOG`80
H61P0P1RHV8206ATI080IFEU0P1WIfL206UYJ@80Jf][0P1]KFd206m_K`80L71`0P1bLW8207EeM@80
MgMg00<0NGUi07alO01lO7`00P1nOWh20861P@80Q8B40P26QXH208V9R@80SHf=0P2@T90209BDU080
V9RH0P2LW9`20:6QX@80YZJV0P2/[:`30;2`/0@0[Zj^0P2_[jl20;6a/@80/k>c0P2d];@20;Jf]P80
]kNg0P2i^KT20;Zj^P80^k^k0P2l_;`20;fm_@@0_;bl00<0_Kfm0;no_`2o_kl00P31`L420<C4a080
alO70P38b<P20<c<c080dM7A0P3EeMD20=WIf@80gMgM0P3QhN420>?Sh`80i>CT0P3Vi^H20>[ZjP03
0>_[j`3YjNT0jNWY0080iNGU0P3QhN420=gMg@80f=SH0P3De=@20=3@d080c<c<0P37alL20<?3``80
_kno0P2k^k/20;Ng]`80];Bd0P2`/;000`2][Jd0ZJVY0:VYZ@020:JVYP80XZ:R0P2OWil209bLW080
VIVI0P2FUYH209>CT`80TI6A0P2>SXh208b<S080RHV90P26QXH208B4Q080PH6100<0Ogmo07alO01l
O7`00P1jNWX207QhN080MWIf0P1cLg<2075aL@80Kfm_0P1^KVh206a/K080JFUY0P1WIfL206EUI@80
Hf=S0P1QHF42061PH00305iNGP1LG5`0G5aL0080FUYJ0P1HF5P205IFEP80EEEE0P1CDe<2055ADAD0
oooo000C0?ooo`80D51@0P1BDU8205=CD`80EEEE0P1FEUH205MGE`80FEUI0P1JFUX00`1LG5`0GEeM
05eMG@0205mOG`80H61P0P1RHV8206ATI080IFEU0P1WIfL206UYJ@80Jf][0P1]KFd206m_K`80L71`
0P1bLW8207EeM@80MgMg00<0NGUi07alO01lO7`00P1nOWh20861P@80Q8B40P26QXH208V9R@80SHf=
0P2@T90209BDU080V9RH0P2LW9`20:6QX@80YZJV0P2/[:`30;2`/0@0[Zj^0P2_[jl20;6a/@80/k>c
0P2d];@20;Jf]P80]kNg0P2i^KT20;Zj^P80^k^k0P2l_;`20;fm_@@0_;bl00<0_Kfm0;no_`2o_kl0
0P31`L420<C4a080alO70P38b<P20<c<c080dM7A0P3EeMD20=WIf@80gMgM0P3QhN420>?Sh`80i>CT
0P3Vi^H20>[ZjP030>_[j`3YjNT0jNWY0080iNGU0P3QhN420=gMg@80f=SH0P3De=@20=3@d080c<c<
0P37alL20<?3``80_kno0P2k^k/20;Ng]`80];Bd0P2`/;000`2][Jd0ZJVY0:VYZ@020:JVYP80XZ:R
0P2OWil209bLW080VIVI0P2FUYH209>CT`80TI6A0P2>SXh208b<S080RHV90P26QXH208B4Q080PH61
00<0Ogmo07alO01lO7`00P1jNWX207QhN080MWIf0P1cLg<2075aL@80Kfm_0P1^KVh206a/K080JFUY
0P1WIfL206EUI@80Hf=S0P1QHF42061PH00305iNGP1LG5`0G5aL0080FUYJ0P1HF5P205IFEP80EEEE
0P1CDe<2055ADAD0oooo000C0?ooo`80D51@0P1BDU8205=CD`80E5AD0P1FEUH205MGE`80F5QH0P1J
FUX00`1KFe/0G5aL05aLG00205iNGP80GemO0P1QHF42069RHP80I6AT0P1VIVH206MWI`80JFUY0P1[
Jf/206e]K@80Kfm_0P1aLG4207=cL`80MGEe00<0MgMg07UiN@1iNGT00P1lO7`207inOP80PH610P23
Ph<208J6QP80RHV90P2=SHd2092@T080U9BD0P2HV9P209bLW080X:2P0P2TY:@20:VYZ@030:f][@2a
/K40/K6a0080/k>c0P2a/K440:n_[`80/;2`0P2a/K420;Bd]080][Jf0P2g]kL20;Rh^080^[Zj0P2k
^k/20;bl_080_[jn00<0_kno0<71`@31`L400P32`/820<G5a@80b/[:0P3=cLd20=7Ad@80e=CD0P3F
e]H20=SHf080f][J0P3Ng]h20>7Qh@80i>CT0P3UiND20>?Sh`030>3Ph03MgMd0gMgM0080f][J0P3G
emL20=?Cd`80clo?0P3;bl/20<O7a`80`l?30P2o_kl20;bl_080^;Rh0P2d];@20;6a/@80[Jf]0P2Z
ZZX00`2VYZH0Xj>S0:>SX`020:2PX080WIfM0P2JVYX209NGU`80U9BD0P2BTY8208n?S`80SHf=0P2:
RXX208R8R080QHF50P23Ph<20861P@80OWin00<0O7al07YjNP1jNWX00P1gMgL207EeM@80Lg=c0P1a
LG4206m_K`80KFe]0P1[Jf/206UYJ@80IfMW0P1VIVH206ATI080HV9R0P1PH60205mOG`0305eMG@1K
Fe/0Fe]K0080FEUI0P1GEeL205IFEP80E5AD0P1CDe<2055ADAD0oooo000C0?ooo`80D51@0P1BDU82
05=CD`80E5AD0P1FEUH205MGE`80F5QH0P1JFUX00`1KFe/0G5aL05aLG00205iNGP80GemO0P1QHF42
069RHP80I6AT0P1VIVH206MWI`80JFUY0P1[Jf/206e]K@80Kfm_0P1aLG4207=cL`80MGEe00<0MgMg
07UiN@1iNGT00P1lO7`207inOP80PH610P23Ph<208J6QP80RHV90P2=SHd2092@T080U9BD0P2HV9P2
09bLW080X:2P0P2TY:@20:VYZ@030:f][@2a/K40/K6a0080/k>c0P2a/K440:n_[`80/;2`0P2a/K42
0;Bd]080][Jf0P2g]kL20;Rh^080^[Zj0P2k^k/20;bl_080_[jn00<0_kno0<71`@31`L400P32`/82
0<G5a@80b/[:0P3=cLd20=7Ad@80e=CD0P3Fe]H20=SHf080f][J0P3Ng]h20>7Qh@80i>CT0P3UiND2
0>?Sh`030>3Ph03MgMd0gMgM0080f][J0P3GemL20=?Cd`80clo?0P3;bl/20<O7a`80`l?30P2o_kl2
0;bl_080^;Rh0P2d];@20;6a/@80[Jf]0P2ZZZX00`2VYZH0Xj>S0:>SX`020:2PX080WIfM0P2JVYX2
09NGU`80U9BD0P2BTY8208n?S`80SHf=0P2:RXX208R8R080QHF50P23Ph<20861P@80OWin00<0O7al
07YjNP1jNWX00P1gMgL207EeM@80Lg=c0P1aLG4206m_K`80KFe]0P1[Jf/206UYJ@80IfMW0P1VIVH2
06ATI080HV9R0P1PH60205mOG`0305eMG@1KFe/0Fe]K0080FEUI0P1GEeL205IFEP80E5AD0P1CDe<2
055ADAD0oooo000C0?ooo`80D51@0P1BDU8205=CD`80E5AD0P1EEED205IFEP80F5QH0P1IFET00`1J
FUX0G5aL05aLG00205eMG@80GUiN0P1PH602065QH@80Hf=S0P1TI6@206IVIP80IfMW0P1YJFT206][
J`80K6a/0P1^KVh2071`L080LW9b00<0M7Ad07MgM`1gMgL00P1iNGT207]kN`80OWin0P20P80208>3
P`80QXJ60P29RHT208b<S080Shn?0P2CTi<209JFUP80VYZJ0P2NWYh20::RXP030:JVYP2YZJT0ZJVY
0080Zj^[0P2^[Zh20;6a/@80/;2`0P2_[jl20;2`/0@0/K6a0P2c/k<20;Fe]@80][Jf0P2h^;P20;Zj
^P80_Kfm00<0_kno0<71`@31`L400P33`l<20<K6aP80b<S80P3:b/X20<g=c@80c/k>0P3AdM420=GE
e@80fMWI0P3Kfm/20=[JfP80fMWI0P3Hf=P20=KFeP030=CDe03Bd]80d];B0080clo?0P3<c<`20<S8
b080aLG50P32`/820;jn_P80^k^k0P2g]kL20;Bd]080/;2`0P2][Jd20:ZZZP80YjNW0P2TY:@00`2Q
XJ40WYjN09jNWP0209^KV`80V9RH0P2EUID209:BTP80T92@0P2=SHd208^;R`80R8R80P26QXH208>3
P`80PH610P1oOgl207alO080NWYj00<0NGUi07MgM`1gMgL00P1eMGD207=cL`80LG5a0P1_Kfl206e]
K@80Jf][0P1YJFT206MWI`80IFEU0P1TI6@2069RHP80HF5Q0P1OGel205eMG@0305aLG01JFUX0FUYJ
0080FEUI0P1GEeL205IFEP80E5AD0P1BDU82055ADAD0oooo000C0?ooo`80D51@0P1BDU8205=CD`80
E5AD0P1EEED205IFEP80F5QH0P1IFET00`1JFUX0G5aL05aLG00205eMG@80GUiN0P1PH602065QH@80
Hf=S0P1TI6@206IVIP80IfMW0P1YJFT206][J`80K6a/0P1^KVh2071`L080LW9b00<0M7Ad07MgM`1g
MgL00P1iNGT207]kN`80OWin0P20P80208>3P`80QXJ60P29RHT208b<S080Shn?0P2CTi<209JFUP80
VYZJ0P2NWYh20::RXP030:JVYP2YZJT0ZJVY0080Zj^[0P2^[Zh20;6a/@80/;2`0P2_[jl20;2`/0@0
/K6a0P2c/k<20;Fe]@80][Jf0P2h^;P20;Zj^P80_Kfm00<0_kno0<71`@31`L400P33`l<20<K6aP80
b<S80P3:b/X20<g=c@80c/k>0P3AdM420=GEe@80fMWI0P3Kfm/20=[JfP80fMWI0P3Hf=P20=KFeP03
0=CDe03Bd]80d];B0080clo?0P3<c<`20<S8b080aLG50P32`/820;jn_P80^k^k0P2g]kL20;Bd]080
/;2`0P2][Jd20:ZZZP80YjNW0P2TY:@00`2QXJ40WYjN09jNWP0209^KV`80V9RH0P2EUID209:BTP80
T92@0P2=SHd208^;R`80R8R80P26QXH208>3P`80PH610P1oOgl207alO080NWYj00<0NGUi07MgM`1g
MgL00P1eMGD207=cL`80LG5a0P1_Kfl206e]K@80Jf][0P1YJFT206MWI`80IFEU0P1TI6@2069RHP80
HF5Q0P1OGel205eMG@0305aLG01JFUX0FUYJ0080FEUI0P1GEeL205IFEP80E5AD0P1BDU82055ADAD0
oooo000C0?ooo`80D51@0P1ADE4205=CD`80E5AD0P1EEED205IFEP80EeMG0P1HF5P00`1JFUX0Fe]K
05]KF`0205aLG080GEeM0P1OGel2061PH080HF5Q0P1SHf<206ATI080IVIV0P1WIfL206UYJ@80Jf][
0P1/K6`206i^KP80L71`00<0LW9b07AdM01dM7@00P1fMWH207QhN080NWYj0P1mOGd207moO`80PX:2
0P25QHD208R8R080Rh^;0P2>SXh2096AT@80U9BD0P2HV9P209^KV`0309jNWP2QXJ40XJ6Q0080Xj>S
0P2VYZH20:RXZ080Zj^[0P2^[Zh20;2`/0@0/K6a102b/[820;>c/`80];Bd0P2e]KD20;Jf]P030;Ng
]`2k^k/0^k^k0080_[jn0P30`<020<;2`P80aLG50P39bLT20<g=c@80clo?103@d=020<o?c`80c/k>
0P3=cLd20<c<c080bl_;00<0bLW90<O7a`37alL00P34a<@20<;2`P80_kno0P2l_;`20;Vi^@80][Jf
0P2c/k<20:n_[`80[:b/0P2YZJT20:JVYP80Xj>S0P2QXJ4209jNWP0309^KV`2HV9P0V9RH0080UIFE
0P2CTi<2092@T080SXj>0P2;Rh/208V9R@80QhN70P24Q8@208:2PP80P8200P1mOGd207]kN`80NGUi
0P1hN7P00`1fMWH0M7Ad07AdM002079bLP80L71`0P1^KVh206e]K@80Jf][0P1YJFT206MWI`80IVIV
0P1TI6@2069RHP80HF5Q0P1PH60205iNGP80G5aL00<0Fe]K05UIF@1IFET00P1HF5P205MGE`80EEEE
0P1DE5@2059BDP80DE5A5@3oool001<0oooo0P1@D502055AD@80De=C0P1DE5@205EEE@80EUIF0P1G
EeL205QHF00305YJFP1KFe/0Fe]K0080G5aL0P1MGEd205mOG`80H61P0P1QHF4206=SH`80I6AT0P1V
IVH206MWI`80JFUY0P1[Jf/206a/K080KVi^0P1`L7000`1bLW80M7Ad07AdM00207IfMP80N7Qh0P1j
NWX207emO@80Ogmo0P22PX8208F5Q@80R8R80P2;Rh/208j>SP80TI6A0P2DU9@209RHV080Vi^K00<0
WYjN0:6QX@2QXJ400P2SXj<20:JVYP80Z:RX0P2[Zj/20:j^[P80/;2`102a/K440;:b/P80/k>c0P2d
];@20;Fe]@80][Jf00<0]kNg0;^k^`2k^k/00P2n_[h20<30`080`/;20P35aLD20<W9b@80cLg=0P3?
cll40=3@d080clo?0P3>c/h20<g=c@80c<c<0P3;bl/00`39bLT0alO70<O7a`020<C4a080`/;20P2o
_kl20;bl_080^KVi0P2f][H20;>c/`80[jn_0P2/[:`20:VYZ@80YZJV0P2SXj<20:6QX@80WYjN00<0
Vi^K09RHV02HV9P00P2EUID209>CT`80T92@0P2>SXh208^;R`80RHV90P27QhL208B4Q080PX:20P20
P80207emO@80Ng]k0P1iNGT207QhN00307IfMP1dM7@0M7Ad0080LW9b0P1`L70206i^KP80KFe]0P1[
Jf/206UYJ@80IfMW0P1VIVH206ATI080HV9R0P1QHF42061PH080GUiN0P1LG5`00`1KFe/0FEUI05UI
F@0205QHF080EeMG0P1EEED205ADE080DU9B0P1ADE4E0?ooo`004`3oool2051@D080DE5A0P1BDU82
05=CD`80E5AD0P1EEED205MGE`80F5QH00<0FEUI05YJFP1JFUX00P1KFe/205aLG080GUiN0P1OGel2
061PH080HF5Q0P1SHf<206ATI080IVIV0P1WIfL206QXJ080JVYZ0P1/K6`206i^KP0306m_K`1aLG40
LG5a0080Lg=c0P1eMGD207MgM`80NGUi0P1lO7`207inOP80PH610P23Ph<208J6QP80RHV90P2<S8`2
08n?S`80TI6A0P2DU9@00`2GUiL0VYZJ09ZJVP0209bLW080WinO0P2QXJ420:>SX`80YZJV0P2WYjL2
0:VYZ@80ZZZZ0P2[Zj/20:b/[080[Jf]0P2^[Zh20;2`/080/k>c00<0]KFe0;Ng]`2g]kL00P2j^[X2
0;bl_080_[jn0P30`<020<71`@80`/;20P33`l<60<C4a080`l?30P32`/820<71`@80_kno00<0_Kfm
0;^k^`2k^k/00P2i^KT20;Ng]`80]KFe0P2c/k<20;2`/080[Jf]0P2[Zj/20:RXZ080YJFU0P2RXZ82
09nOW`80WIfM0P2JVYX209RHV00309FEU@2BTY80TY:B0080Shn?0P2=SHd208^;R`80RHV90P26QXH2
08B4Q080PX:20P20P80207inOP80O7al0P1jNWX207QhN080MWIf0P1dM7@00`1cLg<0LG5a075aL@02
06m_K`80KFe]0P1/K6`206YZJP80J6QX0P1WIfL206EUI@80I6AT0P1SHf<2065QH@80GemO0P1NGUh2
05eMG@80Fe]K00<0FUYJ05UIF@1IFET00P1GEeL205IFEP80E5AD0P1CDe<2059BDP80D51@5@3oool0
01<0oooo0P1@D502055AD@80DU9B0P1CDe<205ADE080EEEE0P1GEeL205QHF00305UIF@1JFUX0FUYJ
0080Fe]K0P1LG5`205iNGP80GemO0P1PH602065QH@80Hf=S0P1TI6@206IVIP80IfMW0P1XJ6P206YZ
JP80K6a/0P1^KVh00`1_Kfl0LG5a075aL@0207=cL`80MGEe0P1gMgL207UiN@80O7al0P1nOWh20861
P@80Ph>30P26QXH208V9R@80S8b<0P2?Shl2096AT@80U9BD00<0UiNG09ZJVP2JVYX00P2LW9`209nO
W`80XJ6Q0P2SXj<20:JVYP80YjNW0P2YZJT20:ZZZP80Zj^[0P2/[:`20:f][@80[Zj^0P2`/;020;>c
/`030;Fe]@2g]kL0]kNg0080^[Zj0P2l_;`20;jn_P80`<300P31`L420<;2`P80`l?31P34a<@20<?3
``80`/;20P31`L420;no_`030;fm_@2k^k/0^k^k0080^KVi0P2g]kL20;Fe]@80/k>c0P2`/;020:f]
[@80Zj^[0P2XZ:P20:FUY@80XZ:R0P2OWil209fMW@80VYZJ0P2HV9P00`2EUID0TY:B09:BTP0208n?
S`80SHf=0P2;Rh/208V9R@80QXJ60P24Q8@208:2PP80P8200P1nOWh207alO080NWYj0P1hN7P207If
MP80M7Ad00<0Lg=c075aL@1aLG400P1_Kfl206e]K@80K6a/0P1ZJVX206QXJ080IfMW0P1UIFD206AT
I080Hf=S0P1QHF4205mOG`80GUiN0P1MGEd205]KF`0305YJFP1IFET0FEUI0080EeMG0P1FEUH205AD
E080De=C0P1BDU82051@D1D0oooo000C0?ooo`80D51@0P1ADE42059BDP80De=C0P1DE5@205EEE@80
EUIF0P1GEeL00`1HF5P0FEUI05UIF@0205YJFP80Fe]K0P1LG5`205eMG@80GemO0P1PH602065QH@80
HV9R0P1TI6@206EUI@80IfMW0P1XJ6P206UYJ@80Jf][00<0KFe]06i^KP1^KVh00P1`L702079bLP80
M7Ad0P1fMWH207QhN080NWYj0P1lO7`207moO`80PH610P24Q8@208J6QP80RHV90P2;Rh/208j>SP03
092@T02CTi<0Ti>C0080UIFE0P2GUiL209VIV@80Vi^K0P2MWId209nOW`80X:2P0P2QXJ420:>SX`80
Y:BT0P2UYJD20:JVYP80Z:RX0P2ZZZX00`2/[:`0[Zj^0:j^[P020;2`/080/K6a0P2c/k<20;Bd]080
][Jf0P2g]kL:0;Rh^080]kNg0P2f][H20;Bd]0030;>c/`2a/K40/K6a0080[jn_0P2][Jd20:^[Z`80
ZJVY0P2WYjL20:BTY080XZ:R0P2OWil209fMW@80Vi^K0P2HV9P209FEU@80Ti>C0P2ATI400`2?Shl0
S8b<08b<S00208Z:RP80R8R80P26QXH208B4Q080PX:20P20P80207inOP80O7al0P1jNWX207QhN080
MWIf0P1eMGD207=cL`80LG5a00<0L71`06i^KP1^KVh00P1/K6`206][J`80JFUY0P1XJ6P206IVIP80
IFEU0P1SHf<2069RHP80HF5Q0P1PH60205iNGP80GEeM0P1KFe/205YJFP0305UIF@1HF5P0F5QH0080
EeMG0P1EEED205ADE080De=C0P1ADE42051@D1D0oooo000C0?ooo`80D51@0P1ADE42059BDP80De=C
0P1DE5@205EEE@80EUIF0P1GEeL00`1HF5P0FEUI05UIF@0205YJFP80Fe]K0P1LG5`205eMG@80GemO
0P1PH602065QH@80HV9R0P1TI6@206EUI@80IfMW0P1XJ6P206UYJ@80Jf][00<0KFe]06i^KP1^KVh0
0P1`L702079bLP80M7Ad0P1fMWH207QhN080NWYj0P1lO7`207moO`80PH610P24Q8@208J6QP80RHV9
0P2;Rh/208j>SP03092@T02CTi<0Ti>C0080UIFE0P2GUiL209VIV@80Vi^K0P2MWId209nOW`80X:2P
0P2QXJ420:>SX`80Y:BT0P2UYJD20:JVYP80Z:RX0P2ZZZX00`2/[:`0[Zj^0:j^[P020;2`/080/K6a
0P2c/k<20;Bd]080][Jf0P2g]kL:0;Rh^080]kNg0P2f][H20;Bd]0030;>c/`2a/K40/K6a0080[jn_
0P2][Jd20:^[Z`80ZJVY0P2WYjL20:BTY080XZ:R0P2OWil209fMW@80Vi^K0P2HV9P209FEU@80Ti>C
0P2ATI400`2?Shl0S8b<08b<S00208Z:RP80R8R80P26QXH208B4Q080PX:20P20P80207inOP80O7al
0P1jNWX207QhN080MWIf0P1eMGD207=cL`80LG5a00<0L71`06i^KP1^KVh00P1/K6`206][J`80JFUY
0P1XJ6P206IVIP80IFEU0P1SHf<2069RHP80HF5Q0P1PH60205iNGP80GEeM0P1KFe/205YJFP0305UI
F@1HF5P0F5QH0080EeMG0P1EEED205ADE080De=C0P1ADE42051@D1D0oooo000C0?ooo`80D51@0P1A
DE42059BDP@0De=C0P1DE5@205EEE@80EUIF00<0EeMG05QHF01HF5P00P1IFET205YJFP80Fe]K0P1L
G5`205eMG@80GUiN0P1PH602065QH@80HV9R0P1SHf<206ATI080IVIV0P1WIfL206QXJ00306YZJP1[
Jf/0Jf][0080KFe]0P1_Kfl2071`L080LW9b0P1dM7@207IfMP80N7Qh0P1jNWX207alO080Ogmo0P21
PH4208>3P`80QXJ60P28R8P00`2:RXX0S8b<08b<S00208f=S@80T92@0P2ATI4209>CT`80UIFE0P2G
UiL209RHV080VIVI0P2JVYX209bLW080WIfM0P2NWYh20:2PX080XJ6Q00<0Xj>S0:BTY02TY:@00P2V
YZH20:NWY`80ZJVY0P2ZZZX20:^[Z`@0[:b/1P2][Jd20:b/[0@0Zj^[0P2ZZZX00`2XZ:P0YjNW0:NW
Y`020:FUY@80Xj>S0P2RXZ820:2PX080WIfM0P2KVi/209ZJVP80UiNG0P2EUID209>CT`80TI6A0P2?
Shl208f=S@80RXZ:00<0R8R808J6QP26QXH00P25QHD208>3P`80PH610P1oOgl207emO@80Ng]k0P1i
NGT207MgM`80MWIf0P1dM7@207=cL`80LG5a0P1_Kfl206i^KP0306e]K@1[Jf/0Jf][0080JVYZ0P1X
J6P206IVIP80IFEU0P1TI6@206=SH`80HF5Q0P1PH60205mOG`80GEeM0P1LG5`205]KF`80FUYJ0P1I
FET00`1HF5P0EeMG05MGE`0205IFEP80EEEE0P1CDe<4059BDP80D51@5@3oool001<0oooo0P1@D502
055AD@80DU9B101CDe<205ADE080EEEE0P1FEUH00`1GEeL0F5QH05QHF00205UIF@80FUYJ0P1KFe/2
05aLG080GEeM0P1NGUh2061PH080HF5Q0P1RHV8206=SH`80I6AT0P1VIVH206MWI`80J6QX00<0JVYZ
06][J`1[Jf/00P1]KFd206m_K`80L71`0P1bLW8207AdM080MWIf0P1hN7P207YjNP80O7al0P1oOgl2
0861P@80Ph>30P26QXH208R8R00308Z:RP2<S8`0S8b<0080SHf=0P2@T902096AT@80Ti>C0P2EUID2
09NGU`80V9RH0P2IVIT209ZJVP80W9bL0P2MWId209jNWP80X:2P0P2QXJ400`2SXj<0Y:BT0:BTY002
0:JVYP80YjNW0P2YZJT20:ZZZP80Zj^[102/[:`60:f][@80[:b/102[Zj/20:ZZZP030:RXZ02WYjL0
YjNW0080YJFU0P2SXj<20::RXP80X:2P0P2MWId209^KV`80VYZJ0P2GUiL209FEU@80Ti>C0P2ATI42
08n?S`80SHf=0P2:RXX00`28R8P0QXJ608J6QP0208F5Q@80Ph>30P21PH4207moO`80OGem0P1kNg/2
07UiN@80MgMg0P1fMWH207AdM080Lg=c0P1aLG4206m_K`80KVi^00<0KFe]06][J`1[Jf/00P1ZJVX2
06QXJ080IVIV0P1UIFD206ATI080Hf=S0P1QHF42061PH080GemO0P1MGEd205aLG080Fe]K0P1JFUX2
05UIF@0305QHF01GEeL0EeMG0080EUIF0P1EEED205=CD`@0DU9B0P1@D50E0?ooo`004`3oool2051@
D0@0DE5A0P1BDU8205=CD`80E5AD101EEED00`1FEUH0EeMG05MGE`0205QHF080FEUI0P1JFUX205]K
F`80G5aL0P1MGEd205iNGP80GemO0P1PH602065QH@80HV9R0P1SHf<206ATI080IVIV00<0IfMW06QX
J01XJ6P00P1ZJVX206][J`80KFe]0P1^KVh2071`L080LW9b0P1dM7@207EeM@80MgMg0P1iNGT207]k
N`80OGem0P1oOgl20861P@0308:2PP24Q8@0Q8B40080QXJ60P28R8P208Z:RP80S8b<0P2=SHd208j>
SP80Shn?0P2ATI4209:BTP80Ti>C0P2DU9@209FEU@80UiNG0P2HV9P00`2JVYX0Vi^K09^KV`0209bL
W080WIfM0P2NWYh20:2PX0@0XJ6Q202RXZ840:6QX@80X:2P0P2OWil00`2NWYh0WIfM09fMW@0209^K
V`80VYZJ0P2IVIT209NGU`80UIFE0P2CTi<2096AT@80Shn?0P2>SXh208^;R`80RHV90P27QhL208J6
QP80Q8B400<0PX:20820P020P8000P1oOgl207emO@80O7al0P1jNWX207QhN080MWIf0P1eMGD207=c
L`80LW9b0P1`L70206m_K`80KFe]0P1/K6`206][J`0306UYJ@1XJ6P0J6QX0080IfMW0P1UIFD206AT
I080Hf=S0P1RHV82061PH080GemO0P1NGUh205eMG@80G5aL0P1KFe/205YJFP80FEUI0P1HF5P00`1G
EeL0EUIF05IFEP0205EEE@80E5AD0P1CDe<2059BDP80DE5A0P1@D50E0?ooo`004`3oool4051@D080
DE5A0P1BDU8405=CD`80E5AD0`1EEED205IFEP80EeMG0P1HF5P405UIF@80FUYJ0P1KFe/205aLG080
GEeM0P1NGUh205mOG`80H61P0P1QHF42069RHP80Hf=S00<0I6AT06EUI@1UIFD00P1WIfL206QXJ080
JFUY0P1[Jf/206a/K080KVi^0P1_Kfl2075aL@80LW9b0P1dM7@207IfMP80MgMg0P1iNGT207]kN`03
07alO01nOWh0OWin0080Ogmo0P21PH4208>3P`80Q8B40P25QHD208J6QP80R8R81029RHT208Z:RP80
S8b<0P2=SHd208j>SP80Shn?00<0T92@09:BTP2BTY800P2CTi<209BDU0@0UIFE0P2FUYH<09NGU`80
UYJF0P2EUID309BDU080Ti>C0P2BTY82096AT@80Shn?0P2=SHd208b<S080Rh^;0P29RHT208N7Q`80
QHF50P23Ph<208:2PP80PH610P1oOgl207emO@0307alO01jNWX0NWYj0080NGUi0P1gMgL207IfMP80
MGEe0P1cLg<2079bLP80L71`0P1_Kfl206e]K@80K6a/0P1ZJVX206UYJ@80J6QX0P1WIfL00`1VIVH0
IFEU06EUI@0206=SH`80HV9R0P1QHF42061PH080GemO0P1NGUh405eMG@80G5aL0P1KFe/205YJFP80
FEUI0P1HF5P205MGE`0305IFEP1EEED0EEEE0080E5AD0P1CDe<4059BDP80DE5A0P1@D50E0?ooo`00
4`3oool4051@D080DE5A0P1BDU8405=CD`80E5AD0`1EEED205IFEP80EeMG0P1HF5P405UIF@80FUYJ
0P1KFe/205aLG080GEeM0P1NGUh205mOG`80H61P0P1QHF42069RHP80Hf=S00<0I6AT06EUI@1UIFD0
0P1WIfL206QXJ080JFUY0P1[Jf/206a/K080KVi^0P1_Kfl2075aL@80LW9b0P1dM7@207IfMP80MgMg
0P1iNGT207]kN`0307alO01nOWh0OWin0080Ogmo0P21PH4208>3P`80Q8B40P25QHD208J6QP80R8R8
1029RHT208Z:RP80S8b<0P2=SHd208j>SP80Shn?00<0T92@09:BTP2BTY800P2CTi<209BDU0@0UIFE
0P2FUYH<09NGU`80UYJF0P2EUID309BDU080Ti>C0P2BTY82096AT@80Shn?0P2=SHd208b<S080Rh^;
0P29RHT208N7Q`80QHF50P23Ph<208:2PP80PH610P1oOgl207emO@0307alO01jNWX0NWYj0080NGUi
0P1gMgL207IfMP80MGEe0P1cLg<2079bLP80L71`0P1_Kfl206e]K@80K6a/0P1ZJVX206UYJ@80J6QX
0P1WIfL00`1VIVH0IFEU06EUI@0206=SH`80HV9R0P1QHF42061PH080GemO0P1NGUh405eMG@80G5aL
0P1KFe/205YJFP80FEUI0P1HF5P205MGE`0305IFEP1EEED0EEEE0080E5AD0P1CDe<4059BDP80DE5A
0P1@D50E0?ooo`004`3oool4051@D0@0DE5A0P1BDU8405=CD`80E5AD0`1EEED205IFEP@0EeMG0P1H
F5P405UIF@80FUYJ0P1KFe/205aLG080GEeM0P1NGUh405mOG`80H61P00<0HF5Q069RHP1RHV800P1S
Hf<206ATI080IVIV0P1WIfL206QXJ080JFUY0P1[Jf/206a/K080KFe]0P1_Kfl2071`L080LW9b0P1c
Lg<207AdM00307IfMP1gMgL0MgMg0080NGUi0P1jNWX207]kN`80O7al0P1mOGd207inOP80Ogmo0P20
P8020861P@80PX:20P23Ph<208B4Q080QHF50P26QXH00`27QhL0R8R808R8R00208R8R080RHV90P2:
RXX208^;R`@0S8b<202=SHd408b<S080Rh^;0`2:RXX208V9R@80R8R80P27QhL208J6QP80QHF50P24
Q8@208:2PP80PH610P1oOgl207inOP80O7al0P1kNg/207YjNP80N7Qh0P1gMgL00`1fMWH0M7Ad07Ad
M00207=cL`80LG5a0P1`L70206m_K`80KVi^0P1/K6`206][J`80JVYZ0P1YJFT206QXJ080IfMW0P1V
IVH206EUI@80I6AT00<0Hf=S069RHP1RHV800P1QHF42061PH080GemO0P1NGUh205eMG@@0G5aL0P1K
Fe/205YJFP80FEUI0P1HF5P405MGE`80EUIF00<0EEEE05ADE01DE5@00P1DE5@205=CD`80DU9B0P1A
DE44051@D1D0oooo000C0?ooo`@0D51@101ADE42059BDP@0De=C0P1DE5@305EEE@80EUIF101GEeL2
05QHF0@0FEUI0P1JFUX205]KF`80G5aL0P1MGEd205iNGP@0GemO0P1PH6000`1QHF40HV9R069RHP02
06=SH`80I6AT0P1VIVH206MWI`80J6QX0P1YJFT206][J`80K6a/0P1]KFd206m_K`80L71`0P1bLW82
07=cL`80M7Ad00<0MWIf07MgM`1gMgL00P1iNGT207YjNP80Ng]k0P1lO7`207emO@80OWin0P1oOgl2
0820P080PH610P22PX8208>3P`80Q8B40P25QHD208J6QP0308N7Q`28R8P0R8R80080R8R80P29RHT2
08Z:RP80Rh^;102<S8`808f=S@@0S8b<0P2;Rh/308Z:RP80RHV90P28R8P208N7Q`80QXJ60P25QHD2
08B4Q080PX:20P21PH4207moO`80OWin0P1lO7`207]kN`80NWYj0P1hN7P207MgM`0307IfMP1dM7@0
M7Ad0080Lg=c0P1aLG42071`L080Kfm_0P1^KVh206a/K080Jf][0P1ZJVX206UYJ@80J6QX0P1WIfL2
06IVIP80IFEU0P1TI6@00`1SHf<0HV9R069RHP02065QH@80H61P0P1OGel205iNGP80GEeM101LG5`2
05]KF`80FUYJ0P1IFET205QHF0@0EeMG0P1FEUH00`1EEED0E5AD05ADE00205ADE080De=C0P1BDU82
055AD@@0D51@5@3oool001<0oooo101@D504055AD@@0DU9B101CDe<305ADE0@0EEEE0P1FEUH405MG
E`@0F5QH0P1IFET205YJFP@0Fe]K0P1LG5`405eMG@0305iNGP1OGel0GemO0080H61P0P1QHF42069R
HP80Hf=S0P1TI6@206EUI@80IVIV0P1WIfL206UYJ@80JVYZ0P1[Jf/206a/K080KFe]0P1^KVh00`1_
Kfl0L71`071`L002079bLP80Lg=c0P1dM7@207EeM@80MWIf101gMgL207QhN0@0NGUi0P1jNWX207]k
N`80O7al0P1mOGd307inOP80Ogmo1020P8040861P@H0PX:20P23Ph<408:2PPH0PH6100<0P82007mo
O`1oOgl00P1nOWh407emO@80O7al0P1jNWX207UiN@80N7Qh0P1gMgL207IfMP80MGEe0P1dM7@2079b
LP80LG5a0P1`L7000`1_Kfl0KVi^06i^KP0206e]K@80K6a/0P1[Jf/206YZJP@0J6QX0P1WIfL206IV
IP@0I6AT0P1SHf<2069RHP80HF5Q0P1PH6000`1OGel0GUiN05iNGP0405eMG@80G5aL101KFe/205YJ
FP80FEUI101HF5P405MGE`80EUIF101EEED305ADE080De=C0P1BDU86055AD@80D51@5@3oool001<0
oooo101@D504055AD@@0DU9B101CDe<305ADE0@0EEEE0P1FEUH405MGE`@0F5QH0P1IFET205YJFP@0
Fe]K0P1LG5`405eMG@0305iNGP1OGel0GemO0080H61P0P1QHF42069RHP80Hf=S0P1TI6@206EUI@80
IVIV0P1WIfL206UYJ@80JVYZ0P1[Jf/206a/K080KFe]0P1^KVh00`1_Kfl0L71`071`L002079bLP80
Lg=c0P1dM7@207EeM@80MWIf101gMgL207QhN0@0NGUi0P1jNWX207]kN`80O7al0P1mOGd307inOP80
Ogmo1020P8040861P@H0PX:20P23Ph<408:2PPH0PH6100<0P82007moO`1oOgl00P1nOWh407emO@80
O7al0P1jNWX207UiN@80N7Qh0P1gMgL207IfMP80MGEe0P1dM7@2079bLP80LG5a0P1`L7000`1_Kfl0
KVi^06i^KP0206e]K@80K6a/0P1[Jf/206YZJP@0J6QX0P1WIfL206IVIP@0I6AT0P1SHf<2069RHP80
HF5Q0P1PH6000`1OGel0GUiN05iNGP0405eMG@80G5aL101KFe/205YJFP80FEUI101HF5P405MGE`80
EUIF101EEED305ADE080De=C0P1BDU86055AD@80D51@5@3oool001<0oooo1P1@D504055AD@H0DU9B
0`1CDe<405ADE0@0EEEE101FEUH405MGE`@0F5QH101IFET405YJFP0305]KF`1LG5`0G5aL00@0GEeM
0P1NGUh205mOG`80H61P0P1QHF42069RHP80Hf=S101TI6@206EUI@80IVIV0P1WIfL206QXJ00306UY
J@1ZJVX0JVYZ0080Jf][0P1/K6`206e]K@@0KVi^101_Kfl4071`L080LG5a101bLW8207=cL`<0M7Ad
0P1eMGD407IfMPH0MgMg3P1hN7P207MgM`<0MWIf101eMGD407AdM080Lg=c0P1bLW82075aL@80L71`
0P1_Kfl206i^KP@0KFe]0P1/K6`206][J`80JVYZ00<0JFUY06QXJ01XJ6P0101WIfL206IVIP80IFEU
0P1TI6@206=SH`80HV9R101QHF42061PH080GemO0P1NGUh205eMG@<0G5aL101KFe/405YJFP80FEUI
101HF5P205MGE`H0EUIF101EEED405ADE0<0De=C101BDU84055AD@80D51@0P1?CdlE0?ooo`004`3o
ool6051@D0@0DE5A1P1BDU8305=CD`@0E5AD101EEED405IFEP@0EeMG101HF5P405UIF@@0FUYJ00<0
Fe]K05aLG01LG5`0101MGEd205iNGP80GemO0P1PH602065QH@80HV9R0P1SHf<406ATI080IFEU0P1V
IVH206MWI`80J6QX00<0JFUY06YZJP1ZJVX00P1[Jf/206a/K080KFe]101^KVh406m_K`@0L71`0P1a
LG44079bLP80Lg=c0`1dM7@207EeM@@0MWIf1P1gMgL>07QhN080MgMg0`1fMWH407EeM@@0M7Ad0P1c
Lg<2079bLP80LG5a0P1`L70206m_K`80KVi^101]KFd206a/K080Jf][0P1ZJVX00`1YJFT0J6QX06QX
J00406MWI`80IVIV0P1UIFD206ATI080Hf=S0P1RHV84065QH@80H61P0P1OGel205iNGP80GEeM0`1L
G5`405]KF`@0FUYJ0P1IFET405QHF080EeMG1P1FEUH405EEE@@0E5AD0`1CDe<4059BDP@0DE5A0P1@
D50204m?CaD0oooo000C0?ooo`80Cdm?1P1@D506055AD@D0DU9B1P1CDe<605ADE0@0EEEE101FEUH6
05MGE`<0F5QH101IFET405YJFP80Fe]K101LG5`205eMG@@0GUiN0P1OGel2061PH0@0HF5Q0P1RHV80
0`1SHf<0I6AT06ATI00206ATI0@0IFEU101VIVH406MWI`H0J6QX0P1YJFT406YZJPD0Jf][101/K6`6
06e]K@X0KVi^1P1]KFd706a/K0@0Jf][0P1ZJVX206UYJ@@0J6QX101WIfL206IVIP80IFEU101TI6@3
06=SH`@0HV9R0P1QHF42061PH0@0GemO0P1NGUh605eMG@80G5aL0P1KFe/405YJFP<0FEUI101HF5P6
05MGE`@0EUIF101EEED605ADE0H0De=C1@1BDU86055AD@80D51@0P1?CdlE0?ooo`004`3oool204m?
C`H0D51@1P1ADE45059BDPH0De=C1P1DE5@405EEE@@0EUIF1P1GEeL305QHF0@0FEUI101JFUX205]K
F`@0G5aL0P1MGEd405iNGP80GemO0P1PH604065QH@80HV9R00<0Hf=S06ATI01TI6@00P1TI6@406EU
I@@0IVIV101WIfL606QXJ080JFUY101ZJVX506][J`@0K6a/1P1]KFd:06i^KPH0KFe]1`1/K6`406][
J`80JVYZ0P1YJFT406QXJ0@0IfMW0P1VIVH206EUI@@0I6AT0`1SHf<4069RHP80HF5Q0P1PH60405mO
G`80GUiN1P1MGEd205aLG080Fe]K101JFUX305UIF@@0F5QH1P1GEeL405IFEP@0EEEE1P1DE5@605=C
D`D0DU9B1P1ADE42051@D080Cdm?5@3oool001<0oooo0P1?Cdl:051@D0T0DE5A201BDU8605=CD`H0
E5AD2@1EEED405IFEP@0EeMG101HF5P605UIF@H0FUYJ101KFe/305aLG0@0GEeM1P1NGUh605mOG`H0
H61P1P1QHF45069RHPX0Hf=S1P1TI6@:06=SH`D0HV9R201QHF44061PH0@0GemO0P1NGUh605eMG@<0
G5aL201KFe/405YJFP@0FEUI101HF5P805MGE`<0EUIF1P1EEED605ADE0P0De=C201BDU85055AD@P0
D51@101?CdlE0?ooo`004`3oool204m?C`X0D51@2@1ADE48059BDPH0De=C1P1DE5@905EEE@@0EUIF
101GEeL405QHF0H0FEUI1P1JFUX405]KF`<0G5aL101MGEd605iNGPH0GemO1P1PH606065QH@D0HV9R
2P1SHf<606ATI0X0Hf=S1@1RHV88065QH@@0H61P101OGel205iNGPH0GEeM0`1LG5`805]KF`@0FUYJ
101IFET405QHF0P0EeMG0`1FEUH605EEE@H0E5AD201CDe<8059BDPD0DE5A201@D50404m?CaD0oooo
000C0?ooo`H0Cdm?4@1@D50<055AD@l0DU9B301CDe<:05ADE0H0EEEE1@1FEUH>05MGE``0F5QH3`1I
FET405YJFPl0FEUI3P1HF5P605MGE`P0EUIF2`1EEED805ADE0X0De=C3`1BDU8B055AD@T0D51@1P1?
CdlE0?ooo`004`3oool604m?Ca40D51@301ADE4?059BDP`0De=C2P1DE5@605EEE@D0EUIF3P1GEeL<
05QHF0l0FEUI101JFUX?05UIF@h0F5QH1P1GEeL805IFEP/0EEEE201DE5@:05=CD`l0DU9B4P1ADE49
051@D0H0Cdm?5@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3o
ool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3o
ool00?l0oooo8@3oool009P0oooo0T0000260?ooo`00VP3oool00d000000oooo0?ooo`230?ooo`00
NP3oool5@00000040?oood0000100000@00000<0oooo00=000000?ooo`3oool01@3oool3@0000080
oooo0T0000030?ooo`=000001@3oool00d000000oooo0?ooo`1m0?ooo`00O03oool01D000000oooo
0?ooo`3ooom0000000@0oooo00=000000?oood0000001@3oool01T000000oooo0?oood000000oooo
@00000@0oooo00A000000?ooo`3ooom00000Q@3oool007`0oooo00=000000?ooo`3oool00P3oool0
1d000000oooo0?ooo`3ooom000000?oood0000001@3oool01D000000oooo0?oood000000oooo00=0
00000P3oool014000000oooo0?oood0000250?ooo`00O03oool00d000000oooo0?ooo`020?ooo`07
@000003oool0oooo0?oood000000oooo@00000060?ooo`=0000000@0oooo@0000400001000000`3o
ool3@00008D0oooo001l0?ooo`07@000003oool0oooo0?oood000000oooo@00000020?ooo`03@000
003ooom0000000P0oooo00=000000?ooo`3oool0S@3oool007/0oooo0T0000040?ooo`03@000003o
ool0oooo0080oooo00=000000?ooo`3oool01P3oool2@00008l0oooo003o0?ooob40oooo003o0?oo
ob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?oo
ob40oooo003o0?ooob40oooo003o0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.0250052, -0.0250052, 
  0.00365857, 0.00365857}, {{6.8125, 280.125}, {280.125, 
  6.8125}} -> {-10.161, -6.11446, 0.516914, 0.516914}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0238095 0.952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0238095 0.97619 0.97619 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00751202 0.0192308 0.00751202 [
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(180) show
81.000000 12.812500 moveto
(deg) show
99.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(.) show
105.000000 12.812500 moveto
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
128 string
128 128 8 [128 0 0 128 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
6C6C6C6C6D6D6D6D6D6E6F707070706F70706F6F6F6F7073
6F6F706F6F6E6E6E6D6D6D6D6D6C6B6B6A6B6B6A6A6A6A6A
6A6969696969696969696969696A6A69696A6A6A6A6A6A69
69696969696969686868686767696B686868686868686767
676767676667676666666666676767686868696969696969
696A6B6868696A6B
6C6C6C6C6D6E6E6F6F707274757474747474737373727478
74737373737271706F6E6E6D6D6C6B6A6A69696969696868
696867676767676767676767676768676768686868686767
676767666666666565656463636569666464646464646363
636362626262626161616161626263646464656666666667
676868666567686A
6C6C6C6D6E6E6F707172747678787878787877777777777B
7A7677777675747371706F6E6D6C6B6A6868686868686767
676766656565656565656565656565656666666666666565
65646464636363626261616060606466636060606060605F
5E5E5E5D5D5D5D5D5C5C5C5D5D5E5F5F6060616263636464
646767656465676A
6C6D6D6E6F6F707172747577797B7C7C7C7C7B7B7B7B7B7C
807D7B7B7A7977757372706F6E6C6B6A6867676766666666
666666656464646464646363636363636363636363636363
626261616160605F5F5E5E5D5D5D5D5F62605C5D5C5C5C5B
5B5A5A59585858585757585858595A5B5B5C5C5E5F616161
6263656463646669
6C6D6E6E6F707172737576787A7C7D7F8080807F7F7F7F7F
8182807F7E7D7A787674716F6E6C6B696766656565646565
656565656463636362626262626261616161616061616060
5F5F5F5E5E5D5D5C5C5B5B5A5A5959595B5D5A5858585857
56555554545353535352525353545556565757595B5D5D5E
6060626261646769
6C6D6E6F70717273747577797A7C7E808283838383838282
8386858381807E7B787673716E6C6A686665646363626363
6364646464636262626161606060605F5F5F5F5E5E5E5D5D
5C5C5C5B5B5A5A5958585756565656555557585554545352
5251504F4F4E4E4E4E4D4D4E4E4F5050505152545658585A
5C5D606061636669
6C6D6F7071727374757678797B7D7F818385868786868686
868788878583817E7B7874716F6C6A676564636261606161
61626363646363626160605F5F5E5E5E5D5D5C5C5C5B5B5A
5959585857575655555454535352525151505253514F4F4E
4D4C4B4A4A49494948494848494A4A4B4B4C4D4F51555557
595B5D5D60636669
6C6D6E70717274757677797A7C7D7F818385878889898989
89898A8B898583817D7A76736F6D6A6765636261605F5E5F
5F606161626262616160605F5F5E5D5D5C5C5B5A5A595858
57565555545353525251504F4F4F4E4E4D4C4B4C4D4C4B49
484746454444444343434343444445464848494C4D505254
57595B5B5E626568
6D6E6F707173747577787A7B7D7E8081838587888A8A8B8B
8C8C8C8D8E8B8783807C7773706D6A67646261605F5D5C5C
5D5E5F5F606162616060605F5E5E5E5D5C5B5A5959585756
555453525251504F4F4E4D4D4C4C4B4A4A49474747484745
434241403F3F3F3E3E3E3E3E3F3F4143454546494C4E5052
5558595B5D616568
6D6E6F707273757677797A7C7D7F8082838587888A8B8C8C
8C8D8E8E8E8F8C86817E7974706C696562605E5D5D5C5B5B
5B5C5D5E5E5F6060605F5F5E5E5D5D5D5C5C5B5A5A595757
5554535251504F4E4E4D4C4B4A4949484746464544444444
43403C3C3B3B3A39393837383A3B3E40424345474A4C4E4F
5456575A5D616468
6D6E6F7172737577787A7B7D7E808183848688898A8B8C8D
8D8E8F8F8F908F8B847F7A746F6B6864625E5C5B5B5A5959
595A5B5C5D5E5E5F5F5E5E5D5D5D5C5C5C5B5A5959585756
55535251504E4D4C4B4A494848464645444342424140403F
3F403C3B393736353536373738393A3D3F404445474A4C4E
525557595D606468
6D6E6F7173747677797A7C7D7F808284858688898B8C8D8E
8F8F90909191928F89827C756E6965625F5C5A5958585857
5859595A5B5C5D5D5E5D5D5C5C5C5B5B5A5A595857565554
5352504F4D4C4B4A484746454443424141403F3E3D3D3C3B
3A3A383838373634343536363637373A3C3D424345494A4D
5153575A5D606468
6D6E707173747678797B7C7E7F8182848687898A8B8C8E8F
90919192929394918E877F796E66625F5C5A585756565656
565758595A5B5B5C5C5C5C5B5B5A5A5A5959585756555352
51504E4D4B4A48474544434241403F3E3E3C3B3A3A393837
363534333232343434343535353637393A3C41424448494C
4F5256595D606468
6D6E7072737476787A7B7D7E808283858688898B8C8D8E90
9192929394959694928D847D73685F5C5957555454545454
55565758595A5A5B5B5B5B5B5A5959585857575655545251
4F4E4D4B494846444341403F3E3D3C3B3B39383736353434
33323131313132333435343435353638393C3F414346494B
4E5155595D606468
6D6E7072737577787A7C7E7F8182848587888A8B8D8E8F91
929394959696979595918981786E60575553525151525252
535556575858595A5A5A5B5A5A595858575656555453514F
4E4C4B4947464442403E3D3C3B3A39383736353433323130
302F2F2F2F3031313234343434353537383B3E414446494B
4E5155595C606468
6D6F7072747577797B7C7E8081838586888A8B8D8E8F9092
939495969798999797958F857D73675951504E4E4E4F5051
52545556575859595A5A5A5959585857565555545352504E
4D4B4947454442403D3C3A3938373635343332312F2E2D2D
2D2C2C2C2D2F302F3032343434343436383B3D404346494B
4D5154585C606468
6D6F7173747678797B7D7E8082848587898A8C8E8F909293
94959698999A9A9A9997928981786D60534B4B4B4B4D4F50
5153545557585959595A5A59595958575555545352514F4E
4C4A48454342403E3B393836353433313131302F2E2D2B2B
2B2B2B2B2B2D2F2F3030313234353536383A3C3F4145484B
4E5155585D606468
6D6F71737577787A7C7E7F8183848687898B8D8E90919394
969798999A9B9B9C9A9A948D857C72675B4D4547494B4D4F
5153545657575959595A5959595858575554535251504F4D
4B49474442403E3C3A3836343331302F2E2E2E2D2C2B2A29
2A2A2A2A2B2B2D2D2E2F303132343536383A3C3F4144484B
4E5255595D616468
6D6F71737577797A7C7E8081838587898A8C8E8F91929495
97989A9B9C9D9E9E9D9D96908980766C61554843474A4D4F
51535456575859595A5A5A595958585756555452514F4E4C
4A484644413F3C3A38363432312F2E2D2C2B2C2B2B2A2928
29292829292A2B2B2D2F303132333436383A3C3E4144474B
4E5255595D606467
6E7071737577797B7D7F8182848688898B8D8F9192949596
989A9B9D9E9FA0A09F9E98928B837B71675B504547494C4F
51535557575859595A5A5A595958585756555452514F4E4C
4A484643403D3B39373533302F2D2C2B2A292A2A2B292A28
282727282828292A2B2D2E2F3032333537393C3E4144474B
4E5255595D606468
6E7072737577797B7D7F81838587898A8C8E909193959698
9A9B9D9E9FA1A1A2A19F9A958E867E756C61554945494D50
5254555758595A5A5A5B5B5A5959585756555453514F4D4C
4A484543403D3A373634322F2D2C2A29292829292A2A2929
2827272828272728292A2C2D2E30323436393B3E4144474B
4E5255595D606468
6E70727476787A7C7E80828486888A8B8D8F919294969899
9B9D9EA0A1A2A3A4A3A09B968F8881786F655A50474A4E50
53555758595A5B5B5B5B5B5B5A59585857565453514F4E4B
4A484543403D39363533302E2C2B29282727292928282827
252526262726262828292A2C2D2F313336383B3D4144474A
4E5255595D606468
6E70727476787A7C7E80828486888B8C8E9092949597999B
9C9EA0A2A3A4A5A6A4A29D979089837A71685E54494C4F52
5557585A5B5C5C5D5D5C5C5C5B5A59585756555352504E4C
4A484643403C393634322F2D2B2A29282727292929272726
2424242526262627272828292B2D2F3235373B3D4043474A
4E5255595D606468
6E70727576787A7C7F81838587898B8D8F91939597989A9C
9E9FA1A3A5A6A7A8A6A39F99938C847C736B61584C4F5154
57585A5C5D5E5E5E5E5E5D5D5C5B5A595857555453514F4D
4B484644403D393634312F2D2B2A28282626282929282726
242323232425252626272728292C2E313437393D4043464A
4E5255595D606468
6E70727577797B7D7F818385878A8C8E9092949698999B9D
9FA1A2A4A6A8A9AAA7A4A09A948E867E766D63594F525457
595B5D5E5F60606060605F5F5E5D5C5A595857555452504E
4C4A4745413D3A3734312F2C2B2928272525262829282625
232221212224252625262727272A2D303336393C4043464A
4E5255595D606468
6E70737577797B7D7F828486888A8D8F91939597999A9D9E
A0A2A4A6A8AAABAAA8A5A19B958F877F7870665C5155575A
5C5E5F616262636363636261605F5E5C5B5A59575553514F
4D4B4946423F3C3935322F2D2B2927252424252728282725
23222120202123242425262626292B2F3235383C3F43464A
4E5155595D606468
6E70737577797B7E80828486898B8D8F919496989A9C9EA0
A1A4A5A7A9ABADABA8A5A19B969088827B72685F55585A5D
5F61626465656667666665646362605F5D5C5A5957555351
4F4C4A4743413E3A3633302E2B2927252322232526272726
24211F1F1F2021232323232425282A2D3135383B3F42464A
4E5155595D616468
6E707375777A7C7E80838587898C8E90929496989A9D9FA1
A3A5A7A9ABADAEACAAA6A29C97918A847D736A62585C5D60
626466676869696A6A696968676563615F5E5C5B59575553
504E4C4945423F3B3835322F2B2927252422222325272827
24221F1E1E1E2021212121222427292D3033373B3F42464A
4D5155595D606468
6E707375787A7C7E818386888A8C8F919395989A9C9EA0A2
A4A6A8AAACAEAEADAAA7A29C98928C857F766D655C5F6264
66686A6B6C6D6E6E6E6E6D6C6B69686563615F5E5C5A5855
53504E4B4945413D3A36332F2B2726252422212122242628
2622201E1D1D1E1F202020202326292C3033373A3E424549
4D5155595D606468
6E717376787A7D7F818486898B8D8F929496999A9D9FA1A3
A5A8AAACAEAFAFADAAA7A39D98928E878179716960646668
6B6D6E7071727272737372706F6D6C6A676563615F5D5B58
5653504D4C48433F3C3733302C2826252322201F20232426
2523211E1D1C1D1E1F1E1F202225282B2F33363A3E424549
4D5155595D606468
6E717376787B7D7F828487898C8E91939597999B9EA0A3A5
A7A9ABADAFB0AFAEAAA7A39E99948F89837C756D65696B6E
7072737475767777787877767573716F6C6A676563605E5C
5956534F4E4A45423E3935312E2926262422201E1F212324
2422201D1C1C1D1D1E1E1E1F2125282B2F32363A3E424549
4D5155595C606468
6E717376787B7E808385878A8C8F919496989B9D9FA1A4A6
A8AAACAFB1B1B0AEAAA7A39E9B95918A857F78726C6E7173
75767879797A7B7B7C7D7D7D7B797774726F6C6A67656260
5D595552514D4845413C37322F2A27262422201D1D1F2224
2422201D1A1B1C1C1C1C1D1E2124282B2E32363A3D414549
4D5054585C606468
6E717376797B7E808386888B8D90929597999C9EA0A2A5A7
A9ABAEB0B1B1B0AEAAA7A29E9B96928B87827C7673747577
78797A7B7C7D7E7E7F80808181807E7B787673706D696764
615D595453504C4A453F3933312B28262523201D1C1D2022
2322201D1A191A1A1A1B1B1C2023262A2E3235393D414549
4C5054585C606468
6E717476797C7E818386898B8E909395989A9D9FA1A4A6A8
ABADAFB2B2B1B0ADAAA7A39F9A97928C8884807C79797979
7A7B7C7D7E7F80808182838384848482807C7975726F6B68
65615C5653524E4E48423A34322E29272623211E1C1C1E20
22221F1C19181819191A1A1C1F22262A2D3235393D414549
4C5054585C606468
6E7174777A7C7F828487898C8F919496999B9EA0A2A5A8AA
ACAEB0B2B3B1B0ADA9A5A29E9A97918D898684807D7C7C7C
7C7D7E7E7F7F808182838585868687878684807C7875716D
6965605A54544F514D463F3632312B282723211E1B1B1B1E
21221F1B191817171818181B1F2226292D3135393D414549
4D5054585C606468
6E7174777A7C7F8285888A8D909295979A9C9FA1A4A6A8AB
ADAFB1B2B3B1AFADA9A5A19E9B96918D89858482807F7E7E
7E7E7F7F80808181828485868788898A8A8987847F7B7773
6E69645D555652525049423A35332E2A2724201E1B1A1A1B
1F211F1B181615161717171A1E2225292D3135393D414548
4C5054585C606467
6E7174777A7D808385888B8E919396989B9DA0A2A5A7A9AC
AEB0B2B3B3B1AFACA8A4A09D9A95918E8A88868583818080
7F7F7F7F808080818284858688898A8B8C8D8C8B87827E79
736E676056545451524D463D37322F2B2825211E1B191919
1D201F1B181614131516171A1D2125282D3135393D414448
4C5054585C606468
6F7175777A7D818386898C8F929497999C9FA1A3A6A9ABAD
AFB1B2B4B2B0ADABA8A3A09C9994918E8C8A888785848281
8080807F8080808081838486888A8B8D8E8F8F8F8E8A857F
79736C63595354504F4D48413B34302D2825211D1B181918
1A1E1F1B171514121315171A1D2125282C3034383D414448
4C5054585C606468
6F7275787B7E8184878A8C8F9295989B9DA0A2A4A7A9ACAF
B0B2B3B3B2AFACA9A6A29F9B9793908F8E8C8B8988868583
828181808081808081828386888A8C8E8F91919191908D87
807871675C5451514D4C48433D36312F2A26221E1B191717
181B1D1B181613111213161A1D2024282C3034383C404548
4C5054585C606468
6F7275787B7E8184888B8E909396999C9EA1A3A6A8ABADB0
B1B2B4B3B1AEACA8A4A19E9A969391908F8E8D8C8A898786
858484838383828282828385878A8D8F919393949392918D
867E756B5F56504F4B4746434039332F2C28231F1A181616
16171B1A17151311111116191D2024282C3034383C404548
4C5054585C606468
6F7275787B7F8285888B8E9194979A9DA0A2A5A7A9ACAEB0
B2B3B3B2B0ACA9A7A29F9C98948F91919190908F8E8C8988
888888878787868484838385888A8D909394959696959492
8E857B7063584F4D4C4643413E3B36302C29241F1A171514
1415181816141110101114181C2024282C3034383C404548
4C5054585C606468
6F7275797C7F8285898C8F9295989B9EA1A4A6A9ABADB0B2
B2B3B2B1AEABA7A5A19E9A96939292939393939391908F8E
8F8E8D8C8C8C8B8A89888786888B8E919496979898989795
938D8276685B514949463F3E3A3836322E2A25201B171513
121215161412100E0E1215181C1F24282C3034383C404448
4C5054585C606468
6F7276797C808386898D909396999C9FA2A5A7AAADAFB1B2
B2B2B1B0ADA8A5A29F9A9794919394949596979896959391
909190908F8F8E8D8C8D8C8A898D90939698999A9A9A9997
95918A7C6E5F554A46443E3B383434332E2A26211B171412
1010121514110F0D0D1114181C1F23282C3034383C404448
4C5054585C606468
6F7276797D8083878A8D9194979A9DA1A4A6A9ABAEB0B3B4
B4B3B1AEABA7A4A09C9995929293949697999A9C9B999897
9796969796959493919091908E8E919597999A9C9C9B9A99
97938E837464574B45423E3735302E302F2B26211C171411
0E0E101313110F0D0C1014171B1F23282C3034383C404448
4C5054585C606468
6F7276797D8184888B8E9295999C9FA2A5A8AAADAFB2B4B5
B5B2B0ADA9A5A19E9A96929192939597999D9FA3A3A2A1A0
A09F9FA0A09F9E9C9B9A9B9A989796989A9B9C9D9E9D9C9A
999591897A695A4F46403E37322E292A2C2B26221D181411
0D0C0D0F110E0E0C0D1013171B1F23282C3034383C404448
4C5054585C606468
6F73767A7E8185888C8F93969A9DA0A4A7A9ACAFB1B4B5B6
B5B2AFACA7A39F9A96928D90919395989A9DA0A4A7A8A8A7
A7A7A6A6A6A6A4A3A19E9D9D9B9B9A9B9C9D9E9E9F9E9D9B
9997938C80705F5348403C38302C2625262926221E181410
0C0B0A0D0F0D0C090C1013171B1F24282C3034383D404448
4C5054585C606468
6F73777A7E8285898D9094979B9EA2A5A8ABAEB1B3B5B6B6
B5B2AEAAA6A19C97938E8D8F919395989A9D9FA2A4A6A7A7
A6A7A6A5A4A4A3A2A09F9E9D9D9D9D9D9E9FA0A0A09F9E9D
9A97948E847563574C443D39302A2622222424221E19140F
0B09080B0D0C0B080C1013171B1F24282C3034383C404549
4D5054585C606468
6F73777B7E82868A8D9195999CA0A3A7AAADB0B3B6B8B8B7
B5B2AEA9A49F9A958F898B8E909395989A9D9FA1A3A4A5A6
A6A6A5A4A4A3A2A1A09F9E9E9E9E9FA0A0A1A1A2A1A1A09E
9C999691887A68594E453D38322A241F1E1F20201D191510
0D0907080B0B0A080B1013161B1F24282C3035393D414549
4D5054585C606468
7073777B7F83878B8E92969A9EA1A5A8ACAFB2B5B7B9BAB8
B5B1ADA8A39D97928D868A8D8F9295979A9C9EA0A2A3A4A5
A5A5A4A3A3A2A1A09F9E9E9E9F9FA0A2A3A3A3A3A3A2A19F
9D9A96928A7D6E5D52484039332B241D1B1B1D1E1C18150F
0D0907070A0A09090B0F13171B2024282D3135393D414549
4D5055585C606468
7074787C8084888B8F93979B9FA3A6AAADB1B5B8BABBBAB8
B4B1ACA7A19C95908A86898C8F929497999C9E9FA1A3A4A4
A5A5A4A3A2A1A09F9E9E9E9E9FA0A1A2A3A4A5A5A4A4A3A1
9F9C98938D827262544A413A332D251D1919191A1B18150F
0B080606080A080A0B0F13171B2024292D3135393D414549
4D5155585C606468
7074787C8084888C9094989CA0A4A8ACB0B3B7BABDBDBBB8
B4AFABA59F99948E8687898C8F919497999B9D9FA1A3A4A5
A6A7A7A5A3A2A09F9E9D9E9E9FA0A2A3A5A5A6A6A6A5A4A2
A09E9A958F857665574C423C342F2720171616181A171510
0B0705040709080A0B0E12171C2025292D3135393D414549
4D5155595C606468
7074787C8185898D9195999DA1A5A9ADB1B5B9BDBFBFBCB8
B4AFA9A49E98928B8387898C8E919496999B9D9FA1A3A3A4
A7A9A9A8A4A2A1A09E9D9E9EA0A1A2A4A5A6A6A7A7A6A5A4
A29F9C9791897C6A5B4F453D353029211915151517171410
0A070403050709080C0F13181C2125292E31363A3E424649
4D5155595C606468
7074787D81858A8E92969A9EA3A7ABAFB3B7BBBFC2C0BDB9
B4AFA9A39D9790898387898C8F929496999B9D9FA1A5A7A6
A8AAABACAAA7A5A4A19E9E9EA0A1A3A4A5A6A7A8A8A7A6A5
A3A09D99948C816F6052484038302B221B13141415171411
0B070402030508080C1014181D21252A2E32363A3E42464A
4D5155595C606468
7074797D82868A8F93989CA0A4A8ADB1B5B9BDC2C4C1BDB8
B3AEA9A29C968F8884878A8C8F919496999B9D9FA0A3A5A7
A8AAABABAAA7A5A4A3A19F9FA0A2A3A4A6A6A7A8A8A8A7A7
A5A29F9B958F867465564C423B322D251F14141415171411
0C0704020205080A0C1015191D22262A2E32363A3E42464A
4E5155595D606468
7075797E82878B9094999DA1A6AAAEB3B7BBC0C4C6C2BDB9
B3ADA8A29C958D8686888B8D8F919496989A9D9EA0A2A4A6
A8A9AAABA9A7A6A4A3A1A0A0A1A2A3A4A5A6A7A8A8A8A8A7
A6A4A19D9891897A695A4F443E352F272017141314171511
0D0703010205070A0D11161A1E22262B2F33373B3F42464A
4E5255595D606468
7075797E83878C91959A9EA2A7ACB0B4B9BDC2C6C6C2BDB7
B2ADA7A19B948C8387898B8D8F919395989A9C9E9FA1A3A4
A7A9AAAAA9A7A6A4A3A2A1A1A1A2A3A4A5A6A7A8A8A8A8A7
A7A5A29F9A948C806E5E5348403831292119151414161611
0D070401020506090E12161A1F23272B2F33373B3F43464A
4E5256595D616468
7075797E83888D92969BA0A4A9ADB2B6BBBFC4C9C7C2BEB7
B3ADA7A19A938D85888A8C8E9091939597999B9D9FA0A2A4
A6A8A9A9A9A7A6A5A3A2A1A1A1A1A2A4A4A5A6A7A8A8A8A7
A6A5A4A09B958E837263554B423A332C241B171514151712
0D0703000206070B0F13171C2024282C3034383B3F43474B
4E5256595D616468
70757A7F84898D92979CA1A5AAAFB3B8BDC1C6CBC8C3BDB7
B2ACA7A29A948E8A8A8B8D8F9091939596989A9C9EA0A1A3
A6A8A9A9A9A7A6A4A3A1A1A1A1A1A2A3A4A4A5A6A7A7A7A7
A6A5A3A19D968F877666594D443C332D251D181615151712
0E0703000205070B1014181C2025292D3034383C4044474B
4F52565A5D616468
70757A7F84898E93989DA2A7ABB0B5BABFC3C8CBC8C3BCB7
B2ACA6A09A93908D8D8D8E8F909292939597999B9D9FA1A2
A5A7A9AAA9A7A5A4A2A1A0A0A1A1A1A2A2A3A4A5A5A6A6A6
A6A5A3A19E9890887B6B5D51463E352E261E191715141713
0E0703000105080C1115191D2125292D3135393C4044484B
4F52565A5D616568
70757B7F858A8F94999EA3A8ADB2B7BCC1C6CBCAC7C2BBB6
B1ABA7A0998F8F8E8E8E8F8F90919293949697999B9DA0A1
A4A7A9A9A8A6A5A4A2A0A09F9FA0A0A0A1A1A2A3A3A4A5A5
A5A4A2A09E9891887C6D5F52483F362F271F1A1816141613
0F0703000104090D11161A1E22262A2E32363A3D4144484C
4F53565A5D616568
71767B80858A90959A9FA4AAAFB3B9BEC3C8CFCCC8C2BBB6
B0AAA59E9791908F8F8F8F9090919192939495989A9C9EA0
A3A5A8A9A8A6A4A3A1A09F9E9E9E9E9F9F9F9FA0A1A1A2A3
A3A2A19F9D9892897D6F6154493F372F261F1B1916151514
0F0803000005090E12171B1F23272B2F33363A3E4145494C
5053575A5E616568
71767B81868B90969BA0A6ABB0B5BAC0C5CACFCCC8C2BBB4
AFA9A29D9693919090908F909090919191929395989A9D9F
A2A5A8AAA9A7A4A3A19F9E9E9D9D9D9D9D9D9D9D9E9E9FA0
A1A1A09E9C99928A7F716355493F372F261D1C1917151314
0D08040101050A0F13181C2024282C3033373B3E4245494C
5054575A5E616568
71767C81878C91979CA1A7ACB1B7BCC1C6CBCECAC7C1BBB4
AEA7A0999593929191909090909090909090919395989B9E
A1A4A7AAAAA8A5A3A19F9E9D9D9C9C9B9A9A9A9A9B9B9D9E
9E9F9E9D9B98928A807364574A403830271E1C1917151114
0C08050202070C1014191D2125292D3034383C3F43464A4D
5054575B5E616568
71777C82878D92989DA3A8ADB3B8BEC3C8CECDCBC6BFBAB3
ADA59E95949391919191919090908F8F8E8E8F9193969A9D
A0A4A7AAAAA9A7A4A2A09E9D9D9C9B99989797979798999B
9C9C9C9B9A96928A807566584B403830281F1D1A17161014
0D07050404090D12161A1E22262A2E3135393C4043474A4D
5154585B5E626568
71777D82888E93999EA4A9AFB4BABFC5CAD1CBCAC5BEB8B2
ABA29C969492919292929291908F8E8E8D8C8C8E9194989C
9FA4A7ABACABA8A6A3A19F9E9D9C9B989695949393949697
999A9A9A9895908A817769594C413830281F1D1B17171014
0E070504060A0F13171B1F23272B2F3236393D4044474B4E
5154585B5E626568
71777D83898E949A9FA5ABB0B6BCC1C7CCD3CCC9C2BCB6B0
A8A098979391929393939392918F8E8D8C8B8B8C8F93989B
9FA4A8ACAEADABA8A6A3A09F9E9D9C999594939291919395
9697989897948F8981776B5D4E41383029211D1C19171114
0E070605070C1115191D2125282C3033373A3E4145484B4E
5255585B5F626568
71777D83898F959BA0A6ACB2B7BDC3C8CDD0CDC9C1BBB4AF
A59E99989492929494959493919293908C8B8A8C8D91979B
A0A5A9ADB0B1AFACA8A6A19FA0A1A09C97959392908F9193
9596969695938E8880776B5F4F42393029221F1D19171114
0F090807090E12161A1E22262A2D3134383B3F4245484C4F
5255595C5F626568
72787E848A90969CA2A8ADB3B9BFC4CAD1D1CEC9C2B9B2AD
A2989997959294959697979694959795928E8D8E9092979C
A1A6ABAFB2B4B3B1ADADAAA4A5A6A4A19C99969692909093
9495969594928E8780766B5F50433A312923201D1A181214
0D0A09080C1014181C2024272B2E3235393C3F4346494C4F
5356595C5F626568
72787E848A91979DA3A9AFB5BBC0C6CBD2D3CEC8C1B8B1AB
A3989896949394979A9B9C9995969B99999292909395999E
A3A8ADB1B4B7B8B6B4B0AFAAA7ACA8A79F9E9A9B96939393
9495969593918D8780776D6152443A322A24201E1B181315
0D0A0A0A0E12161A1E2225292C3033363A3D4044474A4D50
5356595C5F626569
72787E858B91979EA4AAB0B6BCC2C8CCCDD2CFC9C1B8B0A8
A0989896949396999DA0A2A19D9C9C9A9D9A9A98999B9DA1
A5AAAFB3B6B9BCBCBAB7B3B1AEB1ACADA7A4A0A09D9A9897
9696969694918D8780786F6355483C332A26221E1A181516
0F0C0B0D1115181C2023272A2E3134383B3E4144474B4E51
54575A5D60636669
72787F858C92989FA5ABB2B8BEC4CBD1CFD0CEC7BFB8AFA6
9D9897959393979BA0A5A9A9A7A7A7A5A3A1A09F9FA0A2A4
A8ACB0B5B8BCBEBFBFBDBBB7B5B8B8B6B2ADAAA7A5A29F9D
9B99989795928E8780786F64564A3F342C2724201B191617
110E0D1013171B1E2225282C2F3236393C3F4245484B4E51
54575A5D60636669
72797F868C9399A0A6ADB3BAC0C6CDD5D5D0CDC6BEB6AFA5
9D9896949293979BA0A5AAADAFAFAFADABA8A5A2A2A3A5A8
ABAEB2B6BABDC0C1C1C0BEBDBBBBBBBBB9B7B3AFABA8A5A2
9E9C9A9896938F8881786E63574B41362C2825211B191718
120F101316191D2024272A2D3134373A3D404346494C4F52
55585A5D60636669
727980868D939AA1A8AEB5BBC2C8CFD5D9D2CDC6BEB7B0A5
9D9895949292969A9EA3A7AAACAEAEABA9A7A5A4A6A6A8AA
ADB0B3B7BABEC2C4C4C3C0BDBBBBBCBCBAB8B4B1ADAAA7A4
A19E9C9A97938F8981796F64574B41372E2826211B191718
130F1215181C1F2225292C2F3235383B3E4144474A4D5052
55585B5E60636669
727980878D949BA2A9B0B7BDC4CAD0D5DDD4CFC8C0B8B1A7
9F999593919296999CA0A4A7A9ABABACABABABA9A9A9AAAC
AEB1B4B7BABEC2C5C8C9C6C2BEBAB9B9B7B6B3B1ADABA8A6
A3A09E9C9995908A82797064594D4238312B27221C1A1717
131114181B1E2124272B2E3134373A3C3F4245484B4D5053
56595B5E61636669
727980878E959CA3AAB1B8BFC6CDD3D5DED7D1CBC3BAB3A9
A19A95939192969A9B9EA1A4A7AAACAEB0AEACABABABACAE
AFB2B4B7BABDC1C4C7CACCCAC7C2BDB9B7B4B2B0ADABA9A7
A6A3A19E9B96918B847C70665A4E4137312C28241E1B1916
1313171A1D202326292C2F3235383B3E414346494B4E5154
56595C5E61646669
737A81888F969DA4ABB2BAC1C8D0D8D8DBD8D3CDC7BDB5AC
A49E98949192969C9FA2A4A7AAACADADADADACABABACADAE
B0B2B4B7BABCBFC2C5C7C9C9C9C7C5C2C0BBB7B4B2AFAEAB
A8A5A3A09C98928D847C71665A4E4237332E2926201D1B17
14161A1D202326292C2E3134373A3C3F4245474A4C4F5254
575A5C5F61646669
737A81888F969EA5ACB4BBC3CBD3DCDFDDD9D3D0C9C1B8AF
A8A09A969292969A9EA2A6A8AAAAAAABABABABABABACADAE
B0B2B4B6B8BBBDC0C2C4C5C6C6C5C3C1C1BFBDBAB7B3B0AE
AAA7A4A19D98938E877D72665B4F433835302A28211E1E18
16191C1F2225282B2E303336383B3E404346484B4D505255
575A5D5F62646769
737A818890979EA6ADB5BDC5CDD6DFE3DFDBD4D1CBC3BBB2
AAA39C97929295999C9FA3A5A7A8A8A9A9AAAAAAABACADAE
B0B1B3B5B7B9BBBDBFC1C2C3C2C2C1C0BFBDBCB9B7B4B1AF
ABA9A6A39F99948E877F74695D50443837322B2A241F1F1A
191D1F2225282A2D303235383A3D3F424447494C4E515356
585B5D5F62646769
737A818990979FA7AEB6BEC7CFD9E3E8E2DDD6D2CCC6BEB5
ADA59E99949295989B9DA0A3A4A5A7A8A8A9A9AAAAABACAD
AFB1B2B4B6B7B9BBBCBEBFC0C0C0BFBEBDBCBAB9B7B5B2AF
ADAAA7A39F9A948E877E74695D4F433736332D2C2721201B
1D202325282A2D2F323437393C3E414346484A4D4F525456
595B5D6062646769
737A828990989FA7AFB7BFC8D1DAE4ECE5DFD8D3CEC7C0B8
B0A8A09B979495979A9C9FA1A3A4A5A6A7A8A8A9A9AAABAD
AEAFB1B2B4B6B7B9BABBBCBDBDBDBDBCBBBAB9B8B6B4B2B0
ADAAA7A4A09A958E877E74695D50433835342F2E2A24211E
212326282A2D2F323436393B3D40424447494B4E50525557
595C5E6062656769
737A82899198A0A8B0B8C0C9D2DBE5EEE9E3DDD7D0CAC3BB
B2ABA39D99959697999C9EA0A1A3A4A5A6A6A7A8A9AAABAB
ADAEB0B1B2B4B5B7B8B9BABBBBBBBBBBBAB9B8B7B6B4B2B0
AEABA8A4A09B958F887E74695D51443934332E2E2C292322
2427292B2D2F323436383B3D3F414446484A4D4F51535558
5A5C5E6063656769
737A82899198A0A8B0B8C1C9D3DCE6F1ECE6E0DAD3CCC5BD
B5ADA59F9B979798999B9D9FA0A1A3A4A5A6A6A8A8A9AAAB
ACADAEB0B1B2B3B5B6B7B8B9B9B9B9B9B9B8B7B6B4B3B1AF
ADABA8A49F9B958F887E75695D51453B35332F2F2D2C2627
282A2C2E30323436383A3C3F41434547494B4E5052545658
5A5D5F6163656769
737A82899198A0A8B0B8C1CAD3DCE6F1EFEBE4DDD6CFC7BF
B7AEA7A19D9998999A9B9D9EA0A1A2A3A4A5A6A7A8A8A9AA
ABACADAEAFB0B2B3B4B5B6B6B7B7B7B7B7B6B5B4B3B2B1AF
AEAAA8A4A09B958F877F75695D52453E38332F2E2D2C2A2A
2C2D2F31333436383A3C3E40424446494B4D4F5153555759
5B5D5F6163656769
737A82899198A0A8B0B8C1CAD3DCE7F3F4EEE8E0D9D2CAC1
BAB1A9A4A09C9A9A9B9C9D9E9FA0A2A3A3A4A5A6A7A7A8A9
AAABACADAEAFB0B1B2B3B3B4B5B5B5B5B5B5B4B3B2B1B0AF
ADAAA8A4A09B9690877F756A5D5245403A36302F2E2C2D2E
2F3032333537393B3C3E40424446484A4C4E50525456585A
5C5E60626466686A
737A82899198A0A8B0B8C0C9D2DCE6F0F7F3ECE5DDD6CDC4
BCB4ACA6A19E9C9B9C9C9D9E9FA0A1A2A3A4A5A6A6A7A7A8
A9AAAAABACADAEAFAFB0B1B2B2B3B3B3B3B3B3B2B1B0AEAD
ACAAA7A4A09B958F877E756A5D5246423C3731302F2E2F31
3233353638393B3D3E4042444648494B4D4F51535557585A
5C5E60626466686A
737A82899098A0A7AFB7C0C8D1DBE4EEF9F9F2EAE2DAD2C8
BFB6AEA8A3A09E9D9D9D9E9F9FA0A1A2A3A3A4A5A5A6A6A7
A7A8A9A9AAABACACAEAEAFAFB0B0B1B1B1B1B1B1B0AFADAC
ABA9A7A39F9B9690887F756B5F5347433F39333131313233
353637393A3C3D3F4142444647494B4D4E5052545657595B
5D5F60626466686A
737A818990989FA7AFB7BFC7D0D9E2ECF7FCF7EFE8DFD6CD
C3B9B1AAA6A2A09F9E9E9E9FA0A0A1A1A2A3A3A4A4A5A5A6
A6A7A7A8A8A9A9AAABABACADADAEAEAEAFAFAFAFAEADACAB
AAA8A5A39F9A95908880756B60544743413A363332343536
38393A3B3D3E404143444647494B4C4E5051535556585A5C
5D5F61636466686A
737A818890979FA6AEB6BEC6CED7E0EAF3FDFCF6EEE5DCD1
C7BDB3ACA7A4A2A0A0A09FA0A0A0A1A1A2A2A3A3A4A4A4A5
A5A5A6A6A6A7A7A8A9A9AAAAABABABACACACACACACABABAA
A9A7A4A29E9A958F8880766B61564A45413B373535373839
3A3B3D3E3F404243454647494A4C4E4F5152545657595B5C
5E6061636566686A
737A81888F979EA5ADB5BDC5CDD5DEE7F0FBFFFDF5EBE1D7
CBC0B7AFA9A5A3A2A1A0A0A0A0A1A1A1A1A2A2A3A3A3A4A4
A4A4A4A4A4A5A5A6A6A7A7A8A8A9A9A9AAAAAAAAAAAAA9A8
A7A5A3A09D99948F8880776C62584E49443E3937393A3B3C
3D3E3F40424344454748494B4C4E4F5052545557585A5B5D
5F6062636567686A
737A80888F969DA4ACB3BBC3CBD3DBE3ECF4FBFFFBF0E5DA
CFC4BAB2ACA7A5A4A3A2A1A1A1A1A1A1A2A2A2A2A2A3A3A3
A3A3A3A3A3A3A3A3A4A4A4A5A6A6A7A7A7A7A8A8A8A8A7A6
A6A4A29F9C98948E8880776E6459524C45403C3B3C3D3E3F
4041424344454647484A4B4C4E4F505253555658595B5C5E
5F6162646567686A
727980878E959CA3ABB2BAC1C9D0D8E0E7EEF5FAFDF5E9DE
D3C8BEB5AFAAA7A5A4A3A2A2A2A2A2A2A2A2A2A2A2A2A2A2
A1A1A1A1A1A1A1A1A1A2A2A2A3A3A4A5A5A5A5A5A5A6A5A5
A4A2A19E9B97938F8880786F655D564F4843403F40404142
43444445464748494A4B4D4E4F505253545657595A5B5D5E
606163646667696A
727980878D949BA2A9B1B8BFC6CED5DDE4EAF1F6FBF9EBE1
D7CCC2B9B2ADAAA8A6A5A4A3A3A3A3A2A2A2A2A2A1A1A1A1
A1A0A09F9F9F9E9F9F9F9FA0A0A1A1A2A2A2A2A3A3A3A2A2
A2A19F9D9A96918E89807870655E59524B46434343444445
4646474848494A4B4C4D4E4F51525354565758595B5C5E5F
606263646667696A
72797F868D949AA1A8AFB6BDC4CBD2DAE0E7EDF3F9FAF0E4
DACFC6BDB6B0ACAAA8A7A6A5A4A4A4A3A3A2A2A1A1A1A0A0
A09F9E9E9D9C9C9D9D9D9D9D9D9E9E9E9F9FA0A0A1A1A0A0
A09F9E9B9895908C8882797067615B554F4A464747474748
4849494A4B4B4C4D4E4F5051525354555758595A5C5D5E60
616263656667696A
72797F868C9399A0A7ADB4BBC2C9D0D7DDE4EBF1F9FAF5E9
DED3C9C0B9B3AFACAAA9A8A6A6A5A5A4A3A3A2A1A1A1A0A0
9F9F9E9D9C9B9A9B9B9A9A9A9A9B9C9C9C9D9D9E9E9F9F9F
9F9E9D9A97938F8B8680787369625C57514D4B4A4A4A4A4B
4B4B4C4C4D4D4E4F505152525354555758595A5B5C5E5F60
616364656668696A
72787F858B92989FA5ACB2B9C0C6CDD4DAE1E8EFF7FAF9ED
E3D9CEC5BDB7B3AFADABAAA8A8A7A6A6A5A4A3A2A1A1A0A0
9F9E9E9C9B9A999999999898989999999A9A9B9B9C9D9D9D
9D9C9B9996938F8B857F77726A645D59544F4E4E4D4D4D4D
4D4E4E4E4F4F50515252535455565758595A5B5C5D5E6061
626364656768696A
72787E848B91979DA4AAB0B7BDC4CAD1D7DEE5ECF4F9FCF4
E9E0D5CBC2BBB6B2B0AEADABAAAAA9A7A6A5A4A2A2A1A0A0
9F9F9E9D9B9A99989898989897979797989899999A9B9B9B
9A9A9A9894928D88837D76716A645E5A5653525150505050
505050515151525353545556565758595A5B5C5D5E5F6061
626365666768696A
72787E848A90969CA2A8AFB5BBC1C8CED4DBE1E8F0F8FCF9
F1E6DCD2C9C1BAB5B3B2B0AFADACABA9A8A7A5A4A3A2A3A2
A1A09F9E9D9B9A9A99999998989797989798989898999A9A
9A99989692908D87807B77716B65605B5756555453535252
5252525353535454555556575858595A5B5C5D5E5F606162
636465666768696A
71777D83898F959BA1A7ADB3B9BFC5CBD1D8DEE4EBF2F9FB
F8EEE3D8CFC8C0BBB7B5B4B2B1AFAEACABA9A8A7A5A4A4A4
A3A2A2A09F9E9D9C9C9B9B9A9A9A99999898989998979797
97969694918D8A87817B76716C66615C5A59585756555555
54545455555555565657585859595A5B5C5C5E5F60606162
636465666768696B
71777D82888E94999FA5AAB0B6BCC2C8CED4DAE0E7ECF2F6
F9F2EADFD6CFC7C1BBB9B6B5B4B3B1B0AEADABA9A8A8A7A6
A6A6A5A4A2A1A1A09F9F9F9F9D9C9C9B9B9A9A9A9A989796
96959492908D8985807B76716B66625E5C5B5A5959585757
5756565657575757585859595A5B5B5C5D5E5E5F60616263
6465666768696A6B
71777C81878D92989EA3A9AEB4BABFC5CBD1D7DCE2E8EDF2
F7F7EEE5DBD2CBC5C0BDBBBAB8B6B5B3B2B0AFADACABAAAA
AAA9A9A7A6A5A3A2A2A2A1A1A19F9F9D9C9B9A9A9A999796
959392918E8B8884807B75706B6661605F5D5C5B5B5A5959
5958585858595959595A5A5B5B5C5C5D5E5F5F6061626363
6465666768696A6B
71767C81868C91969CA1A7ACB2B7BDC2C8CDD3D8DEE3E8ED
F1F7F4EBE2D8D1CBC6C2C0BFBDBBB9B7B6B4B4B2B0AFAEAE
AEADADACABABA8A6A6A5A5A5A4A2A1A09F9C9B9B9B9A9998
979594928F8C88857F7A756E6A66636261605F5E5D5C5B5B
5B5A5A5A5A5A5A5A5B5B5B5C5C5D5D5E5F5F606162626364
6566666768696A6B
71767B80858B90959A9FA5AAAFB5BABFC4CACFD4DADFE4E8
EDF1F4EFE6DCD5CEC8C6C4C3C3C0BDBBBAB8B7B6B4B4B3B2
B2B2B1B1B0AFB0ACABAAA9A8A8A7A5A4A3A19F9E9D9C9A99
97959493908C87837F7A766F6C666564636261605F5E5D5D
5C5C5C5C5C5C5C5C5C5C5D5D5D5E5E5F6060616262636464
6566676868696A6B
71767B8085898F94999EA3A8ADB2B7BCC1C6CBD0D5DADFE4
E9EDF3F4EBE4DDD4CECAC8C8C7C6C2C0BEBDBCBBB9B8B8B6
B7B7B5B4B5B4B4B3B0B0AFAEAEADABAAA8A6A3A1A09E9C9B
999795928F8A87827C7975716E6A68666564636261605F5F
5E5E5D5D5D5D5D5D5D5E5E5E5F5F5F606061626263646465
6666676869696A6B
70757A7F84888D92979CA1A5AAAFB4B9BEC3C8CDD1D6DBE0
E4E9EEF5F3E9E0DAD4CFCCCCCCCCC7C5C2C1C1C0BDBDBCBA
BBBABBB9BABAB9B8B6B7B5B4B4B3B1AFADABA8A5A3A19F9E
9B9896938F8B86837E7975716F6D6B696766656463626160
605F5F5F5E5E5E5E5F5F5F5F606060616162626364646565
6667676869696A6B
7075797E83878C91959A9FA3A8ADB1B6BBBFC4C9CED2D7DB
E0E5EAEFF4F3E8DED8D3D0CFD0D1CDCAC9C6C6C5C3C1C1C0
BFBFC0BEBFC0C0C0BCBCBCBCBAB9B7B6B4B2AEABA8A4A1A0
9E9A96928E8984827F7A7671706E6D6B6968666565636362
616160606060606060606060616161626263636464656566
66676868696A6A6B
7074797D82868A8F94989DA1A5AAAFB3B8BCC1C5CACED3D7
DCE0E5EAEEF3F1E7DED8D4D2D3D5D3CECDCCCAC9C9C6C5C5
C4C3C4C4C3C4C6C7C6C4C1C1C1C0BEBDBBBAB6B3AFABA7A2
9E9B98928F8C8582807D787573716F6D6B6A686766656463
636262616161616161616161616262626363646465656666
67676869696A6A6B
7074787D8185898E92969A9FA3A7ACB0B4B9BDC1C6CACED3
D7DCE0E5EAF0F4F0E7DFD9D5D5D7D8D4D1D1D0CFCECCCAC9
C9C8C8C8C8C7C9CBCBCBCAC9C7C5C4C2BFBDBAB7B3AFA9A4
9F9A9793908D8885817D7A777573706E6D6B6A6867666665
646363636262626262626262626263636464646565666667
67686869696A6A6B
7074787C8084888C9094989CA1A5A9ADB1B5B9BEC2C6CACE
D3D7DCE0E5EAF0F3EEE8E2DDDAD9DCDBD7D5D5D5D4D4D1D0
CECECDCDCCCCCDCFCFD1D0CFCCC9C8C6C4C1BDB8B4B0AAA3
9F9B9793928F8A86837F7C79767472706E6C6B6A68676766
656564646363636363636363636363646465656566666767
67686869696A6B6B
6F73777B7F83878B8E92969A9EA2A6AAAEB2B6BABEC2C6CA
CED2D6DBE0E5EAEFF2EEE8E2DFDCDCDEDEDAD9D9D8D9D8D7
D5D3D1D2CFD0D0D1D1D3D5D4D1CFCCC9C5C2BEB9B4AFABA6
A29E9B9794918C8784807D7A777573716F6E6C6B69686867
666665656464646464646464646464656565666666676767
686869696A6A6B6B
6F73777A7E8285898D9094989C9FA3A7ABAEB2B6BABEC2C5
C9CDD2D6DADFE4E9EEF1EFE8E2DEDDDEE0DFDEDCDCDCDCDD
DDDBD8D8D5D4D3D4D1D0D2D2D0CECCC8C3BFBBB7B5B1ADA9
A5A29E9996938F8985827E7B79767472706F6D6C6A696968
676666666565656565646465656565656566666667676768
686969696A6A6B6B
6F73767A7D8184888B8F9296999DA0A4A7ABAFB2B6BABDC1
C5C9CCD0D4D9DDE2E6EAEFEFE9E2DEDCDEE0DEDEDEDEDEDD
DEDFDEDEDBD8D6D6D4D2D1CFCDCBC8C4C3BFBBB8B6B3B0AD
AAA5A09B9897908A86837F7C7A77757371706E6D6B6A6A69
686767676666666665656565656566666666676767676868
6869696A6A6A6B6B
6F7275797C7F8386898D9093979A9DA1A4A8ABAEB2B6B9BC
C0C3C7CBCFD3D6DBDFE3E7ECEDE9E1DDDBDCDCDCDCDBDBDB
DADAD8D8D7D5D5D4D2D0CFCDCAC9C8C4C3C0BDB9B8B5B3AF
ABA7A29E98948F8B8783807D7B78767472706F6E6C6B6A6A
696868686766666666666666666666676767676868686868
6969696A6A6A6B6B
6F7275787B7E8184888B8E9194979A9EA1A4A7AAAEB1B4B8
BBBEC2C5C9CCD0D4D8DBDFE3E6E9E7E0DCD9D8D7D7D7D7D7
D6D6D5D5D4D2D1D1CFCECDCDC9C8C7C4C3C1BFBBB9B7B3AF
ABA8A39D98938F8B8783807D7B7976747371706E6D6C6B6A
6A6969686867676767676766666667676767686868686869
69696A6A6A6B6B6B
6E7174777A7D808386898C8F9295989B9EA1A4A7AAADB0B3
B6B9BCC0C3C6C9CDD0D3D7DADDE0E4E2E0DAD6D4D4D3D2D2
D1D1D0D0D0CFCECDCCCBCBCBCBC8C6C5C4C1C0BDB9B6B2B0
ADA7A19B97928E8A8683807D7B7977757372706F6E6C6C6B
6A6A69696868686867676767676767676768686968696969
69696A6A6A6B6B6B
6E717476797C7F8184878A8C8F9295979A9DA0A3A6A9ABAE
B1B4B7BABDC0C3C6C9CCCFD2D4D7D9DADCDCDAD6D2CFCECD
CCCDCCCDCDCECECECDCBCACACBCBC8C5C4C0BDB9B8B6B3AD
A8A39E9995918C898683807D7B7977757372706F6E6D6C6B
6B6A6A696969696868686867676867676768686969696969
696A6A6A6B6B6B6B
6E717376787B7D808285888A8D8F9294979A9C9EA2A4A7AA
ACAFB2B4B7BABCBFC2C5C7CACCCED0D1D2D3D2D4D2D0CCCA
C9C8C8C8C9CACBCBCCCBCAC8C7C7C5C1BFBEBBB7B3B0ACA8
A49F9B96938F8B8885827F7D7B797775747271706E6D6C6B
6B6A6A696969686868686868686868686768686969696969
6A6A6A6A6B6B6B6B
6E707375777A7C7E818385888A8C8F919496999B9EA0A2A5
A7AAACAFB1B4B6B9BBBDC0C2C4C5C7C8C9CACACACBCCCBC9
C8C7C5C5C5C5C5C4C4C4C4C3C2C1C1BFBDB9B6B2AEAAA7A4
9F9C9894908D8A8784817F7C7A787775747271706F6E6D6C
6C6B6A6A69696969686969686968686868686969696A6A6A
6A6A6A6A6B6B6B6B
6E70727476787B7D7F818385888A8C8E90939597999B9EA0
A2A5A7A9ABADB0B2B4B6B8BABCBDBEBFC0C1C2C2C2C2C2C1
C1C1C0C0BFC0C1C1C1C0BFBFBEBCBAB8B5B2AFACA8A4A19F
9B9794918D8B888583807E7C7A787675747271706F6E6D6C
6C6B6B6A6A6A6A69696969686969696969696969696A6A6A
6A6A6A6A6B6B6B6B
6E6F71737577797B7D7F81838587898B8D8F91939597999B
9D9FA1A3A5A7A9ABADAFB1B2B4B5B6B7B8B9BABABABABAB9
B9B9B8B8B8B8B9B9B9B8B7B7B5B4B2B0ADABA8A5A29F9C9A
9794918E8B888683817F7D7B79777674737271706F6E6D6D
6C6B6B6B6A6A6A6A6A696969696969696969696A6A6A6A6A
6A6A6A6B6B6B6B6B
6D6F71737476787A7B7D7F81838486888A8C8D8F91939597
989A9C9EA0A1A3A5A6A8AAABACAEAFAFB0B1B1B2B2B2B2B1
B1B1B0B1B1B1B1B1B0B0AFAEADACAAA8A6A4A19F9C9A9795
93908D8A888583817F7D7B7A78767574727271706F6E6D6D
6D6C6B6B6A6A6A6A6A6A6A6969696969696969696A6A6A6A
6A6A6B6B6B6B6B6C
6D6F7072737577787A7B7D7E8082838586888A8B8D8E9092
939597989A9B9D9EA0A1A2A4A5A6A7A7A8A9A9AAAAAAA9A9
A9A9A9A9A9A9A9A9A9A8A7A7A6A4A3A19F9E9B9997959290
8E8C8A878583817F7D7B7A7877757473727170706F6E6D6D
6D6C6B6B6B6A6A6A6A6A6A6A6A6A6A6A6A6A6A696A6A6A6A
6A6B6B6B6B6B6B6B
6D6E70717274757778797B7C7D7F808283848687898A8C8D
8F90919394959798999A9B9D9D9E9FA0A0A1A1A2A2A2A1A2
A1A1A1A1A1A1A1A1A1A0A09F9E9D9C9A9997959391908D8B
8A88868482807F7D7B797877767473727271706F6E6E6D6D
6D6C6C6B6B6B6A6A6A6A6A6A6A6A6A6A6A6A6A6A6A6A6A6B
6B6B6A6B6B6B6B6B
6D6E6F70717374757677797A7B7C7D7E8081828385868788
8A8B8C8D8E8F909193949495969798989999999A9A9A9A9A
9A999A9999999999999898979796959392918F8D8C8A8987
858482817F7D7C7B7A7877757473737271706F6F6E6E6D6C
6C6C6C6B6B6B6B6B6B6A6A6A6A6A6A6A6A6A6A6A6A6B6B6B
6B6B6B6B6B6B6B6B
6D6E6E6F707172737475767778797A7B7C7D7E7F80818284
8585868788898A8B8C8D8E8E8F9090909191929292929292
9292929291919191919190908F8F8E8C8C8B898886858483
81807E7D7C7A7A787776757473727171706F6F6E6E6E6D6C
6C6C6C6B6B6B6B6A6B6B6A6B6A6A6A6A6B6A6A6A6A6B6B6B
6B6B6B6B6B6B6C6C
6C6D6E6F6F7071727373747576777778797A7B7B7C7D7E7F
7F80818283838485858687878888898989898A8A8A8B8B8A
8A8A8A8A8A8A8A8A89898989888887868584838381807F7E
7D7C7B7A7977777675747372727170706F6F6E6E6E6D6D6D
6C6C6C6C6B6B6B6B6B6B6B6B6B6B6B6A6B6B6A6B6B6B6B6B
6B6B6B6B6C6B6B6C
6C6D6D6E6E6F70707171727373747475767677787879797A
7A7B7C7C7D7D7E7E7F7F8080818182828282828382828383
8383828282828282828282818181807F7F7E7D7D7C7B7A79
78787777767574737372717170706F6F6F6E6E6E6D6D6D6D
6C6C6C6C6B6B6B6B6B6B6B6B6B6B6B6B6B6B6B6B6B6B6B6B
6B6B6B6C6B6B6C6C
6C6C6D6D6E6E6E6F6F6F7070717171727273737474757575
757676777777787879797979797A7A7A7B7A7A7B7B7B7B7B
7B7B7B7B7B7B7A7A7A7A7B7A797979797878787776767575
747373727272717171706F6F6E6E6E6D6D6D6D6D6D6D6D6C
6C6B6B6C6C6B6B6C6B6B6B6B6B6B6B6B6B6B6B6B6B6B6B6B
6B6B6B6B6B6B6C6C
6C6C6C6C6D6D6D6D6D6E6E6E6E6E6F6F6F6F6F7070707171
717171717171727272727272727373737373737373737473
737373737373737373737373737272727272727171717070
706F6F6F6F6F6F6F6E6E6E6D6D6D6D6C6C6C6C6C6C6C6C6C
6C6C6B6C6C6B6B6B6B6B6B6B6B6B6C6B6B6B6B6B6B6C6B6B
6C6B6B6B6B6B6C6C
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[57]:=",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`004`3oool806a/K0T0KFe]0P1^KVh206m_K`P0L71`
0P1_Kfl4071`L0P0Kfm_0P1`L70207=cL`<0Kfm_0P1`L70406m_K`H0KVi^2P1]KFd206a/K0@0Jf][
00<0JVYZ06][J`1[Jf/00P1[Jf/<06YZJQL0JFUY101ZJVX406UYJ@`0JVYZ3`1YJFT806QXJ0@0IfMW
0P1YJFT206][J`d0J6QX301WIfL206IVIP@0IfMW2@1VIVH606MWI`H0J6QX3@1YJFT206YZJP80Jf][
101XJ6P206UYJ@80JVYZ0P1[Jf/E0?ooo`004`3oool806a/K0T0KFe]0P1^KVh206m_K`P0L71`0P1_
Kfl4071`L0P0Kfm_0P1`L70207=cL`<0Kfm_0P1`L70406m_K`H0KVi^2P1]KFd206a/K0@0Jf][00<0
JVYZ06][J`1[Jf/00P1[Jf/<06YZJQL0JFUY101ZJVX406UYJ@`0JVYZ3`1YJFT806QXJ0@0IfMW0P1Y
JFT206][J`d0J6QX301WIfL206IVIP@0IfMW2@1VIVH606MWI`H0J6QX3@1YJFT206YZJP80Jf][101X
J6P206UYJ@80JVYZ0P1[Jf/E0?ooo`004`3oool806a/K080KFe]101^KVh306m_K`80L71`0P1bLW82
07AdM080MGEe2P1dM7@607=cL`80LW9b0P1dM7@207QhN00307AdM01cLg<0Lg=c00H0Lg=c0P1bLW82
075aL@80L71`0P1_Kfl406i^KP@0KFe]0P1/K6`206][J`<0JVYZ2P1YJFT406QXJ080JFUY0P1XJ6PG
06MWI`80J6QX101WIfL:06QXJ0T0IfMW201VIVH606EUI@80I6AT101SHf<206EUI@80JFUY0P1VIVH;
06ATI0P0Hf=S2P1RHV89065QH@@0HV9R0P1SHf<606ATI080IFEU201VIVH306MWI`@0J6QX0P1VIVH2
06EUI@80IfMW0P1XJ6P206YZJQD0oooo000C0?ooo`P0K6a/0P1]KFd406i^KP<0Kfm_0P1`L702079b
LP80M7Ad0P1eMGD:07AdM0H0Lg=c0P1bLW8207AdM080N7Qh00<0M7Ad07=cL`1cLg<01P1cLg<2079b
LP80LG5a0P1`L70206m_K`@0KVi^101]KFd206a/K080Jf][0`1ZJVX:06UYJ@@0J6QX0P1YJFT206QX
J1L0IfMW0P1XJ6P406MWI`X0J6QX2@1WIfL806IVIPH0IFEU0P1TI6@406=SH`80IFEU0P1YJFT206IV
IP/0I6AT201SHf<:069RHPT0HF5Q101RHV8206=SH`H0I6AT0P1UIFD806IVIP<0IfMW101XJ6P206IV
IP80IFEU0P1WIfL206QXJ080JVYZ5@3oool001<0oooo1P1/K6`206e]K@@0KVi^0P1_Kfl2071`L003
075aL@1bLW80LW9b0080M7Ad0P1fMWH<07QhN0X0MgMg0P1kNg/00`1jNWX0MWIf07IfMP0407MgM`80
MWIf0P1eMGD207AdM080Lg=c0P1aLG42071`L080Kfm_0P1^KVh206e]K@80K6a/0P1[Jf/206YZJP/0
J6QX201WIfL206IVIQT0IFEU301VIVH506EUI@H0I6AT1P1SHf<4069RHP@0HF5Q1P1PH60206ATI080
IVIV00<0Hf=S061PH01PH6002P1PH60205mOG`H0GUiN2P1MGEd505aLG0@0GEeM0P1NGUh405mOG`@0
H61P0P1QHF42069RHP@0Hf=S1@1TI6@406MWI`80IFEU0P1TI6@206EUI@80IfMW0P1ZJVXE0?ooo`00
4`3oool606a/K080KFe]101^KVh206m_K`80L71`00<0LG5a079bLP1bLW800P1dM7@207IfMP`0N7Qh
2P1gMgL207]kN`0307YjNP1fMWH0MWIf00@0MgMg0P1fMWH207EeM@80M7Ad0P1cLg<2075aL@80L71`
0P1_Kfl206i^KP80KFe]0P1/K6`206][J`80JVYZ2`1XJ6P806MWI`80IVIV6@1UIFD<06IVIPD0IFEU
1P1TI6@606=SH`@0HV9R101QHF46061PH080I6AT0P1VIVH00`1SHf<0H61P061PH00:061PH080GemO
1P1NGUh:05eMG@D0G5aL101MGEd205iNGP@0GemO101PH602065QH@80HV9R101SHf<506ATI0@0IfMW
0P1UIFD206ATI080IFEU0P1WIfL206YZJQD0oooo000C0?ooo`80K6a/101]KFd206i^KP@0Kfm_0P1`
L702075aL@03079bLP1dM7@0M7Ad0080MGEe0P1gMgL207UiN@80Ng]k201lO7`:07]kN`80O7al00<0
P82007emO@1mOGd0101kNg/207YjNP80NGUi0P1gMgL207EeM@80Lg=c0P1bLW82071`L080Kfm_0P1^
KVh206a/K080Jf][0P1ZJVX00`1XJ6P0IfMW06MWI`0406MWI`h0IVIV0P1UIFD;06ATI1`0Hf=S0`1R
HV86065QH@@0H61P101OGel405iNGPP0GEeM0P1OGel00`1RHV80H61P061PH00205aLG080GEeM1P1L
G5`405]KF`@0FUYJ0P1IFET805QHF0<0EeMG1P1HF5P205UIF@80FUYJ101KFe/405aLG080GUiN0P1O
Gel6065QH@03069RHP1SHf<0Hf=S0080IFEU0P1TI6@206=SH`80I6AT0P1VIVH206UYJAD0oooo000C
0?ooo`80K6a/101]KFd206i^KP@0Kfm_0P1`L702075aL@03079bLP1dM7@0M7Ad0080MGEe0P1gMgL2
07UiN@80Ng]k201lO7`:07]kN`80O7al00<0P82007emO@1mOGd0101kNg/207YjNP80NGUi0P1gMgL2
07EeM@80Lg=c0P1bLW82071`L080Kfm_0P1^KVh206a/K080Jf][0P1ZJVX00`1XJ6P0IfMW06MWI`04
06MWI`h0IVIV0P1UIFD;06ATI1`0Hf=S0`1RHV86065QH@@0H61P101OGel405iNGPP0GEeM0P1OGel0
0`1RHV80H61P061PH00205aLG080GEeM1P1LG5`405]KF`@0FUYJ0P1IFET805QHF0<0EeMG1P1HF5P2
05UIF@80FUYJ101KFe/405aLG080GUiN0P1OGel6065QH@03069RHP1SHf<0Hf=S0080IFEU0P1TI6@2
06=SH`80I6AT0P1VIVH206UYJAD0oooo000C0?ooo`80K6a/0P1]KFd406i^KP80Kfm_0P1`L702075a
L@80LW9b00<0Lg=c07EeM@1eMGD00P1fMWH207QhN080NWYj0P1lO7`207emO@80Ogmo1P20P80:07mo
O`030861P@22PX80PX:20080P8200P1oOgl207inOP80OGem0P1jNWX207QhN080MWIf0P1dM7@2075a
L@80Kfm_0P1^KVh206a/K080Jf][0P1YJFT00`1WIfL0IVIV06IVIP0606EUI@80I6AT301UIFD206AT
I0H0Hf=S2`1RHV8:065QH@80H61P101QHF44061PH0D0GemO101NGUh405eMG@@0G5aL101KFe/405YJ
FPH0FEUI00<0Fe]K05eMG@1MGEd00P1JFUX805QHF080EeMG0P1FEUH405EEE@@0E5AD1`1CDe<4059B
DP@0De=C0P1DE5@205EEE@@0EUIF101GEeL205UIF@80Fe]K101MGEd205iNGP<0H61P101RHV82065Q
H@80I6AT0P1WIfL206UYJAD0oooo000C0?ooo`80K6a/0P1]KFd406i^KP80Kfm_0P1`L702075aL@80
LW9b00<0Lg=c07EeM@1eMGD00P1fMWH207QhN080NWYj0P1lO7`207emO@80Ogmo1P20P80:07moO`03
0861P@22PX80PX:20080P8200P1oOgl207inOP80OGem0P1jNWX207QhN080MWIf0P1dM7@2075aL@80
Kfm_0P1^KVh206a/K080Jf][0P1YJFT00`1WIfL0IVIV06IVIP0606EUI@80I6AT301UIFD206ATI0H0
Hf=S2`1RHV8:065QH@80H61P101QHF44061PH0D0GemO101NGUh405eMG@@0G5aL101KFe/405YJFPH0
FEUI00<0Fe]K05eMG@1MGEd00P1JFUX805QHF080EeMG0P1FEUH405EEE@@0E5AD1`1CDe<4059BDP@0
De=C0P1DE5@205EEE@@0EUIF101GEeL205UIF@80Fe]K101MGEd205iNGP<0H61P101RHV82065QH@80
I6AT0P1WIfL206UYJAD0oooo000C0?ooo`80K6a/0P1]KFd206i^KP80Kfm_0P1`L702075aL@80LW9b
0P1cLg<00`1dM7@0MGEe07EeM@0207MgM`80NGUi0P1jNWX207alO080OWin0P20P80208:2PPX0Ph>3
1022PX800`23Ph<0QXJ608J6QP0208F5Q@80Ph>30P21PH420820P080OWin0P1kNg/207QhN080MWIf
0P1cLg<2075aL@80KVi^0P1/K6`206YZJP80J6QX00<0IVIV06EUI@1UIFD00P1TI6@406=SH`80HV9R
1P1SHf<806ATI080Hf=S1@1RHV84065QH@P0H61P201OGel605iNGP@0GEeM1@1LG5`405]KF`@0FUYJ
0P1IFET405QHF080EeMG201FEUH305EEE@80EeMG0P1HF5P205EEE@@0E5AD0P1CDe<4059BDP80DE5A
0P1@D50404m?C`L0CTi>101=CDd404i>CP80Cdm?1P1@D502055AD@80DU9B0P1DE5@205IFEP@0F5QH
0P1JFUX00`1LG5`0GEeM05eMG@04061PH080HF5Q0P1SHf<206IVIP80JFUY5@3oool001<0oooo0P1/
K6`206e]K@80KVi^0P1_Kfl2071`L080LG5a0P1bLW8207=cL`0307AdM01eMGD0MGEe0080MgMg0P1i
NGT207YjNP80O7al0P1nOWh20820P080PX:22P23Ph<408:2PP0308>3P`26QXH0QXJ60080QHF50P23
Ph<20861P@80P8200P1nOWh207]kN`80N7Qh0P1fMWH207=cL`80LG5a0P1^KVh206a/K080JVYZ0P1X
J6P00`1VIVH0IFEU06EUI@0206ATI0@0Hf=S0P1RHV8606=SH`P0I6AT0P1SHf<5069RHP@0HF5Q201P
H60805mOG`H0GUiN101MGEd505aLG0@0Fe]K101JFUX205UIF@@0F5QH0P1GEeL805IFEP<0EEEE0P1G
EeL205QHF080EEEE101DE5@205=CD`@0DU9B0P1ADE42051@D0@0Cdm?1`1>CTh404e=C@@0CTi>0P1?
Cdl6051@D080DE5A0P1BDU8205ADE080EUIF101HF5P205YJFP0305aLG01MGEd0GEeM00@0H61P0P1Q
HF4206=SH`80IVIV0P1YJFTE0?ooo`004`3oool206a/K080KFe]0P1_Kfl2071`L080LG5a0P1bLW82
07=cL`80M7Ad00<0MGEe07IfMP1fMWH00P1hN7P207UiN@80Ng]k0P1mOGd207moO`80PH610P23Ph<2
08F5Q@80QXJ60P27QhL908J6QP80QhN70P28R8P208N7Q`80QHF50P23Ph<20861P@80OWin0P1kNg/2
07QhN080M7Ad0P1aLG4206m_K`80K6a/0P1ZJVX206MWI`0306EUI@1TI6@0I6AT0080Hf=S0P1RHV82
065QH@80H61P1P1QHF42069RHP@0Hf=S0P1TI6@406=SH`80HV9R00<0HF5Q061PH01PH6000P1PH604
05mOG`H0GUiN101MGEd605aLG0@0Fe]K0P1JFUX305UIF@@0F5QH101GEeL205IFEP@0EEEE101DE5@4
05=CD`@0DU9B0`1ADE42051@D080DU9B0P1CDe<2055AD@@0Cdm?0P1>CTh204e=C@80C4a<0P1;Bd/4
04Y:BPH0BDU900<0B4Q804U9B@19BDT01018B4P204U9B@@0BTY:101;Bd/204a<C080CDe=0P1?Cdl2
055AD@@0EEEE0P1GEeL00`1IFET0Fe]K05]KF`0405eMG@80H61P0P1SHf<206IVIP80JFUY5@3oool0
01<0oooo0P1/K6`206e]K@80Kfm_0P1`L702075aL@80LW9b0P1cLg<207AdM00307EeM@1fMWH0MWIf
0080N7Qh0P1iNGT207]kN`80OGem0P1oOgl20861P@80Ph>30P25QHD208J6QP80QhN72@26QXH208N7
Q`80R8R80P27QhL208F5Q@80Ph>30P21PH4207inOP80Ng]k0P1hN7P207AdM080LG5a0P1_Kfl206a/
K080JVYZ0P1WIfL00`1UIFD0I6AT06ATI00206=SH`80HV9R0P1QHF42061PH0H0HF5Q0P1RHV8406=S
H`80I6AT101SHf<2069RHP03065QH@1PH600H61P0080H61P101OGel605iNGP@0GEeM1P1LG5`405]K
F`80FUYJ0`1IFET405QHF0@0EeMG0P1FEUH405EEE@@0E5AD101CDe<4059BDP<0DE5A0P1@D502059B
DP80De=C0P1ADE4404m?C`80CTi>0P1=CDd204a<C080Bd];101:BTX604U9B@0304Q8B019BDT0BDU9
00@0B4Q80P19BDT404Y:BP@0Bd];0P1<C4`204e=C@80Cdm?0P1ADE4405EEE@80EeMG00<0FEUI05]K
F`1KFe/0101MGEd2061PH080Hf=S0P1VIVH206UYJAD0oooo000C0?ooo`80K6a/0P1]KFd206i^KP80
L71`0P1aLG42079bLP80M7Ad0P1eMGD00`1fMWH0MgMg07MgM`0207UiN@80NWYj0P1lO7`207emO@80
Ogmo0P21PH4208>3P`80QHF50P27QhL208R8R0/0RHV90P2:RXX208^;R`80RHV90P25QHD208>3P`80
PH610P1mOGd207YjNP80MWIf0P1cLg<206m_K`80KFe]0P1ZJVX206MWI`0306EUI@1SHf<0Hf=S0080
HV9R0P1QHF42061PH080GemO0P1NGUh405mOG`80H61P101QHF46069RHP<0HF5Q101PH60405mOG`80
GUiN101MGEd405aLG080Fe]K101JFUX205UIF@@0F5QH00<0EeMG05IFEP1FEUH0101EEED205ADE0@0
De=C101BDU82055AD@80D51@1P1?Cdl404i>CP0304e=C@1<C4`0C4a<0080Bd];0P1<C4`204e=C@80
C4a<0P1;Bd/204U9B@80B4Q80P17AdL204I6AP80ADE51P14A4@904=3@`@0A4A40P15ADD204I6AP@0
B4Q80P19BDT204a<C080CDe=0P1@D502059BDP80E5AD00<0EeMG05UIF@1IFET0101KFe/205iNGP80
HV9R0P1UIFD206QXJ1D0oooo000C0?ooo`80K6a/0P1]KFd206i^KP80L71`0P1aLG42079bLP80M7Ad
0P1eMGD00`1fMWH0MgMg07MgM`0207UiN@80NWYj0P1lO7`207emO@80Ogmo0P21PH4208>3P`80QHF5
0P27QhL208R8R0/0RHV90P2:RXX208^;R`80RHV90P25QHD208>3P`80PH610P1mOGd207YjNP80MWIf
0P1cLg<206m_K`80KFe]0P1ZJVX206MWI`0306EUI@1SHf<0Hf=S0080HV9R0P1QHF42061PH080GemO
0P1NGUh405mOG`80H61P101QHF46069RHP<0HF5Q101PH60405mOG`80GUiN101MGEd405aLG080Fe]K
101JFUX205UIF@@0F5QH00<0EeMG05IFEP1FEUH0101EEED205ADE0@0De=C101BDU82055AD@80D51@
1P1?Cdl404i>CP0304e=C@1<C4`0C4a<0080Bd];0P1<C4`204e=C@80C4a<0P1;Bd/204U9B@80B4Q8
0P17AdL204I6AP80ADE51P14A4@904=3@`@0A4A40P15ADD204I6AP@0B4Q80P19BDT204a<C080CDe=
0P1@D502059BDP80E5AD00<0EeMG05UIF@1IFET0101KFe/205iNGP80HV9R0P1UIFD206QXJ1D0oooo
000C0?ooo`80KFe]0P1^KVh206m_K`80L71`0P1aLG4207=cL`80M7Ad0P1eMGD00`1gMgL0N7Qh07Qh
N00207YjNP80Ng]k0P1mOGd207inOP80P8200P21PH4208>3P`80QHF50P27QhL208R8R0@0RXZ:102;
Rh/508b<S080SHf=0P2>SXh208^;R`80QhN70P23Ph<20820P080O7al0P1gMgL207=cL`80L71`0P1]
KFd206YZJP80IfMW00<0I6AT069RHP1RHV800P1QHF42061PH080GemO0P1MGEd405aLG080GEeM0P1N
GUh405mOG`80H61P0P1QHF42069RHP80HF5Q1@1PH60205mOG`H0GUiN0P1MGEd205aLG080Fe]K0P1J
FUX405UIF@80F5QH0P1GEeL205IFEP0305EEE@1DE5@0E5AD0080De=C101BDU82055AD@80D51@101?
Cdl204i>CP@0CDe=101<C4`204];B`<0BTY:0P19BDT604M7A`80B4Q80P17AdL204E5A@80@d=30P12
@T820451@@80@4101P0o?cl903hn?P@0?clo0P11@D4204=3@`@0ADE50P16ATH204U9B@80C4a<0P1>
CTh2051@D080DU9B00<0EEEE05QHF01HF5P00P1IFET205]KF`80GEeM0P1QHF4206EUI@80J6QX5@3o
ool001<0oooo0P1]KFd206i^KP80Kfm_0P1`L702079bLP80Lg=c0P1eMGD207IfMP0307MgM`1iNGT0
NGUi0080NWYj0P1lO7`207emO@80Ogmo0P20P80208:2PP80Ph>30P25QHD208N7Q`80R8R80P2:RXX2
08^;R`D0S8b<0P2=SHd608j>SP80Shn?0P2<S8`208J6QP80PH610P1nOWh207UiN@80M7Ad0P1`L702
06a/K080JFUY0P1UIFD00`1RHV80H61P061PH00205iNGP@0GEeM0P1LG5`605]KF`80G5aL0P1MGEd4
05iNGP80GemO1@1PH60405mOG`@0GUiN1P1MGEd405aLG080Fe]K101JFUX205UIF@@0EeMG00<0EEEE
05ADE01DE5@00P1CDe<2059BDP80DE5A0P1@D50204m?C`@0CTi>0P1=CDd204a<C080Bd];0P1:BTX4
04U9B@80B4Q800<0AdM704I6AP16ATH00P16ATH204E5A@P0A4A40P13@d<20410@0@0?3`l100k>c/2
03Xj>P<0>CTi0P0h>3P203Lg=`80>3Ph0P0j>SX203/k>`80?Shn0P10@4020492@P80@d=30P15ADD2
04M7A`80BTY:0P1<C4`204i>CP80Cdm?00<0E5AD05IFEP1FEUH00P1GEeL205YJFP80GEeM0P1QHF42
06ATI080J6QX5@3oool001<0oooo0P1]KFd206i^KP80Kfm_0P1`L702079bLP80Lg=c0P1eMGD207If
MP0307MgM`1iNGT0NGUi0080NWYj0P1lO7`207emO@80Ogmo0P20P80208:2PP80Ph>30P25QHD208N7
Q`80R8R80P2:RXX208^;R`D0S8b<0P2=SHd608j>SP80Shn?0P2<S8`208J6QP80PH610P1nOWh207Ui
N@80M7Ad0P1`L70206a/K080JFUY0P1UIFD00`1RHV80H61P061PH00205iNGP@0GEeM0P1LG5`605]K
F`80G5aL0P1MGEd405iNGP80GemO1@1PH60405mOG`@0GUiN1P1MGEd405aLG080Fe]K101JFUX205UI
F@@0EeMG00<0EEEE05ADE01DE5@00P1CDe<2059BDP80DE5A0P1@D50204m?C`@0CTi>0P1=CDd204a<
C080Bd];0P1:BTX404U9B@80B4Q800<0AdM704I6AP16ATH00P16ATH204E5A@P0A4A40P13@d<20410
@0@0?3`l100k>c/203Xj>P<0>CTi0P0h>3P203Lg=`80>3Ph0P0j>SX203/k>`80?Shn0P10@4020492
@P80@d=30P15ADD204M7A`80BTY:0P1<C4`204i>CP80Cdm?00<0E5AD05IFEP1FEUH00P1GEeL205YJ
FP80GEeM0P1QHF4206ATI080J6QX5@3oool001<0oooo0P1]KFd206i^KP80Kfm_0P1aLG42079bLP80
Lg=c0P1eMGD207MgM`0307QhN01jNWX0NWYj0080Ng]k0P1mOGd207inOP80P8200P21PH4208>3P`80
Q8B40P26QXH208R8R080RHV90P2:RXX208^;R`80S8b<0`2=SHd208j>SPH0Shn?0P2@T90208n?S`80
Rh^;0P24Q8@207moO`80NWYj0P1dM7@206m_K`80Jf][0P1XJ6P206ATI003069RHP1NGUh0GUiN0080
G5aL101KFe/205YJFPH0FEUI0P1JFUX205]KF`80G5aL0P1MGEd405iNGP<0GemO101NGUh605eMG@H0
G5aL0P1KFe/205YJFP@0FEUI0P1HF5P205MGE`80EUIF00<0EEEE05=CD`1CDe<00P1BDU82055AD@80
D51@0P1>CTh204e=C@80C4a<0P1;Bd/204Y:BP80BDU91018B4P404I6AP80ADE500<0A4A404=3@`13
@d<01012@T820451@@@0@410100o?cl20410@080?3`l0P0k>c/203Ti>@80=cLg0P0f=SH303De=@80
=SHf100g=cL203Ph>080>CTi0P0j>SX203dm?@80?clo0P10@40204A4A080ADE50P17AdL204Y:BP80
C4a<0P1>CTh00`1BDU80EEEE05EEE@0205MGE`80FEUI0P1MGEd2061PH080I6AT0P1XJ6PE0?ooo`00
4`3oool206e]K@80KVi^0P1_Kfl2075aL@80LW9b0P1cLg<207EeM@80MgMg00<0N7Qh07YjNP1jNWX0
0P1kNg/207emO@80OWin0P20P8020861P@80Ph>30P24Q8@208J6QP80R8R80P29RHT208Z:RP80Rh^;
0P2<S8`308f=S@80SXj>1P2?Shl2092@T080Shn?0P2;Rh/208B4Q080Ogmo0P1jNWX207AdM080Kfm_
0P1[Jf/206QXJ080I6AT00<0HV9R05iNGP1NGUh00P1LG5`405]KF`80FUYJ1P1IFET205YJFP80Fe]K
0P1LG5`205eMG@@0GUiN0`1OGel405iNGPH0GEeM1P1LG5`205]KF`80FUYJ101IFET205QHF080EeMG
0P1FEUH00`1EEED0De=C05=CD`02059BDP80DE5A0P1@D50204i>CP80CDe=0P1<C4`204];B`80BTY:
0P19BDT404Q8B0@0ATI60P15ADD00`14A4@0@d=304=3@`040492@P80@D511010@40403lo?`80@410
0P0l?3`203/k>`80>CTi0P0g=cL203Hf=P<0=CDe0P0f=SH403Lg=`80>3Ph0P0i>CT203Xj>P80?Cdm
0P0o?cl20410@080A4A40P15ADD204M7A`80BTY:0P1<C4`204i>CP03059BDP1EEED0EEEE0080EeMG
0P1IFET205eMG@80H61P0P1TI6@206QXJ1D0oooo000C0?ooo`80KFe]0P1^KVh206m_K`80LG5a0P1c
Lg<207AdM080MWIf0P1gMgL00`1iNGT0NWYj07YjNP0207alO080OGem0P1oOgl20820P080PX:20P24
Q8@208F5Q@80QXJ60P28R8P208V9R@80Rh^;0P2<S8`208f=S@80SXj>0`2?Shl4092@T0@0TI6A0P2B
TY8208n?S`80RHV90P22PX8207alO080MGEe0P1^KVh206UYJ@80IFEU0P1RHV800`1OGel0G5aL05aL
G00205YJFP80FEUI1P1HF5P205MGE`80F5QH101IFET205YJFP80Fe]K0P1LG5`405eMG@0305iNGP1M
GEd0GEeM0080GEeM1P1LG5`405]KF`@0FUYJ0P1IFET205QHF080EeMG0P1FEUH205EEE@80E5AD00<0
De=C059BDP1BDU800P1@D50204m?C`80CDe=0P1<C4`204];B`80BTY:0P18B4P204M7A`80ATI60P15
ADD204A4A080@d=30P12@T830451@@80@4100P0o?cl203hn?P@0?Cdm0P0l?3`203/k>`@0>SXj1P0h
>3P203Lg=`80=SHf0`0d=3@203De=@H0=SHf100g=cL203Xj>P80?3`l0P0m?Cd20492@P80@d=30P15
ADD204U9B@80BTY:0P1=CDd00`1ADE40De=C05=CD`0205MGE`80FUYJ0P1MGEd2061PH080I6AT0P1X
J6PE0?ooo`004`3oool206e]K@80KVi^0P1_Kfl2075aL@80Lg=c0P1dM7@207IfMP80MgMg00<0NGUi
07YjNP1jNWX00P1lO7`207emO@80Ogmo0P20P80208:2PP80Q8B40P25QHD208J6QP80R8R80P29RHT2
08^;R`80S8b<0P2=SHd208j>SP<0Shn?102@T904096AT@80TY:B0P2?Shl208V9R@80PX:20P1lO7`2
07EeM@80KVi^0P1YJFT206EUI@80HV9R00<0GemO05aLG01LG5`00P1JFUX205UIF@H0F5QH0P1GEeL2
05QHF0@0FEUI0P1JFUX205]KF`80G5aL101MGEd00`1NGUh0GEeM05eMG@0205eMG@H0G5aL101KFe/4
05YJFP80FEUI0P1HF5P205MGE`80EUIF0P1EEED205ADE00305=CD`1BDU80DU9B0080D51@0P1?Cdl2
04e=C@80C4a<0P1;Bd/204Y:BP80B4Q80P17AdL204I6AP80ADE50P14A4@204=3@`80@T920`11@D42
0410@080?clo0P0n?Sh403dm?@80?3`l0P0k>c/403Xj>PH0>3Ph0P0g=cL203Hf=P<0=3@d0P0e=CD6
03Hf=P@0=cLg0P0j>SX203`l?080?Cdm0P12@T8204=3@`80ADE50P19BDT204Y:BP80CDe=00<0DE5A
05=CD`1CDe<00P1GEeL205YJFP80GEeM0P1PH60206ATI080J6QX5@3oool001<0oooo0P1]KFd206i^
KP80L71`0P1aLG4207=cL`80M7Ad0P1fMWH207QhN00307UiN@1kNg/0Ng]k0080O7al0P1nOWh207mo
O`80PH610P22PX8208B4Q080QXJ60P27QhL208V9R@80RXZ:0P2;Rh/208b<S080SXj>0P2?Shl00`2@
T900TI6A096AT@02096AT@@0TY:B0P2CTi<209BDU080TI6A0P2>SXh208N7Q`80Ogmo0P1iNGT206i^
KP80IVIV0P1RHV8205mOG`0305aLG01JFUX0FUYJ0080F5QH0P1GEeL:05IFEP80EeMG0P1HF5P205UI
F@80FUYJ101KFe/705aLG0@0Fe]K1P1JFUX405UIF@80F5QH0P1GEeL205IFEP80EEEE0P1CDe<2059B
DP03055AD@1@D500D51@0080CTi>0P1=CDd204];B`80BTY:0P18B4P204M7A`80ADE50P14A4@204=3
@`80@T920P11@D420410@080?clo0`0n?Sh203`l?080>c/k100j>SX203Ti>@80>3Ph0P0g=cL203Hf
=P80=CDe0P0d=3@203<c<`@0<S8b1`0d=3@603De=@80=SHf0P0g=cL203Ti>@80>SXj0P0l?3`20451
@@80@T920P14A4@204Q8B080BDU90P1<C4`00`1?Cdl0DU9B059BDP0205IFEP80FEUI0P1MGEd2061P
H080I6AT0P1XJ6PE0?ooo`004`3oool206e]K@80KVi^0P1`L702075aL@80Lg=c0P1dM7@207IfMP80
N7Qh00<0NGUi07]kN`1kNg/00P1lO7`207inOP80Ogmo0P21PH4208:2PP80Q8B40P26QXH208N7Q`80
RHV90P2:RXX208^;R`80S8b<0P2>SXh208n?S`03092@T02ATI40TI6A0080TI6A102BTY8209>CT`80
U9BD0P2ATI4208j>SP80QhN70P1oOgl207UiN@80KVi^0P1VIVH2069RHP80GemO00<0G5aL05YJFP1J
FUX00P1HF5P205MGE`X0EUIF0P1GEeL205QHF080FEUI0P1JFUX405]KF`L0G5aL101KFe/605YJFP@0
FEUI0P1HF5P205MGE`80EUIF0P1EEED205=CD`80DU9B00<0DE5A051@D01@D5000P1>CTh204e=C@80
Bd];0P1:BTX204Q8B080AdM70P15ADD204A4A080@d=30P12@T820451@@80@4100P0o?cl303hn?P80
?3`l0P0k>c/403Xj>P80>CTi0P0h>3P203Lg=`80=SHf0P0e=CD203@d=080<c<c100b<S8703@d=0H0
=CDe0P0f=SH203Lg=`80>CTi0P0j>SX203`l?080@D510P12@T8204A4A080B4Q80P19BDT204a<C003
04m?C`1BDU80DU9B0080EUIF0P1IFET205eMG@80H61P0P1TI6@206QXJ1D0oooo000C0?ooo`80KFe]
0P1^KVh2071`L080LW9b0P1cLg<207AdM080MWIf0P1hN7P00`1jNWX0Ng]k07]kN`0207emO@80OWin
0P20P80208:2PP80Ph>30P25QHD208J6QP80R8R80P29RHT208^;R`80S8b<0P2=SHd208j>SP80T92@
00<0TI6A09:BTP2BTY800P2BTY8209>CT`80U9BD0P2EUID209JFUP80U9BD0P2BTY8208f=S@80Q8B4
0P1mOGd207=cL`80J6QX0P1OGel205aLG00305UIF@1GEeL0EeMG0080EEEE2P1DE5@205EEE@80EUIF
0P1GEeL205QHF080FEUI101JFUX905]KF`80FUYJ101IFET405QHF0@0EeMG0P1FEUH205EEE@80E5AD
0P1BDU82055AD@0304m?C`1>CTh0CTi>0080CDe=0P1;Bd/204U9B@80B4Q80P16ATH204A4A080@d=3
0P11@D420410@080?clo0P0n?Sh203dm?@80?3`l0`0k>c/203Ti>@80>3Ph0P0g=cL203Hf=P80=CDe
100d=3@203<c<`80<S8b200a<C42038b<P80<c<c00<0=3@d03De=@0e=CD0100d=3@403De=@80=SHf
0P0h>3P203Ti>@80?3`l0P0o?cl20451@@80@d=30P16ATH204U9B@80Bd];00<0CTi>055AD@1ADE40
0P1EEED205UIF@80GEeM0P1PH60206ATI080J6QX5@3oool001<0oooo0P1]KFd206i^KP80L71`0P1b
LW8207=cL`80M7Ad0P1fMWH207QhN00307YjNP1kNg/0Ng]k0080OGem0P1nOWh20820P080PX:20P23
Ph<208F5Q@80QXJ60P28R8P208V9R@80Rh^;0P2<S8`208f=S@80SXj>0P2@T9000`2ATI40TY:B09:B
TP0209:BTP80Ti>C0P2DU9@209FEU@80UYJF0P2DU9@209:BTP80SHf=0P24Q8@207emO@80Lg=c0P1X
J6P205mOG`80G5aL00<0FEUI05MGE`1GEeL00P1EEED:05ADE080EEEE0P1FEUH205MGE`80F5QH0P1I
FET405YJFPT0Fe]K0P1JFUX405UIF@@0F5QH101GEeL205IFEP80EEEE0P1DE5@2059BDP80DE5A00<0
Cdm?04i>CP1>CTh00P1=CDd204];B`80BDU90P18B4P204I6AP80A4A40P13@d<20451@@80@4100P0o
?cl203hn?P80?Cdm0P0l?3`303/k>`80>CTi0P0h>3P203Lg=`80=SHf0P0e=CD403@d=080<c<c0P0b
<S88034a<@80<S8b0P0c<c<00`0d=3@0=CDe03De=@0403@d=0@0=CDe0P0f=SH203Ph>080>CTi0P0l
?3`203lo?`80@D510P13@d<204I6AP80BDU90P1;Bd/00`1>CTh0DE5A055AD@0205EEE@80FEUI0P1M
GEd2061PH080I6AT0P1XJ6PE0?ooo`004`3oool206e]K@80KVi^0P1`L702079bLP80Lg=c0P1eMGD2
07MgM`80N7Qh00<0NWYj07alO01lO7`00P1nOWh207moO`80PH610P22PX8208B4Q080QHF50P27QhL2
08R8R080RXZ:0P2;Rh/208f=S@80SXj>0P2?Shl2096AT@0309:BTP2CTi<0Ti>C0080U9BD0P2EUID4
09JFUP80UiNG102EUID2096AT@80RHV90P21PH4207QhN080KVi^0P1PH60205MGE`0305EEE@1CDe<0
De=C0080DU9B101ADE46059BDP80De=C0P1EEED205IFEP80EeMG101HF5P205UIF@D0FUYJ0P1KFe/4
05YJFP80FEUI101HF5P205MGE`@0EUIF0P1EEED205ADE080De=C0P1ADE4204m?C`0304i>CP1<C4`0
C4a<0080Bd];0P19BDT204M7A`80ATI60P14A4@20492@P80@4100P0n?Sh203dm?@80?3`l0P0k>c/2
03Xj>P80>CTi0P0h>3P00`0g=cL0=SHf03Hf=P0203De=@80=3@d0P0c<c<2038b<P80<C4a100`<308
02l_;`80<30`100a<C400`0b<S80=3@d03@d=00603@d=0@0=CDe0P0g=cL203Ph>080>c/k0P0n?Sh2
0451@@80A4A40P16ATH204U9B@80Bd];00<0CTi>055AD@1ADE400P1EEED205UIF@80G5aL0P1PH602
06ATI080J6QX5@3oool001<0oooo0P1]KFd206i^KP80L71`0P1bLW8207=cL`80MGEe0P1gMgL207Qh
N00307YjNP1lO7`0O7al0080OWin0P1oOgl20861P@80PX:20P24Q8@208F5Q@80QhN70P28R8P208Z:
RP80Rh^;0P2=SHd208j>SP80Shn?0P2ATI400`2BTY80Ti>C09>CT`0209BDU080UIFE102FUYH209NG
U`@0UIFE0P2ATI4208V9R@80PH610P1hN7P206i^KP80H61P0P1GEeL00`1EEED0De=C05=CD`02059B
DP@0DE5A1P1BDU8205=CD`80EEEE0P1FEUH205MGE`@0F5QH0P1IFET505YJFP80Fe]K101JFUX205UI
F@@0F5QH0P1GEeL405IFEP80EEEE0P1DE5@205=CD`80DE5A0P1?Cdl00`1>CTh0C4a<04a<C00204];
B`80BDU90P17AdL204I6AP80A4A40P12@T820410@080?Shn0P0m?Cd203`l?080>c/k0P0j>SX203Ti
>@80>3Ph00<0=cLg03Hf=P0f=SH00P0e=CD203@d=080<c<c0P0b<S82034a<@@0<30`200_;bl2030`
<0@0<C4a00<0<S8b03@d=00d=3@01P0d=3@403De=@80=cLg0P0h>3P203/k>`80?Shn0P11@D4204A4
A080ATI60P19BDT204];B`0304i>CP1ADE40DE5A0080EEEE0P1IFET205aLG080H61P0P1TI6@206QX
J1D0oooo000C0?ooo`80KFe]0P1_Kfl2071`L080LW9b0P1dM7@207EeM@80MgMg0P1iNGT00`1kNg/0
O7al07alO00207inOP80P8200P21PH4208>3P`80QHF50P26QXH208R8R080RXZ:0P2;Rh/208f=S@80
SXj>0P2?Shl2092@T080TY:B00<0Ti>C09BDU02DU9@00P2EUID209JFUP80UiNG0P2HV9P209VIV@@0
UiNG0P2EUID208n?S`80QHF50P1mOGd207=cL`80IfMW0P1IFET00`1ADE40D51@051@D00604i>CP80
Cdm?0P1@D502055AD@80DU9B0P1DE5@205EEE@80EUIF0P1GEeL205QHF0@0FEUI1@1JFUX405UIF@@0
F5QH0P1GEeL205IFEP@0EEEE0P1DE5@205=CD`80DU9B0P1@D50204i>CP0304e=C@1;Bd/0Bd];0080
BDU90P17AdL204E5A@80A4A40P12@T820410@080?Cdm0P0l?3`203Xj>P80>CTi0P0h>3P203Lg=`80
=SHf0P0e=CD00`0d=3@0<c<c03<c<`02038b<P80<C4a0P0_;bl202h^;PH0;Bd]1P0/;2`202d];@80
;bl_0P0`<30202l_;`03030`<00b<S80<S8b00X0=3@d0P0f=SH203Ph>080>c/k0P0m?Cd20410@080
@d=30P16ATH204U9B@80Bd];00<0CDe=055AD@1ADE400P1DE5@205QHF080G5aL0P1PH60206ATI080
J6QX5@3oool001<0oooo0P1]KFd206m_K`80L71`0P1bLW8207AdM080MGEe0P1gMgL207UiN@0307]k
N`1lO7`0O7al0080OWin0P20P8020861P@80Ph>30P25QHD208J6QP80R8R80P2:RXX208^;R`80SHf=
0P2>SXh208n?S`80T92@0P2BTY800`2CTi<0U9BD09BDU00209FEU@80UYJF0P2GUiL209RHV080VIVI
102GUiL209FEU@80Shn?0P25QHD207emO@80Lg=c0P1WIfL205UIF@03055AD@1@D500D51@00H0CTi>
0P1?Cdl2051@D080DE5A0P1BDU8205ADE080EEEE0P1FEUH205MGE`80F5QH101IFET505YJFP@0FEUI
101HF5P205MGE`80EUIF101EEED205ADE080De=C0P1BDU82051@D080CTi>00<0CDe=04];B`1;Bd/0
0P19BDT204M7A`80ADE50P14A4@20492@P80@4100P0m?Cd203`l?080>SXj0P0i>CT203Ph>080=cLg
0P0f=SH203De=@0303@d=00c<c<0<c<c0080<S8b0P0a<C4202l_;`80;Rh^1P0];Bd602`/;080;Bd]
0P0_;bl2030`<080;bl_00<0<30`038b<P0b<S802P0d=3@203Hf=P80>3Ph0P0k>c/203dm?@80@410
0P13@d<204I6AP80BDU90P1;Bd/00`1=CDd0DE5A055AD@0205ADE080F5QH0P1LG5`2061PH080I6AT
0P1XJ6PE0?ooo`004`3oool206e]K@80Kfm_0P1aLG4207=cL`80M7Ad0P1fMWH207QhN080NGUi00<0
Ng]k07emO@1mOGd00P1nOWh20820P080PX:20P24Q8@208F5Q@80QhN70P29RHT208Z:RP80S8b<0P2>
SXh208n?S`80T92@0P2BTY8209>CT`0309BDU02EUID0UIFE0080UYJF0P2HV9P209VIV@H0VYZJ0P2I
VIT209NGU`80TY:B0P29RHT20861P@80N7Qh0P1]KFd2061PH00305=CD`1;Bd/0Bd];00H0Bd];0P1=
CDd204m?C`80D51@0P1ADE4205=CD`80E5AD0P1EEED205MGE`80F5QH1@1IFET405YJFPH0FEUI0P1H
F5P205MGE`@0EEEE0P1DE5@205=CD`80DU9B0P1ADE4204m?C`80CTi>00<0C4a<04Y:BP1:BTX00P18
B4P204E5A@80@d=30P12@T820410@080?Shn0P0k>c/203Ti>@80>3Ph0P0f=SH203De=@80=3@d0P0c
<c<5034a<@80<30`0P0_;bl202h^;P80;Bd]3P0[:b/202d];@@0;bl_0`0`<302034a<@80<S8b0P0d
=3@403De=@80=SHf0P0h>3P203Xj>P80?3`l0P0o?cl20451@@80ADE50P18B4P204];B`0304i>CP1A
DE40DE5A0080EEEE0P1HF5P205eMG@80H61P0P1TI6@206QXJ1D0oooo000C0?ooo`80KFe]0P1_Kfl2
075aL@80Lg=c0P1dM7@207IfMP80N7Qh0P1iNGT00`1kNg/0OGem07emO@0207inOP80P8200P22PX82
08B4Q080QHF50P27QhL208V9R@80RXZ:0P2<S8`208j>SP80Shn?0P2@T90209:BTP80Ti>C00<0U9BD
09FEU@2EUID00P2FUYH209RHV080VIVI1P2JVYX209VIV@80UiNG0P2BTY8208V9R@80PH610P1hN7P2
06e]K@80H61P00<0De=C04];B`1;Bd/01P1;Bd/204e=C@80Cdm?0P1@D502055AD@80De=C0P1DE5@2
05EEE@80EeMG0P1HF5P505UIF@@0FUYJ1P1IFET205QHF080EeMG101EEED205ADE080De=C0P1BDU82
055AD@80Cdm?0P1>CTh00`1<C4`0BTY:04Y:BP0204Q8B080ADE50P13@d<20492@P80@4100P0n?Sh2
03/k>`80>CTi0P0h>3P203Hf=P80=CDe0P0d=3@203<c<`D0<C4a0P0`<30202l_;`80;Rh^0P0];Bd>
02/[:`80;Bd]100_;bl3030`<080<C4a0P0b<S8203@d=0@0=CDe0P0f=SH203Ph>080>SXj0P0l?3`2
03lo?`80@D510P15ADD204Q8B080Bd];00<0CTi>055AD@1ADE400P1EEED205QHF080GEeM0P1PH602
06ATI080J6QX5@3oool001<0oooo0P1]KFd206m_K`80LG5a0P1cLg<207EeM@80MgMg0P1hN7P207Yj
NP0307alO01nOWh0OWin0080Ogmo0P21PH4208>3P`80Q8B40P26QXH208N7Q`80RHV90P2;Rh/208f=
S@80SXj>0P2@T902096AT@80Ti>C0P2DU9@00`2FUYH0UiNG09NGU`0209RHV080VIVI0P2JVYX409^K
V`80W9bL102JVYX209BDU080SHf=0P25QHD207alO080LW9b0P1WIfL00`1KFe/0CDe=04e=C@0204E5
A@80AdM70P19BDT204];B`80CDe=0P1?Cdl2055AD@80De=C0P1DE5@205IFEP@0EeMG1@1IFET205YJ
FPH0FEUI101HF5P205MGE`80EEEE0P1DE5@205=CD`80DU9B0P1ADE42051@D080Cdm?0P1=CDd00`1;
Bd/0BDU904U9B@0204M7A`80A4A40P12@T820410@080?Shn0P0l?3`203Xj>P80>3Ph0P0f=SH203@d
=080<c<c0P0a<C42030`<080;bl_1@0^;Rh202d];@80;2`/0P0[:b/202XZ:P80:BTY200Z:RX402/[
:`@0;Bd]00<0;Rh^02l_;`0_;bl00P0`<302034a<@80<S8b0P0d=3@203De=@80=SHf0P0h>3P203Xj
>P80?3`l0P0o?cl20451@@80A4A40P18B4P204];B`0304i>CP1BDU80DU9B0080EEEE0P1IFET205eM
G@80HF5Q0P1TI6@206QXJ1D0oooo000C0?ooo`80KFe]0P1_Kfl2075aL@80Lg=c0P1eMGD207MgM`80
N7Qh0P1jNWX00`1lO7`0OWin07inOP0207moO`80PH610P23Ph<208B4Q080QXJ60P27QhL208V9R@80
Rh^;0P2=SHd208j>SP80T92@0P2ATI4209>CT`80U9BD00<0UYJF09NGU`2GUiL00P2HV9P209VIV@80
VYZJ102KVi/209bLW0@0VYZJ0P2DU9@208f=S@80QHF50P1lO7`2079bLP80IfMW00<0Fe]K04e=C@1=
CDd00P15ADD204M7A`80BDU90P1;Bd/204e=C@80Cdm?0P1ADE4205=CD`80E5AD0P1FEUH405MGE`D0
FEUI0P1JFUX605UIF@@0F5QH0P1GEeL205EEE@80E5AD0P1CDe<2059BDP80DE5A0P1@D50204m?C`80
CDe=00<0Bd];04U9B@19BDT00P17AdL204A4A080@T920P10@40203hn?P80?3`l0P0j>SX203Ph>080
=SHf0P0d=3@203<c<`80<C4a0P0`<30202l_;`D0;Rh^0P0];Bd202`/;080:b/[0P0Z:RX202TY:@P0
:RXZ100[:b/402d];@0302h^;P0_;bl0;bl_0080<30`0P0a<C42038b<P80=3@d0P0e=CD203Hf=P80
>3Ph0P0j>SX203`l?080?clo0P11@D4204A4A080B4Q80P1;Bd/00`1>CTh0DU9B059BDP0205EEE@80
FEUI0P1MGEd2065QH@80I6AT0P1XJ6PE0?ooo`004`3oool206e]K@80Kfm_0P1aLG4207=cL`80MGEe
0P1gMgL207UiN@80NWYj00<0O7al07inOP1nOWh00P20P8020861P@80Ph>30P25QHD208N7Q`80RHV9
0P2:RXX208b<S080SXj>0P2?Shl2096AT@80TY:B0P2DU9@209FEU@0309NGU`2HV9P0V9RH0080VYZJ
0P2KVi/209bLW080WIfM102NWYh409fMW@80UYJF0P2@T90208V9R@80P8200P1fMWH206a/K003065Q
H@1EEED0EEEE0080B4Q80P13@d<204M7A`80BTY:0P1=CDd204m?C`80DE5A0P1CDe<205ADE080EUIF
0P1GEeL205QHF0@0FEUI1@1JFUX405UIF@@0F5QH0P1GEeL205IFEP80EEEE0P1DE5@2059BDP80DE5A
0P1?Cdl204i>CP80C4a<00<0BTY:04Q8B018B4P00P16ATH204A4A080@D510P0o?cl203`l?080>SXj
0P0h>3P203Hf=P80=3@d0P0b<S82034a<@80;bl_0P0^;Rh202d];@0302`/;00[:b/0:b/[0080;2`/
100[:b/202XZ:P80:BTY0P0X:2P402TY:@80:2PX100Y:BT202XZ:P@0:b/[00<0;Bd]02l_;`0_;bl0
0P0`<302034a<@80<S8b0P0c<c<203@d=080=SHf0P0h>3P203Xj>P80?3`l0P0n?Sh20451@@80A4A4
0P17AdL204];B`0304i>CP1BDU80DU9B0080EEEE0P1IFET205eMG@80H61P0P1TI6@206MWIaD0oooo
000C0?ooo`80KFe]0P1_Kfl2075aL@80Lg=c0P1eMGD207MgM`80NGUi0P1jNWX00`1lO7`0OWin07in
OP020820P080PH610P23Ph<208F5Q@80QhN70P29RHT208Z:RP80S8b<0P2>SXh208n?S`80TI6A0P2B
TY8209BDU080UIFE00<0UiNG09RHV02HV9P00P2JVYX209^KV`80W9bL0P2MWId409jNWP@0WIfM0P2F
UYH2092@T080RHV90P20P80207IfMP80K6a/00<0HF5Q05EEE@1EEED00P18B4P204=3@`80AdM70P1:
BTX204e=C@80Cdm?0P1ADE4205=CD`80E5AD0P1FEUH205MGE`80F5QH101IFET505YJFP@0FEUI101H
F5P205MGE`80EUIF0P1EEED205ADE080DU9B0P1ADE4204m?C`80CTi>0P1<C4`00`1:BTX0B4Q804Q8
B00204I6AP80A4A40P11@D4203lo?`80?3`l0P0j>SX203Ph>080=SHf0P0d=3@2038b<P80<C4a0P0_
;bl202h^;P80;Bd]00<0;2`/02/[:`0[:b/00P0/;2`402/[:`80:RXZ0P0Y:BT202PX:0@0:BTY0P0X
:2P402TY:@80:RXZ100[:b/00`0];Bd0;bl_02l_;`02030`<080<C4a0P0b<S8203<c<`80=3@d0P0f
=SH203Ph>080>SXj0P0l?3`203hn?P80@D510P14A4@204M7A`80Bd];00<0CTi>059BDP1BDU800P1E
EED205UIF@80GEeM0P1PH60206ATI080IfMW5@3oool001<0oooo0P1^KVh2071`L080LG5a0P1cLg<2
07EeM@80MgMg0P1iNGT207]kN`0307emO@1oOgl0Ogmo0080PH610P22PX8208B4Q080QXJ60P28R8P2
08V9R@80Rh^;0P2=SHd208n?S`80TI6A0P2BTY8209BDU080UIFE0P2FUYH00`2HV9P0VYZJ09ZJVP02
09^KV`80WIfM0P2NWYh209nOW`@0X:2P0P2OWil209jNWP80V9RH0P2BTY8208^;R`80Ph>30P1kNg/2
075aL@0306MWI`1KFe/0Fe]K0080D51@0P15ADD204M7A`80BDU90P1<C4`204m?C`80DE5A0P1CDe<2
05EEE@@0EeMG0P1HF5P405UIF@D0FUYJ101IFET405QHF080EeMG0P1FEUH205EEE@80E5AD0P1BDU82
055AD@80Cdm?0P1>CTh204a<C00304Y:BP18B4P0B4Q80080ATI60P13@d<20410@080?Cdm0P0k>c/2
03Ti>@80=cLg0P0e=CD203<c<`80<30`0P0_;bl202d];@80;2`/0P0[:b/00`0Z:RX0:BTY02TY:@04
02XZ:P80:b/[0P0Y:BT202XZ:P@0:2PX100W9bL602PX:080:BTY0P0Z:RX00`0[:b/0;Bd]02d];@02
02h^;P80;bl_0P0`<302038b<P80<c<c0P0e=CD203Lg=`80>CTi0P0l?3`203hn?P80@D510P14A4@2
04M7A`80Bd];00<0CTi>059BDP1BDU800P1EEED205UIF@80GEeM0P1PH60206ATI080J6QX5@3oool0
01<0oooo0P1^KVh2071`L080LG5a0P1cLg<207EeM@80MgMg0P1iNGT207]kN`0307emO@1oOgl0Ogmo
0080PH610P22PX8208B4Q080QXJ60P28R8P208V9R@80Rh^;0P2=SHd208n?S`80TI6A0P2BTY8209BD
U080UIFE0P2FUYH00`2HV9P0VYZJ09ZJVP0209^KV`80WIfM0P2NWYh209nOW`@0X:2P0P2OWil209jN
WP80V9RH0P2BTY8208^;R`80Ph>30P1kNg/2075aL@0306MWI`1KFe/0Fe]K0080D51@0P15ADD204M7
A`80BDU90P1<C4`204m?C`80DE5A0P1CDe<205EEE@@0EeMG0P1HF5P405UIF@D0FUYJ101IFET405QH
F080EeMG0P1FEUH205EEE@80E5AD0P1BDU82055AD@80Cdm?0P1>CTh204a<C00304Y:BP18B4P0B4Q8
0080ATI60P13@d<20410@080?Cdm0P0k>c/203Ti>@80=cLg0P0e=CD203<c<`80<30`0P0_;bl202d]
;@80;2`/0P0[:b/00`0Z:RX0:BTY02TY:@0402XZ:P80:b/[0P0Y:BT202XZ:P@0:2PX100W9bL602PX
:080:BTY0P0Z:RX00`0[:b/0;Bd]02d];@0202h^;P80;bl_0P0`<302038b<P80<c<c0P0e=CD203Lg
=`80>CTi0P0l?3`203hn?P80@D510P14A4@204M7A`80Bd];00<0CTi>059BDP1BDU800P1EEED205UI
F@80GEeM0P1PH60206ATI080J6QX5@3oool001<0oooo0P1^KVh2071`L080LW9b0P1cLg<207EeM@80
MgMg0P1iNGT207]kN`0307emO@1oOgl0Ogmo0080PH610P23Ph<208F5Q@80QhN70P29RHT208Z:RP80
S8b<0P2>SXh2092@T080TI6A0P2CTi<209FEU@80UYJF0P2HV9P00`2JVYX0Vi^K09^KV`0209fMW@80
WYjN0P2OWil40:6QX@80XZ:R0P2QXJ4209nOW`80VYZJ0P2EUID208j>SP80QXJ60P1nOWh207EeM@03
06a/K01QHF40HF5Q0080EEEE0P19BDT204E5A@80BDU90P1=CDd2051@D080DU9B0P1DE5@205EEE@80
EeMG0P1HF5P205UIF@D0FUYJ101KFe/205YJFP@0FEUI0P1HF5P205MGE`80EUIF0P1EEED205ADE080
De=C0P1ADE4204m?C`80CDe=0P1<C4`00`1:BTX0B4Q804Q8B00204E5A@80@d=30P10@40203dm?@80
>SXj0P0g=cL203Hf=P80=3@d0P0b<S8202l_;`80;Bd]0P0/;2`202XZ:P<0:BTY0P0X:2P402TY:@@0
:RXZ100Y:BT202PX:0@09bLW100X:2P402LW9`80:2PX00<0:BTY02XZ:P0Z:RX00P0/;2`202d];@80
;Rh^0P0`<302038b<P80=3@d0P0f=SH203Ti>@80>c/k0P0n?Sh20451@@80A4A40P17AdL204];B`03
04i>CP1BDU80DU9B0080EEEE0P1IFET205eMG@80H61P0P1TI6@206QXJ1D0oooo000C0?ooo`80KVi^
0P1`L702079bLP80Lg=c0P1eMGD207MgM`80NGUi0P1kNg/00`1mOGd0Ogmo07moO`020861P@80Ph>3
0P25QHD208N7Q`80RHV90P2:RXX208b<S080SXj>0P2@T902096AT@80Ti>C0P2EUID209JFUP80V9RH
00<0VYZJ09^KV`2KVi/00P2MWId209jNWP80WinO102QXJ420::RXP80XJ6Q0P2OWil209ZJVP80UIFE
0P2>SXh208J6QP80OWin0P1eMGD00`1/K6`0HF5Q065QH@0205EEE@80BDU90P15ADD204U9B@80CDe=
0P1@D502059BDP80E5AD0P1EEED205MGE`80F5QH0P1IFET505YJFP@0Fe]K0P1JFUX405UIF@80F5QH
0P1GEeL205IFEP80EEEE0P1DE5@205=CD`80DE5A0P1?Cdl204e=C@80C4a<00<0BTY:04Q8B018B4P0
0P15ADD204=3@`80@4100P0m?Cd203Xj>P80=cLg0P0f=SH203@d=080<S8b0P0_;bl202d];@80;2`/
0P0Z:RX302TY:@80:2PX100Y:BT402XZ:P@0:BTY0P0X:2P402LW9`@0:2PX100W9bL202PX:00302TY
:@0Z:RX0:RXZ0080;2`/0P0];Bd202h^;P80<30`0P0b<S8203@d=080=SHf0P0i>CT203/k>`80?Shn
0P11@D4204A4A080AdM70P1;Bd/00`1>CTh0DU9B059BDP0205EEE@80FEUI0P1MGEd2061PH080I6AT
0P1XJ6PE0?ooo`004`3oool206i^KP80L71`0P1bLW8207AdM080MWIf0P1hN7P207YjNP80O7al00<0
OWin0820P020P8000P22PX8208B4Q080QXJ60P28R8P208Z:RP80Rh^;0P2=SHd208n?S`80TI6A0P2B
TY8209BDU080UYJF0P2HV9P209VIV@0309^KV`2MWId0WIfM0080WYjN0P2PX:020:6QX@80XZ:R0P2S
Xj<20:BTY080Xj>S0P2PX:0209^KV`80UYJF0P2?Shl208R8R080PH610P1hN7P00`1_Kfl0IFEU06EU
I@0205YJFP80D51@0P17AdL204Y:BP80CTi>0P1@D50205=CD`80EEEE0P1GEeL205QHF080FEUI0P1J
FUX;05]KF`80FUYJ0P1IFET405QHF080EeMG0P1FEUH205ADE080De=C0P1ADE4204m?C`80CTi>0P1;
Bd/00`1:BTX0B4Q804Q8B00204E5A@80@d=30P10@40203dm?@80>CTi0P0f=SH203De=@80<c<c0P0`
<30202h^;P80;2`/0P0[:b/202TY:@80:2PX0`0W9bL402TY:@H0:2PX0P0W9bL402DU9@@09RHV0P0W
9bL402HV9P<0:2PX0P0Y:BT202XZ:P80;2`/0P0];Bd202l_;`80<C4a0P0c<c<203Hf=P80>3Ph0P0k
>c/203dm?@80@D510P14A4@204M7A`80BTY:00<0CTi>059BDP1BDU800P1EEED205UIF@80GEeM0P1P
H60206ATI080J6QX5@3oool001<0oooo0P1^KVh2071`L080LW9b0P1dM7@207IfMP80N7Qh0P1jNWX2
07alO00307inOP20P800P8200080PX:20P24Q8@208J6QP80R8R80P2:RXX208^;R`80SHf=0P2?Shl2
096AT@80TY:B0P2DU9@209JFUP80V9RH0P2IVIT00`2KVi/0WIfM09fMW@0209jNWP80X:2P0P2QXJ42
0::RXP80Xj>S0P2TY:@20:>SX`80X:2P0P2KVi/209JFUP80Shn?0P28R8P20861P@80N7Qh00<0Kfm_
06EUI@1UIFD00P1JFUX2051@D080AdM70P1:BTX204i>CP80D51@0P1CDe<205EEE@80EeMG0P1HF5P2
05UIF@80FUYJ2`1KFe/205YJFP80FEUI101HF5P205MGE`80EUIF0P1DE5@205=CD`80DE5A0P1?Cdl2
04i>CP80Bd];00<0BTY:04Q8B018B4P00P15ADD204=3@`80@4100P0m?Cd203Ti>@80=SHf0P0e=CD2
03<c<`80<30`0P0^;Rh202`/;080:b/[0P0Y:BT202PX:0<09bLW100Y:BT602PX:0809bLW100U9BD4
02HV9P809bLW100V9RH302PX:080:BTY0P0Z:RX202`/;080;Bd]0P0_;bl2034a<@80<c<c0P0f=SH2
03Ph>080>c/k0P0m?Cd20451@@80A4A40P17AdL204Y:BP0304i>CP1BDU80DU9B0080EEEE0P1IFET2
05eMG@80H61P0P1TI6@206QXJ1D0oooo000C0?ooo`80KVi^0P1`L702079bLP80M7Ad0P1fMWH207Qh
N080NWYj0P1lO7`00`1nOWh0P8200820P00208:2PP80Q8B40P26QXH208R8R080Rh^;0P2<S8`208j>
SP80T92@0P2BTY8209BDU080UIFE0P2GUiL209VIV@80Vi^K00<0W9bL09jNWP2NWYh00P2PX:020::R
XP80Xj>S0P2TY:@20:FUY@80YZJV0P2TY:@20::RXP80WIfM0P2GUiL2092@T080RHV90P23Ph<207Yj
NP03075aL@1XJ6P0J6QX0080GUiN0P1DE5@204U9B@80C4a<0P1?Cdl2059BDP80EEEE0P1GEeL205QH
F080FUYJ0P1KFe/405aLG0<0GEeM1P1LG5`205]KF`80FUYJ0P1IFET205QHF080EeMG0P1FEUH205EE
E@80De=C0P1BDU82051@D080CTi>0P1<C4`00`1:BTX0B4Q804Q8B00204I6AP80@d=30P10@40203`l
?080>CTi0P0f=SH203@d=080<S8b0P0_;bl202d];@80:b/[0P0Z:RX202TY:@80:2PX0`0W9bL602TY
:@@09bLW0P0V9RH602@T90809BDU1P0V9RH302LW9`@0:2PX0P0Y:BT202/[:`80;Bd]0P0_;bl2038b
<P80=CDe0P0g=cL203/k>`80?Cdm0P10@40204=3@`80AdM70P1:BTX00`1>CTh0DU9B059BDP0205EE
E@80FEUI0P1MGEd2061PH080I6AT0P1XJ6PE0?ooo`004`3oool206i^KP80L71`0P1bLW8207AdM080
MWIf0P1hN7P207YjNP80O7al00<0OWin0820P020P8000P22PX8208B4Q080QXJ60P28R8P208^;R`80
S8b<0P2>SXh2092@T080TY:B0P2DU9@209FEU@80UiNG0P2IVIT209^KV`0309bLW02NWYh0WYjN0080
X:2P0P2RXZ820:>SX`80Y:BT0P2UYJD20:JVYP80Y:BT0P2RXZ8209fMW@80UiNG0P2@T90208V9R@80
Ph>30P1jNWX00`1aLG40J6QX06QXJ00205iNGP80E5AD0P19BDT204a<C080Cdm?0P1BDU8205EEE@80
EeMG0P1HF5P205YJFP80Fe]K101LG5`305eMG@H0G5aL0P1KFe/205YJFP80FEUI0P1HF5P205MGE`80
EUIF0P1EEED205=CD`80DU9B0P1@D50204i>CP80C4a<00<0BTY:04Q8B018B4P00P16ATH204=3@`80
@4100P0l?3`203Ti>@80=SHf0P0d=3@2038b<P80;bl_0P0];Bd202/[:`80:RXZ0P0Y:BT202PX:0<0
9bLW1P0Y:BT402LW9`809RHV1P0T92@202DU9@H09RHV0`0W9bL402PX:080:BTY0P0[:b/202d];@80
;bl_0P0b<S8203De=@80=cLg0P0k>c/203dm?@80@4100P13@d<204M7A`80BTY:00<0CTi>059BDP1B
DU800P1EEED205UIF@80GEeM0P1PH60206ATI080J6QX5@3oool001<0oooo0P1^KVh2071`L080LW9b
0P1eMGD207IfMP80N7Qh0P1jNWX207alO00307moO`21PH40PH610080Ph>30P25QHD208N7Q`80RHV9
0P2;Rh/208f=S@80Shn?0P2ATI4209>CT`80UIFE0P2GUiL209RHV080VYZJ0P2LW9`00`2NWYh0WinO
09nOW`020:6QX@80Xj>S0P2UYJD20:JVYP80YjNW0P2XZ:P20:JVYP80Xj>S0P2OWil209VIV@80Ti>C
0P2<S8`208B4Q080O7al00<0Lg=c06][J`1[Jf/00P1QHF4205QHF080C4a<0P1?Cdl2055AD@80E5AD
0P1GEeL205QHF080FUYJ0P1LG5`205eMG@T0GUiN101MGEd205aLG080Fe]K0P1JFUX205UIF@80F5QH
0P1GEeL205EEE@80E5AD0P1CDe<2055AD@80Cdm?0P1=CDd00`1;Bd/0B4Q804Q8B00204I6AP80A4A4
0P10@40203dm?@80>CTi0P0f=SH203@d=080<C4a0P0_;bl202d];@80:b/[0P0Z:RX402PX:0<09RHV
0P0X:2P402TY:@80:2PX0P0W9bL202HV9P8092@T1P0S8b<202@T90@09BDU0`0V9RH402LW9`80:2PX
0P0Y:BT202`/;080;Rh^0P0a<C4203@d=080=cLg0P0i>CT203dm?@80@4100P13@d<204I6AP80BTY:
00<0CTi>059BDP1BDU800P1EEED205UIF@80GEeM0P1PH60206ATI080J6QX5@3oool001<0oooo0P1^
KVh2071`L080LW9b0P1eMGD207IfMP80N7Qh0P1jNWX207alO00307moO`21PH40PH610080Ph>30P25
QHD208N7Q`80RHV90P2;Rh/208f=S@80Shn?0P2ATI4209>CT`80UIFE0P2GUiL209RHV080VYZJ0P2L
W9`00`2NWYh0WinO09nOW`020:6QX@80Xj>S0P2UYJD20:JVYP80YjNW0P2XZ:P20:JVYP80Xj>S0P2O
Wil209VIV@80Ti>C0P2<S8`208B4Q080O7al00<0Lg=c06][J`1[Jf/00P1QHF4205QHF080C4a<0P1?
Cdl2055AD@80E5AD0P1GEeL205QHF080FUYJ0P1LG5`205eMG@T0GUiN101MGEd205aLG080Fe]K0P1J
FUX205UIF@80F5QH0P1GEeL205EEE@80E5AD0P1CDe<2055AD@80Cdm?0P1=CDd00`1;Bd/0B4Q804Q8
B00204I6AP80A4A40P10@40203dm?@80>CTi0P0f=SH203@d=080<C4a0P0_;bl202d];@80:b/[0P0Z
:RX402PX:0<09RHV0P0X:2P402TY:@80:2PX0P0W9bL202HV9P8092@T1P0S8b<202@T90@09BDU0`0V
9RH402LW9`80:2PX0P0Y:BT202`/;080;Rh^0P0a<C4203@d=080=cLg0P0i>CT203dm?@80@4100P13
@d<204I6AP80BTY:00<0CTi>059BDP1BDU800P1EEED205UIF@80GEeM0P1PH60206ATI080J6QX5@3o
ool001<0oooo0P1^KVh2071`L080LW9b0P1eMGD207MgM`80NGUi0P1kNg/207emO@0307moO`21PH40
PH610080Ph>30P25QHD208N7Q`80RXZ:0P2<S8`208j>SP80T92@0P2BTY8209BDU080UYJF0P2HV9P2
09VIV@80Vi^K0P2MWId00`2OWil0XJ6Q0:6QX@020::RXP80Y:BT0P2VYZH20:RXZ080ZJVY0P2ZZZX2
0:NWY`80Y:BT0P2PX:0209ZJVP80U9BD0P2>SXh208J6QP80OWin00<0MWIf06e]K@1]KFd00P1SHf<2
05UIF@80Cdm?0P1BDU8205ADE080EeMG0P1IFET205]KF`80GEeM0P1NGUh205mOG`T0H61P101OGel2
05iNGP80GEeM0P1LG5`205YJFP80FEUI0P1HF5P205MGE`80EEEE0P1DE5@2059BDP80D51@0P1>CTh0
0`1<C4`0BTY:04Y:BP0204M7A`80ADE50P11@D4203dm?@80>SXj0P0g=cL203@d=080<C4a0P0_;bl2
02`/;080:b/[0P0Y:BT202PX:0809bLW0`0U9BD202HV9P80:2PX0P0Y:BT202PX:0809RHV0P0U9BD2
02<S8`808R8R100Q8B42028R8P8092@T0P0U9BD202HV9P0302DU9@0V9RH09RHV00H09bLW0P0Z:RX2
02d];@80<30`0P0c<c<203Hf=P80>CTi0P0l?3`20410@080@d=30P16ATH204Y:BP0304i>CP1BDU80
DU9B0080EEEE0P1IFET205eMG@80H61P0P1TI6@206QXJ1D0oooo000C0?ooo`80KVi^0P1`L70207=c
L`80MGEe0P1gMgL207UiN@80Ng]k0P1mOGd00`1oOgl0PX:208:2PP0208B4Q080QXJ60P28R8P208Z:
RP80SHf=0P2?Shl2096AT@80Ti>C0P2EUID209NGU`80VIVI0P2JVYX209fMW@80WYjN00<0X:2P0::R
XP2RXZ800P2TY:@20:JVYP80Z:RX0P2ZZZX20:^[Z`80ZZZZ0P2XZ:P20:FUY@80XJ6Q0P2KVi/209FE
U@80Shn?0P27QhL207moO`0307QhN01`L700L71`0080IVIV0P1LG5`2055AD@80EEEE0P1GEeL205YJ
FP80G5aL0P1NGUh205mOG`80HF5Q101RHV8706=SH`80HV9R0P1QHF42061PH080GemO0P1NGUh205aL
G080Fe]K0P1JFUX205UIF@80EeMG0P1EEED205=CD`80DE5A0P1?Cdl00`1=CDd0Bd];04];B`0204U9
B@80ATI60P12@T8203lo?`80?3`l0P0i>CT203De=@80<S8b0P0_;bl202d];@80:b/[0P0Y:BT202LW
9`809BDU0`0T92@202DU9@809bLW100X:2P202LW9`809BDU0P0S8b<2028R8P808B4Q100P8202024Q
8@808b<S0`0T92@202DU9@H09RHV0P0Y:BT202/[:`80;bl_0P0b<S8203De=@80>3Ph0P0l?3`203lo
?`80@d=30P16ATH204Y:BP0304i>CP1ADE40DE5A0080EEEE0P1IFET205eMG@80H61P0P1TI6@206QX
J1D0oooo000C0?ooo`80KVi^0P1`L70207=cL`80MGEe0P1gMgL207UiN@80Ng]k0P1mOGd00`1oOgl0
PX:208:2PP0208B4Q080QXJ60P28R8P208Z:RP80SHf=0P2?Shl2096AT@80Ti>C0P2EUID209NGU`80
VIVI0P2JVYX209fMW@80WYjN00<0X:2P0::RXP2RXZ800P2TY:@20:JVYP80Z:RX0P2ZZZX20:^[Z`80
ZZZZ0P2XZ:P20:FUY@80XJ6Q0P2KVi/209FEU@80Shn?0P27QhL207moO`0307QhN01`L700L71`0080
IVIV0P1LG5`2055AD@80EEEE0P1GEeL205YJFP80G5aL0P1NGUh205mOG`80HF5Q101RHV8706=SH`80
HV9R0P1QHF42061PH080GemO0P1NGUh205aLG080Fe]K0P1JFUX205UIF@80EeMG0P1EEED205=CD`80
DE5A0P1?Cdl00`1=CDd0Bd];04];B`0204U9B@80ATI60P12@T8203lo?`80?3`l0P0i>CT203De=@80
<S8b0P0_;bl202d];@80:b/[0P0Y:BT202LW9`809BDU0`0T92@202DU9@809bLW100X:2P202LW9`80
9BDU0P0S8b<2028R8P808B4Q100P8202024Q8@808b<S0`0T92@202DU9@H09RHV0P0Y:BT202/[:`80
;bl_0P0b<S8203De=@80>3Ph0P0l?3`203lo?`80@d=30P16ATH204Y:BP0304i>CP1ADE40DE5A0080
EEEE0P1IFET205eMG@80H61P0P1TI6@206QXJ1D0oooo000C0?ooo`80KVi^0P1`L70207=cL`80MGEe
0P1gMgL207UiN@80Ng]k0P1nOWh00`20P800PX:208:2PP0208B4Q080QXJ60P29RHT208^;R`80SHf=
0P2?Shl2096AT@80U9BD0P2FUYH209RHV080VYZJ0P2LW9`209jNWP80X:2P00<0XJ6Q0:BTY02TY:@0
0P2UYJD20:NWY`80ZJVY0P2[Zj/20:f][@80Zj^[0P2XZ:P20:FUY@80XJ6Q0P2KVi/209JFUP80T92@
0P28R8P208:2PP0307]kN`1bLW80LW9b0080J6QX0P1OGel205EEE@80F5QH0P1JFUX205eMG@80GemO
0P1QHF42069RHP80I6AT101UIFD206IVIP80IfMW0`1VIVH206EUI@80I6AT0P1SHf<2069RHP80H61P
0P1OGel205eMG@80G5aL0P1JFUX205UIF@80EeMG0P1EEED205=CD`80DE5A00<0Cdm?04a<C01<C4`0
0P1:BTX204M7A`80@d=30P11@D4203hn?P80>SXj0P0f=SH203<c<`80<30`0P0^;Rh202/[:`80:BTY
0P0W9bL202DU9@0302<S8`0R8R808R8R00808b<S0P0U9BD202HV9P@09bLW0P0V9RH202@T90808B4Q
1P0O7al2020P80808B4Q1`0S8b<202@T90809BDU0P0X:2P202XZ:P80;Bd]0P0a<C4203De=@80>3Ph
0P0k>c/203lo?`80@T920P16ATH204Y:BP0304i>CP1ADE40DE5A0080EEEE0P1IFET205eMG@80HF5Q
0P1TI6@206QXJ1D0oooo000C0?ooo`80KVi^0P1`L70207=cL`80MGEe0P1gMgL207UiN@80Ng]k0P1n
OWh00`20P800PX:208:2PP0208B4Q080QXJ60P29RHT208^;R`80SHf=0P2?Shl2096AT@80U9BD0P2F
UYH209RHV080VYZJ0P2LW9`209jNWP80X:2P00<0XJ6Q0:BTY02TY:@00P2UYJD20:NWY`80ZJVY0P2[
Zj/20:f][@80Zj^[0P2XZ:P20:FUY@80XJ6Q0P2KVi/209JFUP80T92@0P28R8P208:2PP0307]kN`1b
LW80LW9b0080J6QX0P1OGel205EEE@80F5QH0P1JFUX205eMG@80GemO0P1QHF42069RHP80I6AT101U
IFD206IVIP80IfMW0`1VIVH206EUI@80I6AT0P1SHf<2069RHP80H61P0P1OGel205eMG@80G5aL0P1J
FUX205UIF@80EeMG0P1EEED205=CD`80DE5A00<0Cdm?04a<C01<C4`00P1:BTX204M7A`80@d=30P11
@D4203hn?P80>SXj0P0f=SH203<c<`80<30`0P0^;Rh202/[:`80:BTY0P0W9bL202DU9@0302<S8`0R
8R808R8R00808b<S0P0U9BD202HV9P@09bLW0P0V9RH202@T90808B4Q1P0O7al2020P80808B4Q1`0S
8b<202@T90809BDU0P0X:2P202XZ:P80;Bd]0P0a<C4203De=@80>3Ph0P0k>c/203lo?`80@T920P16
ATH204Y:BP0304i>CP1ADE40DE5A0080EEEE0P1IFET205eMG@80HF5Q0P1TI6@206QXJ1D0oooo000C
0?ooo`80KVi^0P1`L70207=cL`80MGEe0P1gMgL207YjNP80O7al0P1nOWh00`20P800Ph>308>3P`02
08F5Q@80QhN70P29RHT208b<S080SXj>0P2@T90209:BTP80U9BD0P2FUYH209RHV080VYZJ0P2MWId2
09nOW`80XJ6Q00<0Xj>S0:FUY@2UYJD00P2WYjL20:VYZ@80Zj^[0P2][Jd20:j^[P80[:b/0P2ZZZX2
0:JVYP80XZ:R0P2LW9`209NGU`80TI6A0P2:RXX208B4Q00307emO@1cLg<0Lg=c0080JVYZ0P1RHV82
05QHF080G5aL0P1MGEd2061PH080HV9R0P1TI6@206IVIP80IfMW0P1XJ6P406UYJ@<0JVYZ101YJFT2
06QXJ080IfMW0P1UIFD206=SH`80HF5Q0P1OGel205iNGP80G5aL0P1KFe/205UIF@80EeMG0P1EEED2
05=CD`03051@D01>CTh0CTi>0080C4a<0P19BDT204E5A@80@T920P0o?cl203/k>`80>3Ph0P0e=CD2
038b<P80;bl_0P0[:b/202TY:@809bLW0P0U9BD00`0T92@08R8R028R8P02028R8P808b<S0P0U9BD2
02LW9`80:2PX0P0W9bL202@T90808R8R0P0O7al601hN7P80820P1`0Q8B42028R8P8092@T0P0W9bL2
02TY:@80;Bd]0P0`<30203<c<`80=cLg0P0k>c/203lo?`80@T920P16ATH204Y:BP0304e=C@1ADE40
DE5A0080EEEE0P1IFET205eMG@80H61P0P1TI6@206QXJ1D0oooo000C0?ooo`80KVi^0P1`L70207=c
L`80MGEe0P1gMgL207YjNP80O7al0P1nOWh00`20P800Ph>308>3P`0208F5Q@80QhN70P29RHT208b<
S080SXj>0P2@T90209:BTP80U9BD0P2FUYH209RHV080VYZJ0P2MWId209nOW`80XJ6Q00<0Xj>S0:FU
Y@2UYJD00P2WYjL20:VYZ@80Zj^[0P2][Jd20:j^[P80[:b/0P2ZZZX20:JVYP80XZ:R0P2LW9`209NG
U`80TI6A0P2:RXX208B4Q00307emO@1cLg<0Lg=c0080JVYZ0P1RHV8205QHF080G5aL0P1MGEd2061P
H080HV9R0P1TI6@206IVIP80IfMW0P1XJ6P406UYJ@<0JVYZ101YJFT206QXJ080IfMW0P1UIFD206=S
H`80HF5Q0P1OGel205iNGP80G5aL0P1KFe/205UIF@80EeMG0P1EEED205=CD`03051@D01>CTh0CTi>
0080C4a<0P19BDT204E5A@80@T920P0o?cl203/k>`80>3Ph0P0e=CD2038b<P80;bl_0P0[:b/202TY
:@809bLW0P0U9BD00`0T92@08R8R028R8P02028R8P808b<S0P0U9BD202LW9`80:2PX0P0W9bL202@T
90808R8R0P0O7al601hN7P80820P1`0Q8B42028R8P8092@T0P0W9bL202TY:@80;Bd]0P0`<30203<c
<`80=cLg0P0k>c/203lo?`80@T920P16ATH204Y:BP0304e=C@1ADE40DE5A0080EEEE0P1IFET205eM
G@80H61P0P1TI6@206QXJ1D0oooo000C0?ooo`80KVi^0P1`L70207=cL`80MGEe0P1hN7P207YjNP80
O7al0P1nOWh00`21PH40Ph>308>3P`0208J6QP80R8R80P2:RXX208b<S080Shn?0P2ATI4209>CT`80
UIFE0P2HV9P209ZJVP80W9bL0P2NWYh20:2PX080XZ:R00<0Y:BT0:JVYP2VYZH00P2XZ:P20:ZZZP80
[:b/102^[Zh20:f][@80ZZZZ0P2WYjL20::RXP80W9bL0P2HV9P209:BTP80S8b<0P25QHD00`1oOgl0
MWIf07IfMP0206e]K@80IFEU0P1LG5`205mOG`80HV9R0P1TI6@206IVIP80J6QX0P1ZJVX206][J`80
K6a/0P1]KFd706i^KP80KFe]0P1/K6`206][J`80JFUY0P1XJ6P206EUI@80Hf=S0P1QHF4205mOG`80
GUiN0P1LG5`205YJFP80F5QH0P1EEED00`1CDe<0D51@051@D00204i>CP80Bd];0P19BDT204E5A@80
@D510P0m?Cd203Xj>P80=SHf0P0c<c<202l_;`80:b/[0P0W9bL202HV9P809BDU00<092@T028R8P0R
8R80100Q8B42028R8P8092@T0P0V9RH202PX:0809RHV0P0R8R82020P80807QhN100M7Ad201hN7P80
7alO1`0P820202<S8`809RHV0P0Y:BT202`/;080<30`0P0c<c<203Lg=`80>SXj0P0n?Sh20492@P80
ADE50P19BDT00`1=CDd0DE5A055AD@0205EEE@80FEUI0P1MGEd2061PH080I6AT0P1XJ6PE0?ooo`00
4`3oool206i^KP80L71`0P1cLg<207EeM@80N7Qh0P1jNWX207alO080OWin00<0PH6108>3P`23Ph<0
0P26QXH208R8R080RXZ:0P2<S8`208n?S`80TI6A0P2CTi<209FEU@80V9RH0P2JVYX209bLW080WYjN
0P2PX:020::RXP030:BTY02VYZH0YZJV0080Z:RX0P2ZZZX20:b/[0@0[Zj^0P2][Jd20:ZZZP80YjNW
0P2RXZ8209bLW080V9RH0P2BTY8208b<S080QHF500<0Ogmo07IfMP1fMWH00P1]KFd206EUI@80G5aL
0P1OGel2069RHP80I6AT0P1VIVH206QXJ080JVYZ0P1[Jf/206a/K080KFe]1`1^KVh206e]K@80K6a/
0P1[Jf/206UYJ@80J6QX0P1UIFD206=SH`80HF5Q0P1OGel205iNGP80G5aL0P1JFUX205QHF080EEEE
00<0De=C051@D01@D5000P1>CTh204];B`80BDU90P15ADD20451@@80?Cdm0P0j>SX203Hf=P80<c<c
0P0_;bl202/[:`809bLW0P0V9RH202DU9@0302@T900R8R808R8R00@08B4Q0P0R8R8202@T90809RHV
0P0X:2P202HV9P808R8R0P0P820201hN7P@07AdM0P0N7Qh201lO7`L0820P0P0S8b<202HV9P80:BTY
0P0/;2`2030`<080<c<c0P0g=cL203Xj>P80?Shn0P12@T8204E5A@80BDU900<0CDe=055AD@1ADE40
0P1EEED205UIF@80GEeM0P1PH60206ATI080J6QX5@3oool001<0oooo0P1^KVh2075aL@80Lg=c0P1f
MWH207QhN080NWYj0P1mOGd207moO`030861P@24Q8@0Q8B40080QXJ60P29RHT208^;R`80SHf=0P2?
Shl209:BTP80U9BD0P2FUYH209VIV@80VYZJ0P2MWId209nOW`80XJ6Q0P2SXj<00`2UYJD0Z:RX0:RX
Z0020:ZZZP80[:b/0P2^[Zh40:n_[`80[Jf]0P2ZZZX20:NWY`80Xj>S0P2MWId209RHV080TY:B0P2>
SXh208N7Q`030861P@1iNGT0NGUi0080LG5a0P1YJFT2061PH080I6AT0P1VIVH206QXJ080Jf][0P1]
KFd206i^KP80L71`0P1aLG46079bLP<0Lg=c0P1bLW82071`L080Kfm_0P1]KFd206a/K080JVYZ0P1W
IfL206EUI@80Hf=S0P1QHF4205mOG`80GEeM0P1KFe/205QHF00305IFEP1CDe<0De=C0080D51@0P1=
CDd204a<C080B4Q80P13@d<203lo?`80?3`l0P0g=cL203<c<`80<30`0P0/;2`202PX:0809RHV0P0U
9BD00`0S8b<08R8R028R8P02020P80807alO0P0P820202<S8`8092@T0P0V9RH202DU9@808b<S0P0Q
8B4201hN7P807AdM0P0L71`201dM7@807QhN00<07alO01hN7P0N7Qh00P0O7al2020P80808R8R0P0U
9BD202PX:080:b/[0P0_;bl203<c<`80=SHf0P0j>SX203hn?P80@T920P15ADD204U9B@0304e=C@1A
DE40DE5A0080EEEE0P1IFET205eMG@80H61P0P1TI6@206QXJ1D0oooo000C0?ooo`80KVi^0P1aLG42
07=cL`80MWIf0P1hN7P207YjNP80OGem0P1oOgl00`21PH40Q8B408B4Q00208J6QP80RHV90P2;Rh/2
08f=S@80Shn?0P2BTY8209BDU080UYJF0P2IVIT209ZJVP80WIfM0P2OWil20:6QX@80Xj>S00<0YJFU
0:RXZ02XZ:P00P2ZZZX20:b/[080[Zj^102_[jl20:f][@80ZZZZ0P2WYjL20:>SX`80WIfM0P2HV9P2
09:BTP80SXj>0P27QhL00`21PH40NGUi07UiN@02075aL@80JFUY0P1PH60206ATI080IVIV0P1XJ6P2
06][J`80KFe]0P1^KVh2071`L080LG5a1P1bLW8307=cL`80LW9b0P1`L70206m_K`80KFe]0P1/K6`2
06YZJP80IfMW0P1UIFD206=SH`80HF5Q0P1OGel205eMG@80Fe]K0P1HF5P00`1FEUH0De=C05=CD`02
051@D080CDe=0P1<C4`204Q8B080@d=30P0o?cl203`l?080=cLg0P0c<c<2030`<080;2`/0P0X:2P2
02HV9P809BDU00<08b<S028R8P0R8R800P0P820201lO7`80820P0P0S8b<202@T90809RHV0P0U9BD2
02<S8`808B4Q0P0N7Qh201dM7@8071`L0P0M7Ad201hN7P0301lO7`0N7Qh07QhN00807alO0P0P8202
028R8P809BDU0P0X:2P202/[:`80;bl_0P0c<c<203Hf=P80>SXj0P0n?Sh20492@P80ADE50P19BDT0
0`1=CDd0DE5A055AD@0205EEE@80FEUI0P1MGEd2061PH080I6AT0P1XJ6PE0?ooo`004`3oool206i^
KP80LG5a0P1cLg<207IfMP80N7Qh0P1kNg/207emO@80Ogmo00<0PX:208B4Q024Q8@00P27QhL208V9
R@80S8b<0P2>SXh2096AT@80Ti>C0P2EUID209NGU`80VIVI0P2KVi/209jNWP80X:2P0P2SXj<20:FU
Y@030:NWY`2YZJT0ZJVY0080Zj^[0P2][Jd20:n_[`80/;2`0P2_[jl20:j^[P80ZZZZ0P2WYjL20:>S
X`80WYjN0P2IVIT209BDU080Shn?0P29RHT00`23Ph<0O7al07alO00207EeM@80KFe]0P1UIFD206UY
J@80Jf][0P1^KVh2071`L080LW9b0P1cLg<207AdM080MGEe0P1fMWH407MgM`<0N7Qh0P1gMgL207If
MP80MGEe0P1cLg<2075aL@80Kfm_0P1/K6`206YZJP80IfMW0P1UIFD206=SH`80H61P0P1NGUh205aL
G00305UIF@1FEUH0EUIF0080De=C0P1?Cdl204i>CP80BTY:0P15ADD20492@P80?Shn0P0i>CT203De
=@80<C4a0P0^;Rh202TY:@@09RHV00<092@T028R8P0R8R800P0P820201hN7P807alO0P0Q8B4202<S
8`@092@T0P0R8R82020P80807AdM100L71`401dM7@D07QhN0P0O7al2024Q8@809BDU0P0X:2P202/[
:`80;bl_0P0b<S8203Hf=P80>SXj0P0n?Sh20492@P80ADE50P19BDT00`1=CDd0DE5A055AD@0205EE
E@80FEUI0P1LG5`2061PH080I6AT0P1XJ6PE0?ooo`004`3oool206i^KP80LG5a0P1cLg<207IfMP80
N7Qh0P1kNg/207emO@80Ogmo00<0PX:208B4Q024Q8@00P27QhL208V9R@80S8b<0P2>SXh2096AT@80
Ti>C0P2EUID209NGU`80VIVI0P2KVi/209jNWP80X:2P0P2SXj<20:FUY@030:NWY`2YZJT0ZJVY0080
Zj^[0P2][Jd20:n_[`80/;2`0P2_[jl20:j^[P80ZZZZ0P2WYjL20:>SX`80WYjN0P2IVIT209BDU080
Shn?0P29RHT00`23Ph<0O7al07alO00207EeM@80KFe]0P1UIFD206UYJ@80Jf][0P1^KVh2071`L080
LW9b0P1cLg<207AdM080MGEe0P1fMWH407MgM`<0N7Qh0P1gMgL207IfMP80MGEe0P1cLg<2075aL@80
Kfm_0P1/K6`206YZJP80IfMW0P1UIFD206=SH`80H61P0P1NGUh205aLG00305UIF@1FEUH0EUIF0080
De=C0P1?Cdl204i>CP80BTY:0P15ADD20492@P80?Shn0P0i>CT203De=@80<C4a0P0^;Rh202TY:@@0
9RHV00<092@T028R8P0R8R800P0P820201hN7P807alO0P0Q8B4202<S8`@092@T0P0R8R82020P8080
7AdM100L71`401dM7@D07QhN0P0O7al2024Q8@809BDU0P0X:2P202/[:`80;bl_0P0b<S8203Hf=P80
>SXj0P0n?Sh20492@P80ADE50P19BDT00`1=CDd0DE5A055AD@0205EEE@80FEUI0P1LG5`2061PH080
I6AT0P1XJ6PE0?ooo`004`3oool206i^KP80LG5a0P1cLg<207IfMP80N7Qh0P1kNg/207inOP80P820
00<0Ph>308F5Q@25QHD00P27QhL208Z:RP80S8b<0P2?Shl2096AT@80U9BD0P2FUYH209RHV080Vi^K
0P2MWId209nOW`80XJ6Q0P2TY:@20:JVYP030:RXZ02ZZZX0ZZZZ0080[:b/0P2_[jl40;6a/@80/;2`
0P2^[Zh20:ZZZP80YjNW0P2SXj<209jNWP80Vi^K0P2EUID2096AT@80RXZ:00<0QHF507moO`1oOgl0
0P1hN7P2079bLP80K6a/0P1^KVh2075aL@80Lg=c0P1eMGD207IfMP80N7Qh101iNGT207YjNP@0Ng]k
00<0O7al07emO@1mOGd0101mOGd207]kN`80NGUi0P1gMgL207AdM080LW9b0P1_Kfl206a/K080JVYZ
0P1WIfL206EUI@80HV9R0P1PH6000`1MGEd0FEUI05UIF@0205EEE@80DU9B0P1ADE4204e=C@80B4Q8
0P15ADD20451@@80?3`l0P0g=cL2038b<P80;bl_0P0Z:RX202LW9`809RHV00<092@T028R8P0R8R80
0P0P820401dM7@807alO0P0R8R8402@T90808R8R0P0P820201dM7@806QXJ0P0K6a/701`L70807AdM
0P0N7Qh2024Q8@8092@T0P0X:2P202/[:`80;Rh^0P0b<S8203Hf=P80>SXj0P0m?Cd20451@@80ADE5
0P19BDT00`1=CDd0D51@051@D00205ADE080F5QH0P1LG5`2061PH080I6AT0P1XJ6PE0?ooo`004`3o
ool206i^KP80LG5a0P1cLg<207IfMP80N7Qh0P1kNg/207inOP80P82000<0Ph>308F5Q@25QHD00P27
QhL208Z:RP80S8b<0P2?Shl2096AT@80U9BD0P2FUYH209RHV080Vi^K0P2MWId209nOW`80XJ6Q0P2T
Y:@20:JVYP030:RXZ02ZZZX0ZZZZ0080[:b/0P2_[jl40;6a/@80/;2`0P2^[Zh20:ZZZP80YjNW0P2S
Xj<209jNWP80Vi^K0P2EUID2096AT@80RXZ:00<0QHF507moO`1oOgl00P1hN7P2079bLP80K6a/0P1^
KVh2075aL@80Lg=c0P1eMGD207IfMP80N7Qh101iNGT207YjNP@0Ng]k00<0O7al07emO@1mOGd0101m
OGd207]kN`80NGUi0P1gMgL207AdM080LW9b0P1_Kfl206a/K080JVYZ0P1WIfL206EUI@80HV9R0P1P
H6000`1MGEd0FEUI05UIF@0205EEE@80DU9B0P1ADE4204e=C@80B4Q80P15ADD20451@@80?3`l0P0g
=cL2038b<P80;bl_0P0Z:RX202LW9`809RHV00<092@T028R8P0R8R800P0P820401dM7@807alO0P0R
8R8402@T90808R8R0P0P820201dM7@806QXJ0P0K6a/701`L70807AdM0P0N7Qh2024Q8@8092@T0P0X
:2P202/[:`80;Rh^0P0b<S8203Hf=P80>SXj0P0m?Cd20451@@80ADE50P19BDT00`1=CDd0D51@051@
D00205ADE080F5QH0P1LG5`2061PH080I6AT0P1XJ6PE0?ooo`004`3oool206i^KP80LG5a0P1cLg<2
07IfMP80NGUi0P1kNg/207inOP80P82000<0Ph>308J6QP26QXH00P28R8P208^;R`80SHf=0P2@T902
09:BTP80UIFE0P2GUiL209VIV@80W9bL0P2NWYh20:2PX080XZ:R0P2UYJD20:NWY`030:VYZ@2[Zj/0
Zj^[0080[Zj^0P2`/;040;6a/@80/;2`0P2^[Zh20:ZZZP80YjNW0P2RXZ8209jNWP80Vi^K0P2FUYH2
09:BTP80Rh^;00<0QhN708:2PP22PX800P1lO7`207IfMP80Lg=c0P1dM7@207EeM@80MgMg0P1hN7P2
07UiN@80NWYj0P1kNg/207alO080OGem101nOWh00`1oOgl0P8200820P0020820P0@0PH610P20P802
07inOP80Ng]k0P1hN7P207IfMP80Lg=c0P1`L70206e]K@80JFUY0P1WIfL206ATI003065QH@1MGEd0
GEeM0080FEUI0P1DE5@205=CD`80D51@0P1<C4`204Y:BP80ADE50P0o?cl203Ti>@80<c<c0P0a<C42
02/[:`80:2PX0P0V9RH00`0U9BD08b<S02<S8`02020P80807AdM0P0L71`201dM7@80820P0P0R8R82
02<S8`808R8R0P0P820201dM7@806QXJ0P0I6AT501XJ6P@06a/K0P0L71`2020P80808b<S0P0V9RH2
02XZ:P80;Rh^0P0b<S8203De=@80>CTi0P0m?Cd20451@@80ADE50P19BDT00`1<C4`0D51@051@D002
05ADE080F5QH0P1LG5`2061PH080I6AT0P1XJ6PE0?ooo`004`3oool206i^KP80LG5a0P1cLg<207If
MP80NGUi0P1kNg/207inOP80P82000<0Ph>308J6QP26QXH00P28R8P208^;R`80SHf=0P2@T90209:B
TP80UIFE0P2GUiL209VIV@80W9bL0P2NWYh20:2PX080XZ:R0P2UYJD20:NWY`030:VYZ@2[Zj/0Zj^[
0080[Zj^0P2`/;040;6a/@80/;2`0P2^[Zh20:ZZZP80YjNW0P2RXZ8209jNWP80Vi^K0P2FUYH209:B
TP80Rh^;00<0QhN708:2PP22PX800P1lO7`207IfMP80Lg=c0P1dM7@207EeM@80MgMg0P1hN7P207Ui
N@80NWYj0P1kNg/207alO080OGem101nOWh00`1oOgl0P8200820P0020820P0@0PH610P20P80207in
OP80Ng]k0P1hN7P207IfMP80Lg=c0P1`L70206e]K@80JFUY0P1WIfL206ATI003065QH@1MGEd0GEeM
0080FEUI0P1DE5@205=CD`80D51@0P1<C4`204Y:BP80ADE50P0o?cl203Ti>@80<c<c0P0a<C4202/[
:`80:2PX0P0V9RH00`0U9BD08b<S02<S8`02020P80807AdM0P0L71`201dM7@80820P0P0R8R8202<S
8`808R8R0P0P820201dM7@806QXJ0P0I6AT501XJ6P@06a/K0P0L71`2020P80808b<S0P0V9RH202XZ
:P80;Rh^0P0b<S8203De=@80>CTi0P0m?Cd20451@@80ADE50P19BDT00`1<C4`0D51@051@D00205AD
E080F5QH0P1LG5`2061PH080I6AT0P1XJ6PE0?ooo`004`3oool206i^KP80LG5a0P1dM7@207IfMP80
NGUi0P1lO7`207inOP80PH6100<0Ph>308J6QP26QXH00P29RHT208^;R`80SXj>0P2@T90209>CT`80
UIFE0P2HV9P209ZJVP80WIfM0P2OWil20:6QX@80Y:BT0P2VYZH20:RXZ0030:^[Z`2][Jd0[Jf]0080
[jn_102b/[820;6a/@80/;2`0P2][Jd20:ZZZP80YjNW0P2SXj<209nOW`80VYZJ0P2GUiL209:BTP80
S8b<00<0R8R808B4Q024Q8@00P20P80207alO0P0NGUi0P1jNWX207]kN`80O7al0P1mOGd207inOP80
Ogmo1020P8000`21PH40PX:208:2PP0408>3P`H0Q8B40P22PX820820P080O7al0P1iNGT207EeM@80
LW9b0P1_Kfl206][J`80J6QX00<0IFEU065QH@1QHF400P1LG5`205IFEP80De=C0P1BDU8404i>CP80
B4Q80P12@T8203Xj>P80=3@d0P0b<S8202h^;P80:BTY0P0W9bL00`0V9RH08b<S02<S8`02024Q8@80
7QhN100L71`201hN7P80820P100R8R8201lO7`8071`L0P0I6AT401PH60<06ATI100J6QX201`L7080
7alO0P0R8R8202HV9P80:RXZ0P0];Bd2038b<P80=CDe0P0i>CT203dm?@80@D510P15ADD204U9B@03
04a<C01@D500D51@0080E5AD0P1HF5P205aLG080H61P0P1TI6@206QXJ1D0oooo000C0?ooo`80KVi^
0P1aLG4207AdM080MWIf0P1iNGT207alO080OWin0P21PH400`23Ph<0QXJ608J6QP0208V9R@80Rh^;
0P2>SXh2092@T080Ti>C0P2EUID209RHV080VYZJ0P2MWId209nOW`80XJ6Q0P2TY:@20:JVYP80Z:RX
00<0Zj^[0:f][@2][Jd00P2_[jl40;:b/P80/K6a0P2`/;020:f][@80ZZZZ0P2WYjL20:>SX`80WinO
0P2JVYX209NGU`80TY:B0P2<S8`00`28R8P0Q8B408B4Q0020820P080O7al201iNGT207YjNP80Ng]k
0P1lO7`207emO@80OWin0P1oOgl40820P0030861P@22PX80PX:200@0Ph>31P24Q8@208:2PP80P820
0P1lO7`207UiN@80MGEe0P1bLW8206m_K`80Jf][0P1XJ6P00`1UIFD0HF5Q065QH@0205aLG080EUIF
0P1CDe<2059BDP@0CTi>0P18B4P20492@P80>SXj0P0d=3@2038b<P80;Rh^0P0Y:BT202LW9`0302HV
9P0S8b<08b<S00808B4Q0P0N7Qh401`L70807QhN0P0P8204028R8P807alO0P0L71`201TI6@@061PH
0`0I6AT401XJ6P8071`L0P0O7al2028R8P809RHV0P0Z:RX202d];@80<S8b0P0e=CD203Ti>@80?Cdm
0P11@D4204E5A@80BDU900<0C4a<051@D01@D5000P1DE5@205QHF080G5aL0P1PH60206ATI080J6QX
5@3oool001<0oooo0P1^KVh2075aL@80M7Ad0P1gMgL207YjNP80O7al0P1oOgl208:2PP0308B4Q027
QhL0QhN70080RHV90P2<S8`208n?S`80TI6A0P2DU9@209JFUP80VIVI0P2KVi/209jNWP80X:2P0P2R
XZ820:FUY@80Z:RX0P2ZZZX00`2/[:`0[Zj^0:j^[P020;2`/080/[:b0P2c/k<20;6a/@80/;2`0P2]
[Jd20:VYZ@80YJFU0P2RXZ8209jNWP80VYZJ0P2GUiL2096AT@80SHf=00<0RHV908J6QP26QXH00P24
Q8@20820P080OGem201lO7`207emO@@0OWin101oOgl20820P080PH6100<0PX:208>3P`23Ph<01025
QHD408J6QP@0QhN70P26QXH208B4Q080P8200P1lO7`207QhN080MGEe0P1aLG4206e]K@0306UYJ@1U
IFD0IFEU0080H61P0P1JFUX405ADE080Cdm?0P1ADE4204e=C@80ATI60P0o?cl203Hf=P80<S8b0P0a
<C4202/[:`80:2PX00<09bLW02<S8`0S8b<00P0Q8B4201hN7PH06a/K0P0N7Qh2024Q8@808R8R0P0O
7al201/K6`806ATI0P0H61P401LG5`D061PH0P0K6a/201lO7`808R8R0P0V9RH202TY:@80;Bd]0P0a
<C4203De=@80>CTi0P0m?Cd20451@@80ADE50P19BDT00`1=CDd0D51@051@D00205ADE080F5QH0P1L
G5`2061PH080I6AT0P1XJ6PE0?ooo`004`3oool206i^KP80LG5a0P1dM7@207MgM`80NWYj0P1lO7`2
07moO`80PX:200<0Q8B408N7Q`27QhL00P29RHT208b<S080Shn?0P2ATI4209BDU080UYJF0P2IVIT2
09^KV`80WYjN0P2PX:020::RXP80YJFU0P2XZ:P20:ZZZP030:b/[02^[Zh0[Zj^0080/;2`0P2b/[82
0;>c/`80/K6a0P2`/;020:f][@80ZJVY0P2UYJD20::RXP80WYjN0P2JVYX209NGU`80TI6A0P2=SHd0
0`29RHT0QXJ608J6QP0208B4Q080P8200P1mOGd807alO080OGem101nOWh407moO`80P8200P21PH40
0`22PX80Ph>308>3P`0408F5Q@@0QXJ61027QhL208J6QP80Q8B40P20P80207alO080N7Qh0P1eMGD2
075aL@80KFe]00<0JFUY06EUI@1UIFD00P1PH60205YJFP@0E5AD0P1?Cdl2055AD@80CDe=0P16ATH2
03lo?`80=SHf0P0b<S82034a<@80:b/[0P0X:2P00`0W9bL08b<S02<S8`02024Q8@807QhN1P0K6a/2
01hN7P808B4Q0P0R8R8201lO7`806a/K0P0I6AT201PH60@05aLG1@0H61P201/K6`807alO0P0R8R82
02HV9P80:BTY0P0];Bd2034a<@80=CDe0P0i>CT203dm?@80@D510P15ADD204U9B@0304e=C@1@D500
D51@0080E5AD0P1HF5P205aLG080H61P0P1TI6@206QXJ1D0oooo000C0?ooo`80KVi^0P1aLG4207Ad
M080MgMg0P1jNWX207alO080Ogmo0P22PX800`25QHD0R8R808R8R00208Z:RP80SHf=0P2@T90209:B
TP80UIFE0P2GUiL209ZJVP80W9bL0P2OWil20:6QX@80Y:BT0P2VYZH20:RXZ080Zj^[00<0[Jf]0:n_
[`2_[jl00P2a/K420;:b/P80/k>c0P2a/K420:n_[`80[Jf]0P2YZJT20:FUY@80XJ6Q0P2NWYh209^K
V`80UYJF0P2ATI4208f=S@0308V9R@25QHD0QHF50080Q8B40P22PX820820P080Ogmo201nOWh407mo
O`@0P8201021PH400`22PX80Q8B408B4Q00208F5Q@80QXJ60P27QhL208R8R080RHV9102:RXX208V9
R@80QhN70P24Q8@207moO`80Ng]k0P1gMgL207=cL`0306i^KP1YJFT0JFUY0080I6AT0P1MGEd205EE
E@80EUIF101BDU82051@D080BDU90P12@T8203Xj>P80=CDe0P0c<c<202h^;P80:RXZ00<09bLW02@T
900T92@00P0P820201hN7P806a/K100J6QX201/K6`807alO0P0Q8B4201lO7`806a/K0P0H61P201HF
5P805ADE0P0F5QH501LG5`806QXJ0P0N7Qh2028R8P809BDU0P0Y:BT202d];@80<C4a0P0e=CD203Ti
>@80?Cdm0P11@D4204E5A@80B4Q800<0C4a<051@D01@D5000P1DE5@205QHF080G5aL0P1PH60206AT
I080IfMW5@3oool001<0oooo0P1^KVh2075aL@80M7Ad0P1gMgL207YjNP80O7al0P1oOgl208:2PP03
08F5Q@28R8P0R8R80080RXZ:0P2=SHd2092@T080TY:B0P2EUID209NGU`80VYZJ0P2LW9`209nOW`80
XJ6Q0P2TY:@20:JVYP80Z:RX0P2[Zj/00`2][Jd0[jn_0:n_[`020;6a/@80/[:b0P2c/k<20;6a/@80
[jn_0P2][Jd20:VYZ@80YJFU0P2QXJ4209jNWP80Vi^K0P2FUYH2096AT@80SHf=00<0RHV908F5Q@25
QHD00P24Q8@208:2PP80P8200P1oOgl807inOP@0Ogmo1020P8040861P@0308:2PP24Q8@0Q8B40080
QHF50P26QXH208N7Q`80R8R80P29RHT408Z:RP80RHV90P27QhL208B4Q080Ogmo0P1kNg/207MgM`80
Lg=c00<0KVi^06UYJ@1YJFT00P1TI6@205eMG@80EEEE0P1FEUH4059BDP80D51@0P19BDT20492@P80
>SXj0P0e=CD203<c<`80;Rh^0P0Z:RX00`0W9bL092@T02@T9002020P80807QhN0P0K6a/401XJ6P80
6a/K0P0O7al2024Q8@807alO0P0K6a/201PH60805QHF0P0E5AD201HF5PD05aLG0P0J6QX201hN7P80
8R8R0P0U9BD202TY:@80;Bd]0P0a<C4203De=@80>CTi0P0m?Cd20451@@80ADE50P18B4P00`1<C4`0
D51@051@D00205ADE080F5QH0P1LG5`2061PH080I6AT0P1WIfLE0?ooo`004`3oool206i^KP80LG5a
0P1dM7@207MgM`80NWYj0P1mOGd20820P080Ph>300<0QHF508R8R028R8P00P2;Rh/208j>SP80TI6A
0P2CTi<209JFUP80V9RH0P2KVi/209fMW@80X:2P0P2RXZ820:FUY@80YjNW0P2YZJT20:b/[0030:j^
[P2`/;00/;2`0080/[:b102c/k<20;6a/@80[jn_0P2/[:`20:RXZ080Y:BT0P2PX:0209fMW@80VYZJ
0P2EUID2096AT@80SXj>00<0RXZ:08R8R028R8P00P26QXH208F5Q@80Ph>30P21PH440820P0P0Ogmo
1P20P8020861P@0308:2PP24Q8@0Q8B40080QHF50P26QXH208R8R080RHV90P2:RXX208^;R`80S8b<
0P2=SHd208b<S080Rh^;0P27QhL208:2PP80OWin0P1iNGT00`1cLg<0KVi^06i^KP0206MWI`80H61P
0P1FEUH405ADE080DE5A0P1BDU8204e=C@80ATI60P0m?Cd203Lg=`80<S8b0P0_;bl202/[:`0302PX
:00U9BD09BDU00808B4Q0P0N7Qh201/K6`H06ATI0P0M7Ad2020P80807alO0P0K6a/201PH60805QHF
0P0D51@201<C4`0301DE5@0F5QH05QHF00805aLG0P0J6QX201dM7@808B4Q0P0U9BD202PX:080;Bd]
0P0a<C4203De=@80>CTi0P0m?Cd20451@@80A4A40P18B4P00`1<C4`0D51@051@D00205ADE080F5QH
0P1LG5`2061PH080I6AT0P1XJ6PE0?ooo`004`3oool206i^KP80LG5a0P1dM7@207MgM`80NWYj0P1m
OGd20820P080Ph>300<0QHF508R8R028R8P00P2;Rh/208j>SP80TI6A0P2CTi<209JFUP80V9RH0P2K
Vi/209fMW@80X:2P0P2RXZ820:FUY@80YjNW0P2YZJT20:b/[0030:j^[P2`/;00/;2`0080/[:b102c
/k<20;6a/@80[jn_0P2/[:`20:RXZ080Y:BT0P2PX:0209fMW@80VYZJ0P2EUID2096AT@80SXj>00<0
RXZ:08R8R028R8P00P26QXH208F5Q@80Ph>30P21PH440820P0P0Ogmo1P20P8020861P@0308:2PP24
Q8@0Q8B40080QHF50P26QXH208R8R080RHV90P2:RXX208^;R`80S8b<0P2=SHd208b<S080Rh^;0P27
QhL208:2PP80OWin0P1iNGT00`1cLg<0KVi^06i^KP0206MWI`80H61P0P1FEUH405ADE080DE5A0P1B
DU8204e=C@80ATI60P0m?Cd203Lg=`80<S8b0P0_;bl202/[:`0302PX:00U9BD09BDU00808B4Q0P0N
7Qh201/K6`H06ATI0P0M7Ad2020P80807alO0P0K6a/201PH60805QHF0P0D51@201<C4`0301DE5@0F
5QH05QHF00805aLG0P0J6QX201dM7@808B4Q0P0U9BD202PX:080;Bd]0P0a<C4203De=@80>CTi0P0m
?Cd20451@@80A4A40P18B4P00`1<C4`0D51@051@D00205ADE080F5QH0P1LG5`2061PH080I6AT0P1X
J6PE0?ooo`004`3oool206m_K`80LG5a0P1eMGD207MgM`80NWYj0P1mOGd20861P@80Ph>300<0QXJ6
08V9R@29RHT00P2<S8`208n?S`80TY:B0P2DU9@209NGU`80VIVI0P2LW9`209nOW`80XJ6Q0P2SXj<2
0:JVYP80ZJVY0P2[Zj/20:f][@030:n_[`2a/K40/K6a0080/[:b0P2d];@20;:b/P80/;2`0P2][Jd2
0:^[Z`80Z:RX0P2SXj<20:2PX080W9bL0P2IVIT209BDU080TI6A0P2>SXh00`2<S8`0RXZ:08Z:RP02
08R8R080QhN70P25QHD208B4Q080PX:20P21PH460820P080Ogmo2020P8000`21PH40Ph>308>3P`02
08B4Q080QXJ60P28R8P208Z:RP80Rh^;0P2=SHd208j>SPH0Shn?0P2>SXh208Z:RP80QHF50P1oOgl0
0`1iNGT0Lg=c07=cL`0206a/K080Hf=S0P1IFET205=CD`80E5AD0P1@D50204m?C`80CDe=0P18B4P2
0451@@80>c/k0P0d=3@2030`<080;Bd]00<0:2PX02DU9@0U9BD00P0Q8B4201dM7@806a/K0P0H61P2
01TI6@8061PH0P0J6QX201hN7P807alO0P0K6a/201LG5`805ADE0P0D51@2018B4P0301<C4`0E5AD0
5ADE00805aLG0P0J6QX201dM7@808B4Q0P0U9BD202PX:080;2`/0P0`<30203@d=080>3Ph0P0m?Cd2
0451@@80A4A40P18B4P00`1<C4`0D51@051@D00205ADE080F5QH0P1LG5`2061PH080I6AT0P1XJ6PE
0?ooo`004`3oool206m_K`80LG5a0P1eMGD207MgM`80NWYj0P1mOGd20861P@80Ph>300<0QXJ608V9
R@29RHT00P2<S8`208n?S`80TY:B0P2DU9@209NGU`80VIVI0P2LW9`209nOW`80XJ6Q0P2SXj<20:JV
YP80ZJVY0P2[Zj/20:f][@030:n_[`2a/K40/K6a0080/[:b0P2d];@20;:b/P80/;2`0P2][Jd20:^[
Z`80Z:RX0P2SXj<20:2PX080W9bL0P2IVIT209BDU080TI6A0P2>SXh00`2<S8`0RXZ:08Z:RP0208R8
R080QhN70P25QHD208B4Q080PX:20P21PH460820P080Ogmo2020P8000`21PH40Ph>308>3P`0208B4
Q080QXJ60P28R8P208Z:RP80Rh^;0P2=SHd208j>SPH0Shn?0P2>SXh208Z:RP80QHF50P1oOgl00`1i
NGT0Lg=c07=cL`0206a/K080Hf=S0P1IFET205=CD`80E5AD0P1@D50204m?C`80CDe=0P18B4P20451
@@80>c/k0P0d=3@2030`<080;Bd]00<0:2PX02DU9@0U9BD00P0Q8B4201dM7@806a/K0P0H61P201TI
6@8061PH0P0J6QX201hN7P807alO0P0K6a/201LG5`805ADE0P0D51@2018B4P0301<C4`0E5AD05ADE
00805aLG0P0J6QX201dM7@808B4Q0P0U9BD202PX:080;2`/0P0`<30203@d=080>3Ph0P0m?Cd20451
@@80A4A40P18B4P00`1<C4`0D51@051@D00205ADE080F5QH0P1LG5`2061PH080I6AT0P1XJ6PE0?oo
o`004`3oool206m_K`80LW9b0P1eMGD207QhN080Ng]k0P1nOWh20861P@80Q8B400<0QhN708Z:RP2:
RXX00P2<S8`208n?S`80TY:B0P2EUID209RHV080Vi^K0P2MWId20:2PX080XZ:R0P2TY:@20:NWY`80
ZJVY0P2/[:`20:n_[`030;2`/02b/[80/[:b00@0/k>c0P2b/[820:n_[`80[:b/0P2YZJT20:JVYP80
XZ:R0P2OWil209^KV`80UiNG0P2CTi<2092@T080Shn?00<0SXj>08b<S02<S8`00P2;Rh/208V9R@80
R8R80P26QXH208F5Q@80Ph>30P22PX840861P@@0P8200P21PH440820P0030861P@22PX80PX:20080
Ph>30P26QXH208R8R080RXZ:0P2<S8`208j>SP80Shn?202ATI42092@T080SHf=0P27QhL00`20P800
N7Qh07QhN002075aL@80IfMW0P1LG5`205ADE0@0DE5A0P1=CDd204a<C080B4Q80P13@d<203dm?@80
=SHf0P0a<C4202l_;`0302XZ:P0V9RH09RHV00808R8R0P0N7Qh201/K6`806ATI100G5aL201PH6080
6a/K0P0M7Ad201/K6`8061PH0P0F5QH201<C4`804A4A00<04Q8B01<C4`0C4a<00P0F5QH201XJ6P80
7AdM0P0P820202@T9080:2PX0P0/;2`2030`<080=3@d0P0h>3P203`l?080@4100P15ADD204Q8B003
04a<C01@D500D51@0080E5AD0P1HF5P205aLG080H61P0P1TI6@206QXJ1D0oooo000C0?ooo`80Kfm_
0P1bLW8207EeM@80N7Qh0P1kNg/207inOP80PH610P24Q8@00`27QhL0RXZ:08Z:RP0208b<S080Shn?
0P2BTY8209FEU@80V9RH0P2KVi/209fMW@80X:2P0P2RXZ820:BTY080YjNW0P2YZJT20:b/[080[jn_
00<0/;2`0;:b/P2b/[80102c/k<20;:b/P80[jn_0P2/[:`20:VYZ@80YZJV0P2RXZ8209nOW`80Vi^K
0P2GUiL209>CT`80T92@0P2?Shl00`2>SXh0S8b<08b<S00208^;R`80RHV90P28R8P208J6QP80QHF5
0P23Ph<208:2PP@0PH611020P8020861P@@0P82000<0PH6108:2PP22PX800P23Ph<208J6QP80R8R8
0P2:RXX208b<S080SXj>0P2?Shl8096AT@80T92@0P2=SHd208N7Q`030820P01hN7P0N7Qh0080LG5a
0P1WIfL205aLG080E5AD101ADE4204e=C@80C4a<0P18B4P204=3@`80?Cdm0P0f=SH2034a<@80;bl_
00<0:RXZ02HV9P0V9RH00P0R8R8201hN7P806a/K0P0I6AT401LG5`8061PH0P0K6a/201dM7@806a/K
0P0H61P201HF5P804a<C0P0A4A400`0B4Q804a<C01<C4`0201HF5P806QXJ0P0M7Ad2020P808092@T
0P0X:2P202`/;080<30`0P0d=3@203Ph>080?3`l0P10@40204E5A@80B4Q800<0C4a<051@D01@D500
0P1DE5@205QHF080G5aL0P1PH60206ATI080J6QX5@3oool001<0oooo0P1_Kfl2079bLP80MGEe0P1h
N7P207]kN`80OWin0P21PH4208B4Q00308R8R02;Rh/0Rh^;0080SXj>0P2@T90209>CT`80UYJF0P2I
VIT209bLW080WYjN0P2QXJ420:>SX`80YZJV0P2XZ:P20:^[Z`80[Jf]0P2`/;000`2a/K40/[:b0;:b
/P020;Bd]080/k>c0P2a/K420:j^[P80[:b/0P2XZ:P20:BTY080XJ6Q0P2NWYh209ZJVP80UYJF0P2C
Ti<2096AT@80T92@00<0Shn?08j>SP2>SXh00P2=SHd208b<S080RXZ:0P29RHT208N7Q`80QXJ60P25
QHD408B4Q0H0Ph>31`22PX8208>3P`80QHF50P27QhL208Z:RP80SHf=0P2?Shl2096AT@@0Ti>C0P2D
U9@209>CT`80TY:B0P2ATI4208f=S@0308J6QP1nOWh0OWin0080MGEe0P1[Jf/205mOG`80EUIF0P1@
D50204m?C`80Bd];0P17AdL204I6AP80@d=30P10@40203Ti>@80<c<c0P0_;bl00`0/;2`0:2PX02PX
:00202<S8`807alO0P0J6QX201PH60H05QHF0P0G5aL201/K6`806QXJ0P0G5aL201DE5@804a<C1@0A
4A4201HF5P806ATI0P0M7Ad2020P808092@T0P0X:2P202`/;080<30`0P0d=3@203Ph>080?3`l0P10
@40204E5A@80B4Q800<0C4a<051@D01@D5000P1DE5@205QHF080G5aL0P1PH60206ATI080J6QX5@3o
ool001<0oooo0P1_Kfl2079bLP80MGEe0P1hN7P207]kN`80OWin0P21PH4208B4Q00308R8R02;Rh/0
Rh^;0080SXj>0P2@T90209>CT`80UYJF0P2IVIT209bLW080WYjN0P2QXJ420:>SX`80YZJV0P2XZ:P2
0:^[Z`80[Jf]0P2`/;000`2a/K40/[:b0;:b/P020;Bd]080/k>c0P2a/K420:j^[P80[:b/0P2XZ:P2
0:BTY080XJ6Q0P2NWYh209ZJVP80UYJF0P2CTi<2096AT@80T92@00<0Shn?08j>SP2>SXh00P2=SHd2
08b<S080RXZ:0P29RHT208N7Q`80QXJ60P25QHD408B4Q0H0Ph>31`22PX8208>3P`80QHF50P27QhL2
08Z:RP80SHf=0P2?Shl2096AT@@0Ti>C0P2DU9@209>CT`80TY:B0P2ATI4208f=S@0308J6QP1nOWh0
OWin0080MGEe0P1[Jf/205mOG`80EUIF0P1@D50204m?C`80Bd];0P17AdL204I6AP80@d=30P10@402
03Ti>@80<c<c0P0_;bl00`0/;2`0:2PX02PX:00202<S8`807alO0P0J6QX201PH60H05QHF0P0G5aL2
01/K6`806QXJ0P0G5aL201DE5@804a<C1@0A4A4201HF5P806ATI0P0M7Ad2020P808092@T0P0X:2P2
02`/;080<30`0P0d=3@203Ph>080?3`l0P10@40204E5A@80B4Q800<0C4a<051@D01@D5000P1DE5@2
05QHF080G5aL0P1PH60206ATI080J6QX5@3oool001<0oooo0P1_Kfl2079bLP80MGEe0P1hN7P207]k
N`80Ogmo0P22PX8208F5Q@0308R8R02;Rh/0Rh^;0080SXj>0P2ATI4209BDU080UiNG0P2JVYX209fM
W@80X:2P0P2RXZ820:FUY@80YjNW0P2YZJT20:b/[080[Zj^0P2`/;000`2b/[80/k>c0;>c/`020;>c
/`80/[:b0P2`/;020:b/[080ZJVY0P2WYjL20::RXP80WinO0P2LW9`209RHV080U9BD0P2?Shl5096A
T@@0T92@0P2?Shl208j>SP80S8b<0P29RHT808R8R0H0QhN70P26QXH308B4Q0@0Ph>30P25QHD208R8
R080RXZ:0P2=SHd2092@T080Ti>C0P2DU9@209FEU@@0UYJF0P2EUID209BDU080TY:B00<0SXj>08F5
Q@25QHD00P1kNg/2071`L080Hf=S0P1HF5P204m?C`80CDe=0P1<C4`204I6AP80@d=30P11@D4203hn
?P80>c/k0P0f=SH2030`<00302`/;00Y:BT0:BTY008092@T0P0O7al201XJ6P805aLG0P0E5AD401@D
50805ADE100H61P201HF5P8051@D0P0A4A43010@40804A4A0P0D51@201PH608071`L0P0P820202@T
9080:2PX0P0/;2`2030`<080=3@d0P0h>3P203`l?080@4100P15ADD204Q8B00304a<C01@D500D51@
0080E5AD0P1HF5P205aLG080H61P0P1TI6@206QXJ1D0oooo000C0?ooo`80Kfm_0P1bLW8207EeM@80
NGUi0P1lO7`207moO`80PX:20P25QHD00`29RHT0S8b<08b<S00208n?S`80TY:B0P2EUID209RHV080
Vi^K0P2NWYh20:6QX@80Y:BT0P2VYZH20:VYZ@80Zj^[0P2][Jd20;2`/0<0/[:b0P2c/k<20;:b/P80
/K6a0P2^[Zh20:^[Z`80YjNW0P2UYJD20:6QX@80WYjN0P2JVYX209JFUP80Ti>C102BTY8909>CT`80
TI6A0P2@T90208n?S`80SXj>0P2?Shl208j>SP80SHf=1P2<S8`208^;R`80RXZ:00<0RHV908R8R028
R8P00P27QhL208J6QP80R8R80P2;Rh/208j>SP80TI6A0P2DU9@209JFUP80UiNG1P2HV9P209NGU`80
UIFE00<0Ti>C08f=S@2=SHd00P22PX8207IfMP80J6QX0P1KFe/2055AD@@0BDU90P16ATH203lo?`80
?Shn0P0j>SX203Ph>080=SHf0P0b<S800`0^;Rh0:RXZ02XZ:P0202DU9@80820P0P0K6a/201LG5`80
5ADE0P0C4a<4018B4P805ADE0P0F5QH201@D50804Q8B0P0@410300h>3P804Q8B0P0E5AD201PH6080
71`L0P0O7al202@T9080:2PX0P0/;2`2030`<080=3@d0P0h>3P203`l?080@4100P14A4@204Q8B003
04a<C01@D500D51@0080E5AD0P1HF5P205aLG080H61P0P1TI6@206QXJ1D0oooo000C0?ooo`80Kfm_
0P1bLW8207EeM@80NGUi0P1lO7`207moO`80PX:20P25QHD00`29RHT0S8b<08b<S00208n?S`80TY:B
0P2EUID209RHV080Vi^K0P2NWYh20:6QX@80Y:BT0P2VYZH20:VYZ@80Zj^[0P2][Jd20;2`/0<0/[:b
0P2c/k<20;:b/P80/K6a0P2^[Zh20:^[Z`80YjNW0P2UYJD20:6QX@80WYjN0P2JVYX209JFUP80Ti>C
102BTY8909>CT`80TI6A0P2@T90208n?S`80SXj>0P2?Shl208j>SP80SHf=1P2<S8`208^;R`80RXZ:
00<0RHV908R8R028R8P00P27QhL208J6QP80R8R80P2;Rh/208j>SP80TI6A0P2DU9@209JFUP80UiNG
1P2HV9P209NGU`80UIFE00<0Ti>C08f=S@2=SHd00P22PX8207IfMP80J6QX0P1KFe/2055AD@@0BDU9
0P16ATH203lo?`80?Shn0P0j>SX203Ph>080=SHf0P0b<S800`0^;Rh0:RXZ02XZ:P0202DU9@80820P
0P0K6a/201LG5`805ADE0P0C4a<4018B4P805ADE0P0F5QH201@D50804Q8B0P0@410300h>3P804Q8B
0P0E5AD201PH608071`L0P0O7al202@T9080:2PX0P0/;2`2030`<080=3@d0P0h>3P203`l?080@410
0P14A4@204Q8B00304a<C01@D500D51@0080E5AD0P1HF5P205aLG080H61P0P1TI6@206QXJ1D0oooo
000C0?ooo`80Kfm_0P1bLW8207IfMP80NGUi0P1lO7`20820P080Ph>30P26QXH00`29RHT0SHf=08f=
S@02092@T080Ti>C0P2FUYH209VIV@80W9bL0P2OWil20::RXP80YJFU0P2WYjL20:ZZZP80[Jf]0P2_
[jl20;6a/@D0/[:b0P2a/K420;2`/080[Jf]0P2XZ:P20:FUY@80XZ:R0P2OWil209ZJVP80UiNG0P2D
U9@2096AT@80Ti>C102DU9@00`2EUID0UYJF09JFUP0209NGU`80V9RH0P2FUYH209FEU@80Ti>C0P2A
TI42092@T080TI6A102@T90408n?S`80SXj>0P2=SHd00`2<S8`0SHf=08f=S@0208b<S080RXZ:0P29
RHT208f=S@80T92@0P2CTi<209JFUP80V9RH0P2IVIT609ZJVP80VIVI0P2GUiL00`2EUID0TI6A096A
T@0208Z:RP80O7al0P1^KVh205mOG`80EEEE0P1:BTX204I6AP80A4A40P0n?Sh203/k>`80>3Ph100d
=3@203<c<`0302h^;P0Z:RX0:RXZ00809RHV0P0Q8B4201/K6`805aLG0P0D51@2018B4P@0410@0P0B
4Q8201DE5@8051@D0P0A4A4200l?3`<03@d=0P0A4A4201@D508061PH0P0L71`201lO7`808b<S0P0X
:2P202`/;080<30`0P0d=3@203Ph>080?3`l0P10@40204A4A080B4Q800<0C4a<051@D01@D5000P1D
E5@205QHF080G5aL0P1PH60206ATI080J6QX5@3oool001<0oooo0P1_Kfl2079bLP80MWIf0P1iNGT2
07alO080P8200P23Ph<208J6QP0308V9R@2=SHd0SHf=0080T92@0P2CTi<209JFUP80VIVI0P2LW9`2
09nOW`80XZ:R0P2UYJD20:NWY`80ZZZZ0P2][Jd20:n_[`80/K6a1@2b/[820;6a/@80/;2`0P2][Jd2
0:RXZ080YJFU0P2RXZ8209nOW`80VYZJ0P2GUiL209BDU080TI6A0P2CTi<409BDU00309FEU@2FUYH0
UYJF0080UiNG0P2HV9P209JFUP80UIFE0P2CTi<2096AT@80T92@0P2ATI44092@T0@0Shn?0P2>SXh2
08f=S@0308b<S02=SHd0SHf=0080S8b<0P2:RXX208V9R@80SHf=0P2@T90209>CT`80UYJF0P2HV9P2
09VIV@H0VYZJ0P2IVIT209NGU`0309FEU@2ATI40TI6A0080RXZ:0P1lO7`206i^KP80GemO0P1EEED2
04Y:BP80ATI60P14A4@203hn?P80>c/k0P0h>3P403@d=080<c<c00<0;Rh^02XZ:P0Z:RX00P0V9RH2
024Q8@806a/K0P0G5aL201@D50804Q8B100@4102018B4P805ADE0P0D51@2014A4@803`l?0`0=3@d2
014A4@8051@D0P0H61P201`L70807alO0P0S8b<202PX:080;2`/0P0`<30203@d=080>3Ph0P0l?3`2
0410@080A4A40P18B4P00`1<C4`0D51@051@D00205ADE080F5QH0P1LG5`2061PH080I6AT0P1XJ6PE
0?ooo`004`3oool206m_K`80LW9b0P1fMWH207UiN@80OGem0P20P80208>3P`80QhN700<0RXZ:08f=
S@2=SHd00P2ATI4209BDU080UiNG0P2JVYX209fMW@80XJ6Q0P2TY:@20:JVYP80ZJVY0P2[Zj/20:j^
[P80/;2`0P2c/k<30;Bd]080/k>c0P2a/K420:j^[P80Zj^[0P2WYjL20:BTY080X:2P0P2LW9`209VI
V@80UIFE102BTY8209>CT`80U9BD0P2FUYH00`2GUiL0VIVI09VIV@0209ZJVP80W9bL0P2KVi/209VI
V@80V9RH102GUiL409JFUP80UiNG0P2FUYH209FEU@80U9BD0P2CTi<00`2ATI40T92@092@T002096A
T@80T92@102>SXh2096AT@80UIFE0P2GUiL209VIV@80VYZJ102LW9`209^KV`80VYZJ0P2IVIT00`2G
UiL0Ti>C09>CT`0208j>SP80Ph>30P1dM7@206ATI080EeMG0P1;Bd/204E5A@80@T920P0n?Sh203Lg
=`80=CDe0P0`<30202h^;P80<30`00<0;bl_02/[:`0[:b/00P0V9RH2024Q8@8071`L0P0G5aL201@D
50804A4A100>3Ph2010@40@04a<C0P0A4A4200l?3`803@d=00<030`<010@400@41000P0D51@201LG
5`806a/K0P0O7al202<S8`80:2PX0P0/;2`2030`<080=3@d0P0h>3P203`l?080@4100P14A4@204Q8
B00304a<C01@D500D51@0080E5AD0P1HF5P205aLG080H61P0P1TI6@206QXJ1D0oooo000C0?ooo`80
Kfm_0P1bLW8207IfMP80NGUi0P1mOGd20820P080Ph>30P27QhL00`2:RXX0SHf=08f=S@02096AT@80
U9BD0P2GUiL209ZJVP80WIfM0P2QXJ420:BTY080YZJV0P2YZJT20:^[Z`80[Zj^0P2`/;020;>c/`<0
];Bd0P2c/k<20;6a/@80[Zj^0P2[Zj/20:NWY`80Y:BT0P2PX:0209bLW080VIVI0P2EUID409:BTP80
Ti>C0P2DU9@209JFUP0309NGU`2IVIT0VIVI0080VYZJ0P2LW9`209^KV`80VIVI0P2HV9P409NGU`@0
UYJF0P2GUiL209JFUP80UIFE0P2DU9@209>CT`03096AT@2@T900T92@0080TI6A0P2@T90408j>SP80
TI6A0P2EUID209NGU`80VIVI0P2JVYX409bLW080Vi^K0P2JVYX209VIV@0309NGU`2CTi<0Ti>C0080
SXj>0P23Ph<207AdM080I6AT0P1GEeL204];B`80ADE50P12@T8203hn?P80=cLg0P0e=CD2030`<080
;Rh^0P0`<3000`0_;bl0:b/[02/[:`0202HV9P808B4Q0P0L71`201LG5`8051@D0P0A4A4400h>3P80
410@100C4a<2014A4@803`l?0P0=3@d00`0<30`0410@010@400201@D50805aLG0P0K6a/201lO7`80
8b<S0P0X:2P202`/;080<30`0P0d=3@203Ph>080?3`l0P10@40204A4A080B4Q800<0C4a<051@D01@
D5000P1DE5@205QHF080G5aL0P1PH60206ATI080J6QX5@3oool001<0oooo0P1_Kfl2079bLP80MWIf
0P1iNGT207emO@80PH610P24Q8@208R8R00308^;R`2>SXh0SXj>0080TY:B0P2EUID209VIV@80W9bL
0P2OWil20::RXP80YJFU0P2XZ:P20:ZZZP80[Jf]0P2_[jl20;:b/P80];Bd0`2e]KD20;:b/P80/;2`
0P2][Jd20:VYZ@80YJFU0P2QXJ4209jNWP80VYZJ0P2FUYH209:BTP80TI6A0P2BTY8209>CT`80UIFE
0P2GUiL00`2IVIT0WIfM09fMW@0209nOW`@0Xj>S0P2RXZ820:6QX@@0X:2P102OWil40:2PX080WinO
0P2NWYh209bLW00309^KV`2JVYX0VYZJ0080Vi^K0P2JVYX209RHV080UiNG0P2FUYH209RHV080VYZJ
0P2KVi/209bLW080WIfM0P2NWYh209fMW@80W9bL0P2JVYX00`2IVIT0UIFE09FEU@02096AT@80RHV9
0P1jNWX206UYJ@80FUYJ0P1?Cdl204I6AP80@4100P0n?Sh203Lg=`80<S8b0P0^;Rh202TY:@80:RXZ
00<0;2`/02/[:`0[:b/00P0V9RH2028R8P807AdM0P0H61P201@D50804A4A0P0=3@d200`<30803@d=
0P0?3`l2014A4@@03Ph>0P0<30`00`0=3@d0410@010@400201<C4`805aLG0P0K6a/201lO7`808b<S
0P0X:2P202`/;080<30`0P0d=3@203Ph>080?3`l0P10@40204A4A080B4Q800<0C4a<051@D01@D500
0P1DE5@205QHF080G5aL0P1PH60206ATI080J6QX5@3oool001<0oooo0P1_Kfl2079bLP80MWIf0P1i
NGT207emO@80PH610P24Q8@208R8R00308^;R`2>SXh0SXj>0080TY:B0P2EUID209VIV@80W9bL0P2O
Wil20::RXP80YJFU0P2XZ:P20:ZZZP80[Jf]0P2_[jl20;:b/P80];Bd0`2e]KD20;:b/P80/;2`0P2]
[Jd20:VYZ@80YJFU0P2QXJ4209jNWP80VYZJ0P2FUYH209:BTP80TI6A0P2BTY8209>CT`80UIFE0P2G
UiL00`2IVIT0WIfM09fMW@0209nOW`@0Xj>S0P2RXZ820:6QX@@0X:2P102OWil40:2PX080WinO0P2N
WYh209bLW00309^KV`2JVYX0VYZJ0080Vi^K0P2JVYX209RHV080UiNG0P2FUYH209RHV080VYZJ0P2K
Vi/209bLW080WIfM0P2NWYh209fMW@80W9bL0P2JVYX00`2IVIT0UIFE09FEU@02096AT@80RHV90P1j
NWX206UYJ@80FUYJ0P1?Cdl204I6AP80@4100P0n?Sh203Lg=`80<S8b0P0^;Rh202TY:@80:RXZ00<0
;2`/02/[:`0[:b/00P0V9RH2028R8P807AdM0P0H61P201@D50804A4A0P0=3@d200`<30803@d=0P0?
3`l2014A4@@03Ph>0P0<30`00`0=3@d0410@010@400201<C4`805aLG0P0K6a/201lO7`808b<S0P0X
:2P202`/;080<30`0P0d=3@203Ph>080?3`l0P10@40204A4A080B4Q800<0C4a<051@D01@D5000P1D
E5@205QHF080G5aL0P1PH60206ATI080J6QX5@3oool001<0oooo0P1_Kfl207=cL`80MWIf0P1jNWX2
07inOP80PH610P25QHD208R8R00308b<S02?Shl0Shn?0080Ti>C0P2FUYH209ZJVP80WIfM0P2PX:02
0:BTY080YjNW0P2YZJT20:b/[080[jn_0P2a/K420;Bd]080]KFe0P2f][H00`2e]KD0/[:b0;:b/P02
0:n_[`80[:b/0P2WYjL20:>SX`80WinO0P2JVYX209JFUP80TY:B0P2=SHd2092@T080TI6A0P2CTi<2
09FEU@80V9RH00<0VYZJ09fMW@2MWId00P2PX:020:BTY080YjNW102XZ:P60:NWY`P0YZJV0P2TY:@2
0:>SX`030:6QX@2NWYh0WYjN00@0WIfM102KVi/209ZJVP80Vi^K0P2LW9`209fMW@@0WYjN0P2OWil2
09jNWP80WIfM0P2KVi/00`2IVIT0UiNG09NGU`0209>CT`80S8b<0P20P802071`L080GemO0P1CDe<2
04Q8B080@4100P0l?3`203Ph>080<30`0P0/;2`202HV9P809BDU00<09RHV02TY:@0Y:BT00P0V9RH2
028R8P807QhN0P0H61P201@D5080410@0P0<30`200/;2`802PX:0P0=3@d200l?3`803@d=0P0<30`2
00T92@0300`<300@4100410@00804a<C0P0G5aL201/K6`807alO0P0T92@202PX:080;2`/0P0`<302
03@d=080>3Ph0P0m?Cd20410@080A4A40P18B4P00`1<C4`0D51@051@D00205ADE080F5QH0P1LG5`2
061PH080I6AT0P1XJ6PE0?ooo`004`3oool206m_K`80Lg=c0P1fMWH207YjNP80OWin0P21PH4208F5
Q@80R8R800<0S8b<08n?S`2?Shl00P2CTi<209JFUP80VYZJ0P2MWId20:2PX080Y:BT0P2WYjL20:VY
Z@80[:b/0P2_[jl20;6a/@80];Bd0P2e]KD20;Jf]P030;Fe]@2b/[80/[:b0080[jn_0P2/[:`20:NW
Y`80Xj>S0P2OWil209ZJVP80UYJF0P2BTY8208f=S@80T92@0P2ATI4209>CT`80UIFE0P2HV9P00`2J
VYX0WIfM09fMW@020:2PX080Y:BT0P2WYjL40:RXZ0H0YjNW202VYZH20:BTY080Xj>S00<0XJ6Q09jN
WP2NWYh0102MWId409^KV`80VYZJ0P2KVi/209bLW080WIfM102NWYh209nOW`80WYjN0P2MWId209^K
V`0309VIV@2GUiL0UiNG0080Ti>C0P2<S8`20820P080L71`0P1OGel205=CD`80B4Q80P10@40203`l
?080>3Ph0P0`<30202`/;0809RHV0P0U9BD00`0V9RH0:BTY02TY:@0202HV9P808R8R0P0N7Qh201PH
608051@D0P0@410200`<30802`/;0P0:2PX200d=3@803`l?0P0=3@d200`<30802@T900<030`<010@
400@41000P0C4a<201LG5`806a/K0P0O7al202@T9080:2PX0P0/;2`2030`<080=3@d0P0h>3P203dm
?@80@4100P14A4@204Q8B00304a<C01@D500D51@0080E5AD0P1HF5P205aLG080H61P0P1TI6@206QX
J1D0oooo000C0?ooo`80Kfm_0P1cLg<207MgM`80NWYj0P1nOWh208:2PP80QHF50P29RHT00`2=SHd0
T92@092@T00209BDU080UiNG0P2KVi/209jNWP80XZ:R0P2UYJD20:RXZ080Zj^[0P2^[Zh20;6a/@80
/k>c0P2e]KD40;Jf]P030;Fe]@2b/[80/[:b0080[Zj^0P2ZZZX20:JVYP80XJ6Q0P2LW9`209NGU`80
Ti>C0P2>SXh208f=S@80Shn?0P2ATI4209>CT`80UIFE0P2HV9P00`2JVYX0WIfM09fMW@0209nOW`80
XZ:R0P2TY:@20:JVYP@0YjNW0P2VYZH20:NWY`80YZJV0P2UYJD40:BTY080Xj>S0P2RXZ800`2PX:00
WinO09nOW`0209jNWPX0WIfM0P2NWYh209nOW`H0X:2P0P2OWil209jNWP80WIfM00<0VYZJ09NGU`2G
UiL00P2DU9@208j>SP80Q8B40P1eMGD206=SH`80EeMG0P1<C4`204A4A080?Cdm0P0i>CT2030`<080
:RXZ0P0V9RH3028R8P@092@T0P0R8R8201hN7P806ATI0P0D51@200l?3`802`/;0P092@T200P82080
2`/;0P0=3@d200`<30802`/;0P0820P00`0<30`0410@010@400201<C4`805aLG0P0K6a/201lO7`80
92@T0P0X:2P202`/;080<30`0P0d=3@203Ph>080?3`l0P10@40204E5A@80BDU900<0CDe=051@D01@
D5000P1DE5@205QHF080G5aL0P1PH60206ATI080J6QX5@3oool001<0oooo0P1_Kfl207=cL`80MgMg
0P1jNWX207inOP80PX:20P25QHD208V9R@0308f=S@2@T900T92@0080U9BD0P2GUiL209^KV`80WYjN
0P2RXZ820:FUY@80Z:RX0P2[Zj/20:j^[P80/K6a0P2c/k<20;Fe]@@0][Jf00<0]KFe0;:b/P2b/[80
0P2^[Zh20:ZZZP80YZJV0P2QXJ4209bLW080UiNG0P2CTi<208j>SP80SHf=0P2?Shl2096AT@80Ti>C
0P2EUID209RHV00309ZJVP2MWId0WIfM0080WinO0P2RXZ820:BTY080YZJV102WYjL20:JVYP80YjNW
0P2VYZH20:FUY@@0Y:BT0P2SXj<20::RXP030:2PX02OWil0WinO0080WYjN2P2MWId209jNWP80WinO
1P2PX:0209nOW`80WYjN0P2MWId00`2JVYX0UiNG09NGU`0209BDU080SXj>0P24Q8@207EeM@80Hf=S
0P1GEeL204a<C080A4A40P0m?Cd203Ti>@80<30`0P0Z:RX202HV9P<08R8R100T92@2028R8P807QhN
0P0I6AT201@D50803`l?0P0;2`/200T92@8020P80P0;2`/200d=3@8030`<0P0;2`/200P8200300`<
300@4100410@00804a<C0P0G5aL201/K6`807alO0P0T92@202PX:080;2`/0P0`<30203@d=080>3Ph
0P0l?3`20410@080ADE50P19BDT00`1=CDd0D51@051@D00205ADE080F5QH0P1LG5`2061PH080I6AT
0P1XJ6PE0?ooo`004`3oool206m_K`80Lg=c0P1gMgL207]kN`80OWin0P22PX8208J6QP80RXZ:00<0
SHf=096AT@2ATI400P2EUID209VIV@80W9bL0P2PX:020:>SX`80YjNW0P2ZZZX20:f][@80/;2`0P2c
/k<20;Jf]P@0^;Rh0P2g]kL00`2e]KD0/[:b0;:b/P020:j^[P80ZJVY0P2TY:@209nOW`80VYZJ0P2E
UID208n?S`80RHV90P2;Rh/208j>SP80T92@0P2CTi<209FEU@80V9RH00<0VYZJ09fMW@2MWId00P2O
Wil20:6QX@80Xj>S0P2TY:@20:FUY@H0YZJV0P2UYJD40:BTY080Xj>S0P2RXZ820:6QX@030:2PX02O
Wil0WinO00P0WYjN0P2OWil40:2PX0@0XJ6Q0P2RXZ840:6QX@80X:2P0P2NWYh00`2LW9`0VIVI09VI
V@0209JFUP80TI6A0P28R8P207YjNP80J6QX0P1IFET204i>CP80ADE50P0m?Cd203Ph>080<S8b0P0Z
:RX202@T90807alO00<07QhN01lO7`0O7al0100P820201dM7@806ATI0P0E5AD2010@40803@d=0P09
2@T200L71`8020P8100;2`/200X:2P8020P800<02`/;010@400@41000P0C4a<201HF5P806a/K0P0O
7al202@T9080:2PX0P0/;2`2030`<080=CDe0P0i>CT203dm?@80@D510P15ADD204U9B@0304e=C@1@
D500D51@0080E5AD0P1HF5P205aLG080H61P0P1TI6@206QXJ1D0oooo000C0?ooo`80Kfm_0P1cLg<2
07MgM`80Ng]k0P1nOWh208:2PP80QXJ60P2:RXX00`2=SHd0TI6A096AT@0209FEU@80VIVI0P2LW9`2
0:2PX080Xj>S0P2WYjL20:ZZZP80[Jf]0P2`/;020;>c/`80][Jf102h^;P20;Ng]`030;Fe]@2b/[80
/[:b0080[Zj^0P2YZJT20:BTY080WinO0P2JVYX209FEU@80Shn?0P29RHT208^;R`80SXj>0P2@T902
09>CT`80UIFE0P2HV9P00`2JVYX0WIfM09fMW@0209nOW`80XJ6Q0P2SXj<20:BTY080YJFU1P2VYZH2
0:FUY@@0Y:BT0P2SXj<20::RXP80XJ6Q00<0X:2P09nOW`2OWil0202NWYh209nOW`@0X:2P102QXJ42
0::RXP@0XJ6Q0P2PX:0209jNWP0309bLW02IVIT0VIVI0080UYJF0P2ATI4208R8R080NWYj0P1XJ6P2
05UIF@80CTi>0P15ADD203dm?@80>3Ph0P0b<S8202XZ:P8092@T0P0O7al00`0N7Qh07alO01lO7`04
020P80807AdM0P0I6AT201DE5@80410@0P0=3@d200T92@801`L70P0820P400/;2`802PX:0P0820P0
0`0;2`/0410@010@400201<C4`805QHF0P0K6a/201lO7`8092@T0P0X:2P202`/;080<30`0P0e=CD2
03Ti>@80?Cdm0P11@D4204E5A@80BDU900<0CDe=051@D01@D5000P1DE5@205QHF080G5aL0P1PH602
06ATI080J6QX5@3oool001<0oooo0P1`L70207=cL`80MgMg0P1kNg/207moO`80Ph>30P27QhL208^;
R`0308j>SP2BTY80TY:B0080UYJF0P2JVYX209jNWP80XJ6Q0P2UYJD20:RXZ080[:b/0P2_[jl20;:b
/P80]KFe0P2g]kL20;Vi^@80^[Zj0P2h^;P00`2e]KD0/K6a0;6a/@020:f][@80Z:RX0P2SXj<209fM
W@80UiNG0P2BTY8208f=S@80QXJ60P2:RXX208f=S@80Shn?0P2BTY8209FEU@80UiNG00<0VYZJ09bL
W02LW9`00P2NWYh20:2PX080XZ:R0P2SXj<20:BTY0H0YJFU0P2TY:@40:>SX`80XZ:R0P2QXJ420:2P
X00309nOW`2NWYh0WYjN00@0WYjN102OWil20:2PX080XZ:R2P2SXj<20::RXP80XJ6Q0P2OWil00`2M
WId0VYZJ09ZJVP0209JFUP80TY:B0P2:RXX207emO@80KVi^0P1MGEd2059BDP80B4Q80P10@40203Ti
>@80<c<c0P0[:b/202@T90807AdM0`0K6a/201dM7@807QhN0P0L71`201PH60805ADE0P0?3`l200d=
3@802@T910071`L400X:2P@02@T900<02`/;00l?3`0?3`l00P0C4a<201LG5`806a/K0P0P820202@T
9080:2PX0P0];Bd2034a<@80=CDe0P0i>CT203dm?@80@D510P15ADD204U9B@0304e=C@1@D500D51@
0080EEEE0P1HF5P205aLG080H61P0P1TI6@206QXJ1D0oooo000C0?ooo`80L71`0P1cLg<207MgM`80
Ng]k0P1oOgl208>3P`80QhN70P2;Rh/00`2>SXh0TY:B09:BTP0209JFUP80VYZJ0P2NWYh20:6QX@80
YJFU0P2XZ:P20:b/[080[jn_0P2b/[820;Fe]@80]kNg0P2i^KT20;Zj^P80^;Rh00<0]KFe0;6a/@2a
/K400P2][Jd20:RXZ080Xj>S0P2MWId209NGU`80TY:B0P2=SHd208J6QP80RXZ:0P2=SHd208n?S`80
TY:B0P2EUID209NGU`0309ZJVP2LW9`0W9bL0080WYjN0P2PX:020::RXP80Xj>S0P2TY:@60:FUY@80
Y:BT102SXj<20::RXP80XJ6Q0P2PX:000`2OWil0WYjN09jNWP0409jNWP@0WinO0P2PX:020::RXPX0
Xj>S0P2RXZ820:6QX@80WinO00<0WIfM09ZJVP2JVYX00P2FUYH209:BTP80RXZ:0P1mOGd206i^KP80
GEeM0P1BDU8204Q8B080@4100P0i>CT203<c<`80:b/[0P0T92@201dM7@<06a/K0P0M7Ad201hN7P80
71`L0P0H61P201DE5@803`l?0P0=3@d200T92@@01`L7100:2PX400T92@0300/;2`0?3`l03`l?0080
4a<C0P0G5aL201/K6`80820P0P0T92@202PX:080;Bd]0P0a<C4203De=@80>CTi0P0m?Cd20451@@80
ADE50P19BDT00`1=CDd0D51@051@D00205EEE@80F5QH0P1LG5`2061PH080I6AT0P1XJ6PE0?ooo`00
4`3oool2071`L080M7Ad0P1hN7P207alO080P8200P24Q8@208R8R080Rh^;00<0Shn?09>CT`2CTi<0
0P2GUiL209^KV`80WinO0P2SXj<20:JVYP80ZZZZ0P2][Jd20;6a/@80]KFe0P2h^;P20;Zj^P80^k^k
0P2j^[X20;Rh^0030;Bd]02a/K40/K6a0080[:b/0P2WYjL20:6QX@80W9bL0P2EUID2092@T080RXZ:
0P26QXH208V9R@80S8b<0P2?Shl209:BTP80U9BD0P2GUiL00`2IVIT0W9bL09bLW00209jNWP80WinO
0P2QXJ420:>SX`@0Y:BT102UYJD20:BTY080Xj>S0P2RXZ820:6QX@80X:2P0P2OWil709jNWP80WinO
0P2PX:020:6QX@80XZ:R0P2SXj<20:BTY0@0YJFU102TY:@20:>SX`80XJ6Q00<0WinO09bLW02LW9`0
0P2HV9P209>CT`80SHf=0P22PX82079bLP80HV9R0P1DE5@204Y:BP80@D510P0j>SX203<c<`80;Bd]
0P0U9BD201dM7@D06ATI0P0J6QX201/K6`8061PH0P0E5AD200l?3`802`/;0P0820P400H61P8020P8
0P0:2PX200P820802PX:00<02`/;00l?3`0?3`l00P0C4a<201LG5`806a/K0P0P820202@T9080:BTY
0P0];Bd2034a<@80=CDe0P0i>CT203dm?@80@D510P15ADD204U9B@0304e=C@1ADE40DE5A0080EEEE
0P1HF5P205aLG080H61P0P1TI6@206QXJ1D0oooo000C0?ooo`80L71`0P1dM7@207QhN080O7al0P20
P80208B4Q080R8R80P2;Rh/00`2?Shl0Ti>C09>CT`0209NGU`80Vi^K0P2OWil20:>SX`80YZJV0P2Z
ZZX20:f][@80/K6a0P2e]KD20;Rh^080^[Zj0P2k^k/20;Zj^P80^;Rh00<0];Bd0;6a/@2a/K400P2/
[:`20:NWY`80XJ6Q0P2LW9`209FEU@80T92@0P2:RXX208J6QP80RHV90P2<S8`208n?S`80TY:B0P2D
U9@209NGU`0309VIV@2LW9`0W9bL0080WYjN0P2OWil20:6QX@80Xj>S102TY:@40:FUY@80Y:BT0P2S
Xj<20::RXP80XJ6Q0P2PX:0209nOW`L0WYjN0P2OWil20:2PX080XJ6Q0P2RXZ820:>SX`80Y:BT102U
YJD40:BTY080Xj>S0P2QXJ400`2OWil0W9bL09bLW00209RHV080Ti>C0P2=SHd208:2PP80LW9b0P1R
HV8205ADE080BTY:0P11@D4203Xj>P80<c<c0P0];Bd202DU9@807AdM1@0I6AT201XJ6P806a/K0P0H
61P201DE5@803`l?0P0;2`/200P820@01PH60P0820P200X:2P8020P80P0:2PX00`0;2`/03`l?00l?
3`0201<C4`805aLG0P0K6a/2020P808092@T0P0Y:BT202d];@80<C4a0P0e=CD203Ti>@80?Cdm0P11
@D4204E5A@80BDU900<0CDe=055AD@1ADE400P1EEED205QHF080G5aL0P1PH60206ATI080J6QX5@3o
ool001<0oooo0P1`L70207AdM080N7Qh0P1lO7`20820P080Q8B40P28R8P208b<S003092@T02DU9@0
U9BD0080V9RH0P2LW9`20:2PX080Y:BT0P2XZ:P20:b/[080/;2`0P2c/k<20;Ng]`80^[Zj102m_Kd2
0;^k^`80^;Rh00<0];Bd0:n_[`2_[jl00P2[Zj/20:FUY@80WinO0P2IVIT209BDU080SXj>0P26QXH2
08N7Q`80RHV90P2<S8`208n?S`80TI6A0P2DU9@209NGU`0309VIV@2KVi/0Vi^K0080WIfM0P2OWil2
0:6QX@80Xj>S0P2TY:@20:FUY@80YZJV102WYjL20:FUY@80Xj>S0P2RXZ820:2PX080WinO00<0WYjN
09fMW@2MWId0102NWYh209nOW`80X:2P0P2RXZ820:>SX`@0YJFU1P2VYZH20:FUY@80Y:BT0P2RXZ80
0`2PX:00WYjN09jNWP0209ZJVP80UIFE0P2?Shl208F5Q@80MWIf0P1UIFD205MGE`80C4a<0P12@T82
03`l?080=3@d0P0_;bl202LW9`80820P00<05aLG01HF5P0F5QH00P0F5QH201PH60806QXJ0P0G5aL2
01DE5@80410@0P0;2`/200L71`801@D50P0410@200L71`802@T90P0820P200X:2P0300/;2`0>3Ph0
3Ph>00804Q8B0P0G5aL201`L7080820P0P0U9BD202TY:@80;Bd]0P0a<C4203De=@80>CTi0P0m?Cd2
0451@@80ADE50P19BDT00`1=CDd0DE5A055AD@0205EEE@80FEUI0P1LG5`2061PH080I6AT0P1XJ6PE
0?ooo`004`3oool2071`L080M7Ad0P1hN7P207alO080P8200P24Q8@208R8R080S8b<00<0T92@09BD
U02DU9@00P2HV9P209bLW080X:2P0P2TY:@20:RXZ080[:b/0P2`/;020;>c/`80]kNg0P2j^[X40;fm
_@80^k^k0P2h^;P00`2d];@0[jn_0:n_[`020:^[Z`80YJFU0P2OWil209VIV@80U9BD0P2>SXh208J6
QP80QhN70P29RHT208b<S080Shn?0P2ATI4209BDU080UiNG00<0VIVI09^KV`2KVi/00P2MWId209nO
W`80XJ6Q0P2SXj<20:BTY080YJFU0P2VYZH40:NWY`80YJFU0P2SXj<20::RXP80X:2P0P2OWil00`2N
WYh0WIfM09fMW@0409jNWP80WinO0P2PX:020::RXP80Xj>S102UYJD60:JVYP80YJFU0P2TY:@20::R
XP030:2PX02NWYh0WYjN0080VYZJ0P2EUID208n?S`80QHF50P1fMWH206EUI@80EeMG0P1<C4`20492
@P80?3`l0P0d=3@202l_;`809bLW0P0P82000`0G5aL05QHF01HF5P0201HF5P8061PH0P0J6QX201LG
5`805ADE0P0@410200/;2`801`L70P051@D200@410801`L70P092@T200P820802PX:00<02`/;00h>
3P0>3Ph00P0B4Q8201LG5`8071`L0P0P820202DU9@80:BTY0P0];Bd2034a<@80=CDe0P0i>CT203dm
?@80@D510P15ADD204U9B@0304e=C@1ADE40DE5A0080EEEE0P1IFET205aLG080H61P0P1TI6@206QX
J1D0oooo000C0?ooo`80L71`0P1dM7@207QhN080O7al0P21PH4208F5Q@80RHV90P2=SHd00`2ATI40
UIFE09FEU@0209VIV@80WIfM0P2QXJ420:FUY@80ZJVY0P2][Jd20;6a/@80]KFe0P2i^KT20;fm_@@0
_kno0P2l_;`20;Rh^0030;Bd]02_[jl0[jn_0080ZJVY0P2TY:@209jNWP80V9RH0P2BTY8208^;R`80
Ph>30P27QhL208V9R@80S8b<0P2>SXh2096AT@80U9BD0P2FUYH00`2IVIT0Vi^K09^KV`0209fMW@80
WinO0P2QXJ440:>SX`80Y:BT0P2WYjL40:VYZ@80Z:RX0P2TY:@20::RXP80XJ6Q0P2PX:000`2NWYh0
WIfM09fMW@0409jNWP80X:2P0P2QXJ420::RXP80Y:BT0P2UYJD40:JVYP@0YjNW0P2VYZH20:FUY@80
Y:BT00<0XZ:R09nOW`2OWil00P2LW9`209NGU`80TI6A0P29RHT207alO080JVYZ0P1KFe/204m?C`80
ADE50P0m?Cd203De=@80<30`0P0Y:BT2024Q8@0301TI6@0E5AD05ADE00@05ADE100G5aL201@D5080
410@0P0:2PX200L71`8010@40P030`<200D51@801`L70P092@T200P8200300`<300?3`l03`l?0080
4a<C0P0H61P201`L70808B4Q0P0U9BD202TY:@80;Rh^0P0a<C4203Hf=P80>SXj0P0n?Sh20492@P80
ATI60P19BDT00`1=CDd0DE5A055AD@0205EEE@80FEUI0P1LG5`2061PH080I6AT0P1XJ6PE0?ooo`00
4`3oool2071`L080M7Ad0P1hN7P207alO080PH610P25QHD208V9R@80SHf=00<0TI6A09FEU@2EUID0
0P2IVIT209fMW@80XJ6Q0P2UYJD20:VYZ@80[Jf]0P2a/K420;Fe]@80^KVi0P2m_Kd40;no_`80_;bl
0P2h^;P00`2d];@0[jn_0:n_[`020:VYZ@80Y:BT0P2NWYh209RHV080TY:B0P2;Rh/208>3P`80QhN7
0P29RHT208b<S080SXj>0P2ATI4209BDU080UYJF00<0VIVI09^KV`2KVi/00P2MWId209nOW`80XJ6Q
102SXj<20:BTY080YjNW102YZJT20:RXZ080Y:BT0P2RXZ820:6QX@80X:2P00<0WYjN09fMW@2MWId0
102NWYh20:2PX080XJ6Q0P2RXZ820:BTY080YJFU102VYZH40:NWY`80YZJV0P2UYJD20:BTY0030::R
XP2OWil0WinO0080W9bL0P2GUiL2096AT@80RHV90P1lO7`206YZJP80Fe]K0P1?Cdl204E5A@80?Cdm
0P0e=CD2030`<080:BTY0P0Q8B400`0I6AT05ADE01DE5@0401DE5@@05aLG0P0D51@2010@40802PX:
0P071`L200@410800`<30P051@D200L71`802@T90P0820P00`0<30`03`l?00l?3`0201<C4`8061PH
0P0L71`2024Q8@809BDU0P0Y:BT202h^;P80<C4a0P0f=SH203Xj>P80?Shn0P12@T8204I6AP80BDU9
00<0CDe=055AD@1ADE400P1EEED205UIF@80G5aL0P1PH60206ATI080J6QX5@3oool001<0oooo0P1`
L70207AdM080N7Qh0P1mOGd20861P@80QHF50P2:RXX208j>SP0309:BTP2FUYH0UYJF0080VYZJ0P2N
WYh20:>SX`80YjNW0P2[Zj/20:n_[`80/k>c0P2g]kL20;^k^`80_kno0P32`/820<30`080_Kfm0P2i
^KT00`2d];@0[jn_0:n_[`020:VYZ@80Xj>S0P2MWId209NGU`80T92@0P29RHT208>3P`80QhN70P29
RHT208b<S080Shn?0P2BTY8209BDU080UYJF00<0VIVI09^KV`2KVi/00P2MWId209nOW`80XJ6Q0P2U
YJD20:NWY`80YZJV0P2XZ:P20:ZZZP80Zj^[0P2/[:`20:ZZZP80YjNW0P2UYJD20:BTY0030:6QX@2N
WYh0WYjN00@0WYjN0P2PX:020:6QX@80Xj>S0P2TY:@20:FUY@80YZJV0P2WYjL40:RXZ080YjNW0P2V
YZH20:FUY@030:>SX`2PX:00X:2P0080WIfM0P2IVIT209BDU080S8b<0P21PH4206m_K`80H61P0P1B
DU8204Q8B080@4100P0h>3P2030`<080:b/[0P0R8R800`0K6a/04a<C01<C4`0401@D50805ADE0P0G
5aL201@D50804A4A0P0;2`/200L71`8010@40P020P8200<30`801@D5100820P00`0<30`0410@010@
400201@D508061PH0P0M7Ad2024Q8@809BDU0P0Z:RX202h^;P80<S8b0P0f=SH203Xj>P80?Shn0P12
@T8204I6AP80BTY:00<0CDe=055AD@1ADE400P1EEED205UIF@80G5aL0P1PH60206ATI080J6QX5@3o
ool001<0oooo0P1`L70207AdM080N7Qh0P1mOGd20861P@80QHF50P2:RXX208j>SP0309:BTP2FUYH0
UYJF0080VYZJ0P2NWYh20:>SX`80YjNW0P2[Zj/20:n_[`80/k>c0P2g]kL20;^k^`80_kno0P32`/82
0<30`080_Kfm0P2i^KT00`2d];@0[jn_0:n_[`020:VYZ@80Xj>S0P2MWId209NGU`80T92@0P29RHT2
08>3P`80QhN70P29RHT208b<S080Shn?0P2BTY8209BDU080UYJF00<0VIVI09^KV`2KVi/00P2MWId2
09nOW`80XJ6Q0P2UYJD20:NWY`80YZJV0P2XZ:P20:ZZZP80Zj^[0P2/[:`20:ZZZP80YjNW0P2UYJD2
0:BTY0030:6QX@2NWYh0WYjN00@0WYjN0P2PX:020:6QX@80Xj>S0P2TY:@20:FUY@80YZJV0P2WYjL4
0:RXZ080YjNW0P2VYZH20:FUY@030:>SX`2PX:00X:2P0080WIfM0P2IVIT209BDU080S8b<0P21PH42
06m_K`80H61P0P1BDU8204Q8B080@4100P0h>3P2030`<080:b/[0P0R8R800`0K6a/04a<C01<C4`04
01@D50805ADE0P0G5aL201@D50804A4A0P0;2`/200L71`8010@40P020P8200<30`801@D5100820P0
0`0<30`0410@010@400201@D508061PH0P0M7Ad2024Q8@809BDU0P0Z:RX202h^;P80<S8b0P0f=SH2
03Xj>P80?Shn0P12@T8204I6AP80BTY:00<0CDe=055AD@1ADE400P1EEED205UIF@80G5aL0P1PH602
06ATI080J6QX5@3oool001<0oooo0P1`L70207AdM080NGUi0P1mOGd208:2PP80QXJ60P2:RXX208n?
S`0309>CT`2HV9P0V9RH0080W9bL0P2PX:020:BTY080Z:RX0P2][Jd20;6a/@80]KFe0P2i^KT20;fm
_@80`/;20P34a<@20<71`@80_Kfm0P2h^;P00`2c/k<0[Zj^0:j^[P020:VYZ@80XZ:R0P2LW9`209JF
UP80Shn?0P28R8P208B4Q080QhN70P2:RXX208b<S080Shn?0P2ATI4209BDU080UYJF00<0VIVI09^K
V`2KVi/00P2MWId209nOW`80X:2P0P2SXj<20:FUY@80YjNW0P2XZ:P20:ZZZP@0Zj^[0P2ZZZX20:NW
Y`80YJFU0P2TY:@00`2SXj<0XJ6Q0:6QX@0409nOW`80X:2P0P2RXZ820:>SX`80Y:BT102VYZH20:NW
Y`H0Z:RX102WYjL00`2UYJD0XZ:R0::RXP0209nOW`80Vi^K0P2EUID208n?S`80QXJ60P1dM7@206EU
I@80EUIF0P1<C4`20492@P80>c/k0P0b<S8202d];@809BDU00<07alO01@D500D51@0100D51@201DE
5@805aLG0P0D51@2014A4@8030`<0P071`L200@410@00P820P051@D200P820802PX:00<030`<010@
400@41000P0E5AD201TI6@807AdM0P0R8R8202HV9P80:RXZ0P0^;Rh2038b<P80=SHf0P0j>SX203hn
?P80@T920P16ATH204Y:BP0304i>CP1ADE40DE5A0080EEEE0P1IFET205eMG@80H61P0P1TI6@206QX
J1D0oooo000C0?ooo`80L71`0P1dM7@207UiN@80OGem0P22PX8208J6QP80RXZ:0P2?Shl00`2CTi<0
V9RH09RHV00209bLW080X:2P0P2TY:@20:RXZ080[Jf]0P2a/K420;Fe]@80^KVi0P2m_Kd20<;2`P80
a<C40P31`L420;fm_@80^;Rh00<0/k>c0:j^[P2^[Zh00P2YZJT20::RXP80W9bL0P2FUYH208n?S`80
R8R80P24Q8@208N7Q`80RXZ:0P2<S8`208n?S`80TI6A0P2DU9@209JFUP0309VIV@2KVi/0Vi^K0080
WIfM0P2OWil20:2PX080Xj>S0P2UYJD20:NWY`80Z:RX0P2ZZZX40:^[Z`80ZZZZ0P2WYjL20:FUY@80
Y:BT00<0Xj>S0:6QX@2QXJ40102OWil20:2PX080XZ:R0P2SXj<20:BTY0@0YZJV0P2WYjL60:RXZ0@0
YjNW00<0YJFU0::RXP2RXZ800P2OWil209^KV`80UIFE0P2?Shl208J6QP80M7Ad0P1UIFD205IFEP80
C4a<0P12@T8203/k>`80<S8b0P0];Bd202DU9@0301lO7`0D51@051@D00@051@D0P0E5AD201LG5`80
51@D0P0A4A4200`<30801`L70P0410@400820P801@D50P0820P200X:2P0300`<300@4100410@0080
5ADE0P0I6AT201dM7@808R8R0P0V9RH202XZ:P80;Rh^0P0b<S8203Hf=P80>SXj0P0n?Sh20492@P80
ATI60P1:BTX00`1>CTh0DE5A055AD@0205EEE@80FEUI0P1MGEd2061PH080I6AT0P1XJ6PE0?ooo`00
4`3oool2071`L080MGEe0P1iNGT207inOP80PX:20P27QhL208^;R`80T92@00<0U9BD09VIV@2IVIT0
0P2MWId20:6QX@80YZJV0P2ZZZX20:j^[P80/k>c0P2g]kL20;^k^`80`<300P34a<@20<K6aP80`/;2
0P2m_Kd20;Vi^@030;>c/`2][Jd0[Jf]0080Z:RX0P2RXZ8209bLW080UIFE0P2=SHd408J6QP80R8R8
0P2;Rh/208f=S@80Shn?0P2ATI4209BDU080UYJF00<0V9RH09ZJVP2JVYX00P2MWId209jNWP80X:2P
0P2RXZ820:BTY080YZJV0P2XZ:P20:VYZ@80ZZZZ0P2[Zj/20:VYZ@80YjNW0P2VYZH20:BTY0030:>S
X`2QXJ40XJ6Q00@0X:2P0P2QXJ420::RXP80Xj>S0P2TY:@20:FUY@80YZJV0P2WYjL80:RXZ080YjNW
00<0YZJV0:BTY02TY:@00P2QXJ4209fMW@80V9RH0P2ATI4208V9R@80NWYj0P1YJFT205YJFP80Cdm?
0P14A4@203hn?P80=CDe0P0_;bl202LW9`03020P800G5aL05aLG008051@D0P0C4a<201@D50805aLG
0P0E5AD2014A4@803@d=0P071`L200<30`800@410P020P8200D51@801`L70P0:2PX00`0=3@d04A4A
014A4@0201HF5P806QXJ0P0N7Qh2028R8P809RHV0P0[:b/202l_;`80<c<c0P0g=cL203/k>`80?clo
0P12@T8204I6AP80BTY:00<0CTi>059BDP1BDU800P1EEED205UIF@80GEeM0P1PH60206ATI080J6QX
5@3oool001<0oooo0P1`L70207EeM@80NGUi0P1nOWh208:2PP80QhN70P2;Rh/2092@T00309BDU02I
VIT0VIVI0080WIfM0P2QXJ420:JVYP80ZZZZ0P2^[Zh20;>c/`80]kNg0P2k^k/20<30`080a<C40P36
a/H20<;2`P80_Kfm0P2i^KT00`2c/k<0[Jf]0:f][@020:RXZ080XZ:R0P2LW9`209FEU@80SHf=1026
QXH208R8R080Rh^;0P2=SHd208n?S`80TI6A0P2DU9@209JFUP0309RHV02JVYX0VYZJ0080WIfM0P2N
WYh20:2PX080XZ:R0P2TY:@20:JVYP80Z:RX0P2YZJT20:ZZZP80Zj^[0P2YZJT20:NWY`80YZJV0P2T
Y:@00`2SXj<0XJ6Q0:6QX@040:2PX080XJ6Q0P2RXZ820:>SX`80Y:BT0P2UYJD20:JVYP80YjNW202X
Z:P20:NWY`030:JVYP2TY:@0Y:BT0080XJ6Q0P2MWId209RHV080TI6A0P29RHT207YjNP80JFUY0P1J
FUX204m?C`80A4A40P0n?Sh203De=@80;bl_0P0W9bL00`0P82005aLG01LG5`0201@D50804a<C0P0D
51@201LG5`805ADE0P0A4A4200d=3@801`L70P030`<200410@800P820P051@D200L71`802PX:00<0
3@d=014A4@0A4A400P0F5QH201XJ6P807QhN0P0R8R8202HV9P80:b/[0P0_;bl203<c<`80=cLg0P0k
>c/203lo?`80@T920P16ATH204Y:BP0304i>CP1BDU80DU9B0080EEEE0P1IFET205eMG@80H61P0P1T
I6@206QXJ1D0oooo000C0?ooo`80L71`0P1eMGD207UiN@80OWin0P23Ph<208N7Q`80S8b<0P2ATI40
0`2EUID0VYZJ09ZJVP0209jNWP80XZ:R0P2WYjL20:b/[080/;2`0P2d];@20;Vi^@80_Kfm0P32`/84
0<K6aP80`/;20P2m_Kd20;Ng]`030;:b/P2][Jd0[Jf]0080YjNW0P2QXJ4209^KV`80U9BD0P2<S8`2
08>3P`80QhN70P29RHT208^;R`80SHf=0P2?Shl2096AT@80Ti>C0P2EUID00`2HV9P0VYZJ09ZJVP02
09bLW080WYjN0P2OWil20:6QX@80Xj>S0P2TY:@20:NWY`80ZJVY102ZZZX20:VYZ@80YjNW0P2VYZH2
0:BTY0030:>SX`2RXZ80XZ:R00H0XJ6Q0P2RXZ820:>SX`80Y:BT0P2UYJD20:JVYP80YjNW202XZ:P3
0:NWY`80YJFU0P2RXZ8209nOW`80VYZJ0P2DU9@208b<S080P8200P1^KVh205iNGP80De=C0P18B4P2
0410@080>3Ph0P0a<C4202TY:@03024Q8@0I6AT06ATI00805ADE100D51@401HF5P804A4A0P0=3@d2
00L71`8010@40P010@4200820P801@D50P061PH200T92@0300h>3P0B4Q804Q8B00805QHF0P0J6QX2
01lO7`808b<S0P0W9bL202/[:`80;bl_0P0c<c<203Lg=`80>c/k0P0o?cl204=3@`80ATI60P1:BTX0
0`1>CTh0DU9B059BDP0205IFEP80FEUI0P1MGEd2065QH@80I6AT0P1XJ6PE0?ooo`004`3oool2071`
L080MGEe0P1iNGT207inOP80Ph>30P27QhL208b<S080TI6A00<0UIFE09ZJVP2JVYX00P2NWYh20::R
XP80YjNW0P2/[:`20;2`/080];Bd0P2i^KT20;fm_@80`/;21036a/H20<;2`P80_Kfm0P2g]kL00`2b
/[80[Jf]0:f][@020:NWY`80XJ6Q0P2KVi/209BDU080S8b<0P23Ph<208N7Q`80RHV90P2;Rh/208f=
S@80Shn?0P2ATI4209>CT`80UIFE00<0V9RH09ZJVP2JVYX00P2LW9`209jNWP80WinO0P2QXJ420:>S
X`80Y:BT0P2WYjL20:VYZ@@0ZZZZ0P2YZJT20:NWY`80YZJV0P2TY:@00`2SXj<0XZ:R0::RXP060:6Q
X@80XZ:R0P2SXj<20:BTY080YJFU0P2VYZH20:NWY`P0Z:RX0`2WYjL20:FUY@80XZ:R0P2OWil209ZJ
VP80U9BD0P2<S8`20820P080KVi^0P1NGUh205=CD`80B4Q80P10@40203Ph>080<C4a0P0Y:BT00`0Q
8B406ATI01TI6@0201DE5@@051@D100F5QH2014A4@803@d=0P071`L200@410800@410P020P8200D5
1@801PH60P092@T00`0>3Ph04Q8B018B4P0201HF5P806QXJ0P0O7al202<S8`809bLW0P0[:b/202l_
;`80<c<c0P0g=cL203/k>`80?clo0P13@d<204I6AP80BTY:00<0CTi>059BDP1BDU800P1FEUH205UI
F@80GEeM0P1QHF4206ATI080J6QX5@3oool001<0oooo0P1`L70207EeM@80NGUi0P1nOWh208>3P`80
R8R80P2=SHd209:BTP0309JFUP2KVi/0Vi^K0080X:2P0P2TY:@20:VYZ@80[Jf]0P2b/[820;Jf]P80
^k^k0P2o_kl20<C4a080bLW90P37alL20<;2`P80_[jn0P2g]kL00`2c/k<0[Jf]0:f][@020:NWY`80
XJ6Q0P2JVYX209>CT`80SHf=0P25QHD208R8R080RXZ:0P2<S8`208j>SP80T92@0P2ATI4209>CT`80
UIFE00<0UiNG09VIV@2IVIT00P2KVi/209fMW@80WinO0P2PX:020::RXP80Y:BT0P2VYZH20:RXZ0H0
ZJVY0P2WYjL20:JVYP80YJFU00<0Xj>S0::RXP2RXZ80202QXJ420::RXP@0Y:BT0P2UYJD20:JVYP80
YjNW1P2XZ:P20:NWY`030:JVYP2UYJD0YJFU0080Y:BT0P2PX:0209^KV`80UIFE0P2>SXh208>3P`80
LW9b0P1SHf<205EEE@80Bd];0P12@T8203Xj>P80<c<c0P0/;2`00`0T92@06a/K01/K6`0201LG5`80
5ADE0P0D51@201DE5@805aLG0P0B4Q8200d=3@801`L70P030`<2000000800P820P061PH200L71`80
2`/;00<03`l?01<C4`0C4a<00P0G5aL201`L7080820P0P0T92@202PX:080;2`/0P0`<30203@d=080
>3Ph0P0k>c/203lo?`80@d=30P17AdL204];B`0304i>CP1BDU80DU9B0080EUIF0P1IFET205eMG@80
HF5Q0P1TI6@206QXJ1D0oooo000C0?ooo`80L71`0P1eMGD207YjNP80Ogmo0P24Q8@208V9R@80SHf=
0P2BTY800`2GUiL0W9bL09bLW0020:6QX@80YJFU0P2ZZZX20:n_[`80/k>c0P2h^;P20;fm_@80`L71
0P36a/H20<_;b`80b<S80P33`l<20;fm_@80]kNg00<0/[:b0:b/[02/[:`00P2WYjL20::RXP80VYZJ
0P2DU9@208j>SP@0RXZ:0P2;Rh/208f=S@80Shn?0P2@T902096AT@80Ti>C0P2EUID00`2FUYH0V9RH
09RHV00209ZJVP80W9bL0P2NWYh20:2PX080XJ6Q0P2SXj<20:JVYP80Z:RX1P2YZJT20:NWY`80YZJV
0P2TY:@00`2SXj<0XJ6Q0:6QX@080:6QX@80XZ:R0P2SXj<40:BTY080YJFU0P2VYZH80:NWY`030:JV
YP2UYJD0YJFU0080Xj>S0P2QXJ4209fMW@80UYJF0P2?Shl208N7Q`80MWIf0P1VIVH205UIF@80CDe=
0P14A4@203`l?080<c<c0P0];Bd00`0U9BD07AdM01dM7@0201PH60805QHF100E5AD201LG5`804Q8B
0P0>3Ph200L71`800`<30P00000200820P801@D50P071`L200/;2`03010@400D51@051@D008061PH
0P0L71`2020P80809BDU0P0Y:BT202d];@80<30`0P0d=3@203Ph>080?3`l0P10@40204A4A080AdM7
0P1;Bd/00`1?Cdl0DU9B059BDP0205IFEP80FUYJ0P1MGEd2065QH@80I6AT0P1XJ6PE0?ooo`004`3o
ool2071`L080MGEe0P1jNWX207moO`80Q8B40P29RHT208f=S@80TY:B00<0UiNG09bLW02LW9`00P2Q
XJ420:FUY@80ZZZZ0P2_[jl20;>c/`80^;Rh0P2m_Kd20<71`@80a/K60P3;bl/20<S8b080`l?30P2m
_Kd20;Ng]`030;:b/P2/[:`0[:b/0080YjNW0P2RXZ8209ZJVP80U9BD0P2>SXh408Z:RP80Rh^;0P2=
SHd208n?S`80T92@0P2ATI4209>CT`80UIFE00<0UYJF09RHV02HV9P00P2JVYX209bLW080WYjN0P2P
X:020:6QX@80Xj>S0P2VYZH20:RXZ0H0ZJVY0P2WYjL20:JVYP80Y:BT00<0Xj>S0:6QX@2QXJ40202Q
XJ420::RXP80Xj>S102TY:@20:FUY@80YZJV202WYjL00`2VYZH0YJFU0:FUY@020:>SX`80XJ6Q0P2M
WId209JFUP80Shn?0P27QhL207IfMP80IVIV0P1IFET204e=C@80A4A40P0l?3`203<c<`80;Bd]00<0
9BDU01dM7@0M7Ad00P0H61P201HF5P@05ADE0P0G5aL2018B4P803Ph>0P071`L200<30`8000000P02
0P8200D51@801`L70P0;2`/00`0@410051@D01@D500201PH608071`L0P0P820202DU9@80:BTY0P0]
;Bd2030`<080=3@d0P0h>3P203`l?080@4100P14A4@204M7A`80Bd];00<0Cdm?059BDP1BDU800P1F
EUH205YJFP80GEeM0P1QHF4206ATI080J6QX5@3oool001<0oooo0P1`L70207EeM@80NWYj0P1oOgl2
08B4Q080RHV90P2>SXh209>CT`0309RHV02MWId0WIfM0080XZ:R0P2WYjL20:^[Z`80/;2`0P2e]KD2
0;Zj^P80_kno0P33`l<20<S8b080bl_;0P38b<P20<?3``80_;bl0P2g]kL00`2b/[80[:b/0:b/[002
0:JVYP80X:2P0P2JVYX209>CT`80T92@1P2=SHd208j>SP80Shn?0P2@T90409:BTP80Ti>C00<0UIFE
09NGU`2GUiL00P2IVIT209^KV`80WIfM0P2OWil20:6QX@80XZ:R0P2UYJD20:NWY`80ZJVY0P2ZZZX2
0:VYZ@80YjNW0P2UYJD20:BTY0030::RXP2QXJ40XJ6Q00@0X:2P1P2QXJ440::RXP80Xj>S0P2TY:@4
0:FUY@L0YZJV0P2UYJD20:>SX`80XJ6Q0P2NWYh209RHV080T92@0P28R8P207]kN`80Jf][0P1MGEd2
055AD@80ATI60P0n?Sh203De=@80;Rh^00<09RHV01hN7P0N7Qh00P0I6AT201LG5`805ADE0P0D51@2
01LG5`804a<C0P0>3Ph200L71`800`<30P00000200410@801@D50P0820P200`<3003014A4@0E5AD0
5ADE00806ATI0P0M7Ad2024Q8@809BDU0P0Y:BT202d];@80<C4a0P0e=CD203Ti>@80?3`l0P10@402
04A4A080B4Q80P1;Bd/00`1?Cdl0DU9B059BDP0205IFEP80FUYJ0P1MGEd2065QH@80IFEU0P1XJ6PE
0?ooo`004`3oool2071`L080MGEe0P1jNWX207moO`80Q8B40P29RHT208j>SP80Ti>C00<0V9RH09fM
W@2MWId00P2RXZ820:NWY`80Zj^[0P2`/;020;Fe]@80^[Zj0P2o_kl20<?3``80b<S80P3;bl/20<S8
b080`l?30P2l_;`20;Ng]`030;:b/P2/[:`0[:b/0080YZJV0P2PX:0209ZJVP80Ti>C0P2@T90608f=
S@80SXj>0P2?Shl2092@T0@0TY:B0P2CTi<00`2EUID0UiNG09NGU`0209VIV@80Vi^K0P2MWId209nO
W`80XJ6Q0P2RXZ820:FUY@80YjNW0P2YZJT20:ZZZP80ZJVY0P2WYjL20:FUY@80Y:BT00<0XZ:R0:6Q
X@2QXJ40102PX:060:6QX@@0XZ:R0P2SXj<20:BTY0@0YJFU1`2VYZH20:FUY@80Xj>S0P2QXJ4209jN
WP80V9RH0P2@T90208R8R080Ng]k0P1[Jf/205eMG@80DE5A0P16ATH203hn?P80=CDe0P0^;Rh00`0V
9RH07QhN01hN7P0201TI6@805aLG0P0E5AD201@D50805aLG0P0C4a<200h>3P801`L70P030`<20000
00800@410P051@D200P8208030`<00<04A4A01DE5@0E5AD00P0I6AT201dM7@808B4Q0P0U9BD202TY
:@80;Bd]0P0a<C4203De=@80>CTi0P0l?3`20410@080A4A40P18B4P204];B`0304m?C`1BDU80DU9B
0080EUIF0P1JFUX205eMG@80HF5Q0P1UIFD206QXJ1D0oooo000C0?ooo`80L71`0P1eMGD207]kN`80
Ogmo0P25QHD208Z:RP80Shn?0P2DU9@00`2IVIT0WYjN09jNWP020:>SX`80Z:RX0P2][Jd20;:b/P80
]kNg0P2l_;`20<71`@80a/K60P3;bl/20<[:bP80alO70P32`/820;^k^`80][Jf00<0/K6a0:^[Z`2[
Zj/00P2WYjL20:2PX080VIVI102?Shl608j>SP@0Shn?0P2@T902096AT@80TY:B0P2CTi<00`2DU9@0
UYJF09JFUP0209NGU`80VIVI0P2KVi/209fMW@80X:2P0P2QXJ420:BTY080YjNW102YZJT20:RXZ080
YZJV0P2UYJD20:BTY0030::RXP2PX:00X:2P0080X:2P102OWil60:2PX0@0XJ6Q0P2RXZ840:>SX`80
Y:BT1@2UYJD20:BTY080XZ:R0P2PX:0209jNWP80V9RH0P2ATI4208R8R080O7al0P1]KFd205mOG`80
DU9B0P18B4P203lo?`80=SHf0P0_;bl00`0W9bL07alO01lO7`0201XJ6P8061PH0P0F5QH201@D5080
5QHF0P0C4a<200l?3`801`L70P030`<2000000800@410P0410@200T92@803@d=00<04A4A01HF5P0F
5QH00P0J6QX201hN7P808R8R0P0V9RH202XZ:P80;Rh^0P0b<S8203Hf=P80>SXj0P0m?Cd20451@@80
A4A40P18B4P204a<C00304m?C`1CDe<0De=C0080EUIF0P1JFUX205eMG@80HF5Q0P1UIFD206QXJ1D0
oooo000C0?ooo`80L71`0P1eMGD207]kN`80Ogmo0P25QHD208Z:RP80Shn?0P2DU9@00`2IVIT0WYjN
09jNWP020:>SX`80Z:RX0P2][Jd20;:b/P80]kNg0P2l_;`20<71`@80a/K60P3;bl/20<[:bP80alO7
0P32`/820;^k^`80][Jf00<0/K6a0:^[Z`2[Zj/00P2WYjL20:2PX080VIVI102?Shl608j>SP@0Shn?
0P2@T902096AT@80TY:B0P2CTi<00`2DU9@0UYJF09JFUP0209NGU`80VIVI0P2KVi/209fMW@80X:2P
0P2QXJ420:BTY080YjNW102YZJT20:RXZ080YZJV0P2UYJD20:BTY0030::RXP2PX:00X:2P0080X:2P
102OWil60:2PX0@0XJ6Q0P2RXZ840:>SX`80Y:BT1@2UYJD20:BTY080XZ:R0P2PX:0209jNWP80V9RH
0P2ATI4208R8R080O7al0P1]KFd205mOG`80DU9B0P18B4P203lo?`80=SHf0P0_;bl00`0W9bL07alO
01lO7`0201XJ6P8061PH0P0F5QH201@D50805QHF0P0C4a<200l?3`801`L70P030`<2000000800@41
0P0410@200T92@803@d=00<04A4A01HF5P0F5QH00P0J6QX201hN7P808R8R0P0V9RH202XZ:P80;Rh^
0P0b<S8203Hf=P80>SXj0P0m?Cd20451@@80A4A40P18B4P204a<C00304m?C`1CDe<0De=C0080EUIF
0P1JFUX205eMG@80HF5Q0P1UIFD206QXJ1D0oooo000C0?ooo`80LG5a0P1fMWH207]kN`80P8200P25
QHD208Z:RP80T92@0P2EUID00`2JVYX0WinO09nOW`020:BTY080ZZZZ0P2_[jl20;>c/`80^KVi0P2n
_[h20<?3``80b<S80P3?cll20<c<c080b<S80P32`/820;^k^`80][Jf00<0/;2`0:ZZZP2ZZZX00P2U
YJD209jNWP80UiNG0P2ATI42092@T0P0Shn?102@T904096AT@80TY:B00<0Ti>C09BDU02DU9@00P2E
UID209RHV080VYZJ0P2LW9`209jNWP80X:2P0P2SXj<20:FUY@80Z:RX0P2YZJT20:RXZ080YZJV0P2T
Y:@20:>SX`030:6QX@2PX:00X:2P0080WinO202NWYh809nOW`80X:2P102QXJ420::RXP<0Xj>S0P2R
XZ820:6QX@80WinO0P2MWId209RHV080TY:B0P29RHT207emO@80Kfm_0P1QHF4205ADE080BDU90P0o
?cl203Lg=`80;bl_00<09RHV01lO7`0O7al00P0K6a/201TI6@805QHF100E5AD201@D50803`l?0P08
20P200<30`@000000P051@D200T92@803Ph>00<04Q8B01LG5`0G5aL00P0K6a/201lO7`808b<S0P0W
9bL202/[:`80;bl_0P0c<c<203Hf=P80>SXj0P0n?Sh20451@@80ADE50P19BDT204a<C003051@D01C
De<0De=C0080EeMG0P1JFUX205iNGP80HF5Q0P1UIFD206QXJ1D0oooo000C0?ooo`80LG5a0P1fMWH2
07]kN`80P8200P25QHD208Z:RP80T92@0P2EUID00`2JVYX0WinO09nOW`020:BTY080ZZZZ0P2_[jl2
0;>c/`80^KVi0P2n_[h20<?3``80b<S80P3?cll20<c<c080b<S80P32`/820;^k^`80][Jf00<0/;2`
0:ZZZP2ZZZX00P2UYJD209jNWP80UiNG0P2ATI42092@T0P0Shn?102@T904096AT@80TY:B00<0Ti>C
09BDU02DU9@00P2EUID209RHV080VYZJ0P2LW9`209jNWP80X:2P0P2SXj<20:FUY@80Z:RX0P2YZJT2
0:RXZ080YZJV0P2TY:@20:>SX`030:6QX@2PX:00X:2P0080WinO202NWYh809nOW`80X:2P102QXJ42
0::RXP<0Xj>S0P2RXZ820:6QX@80WinO0P2MWId209RHV080TY:B0P29RHT207emO@80Kfm_0P1QHF42
05ADE080BDU90P0o?cl203Lg=`80;bl_00<09RHV01lO7`0O7al00P0K6a/201TI6@805QHF100E5AD2
01@D50803`l?0P0820P200<30`@000000P051@D200T92@803Ph>00<04Q8B01LG5`0G5aL00P0K6a/2
01lO7`808b<S0P0W9bL202/[:`80;bl_0P0c<c<203Hf=P80>SXj0P0n?Sh20451@@80ADE50P19BDT2
04a<C003051@D01CDe<0De=C0080EeMG0P1JFUX205iNGP80HF5Q0P1UIFD206QXJ1D0oooo000C0?oo
o`80LG5a0P1fMWH207]kN`80PH610P26QXH208^;R`80T92@0P2FUYH00`2KVi/0X:2P0:2PX0020:JV
YP80Zj^[0P2`/;020;Fe]@80^[Zj0P30`<020<G5a@80b/[:0P3?cll20<c<c080b<S80P32`/820;^k
^`80];Bd00<0[jn_0:VYZ@2YZJT00P2RXZ8209fMW@80UYJF0P2CTi<2096AT@H0T92@0P2?Shl6092@
T0D0TI6A0P2BTY8209>CT`80UIFE0P2HV9P209ZJVP80WIfM0P2OWil20::RXP80YJFU0P2XZ:P20:ZZ
ZP80ZJVY0P2WYjL20:BTY080Xj>S00<0XJ6Q09nOW`2OWil0102NWYh@09fMW@@0WYjN0P2OWil20:2P
X0<0XJ6Q0P2PX:0209jNWP80W9bL0P2IVIT209:BTP80RXZ:0P1oOgl2075aL@80Hf=S0P1EEED204U9
B@80?clo0P0g=cL202l_;`0302HV9P0M7Ad07AdM008071`L0P0I6AT201LG5`805ADE0P0C4a<201@D
50803@d=0P0820P200@410@00@410P051@D200X:2P803`l?00<04a<C01PH600H61P00P0L71`2020P
808092@T0P0X:2P202`/;080<30`0P0c<c<203Lg=`80>c/k0P0n?Sh20492@P80ADE50P19BDT204a<
C003051@D01DE5@0E5AD0080EeMG0P1JFUX205iNGP80HF5Q0P1UIFD206QXJ1D0oooo000C0?ooo`80
LG5a0P1fMWH207]kN`80PH610P26QXH208^;R`80T92@0P2FUYH00`2KVi/0X:2P0:2PX0020:JVYP80
Zj^[0P2`/;020;Fe]@80^[Zj0P30`<020<G5a@80b/[:0P3?cll20<c<c080b<S80P32`/820;^k^`80
];Bd00<0[jn_0:VYZ@2YZJT00P2RXZ8209fMW@80UYJF0P2CTi<2096AT@H0T92@0P2?Shl6092@T0D0
TI6A0P2BTY8209>CT`80UIFE0P2HV9P209ZJVP80WIfM0P2OWil20::RXP80YJFU0P2XZ:P20:ZZZP80
ZJVY0P2WYjL20:BTY080Xj>S00<0XJ6Q09nOW`2OWil0102NWYh@09fMW@@0WYjN0P2OWil20:2PX0<0
XJ6Q0P2PX:0209jNWP80W9bL0P2IVIT209:BTP80RXZ:0P1oOgl2075aL@80Hf=S0P1EEED204U9B@80
?clo0P0g=cL202l_;`0302HV9P0M7Ad07AdM008071`L0P0I6AT201LG5`805ADE0P0C4a<201@D5080
3@d=0P0820P200@410@00@410P051@D200X:2P803`l?00<04a<C01PH600H61P00P0L71`2020P8080
92@T0P0X:2P202`/;080<30`0P0c<c<203Lg=`80>c/k0P0n?Sh20492@P80ADE50P19BDT204a<C003
051@D01DE5@0E5AD0080EeMG0P1JFUX205iNGP80HF5Q0P1UIFD206QXJ1D0oooo000C0?ooo`80LG5a
0P1fMWH207alO080PH610P27QhL208b<S080TI6A0P2GUiL00`2LW9`0XJ6Q0:6QX@020:NWY`80[:b/
0P2a/K420;Ng]`80_;bl0P31`L420<K6aP80bl_;0P3>c/h20<[:bP80alO70P31`L420;^k^`80];Bd
00<0[Zj^0:NWY`2WYjL00P2PX:0209VIV@80UIFE0P2CTi<209:BTP@0TI6A4@2@T902096AT@80Ti>C
0P2EUID209RHV080Vi^K0P2NWYh20:6QX@80Y:BT0P2WYjL40:ZZZP80Z:RX0P2UYJD20:>SX`030:6Q
X@2OWil0WinO0080WYjN102MWId409bLW080Vi^K202JVYX409^KV`80WIfM0`2NWYh209nOW`80WYjN
0P2MWId209^KV`80V9RH0P2BTY8208Z:RP80P8200P1cLg<206ATI080EeMG0P1:BTX20410@080>3Ph
0P0`<3000`0W9bL07QhN01hN7P0201`L70806ATI0P0G5aL201DE5@804A4A0P0D51@200`<308020P8
0P051@D400820P801`L70P0<30`2010@400301@D500I6AT06ATI00807AdM0P0Q8B4202DU9@80:BTY
0P0];Bd2030`<080=3@d0P0h>3P203`l?080?clo0P13@d<204I6AP80BTY:0P1=CDd00`1@D500E5AD
05ADE00205MGE`80Fe]K0P1NGUh2065QH@80IFEU0P1XJ6PE0?ooo`004`3oool2075aL@80MWIf0P1l
O7`20861P@80QhN70P2<S8`2096AT@80UiNG00<0W9bL0:6QX@2QXJ400P2WYjL20:b/[080/K6a0P2g
]kL20;bl_080`L710P36a/H20<_;b`80c/k>0P3:b/X20<O7a`80`L710P2k^k/20;Bd]0030:j^[P2W
YjL0YjNW0080X:2P0P2IVIT209FEU@80Ti>C0P2BTY84096ATA40T92@0P2ATI4209>CT`80UIFE0P2H
V9P209^KV`80WYjN0P2QXJ420:BTY080YjNW102ZZZX20:RXZ080YJFU0P2SXj<00`2QXJ40WinO09nO
W`0209jNWP@0WIfM102LW9`209^KV`P0VYZJ102KVi/209fMW@<0WYjN0P2OWil209jNWP80WIfM0P2K
Vi/209RHV080TY:B0P2:RXX20820P080Lg=c0P1TI6@205MGE`80BTY:0P10@40203Ph>080<30`00<0
9bLW01hN7P0N7Qh00P0L71`201TI6@805aLG0P0E5AD2014A4@8051@D0P0<30`200P820801@D51002
0P8200L71`8030`<0P0@41000`0D51@06ATI01TI6@0201dM7@808B4Q0P0U9BD202TY:@80;Bd]0P0`
<30203@d=080>3Ph0P0l?3`203lo?`80@d=30P16ATH204Y:BP80CDe=00<0D51@05ADE01DE5@00P1G
EeL205]KF`80GUiN0P1QHF4206EUI@80J6QX5@3oool001<0oooo0P1aLG4207MgM`80O7al0P22PX82
08N7Q`80SHf=0P2BTY8209RHV00309fMW@2SXj<0Xj>S0080Z:RX0P2][Jd20;>c/`80^;Rh0P2n_[h2
0<?3``80b<S80P3>c/h20<g=c@80bl_;0P36a/H20;no_`80^[Zj0P2c/k<00`2][Jd0YJFU0:FUY@02
09jNWP80UIFE0P2DU9@209>CT`X0TI6A1P2@T90408n?S`<0SXj>0P2?Shl2096AT@80Ti>C0P2FUYH2
09ZJVP80WIfM0P2PX:020:BTY080YjNW102ZZZX20:VYZ@80YjNW0P2TY:@00`2RXZ80X:2P0:2PX002
09jNWP@0WIfM0P2LW9`209^KV`80VIVI0P2HV9P809NGU`80V9RH0P2IVIT209^KV`D0W9bL0P2KVi/2
09ZJVP80UYJF0P2BTY8208Z:RP80P8200P1eMGD206IVIP80F5QH0P1;Bd/20410@080>3Ph0P0`<300
0`0X:2P07alO01lO7`0201dM7@806QXJ0P0G5aL201HF5P80410@0P0D51@200d=3@801`L70P051@D4
00@410802@T90P0=3@d2018B4P0301HF5P0J6QX06QXJ00807QhN0P0R8R8202HV9P80:RXZ0P0^;Rh2
034a<@80=CDe0P0i>CT203`l?080@4100P13@d<204M7A`80BTY:0P1=CDd00`1ADE40E5AD05ADE002
05QHF080Fe]K0P1NGUh2069RHP80IFEU0P1XJ6PE0?ooo`004`3oool2075aL@80MgMg0P1lO7`208:2
PP80QhN70P2=SHd209:BTP80V9RH00<0WIfM0:>SX`2SXj<00P2XZ:P20:f][@80/k>c0P2h^;P20;jn
_P80`l?30P38b<P20<k>cP80cLg=0P3;bl/20<K6aP80_kno0P2j^[X20;>c/`030:f][@2UYJD0YJFU
0080WYjN0P2EUID209BDU080Ti>C2P2ATI46092@T0@0Shn?0`2>SXh208n?S`80TI6A0P2CTi<209JF
UP80VYZJ0P2MWId20:2PX080Y:BT0P2WYjL40:ZZZP80ZJVY0P2WYjL20:BTY0030::RXP2PX:00X:2P
0080WYjN102MWId209bLW080Vi^K0P2IVIT209RHV0P0UiNG0P2HV9P209VIV@80Vi^K1@2LW9`209^K
V`80VYZJ0P2FUYH209:BTP80RXZ:0P20P80207EeM@80IVIV0P1HF5P204];B`80@4100P0h>3P2030`
<00302PX:00O7al07alO00807AdM0P0J6QX201LG5`805QHF0P0@410201@D50803@d=0P071`L200D5
1@@010@40P092@T200d=3@804Q8B00<05QHF01XJ6P0J6QX00P0N7Qh2028R8P809RHV0P0Z:RX202h^
;P80<C4a0P0e=CD203Ti>@80?3`l0P10@40204=3@`80AdM70P1:BTX204e=C@03055AD@1DE5@0E5AD
0080F5QH0P1KFe/205iNGP80HV9R0P1UIFD206QXJ1D0oooo000C0?ooo`80LG5a0P1gMgL207emO@80
PX:20P28R8P208j>SP80Ti>C0P2IVIT00`2NWYh0Y:BT0:BTY0020:VYZ@80[jn_0P2d];@20;Zj^P80
_kno0P35aLD20<[:bP80dM7A0P3;bl/20<[:bP80aLG50P2n_[h20;Rh^080/[:b00<0Zj^[0::RXP2R
XZ800P2LW9`209JFUP80U9BD0P2BTY82096AT@P0TY:B0P2ATI42092@T080Shn?102>SXh00`2=SHd0
S8b<08b<S00208b<S080SXj>0P2ATI4209BDU080V9RH0P2LW9`209nOW`80Y:BT0P2WYjL20:^[Z`80
[:b/0P2[Zj/20:RXZ080YZJV00<0Xj>S0:6QX@2QXJ400P2OWil209jNWP80WIfM0P2LW9`209^KV`80
V9RH0P2FUYH209FEU@80U9BD102CTi<209BDU080UYJF0P2GUiL00`2IVIT0VYZJ09ZJVP0409ZJVP80
V9RH0P2EUID2092@T080RXZ:0P21PH4207MgM`80JFUY0P1IFET204a<C080@D510P0h>3P2030`<003
02PX:00O7al07alO00807AdM0P0K6a/401LG5`80410@0P0D51@200h>3P801`L70P051@D200@41080
1PH60P0:2PX200l?3`804a<C00<05aLG01/K6`0K6a/00P0O7al202<S8`809bLW0P0[:b/202l_;`80
<S8b0P0f=SH203Ti>@80?Cdm0P10@40204A4A080AdM70P1;Bd/204i>CP03055AD@1DE5@0E5AD0080
F5QH0P1KFe/205iNGP80HV9R0P1UIFD206QXJ1D0oooo000C0?ooo`80LG5a0P1gMgL207emO@80PX:2
0P28R8P208j>SP80Ti>C0P2IVIT00`2NWYh0Y:BT0:BTY0020:VYZ@80[jn_0P2d];@20;Zj^P80_kno
0P35aLD20<[:bP80dM7A0P3;bl/20<[:bP80aLG50P2n_[h20;Rh^080/[:b00<0Zj^[0::RXP2RXZ80
0P2LW9`209JFUP80U9BD0P2BTY82096AT@P0TY:B0P2ATI42092@T080Shn?102>SXh00`2=SHd0S8b<
08b<S00208b<S080SXj>0P2ATI4209BDU080V9RH0P2LW9`209nOW`80Y:BT0P2WYjL20:^[Z`80[:b/
0P2[Zj/20:RXZ080YZJV00<0Xj>S0:6QX@2QXJ400P2OWil209jNWP80WIfM0P2LW9`209^KV`80V9RH
0P2FUYH209FEU@80U9BD102CTi<209BDU080UYJF0P2GUiL00`2IVIT0VYZJ09ZJVP0409ZJVP80V9RH
0P2EUID2092@T080RXZ:0P21PH4207MgM`80JFUY0P1IFET204a<C080@D510P0h>3P2030`<00302PX
:00O7al07alO00807AdM0P0K6a/401LG5`80410@0P0D51@200h>3P801`L70P051@D200@410801PH6
0P0:2PX200l?3`804a<C00<05aLG01/K6`0K6a/00P0O7al202<S8`809bLW0P0[:b/202l_;`80<S8b
0P0f=SH203Ti>@80?Cdm0P10@40204A4A080AdM70P1;Bd/204i>CP03055AD@1DE5@0E5AD0080F5QH
0P1KFe/205iNGP80HV9R0P1UIFD206QXJ1D0oooo000C0?ooo`80LG5a0P1gMgL207emO@80Ph>30P29
RHT208j>SP80U9BD0P2JVYX00`2OWil0YJFU0:FUY@020:^[Z`80/;2`0P2f][H20;bl_080`L710P37
alL20<c<c080dm?C0P3<c<`20<W9b@80`/;20P2l_;`20;Jf]P80/;2`00<0Z:RX0:2PX02PX:000P2H
V9P209NGU`80Ti>C0P2ATI4209:BTPP0Ti>C0P2BTY82096AT@80Shn?0P2>SXh208f=S@0308b<S02;
Rh/0Rh^;0080Rh^;0P2<S8`208n?S`80Ti>C0P2HV9P209^KV`80WinO0P2TY:@20:RXZ080[:b/0P2^
[Zh20:f][@80Zj^[0P2XZ:P00`2VYZH0Xj>S0:>SX`020:2PX080WinO0P2NWYh209fMW@80W9bL0P2I
VIT209FEU@80U9BD0P2CTi<209:BTP@0TI6A0P2CTi<209FEU@0309JFUP2GUiL0UiNG00@0V9RH0P2G
UiL209BDU080Shn?0P29RHT20861P@80MgMg0P1[Jf/205eMG@80CTi>0P11@D4203Ph>080<30`00<0
:BTY024Q8@0Q8B400P0M7Ad201`L70806ATI0P0G5aL2014A4@8051@D0P0>3Ph200L71`801PH60P05
1@D200L71`8030`<0P0A4A4201DE5@0301TI6@0M7Ad07AdM00808B4Q0P0U9BD202PX:080;2`/0P0`
<30203<c<`80=cLg0P0j>SX203hn?P80@D510P15ADD204Q8B080Bd];0P1>CTh00`1BDU80EEEE05EE
E@0205QHF080Fe]K0P1OGel2069RHP80IFEU0P1XJ6PE0?ooo`004`3oool2075aL@80MgMg0P1mOGd2
08>3P`80RHV90P2>SXh209BDU080VYZJ00<0WinO0:FUY@2UYJD00P2[Zj/20;2`/080][Jf0P2l_;`2
0<71`@80alO70P3<c<`20=?Cd`80c<c<0P39bLT20<;2`P80_;bl0P2f][H20;2`/0030:RXZ02PX:00
X:2P0080V9RH0P2GUiL209>CT`80TI6A0P2BTY8809>CT`80TY:B0P2ATI4208n?S`80SXj>0P2=SHd0
0`2<S8`0Rh^;08^;R`0208^;R`80S8b<0P2?Shl209>CT`80V9RH0P2KVi/209nOW`80Y:BT0P2XZ:P2
0:b/[080[Zj^0P2][Jd20:^[Z`80Z:RX00<0YZJV0:>SX`2SXj<00P2PX:0209nOW`80WYjN0P2MWId2
09bLW080VIVI0P2EUID209BDU080Ti>C0P2BTY84096AT@80Ti>C0P2EUID00`2FUYH0UiNG09NGU`04
09RHV080UiNG0P2DU9@208n?S`80RHV90P21PH4207MgM`80Jf][0P1MGEd204i>CP80@D510P0h>3P2
030`<00302TY:@0Q8B408B4Q00807AdM0P0L71`201TI6@805aLG0P0A4A4201@D50803Ph>0P071`L2
00H61P801@D50P071`L200`<30804A4A0P0E5AD00`0I6AT07AdM01dM7@02024Q8@809BDU0P0X:2P2
02`/;080<30`0P0c<c<203Lg=`80>SXj0P0n?Sh20451@@80ADE50P18B4P204];B`80CTi>00<0DU9B
05EEE@1EEED00P1HF5P205]KF`80GemO0P1RHV8206EUI@80J6QX5@3oool001<0oooo0P1aLG4207Mg
M`80OGem0P23Ph<208V9R@80Shn?0P2EUID209^KV`030:2PX02VYZH0YZJV0080[:b/0P2b/[820;Ng
]`80_Kfm0P33`l<20<S8b080cLg=0P3@d=020<g=c@80bLW90P31`L420;^k^`80];Bd0P2_[jl00`2U
YJD0WYjN09jNWP0209VIV@80V9RH0P2DU9@409:BTP@0U9BD0P2EUID209BDU080Ti>C0P2ATI4209:B
TP80Ti>C0P2@T9000`2<S8`0Rh^;08^;R`0208Z:RP80S8b<0P2=SHd2096AT@80UiNG0P2KVi/20:2P
X080YJFU0P2YZJT20:f][@80/;2`0P2a/K420:n_[`80[:b/00<0Z:RX0:JVYP2VYZH00P2QXJ4209nO
W`80X:2P0P2QXJ420:2PX080W9bL0P2GUiL209FEU@80Ti>C0P2BTY82092@T080Shn?0P2ATI4209>C
T`0309FEU@2FUYH0UYJF00@0UYJF0P2EUID209>CT`80SXj>0P28R8P20820P080MgMg0P1[Jf/205mO
G`80Cdm?0P12@T8203Ti>@80<30`00<0:BTY028R8P0R8R800P0O7al201dM7@806ATI0P0G5aL2014A
4@8051@D0P0?3`l200T92@8020P80P071`L200T92@803Ph>0P0B4Q8201HF5P0301XJ6P0N7Qh07QhN
00808R8R0P0V9RH202XZ:P80;Bd]0P0a<C4203@d=080>3Ph0P0k>c/203lo?`80@T920P15ADD204Q8
B080C4a<0P1?Cdl00`1BDU80EEEE05EEE@0205UIF@80G5aL0P1OGel2069RHP80IFEU0P1XJ6PE0?oo
o`004`3oool2075aL@80MgMg0P1mOGd208>3P`80RHV90P2?Shl209FEU@80Vi^K00<0X:2P0:JVYP2V
YZH00P2/[:`20;:b/P80]kNg0P2m_Kd20<?3``80b<S80P3=cLd20=3@d080cLg=0P39bLT20<71`@80
^k^k0P2d];@20:n_[`030:FUY@2NWYh0WYjN0080VIVI0P2HV9P209BDU0@0TY:B102DU9@209FEU@80
U9BD0P2CTi<2096AT@80TY:B0P2CTi<2092@T00308b<S02;Rh/0Rh^;0080RXZ:0P2<S8`208f=S@80
TI6A0P2GUiL209^KV`80X:2P0P2UYJD20:VYZ@80[Jf]0P2`/;020;6a/@80[jn_0P2/[:`00`2XZ:P0
YZJV0:JVYP020:6QX@80WinO0P2PX:020:6QX@80X:2P0P2LW9`209NGU`80UIFE0P2CTi<209:BTP80
T92@0P2?Shl2096AT@80Ti>C00<0UIFE09JFUP2FUYH0102FUYH209FEU@80Ti>C0P2>SXh208R8R080
P8200P1gMgL206][J`80GemO0P1?Cdl20492@P80>CTi0P0`<3000`0Y:BT08R8R028R8P0201lO7`80
7AdM0P0I6AT201LG5`804A4A0P0D51@200l?3`802@T90P0820P200L71`802@T90P0>3Ph2018B4P80
5QHF00<06QXJ01hN7P0N7Qh00P0R8R8202HV9P80:RXZ0P0];Bd2034a<@80=3@d0P0h>3P203/k>`80
?clo0P12@T8204E5A@80B4Q80P1<C4`204m?C`03059BDP1EEED0EEEE0080FEUI0P1LG5`205mOG`80
HV9R0P1UIFD206QXJ1D0oooo000C0?ooo`80LW9b0P1hN7P207inOP80Q8B40P2:RXX2092@T080UYJF
0P2LW9`00`2RXZ80Z:RX0:RXZ0020:f][@80/k>c0P2i^KT20;no_`80a<C40P3:b/X40=7Ad@80c/k>
0P39bLT20<;2`P80^KVi0P2b/[820:f][@030::RXP2HV9P0V9RH0080VIVI0P2GUiL209FEU@80TY:B
0P2DU9@209FEU@80UYJF102GUiL209JFUP80U9BD0P2EUID209NGU`80UIFE00<0TY:B08j>SP2>SXh0
0P2=SHd208j>SP80T92@0P2BTY8209NGU`80W9bL0P2QXJ420:JVYP80Zj^[0P2_[jl20;:b/P80];Bd
0P2c/k<20;6a/@<0[Jf]0P2ZZZX20:BTY080YJFU0P2VYZH20:BTY080XJ6Q0P2LW9`209VIV@@0UYJF
0P2BTY84092@T080Ti>C00<0U9BD09FEU@2EUID00P2FUYH209FEU@80U9BD0P2BTY8208j>SP80QhN7
0P20P80207IfMP80Jf][0P1OGel2051@D080@d=30P0j>SX2034a<@0302TY:@0S8b<08b<S0080820P
0P0M7Ad201XJ6P8061PH0P0B4Q8201@D50803@d=0P0:2PX200T92@8020P80P0<30`2010@408051@D
0P0H61P00`0L71`0820P020P800202@T90809bLW0P0[:b/202h^;P80<S8b0P0e=CD203Ti>@80?3`l
0P0o?cl204=3@`80ATI60P19BDT204a<C080Cdm?00<0De=C05IFEP1FEUH00P1IFET205aLG080GemO
0P1RHV8206EUI@80J6QX5@3oool001<0oooo0P1bLW8207QhN080OWin0P24Q8@208Z:RP80T92@0P2F
UYH209bLW0030::RXP2XZ:P0Z:RX0080[Jf]0P2c/k<20;Vi^@80_kno0P34a<@20<[:bP@0dM7A0P3>
c/h20<W9b@80`/;20P2i^KT20;:b/P80[Jf]00<0XZ:R09RHV02HV9P00P2IVIT209NGU`80UIFE0P2B
TY8209BDU080UIFE0P2FUYH409NGU`80UYJF0P2DU9@209FEU@80UiNG0P2EUID00`2BTY80SXj>08j>
SP0208f=S@80SXj>0P2@T90209:BTP80UiNG0P2LW9`20:6QX@80YZJV0P2[Zj/20:n_[`80/[:b0P2d
];@20;>c/`80/K6a0`2][Jd20:ZZZP80Y:BT0P2UYJD20:JVYP80Y:BT0P2QXJ4209bLW080VIVI102F
UYH209:BTP@0T92@0P2CTi<00`2DU9@0UIFE09FEU@0209JFUP80UIFE0P2DU9@209:BTP80SXj>0P27
QhL20820P080MWIf0P1[Jf/205mOG`80D51@0P13@d<203Xj>P80<C4a00<0:BTY02<S8`0S8b<00P0P
820201dM7@806QXJ0P0H61P2018B4P8051@D0P0=3@d200X:2P802@T90P0820P200`<3080410@0P0D
51@201PH600301`L700P8200820P008092@T0P0W9bL202/[:`80;Rh^0P0b<S8203De=@80>CTi0P0l
?3`203lo?`80@d=30P16ATH204U9B@80C4a<0P1?Cdl00`1CDe<0EUIF05IFEP0205UIF@80G5aL0P1O
Gel2069RHP80IFEU0P1XJ6PE0?ooo`004`3oool2079bLP80N7Qh0P1nOWh208B4Q080RXZ:0P2ATI42
09NGU`80WIfM00<0Xj>S0:VYZ@2YZJT00P2_[jl20;Fe]@80^k^k0P30`<020<K6aP80bl_;0P3Bd]82
0=?Cd`80c/k>0P38b<P20<71`@80^;Rh0P2a/K420:^[Z`030:>SX`2HV9P0V9RH0080V9RH0P2FUYH2
09BDU080Ti>C0P2DU9@209NGU`80VYZJ0P2KVi/209bLW080VIVI0P2EUID209JFUP80Vi^K0`2IVIT4
09:BTP80T92@0P2CTi<209FEU@80VIVI0P2NWYh20:>SX`80Z:RX0P2][Jd20;6a/@80];Bd0P2g]kL2
0;Rh^080][Jf00<0];Bd0;2`/02`/;000P2_[jl20:ZZZP80YjNW0P2/[:`20:RXZ080YjNW0P2OWil2
09jNWP80VYZJ0P2KVi/209JFUPH0Ti>C00<0U9BD09FEU@2EUID00P2FUYH209FEU@80Ti>C0P2ATI42
08f=S@80QhN70P20P80207MgM`80KFe]0P1QHF42059BDP80A4A40P0j>SX2038b<P0302XZ:P0T92@0
92@T0080820P0P0N7Qh201/K6`8061PH0P0C4a<201DE5@803@d=1P0:2PX200h>3P804Q8B0P0F5QH2
01XJ6P0301hN7P0R8R808R8R00809BDU0P0Y:BT202`/;080<30`0P0c<c<203Hf=P80>SXj0P0m?Cd2
0410@080A4A40P17AdL204Y:BP80CDe=0P1@D5000`1CDe<0EUIF05IFEP0205UIF@80G5aL0P1OGel2
069RHP80IFEU0P1YJFTE0?ooo`004`3oool2079bLP80N7Qh0P1nOWh208B4Q080RXZ:0P2ATI4209NG
U`80WIfM00<0Xj>S0:VYZ@2YZJT00P2_[jl20;Fe]@80^k^k0P30`<020<K6aP80bl_;0P3Bd]820=?C
d`80c/k>0P38b<P20<71`@80^;Rh0P2a/K420:^[Z`030:>SX`2HV9P0V9RH0080V9RH0P2FUYH209BD
U080Ti>C0P2DU9@209NGU`80VYZJ0P2KVi/209bLW080VIVI0P2EUID209JFUP80Vi^K0`2IVIT409:B
TP80T92@0P2CTi<209FEU@80VIVI0P2NWYh20:>SX`80Z:RX0P2][Jd20;6a/@80];Bd0P2g]kL20;Rh
^080][Jf00<0];Bd0;2`/02`/;000P2_[jl20:ZZZP80YjNW0P2/[:`20:RXZ080YjNW0P2OWil209jN
WP80VYZJ0P2KVi/209JFUPH0Ti>C00<0U9BD09FEU@2EUID00P2FUYH209FEU@80Ti>C0P2ATI4208f=
S@80QhN70P20P80207MgM`80KFe]0P1QHF42059BDP80A4A40P0j>SX2038b<P0302XZ:P0T92@092@T
0080820P0P0N7Qh201/K6`8061PH0P0C4a<201DE5@803@d=1P0:2PX200h>3P804Q8B0P0F5QH201XJ
6P0301hN7P0R8R808R8R00809BDU0P0Y:BT202`/;080<30`0P0c<c<203Hf=P80>SXj0P0m?Cd20410
@080A4A40P17AdL204Y:BP80CDe=0P1@D5000`1CDe<0EUIF05IFEP0205UIF@80G5aL0P1OGel2069R
HP80IFEU0P1YJFTE0?ooo`004`3oool2079bLP80N7Qh0P1nOWh208F5Q@80Rh^;0P2ATI4209NGU`80
WYjN00<0Y:BT0:ZZZP2ZZZX00P2`/;020;Jf]P80_;bl0P32`/820<S8b080c<c<0P3=cLd20=;BdP80
clo?0P39bLT20<71`@80^;Rh0P2`/;020:RXZ0030:2PX02HV9P0V9RH0080V9RH0P2FUYH209BDU080
Ti>C0P2FUYH209VIV@80WIfM0P2PX:020::RXP80XJ6Q0P2MWId409bLW080VYZJ00<0WIfM09ZJVP2J
VYX00P2JVYX209RHV080VIVI0P2KVi/209fMW@80XJ6Q0P2UYJD20:ZZZP80[jn_0P2c/k<20;Jf]P80
^KVi102l_;`00`2j^[X0]kNg0;Ng]`020;>c/`80/K6a0P2^[Zh20;6a/@80[:b/0P2][Jd20:NWY`80
Y:BT102PX:0209fMW@80VYZJ0P2HV9P209NGU`L0UYJF0P2DU9@2096AT@80SHf=0P27QhL20820P080
N7Qh0P1_Kfl206=SH`80EEEE0P18B4P203`l?080<c<c00<0:RXZ02HV9P0V9RH00P0R8R8201hN7P80
6QXJ0P0H61P201DE5@805QHF0P0?3`l200`<30802`/;0P0=3@d2014A4@805ADE0P0H61P201`L7003
020P800S8b<08b<S00809bLW0P0Z:RX202h^;P80<C4a0P0d=3@203Ph>080>c/k0P0n?Sh20451@@80
A4A40P17AdL204];B`80CTi>0P1ADE400`1DE5@0EeMG05MGE`0205YJFP80GEeM0P1PH60206=SH`80
IVIV0P1YJFTE0?ooo`004`3oool2079bLP80N7Qh0P1nOWh208F5Q@80Rh^;0P2ATI4209NGU`80WYjN
00<0Y:BT0:ZZZP2ZZZX00P2`/;020;Jf]P80_;bl0P32`/820<S8b080c<c<0P3=cLd20=;BdP80clo?
0P39bLT20<71`@80^;Rh0P2`/;020:RXZ0030:2PX02HV9P0V9RH0080V9RH0P2FUYH209BDU080Ti>C
0P2FUYH209VIV@80WIfM0P2PX:020::RXP80XJ6Q0P2MWId409bLW080VYZJ00<0WIfM09ZJVP2JVYX0
0P2JVYX209RHV080VIVI0P2KVi/209fMW@80XJ6Q0P2UYJD20:ZZZP80[jn_0P2c/k<20;Jf]P80^KVi
102l_;`00`2j^[X0]kNg0;Ng]`020;>c/`80/K6a0P2^[Zh20;6a/@80[:b/0P2][Jd20:NWY`80Y:BT
102PX:0209fMW@80VYZJ0P2HV9P209NGU`L0UYJF0P2DU9@2096AT@80SHf=0P27QhL20820P080N7Qh
0P1_Kfl206=SH`80EEEE0P18B4P203`l?080<c<c00<0:RXZ02HV9P0V9RH00P0R8R8201hN7P806QXJ
0P0H61P201DE5@805QHF0P0?3`l200`<30802`/;0P0=3@d2014A4@805ADE0P0H61P201`L7003020P
800S8b<08b<S00809bLW0P0Z:RX202h^;P80<C4a0P0d=3@203Ph>080>c/k0P0n?Sh20451@@80A4A4
0P17AdL204];B`80CTi>0P1ADE400`1DE5@0EeMG05MGE`0205YJFP80GEeM0P1PH60206=SH`80IVIV
0P1YJFTE0?ooo`004`3oool2079bLP80N7Qh0P1oOgl208F5Q@80S8b<0P2BTY8209RHV080WinO00<0
YJFU0:^[Z`2[Zj/00P2b/[820;Rh^080_[jn0P34a<@20<_;b`80dM7A0P3?cll20=3@d080c/k>0P37
alL20;no_`80^;Rh0P2_[jl20:JVYP0309fMW@2HV9P0V9RH0080UiNG0P2EUID409>CT`80UiNG0P2K
Vi/20:2PX080YJFU102YZJT60:NWY`80YJFU00<0Xj>S0:6QX@2QXJ400P2PX:0409nOW`80X:2P0P2R
XZ820:BTY080Z:RX0P2/[:`20;2`/080]KFe0P2h^;P20;bl_080_[jn0`2o_kl20;fm_@80^k^k0P2g
]kL20;Fe]@@0^;Rh0P2f][H20;:b/P80[Jf]0P2ZZZX20:NWY`80YJFU0P2RXZ8209nOW`80WIfM00<0
Vi^K09VIV@2IVIT00P2HV9P209NGU`80UIFE0P2BTY8208j>SP80QhN70P20P80207QhN080Kfm_0P1T
I6@205IFEP80BTY:0P0o?cl203@d=00302`/;00W9bL09bLW008092@T0P0P820201/K6`806ATI0P0F
5QH201LG5`804A4A0P0>3Ph200d=3@80410@0P0C4a<201LG5`806a/K0P0N7Qh00`0R8R809BDU02DU
9@0202PX:080;2`/0P0_;bl2038b<P80=SHf0P0i>CT203`l?080?clo0P12@T8204E5A@80B4Q80P1;
Bd/204i>CP80DE5A00<0E5AD05MGE`1GEeL00P1JFUX205eMG@80H61P0P1SHf<206IVIP80JFUY5@3o
ool001<0oooo0P1bLW8207QhN080Ogmo0P25QHD208b<S080TY:B0P2HV9P209nOW`030:FUY@2[Zj/0
Zj^[0080/[:b0P2h^;P20;jn_P80a<C40P3;bl/20=7Ad@80clo?0P3@d=020<k>cP80alO70P2o_kl2
0;Rh^080[jn_0P2VYZH00`2MWId0V9RH09RHV00209NGU`80UIFE102CTi<209NGU`80Vi^K0P2PX:02
0:FUY@@0ZJVY1P2WYjL20:FUY@030:>SX`2QXJ40XJ6Q0080X:2P102OWil20:2PX080XZ:R0P2TY:@2
0:RXZ080[:b/0P2`/;020;Fe]@80^;Rh0P2l_;`20;jn_P<0_kno0P2m_Kd20;^k^`80]kNg0P2e]KD4
0;Rh^080][Jf0P2b/[820:f][@80ZZZZ0P2WYjL20:FUY@80XZ:R0P2OWil209fMW@0309^KV`2IVIT0
VIVI0080V9RH0P2GUiL209FEU@80TY:B0P2>SXh208N7Q`80P8200P1hN7P206m_K`80I6AT0P1FEUH2
04Y:BP80?clo0P0d=3@00`0/;2`09bLW02LW9`0202@T9080820P0P0K6a/201TI6@805QHF0P0G5aL2
014A4@803Ph>0P0=3@d2010@40804a<C0P0G5aL201/K6`807QhN00<08R8R02DU9@0U9BD00P0X:2P2
02`/;080;bl_0P0b<S8203Hf=P80>CTi0P0l?3`203lo?`80@T920P15ADD204Q8B080Bd];0P1>CTh2
055AD@0305ADE01GEeL0EeMG0080FUYJ0P1MGEd2061PH080Hf=S0P1VIVH206UYJAD0oooo000C0?oo
o`80LW9b0P1iNGT207moO`80QXJ60P2<S8`209>CT`80VIVI0P2PX:000`2VYZH0[Jf]0:f][@020;>c
/`80^[Zj0P30`<020<K6aP80cLg=103EeMD20=3@d080cLg=0P36a/H20;jn_P80][Jf0P2_[jl20:FU
Y@0309fMW@2HV9P0V9RH0080UYJF0P2DU9@209:BTP80Ti>C0P2GUiL209^KV`80X:2P0P2UYJD20:ZZ
ZP80[Jf]1P2_[jl20:f][@030:^[Z`2XZ:P0Z:RX0080YJFU102RXZ820:>SX`80YJFU0P2XZ:P20:^[
Z`80[Zj^0P2b/[820;Jf]P80^[Zj0P2m_Kd20<30`0<0`L710P30`<020;jn_P80_Kfm202k^k/20;Vi
^@80]kNg0P2c/k<20:n_[`80Zj^[0P2XZ:P20:FUY@80XZ:R00<0WYjN09bLW02LW9`00P2JVYX209RH
V080UYJF0P2CTi<208n?S`80R8R80P21PH4207QhN080KVi^0P1SHf<205MGE`80Bd];0P11@D4203Hf
=P0302`/;00X:2P0:2PX00809BDU0P0Q8B4201/K6`806ATI0P0G5aL201PH60804Q8B0P0?3`l2010@
40804a<C0P0F5QH201TI6@807AdM0P0P82000`0T92@09bLW02LW9`0202XZ:P80;Bd]0P0a<C4203@d
=080=cLg0P0j>SX203dm?@80@4100P13@d<204I6AP80BDU90P1<C4`204m?C`80DU9B00<0EEEE05QH
F01HF5P00P1JFUX205eMG@80H61P0P1SHf<206IVIP80JFUY5@3oool001<0oooo0P1bLW8207UiN@80
Ogmo0P26QXH208b<S080Ti>C0P2IVIT20:2PX0030:JVYP2][Jd0[Jf]0080/k>c0P2j^[X20<30`080
a/K60P3=cLd40=GEe@80d=3@0P3=cLd20<K6aP80_[jn0P2f][H20:n_[`80YJFU00<0WIfM09RHV02H
V9P00P2FUYH209BDU080TY:B0P2CTi<209NGU`80Vi^K0P2PX:020:FUY@80ZZZZ0P2][Jd60:n_[`80
[Jf]00<0Zj^[0:RXZ02XZ:P00P2UYJD40::RXP80Xj>S0P2UYJD20:RXZ080Zj^[0P2^[Zh20;:b/P80
][Jf0P2j^[X20;fm_@80`<300`31`L420<30`080_[jn0P2m_Kd80;^k^`80^KVi0P2g]kL20;>c/`80
[jn_0P2[Zj/20:RXZ080YJFU0P2RXZ800`2NWYh0W9bL09bLW00209ZJVP80V9RH0P2FUYH209>CT`80
Shn?0P28R8P20861P@80N7Qh0P1^KVh206=SH`80EeMG0P1;Bd/20451@@80=SHf00<0;2`/02PX:00X
:2P00P0U9BD2024Q8@806a/K0P0I6AT201LG5`8061PH0P0B4Q8200l?3`80410@0P0C4a<201HF5P80
6ATI0P0M7Ad2020P800302@T900W9bL09bLW0080:RXZ0P0];Bd2034a<@80=3@d0P0g=cL203Xj>P80
?Cdm0P10@40204=3@`80ATI60P19BDT204a<C080Cdm?0P1BDU800`1EEED0F5QH05QHF00205YJFP80
GEeM0P1PH60206=SH`80IVIV0P1YJFTE0?ooo`004`3oool2079bLP80NGUi0P20P80208J6QP80SHf=
0P2CTi<209ZJVP80XJ6Q00<0Z:RX0:j^[P2^[Zh00P2e]KD20;^k^`80`/;20P38b<P20<o?c`80eMGE
0P3IfMT20=;BdP80cLg=0P36a/H20;jn_P80]kNg0P2`/;020:FUY@0309fMW@2HV9P0V9RH0080UIFE
0P2DU9@409:BTP80UYJF0P2JVYX209jNWP80Xj>S0P2WYjL20:ZZZP80[:b/102^[Zh20:^[Z`030:VY
Z@2WYjL0YjNW0080YJFU0P2TY:@40:JVYP80Z:RX0P2ZZZX20:f][@80/;2`0P2c/k<20;Ng]`80^[Zj
0P2n_[h20<;2`P<0a<C40P33`l<20<30`080_Kfm102k^k/40;bl_080^[Zj0P2h^;P20;Bd]080/K6a
0P2][Jd20:ZZZP80YjNW0P2TY:@00`2QXJ40WYjN09jNWP0209bLW080VYZJ0P2GUiL209>CT`80Shn?
0P29RHT20861P@80NGUi0P1_Kfl206ATI080EeMG0P1;Bd/20451@@80=cLg00<0;Rh^02PX:00X:2P0
0P0V9RH2024Q8@806a/K0P0I6AT201LG5`8061PH0P0C4a<200l?3`804Q8B0P0E5AD201PH608071`L
0P0O7al2028R8P0302DU9@0Y:BT0:BTY0080;2`/0P0_;bl2038b<P80=CDe0P0h>3P203/k>`80?Shn
0P11@D4204A4A080AdM70P1:BTX204e=C@80D51@0P1BDU800`1EEED0F5QH05QHF00205]KF`80GUiN
0P1PH60206=SH`80IVIV0P1YJFTE0?ooo`004`3oool2079bLP80NGUi0P20P80208N7Q`80SHf=0P2D
U9@209^KV`80XZ:R00<0ZJVY0;2`/02`/;000P2g]kL20;fm_@80a<C40P3:b/X20=3@d080eMGE0P3M
gMd20=CDe080clo?0P38b<P20<30`080^;Rh0P2a/K420:NWY`0309nOW`2IVIT0VIVI0080UIFE0P2C
Ti<2096AT@80TY:B0P2FUYH209VIV@80W9bL0P2PX:020:BTY080YjNW0P2YZJT40:^[Z`80[:b/1@2[
Zj/60:VYZ@80ZZZZ0P2/[:`20:j^[P80/K6a0P2d];@20;Ng]`80^[Zj0P2n_[h20<;2`P80aLG500<0
b<S80<W9b@39bLT00P36a/H20<;2`P80_[jn0P2j^[X40;Vi^@80]kNg0P2f][H20;>c/`80/K6a0P2]
[Jd20:^[Z`80Z:RX0P2VYZH00`2SXj<0X:2P0:2PX00209jNWP80W9bL0P2IVIT209FEU@80T92@0P2:
RXX208:2PP80NGUi0P1`L70206ATI080FEUI0P1=CDd20492@P80>3Ph00<0<C4a02/[:`0[:b/00P0W
9bL2028R8P8071`L0P0J6QX401LG5`804a<C0P0A4A4201@D508061PH0P0K6a/201hN7P808B4Q0P0T
92@00`0W9bL0:b/[02/[:`0202h^;P80<C4a0P0d=3@203Lg=`80>SXj0P0l?3`203lo?`80@T920P15
ADD204Q8B080Bd];0P1=CDd2051@D080De=C00<0EUIF05UIF@1IFET00P1KFe/205iNGP80HF5Q0P1S
Hf<206IVIP80JFUY5@3oool001<0oooo0P1bLW8207UiN@80P8200P27QhL208f=S@80U9BD0P2KVi/2
0::RXP030:VYZ@2`/;00/;2`0080]kNg0P2m_Kd20<C4a080b/[:0P3@d=020=GEe@80gMgM0P3De=@2
0<o?c`80b<S80P30`<020;Rh^080/K6a0P2WYjL00`2OWil0VIVI09VIV@0209FEU@80Ti>C0P2ATI42
09:BTP80UYJF0P2IVIT209bLW080X:2P0P2TY:@20:NWY`80ZJVY102[Zj/20:b/[0D0Zj^[1P2YZJT2
0:ZZZP80[:b/0P2^[Zh20;6a/@80];Bd0P2g]kL20;Zj^P80_[jn0P32`/820<G5a@030<S8b039bLT0
bLW90080a/K60P32`/820;jn_P80^[Zj102i^KT20;Ng]`80][Jf0P2c/k<20;6a/@80[Jf]0P2[Zj/2
0:RXZ080YZJV00<0Xj>S0:2PX02PX:000P2NWYh209bLW080VIVI0P2EUID2092@T080RXZ:0P22PX82
07UiN@80L71`0P1TI6@205UIF@80CDe=0P12@T8203Ph>003034a<@0[:b/0:b/[00809bLW0P0R8R82
01`L70806QXJ100G5aL201<C4`804A4A0P0D51@201PH60806a/K0P0N7Qh2024Q8@8092@T00<09bLW
02/[:`0[:b/00P0^;Rh2034a<@80=3@d0P0g=cL203Xj>P80?3`l0P0o?cl20492@P80ADE50P18B4P2
04];B`80CDe=0P1@D50205=CD`0305IFEP1IFET0FEUI0080Fe]K0P1NGUh2065QH@80Hf=S0P1VIVH2
06UYJAD0oooo000C0?ooo`80LW9b0P1iNGT20820P080QhN70P2>SXh209FEU@80W9bL0P2SXj<00`2Z
ZZX0/K6a0;6a/@020;Rh^080_kno0P36a/H20<g=c@80dm?C0P3EeMD20=kNgP80emOG0P3AdM420<_;
b`80`l?30P2j^[X20;>c/`80ZJVY00<0XJ6Q09ZJVP2JVYX00P2EUID209>CT`80TI6A0P2BTY8209JF
UP80VYZJ0P2KVi/209jNWP80XJ6Q0P2TY:@20:NWY`80ZZZZ0P2/[:`20:j^[P030;2`/02^[Zh0[Zj^
0080[:b/1P2[Zj/20:b/[080[Zj^0P2_[jl20;:b/P80];Bd0P2g]kL20;Zj^P80_Kfm0P31`L420<C4
a0030<O7a`3:b/X0b/[:0080c<c<0P3:b/X20<O7a`80`/;20P2m_Kd20;Vi^@80]kNg0P2d];@20;:b
/P80/;2`0P2][Jd20:^[Z`80ZJVY0P2WYjL00`2VYZH0Xj>S0:>SX`020:6QX@80WYjN0P2KVi/209JF
UP80TI6A0P2;Rh/208B4Q080O7al0P1`L70206IVIP80FUYJ0P1>CTh20451@@80=cLg00<0<C4a02`/
;00/;2`00P0X:2P202@T90807QhN0P0K6a/201TI6@805QHF100C4a<201LG5`806QXJ0P0M7Ad2020P
80808b<S0P0V9RH00`0Y:BT0;2`/02`/;00202l_;`80<S8b0P0e=CD203Ph>080>c/k0P0n?Sh20451
@@80@d=30P16ATH204U9B@80Bd];0P1>CTh2055AD@80E5AD00<0EUIF05UIF@1IFET00P1LG5`205iN
GP80HF5Q0P1TI6@206IVIP80JFUY5@3oool001<0oooo0P1bLW8207UiN@80P8200P27QhL208j>SP80
UIFE0P2LW9`20:>SX`030:ZZZP2a/K40/K6a0080^;Rh0P2o_kl20<K6aP80cLg=0P3Cdm<20=GEe@80
g]kN0P3GemL20=7Ad@80bl_;0P33`l<20;Zj^P80/k>c0P2YZJT00`2QXJ40VYZJ09ZJVP0209FEU@80
Ti>C0P2ATI4209:BTP80UYJF0P2JVYX209^KV`80WYjN0P2QXJ420:BTY080YjNW0P2ZZZX20:b/[080
[Zj^00<0/;2`0:j^[P2^[Zh00P2/[:`60:^[Z`80[:b/0P2^[Zh20:n_[`80/[:b0P2d];@20;Ng]`80
^[Zj0P2m_Kd20<71`@80a<C400<0alO70<[:bP3:b/X00P3<c<`20<[:bP80alO70P32`/820;fm_@80
^KVi0P2g]kL20;Bd]080/[:b0P2`/;020:f][@80Zj^[0P2YZJT20:NWY`030:JVYP2SXj<0Xj>S0080
XJ6Q0P2NWYh209^KV`80UYJF0P2ATI4208^;R`80Q8B40P1lO7`2071`L080IVIV0P1JFUX204i>CP80
@D510P0g=cL00`0a<C40;2`/02`/;00202PX:08092@T0P0N7Qh201/K6`806ATI0P0F5QH401<C4`80
5aLG0P0J6QX201dM7@80820P0P0S8b<202HV9P0302TY:@0/;2`0;2`/0080;bl_0P0b<S8203De=@80
>3Ph0P0k>c/203hn?P80@D510P13@d<204I6AP80BDU90P1;Bd/204i>CP80DE5A0P1DE5@00`1FEUH0
FEUI05UIF@0205aLG080GUiN0P1QHF4206ATI080IVIV0P1YJFTE0?ooo`004`3oool207=cL`80NWYj
0P21PH4208R8R080Shn?0P2FUYH209fMW@80Y:BT00<0Zj^[0;:b/P2b/[800P2j^[X20<71`@80b<S8
0P3@d=040=SHf080fm_K0P3Hf=P20=?Cd`80cLg=0P37alL20;fm_@80]KFe0P2/[:`00`2TY:@0WYjN
09jNWP0209RHV080U9BD0P2ATI4209:BTP80UYJF0P2LW9`209nOW`80XZ:R0P2TY:@20:NWY`80ZZZZ
0P2/[:`70:f][@80[:b/102[Zj/20:b/[080[Jf]0P2^[Zh20;2`/080/[:b0P2d];@20;Ng]`80^[Zj
0P2l_;`20;no_`80`/;200<0aLG50<O7a`37alL01P39bLT20<O7a`80aLG50P32`/820<30`080^k^k
0P2g]kL20;Bd]080/[:b0P2_[jl20:j^[P80Zj^[00<0Z:RX0:FUY@2UYJD00P2SXj<20:2PX080W9bL
0P2HV9P209:BTP80SHf=0P24Q8@207alO080LG5a0P1VIVH205YJFP80CTi>0P12@T8203Lg=`0303<c
<`0^;Rh0;Rh^0080:BTY0P0V9RH2020P80807AdM0P0K6a/201LG5`8051@D0P0F5QH201XJ6P807AdM
0P0P820202<S8`809RHV0P0Y:BT00`0/;2`0;Rh^02h^;P02034a<@80=3@d0P0g=cL203Xj>P80?3`l
0P0o?cl20492@P80ADE50P17AdL204Y:BP80C4a<0P1?Cdl2059BDP80E5AD00<0EeMG05YJFP1JFUX0
0P1LG5`205mOG`80HF5Q0P1TI6@206IVIP80JFUY5@3oool001<0oooo0P1cLg<207YjNP80PH610P28
R8P208n?S`80UYJF0P2MWId20:BTY0030:^[Z`2b/[80/[:b0080^[Zj0P31`L420<S8b080d=3@103H
f=P20=_Kf`80f=SH0P3Cdm<20<g=c@80alO70P2m_Kd20;Fe]@80[:b/00<0Y:BT09jNWP2NWYh00P2H
V9P209BDU080TI6A0P2BTY8209JFUP80W9bL0P2OWil20::RXP80Y:BT0P2WYjL20:ZZZP80[:b/1`2]
[Jd20:b/[0@0Zj^[0P2/[:`20:f][@80[Zj^0P2`/;020;:b/P80];Bd0P2g]kL20;Zj^P80_;bl0P2o
_kl20<;2`P030<G5a@37alL0alO700H0bLW90P37alL20<G5a@80`/;20P30`<020;^k^`80]kNg0P2d
];@20;:b/P80[jn_0P2^[Zh20:^[Z`030:RXZ02UYJD0YJFU0080Xj>S0P2PX:0209bLW080V9RH0P2B
TY8208f=S@80Q8B40P1lO7`2075aL@80IVIV0P1JFUX204i>CP80@T920P0g=cL00`0c<c<0;Rh^02h^
;P0202TY:@809RHV0P0P820201dM7@806a/K0P0G5aL201@D50805QHF0P0J6QX201dM7@80820P0P0S
8b<202HV9P80:BTY00<0;2`/02h^;P0^;Rh00P0a<C4203@d=080=cLg0P0j>SX203`l?080?clo0P12
@T8204E5A@80AdM70P1:BTX204a<C080Cdm?0P1BDU8205ADE00305MGE`1JFUX0FUYJ0080G5aL0P1O
Gel2065QH@80I6AT0P1VIVH206UYJAD0oooo000C0?ooo`80Lg=c0P1jNWX20861P@80R8R80P2?Shl2
09JFUP80WYjN0P2UYJD00`2/[:`0];Bd0;Bd]0020;^k^`80`l?30P3;bl/20=?Cd`80g=cL0P3Ogml2
0=gMg@80fMWI0P3Cdm<20=3@d080bLW90P31`L420;Rh^080[jn_00<0Z:RX0:2PX02PX:000P2JVYX2
09JFUP@0TY:B0P2FUYH209ZJVP80WYjN0P2RXZ820:JVYP80Z:RX1P2ZZZX;0:^[Z`80[:b/0P2][Jd2
0:j^[P80/;2`0P2b/[820;Bd]080][Jf0P2h^;P20;^k^`80_Kfm0P30`<000`32`/80a<C40<C4a002
0<G5a@@0a/K60P35aLD20<?3``@0`L710P2o_kl20;fm_@80^[Zj0P2g]kL20;>c/`80/;2`0P2^[Zh0
0`2ZZZX0YjNW0:NWY`020:BTY080XJ6Q0P2MWId209RHV080Ti>C0P2>SXh208N7Q`80OGem0P1bLW82
06IVIP80Fe]K0P1?Cdl204=3@`80>3Ph00<0=CDe030`<00`<3000P0Z:RX202PX:0808B4Q100N7Qh2
01PH60805QHF0P0I6AT201`L70807alO0P0R8R8202DU9@80:2PX0P0[:b/00`0^;Rh0<30`030`<002
03<c<`80=SHf0P0h>3P203/k>`80?Shn0P10@40204=3@`80ATI60P18B4P204];B`80CDe=0P1@D502
059BDP80EEEE00<0EeMG05YJFP1JFUX00P1MGEd205mOG`80HV9R0P1TI6@206MWI`80JFUY5@3oool0
01<0oooo0P1cLg<207YjNP80PH610P28R8P208n?S`80UYJF0P2NWYh20:FUY@030:b/[02d];@0];Bd
0080^k^k0P33`l<20<_;b`80dm?C0P3Lg=`20=oOg`80gMgM0P3IfMT20=?Cd`80d=3@0P39bLT20<71
`@80^;Rh0P2_[jl00`2XZ:P0X:2P0:2PX00209ZJVP80UYJF102BTY8209JFUP80VYZJ0P2NWYh20::R
XP80YZJV0P2XZ:P60:ZZZP/0Zj^[0P2/[:`20:f][@80[Zj^0P2`/;020;:b/P80];Bd0P2f][H20;Rh
^080^k^k0P2m_Kd20<30`0030<;2`P34a<@0a<C40080aLG51036a/H20<G5a@80`l?31031`L420;no
_`80_Kfm0P2j^[X20;Ng]`80/k>c0P2`/;020:j^[P030:ZZZP2WYjL0YjNW0080Y:BT0P2QXJ4209fM
W@80V9RH0P2CTi<208j>SP80QhN70P1mOGd2079bLP80IVIV0P1KFe/204m?C`80@d=30P0h>3P00`0e
=CD0<30`030`<00202XZ:P80:2PX0P0Q8B4401hN7P8061PH0P0F5QH201TI6@8071`L0P0O7al2028R
8P809BDU0P0X:2P202/[:`0302h^;P0`<300<30`0080<c<c0P0f=SH203Ph>080>c/k0P0n?Sh20410
@080@d=30P16ATH204Q8B080Bd];0P1=CDd2051@D080DU9B0P1EEED00`1GEeL0FUYJ05YJFP0205eM
G@80GemO0P1RHV8206ATI080IfMW0P1YJFTE0?ooo`004`3oool207=cL`80NWYj0P21PH4208R8R080
T92@0P2GUiL209jNWP80YZJV00<0[Jf]0;Fe]@2e]KD00P2m_Kd20<G5a@80cLg=0P3Fe]H20=oOg`80
hn?S0P3Ogml20=_Kf`80e=CD0P3AdM420<_;b`80`l?30P2k^k/20;:b/P030:ZZZP2SXj<0Xj>S0080
W9bL0P2GUiL409:BTP80UIFE0P2IVIT209bLW080WinO0P2SXj<20:FUY@80YjNW102XZ:P30:VYZ@H0
ZZZZ0P2[Zj/20:b/[080[Jf]0P2^[Zh20;2`/080/K6a0P2c/k<20;Fe]@80]kNg0P2i^KT20;^k^`80
_Kfm00<0_kno0<71`@31`L400P32`/820<?3``@0`/;20P31`L420<30`080_kno0P2m_Kd20;bl_080
^KVi0P2g]kL20;Bd]080/K6a0P2_[jl00`2[Zj/0ZJVY0:VYZ@020:JVYP80Xj>S0P2OWil209VIV@80
U9BD0P2>SXh208N7Q`80Ogmo0P1dM7@206UYJ@80GEeM0P1@D50204A4A080>3Ph00<0=cLg038b<P0b
<S800P0[:b/202XZ:P8092@T100O7al201XJ6P806ATI0P0M7Ad201lO7`808R8R0P0U9BD202PX:080
:RXZ0P0];Bd00`0`<300<S8b038b<P0203De=@80>3Ph0P0j>SX203dm?@80?clo0P12@T8204A4A080
AdM70P19BDT204a<C080CTi>0P1ADE4205=CD`80EUIF00<0F5QH05]KF`1KFe/00P1MGEd205mOG`80
HV9R0P1TI6@206MWI`80JFUY5@3oool001<0oooo0P1cLg<207YjNP80PH610P28R8P2092@T080UiNG
0P2NWYh20:JVYP030:f][@2e]KD0]KFe0080_Kfm0P35aLD20<g=c@80e]KF0P3Ogml20>?Sh`80gmoO
0P3Kfm/20=CDe080dM7A0P3;bl/20<?3``80^k^k0P2b/[800`2ZZZX0Xj>S0:>SX`0209bLW080UiNG
102BTY8209FEU@80VIVI0P2LW9`209nOW`80Xj>S0P2UYJD20:NWY`@0Z:RX0`2YZJT60:ZZZP80Zj^[
0P2/[:`20:f][@80[Zj^0P2`/;020;6a/@80/k>c0P2e]KD20;Ng]`80^KVi0P2k^k/20;fm_@030;no
_`31`L40`L710080`/;20P33`l<40<;2`P80`L710P30`<020;no_`80_Kfm0P2l_;`20;Vi^@80]kNg
0P2d];@20;6a/@80[jn_00<0Zj^[0:VYZ@2YZJT00P2VYZH20:>SX`80WinO0P2IVIT209BDU080SXj>
0P27QhL207moO`80M7Ad0P1YJFT205eMG@80D51@0P14A4@203Ph>00303Lg=`0b<S80<S8b0080:b/[
0P0Z:RX202@T90@07alO0P0J6QX201TI6@807AdM0P0O7al2028R8P809BDU0P0X:2P202XZ:P80;Bd]
00<0<30`038b<P0b<S800P0e=CD203Ph>080>SXj0P0m?Cd203lo?`80@T920P14A4@204M7A`80BDU9
0P1<C4`204i>CP80DE5A0P1CDe<205IFEP0305QHF01KFe/0Fe]K0080GEeM0P1OGel2069RHP80I6AT
0P1WIfL206UYJAD0oooo000C0?ooo`80Lg=c0P1jNWX20861P@80RHV90P2@T90209NGU`80WinO0P2W
YjL00`2^[Zh0][Jf0;Jf]P020;jn_P80alO70P3?cll20=WIf@80hn?S0P3Xj>P20>;RhP80gMgM0P3F
e]H20=;BdP80c<c<0P36a/H20;jn_P80]KFe00<0[Jf]0:FUY@2UYJD00P2NWYh209VIV@80U9BD0P2B
TY8209FEU@80V9RH0P2KVi/209fMW@80X:2P0P2SXj<20:BTY080YJFU0P2WYjL30:RXZ0@0ZJVY102Z
ZZX20:^[Z`80[:b/0P2][Jd20:n_[`80/K6a0P2b/[820;Bd]080][Jf0P2g]kL20;Vi^@80^k^k00<0
_;bl0;jn_P2n_[h00P2o_kl60<30`080_kno0P2n_[h20;fm_@80_;bl0P2j^[X20;Vi^@80]kNg0P2e
]KD20;:b/P80[jn_00<0[Jf]0:ZZZP2ZZZX00P2WYjL20:>SX`80WinO0P2JVYX209BDU080SXj>0P27
QhL207inOP80M7Ad0P1YJFT205eMG@80Cdm?0P13@d<203Lg=`0303Hf=P0c<c<0<c<c0080;Bd]0P0/
;2`202LW9`808B4Q0P0P820201/K6`807AdM0P0P820202<S8`809BDU0P0X:2P202XZ:P80;Bd]0P0_
;bl00`0b<S80=3@d03@d=00203Lg=`80>CTi0P0l?3`203hn?P80@D510P13@d<204I6AP80B4Q80P1:
BTX204e=C@80Cdm?0P1BDU8205ADE080EUIF00<0FEUI05]KF`1KFe/00P1MGEd2061PH080HV9R0P1T
I6@206MWI`80JFUY5@3oool001<0oooo0P1cLg<207YjNP80PH610P29RHT2092@T080UiNG0P2OWil2
0:NWY`030:j^[P2f][H0][Jf0080_[jn0P37alL20<o?c`80fMWI0P3Shn<20>SXj080h^;R0P3MgMd2
0=KFeP80d];B0P3<c<`20<K6aP80_[jn0P2e]KD00`2][Jd0YJFU0:FUY@0209jNWP80VIVI0P2DU9@2
09:BTP80UIFE0P2HV9P209^KV`80WIfM0P2PX:020:>SX`80Y:BT0P2UYJD20:NWY`<0Z:RX102YZJT4
0:ZZZP80Zj^[0P2/[:`20:f][@80[jn_0P2a/K420;:b/P80];Bd0P2f][H20;Ng]`80^KVi0P2k^k/0
0`2l_;`0_[jn0;jn_P020;no_`H0`<300P2o_kl20;jn_P80_Kfm0P2l_;`20;Zj^P80^KVi0P2g]kL2
0;Fe]@80/[:b0P2_[jl00`2][Jd0ZZZZ0:ZZZP020:NWY`80Xj>S0P2OWil209ZJVP80U9BD0P2>SXh2
08N7Q`80OWin0P1dM7@206UYJ@80GEeM0P1?Cdl204=3@`80=cLg00<0=SHf03<c<`0c<c<00P0];Bd2
02`/;0809bLW0P0Q8B42020P80806a/K0P0M7Ad2020P80808b<S0P0U9BD202PX:080:RXZ0P0];Bd2
02l_;`03038b<P0d=3@0=3@d0080=cLg0P0i>CT203`l?080?Shn0P11@D4204=3@`80ATI60P18B4P2
04Y:BP80CDe=0P1?Cdl2059BDP80E5AD0P1FEUH00`1IFET0Fe]K05]KF`0205eMG@80H61P0P1RHV82
06ATI080IfMW0P1YJFTE0?ooo`004`3oool207=cL`80NWYj0P22PX8208V9R@80T92@0P2HV9P209nO
W`80YjNW00<0[jn_0;Ng]`2g]kL00P2o_kl20<S8b080dM7A0P3Jf]X20>CTi080k>c/0P3UiND20=oO
g`80f=SH0P3Cdm<20<k>cP80alO70P30`<020;Rh^0030;2`/02XZ:P0Z:RX0080X:2P0P2KVi/209NG
U`80U9BD0P2EUID209NGU`80VYZJ0P2LW9`209nOW`80XJ6Q0P2SXj<20:BTY080YJFU0P2VYZH00`2W
YjL0Z:RX0:RXZ0020:RXZ0@0ZJVY0P2ZZZX20:^[Z`80[Jf]0P2^[Zh20:n_[`80/K6a0P2b/[820;Bd
]080][Jf0P2g]kL20;Vi^@030;Zj^P2k^k/0^k^k0080_;bl202m_Kd20;bl_080^k^k0P2j^[X20;Vi
^@80^;Rh0P2f][H20;Bd]080/[:b0P2`/;000`2][Jd0ZZZZ0:ZZZP020:NWY`80Y:BT0P2PX:0209ZJ
VP80UIFE0P2>SXh208N7Q`80OWin0P1dM7@206UYJ@80GEeM0P1@D50204=3@`80>3Ph00<0=CDe03@d
=00d=3@00P0_;bl202h^;P80:RXZ0P0T92@2024Q8@807QhN0P0Q8B4202<S8`809RHV0P0X:2P202XZ
:P80;Bd]0P0_;bl2038b<P0303@d=00f=SH0=SHf0080>CTi0P0k>c/203dm?@80@4100P12@T8204A4
A080AdM70P19BDT204];B`80CTi>0P1@D502059BDP80EEEE0P1GEeL00`1IFET0G5aL05aLG00205iN
GP80H61P0P1RHV8206EUI@80IfMW0P1YJFTE0?ooo`004`3oool207=cL`80NWYj0P22PX8208V9R@80
T92@0P2HV9P209nOW`80YjNW00<0[jn_0;Ng]`2g]kL00P2o_kl20<S8b080dM7A0P3Jf]X20>CTi080
k>c/0P3UiND20=oOg`80f=SH0P3Cdm<20<k>cP80alO70P30`<020;Rh^0030;2`/02XZ:P0Z:RX0080
X:2P0P2KVi/209NGU`80U9BD0P2EUID209NGU`80VYZJ0P2LW9`209nOW`80XJ6Q0P2SXj<20:BTY080
YJFU0P2VYZH00`2WYjL0Z:RX0:RXZ0020:RXZ0@0ZJVY0P2ZZZX20:^[Z`80[Jf]0P2^[Zh20:n_[`80
/K6a0P2b/[820;Bd]080][Jf0P2g]kL20;Vi^@030;Zj^P2k^k/0^k^k0080_;bl202m_Kd20;bl_080
^k^k0P2j^[X20;Vi^@80^;Rh0P2f][H20;Bd]080/[:b0P2`/;000`2][Jd0ZZZZ0:ZZZP020:NWY`80
Y:BT0P2PX:0209ZJVP80UIFE0P2>SXh208N7Q`80OWin0P1dM7@206UYJ@80GEeM0P1@D50204=3@`80
>3Ph00<0=CDe03@d=00d=3@00P0_;bl202h^;P80:RXZ0P0T92@2024Q8@807QhN0P0Q8B4202<S8`80
9RHV0P0X:2P202XZ:P80;Bd]0P0_;bl2038b<P0303@d=00f=SH0=SHf0080>CTi0P0k>c/203dm?@80
@4100P12@T8204A4A080AdM70P19BDT204];B`80CTi>0P1@D502059BDP80EEEE0P1GEeL00`1IFET0
G5aL05aLG00205iNGP80H61P0P1RHV8206EUI@80IfMW0P1YJFTE0?ooo`004`3oool207=cL`80NWYj
0P22PX8208V9R@80TI6A0P2HV9P20:2PX080Z:RX00<0/;2`0;Rh^02h^;P00P30`<020<W9b@80d];B
0P3Kfm/20>GUi@80k^k^0P3YjNT20>?Sh`80gMgM0P3GemL20=3@d080b/[:0P33`l<20;^k^`030;:b
/P2[Zj/0Zj^[0080Xj>S0P2MWId209VIV@80UIFE0P2FUYH209NGU`80VIVI0P2LW9`209jNWP80X:2P
0P2QXJ420:>SX`80Y:BT0P2UYJD30:JVYP80YjNW0P2XZ:P20:VYZ@80ZZZZ102[Zj/20:f][@80[Zj^
0P2`/;020;6a/@80/[:b0P2d];@20;Fe]@80]kNg00<0^;Rh0;Vi^@2i^KT00P2j^[X:0;^k^`80^[Zj
0P2i^KT20;Rh^080]kNg0P2f][H20;Bd]080/[:b0P2`/;000`2^[Zh0Zj^[0:^[Z`020:RXZ080Y:BT
0P2PX:0209^KV`80UIFE0P2?Shl208R8R080OWin0P1dM7@206UYJ@80GEeM0P1ADE4204A4A080>CTi
00<0=3@d03<c<`0c<c<0100^;Rh202`/;080:BTY0P0S8b<2028R8P8092@T0P0W9bL202TY:@80:b/[
0P0];Bd202l_;`80<S8b0P0d=3@00`0f=SH0>3Ph03Ph>00203/k>`80?Cdm0P0o?cl20451@@80A4A4
0P16ATH204Q8B080BTY:0P1=CDd204m?C`80DE5A0P1CDe<205EEE@80F5QH00<0FUYJ05aLG01LG5`0
0P1NGUh2061PH080Hf=S0P1UIFD206MWI`80JFUY5@3oool001<0oooo0P1cLg<207YjNP80PX:20P29
RHT2096AT@80V9RH0P2PX:020:RXZ0030;2`/02h^;P0^;Rh0080`<300P39bLT20=;BdP80fm_K0P3U
iND20>k^kP80jNWY0P3Shn<20=gMg@80emOG0P3@d=020<[:bP80`l?30P2k^k/00`2b/[80Zj^[0:^[
Z`020:>SX`80WIfM0P2IVIT209FEU@80UYJF0P2GUiL209VIV@80W9bL0P2NWYh20:2PX080XJ6Q0P2S
Xj<20:BTY080YJFU0`2VYZH20:NWY`80Z:RX0P2YZJT20:ZZZP@0Zj^[0P2][Jd20:j^[P80/;2`0P2a
/K420;:b/P80];Bd0P2e]KD20;Ng]`030;Rh^02i^KT0^KVi0080^[Zj2P2k^k/20;Zj^P80^KVi0P2h
^;P20;Ng]`80][Jf0P2d];@20;:b/P80/;2`00<0[Zj^0:^[Z`2[Zj/00P2XZ:P20:BTY080X:2P0P2K
Vi/209FEU@80Shn?0P28R8P207inOP80M7Ad0P1YJFT205eMG@80DE5A0P14A4@203Ti>@0303@d=00c
<c<0<c<c00@0;Rh^0P0/;2`202TY:@808b<S0P0R8R8202@T90809bLW0P0Y:BT202/[:`80;Bd]0P0_
;bl2038b<P80=3@d00<0=SHf03Ph>00h>3P00P0k>c/203dm?@80?clo0P11@D4204A4A080ATI60P18
B4P204Y:BP80CDe=0P1?Cdl2055AD@80De=C0P1EEED205QHF00305YJFP1LG5`0G5aL0080GUiN0P1P
H60206=SH`80IFEU0P1WIfL206UYJAD0oooo000C0?ooo`80Lg=c0P1jNWX208:2PP80RHV90P2ATI42
09RHV080X:2P0P2XZ:P00`2`/;00^;Rh0;Rh^0020<71`@80bLW90P3Cdm<20=cLg080i^KV0P3alO42
0>c/k080i^KV0P3Ph>020=[JfP80dm?C0P3<c<`20<G5a@80_Kfm00<0]KFe0:f][@2][Jd00P2UYJD2
09nOW`80Vi^K102GUiL209RHV080VIVI0P2KVi/209fMW@80WinO0P2PX:020:6QX@80Xj>S0P2TY:@0
0`2UYJD0YZJV0:JVYP020:JVYP@0Z:RX0P2YZJT20:ZZZP80Zj^[0P2/[:`20:f][@80[Zj^0P2`/;02
0;6a/@80/[:b0P2c/k<20;Fe]@030;Jf]P2g]kL0]kNg0080^;Rh302i^KT20;Rh^080]kNg0P2f][H2
0;Bd]080/k>c0P2a/K420:n_[`030:f][@2[Zj/0Zj^[0080Z:RX0P2TY:@209nOW`80Vi^K0P2EUID2
08n?S`80R8R80P1nOWh207EeM@80JFUY0P1MGEd2055AD@80ADE50P0k>c/00`0e=CD0<c<c03<c<`04
02l_;`80;Bd]0P0/;2`202HV9P809bLW0P0X:2P202XZ:P80;2`/0P0^;Rh2030`<080<S8b0P0d=3@2
03Hf=P0303Ph>00j>SX0>SXj0080?3`l0P0o?cl20451@@80@d=30P15ADD204M7A`80BDU90P1;Bd/2
04i>CP80D51@0P1BDU8205ADE080EUIF0P1HF5P00`1JFUX0GEeM05eMG@0205mOG`80HF5Q0P1SHf<2
06EUI@80IfMW0P1YJFTE0?ooo`004`3oool207=cL`80NWYj0P22PX8208V9R@80TI6A0P2HV9P20:2P
X080Z:RX00<0/;2`0;Rh^02h^;P00P31`L420<W9b@80dm?C0P3Lg=`20>KViP80lO7a0P3/k>`20>KV
iP80h>3P0P3Jf]X20=?Cd`80c<c<0P35aLD20;fm_@030;Fe]@2][Jd0[Jf]0080YJFU0P2OWil209^K
V`@0UiNG0P2HV9P209VIV@80Vi^K0P2MWId209nOW`80X:2P0P2QXJ420:>SX`80Y:BT00<0YJFU0:JV
YP2VYZH00P2VYZH40:RXZ080ZJVY0P2ZZZX20:^[Z`80[:b/0P2][Jd20:j^[P80/;2`0P2a/K420;:b
/P80/k>c0P2e]KD00`2f][H0]kNg0;Ng]`020;Rh^0`0^KVi0P2h^;P20;Ng]`80][Jf0P2d];@20;>c
/`80/K6a0P2_[jl00`2][Jd0Zj^[0:^[Z`020:RXZ080Y:BT0P2OWil209^KV`80UIFE0P2?Shl208R8
R080OWin0P1eMGD206UYJ@80GEeM0P1ADE4204E5A@80>c/k00<0=CDe03<c<`0c<c<0100_;bl202d]
;@80;2`/0P0V9RH202LW9`80:2PX0P0Z:RX202`/;080;Rh^0P0`<302038b<P80=3@d0P0f=SH00`0h
>3P0>SXj03Xj>P0203`l?080?clo0P11@D4204=3@`80ADE50P17AdL204U9B@80Bd];0P1>CTh2051@
D080DU9B0P1DE5@205IFEP80F5QH00<0FUYJ05eMG@1MGEd00P1OGel2065QH@80Hf=S0P1UIFD206MW
I`80JFUY5@3oool001<0oooo0P1cLg<207YjNP80PX:20P29RHT2096AT@80V9RH0P2PX:020:RXZ003
0;2`/02h^;P0^;Rh0080`L710P3:b/X20=?Cd`80g=cL0P3Vi^H20?7al@80kno_0P3[jn/20>CTi080
gMgM0P3Fe]H20<o?c`80alO70P2o_kl00`2g]kL0[Zj^0:j^[P020:NWY`80XJ6Q0P2MWId209VIV@80
V9RH0P2IVIT209ZJVP80Vi^K0P2MWId209jNWP80X:2P0P2QXJ420::RXP80Xj>S00<0Y:BT0:FUY@2U
YJD00P2VYZH20:NWY`@0Z:RX0P2YZJT20:ZZZP80Zj^[0P2/[:`20:f][@80[Zj^0P2_[jl20;2`/080
/[:b0P2c/k<00`2d];@0]KFe0;Fe]@040;Jf]PX0]kNg0P2f][H20;Fe]@80];Bd0P2c/k<20;:b/P80
/K6a0P2_[jl00`2^[Zh0ZZZZ0:ZZZP020:RXZ080Y:BT0P2PX:0209^KV`80UIFE0P2?Shl208N7Q`80
Ogmo0P1eMGD206UYJ@80GEeM0P1BDU8204E5A@80?Shn00<0>3Ph03<c<`0c<c<00P0_;bl202h^;P80
;Bd]0P0/;2`402XZ:P80;2`/0P0];Bd202l_;`80<C4a0P0c<c<203@d=080=SHf0P0h>3P00`0j>SX0
?3`l03`l?00203hn?P80@4100P12@T8204A4A080ATI60P19BDT204];B`80CDe=0P1?Cdl2055AD@80
De=C0P1EEED205MGE`80FEUI00<0Fe]K05eMG@1MGEd00P1OGel2065QH@80Hf=S0P1UIFD206MWI`80
JFUY5@3oool001<0oooo0P1cLg<207YjNP80PX:20P29RHT2096AT@80V9RH0P2PX:020:RXZ0030;2`
/02h^;P0^;Rh0080`L710P3:b/X20=?Cd`80g=cL0P3Vi^H20?7al@80kno_0P3[jn/20>CTi080gMgM
0P3Fe]H20<o?c`80alO70P2o_kl00`2g]kL0[Zj^0:j^[P020:NWY`80XJ6Q0P2MWId209VIV@80V9RH
0P2IVIT209ZJVP80Vi^K0P2MWId209jNWP80X:2P0P2QXJ420::RXP80Xj>S00<0Y:BT0:FUY@2UYJD0
0P2VYZH20:NWY`@0Z:RX0P2YZJT20:ZZZP80Zj^[0P2/[:`20:f][@80[Zj^0P2_[jl20;2`/080/[:b
0P2c/k<00`2d];@0]KFe0;Fe]@040;Jf]PX0]kNg0P2f][H20;Fe]@80];Bd0P2c/k<20;:b/P80/K6a
0P2_[jl00`2^[Zh0ZZZZ0:ZZZP020:RXZ080Y:BT0P2PX:0209^KV`80UIFE0P2?Shl208N7Q`80Ogmo
0P1eMGD206UYJ@80GEeM0P1BDU8204E5A@80?Shn00<0>3Ph03<c<`0c<c<00P0_;bl202h^;P80;Bd]
0P0/;2`402XZ:P80;2`/0P0];Bd202l_;`80<C4a0P0c<c<203@d=080=SHf0P0h>3P00`0j>SX0?3`l
03`l?00203hn?P80@4100P12@T8204A4A080ATI60P19BDT204];B`80CDe=0P1?Cdl2055AD@80De=C
0P1EEED205MGE`80FEUI00<0Fe]K05eMG@1MGEd00P1OGel2065QH@80Hf=S0P1UIFD206MWI`80JFUY
5@3oool001<0oooo0P1cLg<207YjNP80PX:20P29RHT2096AT@80V9RH0P2PX:020:RXZ0030;2`/02h
^;P0^;Rh0080`L710P3:b/X20=?Cd`80g=cL0P3WinL20??cl`80m?Cd0P3^k^h20>SXj080h>3P0P3I
fMT20=;BdP80b/[:0P31`L400`2j^[X0/K6a0;6a/@020:VYZ@80Y:BT0P2PX:0209bLW0@0VYZJ0P2K
Vi/209bLW080WIfM0P2NWYh209nOW`80X:2P0P2RXZ830:>SX`80Y:BT0P2UYJD20:JVYP@0YjNW0P2X
Z:P20:VYZ@80ZZZZ0P2[Zj/20:b/[080[Jf]0P2^[Zh20:n_[`80/;2`0P2a/K400`2b/[80/k>c0;>c
/`020;>c/`80];Bd302e]KD20;Bd]080/k>c0P2b/[820;6a/@80/;2`0P2_[jl00`2][Jd0ZZZZ0:ZZ
ZP020:RXZ080Y:BT0P2PX:0209^KV`80UYJF0P2@T90208N7Q`80Ogmo0P1eMGD206YZJP80GEeM0P1B
DU8204E5A@80@41000<0>SXj03Hf=P0f=SH00P0`<30202l_;`80;Rh^0P0/;2`202d];@80;Rh^0P0_
;bl2030`<080<S8b0P0c<c<203De=@80=cLg0P0i>CT203/k>`0303`l?00n?Sh0?Shn0080@4100P12
@T8204A4A080ATI60P18B4P204Y:BP80C4a<0P1>CTh2051@D080DU9B0P1DE5@205IFEP80F5QH0P1J
FUX00`1LG5`0GUiN05iNGP02061PH080HV9R0P1TI6@206IVIP80J6QX0P1ZJVXE0?ooo`004`3oool2
07=cL`80NWYj0P22PX8208V9R@80TI6A0P2HV9P20:2PX080Z:RX00<0/;2`0;Rh^02h^;P00P31`L42
0<[:bP80dm?C0P3Lg=`20>OWi`80lo?c0P3dm?@20>k^kP80j>SX0P3Ph>020=WIf@80d];B0P3:b/X2
0<71`@030;Zj^P2a/K40/K6a0080ZJVY0P2TY:@20:2PX080W9bL102JVYX209^KV`80W9bL0P2MWId2
09jNWP80WinO0P2PX:020::RXP<0Xj>S0P2TY:@20:FUY@80YZJV102WYjL20:RXZ080ZJVY0P2ZZZX2
0:^[Z`80[:b/0P2][Jd20:j^[P80[jn_0P2`/;020;6a/@030;:b/P2c/k<0/k>c0080/k>c0P2d];@<
0;Fe]@80];Bd0P2c/k<20;:b/P80/K6a0P2`/;020:n_[`030:f][@2ZZZX0ZZZZ0080Z:RX0P2TY:@2
0:2PX080Vi^K0P2FUYH2092@T080QhN70P1oOgl207EeM@80JVYZ0P1MGEd2059BDP80ADE50P10@400
0`0j>SX0=SHf03Hf=P02030`<080;bl_0P0^;Rh202`/;080;Bd]0P0^;Rh202l_;`80<30`0P0b<S82
03<c<`80=CDe0P0g=cL203Ti>@80>c/k00<0?3`l03hn?P0n?Sh00P10@4020492@P80A4A40P16ATH2
04Q8B080BTY:0P1<C4`204i>CP80D51@0P1BDU8205ADE080EUIF0P1HF5P205YJFP0305aLG01NGUh0
GUiN0080H61P0P1RHV8206ATI080IVIV0P1XJ6P206YZJQD0oooo000C0?ooo`80Lg=c0P1jNWX208:2
PP80RHV90P2ATI4209RHV080X:2P0P2XZ:P00`2`/;00^;Rh0;Rh^0020<30`080bLW90P3Bd]820=cL
g080i^KV0P3`l?020?Ogm`80lo?c0P3/k>`20>GUi@80gMgM0P3Fe]H20<g=c@80a<C400<0_;bl0;Bd
]02d];@00P2/[:`20:JVYP80XJ6Q0P2NWYh209bLW080Vi^K102LW9`209fMW@80WYjN0P2OWil20:2P
X080XJ6Q0P2RXZ800`2SXj<0Y:BT0:BTY0020:FUY@@0YZJV102WYjL20:RXZ080ZJVY102ZZZX20:^[
Z`80[:b/0P2][Jd20:j^[P<0[jn_0P2`/;020;6a/@@0/[:b302c/k<20;:b/P80/K6a0P2`/;020:j^
[P80[Jf]00<0[:b/0:ZZZP2ZZZX00P2WYjL20:BTY080X:2P0P2KVi/209FEU@80Shn?0P27QhL207in
OP80MGEe0P1ZJVX205eMG@80DU9B0P16ATH20492@P0303`l?00g=cL0=cLg0080<C4a0P0`<30202l_
;`80;Rh^0P0_;bl2034a<@80<S8b0P0c<c<203De=@80=SHf0P0h>3P203Ti>@80>c/k0P0m?Cd00`0n
?Sh0@4100410@0020492@P80A4A40P16ATH204Q8B080BDU90P1;Bd/204e=C@80Cdm?0P1ADE4205=C
D`80EEEE0P1GEeL205QHF080FUYJ00<0G5aL05iNGP1NGUh00P1PH602069RHP80I6AT0P1VIVH206QX
J080JVYZ5@3oool001<0oooo0P1cLg<207YjNP80PX:20P29RHT2096AT@80V9RH0P2PX:020:RXZ003
0;2`/02h^;P0^;Rh0080`<300P39bLT20=;BdP80g=cL0P3Vi^H20?3`l080moOg0P3clo<20>c/k080
iNGU0P3MgMd20=KFeP80cLg=0P34a<@00`2l_;`0];Bd0;Bd]0020:b/[080YZJV0P2QXJ4209jNWP80
W9bL0P2KVi/409bLW080WIfM0P2NWYh209nOW`80X:2P0P2QXJ420::RXP030:>SX`2TY:@0Y:BT0080
YJFU102VYZH40:NWY`80Z:RX0P2YZJT40:ZZZP80Zj^[0P2/[:`20:f][@80[Zj^0`2_[jl20;2`/080
/K6a102b/[8<0;>c/`80/[:b0P2a/K420;2`/080[Zj^0P2][Jd00`2/[:`0ZZZZ0:ZZZP020:NWY`80
Y:BT0P2PX:0209^KV`80UIFE0P2?Shl208N7Q`80OWin0P1eMGD206YZJP80GEeM0P1BDU8204I6AP80
@T9200<0?3`l03Lg=`0g=cL00P0a<C42030`<080;bl_0P0^;Rh202l_;`80<C4a0P0b<S8203<c<`80
=CDe0P0f=SH203Ph>080>CTi0P0k>c/203dm?@0303hn?P10@400@4100080@T920P14A4@204I6AP80
B4Q80P19BDT204];B`80CDe=0P1?Cdl2055AD@80De=C0P1EEED205MGE`80F5QH0P1JFUX00`1LG5`0
GUiN05iNGP02061PH080HV9R0P1TI6@206IVIP80J6QX0P1ZJVXE0?ooo`004`3oool207=cL`80NWYj
0P22PX8208V9R@80T92@0P2HV9P20:2PX080YjNW00<0[jn_0;Ng]`2g]kL00P30`<020<S8b080dM7A
0P3Kfm/20>CTi080k^k^103inOT20?;blP80j^[Z0P3Rh^820=[JfP80d];B0P38b<P00`2o_kl0][Jf
0;Jf]P020:j^[P80Z:RX0P2SXj<20:2PX080WYjN1P2MWId209jNWP@0WinO0P2PX:020:6QX@80XZ:R
0`2SXj<20:BTY0@0YJFU102VYZH40:NWY`80Z:RX102YZJT20:ZZZP80Zj^[102/[:`30:j^[P@0[jn_
102`/;0<0;6a/@80/;2`0P2_[jl20:f][@80[:b/00<0Zj^[0:VYZ@2YZJT00P2WYjL20:>SX`80WinO
0P2KVi/209JFUP80T92@0P28R8P207moO`80MGEe0P1[Jf/205mOG`80De=C0P17AdL204=3@`0303lo
?`0i>CT0>CTi0080<c<c1P0a<C42038b<P80<c<c0P0e=CD203Hf=P80=cLg0P0i>CT203Xj>P80?3`l
0P0m?Cd203lo?`030451@@12@T80@T920080A4A40P16ATH204M7A`80BDU90P1;Bd/204e=C@80CTi>
0P1@D502059BDP80E5AD0P1FEUH205MGE`80FEUI0P1KFe/00`1MGEd0GemO05mOG`02061PH080HV9R
0P1TI6@206IVIP80J6QX0P1ZJVXE0?ooo`004`3oool207=cL`80NWYj0P22PX8208V9R@80T92@0P2H
V9P20:2PX080YjNW00<0[jn_0;Ng]`2g]kL00P30`<020<S8b080dM7A0P3Kfm/20>CTi080k^k^103i
nOT20?;blP80j^[Z0P3Rh^820=[JfP80d];B0P38b<P00`2o_kl0][Jf0;Jf]P020:j^[P80Z:RX0P2S
Xj<20:2PX080WYjN1P2MWId209jNWP@0WinO0P2PX:020:6QX@80XZ:R0`2SXj<20:BTY0@0YJFU102V
YZH40:NWY`80Z:RX102YZJT20:ZZZP80Zj^[102/[:`30:j^[P@0[jn_102`/;0<0;6a/@80/;2`0P2_
[jl20:f][@80[:b/00<0Zj^[0:VYZ@2YZJT00P2WYjL20:>SX`80WinO0P2KVi/209JFUP80T92@0P28
R8P207moO`80MGEe0P1[Jf/205mOG`80De=C0P17AdL204=3@`0303lo?`0i>CT0>CTi0080<c<c1P0a
<C42038b<P80<c<c0P0e=CD203Hf=P80=cLg0P0i>CT203Xj>P80?3`l0P0m?Cd203lo?`030451@@12
@T80@T920080A4A40P16ATH204M7A`80BDU90P1;Bd/204e=C@80CTi>0P1@D502059BDP80E5AD0P1F
EUH205MGE`80FEUI0P1KFe/00`1MGEd0GemO05mOG`02061PH080HV9R0P1TI6@206IVIP80J6QX0P1Z
JVXE0?ooo`004`3oool207=cL`80NWYj0P21PH4208V9R@80T92@0P2HV9P209nOW`80YjNW00<0[jn_
0;Ng]`2g]kL00P2o_kl20<O7a`80d=3@0P3IfMT20>;RhP80k>c/0P3gmoL20?clo080moOg0P3_knl2
0>SXj080gmoO0P3Fe]H20<g=c@030<?3``2i^KT0^KVi0080/K6a0P2ZZZX20:JVYP80XZ:R0P2PX:02
09nOW`H0WYjN0P2OWil40:2PX0@0XJ6Q00<0XZ:R0:>SX`2SXj<00P2SXj<40:BTY0@0YJFU102VYZH4
0:NWY`@0Z:RX102YZJT20:ZZZP<0Zj^[0P2/[:`40:f][@H0[Zj^202_[jl20:j^[P80[Jf]0P2/[:`2
0:^[Z`030:ZZZP2XZ:P0Z:RX0080YJFU0P2SXj<209nOW`80VYZJ0P2EUID2092@T080R8R80P20P802
07EeM@80Jf][0P1PH60205ADE080AdM70P13@d<00`11@D40>SXj03Xj>P0203Hf=P80<c<c0P0b<S82
03@d=080=CDe0P0f=SH203Ph>080>CTi0P0j>SX203/k>`80?Cdm0P0n?Sh20410@080@D5100<0@d=3
04A4A014A4@00P16ATH204M7A`80BDU90P1;Bd/204a<C080CTi>0P1@D502055AD@80De=C0P1EEED2
05IFEP80F5QH0P1JFUX205aLG00305eMG@1OGel0GemO0080HF5Q0P1SHf<206ATI080IVIV0P1XJ6P2
06YZJQD0oooo000C0?ooo`80Lg=c0P1jNWX20861P@80RHV90P2@T90209RHV080WinO0P2WYjL00`2_
[jl0]kNg0;Ng]`020;no_`80alO70P3@d=020=WIf@80h^;R0P3/k>`20?Ogm`80o?cl0P3gmoL20>o_
k`80j>SX0P3Ogml20=KFeP80cLg=00<0`l?30;Vi^@2i^KT00P2a/K420:ZZZP80YZJV0P2RXZ820:2P
X080WinO1P2NWYh209nOW`@0X:2P102QXJ400`2RXZ80Xj>S0:>SX`020:>SX`@0Y:BT102UYJD40:JV
YP@0YjNW102XZ:P40:VYZ@80ZZZZ0`2[Zj/20:b/[0@0[Jf]1P2^[Zh80:n_[`80[Zj^0P2][Jd20:b/
[080Zj^[00<0ZZZZ0:RXZ02XZ:P00P2UYJD20:>SX`80WinO0P2JVYX209FEU@80T92@0P28R8P20820
P080MGEe0P1[Jf/2061PH080E5AD0P17AdL204=3@`030451@@0j>SX0>SXj0080=SHf0P0c<c<2038b
<P80=3@d0P0e=CD203Hf=P80>3Ph0P0i>CT203Xj>P80>c/k0P0m?Cd203hn?P80@4100P11@D400`13
@d<0A4A404A4A00204I6AP80AdM70P19BDT204];B`80C4a<0P1>CTh2051@D080DE5A0P1CDe<205EE
E@80EUIF0P1HF5P205YJFP80G5aL00<0GEeM05mOG`1OGel00P1QHF4206=SH`80I6AT0P1VIVH206QX
J080JVYZ5@3oool001<0oooo0P1cLg<207YjNP80PH610P28R8P2092@T080UiNG0P2OWil20:JVYP03
0:j^[P2f][H0][Jf0080_[jn0P36a/H20<k>cP80emOG0P3Ph>020>[ZjP80lo?c0P3moOd20?clo080
m_Kf0P3^k^h20>GUi@80g=cL0P3AdM400`37alL0_Kfm0;fm_@020;>c/`80[:b/0P2WYjL20:BTY080
XZ:R1P2PX:0209nOW`H0X:2P102QXJ430::RXP@0Xj>S1P2TY:@60:FUY@H0YZJV102WYjL20:RXZ0<0
ZJVY102ZZZX60:^[Z``0[:b/102[Zj/20:ZZZP030:VYZ@2WYjL0YjNW0080Y:BT0P2RXZ8209jNWP80
VYZJ0P2EUID208n?S`80R8R80P20P80207IfMP80Jf][0P1QHF4205IFEP80BTY:0P15ADD00`11@D40
>c/k03/k>`0203Lg=`@0=CDe0P0g=cL203Ph>080>CTi0P0j>SX203/k>`80?Cdm0P0n?Sh203lo?`80
@4100P12@T8204=3@`0304E5A@16ATH0ATI60080AdM70P19BDT204Y:BP80C4a<0P1>CTh204m?C`80
DE5A0P1BDU8205ADE080EUIF0P1GEeL205UIF@80Fe]K0P1LG5`00`1NGUh0H61P061PH002065QH@80
Hf=S0P1UIFD206IVIP80J6QX0P1ZJVXE0?ooo`004`3oool207=cL`80NWYj0P21PH4208R8R080T92@
0P2GUiL209nOW`80YZJV00<0[Zj^0;Jf]P2f][H00P2n_[h20<K6aP80c/k>0P3GemL20>3Ph080j^[Z
0P3clo<20?gmo@80o?cl0P3fm_H20>k^kP80iNGU0P3Lg=`20=7Ad@030<O7a`2m_Kd0_Kfm0080/k>c
0P2/[:`20:NWY`80Y:BT0P2RXZ860:2PX080WinO1P2PX:040:6QX@<0XZ:R102SXj<60:BTY0H0YJFU
1P2VYZH40:NWY`80Z:RX0`2YZJT40:ZZZPH0Zj^[302/[:`40:^[Z`80ZZZZ00<0ZJVY0:NWY`2WYjL0
0P2TY:@20::RXP80WYjN0P2JVYX209FEU@80Shn?0P28R8P20820P080MWIf0P1[Jf/2065QH@80EUIF
0P1:BTX204E5A@030451@@0k>c/0>c/k0080=cLg100e=CD203Lg=`80>3Ph0P0i>CT203Xj>P80>c/k
0P0m?Cd203hn?P80?clo0P10@4020492@P80@d=300<0ADE504I6AP16ATH00P17AdL204U9B@80BTY:
0P1<C4`204i>CP80Cdm?0P1ADE42059BDP80E5AD0P1FEUH205MGE`80FEUI0P1KFe/205aLG00305iN
GP1PH600H61P0080HF5Q0P1SHf<206EUI@80IVIV0P1XJ6P206YZJQD0oooo000C0?ooo`80Lg=c0P1j
NWX20861P@80R8R80P2?Shl209NGU`80WYjN0P2UYJD00`2][Jd0]KFe0;Fe]@020;fm_@80aLG50P3=
cLd20=GEe@80g]kN0P3WinL20?3`l080no_k0P3oool20?gmo@80mOGe0P3[jn/20>7Qh@80emOG00<0
bl_;0<30`030`<000P2g]kL20:n_[`80ZJVY0P2UYJD20:>SX`80XZ:R0P2QXJ480:2PX0L0XJ6Q102R
XZ860:>SX`h0Y:BT102UYJD30:JVYP@0YjNW102XZ:P60:VYZ@`0ZZZZ0P2YZJT20:RXZ0030:NWY`2U
YJD0YJFU0080Xj>S0P2PX:0209fMW@80VIVI0P2DU9@208n?S`80R8R80P20P80207MgM`80K6a/0P1R
HV8205QHF080CTi>0P19BDT00`14A4@0?Shn03hn?P0203Ti>@80=cLg0P0i>CT203Xj>P80>c/k0P0l
?3`203dm?@80?Shn0P0o?cl20410@080@T920P13@d<204A4A080ADE500<0AdM704Q8B018B4P00P19
BDT204];B`80C4a<0P1>CTh204m?C`80D51@0P1BDU8205ADE080EEEE0P1GEeL205QHF080FUYJ0P1K
Fe/205eMG@0305mOG`1PH600H61P0080HV9R0P1SHf<206EUI@80IfMW0P1XJ6P206YZJQD0oooo000C
0?ooo`80Lg=c0P1jNWX20820P080R8R80P2?Shl209JFUP80WIfM0P2TY:@00`2/[:`0/k>c0;>c/`02
0;^k^`80`l?30P3;bl/20=?Cd`80fm_K0P3Shn<20>c/k080m?Cd0P3kno/20?ooo`80no_k0P3`l?02
0>GUi@80f][J00<0clo?0<C4a034a<@00P2j^[X20;:b/P80[:b/0P2WYjL20:FUY@80Y:BT0P2SXj<2
0::RXP`0XJ6Q2@2RXZ8F0:>SX`D0Y:BT0P2UYJD40:JVYPP0YjNW202XZ:P20:NWY`<0YZJV0P2TY:@2
0::RXP80WinO0P2LW9`209RHV080U9BD0P2>SXh208R8R080P8200P1gMgL206i^KP80I6AT0P1IFET2
059BDP80C4a<00<0ADE50410@010@4000P0l?3`203/k>`80?3`l0P0m?Cd203hn?P80?clo0P10@402
0451@@80@T920P13@d<204A4A080ADE50P16ATH204M7A`0304Q8B01:BTX0BTY:0080Bd];0P1<C4`2
04i>CP80Cdm?0P1@D502059BDP80De=C0P1EEED205IFEP80F5QH0P1IFET205]KF`80G5aL0P1NGUh0
0`1OGel0HF5Q065QH@02069RHP80I6AT0P1UIFD206MWI`80J6QX0P1ZJVXE0?ooo`004`3oool207=c
L`80NWYj0P20P80208R8R080Shn?0P2FUYH209fMW@80Y:BT00<0[:b/0;>c/`2c/k<00P2k^k/20<?3
``80bl_;0P3Cdm<20=_Kf`80hn?S0P3/k>`20?Cdm080no_k0P3oool20?_kn`80l?3`0P3UiND20=[J
fP030<o?c`34a<@0a<C40080^[Zj0P2b/[820:b/[080YjNW0P2UYJD20:BTY080Xj>S0P2RXZ8<0:6Q
X@T0XZ:R5P2SXj<50:BTY080YJFU102VYZH80:NWY`P0Z:RX0P2WYjL30:JVYP80Y:BT0P2RXZ8209nO
W`80W9bL0P2HV9P209BDU080SXj>0P28R8P20820P080MgMg0P1^KVh206ATI080FEUI0P1BDU8204a<
C00304E5A@10@400@4100080?3`l0P0k>c/203`l?080?Cdm0P0n?Sh203lo?`80@4100P11@D420492
@P80@d=30P14A4@204E5A@80ATI60P17AdL00`18B4P0BTY:04Y:BP0204];B`80C4a<0P1>CTh204m?
C`80D51@0P1BDU8205=CD`80EEEE0P1FEUH205QHF080FEUI0P1KFe/205aLG080GUiN00<0GemO065Q
H@1QHF400P1RHV8206ATI080IFEU0P1WIfL206QXJ080JVYZ5@3oool001<0oooo0P1bLW8207UiN@80
P8200P27QhL208j>SP80UIFE0P2LW9`20:>SX`030:^[Z`2b/[80/[:b0080^[Zj0P31`L420<W9b@80
d=3@0P3Hf=P20>3Ph080inOW0P3^k^h20?Gem@80n_[j0P3moOd20?Gem@80jNWY0P3Ng]h00`3Cdm<0
b<S80<S8b0020;jn_P80]KFe0P2_[jl20:ZZZP80YjNW0P2UYJD20:BTY080Xj>S6`2RXZ8A0:6QX@H0
XZ:R102SXj<20:BTY0`0YJFU0P2VYZH40:FUY@030:BTY02RXZ80XZ:R0080XJ6Q0P2NWYh209^KV`80
UiNG0P2CTi<208n?S`80R8R80P20P80207QhN080Kfm_0P1UIFD205eMG@80EUIF0P1?Cdl00`18B4P0
@d=304=3@`020410@080?clo1010@4020451@@80@T920P13@d<404A4A080ADE50P16ATH204M7A`80
B4Q80P19BDT00`1:BTX0Bd];04];B`0204e=C@80CTi>0P1?Cdl2051@D080DU9B0P1CDe<205ADE080
EUIF0P1GEeL205UIF@80FUYJ0P1KFe/205eMG@80GUiN00<0H61P065QH@1QHF400P1SHf<206ATI080
IVIV0P1WIfL206UYJ@80JVYZ5@3oool001<0oooo0P1bLW8207UiN@80P8200P27QhL208j>SP80UIFE
0P2LW9`20:>SX`030:^[Z`2b/[80/[:b0080^[Zj0P31`L420<W9b@80d=3@0P3Hf=P20>3Ph080inOW
0P3^k^h20?Gem@80n_[j0P3moOd20?Gem@80jNWY0P3Ng]h00`3Cdm<0b<S80<S8b0020;jn_P80]KFe
0P2_[jl20:ZZZP80YjNW0P2UYJD20:BTY080Xj>S6`2RXZ8A0:6QX@H0XZ:R102SXj<20:BTY0`0YJFU
0P2VYZH40:FUY@030:BTY02RXZ80XZ:R0080XJ6Q0P2NWYh209^KV`80UiNG0P2CTi<208n?S`80R8R8
0P20P80207QhN080Kfm_0P1UIFD205eMG@80EUIF0P1?Cdl00`18B4P0@d=304=3@`020410@080?clo
1010@4020451@@80@T920P13@d<404A4A080ADE50P16ATH204M7A`80B4Q80P19BDT00`1:BTX0Bd];
04];B`0204e=C@80CTi>0P1?Cdl2051@D080DU9B0P1CDe<205ADE080EUIF0P1GEeL205UIF@80FUYJ
0P1KFe/205eMG@80GUiN00<0H61P065QH@1QHF400P1SHf<206ATI080IVIV0P1WIfL206UYJ@80JVYZ
5@3oool001<0oooo0P1bLW8207UiN@80P8200P27QhL208f=S@80U9BD0P2KVi/20::RXP030:VYZ@2a
/K40/K6a0080^;Rh0P2o_kl20<K6aP80c/k>0P3EeMD20=gMg@80i>CT0P3Zj^X20?7al@80m_Kf0P3k
no/20?Win@80jn_[0P3QhN400`3GemL0c<c<0<c<c0020<;2`P80^KVi0P2b/[820:f][@80ZZZZ0P2X
Z:P20:JVYP80YJFU0P2TY:@80:>SX`T0XZ:R2P2QXJ440:2PX0H0WinO0P2NWYh709nOW`@0X:2P102Q
XJ480::RXPH0Xj>S1@2RXZ820:6QX@80WinO0P2MWId209ZJVP80UYJF0P2ATI4208j>SP80RHV90P20
P80207QhN080L71`0P1UIFD205iNGP80FEUI0P1BDU800`1;Bd/0ATI604I6AP0604=3@`@0A4A40P15
ADD404I6AP80AdM71018B4P204U9B@80BTY:0P1;Bd/00`1<C4`0CDe=04e=C@0204i>CP80Cdm?0P1A
DE42059BDP80De=C0P1DE5@205IFEP80EeMG0P1HF5P205UIF@80Fe]K0P1LG5`205iNGP80GemO00<0
H61P069RHP1RHV800P1SHf<206ATI080IVIV0P1WIfL206UYJ@80JVYZ5@3oool001<0oooo0P1bLW82
07UiN@80P8200P27QhL208f=S@80U9BD0P2KVi/20::RXP030:VYZ@2a/K40/K6a0080^;Rh0P2o_kl2
0<K6aP80c/k>0P3EeMD20=gMg@80i>CT0P3Zj^X20?7al@80m_Kf0P3kno/20?Win@80jn_[0P3QhN40
0`3GemL0c<c<0<c<c0020<;2`P80^KVi0P2b/[820:f][@80ZZZZ0P2XZ:P20:JVYP80YJFU0P2TY:@8
0:>SX`T0XZ:R2P2QXJ440:2PX0H0WinO0P2NWYh709nOW`@0X:2P102QXJ480::RXPH0Xj>S1@2RXZ82
0:6QX@80WinO0P2MWId209ZJVP80UYJF0P2ATI4208j>SP80RHV90P20P80207QhN080L71`0P1UIFD2
05iNGP80FEUI0P1BDU800`1;Bd/0ATI604I6AP0604=3@`@0A4A40P15ADD404I6AP80AdM71018B4P2
04U9B@80BTY:0P1;Bd/00`1<C4`0CDe=04e=C@0204i>CP80Cdm?0P1ADE42059BDP80De=C0P1DE5@2
05IFEP80EeMG0P1HF5P205UIF@80Fe]K0P1LG5`205iNGP80GemO00<0H61P069RHP1RHV800P1SHf<2
06ATI080IVIV0P1WIfL206UYJ@80JVYZ5@3oool001<0oooo0P1bLW8207UiN@80Ogmo0P26QXH208f=
S@80U9BD0P2JVYX20:6QX@030:RXZ02_[jl0[jn_0080][Jf0P2m_Kd20<C4a080bl_;0P3Bd]820=[J
fP80h>3P0P3WinL20>g]k@80lo?c0P3inOT20?[jnP80l?3`0P3Ti>@00`3Jf]X0clo?0<o?c`020<K6
aP80_Kfm0P2f][H20;2`/080[:b/0P2ZZZX20:RXZ080YjNW0P2VYZH20:FUY@H0Y:BT0`2SXj<40::R
XPH0XJ6Q1P2PX:0209nOW`@0WYjN0P2MWId409bLW0/0WIfM1P2NWYh409nOW`@0X:2P102QXJ450:2P
X080WinO0P2NWYh209^KV`80V9RH0P2EUID2092@T080S8b<0P28R8P208:2PP80NGUi0P1`L70206MW
I`80HF5Q0P1KFe/205EEE@0304m?C`1:BTX0BTY:0080ATI62017AdL404Q8B0@0BDU90P1:BTX404];
B`80C4a<0P1=CDd00`1>CTh0Cdm?04m?C`02051@D080DE5A0P1BDU8205=CD`80E5AD0P1EEED205MG
E`80F5QH0P1IFET205YJFP80G5aL0P1MGEd205iNGP80H61P00<0HF5Q069RHP1RHV800P1SHf<206EU
I@80IVIV0P1WIfL206UYJ@80JVYZ5@3oool001<0oooo0P1bLW8207UiN@80Ogmo0P26QXH208f=S@80
U9BD0P2JVYX20:6QX@030:RXZ02_[jl0[jn_0080][Jf0P2m_Kd20<C4a080bl_;0P3Bd]820=[JfP80
h>3P0P3WinL20>g]k@80lo?c0P3inOT20?[jnP80l?3`0P3Ti>@00`3Jf]X0clo?0<o?c`020<K6aP80
_Kfm0P2f][H20;2`/080[:b/0P2ZZZX20:RXZ080YjNW0P2VYZH20:FUY@H0Y:BT0`2SXj<40::RXPH0
XJ6Q1P2PX:0209nOW`@0WYjN0P2MWId409bLW0/0WIfM1P2NWYh409nOW`@0X:2P102QXJ450:2PX080
WinO0P2NWYh209^KV`80V9RH0P2EUID2092@T080S8b<0P28R8P208:2PP80NGUi0P1`L70206MWI`80
HF5Q0P1KFe/205EEE@0304m?C`1:BTX0BTY:0080ATI62017AdL404Q8B0@0BDU90P1:BTX404];B`80
C4a<0P1=CDd00`1>CTh0Cdm?04m?C`02051@D080DE5A0P1BDU8205=CD`80E5AD0P1EEED205MGE`80
F5QH0P1IFET205YJFP80G5aL0P1MGEd205iNGP80H61P00<0HF5Q069RHP1RHV800P1SHf<206EUI@80
IVIV0P1WIfL206UYJ@80JVYZ5@3oool001<0oooo0P1bLW8207UiN@80Ogmo0P26QXH208b<S080Ti>C
0P2IVIT20:2PX0030:NWY`2][Jd0[Jf]0080];Bd0P2k^k/20<;2`P80bLW90P3@d=020=OGe`80gMgM
0P3Ti>@20>_[j`80lO7a0P3inOT20?[jnP80mOGe0P3YjNT00`3Ng]h0dm?C0=?Cd`020<W9b@80`<30
0P2i^KT20;>c/`80[jn_0P2/[:`20:ZZZP80ZJVY0P2XZ:P40:JVYP@0YJFU0P2TY:@30:>SX`80XZ:R
1P2QXJ440:2PX0@0WinO0P2NWYh209fMW@80W9bL0P2KVi/209ZJVP<0Vi^K202JVYX209^KV`H0W9bL
102MWId409jNWPL0WinO0P2NWYh209fMW@80VYZJ0P2GUiL209>CT`80Shn?0P2;Rh/208J6QP80P820
0P1hN7P207=cL`80JFUY0P1RHV8205aLG080EeMG00<0DE5A04e=C@1=CDd00P1;Bd/804Y:BPH0Bd];
101<C4`404e=C@80CTi>0P1?Cdl00`1@D500DE5A055AD@04059BDP80De=C0P1DE5@205EEE@80EeMG
0P1HF5P205UIF@80FUYJ0P1KFe/205aLG080GUiN0P1OGel2061PH003065QH@1SHf<0Hf=S0080I6AT
0P1UIFD206IVIP80J6QX0P1YJFT206YZJQD0oooo000C0?ooo`80LW9b0P1iNGT207moO`80QXJ60P2<
S8`209>CT`80VIVI0P2PX:000`2WYjL0[Jf]0:f][@020;Bd]080^k^k0P32`/820<W9b@80d=3@0P3G
emL20=gMg@80i>CT0P3[jn/20?7al@80nOWi0P3jn_X20?Gem@80jNWY00<0g]kN0=?Cd`3Cdm<00P39
bLT20<30`080^KVi0P2c/k<20:n_[`80[:b/0P2ZZZX20:VYZ@80Z:RX102VYZH40:FUY@80Y:BT0`2S
Xj<20::RXPH0XJ6Q102PX:0409nOW`80WYjN0P2MWId209bLW080Vi^K0P2JVYX309^KV`P0VYZJ0P2K
Vi/609bLW0@0WIfM102NWYh709nOW`80WYjN0P2MWId209ZJVP80UiNG0P2CTi<208n?S`80Rh^;0P26
QXH20820P080N7Qh0P1cLg<206UYJ@80HV9R0P1LG5`205MGE`03055AD@1=CDd0CDe=0080Bd];201:
BTX604];B`@0C4a<101=CDd204i>CP80Cdm?00<0D51@055AD@1ADE40101BDU8205=CD`80E5AD0P1E
EED205MGE`80F5QH0P1IFET205YJFP80Fe]K0P1LG5`205iNGP80GemO0P1PH6000`1QHF40Hf=S06=S
H`0206ATI080IFEU0P1VIVH206QXJ080JFUY0P1ZJVXE0?ooo`004`3oool2079bLP80N7Qh0P1oOgl2
08F5Q@80Rh^;0P2BTY8209RHV080WinO00<0YJFU0:b/[02/[:`00P2b/[820;Vi^@80`<300P36a/H2
0<g=c@80e=CD0P3Jf]X20>7Qh@80j>SX0P3_knl20?Ogm`80n_[j0P3inOT20>g]k@030>?Sh`3IfMT0
fMWI0080c/k>0P35aLD20;fm_@80]kNg0P2c/k<20:n_[`80[Jf]0P2[Zj/20:ZZZP@0Z:RX0P2WYjL4
0:JVYP030:FUY@2TY:@0Y:BT0080Xj>S0P2RXZ840:6QX@@0X:2P0P2OWil409jNWP80W9bL0P2KVi/2
09ZJVPL0VIVI1P2HV9P609VIV@@0VYZJ102KVi/209bLW0L0WIfM0P2LW9`209^KV`80VIVI0P2FUYH2
09>CT`80Shn?0P2;Rh/208F5Q@80Ogmo0P1gMgL2079bLP80JVYZ0P1TI6@205eMG@80FEUI00<0E5AD
04m?C`1?Cdl0101>CTh:04e=C@H0CTi>101?Cdl2051@D080DE5A0`1BDU8205=CD`80E5AD0P1EEED2
05IFEP80EeMG0P1HF5P205UIF@80FUYJ0P1KFe/205aLG080GEeM0P1NGUh2061PH080HF5Q00<0HV9R
06=SH`1SHf<00P1TI6@206EUI@80IfMW0P1XJ6P206UYJ@80JVYZ5@3oool001<0oooo0P1bLW8207Qh
N080Ogmo0P25QHD208^;R`80TY:B0P2HV9P209nOW`030:FUY@2/[:`0[:b/0080/[:b0P2i^KT20<30
`080a/K60P3=cLd20=CDe080f][J0P3QhN420>SXj080kno_0P3gmoL20?[jnP80nOWi0P3]kNd00`3S
hn<0fMWI0=WIf@020<k>cP80aLG50P2m_Kd20;Ng]`80/k>c0P2_[jl20:f][@80Zj^[0P2ZZZX40:RX
Z080YjNW102VYZH00`2UYJD0Y:BT0:BTY0020:>SX`80XZ:R102QXJ440:2PX080WinO102NWYh209bL
W080Vi^K0P2JVYX709VIV@H0V9RH1P2IVIT409ZJVP@0Vi^K0P2LW9`709fMW@80W9bL0P2KVi/209VI
V@80UYJF0P2CTi<208n?S`80Rh^;0P25QHD207moO`80MgMg0P1bLW8206YZJP80I6AT0P1MGEd205UI
F@0305ADE01?Cdl0Cdm?00@0CTi>2P1=CDd604i>CP@0Cdm?0P1@D502055AD@<0DU9B0P1CDe<205AD
E080EEEE0P1FEUH205MGE`80F5QH0P1IFET205YJFP80Fe]K0P1LG5`205eMG@80GUiN0P1PH602065Q
H@03069RHP1SHf<0Hf=S0080I6AT0P1UIFD206MWI`80J6QX0P1YJFT206YZJQD0oooo000C0?ooo`80
LW9b0P1hN7P207inOP80Q8B40P2;Rh/2096AT@80UiNG0P2MWId00`2TY:@0ZZZZ0:ZZZP020;2`/080
]kNg0P2m_Kd20<C4a080b/[:0P3AdM420=OGe`80g]kN0P3UiND20>c/k080m?Cd0P3inOT20?clo080
m?Cd00<0jNWY0>3Ph03Ph>000P3EeMD20<_;b`80`/;20P2k^k/20;Jf]P80/[:b0P2`/;020:j^[P80
[Jf]0P2[Zj/40:ZZZP80ZJVY0P2WYjL00`2VYZH0YJFU0:FUY@020:BTY0@0XZ:R0P2QXJ440:2PX0@0
WinO0P2NWYh209fMW@80Vi^K0P2JVYX209VIV@T0V9RH202GUiL409RHV0@0VIVI0P2JVYX609^KV`D0
VYZJ0P2HV9P209BDU080TY:B0P2=SHd208R8R080Ph>30P1mOGd207IfMP80LG5a0P1ZJVX206ATI080
GUiN0P1JFUX00`1FEUH0De=C05=CD`02059BDP80DE5A3P1@D506055AD@80DU9B0`1CDe<205ADE080
EEEE101FEUH205MGE`80F5QH0P1IFET205YJFP80Fe]K0P1LG5`205eMG@80GUiN0P1OGel2061PH080
HF5Q00<0HV9R06=SH`1SHf<00P1UIFD206IVIP80IfMW0P1XJ6P206UYJ@80JVYZ5@3oool001<0oooo
0P1bLW8207QhN080OWin0P24Q8@208^;R`80TI6A0P2GUiL209fMW@030:BTY02ZZZX0ZZZZ0080/;2`
0P2g]kL20;fm_@80a<C40P3:b/X20=7Ad@80emOG0P3Ng]h20>GUi@80k>c/0P3dm?@20?Win@80o?cl
0P3dm?@00`3YjNT0h>3P0>3Ph0020=GEe@80bl_;0P32`/820;^k^`80][Jf0P2b/[820;2`/080[Zj^
0P2][Jd20:^[Z`@0ZZZZ0P2YZJT20:NWY`030:JVYP2UYJD0YJFU0080Y:BT102RXZ820:6QX@@0X:2P
102OWil209jNWP80WIfM0P2KVi/209ZJVP80VIVI2@2HV9P809NGU`@0V9RH102IVIT209ZJVPH0Vi^K
1@2JVYX209RHV080U9BD0P2BTY8208f=S@80R8R80P23Ph<207emO@80MWIf0P1aLG4206YZJP80I6AT
0P1NGUh205YJFP0305IFEP1CDe<0De=C0080DU9B0P1ADE4>051@D0H0DE5A0P1BDU8305=CD`80E5AD
0P1EEED405IFEP80EeMG0P1HF5P205UIF@80FUYJ0P1KFe/205aLG080GEeM0P1NGUh205mOG`80H61P
0P1QHF400`1RHV80Hf=S06=SH`0206EUI@80IVIV0P1WIfL206QXJ080JFUY0P1ZJVXE0?ooo`004`3o
ool2079bLP80N7Qh0P1nOWh208B4Q080RXZ:0P2@T90209JFUP80W9bL00<0XZ:R0:RXZ02XZ:P00P2_
[jl20;Fe]@80^k^k0P31`L420<S8b080c/k>0P3De=@20=_Kf`80hN7Q0P3Xj>P20?3`l080n?Sh0P3l
o?`20?Win@030?7al@3Vi^H0i^KV0080g=cL0P3Bd]820<W9b@80`L710P2j^[X20;Fe]@80/k>c0P2b
/[820;2`/080[jn_0P2][Jd20:b/[080Zj^[0P2YZJT00`2XZ:P0YjNW0:NWY`020:FUY@80Y:BT0P2S
Xj<20::RXP80Xj>S0P2RXZ820:6QX@80X:2P0P2OWil209jNWP80WIfM0P2KVi/409ZJVPD0VIVI102H
V9P409NGU`80V9RH0P2GUiL809RHV080VIVI1@2JVYX209VIV@80V9RH0P2FUYH209:BTP80T92@0P2=
SHd208N7Q`80P8200P1kNg/207MgM`80LG5a0P1[Jf/206EUI@80H61P0P1KFe/00`1GEeL0EUIF05IF
EP0205EEE@80E5AD101CDe<:059BDPH0De=C101DE5@305EEE@80EUIF0P1GEeL405QHF080FEUI0P1J
FUX205]KF`80G5aL0P1MGEd205iNGP80GemO0P1PH602065QH@80HV9R00<0Hf=S06ATI01TI6@00P1U
IFD206IVIP80IfMW0P1XJ6P206UYJ@80JVYZ5@3oool001<0oooo0P1bLW8207QhN080OWin0P24Q8@2
08Z:RP80T92@0P2FUYH209bLW0030::RXP2XZ:P0Z:RX0080[jn_0P2e]KD20;^k^`80`L710P38b<P2
0<k>cP80e=CD0P3Kfm/20>7Qh@80j>SX0P3`l?020?Shn080o?cl0P3inOT00`3alO40i^KV0>KViP02
0=cLg080d];B0P39bLT20<71`@80^[Zj0P2e]KD20;>c/`80/[:b0P2`/;020:n_[`80[Jf]0P2/[:`2
0:^[Z`80ZJVY00<0Z:RX0:NWY`2WYjL00P2UYJD20:BTY080Xj>S0P2RXZ820:>SX`80XZ:R0P2QXJ42
0:2PX080WinO0P2NWYh209fMW@80Vi^K102JVYX509VIV@@0V9RH102GUiL209RHV080UiNG202HV9P2
09VIV@D0VYZJ0P2IVIT209RHV080UYJF0P2BTY82092@T080SHf=0P27QhL20820P080Ng]k0P1gMgL2
075aL@80Jf][0P1UIFD2061PH080Fe]K00<0EeMG05IFEP1FEUH00P1EEED205ADE0@0De=C2P1BDU86
05=CD`@0E5AD0`1EEED205IFEP80EeMG101HF5P205UIF@80FUYJ0P1KFe/205aLG080GEeM0P1NGUh2
05mOG`80H61P0P1QHF42069RHP0306=SH`1TI6@0I6AT0080IFEU0P1VIVH206MWI`80J6QX0P1YJFT2
06YZJQD0oooo000C0?ooo`80LG5a0P1gMgL207emO@80Ph>30P29RHT208n?S`80UIFE0P2KVi/00`2Q
XJ40YjNW0:NWY`020:f][@80/k>c0P2i^KT20;no_`80aLG50P3;bl/20=7Ad@80f=SH0P3Ng]h20>CT
i080jn_[0P3bl_820?Win@80no_k00<0n?Sh0>k^kP3^k^h00P3Shn<20=SHf080clo?0P38b<P20<30
`080^k^k0P2g]kL20;Fe]@80];Bd0P2b/[820;6a/@80[jn_0P2^[Zh20:b/[0030:^[Z`2YZJT0ZJVY
0080Z:RX0P2WYjL20:FUY@H0Y:BT0P2SXj<40::RXP80X:2P0P2OWil209jNWP80WIfM0`2LW9`409^K
V`H0VYZJ102IVIT609RHV080VIVI0P2HV9P709NGU`@0UYJF0P2DU9@2096AT@80SHf=0P2:RXX208N7
Q`80PH610P1kNg/207IfMP80LG5a0P1/K6`206IVIP80HF5Q0P1LG5`00`1JFUX0FEUI05UIF@0205QH
F080EeMG0P1FEUH605EEE@H0E5AD201EEED305IFEP80EeMG101HF5P405UIF@80FUYJ0P1KFe/405aL
G080GUiN0P1OGel4061PH080HF5Q0P1RHV800`1SHf<0I6AT06ATI00206EUI@80IVIV0P1WIfL206QX
J080JFUY0P1[Jf/E0?ooo`004`3oool2075aL@80MgMg0P1mOGd208>3P`80RHV90P2?Shl209FEU@80
Vi^K00<0XJ6Q0:NWY`2WYjL00P2][Jd20;>c/`80^KVi0P2o_kl20<G5a@80bl_;0P3AdM420=SHf080
g]kN0P3Ti>@20>_[j`80l_;b0P3inOT20?_kn`030?Shn03^k^h0k^k^0080hn?S0P3Hf=P20<o?c`80
b<S80P30`<020;^k^`80]kNg0P2e]KD20;Bd]080/[:b0P2a/K420:n_[`80[Zj^0P2/[:`00`2[Zj/0
ZJVY0:VYZ@020:RXZ080YjNW0P2UYJD60:BTY080Xj>S102RXZ820:2PX080WinO0P2NWYh209fMW@<0
W9bL102KVi/609ZJVP@0VIVI1P2HV9P209VIV@80V9RH1`2GUiL409JFUP80U9BD0P2ATI4208f=S@80
RXZ:0P27QhL20861P@80Ng]k0P1fMWH2075aL@80K6a/0P1VIVH2065QH@80G5aL00<0FUYJ05UIF@1I
FET00P1HF5P205MGE`80EUIF1P1EEED605ADE0P0EEEE0`1FEUH205MGE`@0F5QH101IFET205YJFP80
Fe]K101LG5`205iNGP80GemO101PH602065QH@80HV9R00<0Hf=S06ATI01TI6@00P1UIFD206IVIP80
IfMW0P1XJ6P206UYJ@80Jf][5@3oool001<0oooo0P1aLG4207MgM`80OGem0P22PX8208R8R080SXj>
0P2DU9@209VIV@0309nOW`2UYJD0YJFU0080ZZZZ0P2`/;020;Jf]P80_;bl0P32`/820<S8b080c/k>
0P3De=@20=[JfP80h>3P0P3WinL20>c/k080l_;b0P3fm_H00`3inOT0l_;b0?;blP020>[ZjP80gmoO
0P3Fe]H20<o?c`80alO70P31`L420;^k^`80^KVi0P2f][H20;Fe]@80];Bd0P2c/k<20;6a/@80/;2`
00<0[Zj^0:f][@2][Jd00P2[Zj/20:VYZ@@0Z:RX0P2WYjL60:JVYP80YJFU0P2TY:@20::RXP@0XJ6Q
0P2PX:0709nOW`80WIfM102LW9`409^KV`P0VYZJ0P2HV9P209NGU`<0UYJF0P2EUID209BDU080TY:B
0P2@T90208f=S@80RHV90P25QHD20820P080Ng]k0P1fMWH2075aL@80Jf][0P1VIVH2069RHP80GUiN
00<0G5aL05]KF`1KFe/00P1JFUX405UIF@80F5QH1P1GEeL605IFEPP0EeMG0`1HF5P405UIF@80FUYJ
101KFe/205aLG080GEeM101NGUh205mOG`80H61P0P1QHF42069RHP80Hf=S00<0I6AT06EUI@1UIFD0
0P1VIVH206MWI`80J6QX0P1YJFT206YZJP80Jf][5@3oool001<0oooo0P1aLG4207MgM`80OGem0P22
PX8208R8R080SXj>0P2DU9@209VIV@0309nOW`2UYJD0YJFU0080ZZZZ0P2`/;020;Jf]P80_;bl0P32
`/820<S8b080c/k>0P3De=@20=[JfP80h>3P0P3WinL20>c/k080l_;b0P3fm_H00`3inOT0l_;b0?;b
lP020>[ZjP80gmoO0P3Fe]H20<o?c`80alO70P31`L420;^k^`80^KVi0P2f][H20;Fe]@80];Bd0P2c
/k<20;6a/@80/;2`00<0[Zj^0:f][@2][Jd00P2[Zj/20:VYZ@@0Z:RX0P2WYjL60:JVYP80YJFU0P2T
Y:@20::RXP@0XJ6Q0P2PX:0709nOW`80WIfM102LW9`409^KV`P0VYZJ0P2HV9P209NGU`<0UYJF0P2E
UID209BDU080TY:B0P2@T90208f=S@80RHV90P25QHD20820P080Ng]k0P1fMWH2075aL@80Jf][0P1V
IVH2069RHP80GUiN00<0G5aL05]KF`1KFe/00P1JFUX405UIF@80F5QH1P1GEeL605IFEPP0EeMG0`1H
F5P405UIF@80FUYJ101KFe/205aLG080GEeM101NGUh205mOG`80H61P0P1QHF42069RHP80Hf=S00<0
I6AT06EUI@1UIFD00P1VIVH206MWI`80J6QX0P1YJFT206YZJP80Jf][5@3oool001<0oooo0P1aLG42
07MgM`80O7al0P21PH4208N7Q`80SHf=0P2BTY8209RHV00309jNWP2SXj<0Xj>S0080ZJVY0P2^[Zh2
0;Bd]080^[Zj0P2o_kl20<G5a@80bl_;0P3AdM420=OGe`80g=cL0P3Rh^820>SXj080kNg]0P3bl_83
0?Ogm`80k^k^0P3UiND20=_Kf`80d];B0P3;bl/20<G5a@80`<300P2m_Kd20;^k^`80^[Zj0P2h^;P2
0;Jf]P80]KFe0P2c/k<00`2b/[80/;2`0;2`/0020:n_[`80[Jf]0P2/[:`20:^[Z`H0ZZZZ102YZJT2
0:NWY`80YZJV0P2UYJD20:>SX`D0XZ:R1P2QXJ4409nOW`80WIfM0P2LW9`209^KV`H0VYZJ0P2IVIT2
09NGU`80UYJF00<0UIFE09>CT`2CTi<00P2BTY82096AT@80SXj>0P2;Rh/208R8R080Q8B40P20P802
07]kN`80MGEe0P1`L70206][J`80IVIV0P1QHF42061PH00305mOG`1MGEd0GEeM0080G5aL101KFe/2
05YJFPH0FEUI201HF5P705UIF@@0FUYJ101KFe/405aLG080GEeM0P1NGUh405mOG`80H61P0P1QHF42
069RHP@0Hf=S00<0I6AT06EUI@1UIFD00P1VIVH206MWI`80J6QX0P1YJFT206YZJP80Jf][5@3oool0
01<0oooo0P1aLG4207MgM`80O7al0P21PH4208N7Q`80SHf=0P2BTY8209RHV00309jNWP2SXj<0Xj>S
0080ZJVY0P2^[Zh20;Bd]080^[Zj0P2o_kl20<G5a@80bl_;0P3AdM420=OGe`80g=cL0P3Rh^820>SX
j080kNg]0P3bl_830?Ogm`80k^k^0P3UiND20=_Kf`80d];B0P3;bl/20<G5a@80`<300P2m_Kd20;^k
^`80^[Zj0P2h^;P20;Jf]P80]KFe0P2c/k<00`2b/[80/;2`0;2`/0020:n_[`80[Jf]0P2/[:`20:^[
Z`H0ZZZZ102YZJT20:NWY`80YZJV0P2UYJD20:>SX`D0XZ:R1P2QXJ4409nOW`80WIfM0P2LW9`209^K
V`H0VYZJ0P2IVIT209NGU`80UYJF00<0UIFE09>CT`2CTi<00P2BTY82096AT@80SXj>0P2;Rh/208R8
R080Q8B40P20P80207]kN`80MGEe0P1`L70206][J`80IVIV0P1QHF42061PH00305mOG`1MGEd0GEeM
0080G5aL101KFe/205YJFPH0FEUI201HF5P705UIF@@0FUYJ101KFe/405aLG080GEeM0P1NGUh405mO
G`80H61P0P1QHF42069RHP@0Hf=S00<0I6AT06EUI@1UIFD00P1VIVH206MWI`80J6QX0P1YJFT206YZ
JP80Jf][5@3oool001<0oooo0P1aLG4207IfMP80O7al0P21PH4208J6QP80S8b<0P2ATI4209JFUP03
09bLW02QXJ40XJ6Q0080YjNW0P2/[:`20;:b/P80]kNg0P2m_Kd20<;2`P80b<S80P3=cLd20=?Cd`80
f=SH0P3Ng]h20>?Sh`80j>SX0P3]kNd00`3alO40moOg0?Ogm`020?Cdm080jn_[0P3Rh^820=SHf080
dM7A0P3;bl/20<K6aP80`/;20P30`<020;no_`80_Kfm0P2k^k/20;Vi^@80]kNg00<0][Jf0;Bd]02d
];@00P2d];@20;:b/P80/;2`0P2_[jl60:j^[P@0[Jf]0P2/[:`40:^[Z`80Z:RX0`2VYZH60:FUY@80
Y:BT0P2RXZ820:6QX@80X:2P0P2OWil209bLW0H0Vi^K0P2JVYX209VIV@80V9RH00<0UiNG09FEU@2E
UID00P2DU9@209:BTP80Shn?0P2<S8`208R8R080QHF50P1oOgl207YjNP80MGEe0P1^KVh206YZJP80
IVIV0P1SHf<2069RHP03065QH@1PH600H61P0080GemO0P1NGUh205eMG@80G5aL1P1KFe/>05YJFPD0
Fe]K101LG5`405eMG@80GUiN101OGel2061PH080HF5Q101RHV8206=SH`80I6AT00<0IFEU06IVIP1V
IVH00P1VIVH206MWI`80J6QX0P1YJFT206YZJP80Jf][5@3oool001<0oooo0P1aLG4207IfMP80O7al
0P21PH4208J6QP80S8b<0P2ATI4209JFUP0309bLW02QXJ40XJ6Q0080YjNW0P2/[:`20;:b/P80]kNg
0P2m_Kd20<;2`P80b<S80P3=cLd20=?Cd`80f=SH0P3Ng]h20>?Sh`80j>SX0P3]kNd00`3alO40moOg
0?Ogm`020?Cdm080jn_[0P3Rh^820=SHf080dM7A0P3;bl/20<K6aP80`/;20P30`<020;no_`80_Kfm
0P2k^k/20;Vi^@80]kNg00<0][Jf0;Bd]02d];@00P2d];@20;:b/P80/;2`0P2_[jl60:j^[P@0[Jf]
0P2/[:`40:^[Z`80Z:RX0`2VYZH60:FUY@80Y:BT0P2RXZ820:6QX@80X:2P0P2OWil209bLW0H0Vi^K
0P2JVYX209VIV@80V9RH00<0UiNG09FEU@2EUID00P2DU9@209:BTP80Shn?0P2<S8`208R8R080QHF5
0P1oOgl207YjNP80MGEe0P1^KVh206YZJP80IVIV0P1SHf<2069RHP03065QH@1PH600H61P0080GemO
0P1NGUh205eMG@80G5aL1P1KFe/>05YJFPD0Fe]K101LG5`405eMG@80GUiN101OGel2061PH080HF5Q
101RHV8206=SH`80I6AT00<0IFEU06IVIP1VIVH00P1VIVH206MWI`80J6QX0P1YJFT206YZJP80Jf][
5@3oool001<0oooo0P1aLG4207IfMP80Ng]k0P20P80208F5Q@80Rh^;0P2@T90209FEU@0309ZJVP2O
Wil0WinO0080YJFU0P2ZZZX20:n_[`80]KFe0P2j^[X20;no_`80a<C40P3:b/X20<o?c`80e=CD0P3J
f]X20=oOg`80i>CT0P3Xj>P00`3]kNd0lO7a0?7al@020?Cdm080kno_0P3Vi^H20=cLg080eMGE0P3>
c/h20<S8b080a/K60P34a<@40<?3``80`<300P2m_Kd20;^k^`030;Zj^P2h^;P0^;Rh0080]kNg0P2f
][H40;Bd]080/k>c1P2b/[840;6a/@80/;2`0P2_[jl20;2`/080[:b/00<0Zj^[0:ZZZP2ZZZX00P2Y
ZJT40:RXZ080YjNW0P2UYJD20:BTY080Xj>S0P2QXJ4209nOW`80WYjN0P2MWId209bLW080VYZJ0P2I
VIT00`2GUiL0UIFE09FEU@0209BDU080Ti>C0P2@T90208b<S080QhN70P23Ph<207moO`80NWYj0P1f
MWH206m_K`80K6a/0P1VIVH206EUI@80I6AT00<0Hf=S069RHP1RHV800P1QHF42061PH080GemO0P1N
GUh405eMGA<0G5aL1P1MGEd405iNGP80GemO101PH602065QH@@0HV9R0P1SHf<406ATI00306EUI@1V
IVH0IVIV0080IfMW101XJ6P206UYJ@80JVYZ0P1[Jf/E0?ooo`004`3oool2075aL@80MWIf0P1kNg/2
0820P080QHF50P2;Rh/2092@T080UIFE00<0VYZJ09nOW`2OWil00P2UYJD20:ZZZP80[jn_0P2e]KD2
0;Zj^P80_kno0P34a<@20<[:bP80clo?0P3De=@20=[JfP80gmoO0P3Ti>@20>SXj0030>g]k@3alO40
lO7a0080m?Cd0P3_knl20>KViP80g=cL0P3EeMD20<k>cP80b<S80P36a/H20<C4a0@0`l?30P30`<02
0;fm_@80^k^k00<0^[Zj0;Rh^02h^;P00P2g]kL20;Jf]P@0];Bd0P2c/k<60;:b/P@0/K6a0P2`/;02
0:n_[`80/;2`0P2/[:`00`2[Zj/0ZZZZ0:ZZZP020:VYZ@@0Z:RX0P2WYjL20:FUY@80Y:BT0P2SXj<2
0:6QX@80WinO0P2NWYh209fMW@80W9bL0P2JVYX209VIV@0309NGU`2EUID0UIFE0080U9BD0P2CTi<2
092@T080S8b<0P27QhL208>3P`80Ogmo0P1jNWX207IfMP80Kfm_0P1/K6`206IVIP80IFEU0P1TI6@0
0`1SHf<0HV9R069RHP02065QH@80H61P0P1OGel205iNGP@0GEeM4`1LG5`605eMG@@0GUiN0P1OGel4
061PH080HF5Q101RHV8206=SH`@0I6AT00<0IFEU06IVIP1VIVH00P1WIfL406QXJ080JFUY0P1ZJVX2
06][JaD0oooo000C0?ooo`80LG5a0P1fMWH207]kN`80P8200P25QHD208V9R@80Shn?0P2DU9@00`2I
VIT0WYjN09jNWP020:>SX`80Z:RX0P2][Jd20;:b/P80]kNg0P2l_;`20<71`@80a/K60P3;bl/20=3@
d080eMGE0P3Jf]X20=oOg`80i>CT00<0jNWY0>g]k@3]kNd00P3clo<20?Cdm080jn_[0P3Ti>@20=gM
g@80e=CD0P3>c/h20<[:bP@0b<S80P37alL20<K6aP80`/;20P30`<000`2n_[h0_Kfm0;fm_@020;bl
_080^k^k0P2i^KT40;Rh^080][Jf102g]kL20;Fe]@80];Bd0P2e]KD40;Bd]080/k>c0`2`/;020:n_
[`@0[Zj^0P2][Jd20:^[Z`80ZZZZ0P2XZ:P20:JVYP80Xj>S0P2QXJ420:2PX080WYjN0P2LW9`209^K
V`0309VIV@2GUiL0UiNG0080UIFE0P2BTY8208n?S`80RXZ:0P27QhL208:2PP80O7al0P1iNGT207Ee
M@80LG5a0P1^KVh206YZJP80J6QX0P1VIVH00`1UIFD0I6AT06ATI00206=SH`80HV9R0P1QHF42061P
H0@0GemO101NGUh=05eMG@H0GUiN1P1OGel4061PH080HF5Q101RHV8206=SH`@0I6AT0P1UIFD306IV
IP80IfMW0P1XJ6P406UYJ@80JVYZ0P1[Jf/E0?ooo`004`3oool2075aL@80MWIf0P1kNg/20820P080
QHF50P29RHT208n?S`80U9BD00<0VIVI09jNWP2NWYh00P2SXj<20:RXZ080[Jf]0P2b/[820;Ng]`80
_;bl0P31`L420<K6aP80bl_;0P3@d=020=GEe@80f][J0P3Ogml20>CTi0030>WYj@3]kNd0kNg]0080
lo?c0P3dm?@20>_[j`80i>CT0P3MgMd20=CDe080c/k>0P3:b/X40<S8b080alO70P36a/H20<;2`P80
`<3000<0_[jn0;fm_@2m_Kd00P2l_;`20;^k^`80^KVi102h^;P20;Jf]P@0]kNg0P2e]KD20;Bd]080
]KFe102d];@20;>c/`<0/;2`0P2_[jl40:j^[P80[Jf]0P2[Zj/20:ZZZP80Z:RX0P2VYZH20:>SX`80
XJ6Q0P2PX:0209jNWP80W9bL0P2KVi/00`2IVIT0UiNG09NGU`0209FEU@80TY:B0P2?Shl208Z:RP80
QhN70P22PX8207alO080NGUi0P1eMGD2075aL@80KVi^0P1ZJVX206QXJ080IVIV00<0IFEU06ATI01T
I6@00P1SHf<2069RHP80HF5Q0P1PH60405mOG`@0GUiN3@1MGEd605iNGPH0GemO101PH602065QH@@0
HV9R0P1SHf<406ATI080IFEU0`1VIVH206MWI`80J6QX101YJFT206YZJP80Jf][5@3oool001<0oooo
0P1`L70207EeM@80NWYj0P1oOgl208B4Q080R8R80P2=SHd209:BTP0309NGU`2LW9`0W9bL0080XJ6Q
0P2UYJD20:ZZZP80[jn_0P2d];@20;Vi^@80_[jn0P33`l<20<S8b080cLg=0P3AdM420=KFeP80fm_K
0P3Ph>000`3Ti>@0jNWY0>WYj@020>k^kP80mOGe0P3clo<20>WYj@80h>3P0P3Jf]X20=CDe080clo?
203<c<`20<O7a`80aLG500<0`/;20<71`@31`L400P31`L420<30`0@0_Kfm0P2l_;`20;Zj^P80^k^k
0P2j^[X20;^k^`80^KVi102j^[X20;Vi^@80^;Rh00<0][Jf0;Ng]`2g]kL00P2e]KD40;Bd]080/k>c
0P2a/K420:n_[`80[Jf]0P2[Zj/20:RXZ080YJFU0P2SXj<20:6QX@80WinO0P2NWYh00`2KVi/0V9RH
09RHV00209JFUP80Ti>C0P2?Shl208^;R`80QXJ60P23Ph<207inOP80NGUi0P1eMGD2075aL@80Kfm_
0P1]KFd206][J`80JFUY00<0IfMW06IVIP1VIVH00P1UIFD206ATI080Hf=S0P1RHV82065QH@@0H61P
1P1OGel805iNGPL0GemO1P1PH604065QH@@0HV9R0P1SHf<406ATI0@0IFEU00<0IVIV06MWI`1WIfL0
0P1WIfL206QXJ0@0JFUY0P1ZJVX206][JaD0oooo000C0?ooo`80L71`0P1eMGD207YjNP80Ogmo0P24
Q8@208R8R080SHf=0P2BTY800`2GUiL0W9bL09bLW0020:6QX@80YJFU0P2ZZZX20:n_[`80];Bd0P2i
^KT20;jn_P80`l?30P38b<P20<g=c@80dM7A0P3Fe]H20=_Kf`80h>3P00<0i>CT0>WYj@3YjNT00P3^
k^h20?Gem@80lo?c0P3YjNT20>3Ph080f][J0P3De=@20<o?c`P0c<c<0P37alL20<G5a@030<;2`P31
`L40`L710080`L710P30`<040;fm_@80_;bl0P2j^[X20;^k^`80^[Zj0P2k^k/20;Vi^@@0^[Zj0P2i
^KT20;Rh^0030;Jf]P2g]kL0]kNg0080]KFe102d];@20;>c/`80/K6a0P2_[jl20:f][@80Zj^[0P2X
Z:P20:FUY@80Xj>S0P2QXJ4209nOW`80WYjN00<0Vi^K09RHV02HV9P00P2FUYH209>CT`80Shn?0P2;
Rh/208J6QP80Ph>30P1nOWh207UiN@80MGEe0P1aLG4206m_K`80KFe]0P1[Jf/206UYJ@0306MWI`1V
IVH0IVIV0080IFEU0P1TI6@206=SH`80HV9R0P1QHF44061PH0H0GemO201NGUh705mOG`H0H61P101Q
HF44069RHP80Hf=S101TI6@406EUI@0306IVIP1WIfL0IfMW0080IfMW0P1XJ6P406UYJ@80JVYZ0P1[
Jf/E0?ooo`004`3oool2071`L080MGEe0P1iNGT207inOP80Ph>30P27QhL208b<S080TI6A00<0UIFE
09ZJVP2JVYX00P2OWil20:>SX`80Z:RX0P2][Jd20;6a/@80][Jf0P2k^k/20;no_`80a<C40P39bLT2
0<k>cP80d];B0P3GemL20=_Kf`030>3Ph03UiND0iNGU0080j^[Z0P3_knl20?Cdm080lo?c0P3Xj>P2
0=kNgP80f=SH0P3Cdm<20=3@d080clo?0P3@d=020=7Ad@80cLg=0P3:b/X00`39bLT0a/K60<K6aP02
0<K6aP80aLG50P33`l<40<71`@80`<30102o_kl20<30`080_[jn0P2o_kl60<30`0L0_;bl0P2j^[X2
0;Vi^@80]kNg0P2f][H20;Bd]080/[:b0P2^[Zh20:^[Z`80Z:RX0P2TY:@20:6QX@80X:2P00<0WYjN
09ZJVP2JVYX00P2FUYH209:BTP80SXj>0P29RHT208B4Q080PX:20P1oOgl207YjNP80MWIf0P1aLG42
071`L080KVi^0P1]KFd206][J`0306UYJ@1XJ6P0J6QX0080IVIV101UIFD406=SH`80HV9R101QHF4C
061PH0H0HF5Q101RHV8406=SH`@0I6AT101UIFD306IVIP80IfMW101XJ6P206UYJ@@0JVYZ0P1[Jf/E
0?ooo`004`3oool2071`L080M7Ad0P1iNGT207emO@80PX:20P26QXH208Z:RP80Shn?00<0U9BD09RH
V02HV9P00P2MWId20:6QX@80YJFU0P2ZZZX20:n_[`80/k>c0P2h^;P20;bl_080`L710P35aLD20<[:
bP80c/k>0P3Cdm<20=OGe`030=cLg03Ph>00h>3P0080iNGU0P3Zj^X20>k^kP80lo?c0P3alO420>OW
i`80g]kN0P3Hf=P20=CDe080d];B0P3Cdm<20=GEe@80dm?C0P3>c/h00`3=cLd0c<c<0<c<c0020<[:
bP@0bLW90P36a/H40<G5a@80a<C40P33`l<40<C4a080`l?30P34a<@20<K6aP80alO700<0a/K60<C4
a034a<@01P31`L420<30`080_[jn0P2m_Kd20;^k^`80^[Zj0P2f][H20;>c/`80[jn_0P2[Zj/20:NW
Y`80XZ:R00<0WYjN09^KV`2KVi/00P2HV9P209:BTP80Shn?0P2<S8`208F5Q@80PX:20P20P80207em
O@80N7Qh0P1eMGD207=cL`80LG5a0P1_Kfl206e]K@0306][J`1ZJVX0JVYZ0080J6QX0P1WIfL206IV
IP80IFEU0P1TI6@406=SH`@0HV9R4`1QHF46069RHP@0Hf=S101TI6@406EUI@@0IVIV0`1WIfL206QX
J0@0JFUY101ZJVX206][JaD0oooo000C0?ooo`80L71`0P1dM7@207UiN@80OGem0P22PX8208J6QP80
RXZ:0P2?Shl00`2DU9@0V9RH09RHV00209fMW@80XJ6Q0P2UYJD20:ZZZP80[jn_0P2c/k<20;Rh^080
_;bl0P31`L420<G5a@80b/[:0P3>c/h20=?Cd`80emOG00<0g=cL0>3Ph03Ph>000P3UiND20>[ZjP80
k^k^0P3clo<20?7al@80inOW0P3Ng]h20=SHf080e=CD0P3Bd]820=?Cd`80eMGE0P3Cdm<20<k>cP03
0<g=c@3<c<`0c<c<0080b/[:1039bLT20<K6aP@0aLG50P34a<@20<?3``@0a<C40P33`l<20<C4a080
a/K60P37alL00`36a/H0a<C40<C4a0060<71`@80`<300P2n_[h20;fm_@80^k^k0P2j^[X20;Jf]P80
/k>c0P2_[jl20:^[Z`80YjNW0P2RXZ800`2NWYh0Vi^K09^KV`0209RHV080TY:B0P2?Shl208b<S080
QHF50P22PX820820P080OGem0P1hN7P207EeM@80Lg=c0P1aLG4206m_K`80KFe]00<0Jf][06YZJP1Z
JVX00P1XJ6P206MWI`80IVIV0P1UIFD206ATI0@0Hf=S101RHV8C065QH@H0HV9R101SHf<406ATI0@0
IFEU101VIVH306MWI`80J6QX101YJFT406YZJP80Jf][5@3oool001<0oooo0P1`L70207AdM080N7Qh
0P1mOGd20861P@80QHF50P29RHT208j>SP0309:BTP2FUYH0UYJF0080VYZJ0P2OWil20:>SX`80YjNW
0P2/[:`20;2`/080];Bd0P2i^KT20;fm_@80`L710P36a/H20<[:bP80c/k>0P3Cdm<00`3GemL0g=cL
0=cLg0020>3Ph080iNGU0P3Zj^X20?3`l080m?Cd0P3`l?020>OWi`80gmoO0P3IfMT40=GEe@80emOG
0P3Hf=P20=CDe0<0dM7A0P3@d=020<o?c`80c/k>0P3<c<`20<[:bP@0bLW92038b<P20<O7a`80bLW9
1@3;bl/20<[:bP80bLW90P37alL20<G5a@80a<C40P32`/820;no_`80_Kfm0P2j^[X20;Ng]`80/k>c
0P2_[jl20:VYZ@80Y:BT00<0WinO09ZJVP2JVYX00P2GUiL209>CT`80T92@0P2=SHd208R8R080QHF5
0P21PH4207emO@80NWYj0P1gMgL207EeM@80Lg=c0P1`L70206i^KP0306e]K@1[Jf/0Jf][0080JVYZ
0P1XJ6P206MWI`@0IVIV0P1UIFD206ATI0H0Hf=S4`1RHV8406=SH`H0I6AT101UIFD406IVIP<0IfMW
101XJ6P406UYJ@@0JVYZ0P1[Jf/E0?ooo`004`3oool2071`L080M7Ad0P1hN7P207emO@80PH610P25
QHD208V9R@80SXj>00<0TY:B09JFUP2FUYH00P2JVYX209nOW`80Xj>S0P2WYjL20:b/[080/;2`0P2d
];@20;Vi^@80_Kfm0P31`L420<K6aP80b/[:0P3>c/h20=?Cd`030=OGe`3Lg=`0g=cL0080h>3P0P3U
iND20>[ZjP80l?3`0P3dm?@20?3`l080inOW0P3Ogml20=WIf@@0eMGE0P3GemL20=SHf080e=CD0`3A
dM420=3@d080clo?0P3>c/h20<c<c080b/[:1039bLT80<S8b080alO70P39bLT50<_;b`80b/[:0P39
bLT20<O7a`80aLG50P34a<@20<;2`P80_kno0P2m_Kd20;Zj^P80]kNg0P2c/k<20:n_[`80ZJVY0P2T
Y:@00`2OWil0VYZJ09ZJVP0209NGU`80Ti>C0P2@T90208f=S@80R8R80P25QHD20861P@80OGem0P1j
NWX207MgM`80MGEe0P1cLg<2071`L080KVi^00<0KFe]06][J`1[Jf/00P1ZJVX206QXJ080IfMW101V
IVH206EUI@80I6AT1P1SHf<C069RHP@0Hf=S1P1TI6@406EUI@@0IVIV0`1WIfL406QXJ0@0JFUY101Z
JVX206][JaD0oooo000C0?ooo`80L71`0P1dM7@207QhN080O7al0P20P80208B4Q080R8R80P2<S8`0
0`2@T900U9BD09BDU00209RHV080W9bL0P2QXJ420:FUY@80ZJVY0P2][Jd20;6a/@80]KFe0P2i^KT2
0;jn_P80`/;20P36a/H20<[:bP80c/k>00<0dm?C0=OGe`3GemL00P3Lg=`20>3Ph080iNGU0P3Zj^X2
0?3`l080lo?c0P3^k^h20>SXj080h^;R0P3MgMd20=[JfP80fMWI0P3Lg=`20=_Kf`030=OGe`3EeMD0
eMGE00@0eMGE103De=@20=7Ad@80d=3@103>c/h40<g=c@@0c<c<0P3=cLd30<o?c`80dM7A0P3@d=02
0<o?c`80c<c<0P39bLT20<S8b080a/K60P34a<@20<71`@80_Kfm0P2h^;P20;Bd]080/;2`0P2ZZZX2
0:>SX`0309nOW`2KVi/0Vi^K0080UiNG0P2CTi<209:BTP80Shn?0P2:RXX208J6QP80Ph>30P1oOgl2
07alO080NGUi0P1fMWH207AdM080LW9b0P1`L7000`1^KVh0K6a/06a/K00206][J`80JVYZ0P1XJ6P4
06MWI`80IVIV101UIFD406ATI1D0Hf=S101TI6@606EUI@@0IVIV1@1WIfL406QXJ0@0JFUY0P1ZJVX4
06][JaD0oooo000C0?ooo`80L71`0P1dM7@207QhN080O7al0P20P80208B4Q080R8R80P2<S8`00`2@
T900U9BD09BDU00209RHV080W9bL0P2QXJ420:FUY@80ZJVY0P2][Jd20;6a/@80]KFe0P2i^KT20;jn
_P80`/;20P36a/H20<[:bP80c/k>00<0dm?C0=OGe`3GemL00P3Lg=`20>3Ph080iNGU0P3Zj^X20?3`
l080lo?c0P3^k^h20>SXj080h^;R0P3MgMd20=[JfP80fMWI0P3Lg=`20=_Kf`030=OGe`3EeMD0eMGE
00@0eMGE103De=@20=7Ad@80d=3@103>c/h40<g=c@@0c<c<0P3=cLd30<o?c`80dM7A0P3@d=020<o?
c`80c<c<0P39bLT20<S8b080a/K60P34a<@20<71`@80_Kfm0P2h^;P20;Bd]080/;2`0P2ZZZX20:>S
X`0309nOW`2KVi/0Vi^K0080UiNG0P2CTi<209:BTP80Shn?0P2:RXX208J6QP80Ph>30P1oOgl207al
O080NGUi0P1fMWH207AdM080LW9b0P1`L7000`1^KVh0K6a/06a/K00206][J`80JVYZ0P1XJ6P406MW
I`80IVIV101UIFD406ATI1D0Hf=S101TI6@606EUI@@0IVIV1@1WIfL406QXJ0@0JFUY0P1ZJVX406][
JaD0oooo000C0?ooo`80Kfm_0P1cLg<207MgM`80Ng]k0P1oOgl208>3P`80QhN70P2;Rh/00`2>SXh0
TY:B09:BTP0209JFUP80VYZJ0P2NWYh20::RXP80YZJV0P2ZZZX20:j^[P80/[:b0P2f][H20;Zj^P80
_[jn0P32`/820<K6aP80b/[:00<0c/k>0=;BdP3Bd]800P3Fe]H20=_Kf`80h>3P0P3UiND20>[ZjP80
kno_0P3bl_820>k^kP80j>SX0P3Rh^820=oOg`@0g=cL0`3Ng]h20=[JfP@0fMWI0P3Hf=P20=WIf@80
f=SH0P3GemL20=GEe@80dm?C0P3AdM420=;BdP80clo?103@d=030=7Ad@80dm?C0P3EeMD20=CDe080
dM7A0P3?cll20<c<c080bLW90P35aLD20<;2`P80_[jn0P2i^KT20;Bd]080[jn_0P2[Zj/20:JVYP03
0::RXP2NWYh0WYjN0080Vi^K0P2GUiL209BDU080TI6A0P2<S8`208N7Q`80Q8B40P20P80207emO@80
NWYj0P1gMgL207EeM@80Lg=c0P1aLG400`1_Kfl0KVi^06i^KP0206a/K080Jf][0P1YJFT406QXJ080
IfMW101VIVH406EUIAD0I6AT1P1UIFD606IVIPH0IfMW0`1XJ6P406UYJ@@0JVYZ101[Jf/E0?ooo`00
4`3oool206m_K`80Lg=c0P1gMgL207]kN`80Ogmo0P23Ph<208N7Q`80Rh^;00<0SXj>09:BTP2BTY80
0P2FUYH209ZJVP80WYjN0P2RXZ820:JVYP80ZZZZ0P2^[Zh20;:b/P80][Jf0P2j^[X20;jn_P80`/;2
0P36a/H20<[:bP030<k>cP3Bd]80d];B0080e]KF0P3Kfm/20>3Ph080iNGU0P3Zj^X20>o_k`80l_;b
0P3^k^h20>SXj080h^;R0P3Ogml40=cLg0<0g]kN0P3Jf]X40=WIf@80f=SH0P3IfMT20=SHf080emOG
0P3EeMD20=?Cd`80dM7A0P3Bd]820<o?c`@0d=3@0`3AdM420=?Cd`80eMGE0P3De=@20=7Ad@80clo?
0P3<c<`20<W9b@80aLG50P32`/820;jn_P80^KVi0P2d];@20:n_[`80Zj^[0P2VYZH00`2RXZ80WYjN
09jNWP0209^KV`80UiNG0P2DU9@2096AT@80S8b<0P27QhL208B4Q080P8200P1mOGd207YjNP80MgMg
0P1eMGD207=cL`80LG5a00<0Kfm_06i^KP1^KVh00P1/K6`206][J`80JFUY101XJ6P206MWI`@0IVIV
101UIFDE06ATI0H0IFEU1P1VIVH606MWI`<0J6QX101YJFT406YZJP@0Jf][5@3oool001<0oooo0P1_
Kfl207=cL`80MgMg0P1jNWX207inOP80PX:20P25QHD208V9R@0308f=S@2@T900T92@0080U9BD0P2H
V9P209bLW080WinO0P2SXj<20:NWY`80Zj^[0P2^[Zh20;:b/P80][Jf0P2j^[X20;jn_P80`/;20P35
aLD00`39bLT0cLg=0<g=c@020=;BdP80e]KF0P3Jf]X20=oOg`80i>CT0P3YjNT20>k^kP80lO7a0P3_
knl20>SXj080h^;R0P3Ng]h20=gMg@80g]kN00<0h>3P0=oOg`3Ogml00P3Ng]h80=cLg0@0gMgM0P3K
fm/40=SHf080eMGE0P3De=@20=?Cd`80e=CD00<0dM7A0=3@d03@d=00103Bd]820=3@d080c/k>0P3<
c<`20<S8b080`l?30P2o_kl20;^k^`80]kNg0P2e]KD20;6a/@80[Jf]0P2YZJT00`2UYJD0XZ:R0::R
XP0209jNWP80VIVI0P2FUYH209>CT`80Shn?0P29RHT208F5Q@80PX:20P1nOWh207]kN`80NGUi0P1f
MWH207AdM080LW9b00<0L71`06m_K`1_Kfl00P1]KFd206a/K080JVYZ101YJFT206QXJ080IfMW1P1V
IVH906EUI@@0I6AT301UIFD606IVIPH0IfMW0`1XJ6P606UYJ@@0JVYZ101[Jf/E0?ooo`004`3oool2
06m_K`80Lg=c0P1gMgL207YjNP80OWin0P22PX8208F5Q@80RHV900<0SHf=092@T02@T9000P2DU9@2
09RHV080W9bL0P2OWil20:>SX`80YjNW0P2[Zj/20:j^[P80/[:b0P2f][H20;Zj^P80_[jn0P32`/82
0<G5a@030<W9b@3=cLd0cLg=0080d];B0P3Fe]H20=[JfP80gmoO0P3Ti>@20>WYj@80k^k^0P3alO42
0>o_k`80j>SX0P3Rh^820=kNgP80gMgM0P3Ng]h00`3Ph>00gmoO0=oOg`020=kNgPP0g=cL103MgMd2
0=_Kf`@0f=SH0P3EeMD20=CDe080dm?C0P3De=@00`3AdM40d=3@0=3@d0040=;BdP80d=3@0P3>c/h2
0<c<c080b<S80P33`l<20;no_`80^k^k0P2g]kL20;Fe]@80/K6a0P2][Jd20:VYZ@030:FUY@2RXZ80
XZ:R0080WYjN0P2IVIT209JFUP80Ti>C0P2?Shl208V9R@80QHF50P22PX8207inOP80Ng]k0P1iNGT2
07IfMP80M7Ad0P1bLW800`1`L700Kfm_06m_K`0206e]K@80K6a/0P1ZJVX406UYJ@80J6QX0P1WIfL6
06IVIPT0IFEU101TI6@<06EUI@H0IVIV1P1WIfL306QXJ0H0JFUY101ZJVX406][JaD0oooo000C0?oo
o`80Kfm_0P1cLg<207IfMP80NWYj0P1mOGd20861P@80Q8B40P28R8P00`2;Rh/0Shn?08n?S`0209:B
TP80UYJF0P2IVIT209fMW@80X:2P0P2TY:@20:NWY`80Zj^[0P2_[jl20;:b/P80][Jf0P2j^[X20;fm
_@80`L7100<0aLG50<W9b@39bLT00P3<c<`20=3@d080e=CD0P3IfMT20=gMg@80h^;R0P3Vi^H20>[Z
jP@0kno_0P3YjNT20>;RhP80g]kN0P3Lg=`00`3Ng]h0h>3P0>3Ph00:0=kNgP80gMgM0P3Ng]h20=oO
g`@0g]kN0P3Kfm/20=SHf0@0e]KF00<0e=CD0=;BdP3Bd]800P3AdM420<o?c`80cLg=0P3;bl/20<S8
b080a<C40P33`l<20;no_`80^k^k0P2h^;P20;Jf]P80/k>c0P2`/;020:f][@030:ZZZP2UYJD0YJFU
0080X:2P0P2KVi/209RHV080UiNG0P2@T90208Z:RP80QXJ60P23Ph<207moO`80O7al0P1jNWX207Mg
M`80MGEe0P1cLg<00`1aLG40L71`071`L00206i^KP80KFe]0P1[Jf/406YZJP80JFUY0P1XJ6P606MW
I`P0IVIV2`1UIFD806IVIPP0IfMW1@1XJ6P406UYJ@H0JVYZ101[Jf/E0?ooo`004`3oool206m_K`80
Lg=c0P1fMWH207YjNP80OGem0P21PH4208B4Q080R8R800<0Rh^;08n?S`2?Shl00P2BTY8209JFUP80
VIVI0P2MWId20:2PX080Y:BT0P2WYjL20:^[Z`80[jn_0P2b/[820;Jf]P80^[Zj0P2m_Kd20<71`@03
0<G5a@39bLT0bLW90080c<c<0P3@d=020=CDe080fMWI0P3MgMd20>;RhP80i^KV0P3Zj^X40>o_k`80
jNWY0P3Rh^820=kNgP80g=cL00<0g]kN0>3Ph03Ph>002P3Ng]h20=gMg@80g]kN0P3Ogml40=kNgP80
fm_K0P3Hf=P40=KFeP030=CDe03Bd]80d];B0080dM7A0P3?cll20<g=c@80bl_;0P38b<P20<C4a080
`l?30P2o_kl20;^k^`80^;Rh0P2f][H20;>c/`80/;2`0P2][Jd00`2ZZZX0YJFU0:FUY@020:2PX080
Vi^K0P2HV9P209NGU`80T92@0P2:RXX208J6QP80Ph>30P1oOgl207alO080NWYj0P1gMgL207EeM@80
Lg=c00<0LG5a071`L01`L7000P1^KVh206e]K@80Jf][101ZJVX206UYJ@80J6QX1P1WIfL806IVIP/0
IFEU201VIVH806MWI`D0J6QX101YJFT606YZJP@0Jf][5@3oool001<0oooo0P1_Kfl2079bLP80MGEe
0P1iNGT207alO080Ogmo0P23Ph<208J6QP0308V9R@2=SHd0SHf=0080T92@0P2CTi<209NGU`80VYZJ
0P2MWId20:6QX@80Y:BT0P2XZ:P20:^[Z`80[Zj^0P2b/[820;Jf]P80^KVi0P2l_;`00`30`<00`l?3
0<?3``020<O7a`80bl_;0P3?cll20=?Cd`80e]KF0P3Kfm/20=oOg`80hn?S0P3WinL20>c/k080kNg]
0P3YjNT20>7Qh@80gMgM00<0fm_K0=cLg03Lg=`01P3Lg=`60=_Kf`@0f][J103Hf=P20=OGe`@0eMGE
0P3De=@00`3Bd]80d=3@0=3@d0020<o?c`80cLg=0P3:b/X20<W9b@80b<S80P34a<@20<?3``80`<30
0P2m_Kd20;Vi^@80^;Rh0P2e]KD20;>c/`80[jn_00<0Zj^[0:NWY`2WYjL00P2RXZ8209jNWP80V9RH
0P2DU9@208n?S`80Rh^;0P27QhL208>3P`80P8200P1mOGd207]kN`80N7Qh0P1fMWH207AdM003079b
LP1`L700L71`0080Kfm_0P1^KVh206a/K080Jf][101ZJVX206UYJ@H0J6QX0P1WIfLC06IVIPP0IfMW
2P1XJ6P506UYJ@H0JVYZ101[Jf/E0?ooo`004`3oool206m_K`80LW9b0P1eMGD207UiN@80O7al0P1o
Ogl208>3P`80QXJ600<0RHV908f=S@2=SHd00P2@T90209>CT`80UiNG0P2JVYX209fMW@80XJ6Q0P2T
Y:@20:RXZ080Zj^[0P2^[Zh20;:b/P80][Jf0P2i^KT20;bl_0030<30`033`l<0`l?30080alO70P3;
bl/20<o?c`80dm?C0P3Fe]H20=_Kf`80gmoO0P3Shn<20>OWi`80k>c/0P3]kNd20>WYj@80hN7Q0P3M
gMd00`3Kfm/0g=cL0=cLg0060=cLg0H0fm_K103Jf]X40=SHf080emOG103EeMD20=CDe0030=;BdP3@
d=00d=3@0080clo?0P3=cLd20<[:bP80bLW90P38b<P20<C4a080`l?30P30`<020;fm_@80^KVi0P2h
^;P20;Fe]@80/k>c0P2_[jl00`2[Zj/0YjNW0:NWY`020::RXP80WYjN0P2HV9P209BDU080Shn?0P2;
Rh/208N7Q`80Ph>30P20P80207emO@80Ng]k0P1hN7P207IfMP80M7Ad00<0LW9b071`L01`L7000P1_
Kfl206i^KP80K6a/0P1[Jf/406YZJP80JFUY1P1XJ6P206MWIa<0IVIV201WIfL:06QXJ0D0JFUY1P1Z
JVX406][JaD0oooo000C0?ooo`80Kfm_0P1bLW8207EeM@80N7Qh0P1kNg/207inOP80PH610P24Q8@0
0`28R8P0Rh^;08^;R`0208j>SP80TI6A0P2DU9@209NGU`80VYZJ0P2NWYh20:6QX@80Y:BT0P2WYjL2
0:ZZZP80[Zj^0P2a/K420;Bd]080^;Rh00<0^k^k0;jn_P2n_[h00P32`/820<G5a@80bLW90P3<c<`2
0=3@d080e=CD0P3Hf=P20=_Kf`80gmoO0P3Shn<20>KViP80jNWY0P3WinL20>3Ph0030=cLg03IfMT0
fMWI0080f=SH2P3GemL40=KFeP@0eMGE0P3De=@20=;BdP@0dM7A00<0clo?0<k>cP3>c/h0103=cLd2
0<W9b@80b<S80P37alL20<C4a080`l?30P31`L420;no_`80^k^k0P2i^KT20;Ng]`80/k>c0P2_[jl0
0`2[Zj/0Z:RX0:RXZ0020:>SX`80WIfM0P2HV9P209>CT`80Shn?0P2;Rh/208N7Q`80Ph>30P20P802
07emO@80Ng]k0P1iNGT207IfMP80M7Ad00<0Lg=c075aL@1aLG400P1`L70206i^KP80KFe]0P1/K6`2
06][J`@0JVYZ101YJFT406QXJ0/0IfMW1P1VIVH806MWI`X0J6QX1@1YJFT606YZJPH0Jf][5@3oool0
01<0oooo0P1_Kfl2079bLP80MGEe0P1hN7P207]kN`80OWin0P21PH4208B4Q00308R8R02;Rh/0Rh^;
0080SXj>0P2ATI4209BDU080UiNG0P2JVYX209jNWP80XJ6Q0P2TY:@20:NWY`80ZZZZ0P2^[Zh20;6a
/@80];Bd0P2h^;P00`2k^k/0_[jn0;jn_P020<;2`P80aLG50P39bLT20<c<c080d=3@0P3De=@20=SH
f080fm_K0P3Ogml20>?Sh`80i^KV0P3YjNT20>OWi`80h>3P00<0g=cL0=WIf@3IfMT00P3Hf=P:0=OG
e`@0e]KF103EeMD20=CDe080d];B103AdM400`3?cll0c/k>0<k>cP040<g=c@80bLW90P38b<P20<O7
a`80a<C40P33`l<20<71`@80_kno0P2k^k/20;Vi^@80]kNg0P2c/k<20:n_[`030:^[Z`2XZ:P0Z:RX
0080Xj>S0P2MWId209RHV080Ti>C0P2?Shl208^;R`80QhN70P23Ph<20820P080OGem0P1kNg/207Ui
N@80MWIf0P1dM7@00`1cLg<0LG5a075aL@02071`L080KVi^0P1]KFd206a/K080Jf][101ZJVX406UY
J@@0J6QX2`1WIfL606IVIPP0IfMW2P1XJ6P506UYJ@H0JVYZ1P1[Jf/E0?ooo`004`3oool206i^KP80
LG5a0P1dM7@207MgM`80NWYj0P1mOGd20820P080Ph>300<0QXJ608V9R@29RHT00P2<S8`208n?S`80
TY:B0P2EUID209RHV080Vi^K0P2NWYh20:6QX@80Y:BT0P2WYjL20:ZZZP80[Jf]0P2`/;020;>c/`03
0;Jf]P2i^KT0^KVi0080_;bl0P30`<020<?3``80a/K60P39bLT20<g=c@80d=3@0P3Cdm<20=OGe`80
f][J0P3MgMd20>3Ph080i>CT0P3Rh^800`3Ph>00f][J0=[JfP020=KFeP@0e=CD0P3Cdm<40=;BdP@0
dM7A1P3@d=020<o?c`80c/k>0P3=cLd00`3<c<`0bl_;0<_;b`060<_;b`80b<S80P36a/H20<G5a@80
a<C40P31`L420<30`080_Kfm0P2i^KT20;Jf]P80/[:b0P2`/;000`2][Jd0YjNW0:NWY`020:6QX@80
Vi^K0P2GUiL209:BTP80SXj>0P2:RXX208J6QP80Ph>30P20P80207emO@80Ng]k0P1iNGT207MgM`80
MGEe00<0Lg=c079bLP1bLW800P1`L70206m_K`80KVi^101/K6`206][J`@0JVYZ101YJFT806QXJ140
IfMW101XJ6P206UYJ@80J6QX2@1YJFT606YZJPH0Jf][5@3oool001<0oooo0P1^KVh2075aL@80M7Ad
0P1gMgL207YjNP80OGem0P20P80208>3P`0308J6QP29RHT0RHV90080S8b<0P2?Shl209:BTP80UIFE
0P2HV9P209^KV`80WYjN0P2QXJ420:BTY080YjNW0P2ZZZX20:f][@80/;2`0P2c/k<00`2f][H0^KVi
0;Vi^@020;bl_080`<300P33`l<20<K6aP80bLW90P3=cLd20=3@d080dm?C0P3GemL20=[JfP80gMgM
0P3Ph>020>CTi080h^;R00<0h>3P0=[JfP3Jf]X00P3Fe]H40=CDe080dm?C103Bd]840=7Ad@H0d=3@
0P3?cll20<k>cP80cLg=00<0c<c<0<_;b`3;bl/01P3;bl/20<S8b080a/K60P35aLD20<C4a080`L71
0P30`<020;fm_@80^KVi0P2f][H20;:b/P80/;2`00<0[Jf]0:NWY`2WYjL00P2QXJ4209^KV`80UiNG
0P2BTY8208j>SP80RXZ:0P26QXH208>3P`80P8200P1mOGd207]kN`80NGUi0P1gMgL207EeM@0307=c
L`1bLW80LW9b0080L71`0P1_Kfl206i^KP@0K6a/0P1[Jf/406YZJP@0JFUY201XJ6PA06MWI`@0J6QX
0P1YJFT206QXJ0T0JFUY1P1ZJVX606][JaD0oooo000C0?ooo`80KVi^0P1aLG4207AdM080MWIf0P1i
NGT207alO080Ogmo0P21PH400`24Q8@0QhN708N7Q`0208Z:RP80S8b<0P2?Shl209:BTP80UIFE0P2G
UiL209ZJVP80WIfM0P2PX:020:>SX`80YZJV0P2YZJT20:^[Z`80[Zj^00<0/K6a0;Bd]02d];@00P2g
]kL20;Zj^P80_Kfm0P30`<020<?3``80a/K60P39bLT20<c<c080clo?0P3Bd]820=CDe080emOG0P3I
fMT20=[JfP<0g=cL0P3Jf]X20=KFeP80d];B0P3?cll20<k>cP80cLg=0P3<c<`20<g=c@80c<c<103=
cLd60<k>cP030<g=c@3;bl/0bl_;00@0b/[:103;bl/20<S8b080aLG50P34a<@20<30`080_Kfm0P2i
^KT20;Rh^080][Jf0P2c/k<20:f][@030:RXZ02SXj<0Xj>S0080WYjN0P2IVIT209FEU@80TI6A0P2<
S8`208V9R@80QXJ60P23Ph<20820P080OGem0P1kNg/207UiN@80MgMg0P1eMGD00`1cLg<0LW9b079b
LP02071`L080Kfm_0P1^KVh206e]K@80K6a/101[Jf/406YZJPP0JFUY1`1XJ6P406MWI`80J6QX1P1W
IfL406QXJ0/0JFUY1P1ZJVX806][JaD0oooo000C0?ooo`80KVi^0P1aLG4207AdM080MWIf0P1iNGT2
07alO080Ogmo0P21PH400`24Q8@0QhN708N7Q`0208Z:RP80S8b<0P2?Shl209:BTP80UIFE0P2GUiL2
09ZJVP80WIfM0P2PX:020:>SX`80YZJV0P2YZJT20:^[Z`80[Zj^00<0/K6a0;Bd]02d];@00P2g]kL2
0;Zj^P80_Kfm0P30`<020<?3``80a/K60P39bLT20<c<c080clo?0P3Bd]820=CDe080emOG0P3IfMT2
0=[JfP<0g=cL0P3Jf]X20=KFeP80d];B0P3?cll20<k>cP80cLg=0P3<c<`20<g=c@80c<c<103=cLd6
0<k>cP030<g=c@3;bl/0bl_;00@0b/[:103;bl/20<S8b080aLG50P34a<@20<30`080_Kfm0P2i^KT2
0;Rh^080][Jf0P2c/k<20:f][@030:RXZ02SXj<0Xj>S0080WYjN0P2IVIT209FEU@80TI6A0P2<S8`2
08V9R@80QXJ60P23Ph<20820P080OGem0P1kNg/207UiN@80MgMg0P1eMGD00`1cLg<0LW9b079bLP02
071`L080Kfm_0P1^KVh206e]K@80K6a/101[Jf/406YZJPP0JFUY1`1XJ6P406MWI`80J6QX1P1WIfL4
06QXJ0/0JFUY1P1ZJVX806][JaD0oooo000C0?ooo`80KVi^0P1aLG4207=cL`80MWIf0P1hN7P207]k
N`80OGem0P20P8000`22PX80QHF508F5Q@0208R8R080RXZ:0P2=SHd208n?S`80TY:B0P2DU9@209NG
U`80VYZJ0P2LW9`209jNWP80XZ:R0P2TY:@20:NWY`80ZZZZ00<0[:b/0:n_[`2_[jl00P2b/[820;Bd
]080]kNg0P2j^[X20;bl_080_kno0P32`/820<G5a@80alO70P3:b/X20<c<c080c/k>0P3@d=020=7A
d@030=;BdP3Cdm<0dm?C0080d];B0P3De=@20=;BdP80d=3@0P3<c<`20<[:bP80bLW91P38b<P20<W9
b@80b/[:103;bl/00`3<c<`0bl_;0<_;b`020<[:bP80b<S81037alL20<G5a@80`L710P2o_kl20;jn
_P80^k^k0P2g]kL20;>c/`80/;2`0P2/[:`20:RXZ0030:BTY02OWil0WinO0080Vi^K0P2FUYH209>C
T`80Shn?0P2;Rh/208R8R080QHF50P22PX8207moO`80OGem0P1kNg/207UiN@80MgMg0P1eMGD00`1d
M7@0LW9b079bLP02075aL@80L71`0P1^KVh206e]K@80K6a/101[Jf/406YZJPH0JFUY4`1XJ6P206MW
I`@0J6QX2P1YJFT706YZJPP0Jf][5@3oool001<0oooo0P1^KVh2075aL@80Lg=c0P1fMWH207QhN080
Ng]k0P1mOGd20820P00308:2PP25QHD0QHF50080R8R80P2:RXX208f=S@80Shn?0P2BTY8209BDU080
UiNG0P2JVYX209bLW080WYjN0P2RXZ820:BTY080YjNW0P2ZZZX00`2/[:`0[jn_0:n_[`020;:b/P80
];Bd0P2g]kL20;Zj^P80_;bl0P2o_kl20<;2`P80aLG50P37alL20<[:bP80c<c<0P3>c/h20=3@d080
dM7A00<0d];B0=?Cd`3Cdm<00P3Bd]820=CDe080d];B0P3@d=020<c<c080b/[:0P39bLT60<S8b080
bLW90P3:b/X40<_;b`030<c<c03;bl/0bl_;0080b/[:0P38b<P40<O7a`80aLG50P31`L420;no_`80
_[jn0P2k^k/20;Ng]`80/k>c0P2`/;020:b/[080Z:RX00<0Y:BT09nOW`2OWil00P2KVi/209JFUP80
Ti>C0P2?Shl208^;R`80R8R80P25QHD208:2PP80Ogmo0P1mOGd207]kN`80NGUi0P1gMgL207EeM@03
07AdM01bLW80LW9b0080LG5a0P1`L70206i^KP80KFe]0P1/K6`406][J`@0JVYZ1P1YJFTC06QXJ080
IfMW101XJ6P:06UYJ@L0JVYZ201[Jf/E0?ooo`004`3oool206i^KP80L71`0P1cLg<207EeM@80MgMg
0P1jNWX207alO080OWin00<0PH6108>3P`23Ph<00P25QHD208R8R080RXZ:0P2<S8`208n?S`80TI6A
0P2DU9@209JFUP80VIVI0P2KVi/209jNWP80X:2P0P2RXZ820:FUY@030:NWY`2ZZZX0ZZZZ0080[:b/
0P2_[jl20;6a/@80];Bd0P2f][H20;Vi^@80^k^k0P2m_Kd20<30`080`/;20P34a<@20<G5a@80alO7
0P38b<P00`39bLT0b/[:0<[:bP040<[:bP80bl_;0P3<c<`20<_;b`80bLW90P38b<P20<O7a`X0aLG5
1`34a<@20<?3``80`/;21031`L420;no_`80_Kfm0P2i^KT20;Jf]P80/[:b0P2^[Zh20:ZZZP80YjNW
0P2TY:@00`2OWil0W9bL09bLW00209RHV080U9BD0P2@T90208f=S@80RXZ:0P27QhL208B4Q080PH61
0P1oOgl207alO080NWYj0P1hN7P207MgM`80MGEe00<0M7Ad079bLP1bLW800P1aLG42071`L080Kfm_
0P1^KVh206e]K@@0K6a/0P1[Jf/406YZJPP0JFUY00<0J6QX06UYJ@1YJFT00P1YJFT206QXJ080JFUY
2P1XJ6P606UYJ@d0JVYZ201[Jf/E0?ooo`004`3oool206i^KP80L71`0P1cLg<207EeM@80MgMg0P1j
NWX207alO080OWin00<0PH6108>3P`23Ph<00P25QHD208R8R080RXZ:0P2<S8`208n?S`80TI6A0P2D
U9@209JFUP80VIVI0P2KVi/209jNWP80X:2P0P2RXZ820:FUY@030:NWY`2ZZZX0ZZZZ0080[:b/0P2_
[jl20;6a/@80];Bd0P2f][H20;Vi^@80^k^k0P2m_Kd20<30`080`/;20P34a<@20<G5a@80alO70P38
b<P00`39bLT0b/[:0<[:bP040<[:bP80bl_;0P3<c<`20<_;b`80bLW90P38b<P20<O7a`X0aLG51`34
a<@20<?3``80`/;21031`L420;no_`80_Kfm0P2i^KT20;Jf]P80/[:b0P2^[Zh20:ZZZP80YjNW0P2T
Y:@00`2OWil0W9bL09bLW00209RHV080U9BD0P2@T90208f=S@80RXZ:0P27QhL208B4Q080PH610P1o
Ogl207alO080NWYj0P1hN7P207MgM`80MGEe00<0M7Ad079bLP1bLW800P1aLG42071`L080Kfm_0P1^
KVh206e]K@@0K6a/0P1[Jf/406YZJPP0JFUY00<0J6QX06UYJ@1YJFT00P1YJFT206QXJ080JFUY2P1X
J6P606UYJ@d0JVYZ201[Jf/E0?ooo`004`3oool206i^KP80L71`0P1bLW8207AdM080MWIf0P1hN7P2
07]kN`80OGem00<0Ogmo0861P@21PH400P23Ph<208F5Q@80R8R80P2:RXX208b<S080SXj>0P2@T902
09>CT`80UIFE0P2GUiL209VIV@80Vi^K0P2NWYh20:2PX0030::RXP2UYJD0YJFU0080YjNW0P2YZJT2
0:^[Z`80[Jf]0P2`/;020;:b/P80];Bd0P2f][H20;Rh^080^[Zj0P2l_;`20;fm_@80_[jn0P2o_kl0
0`30`<00`L710<71`@0:0<;2`PH0`L711030`<020;no_`80`<301@31`L420<30`0@0_kno0P2n_[h2
0;bl_080^[Zj0P2h^;P20;Fe]@80/[:b0P2_[jl20:b/[080Z:RX0P2TY:@20:6QX@80WinO00<0Vi^K
09NGU`2GUiL00P2DU9@2096AT@80SHf=0P2;Rh/208R8R080QHF50P23Ph<20820P080OWin0P1lO7`2
07YjNP80N7Qh0P1fMWH207EeM@0307AdM01bLW80LW9b0080LG5a0P1`L70206m_K`80KVi^0P1]KFd4
06a/K0@0Jf][201ZJVX706UYJ@80J6QX4P1YJFT=06YZJPP0Jf][5@3oool001<0oooo0P1^KVh2071`
L080LW9b0P1dM7@207IfMP80N7Qh0P1kNg/207emO@0307moO`21PH40PH610080Ph>30P25QHD208R8
R080RXZ:0P2<S8`208j>SP80T92@0P2CTi<209FEU@80UiNG0P2IVIT209^KV`80WYjN0P2PX:000`2R
XZ80YJFU0:FUY@020:NWY`80ZJVY0P2[Zj/20:f][@80/;2`0P2b/[820;Bd]080][Jf0P2h^;P20;Zj
^P80_;bl0P2m_Kd20;jn_P80_kno00<0`<300<71`@31`L402P32`/860<71`@@0`<300P2o_kl20<30
`0D0`L710P30`<040;no_`80_[jn0P2l_;`20;Zj^P80^;Rh0P2e]KD20;:b/P80[jn_0P2/[:`20:RX
Z080Y:BT0P2QXJ4209nOW`0309^KV`2GUiL0UiNG0080U9BD0P2ATI4208f=S@80Rh^;0P28R8P208F5
Q@80Ph>30P20P80207inOP80O7al0P1jNWX207QhN080MWIf0P1eMGD00`1dM7@0LW9b079bLP02075a
L@80L71`0P1_Kfl206i^KP80KFe]101/K6`406][J`P0JVYZ1`1YJFT206QXJ180JFUY3@1ZJVX806][
JaD0oooo000C0?ooo`80KVi^0P1_Kfl2075aL@80Lg=c0P1eMGD207MgM`80NGUi0P1kNg/00`1mOGd0
Ogmo07moO`020861P@80Ph>30P25QHD208N7Q`80RHV90P2;Rh/208f=S@80Shn?0P2ATI4209>CT`80
UIFE0P2GUiL209VIV@80Vi^K00<0WIfM09nOW`2OWil00P2QXJ420:>SX`80YJFU0P2WYjL20:VYZ@80
Zj^[0P2][Jd20:n_[`80/K6a0P2b/[820;Bd]080]KFe0P2f][H20;Ng]`030;Rh^02i^KT0^KVi00X0
^[Zj1P2i^KT80;Rh^0D0^KVi0P2h^;P40;Ng]`80]KFe0P2d];@20;:b/P80/;2`0P2][Jd20:^[Z`80
Z:RX0P2UYJD20::RXP80WinO0P2LW9`209ZJVP0309NGU`2DU9@0U9BD0080TI6A0P2>SXh208^;R`80
R8R80P26QXH208>3P`80PH610P1oOgl207emO@80Ng]k0P1iNGT207MgM`80MWIf0P1dM7@00`1cLg<0
LW9b079bLP02075aL@80L71`0P1_Kfl206i^KP@0KFe]0P1/K6`606][J`T0JVYZ501YJFT?06YZJPX0
Jf][5@3oool001<0oooo0P1^KVh206m_K`80LG5a0P1cLg<207EeM@80MgMg0P1iNGT207]kN`0307em
O@1oOgl0Ogmo0080PH610P23Ph<208F5Q@80QhN70P29RHT208^;R`80SHf=0P2?Shl2096AT@80Ti>C
0P2EUID209NGU`80VIVI0P2KVi/00`2MWId0WinO09nOW`020:6QX@80Xj>S0P2UYJD20:NWY`80ZJVY
0P2[Zj/20:f][@80[jn_0P2a/K420;:b/P80];Bd0P2e]KD20;Jf]P80]kNg00<0^;Rh0;Vi^@2i^KT0
2P2j^[X60;Vi^@P0^;Rh1@2i^KT20;Rh^0@0]kNg0P2e]KD20;Bd]080/[:b0P2`/;020:f][@80Zj^[
0P2XZ:P20:FUY@80XZ:R0P2OWil209bLW080VYZJ00<0UiNG09BDU02DU9@00P2ATI4208j>SP80Rh^;
0P28R8P208J6QP80Ph>30P21PH4207moO`80OGem0P1kNg/207UiN@80MgMg0P1fMWH207AdM00307=c
L`1bLW80LW9b0080LG5a0P1`L70206m_K`80KVi^101]KFd206a/K0H0Jf][2@1ZJVXD06UYJ@l0JVYZ
2P1[Jf/E0?ooo`004`3oool206e]K@80Kfm_0P1aLG4207=cL`80M7Ad0P1fMWH207QhN080NWYj00<0
Ng]k07emO@1mOGd00P1oOgl20861P@80Ph>30P24Q8@208J6QP80R8R80P2:RXX208b<S080SHf=0P2?
Shl2096AT@80Ti>C0P2EUID209NGU`0309RHV02JVYX0VYZJ0080W9bL0P2NWYh20:2PX080XJ6Q0P2S
Xj<20:FUY@80YZJV0P2XZ:P20:ZZZP80Zj^[0P2/[:`20:j^[P@0[jn_00<0/;2`0;6a/@2a/K400P2a
/K480;:b/PH0/K6a0P2`/;0:0;6a/@<0/;2`0P2_[jl20:j^[P80[Jf]0P2/[:`20:ZZZP80Z:RX0P2V
YZH20:BTY080XJ6Q0P2OWil209bLW080VYZJ0P2GUiL209FEU@0309>CT`2@T900T92@0080SHf=0P2:
RXX208R8R080QHF50P23Ph<20861P@80Ogmo0P1mOGd207]kN`80NWYj0P1hN7P207IfMP80MGEe0P1d
M7@3079bLP80LG5a0P1`L70206m_K`80KVi^1P1]KFd206a/K0@0Jf][3@1ZJVXB06UYJ@/0JVYZ2P1[
Jf/206a/K1D0oooo000C0?ooo`80KFe]0P1_Kfl2075aL@80Lg=c0P1dM7@207IfMP80N7Qh0P1jNWX0
0`1kNg/0OGem07emO@0207moO`80PH610P23Ph<208B4Q080QXJ60P28R8P208Z:RP80S8b<0P2=SHd2
08n?S`80TI6A0P2CTi<209FEU@80UiNG00<0V9RH09ZJVP2JVYX00P2LW9`209jNWP80X:2P0P2QXJ42
0:>SX`80YJFU0P2VYZH20:RXZ080ZZZZ0P2[Zj/20:b/[080[Zj^102_[jl00`2`/;00/K6a0;6a/@02
0;6a/@P0/[:b1P2a/K420;2`/0X0/K6a0`2`/;020:n_[`80[Zj^0P2][Jd20:b/[080ZZZZ0P2XZ:P2
0:JVYP80Y:BT0P2QXJ4209nOW`80W9bL0P2JVYX209NGU`80UIFE00<0Ti>C092@T02@T9000P2=SHd2
08Z:RP80R8R80P25QHD208>3P`80PH610P1oOgl207emO@80Ng]k0P1jNWX207QhN080MWIf0P1eMGD2
07AdM0<0LW9b0P1aLG42071`L080Kfm_0P1^KVh606e]K@80K6a/101[Jf/=06YZJQ80JFUY2`1ZJVX:
06][J`80K6a/5@3oool001<0oooo0P1]KFd206m_K`80L71`0P1bLW8207=cL`80MGEe0P1gMgL207Qh
N00307YjNP1kNg/0Ng]k0080OGem0P1nOWh20820P080PX:20P23Ph<208F5Q@80QXJ60P28R8P208Z:
RP80Rh^;0P2=SHd208j>SP80T92@0P2BTY800`2CTi<0UIFE09FEU@0209NGU`80V9RH0P2JVYX209^K
V`80WIfM0P2NWYh20:2PX080XJ6Q0P2RXZ820:BTY080YJFU0P2VYZH40:NWY`030:RXZ02YZJT0ZJVY
0080ZJVY1P2ZZZXE0:VYZ@80Z:RX102WYjL20:JVYP80Y:BT0P2SXj<20:6QX@80WinO0P2NWYh209^K
V`80VIVI0P2GUiL209FEU@80TY:B0P2@T9000`2>SXh0S8b<08b<S00208Z:RP80QhN70P25QHD208>3
P`80PH610P1oOgl207emO@80Ng]k0P1jNWX207QhN080MgMg0P1eMGD207AdM080Lg=c00<0LW9b075a
L@1aLG40101`L70206m_K`80KVi^1P1]KFd206a/K0H0Jf][6`1ZJVX206UYJ@T0JVYZ3P1[Jf/E0?oo
o`004`3oool206e]K@80KVi^0P1`L702075aL@80LW9b0P1dM7@207EeM@80MgMg00<0N7Qh07UiN@1i
NGT00P1kNg/207alO080OGem0P1oOgl20820P080PX:20P23Ph<208B4Q080QXJ60P27QhL208V9R@80
RXZ:0P2<S8`208f=S@0308n?S`2@T900T92@0080TI6A0P2CTi<209BDU080UIFE0P2GUiL209RHV080
VIVI0P2JVYX209^KV`@0WIfM0P2NWYh209nOW`<0X:2P102QXJ460::RXP80XJ6Q0P2RXZ8A0:6QX@@0
X:2P0P2OWil209jNWP80WIfM0P2LW9`209ZJVP80VIVI0P2GUiL209FEU@80Ti>C0P2ATI42092@T080
SHf=0P2;Rh/00`2:RXX0R8R808R8R00208J6QP80Q8B40P22PX820820P080Ogmo0P1mOGd207]kN`80
NGUi0P1hN7P207MgM`80MWIf0P1dM7@207=cL`<0LW9b0P1aLG42071`L080Kfm_101^KVh606e]K@@0
K6a/1P1[Jf/Q06YZJPD0Jf][0P1ZJVX:06][JaD0oooo000C0?ooo`80KFe]0P1^KVh2071`L080LG5a
0P1bLW8207AdM080MGEe0P1gMgL00`1hN7P0NGUi07UiN@0207]kN`80O7al0P1mOGd207moO`80P820
0P22PX8208>3P`80Q8B40P26QXH208N7Q`80RHV90P2:RXX208b<S080SHf=00<0Shn?092@T02@T900
0P2ATI4209>CT`80U9BD0P2EUID209NGU`80V9RH0P2IVIT209ZJVP80Vi^K102MWId209jNWP80WinO
0`2PX:040:6QX@H0XZ:R0P2QXJ420::RXQ40XJ6Q102PX:0209nOW`80WYjN0P2MWId209bLW080VYZJ
0P2IVIT209NGU`80UIFE0P2CTi<2096AT@80T92@0P2=SHd208^;R`0308Z:RP28R8P0R8R80080QXJ6
0P24Q8@208:2PP80P8200P1oOgl207emO@80Ng]k0P1iNGT207QhN080MgMg0P1fMWH207AdM080Lg=c
0`1bLW82075aL@80L71`0P1_Kfl406i^KPH0KFe]101/K6`606][Jb40JVYZ1@1[Jf/206YZJPX0Jf][
5@3oool001<0oooo0P1]KFd206i^KP80Kfm_0P1`L702075aL@80Lg=c0P1dM7@207EeM@0307IfMP1g
MgL0MgMg0080NGUi0P1jNWX207]kN`80O7al0P1mOGd207inOP80P8200P21PH4208:2PP80Ph>30P25
QHD208J6QP80QhN70P28R8P00`2:RXX0Rh^;08^;R`0208b<S080SHf=0P2>SXh208n?S`80T92@0P2A
TI4209>CT`@0U9BD0P2EUID209JFUP80UiNG102HV9P509VIV@`0VYZJ0P2IVIT209ZJVP/0VIVI102H
V9P409NGU`80UYJF0P2EUID209>CT`80TY:B0P2ATI4208n?S`80SHf=0P2<S8`208Z:RP80RHV90P27
QhL00`25QHD0Q8B408B4Q00208:2PP80PH610P1oOgl207emO@80O7al0P1kNg/207YjNP80N7Qh0P1g
MgL207EeM@80M7Ad101cLg<2079bLP03075aL@1`L700L71`00@0Kfm_101^KVh206e]K@P0K6a/2`1[
Jf/H06YZJQD0Jf][5@3oool001<0oooo0P1]KFd206i^KP80Kfm_0P1`L702075aL@80Lg=c0P1dM7@2
07EeM@0307IfMP1gMgL0MgMg0080NGUi0P1jNWX207]kN`80O7al0P1mOGd207inOP80P8200P21PH42
08:2PP80Ph>30P25QHD208J6QP80QhN70P28R8P00`2:RXX0Rh^;08^;R`0208b<S080SHf=0P2>SXh2
08n?S`80T92@0P2ATI4209>CT`@0U9BD0P2EUID209JFUP80UiNG102HV9P509VIV@`0VYZJ0P2IVIT2
09ZJVP/0VIVI102HV9P409NGU`80UYJF0P2EUID209>CT`80TY:B0P2ATI4208n?S`80SHf=0P2<S8`2
08Z:RP80RHV90P27QhL00`25QHD0Q8B408B4Q00208:2PP80PH610P1oOgl207emO@80O7al0P1kNg/2
07YjNP80N7Qh0P1gMgL207EeM@80M7Ad101cLg<2079bLP03075aL@1`L700L71`00@0Kfm_101^KVh2
06e]K@P0K6a/2`1[Jf/H06YZJQD0Jf][5@3oool001<0oooo0P1]KFd406i^KP80Kfm_0P1`L702075a
L@80LW9b0P1cLg<00`1dM7@0MGEe07EeM@0207IfMP80MgMg0P1hN7P207UiN@80NWYj0P1kNg/207al
O080OGem0P1nOWh207moO`80P8200P21PH4208:2PP80Q8B40`25QHD208J6QP80QhN70P28R8P208V9
R@80RXZ:0P2;Rh/208b<S080SHf=102>SXh208n?S`H0T92@0`2ATI4D09:BTP/0TI6A102@T90408n?
S`80SXj>102<S8`208^;R`80RHV90P28R8P208J6QP80QHF50P24Q8@208>3P`030861P@20P800P820
0080OWin0P1mOGd207alO0@0NWYj0P1hN7P207MgM`80MWIf0P1eMGD207AdM080Lg=c0P1bLW84075a
L@03071`L01_Kfl0Kfm_0080Kfm_1P1^KVh206e]K@P0K6a/201[Jf/206YZJP<0Jf][0P1ZJVX206][
J`P0JVYZ0P1[Jf/806YZJQ40Jf][101/K6`E0?ooo`004`3oool206e]K@@0KVi^0P1_Kfl2071`L080
LG5a0P1bLW8207=cL`0307AdM01eMGD0MGEe0080MWIf0P1gMgL207QhN080NGUi0P1jNWX207]kN`80
O7al0P1mOGd207inOP80Ogmo0P20P8020861P@80PX:20P24Q8@308F5Q@80QXJ60P27QhL208R8R080
RHV90P2:RXX208^;R`80S8b<0P2=SHd408j>SP80Shn?1P2@T903096ATA@0TY:B2`2ATI44092@T0@0
Shn?0P2>SXh408b<S080Rh^;0P29RHT208R8R080QXJ60P25QHD208B4Q080Ph>300<0PH610820P020
P8000P1nOWh207emO@80O7al101jNWX207QhN080MgMg0P1fMWH207EeM@80M7Ad0P1cLg<2079bLP@0
LG5a00<0L71`06m_K`1_Kfl00P1_Kfl606i^KP80KFe]201/K6`806][J`80JVYZ0`1[Jf/206YZJP80
Jf][201ZJVX206][J`P0JVYZ4@1[Jf/406a/K1D0oooo000C0?ooo`80K6a/0P1]KFd206i^KP@0Kfm_
0P1`L702075aL@80LW9b0`1cLg<207AdM080MGEe0P1fMWH407MgM`80N7Qh0P1iNGT207YjNP@0Ng]k
0P1lO7`207emO@80OWin0`1oOgl20820P080PH610P22PX8408>3P`80Q8B41025QHD208J6QP@0QhN7
1028R8P708V9R@H0RXZ:102;Rh/B08Z:RPL0RHV91028R8P208N7Q`80QXJ60P25QHD208B4Q0@0Ph>3
0P21PH420820P080Ogmo0P1nOWh00`1mOGd0O7al07alO00207]kN`80NWYj0P1iNGT407MgM`80MWIf
0P1eMGD207AdM080Lg=c101bLW82075aL@@0L71`0`1_Kfl606i^KPH0KFe]201/K6`E06][J`80JVYZ
101[Jf/206YZJQ40Jf][0P1/K6`406][J`80K6a/5@3oool001<0oooo0P1/K6`206e]K@80KVi^101_
Kfl2071`L080LG5a0P1bLW8307=cL`80M7Ad0P1eMGD207IfMP@0MgMg0P1hN7P207UiN@80NWYj101k
Ng/207alO080OGem0P1nOWh307moO`80P8200P21PH4208:2PP@0Ph>30P24Q8@408F5Q@80QXJ61027
QhL408R8R0L0RHV91P2:RXX408^;Ra80RXZ:1`29RHT408R8R080QhN70P26QXH208F5Q@80Q8B41023
Ph<20861P@80P8200P1oOgl207inOP0307emO@1lO7`0O7al0080Ng]k0P1jNWX207UiN@@0MgMg0P1f
MWH207EeM@80M7Ad0P1cLg<4079bLP80LG5a101`L70306m_K`H0KVi^1P1]KFd806a/K1D0Jf][0P1Z
JVX406][J`80JVYZ4@1[Jf/206a/K0@0Jf][0P1/K6`E0?ooo`004`3oool206a/K0@0KFe]101^KVh2
06m_K`@0L71`0`1aLG42079bLP@0Lg=c101dM7@207EeM@@0MWIf0P1gMgL407QhN0@0NGUi0`1jNWX2
07]kN`@0O7al101mOGd407inOP@0Ogmo1020P8040861P@T0PX:20P23Ph<408:2PPP0Ph>34@22PX86
0861P@80P820101oOgl207inOP@0OGem0P1lO7`207]kN`80NWYj0P1iNGT307QhN0@0MgMg0P1fMWH2
07EeM@80M7Ad101cLg<2079bLP@0LG5a101`L70506m_K`H0KVi^201]KFd806a/K2`0Jf][0P1/K6`4
06][J`@0K6a/5@3oool001<0oooo0P1/K6`406e]K@@0KVi^0P1_Kfl4071`L0<0LG5a0P1bLW8407=c
L`@0M7Ad0P1eMGD407IfMP80MgMg101hN7P407UiN@<0NWYj0P1kNg/407alO0@0OGem101nOWh407mo
O`@0P8201021PH4908:2PP80Ph>31022PX8808>3Pa40PX:21P21PH420820P0@0Ogmo0P1nOWh407em
O@80O7al0P1kNg/207YjNP80NGUi0`1hN7P407MgM`80MWIf0P1eMGD207AdM0@0Lg=c0P1bLW84075a
L@@0L71`1@1_Kfl606i^KPP0KFe]201/K6`/06][J`80K6a/101[Jf/406a/K1D0oooo000C0?ooo`@0
K6a/101]KFd606i^KPD0Kfm_101`L706075aL@@0LW9b101cLg<407AdM0L0MGEe101fMWH607MgM`@0
N7Qh2P1iNGT607YjNP0307]kN`1jNWX0NWYj0080NWYj5P1kNg/707YjNP80Ng]k0P1jNWX807UiN@H0
N7Qh0P1gMgL407IfMP@0MGEe00<0M7Ad07=cL`1cLg<00P1cLg<6079bLPH0LG5a0P1`L70406m_K`H0
KVi^3`1]KFd406a/K0@0Jf][101/K6`406][J`80K6a/:P1[Jf/406a/K1D0oooo000C0?ooo`@0K6a/
101]KFd606i^KPD0Kfm_101`L706075aL@@0LW9b101cLg<407AdM0L0MGEe101fMWH607MgM`@0N7Qh
2P1iNGT607YjNP0307]kN`1jNWX0NWYj0080NWYj5P1kNg/707YjNP80Ng]k0P1jNWX807UiN@H0N7Qh
0P1gMgL407IfMP@0MGEe00<0M7Ad07=cL`1cLg<00P1cLg<6079bLPH0LG5a0P1`L70406m_K`H0KVi^
3`1]KFd406a/K0@0Jf][101/K6`406][J`80K6a/:P1[Jf/406a/K1D0oooo000C0?ooo`P0K6a/2@1]
KFd:06i^KPX0Kfm_1P1`L70?075aL@h0LW9b4@1cLg<207AdM1/0Lg=c301bLW86075aL@D0L71`3P1_
Kfl606i^KPP0KFe]5@1/K6`206][J`@0K6a/4@1[Jf/206a/K0`0Jf][0P1/K6`406][J`0306a/K01[
Jf/0Jf][00P0Jf][101/K6`E0?ooo`004`3oool806a/K0T0KFe]2P1^KVh:06m_K`H0L71`3`1aLG4>
079bLQ40Lg=c0P1dM7@K07=cL``0LW9b1P1aLG45071`L0h0Kfm_1P1^KVh806e]KAD0K6a/0P1[Jf/4
06a/K140Jf][0P1/K6`<06][J`80K6a/101[Jf/00`1/K6`0Jf][06][J`0806][J`@0K6a/5@3oool0
0?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool0
0?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool0
09P0oooo0T0000260?ooo`00VP3oool00d000000oooo0?ooo`230?ooo`00NP3oool5@0000080oooo
00=000000?ooo`3oool00P3oool00d000000oooo0?ooo`050?ooo`=000000P3oool2@00000<0oooo
0d0000050?ooo`03@000003oool0oooo07d0oooo001l0?ooo`07@000003oool0oooo0?oood000000
oooo@00000020?ooo`03@000003ooom0000000D0oooo00I000000?ooo`3ooom000000?oood000004
0?ooo`04@000003oool0oooo@00008D0oooo001l0?ooo`07@000003oool0oooo0?oood000000oooo
@00000020?ooo`03@000003ooom0000000D0oooo00E000000?ooo`3ooom000000?ooo`03@0000080
oooo00A000000?ooo`3ooom00000Q@3oool007`0oooo00=000000?ooo`3oool00P3oool01d000000
oooo0?ooo`3ooom000000?oood0000001P3oool3@00000040?oood0000100000@00000<0oooo0d00
00250?ooo`00O03oool01d000000oooo0?ooo`3ooom000000?oood0000000P3oool00d000000oooo
@00000080?ooo`03@000003oool0oooo08d0oooo001k0?ooo`900000103oool00d000000oooo0?oo
o`020?ooo`03@000003oool0oooo00H0oooo0T00002?0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?oo
o`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?oo
o`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.0250052, -0.0250052, 
  0.00365857, 0.00365857}, {{6.8125, 280.125}, {280.125, 
  6.8125}} -> {-10.161, -6.11446, 0.516914, 0.516914}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0238095 0.952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0238095 0.97619 0.97619 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00751202 0.0192308 0.00751202 [
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(240) show
81.000000 12.812500 moveto
(deg) show
99.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(.) show
105.000000 12.812500 moveto
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
128 string
128 128 8 [128 0 0 128 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
969797979797979797989899999999999999999999999A9D
99999A9A9A9A9A9A9A9A9A9A9A9999999999999999989898
989798979797989898989898989898979798989797979797
979797979797979797979696969899969696969696969595
959595959595959594959495959595959595959494949494
9395969393949596
979797979898989999999A9B9B9B9B9B9C9C9C9C9C9C9DA0
9D9D9E9E9E9E9E9E9D9D9D9D9D9C9C9B9B9B9B9B9B9A9A9A
999999999899999999999999999999989899999899999998
989898989898989797979796969899979696969695959595
949494949394939393939393939393939392929191919191
9193939291929495
979797989899999A9A9B9C9C9D9E9E9E9E9F9F9F9F9FA0A2
A2A0A1A2A2A2A2A1A1A1A1A0A0A09F9E9D9D9D9D9C9C9B9B
9B9B9A9A9A9A9A9A9A9A9A9A9A9A9A99999999999A9A9A99
999999999998989898979797979798979796969595949494
9393939292929292919191919191919191908F8F8F8E8E8F
909191908F919395
9797989899999A9B9B9C9D9E9F9FA0A0A1A1A1A2A2A2A3A3
A6A4A4A5A6A6A6A5A5A5A4A4A3A3A2A1A0A09F9F9E9D9D9C
9C9C9B9B9B9B9B9B9B9B9B9B9B9B9A9A9A9B9B9A9B9B9B9A
9A9A9A9A9999999898989897979797979896959594949493
9392929191919090908F8F8F8F8F8F8F8E8D8C8C8C8C8D8D
8E8F8F8F8E8F9294
97979899999A9B9C9C9D9E9FA0A1A2A3A3A4A4A4A5A5A5A6
A8A9A8A9A9AAAAA9A9A8A8A7A7A6A5A4A3A2A1A0A09E9E9D
9D9D9D9C9C9C9C9D9C9C9C9C9C9C9B9B9C9C9C9B9C9C9C9B
9B9B9B9A9A9A999999989898989797969798959494949393
9292919090908F8F8E8E8D8D8D8D8D8D8C8B8989898B8B8B
8D8C8E8D8C8E9194
979898999A9B9C9D9D9E9FA0A1A2A3A4A5A6A7A7A7A8A8A9
AAACACADADAEAEAEADACACABAAA9A8A7A5A4A3A2A19F9F9E
9E9E9E9E9E9E9E9E9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D
9C9C9C9B9B9B9A9A99999998989797969696959494939393
9291908F8F8F8E8E8D8D8C8C8C8B8B8A898886868889898A
8A8A8C8B8B8E9194
9798999A9B9B9D9D9F9FA1A2A2A4A5A6A7A8A9AAAAABABAC
ADAFB0B1B2B2B2B2B1B1B0AFAEACABA9A8A6A5A3A2A0A09F
9F9F9F9F9F9F9F9F9F9E9E9E9E9E9E9E9E9E9E9E9E9E9E9E
9D9D9D9C9C9B9B9B9A9A9998989797969695959494939392
9190908F8E8E8D8C8C8B8B8A8A8A89888785838486878787
88888A898A8D9094
9798999A9B9C9E9EA0A1A2A3A4A5A6A7A9AAABACADADAEAF
B0B2B4B5B7B6B7B6B6B5B4B2B1B0AEACAAA8A6A5A3A2A1A0
A0A0A0A0A0A0A0A0A09F9F9F9F9F9F9F9F9F9F9F9F9F9F9F
9E9E9D9D9D9C9C9B9B9A9999989797969695949494939392
91908F8E8D8D8C8B8A8A8989888786858381818384848485
85868787898D9093
9798999A9C9D9E9FA1A2A3A4A5A7A8A9AAACADAEAFB0B1B2
B3B5B7B9BBBBBBBBBAB9B8B6B4B3B0AEACA9A7A6A5A3A2A1
A0A0A0A1A1A1A1A1A1A0A0A0A0A0A0A0A0A1A0A0A1A0A0A0
9F9F9E9E9D9D9C9C9B9A9998989797969695949494939392
918F8E8D8C8C8B8A8989888786848281807F7F8081818182
83858585888C8F93
97999A9B9C9E9FA0A2A3A4A6A7A8A9ABACAEAFB0B2B3B4B6
B7B9BBBCBEC0C1C1BFBEBCBAB8B5B3B0AEABA9A7A6A4A3A2
A1A1A1A1A2A2A2A2A2A1A1A1A1A1A1A1A1A1A1A1A1A1A0A0
A09F9E9E9D9D9C9B9B9A9998989797969695949493929291
90908D8C8B8B8A8988888684827F7E7D7D7C7C7D7E7E7F7F
81838285878B8F93
98999A9C9D9EA0A1A3A4A5A7A8AAABADAEAFB1B2B4B5B7B9
BABCBEC0C2C4C6C6C3C3C1BEBBB8B6B2B0ADAAA8A7A5A4A2
A2A2A2A2A2A3A3A3A3A3A2A2A2A2A2A2A3A3A3A2A2A2A1A1
A1A09F9F9E9D9D9C9B9A9999989797969694949392929190
908F8B8C8B8A89888684827F7D7B7A7A79787A7A7B7C7B7C
7F808183878B8E92
98999A9C9E9FA0A2A3A5A6A8A9ABADAEB0B1B3B5B6B8BABC
BEC0C1C4C6C8CBCAC9C7C5C3BFBBB8B4B2AEABA9A7A6A4A3
A3A3A3A3A3A3A4A4A4A4A3A3A3A3A3A4A4A4A4A3A3A3A2A2
A2A1A0A09F9E9D9C9C9A9A99989897969694949392919090
8F8D8B8B8A88878582807E7B79787676757578777879787A
7C7D8082868A8E92
98999B9D9E9FA1A3A4A6A8A9ABADAEB0B2B4B5B7B9BBBDBF
C1C3C5C7C9CCCECECFCDCAC8C3BEBAB6B3AFADAAA8A6A5A3
A3A3A3A3A4A4A4A5A5A5A4A4A5A5A5A5A5A5A5A5A4A4A3A3
A3A2A1A1A09F9E9D9C9B9A9999989796969594939291908F
8E8D8B8A888684807D7C7977757473727272757474767578
7A7B7E82868A8E92
989A9B9D9FA0A2A3A5A7A9AAACAEB0B2B4B6B8B9BBBDBFC2
C4C6C8CACDCFD1D2D3D3CFCDC8C2BCB8B4B0ADAAA8A7A5A4
A4A4A4A4A4A5A5A5A5A6A6A6A6A6A6A6A6A6A6A6A6A5A5A4
A4A3A3A2A1A09F9E9D9B9A9A999897969695949292918F8E
8D8B8A8885827E7C7978757372706F6F6F70717171727376
77797D8185898E92
989A9C9D9FA1A3A4A6A8AAACAEB0B2B3B6B8BABCBDC0C2C4
C7C9CBCDD0D2D5D6D8D8D5D1CDC7BFB9B4B1ADAAA8A7A5A4
A4A4A4A5A5A5A6A6A6A7A7A7A7A7A7A7A7A7A7A7A7A7A6A5
A5A4A3A2A1A1A09E9D9C9B9A999897969595939291908E8D
8B8987847F7C7A77757472706E6D6C6C6C6D6D6D6E6F7273
75787D8185898D92
989A9C9EA0A1A3A5A7A9ABADAFB1B3B5B7BABBBEC0C2C4C7
C9CCCED1D3D6D8D9DCDCDAD5D1CBC4BBB4B1ADAAA8A6A5A4
A4A4A5A5A6A6A6A7A7A8A8A8A8A8A8A8A8A8A8A8A8A8A7A7
A6A5A4A3A2A2A09F9E9C9B9A9998979695959392918F8D8B
8987837E7A78777371706E6D6C6B69696969696B6B6E7071
74787C8084898D92
989A9C9EA0A2A4A6A8AAACAEB1B3B5B7B9BBBDC0C2C4C7C9
CCCED1D4D6D9DBDDDFE0DED9D4CEC7BFB6B0ACA9A7A6A4A4
A4A5A5A5A6A6A7A7A8A9A9A9A9A9A9A9A9A9A9A9A9A9A9A8
A7A6A5A5A3A2A1A09E9D9B9A9A98979695949391908D8B89
86827D787674726F6D6C6B6A6968666666666668696C6E70
73787B7F84898D92
989A9C9EA0A3A5A7A9ABADB0B2B4B6B8BBBDBFC2C4C7C9CC
CFD1D4D6D9DCDFE1E2E4E1DCD8D1C9C2BAB1AAA8A5A4A4A3
A4A5A5A6A6A7A8A8A9A9AAAAAAAAABABABABABAAAAAAAAA9
A8A8A7A6A4A3A2A09F9D9C9B9A989795949391908E8C8885
817C777472706E6B6A696866656463626363646667696C6F
73777B7F84888D92
989A9D9FA1A3A5A8AAACAFB1B3B5B8BABCBFC1C4C6C9CCCE
D1D4D6D9DCDFE2E4E5E7E3DFDAD3CCC5BDB4AAA4A4A3A3A3
A4A4A5A6A7A7A8A9AAAAABABABACACACACACACACACABABAA
A9A9A8A7A5A4A3A19F9E9C9B9A9896959391908E8C88857F
7B7773716F6C6A6867666462616060606060626465676B6E
72767B7F84898D92
999B9D9FA2A4A6A8ABADB0B2B4B7B9BCBEC1C3C6C8CBCED1
D3D6D9DCDFE2E5E7E8E9E5E1DBD5CEC7BEB5ABA2A2A1A2A2
A3A4A5A6A7A8A9AAABABACACACADADADADADADADADACACAB
ABAAA9A8A6A5A3A19F9E9D9B99979593928F8E8B89837F7A
76726F6D6B6966646362615F5E5E5D5D5D5E60616366696D
72767B7F84898D92
999B9EA0A2A4A7A9ACAEB1B3B6B8BBBDC0C3C5C8CACDD0D3
D6D9DCDFE2E5E8EAECEBE7E3DDD6CFC8BFB6ACA3A0A0A1A2
A3A4A5A7A8A9AAABABACADADAEAEAEAEAEAEAEAEAEADADAC
ACABAAA9A7A5A3A19F9E9D9B98969492908D8A87837E7A76
726E6C6A68656362605F5E5C5B5B5A5A5B5C5E5F6265696D
72767A7F84888D92
999C9EA0A3A5A7AAADAFB2B4B7BABCBFC1C4C7CACCCFD2D5
D8DBDEE2E5E8EBEDEEEDE8E4DDD7D0C8C0B6ADA59D9EA0A1
A3A4A6A7A8A9ABACACADAEAEAFAFAFAFB0B0AFAFAFAFAEAD
ADACABAAA8A6A3A1A09F9D99979592908D8886827E7A7672
6E6B686764625F5E5C5B5A5958575758595A5C5E6165686D
72767A7F84888D92
999C9EA1A3A6A8ABAEB0B3B5B8BBBEC0C3C6C9CCCED1D4D7
DADEE1E4E7EBEDF0F0EEE9E4DED8D1C8BFB7AFA69B9D9FA1
A3A5A6A8A9AAACACADAEAFAFB0B0B0B0B1B1B1B1B0AFAFAE
AEADACABA9A6A3A1A19F9C989693908D8884817E7A76726F
6A676563615E5C5B595957565554545557585A5D6164686D
71767A7F84888D92
999C9EA1A3A6A9ACAEB1B4B6B9BCBFC2C5C8CBCDD0D3D6D9
DDE0E3E6EAEDF0F2F1EFEAE5DED8D1C8BFB8AFA69A9D9FA1
A3A5A6A8AAABACADAEAFB0B0B1B1B2B2B2B2B2B2B1B1B0AF
AFAEADABA9A6A3A2A19E9A9794918D88837F7C7976726E6B
6764625F5D5B595957555452515151535456595D6064686D
71767B7F84888D92
999C9FA2A4A7AAACAFB2B5B7BBBEC1C3C6C9CCCFD2D5D9DC
DFE2E5E9ECF0F2F4F2EFEBE5DFD8D0C7C0B9AFA59A9D9FA1
A3A5A7A9AAACADAEB0B0B1B2B2B2B3B3B3B3B3B3B2B2B1B0
B0AFADACA9A6A4A3A09C9995928D89847F7A7875726E6B68
64625E5C595857565452514F4E4E4F515255585C6064686C
71767B7F84888D92
999C9FA2A5A8AAADB0B3B6B9BCBFC2C5C8CBCED1D4D7DBDE
E1E4E8EBEEF2F5F5F3EFEBE5DED8CFC8C1B9AEA49A9C9FA1
A3A5A7A9ABACAEAFB0B1B2B3B3B4B4B4B4B3B4B3B3B2B2B1
B0AFAEACA9A6A5A29E9A97938E8985807A7673716E6B6865
625F5B5956555453514F4E4C4B4C4D4F5155585B5F63686C
71767B7F84888D92
999C9FA2A5A8ABAEB1B4B7BABDC0C3C6C9CCD0D3D6D9DDE0
E3E6EAEDF1F4F7F6F3F0EBE4DED7CFC8C0B7ADA49A9C9FA1
A3A6A8AAACADAFB0B1B2B3B4B4B4B5B5B4B4B4B4B4B3B2B2
B0AFAEACA9A7A4A19D9994908B86817B76726F6D6A686563
5F5C5855535251504E4D4B4949494B4D5054575B5F63686C
71767A7F84888D92
9A9DA0A3A6A9ABAFB2B5B8BBBEC1C4C8CBCED1D4D7DBDEE2
E5E8ECEFF3F6F8F6F4EFEAE3DDD6CEC7C0B6ACA3999C9EA1
A3A6A8AAACAEAFB1B2B3B4B5B5B6B6B6B5B5B5B5B4B4B3B2
B1B0AEABA9A7A39F9B96928D88827C77726E6B6866646361
5D595553514F4E4D4C4A48464647494C4F53575B5F63686C
71767A7F84888D92
9A9DA0A3A6A9ACAFB2B5B9BCBFC2C6C9CCCFD3D6D9DDE0E3
E7EAEEF1F5F8F9F7F3EFE9E2DCD4CEC7BFB5ABA2999C9EA1
A4A6A9ABADAFB0B2B3B4B5B6B6B7B7B6B6B6B6B5B5B4B3B3
B1AFADABA9A6A29D99948F8B847E78736F6B676463615F5E
5A5653504E4C4C4B494745434445484B4F52565A5F63686C
71767A7F84888D92
9A9DA0A3A7AAADB0B3B6BABDC0C4C7CACED1D4D7DBDEE2E5
E9ECF0F3F7F9F9F7F3EEE8E1DBD3CDC5BCB2A9A1989C9EA1
A4A7A9ABADAFB1B2B4B5B6B7B7B7B8B7B7B7B6B6B6B5B4B3
B1AFADAAA8A59F9B97928D88817973706C6864615F5D5C5B
5854514E4C494948464442404244474A4E51565A5F63676C
71767A7F84888D92
9A9DA0A4A7AAADB1B4B7BBBEC1C5C8CCCFD2D6D9DCE0E4E7
EBEEF2F5F9FAF9F7F2EDE6E0D9D2CBC2B9B0A8A0989B9EA1
A4A7A9ABADAFB1B2B4B5B7B7B8B8B8B8B8B7B7B6B6B5B4B3
B1AFACA9A7A39D9995908A837C75706D6965615D5B5A5958
5552504C4947474543403F3E404346494D51555A5E63676C
71767A7F84888D92
9A9DA1A4A7AAAEB1B5B8BCBFC2C6C9CDD0D4D7DBDEE2E5E9
EDF0F3F7FAFAF9F6F0EBE4DDD7D0C9BFB6AEA69E989B9FA2
A5A7AAACAEB0B1B3B4B6B7B8B9B9B9B9B8B8B8B7B6B5B4B3
B1AEABA8A6A19B97948D867E79726D6A67635F5A58565655
53514E4A46454442403E3D3C3F4345494D51555A5E63676C
71757A7F84888D92
9A9DA1A4A8ABAFB2B5B9BCC0C4C7CACED2D5D9DCDFE3E7EB
EEF2F5F9FBFAF8F4EFE9E2DBD5CDC6BBB3ABA39B999CA0A3
A6A8ABADAFB0B2B3B5B6B7B8B9B9BAB9B9B9B8B7B7B5B4B2
B1AEAAA6A39E9996918A827A766F6A6764605C5755535252
514F4D484443413F3D3C3B3B3F4245484C51555A5E63676C
71757A7F84888D92
9A9EA1A4A8ACAFB3B6BABDC1C5C8CCCFD3D6DADEE1E5E9EC
F0F3F7FAFBFAF7F3EDE7DFD9D1CBC1B7AFA79F9B9B9EA2A5
A7AAACAEAFB1B3B4B5B6B7B8B9B9BABABAB9B9B8B7B6B4B3
B0ADAAA59F9B96958F887F77736D6864625D595552504F4F
4F4E4A4642413E3C3B3A383A3E4044484C50555A5E63676C
71757A7F84888D92
9A9EA1A5A8ACB0B3B7BBBEC2C6C9CDD1D4D8DCDFE3E7EAEE
F2F5F8FBFCF9F6F1EBE4DDD6CEC7BCB3ABA29E9D9FA1A4A7
A9ABADAFB0B2B3B4B5B6B7B8B9B9BABABBBAB9B9B7B6B4B3
B0ADA9A39B9993928C857D746F6C65625F5B5753504E4C4D
4D4C4844413E3B3A3938373A3D3F43474C5055595E63676C
71757A7F83888D92
9A9EA1A5A9ACB0B4B8BBBFC3C7CBCED2D6D9DDE1E4E8ECF0
F3F7FAFBFBF8F4EFE8E1DAD2CBC2B7AFA69FA0A1A2A4A7A9
ABADAFB0B2B3B4B5B5B7B7B8B8B9BABABABBBAB9B8B7B5B3
B0ACA8A19996908E8A827A726C6964605D5955524E4C4A4A
4A4A47423F3C3938373636383B3F43474C5055595E63676C
71757A7F83888D92
9A9EA2A5A9ADB1B5B8BCC0C4C8CBCFD3D7DBDEE2E6EAEEF2
F5F8FBFBFAF7F2ECE6DED6CEC7BCB3AAA3A1A3A4A6A7A9AB
ADAFB0B1B3B4B4B5B5B6B7B7B8B8B9B9BABABABAB9B7B5B3
B0ACA6A097928F8A877F78706C67645F5B5854504D4A4847
474845403D393736353434373B3E43474B5055595E62676C
70757A7F83888D92
9A9EA2A6AAAEB2B5B9BDC1C5C9CDD0D4D8DCE0E3E7EBEFF3
F6F9FBFCF9F5F0EAE2DAD3CAC1B6AEA6A3A4A5A7A9AAACAE
AFB0B1B2B4B5B5B5B5B6B6B7B7B8B8B9B9BABABAB9B8B6B3
B0ACA69F958F8D87827E76706B65625E5A56534E4B484644
4444433F3B383633323233373A3E42464B5054595E62676C
70757A7F83888D92
9A9EA2A6AAAEB2B6BABEC2C6CACED1D5D9DDE1E5E9EDF1F5
F8FAFBFBF8F3EDE6DED6CFC5BBB1A8A5A6A7A8AAABADAFB0
B1B2B3B4B4B5B5B5B5B5B5B5B6B6B7B8B8B9B9B9B9B8B6B4
B0ABA69E958D89847F7A74706B65605D5956524D49464442
4141413D39363431303033363A3E42464B5054595D62676C
70757A7F83888D92
9A9EA2A6AAAFB2B6BBBFC3C6CACFD3D7DBDFE3E6EAEEF2F6
F9FAFBFAF6F0EAE3DAD2CABFB5ABA6A7A8A9ABADAEB0B1B2
B2B3B4B4B5B5B5B5B5B4B4B4B4B5B5B7B7B8B8B9B8B8B7B5
B1ACA69E958C85827E77736E6A645F5C5855504C47454240
3F3E3E3B3835322F2F2F32353A3D42464B4F54595D62676B
70757A7E83888D92
9B9FA2A7ABAFB3B7BBBFC4C7CCD0D4D8DCE0E4E8ECF0F4F8
FAFBFBF9F4EDE6DFD6CEC4BAB0A7A8A9AAABADAFB1B3B3B2
B3B3B4B4B5B5B5B5B4B3B2B2B2B3B4B5B6B7B8B8B8B7B6B5
B2ADA79F958B847F7B75716D68645F5B5754504B4644413E
3C3B3B3A3634312E2D2E3135393D41464B4F54585D62676B
70757A7E83888D92
9B9FA3A7ABAFB3B8BCC0C4C8CDD1D5D9DDE2E5EAEEF2F6F9
FBFBFBF7F1EAE2DBD1C8BEB4AAA6A8AAABADAFB2B3B4B3B1
B3B4B4B4B4B5B5B4B3B2B1B0B0B1B2B4B5B6B7B7B7B7B6B4
B2AEA89F968C847C79756F6C66625F5A56534F4A4642403C
3A38383835322F2C2B2E3135393C41464A4F54585D62676B
70757A7E83888D92
9B9FA3A7ACB0B4B8BDC1C5C9CED2D6DADFE3E7EBEFF3F8FA
FCFCF9F4EEE6DED6CDC3B8AEA7A8A9ABACAFB1B4B4B3B3B2
B3B4B4B4B5B5B4B3B1B1B0AFAEAFB0B2B4B5B6B7B6B6B5B3
B1AEA9A1988C847B78746E6A65605C5A56534E4A45413E3B
3836363633302D2B2A2D3034383C41454A4F53585D62666B
70757A7E83888D92
9B9FA3A7ACB0B4B9BDC1C6CACFD3D7DCE0E4E8EDF1F5F9FB
FCFBF7F2EBE2DAD1C7BCB2A8A7A8AAABADB0B2B4B4B3B2B2
B3B3B3B4B4B4B2B1B0B0AFAEADADAFB1B3B4B5B6B6B5B4B3
B1AEAAA39A8E847C76726E68655E5A5856514E4944403D3A
36343333322E2C29292C3034383C40454A4F53585D62666B
70757A7F83888D92
9B9FA3A8ACB1B5B9BEC2C7CBCFD4D8DDE1E6EAEEF3F7FAFC
FCF9F5EFE7DED5CBC1B6ABA7A8A8AAABADB0B0B3B3B1B1B1
B1B1B1B2B2B2B0AFAEACACACABACAEB0B2B4B4B5B5B5B4B2
B1AEABA59B90857D76716E68635E585654524D48443F3C38
34323130302D2B28282C3033373B40454A4E53585D62666B
70757A7E83888D92
9B9FA4A8ADB1B5BABEC3C7CCD0D5D9DEE3E7ECF0F4F8FBFD
FCF8F2EBE2DAD0C6BBB1A7A7A7A8AAABADAEAFB1B1B0B0B0
B0B0B0B1B0B0AFAEADACACACACADAEB0B2B3B4B4B5B4B3B2
B0AEABA69D92867E76716D69615D565351504B48443F3B37
32312E2E2E2B2926282B2F33363B4045494E53585D61666B
70757A7E83888D92
9B9FA4A8ADB1B6BABFC3C8CDD1D6DBDFE4E9EDF2F6FAFCFD
FBF6EFE7DFD5CBC0B6ABA5A6A7A8A9ABACADAEAFB0B0B1B1
B1B2B1B1B1B1B0AFAEADADADADAEAFB0B2B3B4B4B4B4B3B2
B0AEABA7A094887F77716C68615B55504F4D4A47433E3A36
322E2B2C2C2A2824272B2E32363B4045494E53585D61666B
70757A7E83888D92
9B9FA4A9ADB2B6BBBFC4C9CDD2D7DCE0E5EAEFF3F8FCFDFD
F9F3ECE3DAD0C6BCB1A6A5A6A6A7A9AAABADAEAFB0B0B1B2
B2B3B2B2B2B2B0AFAEADADADAEAEB0B1B2B3B3B4B4B4B3B2
B0AEABA7A1968B8078726C67615A554F4C4A4945423D3934
302C2A292A282623262A2E31363A3F44494E53585D61666B
70757A7E83888D92
9BA0A4A9ADB2B7BCC0C5CACED3D8DDE2E7EBF0F5FAFDFEFB
F7F0E8E0D6CCC1B7ADA3A4A5A5A7A8A9ABACADAFB0B1B1B2
B3B3B3B3B3B2B0AFAFAEADADAEAEAFB1B2B3B3B4B4B3B3B2
B0AEABA8A2998E8279726C66615A544E4A474543413C3933
2F2A28272726232325292D30353A3F44494E53585C61666B
70757A7E83888D92
9BA0A4A9AEB2B7BCC1C6CACFD4D9DEE3E8EDF2F7FBFDFDFA
F4EDE5DCD1C8BDB3A8A0A2A4A5A6A8A9AAACADAEB0B1B2B3
B4B4B4B3B3B2B1AFAEAEADADAEAEAFB1B2B3B3B4B4B3B3B1
B0AEABA8A39B8F847A736C66605B534D474443413F3B3731
2D2927242524212324282C30353A3F44494E53575C61666B
7075797E83888D92
9BA0A5A9AEB3B8BDC1C6CBD0D5DADFE4E9EEF3F8FDFEFCF8
F1E9E1D8CEC3B9AFA3A0A1A3A4A5A7A9AAACADAEB0B1B2B3
B4B4B5B4B3B2B0AFAEADADADADAEAFB1B2B2B3B4B4B3B3B1
B0AEACA8A39C92867C746C665F5A534D4443403D3D393631
2C2825222222202224282B30353A3F44494E53575C61666B
7075797E83888D92
9BA0A5AAAEB3B8BDC2C7CCD1D6DBE0E5EAEFF4FAFEFEFBF5
EEE6DDD4C9BFB6AB9F9FA0A2A3A5A6A8AAABADAEB0B2B3B2
B3B4B5B5B4B2B0B0AEADACACADAEAFB0B2B2B3B3B3B3B2B1
B0AEACA8A49E95887D746C655E59534B44403C3B3A383430
2B262220201F212124262A30353A3F44494E53575C61666B
70757A7E83888D92
9BA0A5AAAFB4B9BEC2C8CCD1D6DBE1E6EBF0F6FBFFFEF9F2
EBE2D9CFC5BCB2A69C9E9FA1A2A5A6A8AAABADAEAFB1B1B1
B3B4B5B5B3B1B0B0AEACACACADAEAFB0B1B2B3B3B3B3B2B1
B0AEACA8A49E978A7E746C645E57524B453C3A393737322F
2924201E1D1E202022252A2F353A3F44494E53575C61666B
70757A7E83888D91
9BA0A5AAAFB4B9BEC3C8CDD2D7DCE1E7ECF1F7FCFFFDF7F0
E7DED5CBC2B9ADA19B9D9FA1A2A4A6A8AAABACAEAFB0B1B1
B3B4B5B5B3B2B0B0AEACABACADAEAFB0B1B2B2B3B3B3B2B1
B0AEACA8A49F988B7F746B645E56514A433938353435312D
28231F1C1B1C1E1E20252A2F353A3F44494E53575C61666B
70757A7E83888D92
9BA0A5AAAFB4B9BEC4C9CED3D8DDE2E8EDF2F8FDFFFBF4ED
E3DBD2C8BFB5A99D9B9C9EA0A2A4A6A8A9ABACADAEB0B0B1
B3B4B5B5B4B2B1B0AEADACACADAEAFB0B1B2B2B3B3B2B2B1
B0AEACA8A49F998D80746C635D5550484138363332322F2B
27221D1A191B1B1D20252A2F353A3F44494E53575C61666B
70757A7E83888D92
9BA0A5AAAFB5BABFC4C9CED3D8DEE3E8EEF3F9FEFFF9F2E9
E0D7CEC5BCB1A5999B9C9EA0A2A4A6A8A9ABACADAEAFB0B1
B3B4B5B5B4B2B1B0AEACACACADAEAFB0B1B1B2B2B2B2B1B0
AFAEABA8A49F998F81756C635C554F4740383331302F2F2A
26201B171719191B20252B30353A3F44494E53585C61666B
70757A7E83888D92
9BA0A5ABB0B5BABFC4C9CFD4D9DEE4E9EFF4FAFFFDF6EFE5
DCD3CBC2B8ACA1979A9C9FA1A3A4A6A8A9ABACADAEAFB0B1
B3B4B5B5B4B2B1AFAEADACADAEAEAFB0B1B1B1B2B2B2B1B0
AFADABA8A49F989082766C635B544D463E36322F2D2D2E29
241E19161517171B20252B30353A3F44494E53585D61666B
70757A7E83888D92
9BA0A6ABB0B5BABFC5CACFD5DADFE4EAEFF5FAFFFBF4EBE1
D9D0C7BFB2A79C989B9D9FA1A3A5A6A8A9ABACADAEAFB0B1
B3B4B5B5B4B2B1AFAEADADAEAEAFAFB0B1B1B1B1B2B1B0AF
AEACAAA8A49E989083776C635B544B453D35302E2C2B2D28
231C18131315161B20252B30353A3F44494E53585D62666B
70757A7E83888D92
9CA1A6ABB0B5BBC0C5CAD0D5DAE0E5EBF0F6FBFEF9F1E7DE
D6CDC4BAAEA09A9A9C9EA0A2A4A6A7A8AAABACADAEAFB0B1
B2B4B5B5B4B2B1B0AFAEAEAEAEAFAFB0B0B1B1B1B1B0B0AF
ADACA9A7A49E979084776D635A534A433C342E2D2B2A2B27
221A16111113161B20262B30353A3F44494E53585D62676B
70757A7E83888D92
9BA1A6ABB0B6BBC0C6CBD0D6DBE0E6EBF1F6FDFCF6EEE3DB
D2C9C0B4A99C9C9C9E9FA1A3A5A7A8A9AAABABACADAEAFB0
B2B3B4B5B4B2B1B0AFAFAEAEAFB0B0B1B1B1B1B0B0AFAFAE
ADABA9A6A39E978F85796E635A524A423A332E2C2B292926
2018130F0F12161B21262B30353A3F44494E53585D62676B
70757A7F83888D92
9BA1A6ABB0B6BBC0C6CBD0D6DBE1E6ECF1F7FDF9F2EAE0D8
CFC5BBB0A49C9D9EA0A1A3A4A6A7A8A9AAABABACADAEAFB0
B1B3B4B5B5B3B2B1B0AFAFAFB0B0B1B1B1B0B0B0AFAFAEAD
ACAAA8A5A29E978F867A6E635A51494239312E2C2A282724
1E16110E0D11161B21262B30353A3F44494E53585D62676B
70757A7F83888D92
9CA1A6ABB1B6BBC1C6CBD1D6DCE1E7ECF2F7FCF6F0E7DDD4
CBC2B6ABA09E9FA0A1A3A4A6A7A8A9AAABABABACACADAEB0
B1B2B4B5B5B4B3B2B1B1B0B0B1B1B1B1B1B1B0AFAFAEADAC
ABA9A7A4A19D978F867B6F645950484139302E2B29272423
1B15100C0C11161B21262B30353A40454A4F53585D62676B
70757A7F83888D92
9CA1A6ABB1B6BCC1C7CCD1D7DCE2E7EDF3F8FAF3EDE4DBD1
C8BEB2A6A0A1A1A2A3A4A6A7A9AAAAABABABABABABACADAF
B0B1B3B5B6B5B4B3B2B2B1B1B2B2B2B2B1B1B0AFAEACACAB
A9A8A6A3A09C978F867C7064594F4840382F2D2B28262221
19130E0B0B11161C21262B30363B40454A4F54595D62676C
70757A7F83888D92
9CA1A6ACB1B6BCC1C7CCD2D7DDE2E8EEF3F9F7F1EAE0D8CF
C5B9AEA4A3A2A2A3A5A6A8A9AAABABACABABAAAAAAABACAD
AFB1B3B5B6B6B5B4B3B2B2B2B3B3B3B3B2B1B0AEACABAAA9
A8A6A5A29F9B968F867D7064594F473F372E2C2A27251E1F
17100C0A0B11161C21262C31363B40454A4F54595E62676C
71757A7F84888D92
9CA1A6ACB1B7BCC1C7CCD2D8DDE3E8EEF3FAF3EFE7DED6CC
C2B5ABA4A4A3A3A5A6A8AAABACACACACACAAA9A8A8A9ABAC
ADB0B2B5B7B7B6B5B4B3B3B3B4B5B5B4B2B1AFADABA9A9A8
A6A5A4A19E9B958F867D7164594E463E362E2B2926231B1C
150D0A090B11161C21272C31363B40454A4F54595E62676C
71757A7F84888D92
9CA1A7ACB1B7BCC2C7CDD2D8DDE3E9EEF3F9F1EDE4DCD3CA
BDB2A9A7A5A4A4A6A8AAACADAEAEAEADACAAA7A7A6A7A9AA
ACAFB2B5B7B7B7B6B5B5B4B5B5B6B6B5B3B0AEACAAA7A6A6
A5A3A2A09D9A958E867C7165594D453D352D2A282420181A
130B09080B11171C22272C31373C41464B4F54595E63676C
71767A7F84888D92
9CA1A7ACB1B7BCC2C7CDD2D8DEE3E9EFF5F7F1ECE2D9D0C7
B9AFA9A9A6A4A5A7AAACAEAFAEADAEADABA8A5A5A4A5A7A8
AAAEB1B5B7B8B7B7B6B8B6B5B5B6B7B6B2AFADABA8A5A4A4
A3A2A09F9C99948D857C7166594D443B342C2926221E1617
100908080C12171D22272D32373C41464B50555A5E63686C
71767A7F84888D92
9CA1A7ACB2B7BCC2C7CDD3D8DEE4E9EFF5F4F0EAE1D6CDC4
B8ACABA9A6A4A6A8ABAEB0AFACACAFADAAA6A4A2A2A2A4A6
A9ADB0B4B6B8B8B9B8B8B6B3B4B8B8B5B0AEABAAA7A3A2A1
A1A09F9D9B98938C847B7166594C433A322B27241F1B1415
0D0808070C12181D23282D32373C41464B50555A5F63686D
71767B7F84898D92
9CA1A7ACB2B7BDC2C8CDD3D9DEE4EAEFF3F3F0E8DFD3CAC1
B6ABABA9A6A5A6A9ACAFB0AFABABAEAAAAA3A29F9F9FA1A4
A7ACB0B3B6B8B9B9B9B7B7B4B5B9B5B5AFADA8AAA5A1A0A0
9F9E9E9C9A97928B837A7165574B4139302A26221C181213
0A0706070D13181E23282E33383D42474C50555A5F63686D
72767B7F84898D92
9CA1A7ACB2B7BDC2C8CDD3D9DFE5EBF1F2F3EEE6DDD2C8BE
B4ACACA9A6A5A6A9ACAEAFADAAABACA8A7A09F9C9C9D9FA3
A7ABAFB2B5B7B9B9B9B7B7B5B5B8B4B4ADABA7A7A29F9E9E
9D9D9C9B9995918A82797064564B40372E29241F1A151010
090605080E14191E24292E33383D42474C51565B5F64696D
72767B8084898D92
9CA1A7ACB2B7BDC2C8CED3D9DFE5EBF2F1F1EDE5DAD0C7BC
B3ADABA8A5A4A5A7A9ABACAAA9A9A7A4A29E9C9B9B9C9FA2
A6AAAEB1B4B6B8B9B8B8B6B5B4B4B1AFACA9A6A2A09E9E9D
9D9C9C9A98948F8880786E63554A40352C26221D17130F0E
080504090F141A1F252A2F34393E43484D51565B6064696E
72777B8084898D92
9CA1A7ACB2B7BDC2C8CED3D9DFE5EBF1F2F0ECE2D8CFC6BB
B2ADAAA7A4A2A4A5A7A8A9A8A7A6A4A29F9D9C9A9B9C9FA3
A6AAADB0B3B5B7B8B8B8B6B4B2B1AFADAAA7A4A1A09F9F9E
9D9C9B9996938E877F766D6154493E342A24211B14100D0D
0703050A10151B20252B30353A3F44484D52575B6065696E
72777B8084898E92
9CA1A7ACB2B7BDC2C8CED4DADFE5EBF0F6F0E9E0D6CDC5BA
B2ADA9A6A2A1A2A3A4A5A6A6A6A5A4A2A09E9C9A9B9DA0A3
A6AAACAFB2B4B6B8B8B8B6B4B1AFADABA9A7A5A3A2A1A09F
9E9D9A9895928C857E756B6053473D3228221F19120E0B0B
0503060C11161C21262B31363B3F44494E53575C60656A6E
73777C8085898E92
9CA1A7ACB1B7BCC2C8CED4DADFE6EBF0F7EEE7DDD4CBC4B9
B2ACA8A5A19FA0A1A2A3A4A5A5A5A4A19E9B9A9A9C9EA1A4
A7AAACAFB1B3B5B6B7B7B5B3B0AEACABA9A8A6A5A3A2A1A0
9F9C9A9895908B857D746A5E52463A2F27211C17100D0A09
0503070D12181D22272C31363B40454A4E53585C61656A6E
73777C8085898E92
9CA1A6ACB1B7BCC2C8CDD3DAE0E6EDEFF5ECE4DBD3CAC2B9
B2ACA7A39F9D9EA1A1A2A3A3A4A39F9D9C9A9B9C9D9FA2A5
A7AAACAEB0B2B3B5B5B5B4B2B0AEACABAAA9A7A6A5A4A2A0
9E9B9997948F89837B73685C5145382D251F1A150E0C0A07
0303090E13191E23282D32373C41464A4F54585D61666A6F
73787C8185898E92
9CA1A6ACB1B6BCC2C7CDD3D9DFE6EEF0F2E9E1D9D2C9C2B9
B2ACA6A19D9B9C9E9FA0A1A1A09E9C9C9C9C9D9E9FA1A3A6
A8AAACAEAFB1B2B3B4B4B3B1B0AEACAAAAA9A7A6A5A2A19F
9D9B9996938E88827A72665B5043362A231E18130D0A0905
01040A0F151A1F24292E33383D42474B5054595D62666B6F
74787C8185898E92
9CA1A6ABB1B6BCC1C7CDD3D9DFE6EEF0EDE6DED8D1C9C1B9
B2ABA5A09B999B9C9D9E9E9E9D9C9C9D9D9E9E9FA1A2A4A6
A8AAABADAFB0B1B2B2B2B2B1AFAEADABABA9A7A6A4A2A19F
9D9B9996928C87817970665A4E403326221C15120D090803
00060B11161B20252B2F34393E43474C51555A5E63676B70
74787D81858A8E92
9CA1A6ABB1B6BBC1C6CCD2D8DFE5EDF0EAE3DCD7D1C9C1B9
B2ABA49F9A98999A9B9C9C9D9D9D9D9E9E9FA0A1A2A4A5A7
A9AAACADAFB0B1B1B2B2B1B1AFAFADACABA9A8A7A5A3A2A0
9D9B9895918B8680786F64584B3E3123201A13110C070701
01070D12171D22272C31353A3F44484D51565A5F63676C70
74797D81858A8E92
9CA1A6ABB0B5BBC0C5CBD1D7DDE4EBEFE8E2DBD6D0C8C1B9
B2AAA39E999798999A9B9B9C9C9D9E9E9FA0A1A2A3A5A6A8
A9ABACADAEAFB0B1B1B1B1B0AFAFAEADABAAA9A7A6A4A2A0
9E9B9895908A857F776E62564A3C2E211E1812100C060500
03090E14191E23282D32373B4045494E52575B5F64686C71
75797D81868A8E92
9BA0A5ABB0B5BABFC5CAD0D6DCE2E9EEE7E1DBD5CFC8C1B9
B1AAA29D99969798999A9B9C9C9D9E9FA0A1A2A3A4A5A7A8
AAABACADAEAFB0B0B0B0B0B0B0AFAEADACAAA9A8A6A4A2A0
9E9B98948F8A847E766C6055483A2B1F1A16110F0B060200
050B10151B20252A2E33383D41464A4F53575C6064696D71
75797E82868A8E92
9BA0A5AAAFB4B9BEC4C9CFD4DAE0E6EDE7E1DAD4CEC8C0B9
B1AAA29D9996969798999A9B9C9D9EA0A1A1A3A4A5A6A8A9
AAABADADAEAFAFB0B0B0B0B0AFAFAEADACAAA9A8A6A4A2A0
9E9A97938E89837C746A5F534537291D18150F0D09050002
070D12171C21262B3034393E42474B5054585D6165696D72
767A7E82868A8E92
9BA0A5AAAFB3B8BDC3C8CDD3D8DEE4EBE6E0D9D4CEC7C0B9
B1A9A29D9996969698999A9B9D9E9FA0A1A2A3A5A6A7A8A9
ABACADADAEAFAFB0B0B0B0B0AFAEAEADACAAA9A8A6A4A2A0
9D9A97928D88827B72685D504234261C16130D0A07040004
0A0F14191E23282D31363A3F43484C5155595D62666A6E72
767A7E82868A8E92
9BA0A5A9AEB3B8BCC1C7CCD1D6DCE2E9E4DFDAD4CEC7C0B8
B1A9A29D9997969697999A9C9D9E9FA1A2A3A4A6A7A8A9AA
ABACADADAEAFAFAFB0B0B0AFAFAEADADABAAA9A7A6A3A19F
9D9996928D87807970665B4D3F32231B15100B0805030207
0C11161B20252A2E33373C4045494D52565A5E62666B6F73
777B7F83878B8F92
9BA0A4A9ADB2B7BBC0C5CACFD4D9DFE5E4E0DBD4CEC7C0B8
B1A9A29D9A97969798999B9C9D9FA0A2A3A4A5A7A8A9A9AB
ACACADAEAEAFAFAFB0B0AFAFAEAEADACABAAA9A7A5A3A19E
9C9895918C857F776E64584A3C2F201A140F08060402050A
0F14181D22272B3034393D42464A4E53575B5F63676B6F73
777B7F83878B8F93
9B9FA4A8ADB1B6BABFC4C8CDD2D7DCE0E5E0DBD4CEC7C0B8
B1A9A29E9A989797989A9B9D9E9FA1A2A3A5A6A7A8A9AAAB
ACADADAEAEAFAFAFB0AFAFAFAEADADACAAAAA8A7A4A2A09E
9B98948F8A847D766C615547392C1E19130D06040303080D
11161B1F24292D32363A3F43474C5054585C6064686C7074
787C7F83878B8F93
9B9FA3A8ACB0B5B9BDC2C6CBD0D4D9DDE2E0DBD4CEC7C0B9
B1AAA39F9B999898999B9C9E9FA0A2A3A4A5A7A8A9AAABAC
ACADAEAEAEAFAFAFAFAFAFAEAEADACABAAA9A8A6A4A19F9D
9A97938E88827B73695E514436291C17120B050303060B0F
14181D22262B2F33383C4045494D5155595D6165696D7074
787C8084878B8F93
9B9FA3A7ABAFB4B8BCC0C5C9CDD1D6DADEE0DBD4CEC8C1BA
B2AAA49F9C9A999A9A9C9D9EA0A1A3A4A5A7A8A9AAABACAC
ADAEAEAEAFAFAFAFAFAFAFAEADADACABAAA8A7A5A3A09E9C
9995918C86807970655A4E4134271A151009050304090D12
161B1F24282D31353A3E42464A4E52565A5E62666A6D7175
797C8084888B8F93
9A9EA2A6AAAEB3B7BBBFC3C7CBCFD3D6DADEDAD5CFC9C2BB
B3ACA5A09D9B9A9B9C9D9E9FA1A2A4A5A6A8A9AAABACACAD
AEAEAFAFAFAFAFAFAFAFAEAEADACABAAA9A7A6A4A29F9D9A
97948F8A847D766D62574B3E322518130F090504060B1014
191D22262A2F33373B3F44484C4F53575B5F63676A6E7276
797D8184888C8F93
9A9EA2A6AAAEB1B5B9BDC1C5C8CCD0D3D6D9D8D5D0CAC4BD
B5ADA7A29E9C9C9C9D9E9FA1A2A3A5A6A7A9AAABACADADAE
AEAFAFAFB0B0AFAFAFAFAEADACABAAA9A8A6A5A3A09E9C99
96928D88827A72695E53473B2F2216130E080505090E1217
1B2024282D3135393D4145494D5155595C6064686B6F7376
7A7D8185888C8F93
9A9EA2A5A9ADB0B4B8BCBFC3C6CACDD0D3D4D6D5D3CDC6BF
B7AFA9A3A09E9D9E9F9FA1A2A3A5A6A7A8AAABACADADAEAF
AFB0B0B0B0B0AFAFAFAFAEADACABAAA9A7A5A3A19F9D9A97
948F8B857E766E655B5044382B1E16130D0806070C10151A
1E22262B2F33373B3F43474B4F52565A5E6165696C707377
7A7E8185888C8F93
9A9EA1A5A8ACAFB3B6BABDC1C4C7CACDD0D2D3D5D6D1C9C1
B9B1ABA5A2A09FA0A0A1A2A3A5A6A7A8AAABACADAEAEAFB0
B0B0B1B1B0B0B0AFAFAEADACABAAA9A8A6A4A2A09E9B9895
928D88827A726A61574C4034261C18130C08070A0F13181C
2125292D3135393D4145494C5054575B5F6266696D717478
7B7E8285898C9093
9A9DA1A4A8ABAEB2B5B8BCBFC2C5C8CBCDCFD1D3D6D4CAC2
BBB3ADA8A4A2A1A1A2A3A4A5A6A7A9AAABACADAEAFAFB0B1
B1B1B1B1B1B0B0AFAEAEADABAAA9A8A7A5A3A19F9C9A9693
8F8A847E766E655C53483C2F241D18120C09090D12161B1F
23272C3034373B3F43474A4E5255595C6063676B6E717578
7C7F8286898C9093
9A9DA0A4A7AAADB1B4B7BABDC0C3C6C8CBCDD0D2D6D5CCC4
BDB5AFAAA6A4A3A3A3A4A5A6A7A8AAABACADAEAFB0B1B1B2
B2B2B2B2B1B0AFAFAEADACABAAA8A7A5A3A19F9D9A979390
8C87817A726A61584F43372D231D17120D0C0C11151A1E22
262A2E32363A3D4145494C5053575A5E6165686C6F727679
7C808386898D9093
9A9DA0A3A6A9ACAFB3B6B8BBBEC1C4C6C9CBCED1D5D3CFC6
BFB8B2ACA9A6A5A5A5A6A7A7A9AAACADAEAFAFB0B1B2B2B3
B3B3B3B2B1B0AFAFAEADACAAA9A7A6A4A2A09D9B9895918D
88827D766E655D544A40332C231D16130F0E1015191D2125
292D3135383C4043474A4E5155585C5F6266696D7073767A
7D8083868A8D9093
999C9FA3A6A8ABAEB1B4B7BABCBFC2C4C7C9CCCED2D1D1C8
C0BAB4AFABA8A7A7A7A7A8A9AAACADAEAFB0B1B1B2B3B3B4
B4B4B3B2B1B0AFAFAEACABAAA8A6A4A2A09E9B9895918D89
847E78716961584F463B312B231C1614111115181D202428
2C3034373B3E4245494C5053575A5D6164676B6E7174777A
7E8184878A8D9093
999C9FA2A5A8ABADB0B3B6B8BBBDC0C2C5C7C9CCCFD1D0C9
C2BCB7B2AEABA9A8A9A9AAAAACADAEB0B1B2B2B3B3B4B4B4
B4B4B4B3B1B0AFAEADABAAA9A7A5A3A09E9B9895928E8985
807A746D645C544B4238302A221D18151415191C2024282B
2F33363A3D4144484B4E5255585B5F6265686C6F7275787B
7E8184878A8D9093
999C9FA1A4A7AAACAFB2B4B7B9BBBEC0C2C5C7C9CBCDCDCA
C4BFBAB4B1AEABAAAAAAABACADAFB0B1B2B3B3B4B4B4B5B4
B4B4B4B2B1AFAEADACAAA9A7A5A3A09E9B9895928E8A8681
7B756F68605851483F362F29221D191716191D2024272B2F
3236393C4043474A4D5054575A5D606366696D707376797C
7F8285888B8E9193
999C9EA1A4A6A9ABAEB0B3B5B7BABCBEC0C3C5C7C8CACBC9
C7C2BDB7B3B1ADACABABACAEAFB1B2B3B4B4B4B4B4B4B5B4
B4B4B3B2B0AEADACAAA8A7A5A2A09D9B9895928E8B86817C
77716B645C554D453C342E28221E1C191A1D2124282B2E32
35393C3F4246494C4F5256595C5F6265686B6E7174777A7D
7F8285888B8E9194
999B9EA0A3A5A8AAADAFB1B4B6B8BABCBEC0C2C4C6C7C8C8
C9C5C0BAB6B2AFAEADAEAEB0B1B3B4B4B5B5B5B4B4B4B4B4
B4B3B2B0AFADACA9A8A7A5A3A09D9B9995928E8B88827D78
736C6660595149423A332D2824211D1B1E2225282B2F3235
383B3F4245484B4E5155585B5E616366696C6F7275787B7D
808386898B8E9194
999B9EA0A2A5A7A9ACAEB0B2B4B7B9BBBCBEC0C2C3C5C6C7
C8C7C2BEB9B5B2B1AFAFB0B1B3B4B4B5B5B5B5B4B4B4B3B3
B3B2B1AFADACAAA8A6A5A2A09E9B9A96938F8B88847E7974
6E68625C554D463F38322D2A26221E1F2326292C2F323538
3B3E4245484B4E5154575A5C5F6265686B6E707376797B7E
818486898C8E9194
999B9D9FA2A4A6A8ABADAFB1B3B5B7B9BBBCBEC0C1C2C3C5
C6C7C5C1BCB7B5B2B1B1B2B3B5B5B5B6B5B5B5B4B4B3B2B2
B1B0AFADABAAA8A5A4A2A09E9C9A9793918C88847F7A756F
69635E57504A423D3733302B27232024272A2D303336393B
3E4144474A4D505356595C5E616467696C6F7274777A7C7F
828487898C8F9194
999B9D9FA1A3A6A8AAACAEB0B2B3B5B7B9BABCBEBFC0C2C3
C4C5C7C4BFBAB8B5B2B2B3B4B6B6B6B6B5B4B4B4B3B1B1B0
AFAEACABAAA7A6A3A19F9E9C9A9794918D8884807B76716B
655F59534D47413D3835312A282224282B2E313336393C3F
4245474A4D505355585B5E606365686B6E707375787B7D80
8285878A8C8F9194
989B9D9FA1A3A5A7A9ABADAEB0B2B4B5B7B9BABCBDBEC0C1
C2C3C5C6C1BCBAB6B4B3B4B5B7B7B6B5B4B4B4B3B1B0B0AE
ADACAAA9A7A5A4A29F9D9B999794918E8985817C77726D67
615B56514C46423E3A352F2B2726292C2F3234373A3D3F42
45484A4D505255585A5D606265676A6C6F727477797C7E81
8385888A8D8F9294
989A9C9EA0A2A4A6A8AAABADAFB1B2B4B5B7B8BABBBCBEBF
C0C2C3C5C3C0BCB8B6B5B4B5B7B8B6B5B3B3B3B2AFAFAEAC
ABA9A9A5A4A3A1A09C9B989694918E8A87827D78736E6863
5E58534F4A46433F3A342F2A282B2E303336383B3E404345
484B4D505255585A5D5F626467696B6E707375787A7D7F81
8486888B8D8F9294
989A9C9EA0A2A3A5A7A9AAACAEAFB1B2B4B5B7B8B9BBBCBD
BEC0C1C2C3C3BEBAB8B6B4B5B7B8B6B4B3B1B1B0AFADACAA
A8A6A6A2A1A09F9D99989593918E8A87837F7A75706A6560
5B57534F4C49433E39332F2A2D303235373A3C3F41444649
4B4E505355585A5D5F616466686B6D70727477797B7E8082
8487898B8D909294
989A9C9D9FA1A3A4A6A8A9ABACAEAFB1B2B4B5B6B7B9BABB
BCBDBFC0C1C3C1BCB9B6B5B5B6B7B5B2B1B0AFAEADABA9A8
A5A4A2A09E9C9B9A969592908E8B87847F7C77726C67635E
5A56544F4D49413C37332E2E323437393B3E404245474A4C
4E515356585A5D5F616366686A6D6F717376787A7C7F8183
8587898C8E909294
989A9B9D9FA0A2A4A5A7A8AAABADAEAFB1B2B3B5B6B7B8B9
BABBBCBEBFC0C1BEBBB8B6B4B4B4B5B2B0AFAEACABA9A7A5
A3A19F9D9B98979694928F8E8B8784817D79746F6B67635E
5B5755504C463F3B3732323436393B3D40424446484B4D4F
525456585B5D5F616366686A6C6E70737577797B7D808284
86888A8C8E909294
989A9B9D9EA0A1A3A4A6A7A9AAABADAEAFB0B2B3B4B5B6B7
B8B9BABBBCBEBFBFBCB9B6B4B3B2B2B1AEACABAAA8A7A4A2
A09E9C9A97959392908F8D8C8884827E7B77736F6B686560
5C59544F4A443F3A363537393B3E40424446484A4C4E5153
5557595B5D5F626466686A6C6E70727476787B7D7F818385
87898B8D8F919294
98999B9C9E9FA1A2A3A5A6A8A9AAABADAEAFB0B1B2B3B4B5
B6B7B8B9BABBBCBDBCBAB6B4B2B0AFAEADAAA9A7A5A4A19F
9D9B99979392908F8D8C8C898683807D7A7774706D6A6561
5C57524C47443F3A393B3D3F40434546484A4C4E50525456
585A5C5E60626466686A6C6E70727476787A7C7E80828485
87898B8D8F919395
98999B9C9D9FA0A1A3A4A5A7A8A9AAABACADAFB0B1B2B2B3
B4B5B6B7B7B8B9B9BAB9B7B4B2AFACACABA8A6A4A2A09E9C
9B999594918F8E8E8C8B8A898583817E7C7975716E696460
5B55504A47443F3D3F4142444647494B4C4E50525355575A
5B5D5F61636567686A6C6E7072747677797B7D7F81838486
888A8C8D8F919395
98999A9C9D9E9FA1A2A3A4A6A7A8A9AAABACADAEAFB0B1B2
B2B3B4B4B5B5B6B7B7B6B6B5B2AEABA9A8A7A3A19F9D9B9A
989692918F8E8D8D8C8A8A88868583807D7975716D68635E
59544F4B46454344454647494A4C4D4F5152545557595B5D
5F6062646567696B6D6E7072747577797B7D7E8082848587
898B8C8E90919395
98999A9B9D9E9FA0A1A2A3A5A6A7A8A9AAABABACADAEAFB0
B0B1B2B2B3B3B3B4B4B4B3B4B0AFABA7A6A4A19F9E9B9A98
96959392918F8E8E8C8B8B898786837F7D78746F6B66615C
59544F4B494A494A4B4B4D4E4F515253555658595B5C5E60
62636567686A6C6D6F7172747677797B7C7E808283858688
8A8B8D8E90929395
98999A9B9C9D9E9FA0A2A3A4A5A6A7A7A8A9AAABACADADAE
AFAFB0B0B0B1B1B1B1B1B1B0AFAEABA7A4A2A09E9D9B9997
9694939291908F8F8E8C8B8A8785827E7B76736D6865615D
5954514F4F4F4F4F5051525354555658595A5C5D5F606263
656668696B6C6E707173747678797B7C7E7F818384868789
8A8C8D8F90929395
97999A9B9C9D9E9FA0A1A2A3A4A4A5A6A7A8A9A9AAABACAC
ADADAEAEAEAFAFAFAFAEAEADACABAAA6A5A29F9D9B9A9897
95949292919190908E8C8A898784807C7974716B6865615D
5A5756555555545555565758595A5B5C5D5E606162636566
68696B6C6D6F717274757778797B7D7E7F8182848687888A
8B8C8E8F91929495
9798999A9B9C9D9E9FA0A1A2A3A3A4A5A6A7A7A8A9A9AAAA
ABABACACACACADADACACABABAAA8A7A5A4A09E9D9B999896
959492929190908F8D8B8A8785837E7A7874706C68666260
5F5D5C5B5A5A5A5A5A5B5C5C5D5E5F60616263656667686A
6B6C6D6F707273757677797A7B7D7E80818284858788898B
8C8D8E9091929495
9798999A9B9C9D9E9E9FA0A1A2A2A3A4A5A5A6A6A7A8A8A9
A9AAAAAAAAAAABAAAAAAA9A9A8A7A5A4A2A09E9E9B9A9895
9493929190908F8E8D8B888684827E7B7874706C6A686765
63626160605F5F5F5F6060616262636465666768696B6C6D
6E6F717273757677787A7B7C7D7F80818284858788898A8B
8D8E8F9092939495
9798999A9B9B9C9D9E9E9FA0A1A1A2A3A3A4A5A5A6A6A7A7
A8A8A8A8A8A9A9A8A8A8A7A7A6A5A4A2A1A09E9D9B9A9795
9492919190908F8E8D8A888684827F7B787572706E6C6B6A
68676665656464646465656566676768696A6B6C6D6E6F70
71727475767778797B7C7D7E7F81828384858788898A8B8C
8D8E909192939495
979899999A9B9C9C9D9E9E9FA0A0A1A2A2A3A3A4A5A5A5A6
A6A6A6A7A7A7A7A7A6A6A5A5A4A3A2A1A09F9D9C9A999795
9493929190908F8E8C8A888684827F7D7A78767472706F6E
6D6C6B6A696969696969696A6A6B6B6C6D6E6F7071717273
75757678797A7B7C7D7E7F8081838485868688898A8B8C8D
8E8F909192939495
979898999A9A9B9C9C9D9E9E9F9FA0A0A1A2A2A2A3A3A4A4
A4A5A5A5A5A5A5A5A4A4A4A3A3A2A1A09F9D9C9B9A999796
9493929291908F8E8C8B89888683817F7D7B797775747372
71706F6E6E6D6D6D6D6E6E6E6E6F70707172737374757677
7879797A7B7C7D7E7F808182838585868788898A8B8C8D8E
8F90919292949595
97989899999A9B9B9C9C9D9D9E9E9F9FA0A0A1A1A2A2A2A3
A3A3A3A3A3A3A3A3A3A3A2A2A1A09F9E9E9D9C9B9A989796
9594939291908F8E8D8C8A8987858381807E7C7A79787776
75747473727272727272727273737474757676777878797A
7B7C7C7D7E7F8081828383848586878889898A8B8D8D8E8F
9090919293949596
97979899999A9A9B9B9C9C9D9D9D9E9E9F9FA0A0A0A0A1A1
A1A2A2A2A2A2A2A1A1A1A1A09F9F9E9D9D9C9B9A99989796
959493929291908F8E8D8B8A8987858482817F7E7D7C7A7A
7978787776767676767676777777787879797A7A7B7C7C7D
7E7F7F8081818283848586878788898A8A8B8C8C8E8E8F90
9091929393949596
9797989899999A9A9B9B9B9C9C9D9D9D9E9E9E9F9F9F9FA0
A0A0A0A0A0A0A0A0A0A09F9F9E9E9D9D9C9B9A9A99989796
95949493929191908F8E8D8B8A89878685848281807F7E7D
7D7C7C7B7B7B7A7A7A7A7B7B7B7B7C7C7D7D7D7E7E7F8080
818282838484858686878889898A8B8B8C8C8D8E8E8F9091
9192929394959596
979798989899999A9A9A9B9B9B9C9C9C9D9D9D9D9E9E9E9F
9F9F9F9F9F9F9F9E9E9E9E9D9D9D9C9C9B9A9A9998989796
9595949392929191908F8E8D8C8B8A888886858483838281
8180807F7F7F7F7E7F7F7F7F7F7F80808081818282828383
848585868687878889898A8B8B8C8C8D8D8E8E8F8F909191
9292939494959596
9797979898989999999A9A9A9A9B9B9B9C9C9C9C9C9D9D9D
9D9D9D9D9D9D9D9D9D9D9C9C9C9C9B9B9A9A999898979796
969594949393929190908F8E8E8D8C8B8A89888787868585
848484838382838283838383838384848484858585868687
8788888889898A8A8B8C8C8D8D8D8E8E8F8F909091919292
9393949495959596
9797979798989898999999999A9A9A9A9A9B9B9B9B9B9C9C
9C9C9C9C9C9C9C9C9C9B9B9B9B9B9A9A9999989897979796
9695959494939392929191908F8F8E8D8C8C8B8A8A898988
888887878787878787878787878787878888888889898A8A
8A8B8B8B8C8C8C8D8D8E8E8F8F8F90909191919192929393
9394949595959696
97979797979898989898999999999999999A9A9A9A9A9A9A
9A9A9A9A9A9A9A9A9A9A9A9A9A9999999998989897979796
9696959594949493939292929191908F8F8E8E8D8D8D8C8C
8C8B8B8B8B8B8B8B8B8B8B8B8B8B8B8B8B8B8C8C8C8C8D8D
8D8D8E8E8E8F8F8F90909090919191929292929393939494
9494959595959696
979797979797979798989898989898989898989999999999
999999999999999999999999999998989897979797979796
96969695959594949494949393939292919191919090908F
8F8F8F8F8F8F8E8F8F8F8E8F8F8F8F8F8F8F8F8F90909090
909091919191919292929292939393949394949494949595
9595959696969696
969797979797979797979797979797979797979898989898
989898989898989898989898989797979797979797969796
969696969696959595959595959594949493949493939393
939393939392929393939293939393939393939393939393
939393949494949494949494949495959595959595959595
9696969696969696
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[57]:=",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`004`3oool209JFUPl0UiNG102HV9PF09VIV@80VYZJ
0P2MWId309VIVAH0VYZJ3`2IVIT809RHV080UiNG0P2HV9P609NGUa40V9RH102GUiL409RHV1d0UiNG
1P2FUYH209RHV080VIVI3@2FUYHD09FEU@0309BDU02EUID0UIFE0080U9BD402EUID:09BDU00309>C
T`2EUID0UIFE0080UYJF102CTi<209BDU080UIFE0P2FUYHE0?ooo`004`3oool209JFUPl0UiNG102H
V9PF09VIV@80VYZJ0P2MWId309VIVAH0VYZJ3`2IVIT809RHV080UiNG0P2HV9P609NGUa40V9RH102G
UiL409RHV1d0UiNG1P2FUYH209RHV080VIVI3@2FUYHD09FEU@0309BDU02EUID0UIFE0080U9BD402E
UID:09BDU00309>CT`2EUID0UIFE0080UYJF102CTi<209BDU080UIFE0P2FUYHE0?ooo`004`3oool8
09NGU`H0V9RH1@2IVIT209ZJVPX0Vi^K302LW9`209fMW@80X:2P0`2MWId<09jNWPX0WIfM102LW9`;
09^KV`H0VYZJ202IVIT209RHV1<0VIVI102HV9P409VIV@80V9RH1P2IVIT?09RHV0P0UiNG102FUYH2
09RHV080VIVI0P2GUiL709JFUPP0UIFE202DU9@209>CT`80U9BD5@2CTi<409:BTP/0TI6A102CTi<2
09:BTP80TI6A0P2BTY8209BDU080UIFE5@3oool001<0oooo202GUiL609RHV0D0VIVI0P2JVYX:09^K
V``0W9bL0P2MWId20:2PX0<0WIfM302NWYh:09fMW@@0W9bL2`2KVi/609ZJVPP0VIVI0P2HV9PC09VI
V@@0V9RH102IVIT209RHV0H0VIVI3`2HV9P809NGU`@0UYJF0P2HV9P209VIV@80UiNG1`2FUYH809FE
U@P0U9BD0P2CTi<209BDU1D0Ti>C102BTY8;096AT@@0Ti>C0P2BTY82096AT@80TY:B0P2DU9@209FE
UAD0oooo000C0?ooo`H0UiNG102HV9P409VIV@<0VYZJ0P2KVi/409bLW080WIfM202NWYh:09nOW`80
X:2P0`2RXZ820:2PX080XJ6Q202RXZ880:6QX@H0X:2P0P2OWil209jNWPL0WIfM102LW9`809^KVaT0
VYZJ2P2IVIT609ZJVP/0VIVI202HV9P:09NGU`80V9RH0`2GUiL409JFUP@0UIFE1P2DU9@609>CT`X0
TY:B4@2ATI42092@T0H0Shn?102>SXh208n?S`03092@T02ATI40TI6A0080TI6A0P2@T90208n?S`80
TI6A0P2CTi<209FEUAD0oooo000C0?ooo`H0UiNG102HV9P409VIV@<0VYZJ0P2KVi/409bLW080WIfM
202NWYh:09nOW`80X:2P0`2RXZ820:2PX080XJ6Q202RXZ880:6QX@H0X:2P0P2OWil209jNWPL0WIfM
102LW9`809^KVaT0VYZJ2P2IVIT609ZJVP/0VIVI202HV9P:09NGU`80V9RH0`2GUiL409JFUP@0UIFE
1P2DU9@609>CT`X0TY:B4@2ATI42092@T0H0Shn?102>SXh208n?S`03092@T02ATI40TI6A0080TI6A
0P2@T90208n?S`80TI6A0P2CTi<209FEUAD0oooo000C0?ooo`@0UiNG102HV9P409VIV@80VYZJ0`2K
Vi/209bLW080WIfM0P2NWYh409nOW`@0X:2P1P2QXJ460::RXP@0Xj>S00<0YZJV0:BTY02TY:@00P2T
Y:@20:FUY@H0YZJV1P2UYJD40:BTY0@0Xj>S0P2RXZ820:6QX@<0X:2P102OWil209jNWP@0WIfM1P2L
W9`G09^KV`H0VYZJ102KVi/209ZJVPH0Vi^K2@2JVYX609VIV@P0V9RH2P2GUiL00`2HV9P0UYJF09JF
UP0409FEU@H0U9BD102CTi<409:BTPH0TI6A1@2@T90>08n?S`80SXj>0P2=SHd808b<S0@0SHf=00<0
SXj>08n?S`2?Shl0102?Shl208j>SP80Shn?0P2BTY8209BDU1D0oooo000C0?ooo`@0UiNG102HV9P4
09VIV@80VYZJ0`2KVi/209bLW080WIfM0P2NWYh409nOW`@0X:2P1P2QXJ460::RXP@0Xj>S00<0YZJV
0:BTY02TY:@00P2TY:@20:FUY@H0YZJV1P2UYJD40:BTY0@0Xj>S0P2RXZ820:6QX@<0X:2P102OWil2
09jNWP@0WIfM1P2LW9`G09^KV`H0VYZJ102KVi/209ZJVPH0Vi^K2@2JVYX609VIV@P0V9RH2P2GUiL0
0`2HV9P0UYJF09JFUP0409FEU@H0U9BD102CTi<409:BTPH0TI6A1@2@T90>08n?S`80SXj>0P2=SHd8
08b<S0@0SHf=00<0SXj>08n?S`2?Shl0102?Shl208j>SP80Shn?0P2BTY8209BDU1D0oooo000C0?oo
o`@0UiNG0P2HV9P409VIV@80VYZJ0P2KVi/309bLW080WIfM0P2NWYh209nOW`80X:2P0P2QXJ420::R
XP@0Xj>S1P2TY:@60:FUY@80YZJV00<0Z:RX0:VYZ@2YZJT00P2XZ:P40:VYZ@@0ZZZZ102YZJT40:RX
Z0@0YjNW0P2VYZH20:FUY@80Y:BT00<0Xj>S0::RXP2RXZ800P2QXJ440:2PX0@0WYjN202MWId809bL
W080WIfM2`2LW9`409^KV`H0W9bL0P2KVi/609bLW0L0Vi^K1P2JVYX609VIV@P0V9RH102GUiL209JF
UP0309NGU`2HV9P0V9RH0080UIFE1P2DU9@409>CT`@0TY:B0P2ATI46092@T0@0Shn?0`2>SXh<08f=
S@80S8b<0P2;Rh/608V9R@H0Rh^;00<0SHf=08b<S02<S8`00P2>SXh208f=S@80S8b<0P2>SXh2096A
T@80U9BD5@3oool001<0oooo102GUiL209RHV0@0VIVI0P2JVYX209^KV`<0W9bL0P2MWId209jNWP80
WinO0P2PX:020:6QX@80XZ:R102SXj<60:BTY0H0YJFU0P2VYZH00`2XZ:P0ZJVY0:VYZ@020:RXZ0@0
ZJVY102ZZZX40:VYZ@@0Z:RX102WYjL20:JVYP80YJFU0P2TY:@00`2SXj<0XZ:R0::RXP020:6QX@@0
X:2P102NWYh809fMW@P0W9bL0P2MWId;09bLW0@0Vi^K1P2LW9`209^KV`H0W9bL1`2KVi/609ZJVPH0
VIVI202HV9P409NGU`80UYJF00<0UiNG09RHV02HV9P00P2EUID609BDU0@0Ti>C102BTY82096AT@H0
T92@102?Shl308j>SP`0SHf=0P2<S8`208^;R`H0RHV91P2;Rh/00`2=SHd0S8b<08b<S00208j>SP80
SHf=0P2<S8`208j>SP80TI6A0P2DU9@E0?ooo`004`3oool209NGU`@0V9RH0P2IVIT209ZJVP80Vi^K
0P2LW9`309fMW@80WYjN0P2OWil20:2PX080XJ6Q0P2RXZ820:>SX`80Y:BT0P2UYJD20:JVYPH0YjNW
102XZ:P20:VYZ@030:ZZZP2/[:`0[:b/0080[:b/102][Jd60:j^[P80[Jf]102/[:`20:^[Z`80ZZZZ
0P2YZJT20:RXZ080YjNW00<0YJFU0:BTY02TY:@00P2SXj<20::RXP80XJ6Q102OWilB09jNWQl0WIfM
1@2LW9`609^KV`@0VYZJ1P2IVIT409RHV0@0UiNG1@2FUYH209FEU@@0U9BD1P2CTi<209:BTP80TI6A
0P2@T90608n?S`@0SXj>0`2=SHd608b<S0@0Rh^;0P2:RXX208V9R@80R8R81026QXH208R8R0@0RHV9
1@2:RXX208b<S0@0Rh^;0P2>SXh2096AT@80U9BD5@3oool001<0oooo0P2GUiL409RHV080VIVI0P2J
VYX209^KV`80W9bL0`2MWId209jNWP80WinO0P2PX:020:6QX@80XZ:R0P2SXj<20:BTY080YJFU0P2V
YZH60:NWY`@0Z:RX0P2YZJT00`2ZZZX0[:b/0:b/[0020:b/[0@0[Jf]1P2^[Zh20:f][@@0[:b/0P2[
Zj/20:ZZZP80ZJVY0P2XZ:P20:NWY`030:FUY@2TY:@0Y:BT0080Xj>S0P2RXZ820:6QX@@0WinO4P2N
WYhO09fMW@D0W9bL1P2KVi/409ZJVPH0VIVI102HV9P409NGU`D0UYJF0P2EUID409BDU0H0Ti>C0P2B
TY82096AT@80T92@1P2?Shl408j>SP<0SHf=1P2<S8`408^;R`80RXZ:0P29RHT208R8R0@0QXJ60P28
R8P408V9R@D0RXZ:0P2<S8`408^;R`80SXj>0P2ATI4209BDU1D0oooo000C0?ooo`80UiNG0P2HV9P2
09VIV@80VYZJ102KVi/409fMW@<0WinO0P2QXJ440::RXP80Y:BT0P2UYJD20:JVYP80YjNW0P2XZ:P2
0:VYZ@@0ZZZZ102[Zj/20:b/[0030:f][@2_[jl0[jn_0080/;2`0P2a/K480;:b/P@0/K6a0P2`/;02
0:n_[`80[Zj^0P2/[:`20:^[Z`80ZJVY00<0Z:RX0:JVYP2VYZH00P2UYJD20:>SX`80XZ:R102PX:0C
09nOWah0WYjN1@2MWId409bLW0H0Vi^K102JVYX209VIV@@0V9RH102GUiL309JFUP@0UIFE102DU9@4
09>CT`80TY:B0P2ATI44092@T080Shn?102>SXh208f=S@<0S8b<102;Rh/608Z:RP80RHV90P28R8P2
08N7Q`80QHF50P23Ph<208B4Q080QXJ61P27QhL308R8R080RXZ:0P29RHT208Z:RP80SHf=0P2@T902
09BDU1D0oooo000C0?ooo`80UiNG0P2HV9P209VIV@80VYZJ102KVi/409fMW@<0WinO0P2QXJ440::R
XP80Y:BT0P2UYJD20:JVYP80YjNW0P2XZ:P20:VYZ@@0ZZZZ102[Zj/20:b/[0030:f][@2_[jl0[jn_
0080/;2`0P2a/K480;:b/P@0/K6a0P2`/;020:n_[`80[Zj^0P2/[:`20:^[Z`80ZJVY00<0Z:RX0:JV
YP2VYZH00P2UYJD20:>SX`80XZ:R102PX:0C09nOWah0WYjN1@2MWId409bLW0H0Vi^K102JVYX209VI
V@@0V9RH102GUiL309JFUP@0UIFE102DU9@409>CT`80TY:B0P2ATI44092@T080Shn?102>SXh208f=
S@<0S8b<102;Rh/608Z:RP80RHV90P28R8P208N7Q`80QHF50P23Ph<208B4Q080QXJ61P27QhL308R8
R080RXZ:0P29RHT208Z:RP80SHf=0P2@T90209BDU1D0oooo000C0?ooo`80UiNG0P2HV9P209VIV@80
VYZJ0P2KVi/209bLW0@0WYjN00<0X:2P0:6QX@2QXJ400P2RXZ820:>SX`80Y:BT0P2UYJD20:JVYP80
YjNW0P2YZJT20:ZZZP80Zj^[0P2/[:`40:f][@80[Zj^0P2_[jl00`2`/;00/[:b0;:b/P020;Bd]080
]KFe0P2g]kL20;Jf]P80]kNg102f][H20;Fe]@80];Bd0P2b/[820;6a/@80/;2`0P2^[Zh20:b/[003
0:ZZZP2XZ:P0Z:RX0080YZJV0P2UYJD20:>SX`80XZ:R0P2QXJ4C0:2PX1h0WinO0`2NWYh609fMW@@0
W9bL102KVi/209ZJVP@0VIVI0P2HV9P409NGU`<0UYJF0P2EUID609BDU0@0Ti>C0P2BTY82096AT@80
T92@0P2?Shl208j>SP@0SHf=0P2<S8`208^;R`<0RXZ:1029RHT208R8R080QhN70P26QXH208F5Q@80
Ph>31021PH4208>3P`H0Q8B40`25QHD208J6QP@0QhN70P29RHT208f=S@80T92@0P2CTi<E0?ooo`00
4`3oool209NGU`80V9RH0P2IVIT209ZJVP80Vi^K0P2LW9`409jNWP030:2PX02QXJ40XJ6Q0080XZ:R
0P2SXj<20:BTY080YJFU0P2VYZH20:NWY`80ZJVY0P2ZZZX20:^[Z`80[:b/102][Jd20:j^[P80[jn_
00<0/;2`0;:b/P2b/[800P2d];@20;Fe]@80]kNg0P2f][H20;Ng]`@0][Jf0P2e]KD20;Bd]080/[:b
0P2a/K420;2`/080[Zj^0P2/[:`00`2ZZZX0Z:RX0:RXZ0020:JVYP80YJFU0P2SXj<20::RXP80XJ6Q
4`2PX:0N09nOW`<0WYjN1P2MWId409bLW0@0Vi^K0P2JVYX409VIV@80V9RH102GUiL309JFUP80UIFE
1P2DU9@409>CT`80TY:B0P2ATI42092@T080Shn?0P2>SXh408f=S@80S8b<0P2;Rh/308Z:RP@0RHV9
0P28R8P208N7Q`80QXJ60P25QHD208>3P`@0PH610P23Ph<608B4Q0<0QHF50P26QXH408N7Q`80RHV9
0P2=SHd2092@T080Ti>C5@3oool001<0oooo0P2GUiL209RHV080VIVI0P2JVYX209bLW080WIfM0P2N
WYh209nOW`030:6QX@2RXZ80XZ:R0080Xj>S0P2TY:@20:FUY@80YjNW0P2XZ:P20:VYZ@80ZZZZ0P2/
[:`20:f][@80[Zj^0P2_[jl20;2`/080/K6a0P2b/[800`2c/k<0]KFe0;Fe]@020;Ng]`80^KVi202k
^k/20;Zj^P80^KVi0P2h^;P20;Jf]P80];Bd0P2c/k<20;2`/080[Zj^00<0[:b/0:VYZ@2YZJT00P2W
YjL20:JVYP80YJFU0P2SXj<20::RXP80XJ6Q1P2PX:0;0:6QXA00X:2P0P2QXJ440:2PX080XJ6Q1P2P
X:0309nOW`@0WYjN102MWId409bLW080Vi^K0P2JVYX209VIV@@0V9RH102GUiL309JFUP80UIFE1P2D
U9@409>CT`80TY:B0P2ATI4208n?S`80SXj>0P2=SHd408b<S080Rh^;0P2:RXX308V9R@80R8R80P27
QhL208J6QP80Q8B40P22PX820861P@80P820101oOgl20820P0H0PH610P22PX800`23Ph<0QHF508F5
Q@0408F5Q@80R8R80P2<S8`208n?S`80Ti>C5@3oool001<0oooo0P2GUiL209VIV@80VYZJ0P2KVi/2
09bLW080WYjN0P2OWil20:2PX0030::RXP2SXj<0Xj>S0080Y:BT0P2VYZH20:NWY`80Z:RX0P2YZJT2
0:^[Z`80[:b/0P2^[Zh20:n_[`80/;2`0P2b/[820;>c/`80];Bd0P2f][H00`2g]kL0^KVi0;Vi^@02
0;^k^`80_;bl0P2n_[h20<30`0@0`L710P2o_kl20;jn_P80_;bl0P2j^[X20;Rh^080]KFe0P2c/k<2
0;2`/0030:j^[P2[Zj/0Zj^[0080ZJVY0P2WYjL20:JVYP80Y:BT0P2SXj<20::RXPP0XJ6Q2@2RXZ8J
0:6QX@D0X:2P0P2OWil409jNWP@0WIfM0P2LW9`409^KV`80VYZJ0P2IVIT409RHV0@0UiNG0`2FUYH2
09FEU@@0U9BD0P2CTi<409:BTP80TI6A102@T90208f=S@80S8b<102;Rh/208Z:RP80RHV90`28R8P2
08J6QP80Q8B40P22PX8207moO`80OWin101mOGd407alO080OGem101nOWh407moO`030861P@23Ph<0
Ph>30080PX:20P25QHD208N7Q`80Rh^;0P2?Shl209>CTaD0oooo000C0?ooo`80UiNG0P2IVIT209ZJ
VP80Vi^K0P2LW9`209jNWP80WinO0P2PX:000`2RXZ80Xj>S0:>SX`020:BTY080YZJV0P2WYjL20:RX
Z080ZJVY0P2[Zj/20:b/[080[Zj^0P2_[jl20;2`/080/[:b0P2c/k<20;Bd]080][Jf00<0]kNg0;Vi
^@2i^KT00P2k^k/20;bl_080_[jn0P30`<040<71`@80_kno0P2n_[h20;bl_080^[Zj0P2h^;P20;Fe
]@80/k>c0P2`/;000`2^[Zh0Zj^[0:^[Z`020:VYZ@80YjNW0P2VYZH20:BTY080Xj>S0P2RXZ880:6Q
X@T0XZ:R6P2QXJ450:2PX080WinO102NWYh409fMW@80W9bL102KVi/209ZJVP80VIVI102HV9P409NG
U`<0UYJF0P2EUID409BDU080Ti>C102BTY82096AT@@0T92@0P2=SHd208b<S0@0Rh^;0P2:RXX208V9
R@<0R8R80P26QXH208B4Q080PX:20P1oOgl207inOP@0OGem101lO7`207emO@@0OWin101oOgl00`21
PH40Ph>308>3P`0208:2PP80QHF50P27QhL208^;R`80Shn?0P2CTi<E0?ooo`004`3oool209RHV080
VIVI0P2JVYX209bLW080WIfM0P2NWYh20:2PX080XJ6Q00<0Xj>S0:BTY02TY:@00P2UYJD20:NWY`80
Z:RX0P2ZZZX20:^[Z`80[Jf]0P2^[Zh20:n_[`80/K6a0P2b/[820;Bd]080]KFe0P2g]kL20;Vi^@03
0;Zj^P2l_;`0_;bl0080_[jn0P30`<020<;2`P80a<C41036a/H40<?3``80`L710P2n_[h20;^k^`80
^;Rh0P2f][H20;:b/P030;2`/02][Jd0[Jf]0080ZZZZ0P2XZ:P20:NWY`80YJFU0P2TY:@<0::RXPT0
Xj>S302RXZ860:>SX`H0XZ:R1@2QXJ420:2PX0@0WinO0P2NWYh409fMW@80W9bL0P2KVi/209ZJVP@0
VIVI0P2HV9P409NGU`<0UYJF102DU9@209>CT`@0TY:B0P2ATI44092@T080Shn?0P2;Rh/208b<S080
Rh^;0P2:RXX208V9R@80R8R800<0QXJ608B4Q024Q8@00P22PX8207moO`80OGem0P1kNg/407YjNP80
NGUi0P1hN7P407YjNP80Ng]k0P1lO7`207]kN`80O7al00<0Ogmo0820P020P8000P21PH4208>3P`80
QhN70P2;Rh/208j>SP80TY:B5@3oool001<0oooo0P2HV9P209VIV@80VYZJ0P2LW9`209fMW@80WYjN
0P2PX:020:6QX@030:>SX`2TY:@0Y:BT0080YJFU0P2WYjL20:RXZ080ZZZZ0P2[Zj/20:f][@80[Zj^
0P2_[jl20;6a/@80/[:b0P2d];@20;Fe]@80]kNg0P2i^KT00`2j^[X0_;bl0;bl_0020;jn_P80`<30
0P32`/820<C4a0@0a/K61033`l<20<71`@80_[jn0P2k^k/20;Rh^080][Jf0P2b/[800`2`/;00[Jf]
0:f][@020:ZZZP80Z:RX0P2WYjL20:FUY@80Y:BT302RXZ890:>SX``0XZ:R1P2SXj<60::RXPD0XJ6Q
0P2PX:0409nOW`80WYjN102MWId209bLW080Vi^K0P2JVYX409VIV@80V9RH102GUiL309JFUP@0U9BD
0P2CTi<409:BTP80TI6A102@T90208n?S`80Rh^;0P2<S8`208^;R`80RXZ:0P29RHT208R8R00308J6
QP24Q8@0Q8B40080PX:20P1oOgl207emO@80Ng]k101jNWX207UiN@80N7Qh101jNWX207]kN`80O7al
0P1kNg/207alO00307moO`20P800P8200080PH610P23Ph<208N7Q`80Rh^;0P2>SXh209:BTQD0oooo
000C0?ooo`80V9RH0P2IVIT209ZJVP80W9bL0P2NWYh209nOW`80X:2P0P2RXZ800`2SXj<0YJFU0:FU
Y@020:JVYP80Z:RX0P2YZJT20:^[Z`80[Jf]0P2^[Zh20;2`/080/K6a0P2c/k<20;Fe]@80][Jf0P2h
^;P20;Zj^P80_;bl00<0_[jn0<30`030`<000P31`L420<C4a080a/K60P38b<P20<_;b`80b/[:0P39
bLT20<O7a`80aLG50P33`l<20;no_`80^k^k0P2h^;P20;Bd]0030;:b/P2^[Zh0[Zj^0080Zj^[0P2Y
ZJT20:NWY`80YZJV0P2TY:@>0:>SX`L0Y:BT2P2SXj<80:BTY0H0Xj>S1@2RXZ820:6QX@@0X:2P0P2O
Wil209jNWP80WIfM102LW9`409ZJVP80VIVI102HV9P209NGU`<0UYJF102DU9@209>CT`80TY:B0P2A
TI44092@T080Shn?0P2=SHd408^;R`80RXZ:0P28R8P208N7Q`80QHF500<0PX:20820P020P8000P1n
OWh207]kN`80NGUi0P1hN7P407IfMP@0MGEe0P1hN7P207MgM`80N7Qh0P1iNGT207QhN080NWYj00<0
O7al07emO@1mOGd00P20P80208:2PP80QXJ60P2:RXX208j>SP80TY:B5@3oool001<0oooo0P2HV9P2
09VIV@80VYZJ0P2LW9`209jNWP80WinO0P2PX:020::RXP030:>SX`2UYJD0YJFU0080YZJV0P2XZ:P2
0:VYZ@80Zj^[0P2][Jd20:j^[P80/;2`0P2a/K420;>c/`80]KFe0P2f][H20;Rh^080^[Zj0P2l_;`0
0`2n_[h0`<300<30`0020<71`@80a<C40P36a/H20<S8b080bl_;0P3:b/X20<W9b@80alO70P35aLD2
0<?3``80_kno0P2k^k/20;Rh^080];Bd00<0/[:b0:j^[P2^[Zh00P2[Zj/20:VYZ@80YjNW0P2VYZH2
0:BTY0h0Xj>S1`2TY:@:0:>SX`P0Y:BT1P2SXj<50::RXP80XJ6Q102PX:0209nOW`80WYjN0P2MWId4
09bLW0@0VYZJ0P2IVIT409RHV080UiNG0`2FUYH409BDU080Ti>C0P2BTY82096AT@@0T92@0P2?Shl2
08f=S@@0Rh^;0P2:RXX208R8R080QhN70P25QHD00`22PX80P8200820P00207inOP80Ng]k0P1iNGT2
07QhN0@0MWIf101eMGD207QhN080MgMg0P1hN7P207UiN@80N7Qh0P1jNWX00`1lO7`0OGem07emO@02
0820P080PX:20P26QXH208Z:RP80SXj>0P2BTY8E0?ooo`004`3oool209RHV080VIVI0P2KVi/209fM
W@80WYjN0P2OWil20:6QX@80Xj>S00<0Y:BT0:JVYP2VYZH00P2XZ:P20:VYZ@80Zj^[0P2][Jd20:j^
[P80/;2`0P2b/[820;Bd]080]KFe0P2g]kL20;Vi^@80^k^k0P2m_Kd20;no_`030<71`@33`l<0`l?3
0080aLG50P37alL20<W9b@80c<c<103>c/h20<o?c`80cLg=0P3:b/X20<S8b080`l?30P2n_[h20;Zj
^P80][Jf00<0/k>c0:n_[`2_[jl00P2][Jd20:ZZZP80Z:RX0P2VYZH20:FUY@X0Xj>S1P2TY:@50:FU
Y@@0Y:BT402UYJD40:BTY0D0Xj>S0P2RXZ840:6QX@80X:2P0P2OWil209jNWP80WIfM0P2LW9`209^K
V`80VYZJ102IVIT209RHV080UiNG0`2FUYH209FEU@80U9BD0P2CTi<209:BTP80TI6A0P2@T90208n?
S`80SXj>0P2=SHd208^;R`80RXZ:0P28R8P208J6QP80Q8B40P20P8000`1mOGd0O7al07alO00207Ui
N@80MgMg0P1eMGD207AdM080Lg=c1P1bLW8207EeM@@0M7Ad0P1fMWH207EeM@80N7Qh00<0NWYj07]k
N`1kNg/00P1nOWh208:2PP80QXJ60P2:RXX208j>SP80TY:B5@3oool001<0oooo0P2HV9P209VIV@80
Vi^K0P2MWId209jNWP80WinO0P2QXJ420:>SX`030:BTY02VYZH0YZJV0080Z:RX0P2YZJT20:^[Z`80
[Jf]0P2^[Zh20;2`/080/[:b0P2d];@20;Fe]@80]kNg0P2i^KT20;^k^`80_Kfm0P2o_kl00`31`L40
`l?30<?3``020<G5a@80alO70P39bLT20<c<c0@0c/k>0P3?cll20<g=c@80b/[:0P38b<P20<?3``80
_[jn0P2j^[X20;Jf]P030;>c/`2_[jl0[jn_0080[Jf]0P2ZZZX20:RXZ080YZJV0P2UYJD:0:>SX`H0
Y:BT1@2UYJD40:BTY100YJFU102TY:@50:>SX`80XZ:R102QXJ420:2PX080WinO0P2NWYh209fMW@80
W9bL0P2KVi/209ZJVP@0VIVI0P2HV9P209NGU`<0UYJF0P2EUID209BDU080Ti>C0P2BTY82096AT@80
T92@0P2?Shl208j>SP80SHf=0P2;Rh/208Z:RP80R8R80P26QXH208B4Q080P82000<0OGem07alO01l
O7`00P1iNGT207MgM`80MGEe0P1dM7@207=cL`H0LW9b0P1eMGD407AdM080MWIf0P1eMGD207QhN003
07YjNP1kNg/0Ng]k0080OWin0P22PX8208J6QP80RXZ:0P2>SXh209:BTQD0oooo000C0?ooo`80V9RH
0P2JVYX209^KV`80WIfM0P2OWil20:2PX080XZ:R0P2SXj<00`2UYJD0YjNW0:NWY`020:VYZ@80ZZZZ
0P2/[:`20:j^[P80/;2`0P2b/[820;Bd]080][Jf0P2h^;P20;Vi^@80^k^k0P2m_Kd20;no_`80`/;2
00<0a<C40<K6aP36a/H00P38b<P20<[:bP80cLg=0P3?cll20=7Ad@80d];B103Cdm<20<o?c`80cLg=
0P38b<P20<;2`P80_;bl0P2h^;P00`2d];@0/;2`0;2`/0020:f][@80ZZZZ0P2XZ:P20:NWY`80YJFU
302TY:@70:FUYAP0YZJV102UYJD30:BTY0@0Xj>S0P2RXZ820:6QX@80X:2P0P2OWil209jNWP80WIfM
0P2KVi/409ZJVP80VIVI0P2HV9P209NGU`<0UYJF0P2EUID209BDU0@0TY:B0P2ATI4208n?S`80SXj>
0P2=SHd208^;R`80RXZ:0P28R8P208F5Q@80PX:20P1nOWh207alO00307UiN@1hN7P0N7Qh0080MGEe
0P1cLg<2079bLP80L71`1P1_Kfl2071`L0H0LG5a0P1bLW8207=cL`80MWIf00<0MgMg07UiN@1iNGT0
0P1mOGd20861P@80QHF50P29RHT208j>SP80TY:B5@3oool001<0oooo0P2HV9P209ZJVP80Vi^K0P2M
WId209nOW`80X:2P0P2RXZ820:>SX`030:FUY@2WYjL0YjNW0080ZJVY0P2ZZZX20:b/[080[Zj^0P2`
/;020;:b/P80];Bd0P2f][H20;Rh^080^KVi0P2k^k/20;fm_@80_kno0P32`/800`34a<@0a/K60<K6
aP020<S8b080b/[:0P3=cLd20<o?c`80dM7A0P3Bd]840=?Cd`80clo?0P3=cLd20<S8b080`/;20P2l
_;`20;Rh^0030;Bd]02`/;00/;2`0080[Jf]0P2ZZZX20:RXZ080YjNW0P2UYJD<0:BTY0L0YJFU602V
YZH40:FUY@<0Y:BT102SXj<20::RXP80XJ6Q0P2PX:0209nOW`80WYjN0P2MWId209^KV`@0VYZJ0P2I
VIT209RHV080UiNG0`2FUYH209FEU@80U9BD102BTY82096AT@80Shn?0P2>SXh208f=S@80Rh^;0P2:
RXX208R8R080QHF50P22PX8207inOP80O7al00<0NGUi07QhN01hN7P00P1eMGD207=cL`80LW9b0P1`
L70606m_K`80L71`1P1aLG42079bLP80Lg=c0P1fMWH00`1gMgL0NGUi07UiN@0207emO@80PH610P25
QHD208V9R@80SXj>0P2BTY8E0?ooo`004`3oool209RHV080VYZJ0P2LW9`209fMW@80WinO0P2QXJ42
0:>SX`80Y:BT00<0YZJV0:RXZ02XZ:P00P2ZZZX20:b/[080[Zj^0P2`/;020;:b/P80/k>c0P2f][H2
0;Rh^080^[Zj0P2l_;`20;fm_@80`<300P32`/820<C4a0030<O7a`39bLT0bLW90080bl_;0P3=cLd2
0=3@d080d];B0P3EeMD20=KFeP@0f=SH0P3EeMD20=7Ad@80cLg=0P37alL20;no_`80^KVi00<0];Bd
0;6a/@2a/K400P2][Jd20:ZZZP80Z:RX0P2WYjL20:FUY@P0Y:BT1P2UYJD50:JVYQX0YjNW0P2VYZH3
0:FUY@80Y:BT0P2SXj<20::RXP@0XJ6Q0P2PX:0209jNWP80WIfM0P2LW9`209^KV`80VYZJ0P2IVIT2
09RHV080UiNG0P2FUYH309FEU@80Ti>C0P2BTY82096AT@80T92@0P2>SXh208f=S@80Rh^;0P29RHT2
08N7Q`80Q8B40P1oOgl207alO080NWYj0P1gMgL00`1eMGD0M7Ad07AdM002079bLP80L71`0P1^KVh2
06e]K@H0K6a/1P1]KFd206i^KP80Kfm_0P1bLW8207=cL`0307EeM@1hN7P0N7Qh0080OGem0P21PH42
08F5Q@80RHV90P2=SHd209:BTQD0oooo000C0?ooo`80V9RH0P2JVYX209bLW080WIfM0P2OWil20:6Q
X@80Xj>S0P2TY:@00`2VYZH0Z:RX0:RXZ0020:ZZZP80[:b/0P2^[Zh20;2`/080/[:b0P2c/k<20;Jf
]P80^;Rh0P2j^[X20;bl_080_Kfm0P30`<020<;2`P80a<C400<0alO70<W9b@39bLT00P3;bl/20<g=
c@80d=3@0P3Bd]820=GEe@80e]KF103Hf=P20=GEe@80dM7A0P3=cLd20<O7a`80_kno0P2i^KT00`2d
];@0/K6a0;6a/@020:f][@80ZZZZ0P2XZ:P20:NWY`80YJFU202TY:@60:FUY@D0YZJV6P2WYjL20:JV
YP<0YJFU0P2TY:@20:>SX`80XZ:R102QXJ420:2PX080WYjN0P2MWId209bLW080Vi^K0P2JVYX209VI
V@80V9RH0P2GUiL209JFUP<0UIFE0P2CTi<209:BTP80TI6A0P2@T90208j>SP80SHf=0P2;Rh/208V9
R@80QhN70P24Q8@207moO`80O7al0P1jNWX207MgM`0307EeM@1dM7@0M7Ad0080LW9b0P1`L70206i^
KP80KFe]1P1/K6`606e]K@80KVi^0P1_Kfl2079bLP80Lg=c00<0MGEe07QhN01hN7P00P1mOGd20861
P@80QHF50P29RHT208f=S@80TY:B5@3oool001<0oooo0P2HV9P209ZJVP80W9bL0P2NWYh20:2PX080
XJ6Q0P2SXj<20:FUY@030:NWY`2YZJT0ZJVY0080Zj^[0P2][Jd20:n_[`80/K6a0P2c/k<20;Fe]@80
]kNg0P2j^[X20;^k^`80_[jn0P30`<020<;2`P80a<C40P37alL00`39bLT0c<c<0<c<c0020<k>cP80
dM7A0P3Cdm<20=KFeP80f=SH0P3IfMT40=cLg080f][J0P3EeMD20=7Ad@80bl_;0P34a<@20;^k^`03
0;Bd]02a/K40/K6a0080[Jf]0P2ZZZX20:RXZ080YZJV0P2UYJD60:BTY0@0YJFU1P2VYZH30:NWYaX0
Z:RX102WYjL00`2VYZH0YJFU0:FUY@020:BTY080Xj>S102RXZ820:2PX080WinO0P2NWYh209bLW080
Vi^K0P2JVYX209VIV@80V9RH0P2GUiL209JFUP<0UIFE0P2CTi<209:BTP80TI6A0P2?Shl208f=S@80
Rh^;0P29RHT208N7Q`80Ph>30P1nOWh207YjNP80N7Qh0P1gMgL207=cL`03075aL@1`L700L71`0080
KVi^0P1]KFd206a/K080Jf][2P1YJFT406][J`80KVi^0P1`L702075aL@0307AdM01hN7P0N7Qh0080
O7al0P20P80208B4Q080RHV90P2=SHd209:BTQD0oooo000C0?ooo`80V9RH0P2JVYX209bLW080WYjN
0P2PX:020:6QX@80Xj>S0P2UYJD00`2WYjL0ZJVY0:VYZ@020:^[Z`80[Jf]0P2_[jl20;6a/@80/k>c
0P2e]KD20;Ng]`80^[Zj0P2k^k/20;jn_P80`<300P32`/820<C4a080alO700<0bLW90<c<c03<c<`0
0P3>c/h20=7Ad@80dm?C0P3Fe]H20=SHf080fMWI103Lg=`20=[JfP80eMGE0P3AdM420<_;b`80a<C4
0P2k^k/00`2d];@0/K6a0;6a/@020:f][@80ZZZZ0P2XZ:P20:JVYP80YJFU1P2TY:@40:FUY@H0YZJV
0`2WYjLJ0:RXZ0@0YjNW00<0YZJV0:FUY@2UYJD00P2TY:@20:>SX`@0XZ:R0P2PX:0209nOW`80WYjN
0P2LW9`209^KV`80VYZJ0P2IVIT209RHV080UiNG0P2FUYH309FEU@80Ti>C0P2BTY82096AT@80Shn?
0P2=SHd208^;R`80RHV90P27QhL208>3P`80OWin0P1jNWX207QhN080MgMg0P1cLg<00`1aLG40L71`
071`L00206i^KP80KFe]0P1/K6`206][J`X0JFUY101[Jf/206i^KP80L71`0P1aLG400`1dM7@0N7Qh
07QhN00207alO080P8200P24Q8@208V9R@80SHf=0P2BTY8E0?ooo`004`3oool209RHV080VYZJ0P2L
W9`209jNWP80X:2P0P2RXZ820:BTY080YZJV00<0Z:RX0:ZZZP2ZZZX00P2/[:`20:j^[P80/K6a0P2c
/k<20;Fe]@80]kNg0P2i^KT20;^k^`80_Kfm0P30`<020<;2`P80a<C40P37alL20<W9b@030<c<c03>
c/h0c/k>0080dM7A0P3De=@20=KFeP80fMWI0P3Kfm/20=gMg@80gmoO0P3Ph>020=kNgP80fMWI0P3D
e=@20<k>cP80alO70P2o_kl00`2f][H0/;2`0;2`/0020:b/[080ZJVY0P2WYjL20:JVYPH0Y:BT1P2U
YJD40:JVYP@0YjNW00<0Z:RX0:VYZ@2YZJT06P2YZJT20:RXZ0030:NWY`2VYZH0YZJV00@0YJFU0P2S
Xj<20::RXP80XJ6Q0P2PX:0209jNWP80WIfM0P2KVi/409ZJVP80V9RH0P2GUiL209JFUP0309FEU@2D
U9@0U9BD0080Ti>C0P2ATI42092@T080SHf=0P2;Rh/208V9R@80QXJ60P22PX8207emO@80N7Qh0P1f
MWH207AdM080LW9b0P1_Kfl00`1]KFd0K6a/06a/K00206][J`80JVYZ0P1YJFT206QXJ0X0IVIV0P1X
J6P206UYJ@80K6a/0P1^KVh2071`L00307=cL`1hN7P0N7Qh0080Ng]k0P1oOgl208B4Q080RHV90P2=
SHd209:BTQD0oooo000C0?ooo`80V9RH0P2JVYX209bLW080WYjN0P2PX:020::RXP80Y:BT0P2VYZH0
0`2XZ:P0ZZZZ0:ZZZP020:b/[080[Zj^0P2a/K420;>c/`80]KFe0P2g]kL20;Vi^@80^k^k0P2m_Kd2
0<30`080`/;20P34a<@20<O7a`80bLW900<0c<c<0<k>cP3>c/h00P3AdM420=CDe080e]KF0P3IfMT2
0=_Kf`80gMgM0P3Ogml20>3Ph080g]kN0P3IfMT20=CDe080c/k>0P37alL20;no_`030;Jf]P2`/;00
/;2`0080[:b/0P2YZJT20:NWY`80YZJV1P2TY:@60:FUY@@0YZJV102WYjL00`2XZ:P0ZJVY0:VYZ@0J
0:VYZ@80Z:RX00<0YjNW0:JVYP2VYZH0102UYJD20:>SX`80XZ:R0P2QXJ420:2PX080WYjN0P2MWId2
09^KV`@0VYZJ0P2HV9P209NGU`80UYJF00<0UIFE09BDU02DU9@00P2CTi<2096AT@80T92@0P2=SHd2
08^;R`80RHV90P26QXH208:2PP80OGem0P1hN7P207IfMP80M7Ad0P1bLW8206m_K`0306e]K@1/K6`0
K6a/0080Jf][0P1ZJVX206UYJ@80J6QX2P1VIVH206QXJ080JFUY0P1/K6`206i^KP80L71`00<0Lg=c
07QhN01hN7P00P1kNg/207moO`80Q8B40P29RHT208f=S@80TY:B5@3oool001<0oooo0P2HV9P209ZJ
VP80W9bL0P2NWYh20:2PX080Xj>S0P2UYJD20:NWY`030:VYZ@2[Zj/0Zj^[0080[Jf]0P2`/;020;:b
/P80];Bd0P2f][H20;Rh^080^k^k0P2m_Kd20;no_`80`/;20P34a<@20<O7a`80bLW90P3<c<`00`3?
cll0dM7A0=7Ad@020=CDe080e]KF0P3IfMT20=cLg080gmoO0P3QhN420>;RhP80i>CT0P3QhN420=cL
g080f=SH0P3AdM420<W9b@80`/;200<0^[Zj0;6a/@2a/K400P2ZZZX20:RXZ080YJFU102TY:@20:>S
X`80Y:BT102UYJD40:JVYP80YjNW102XZ:P30:VYZ@P0ZZZZ2P2[Zj/80:ZZZP80ZJVY0`2XZ:P20:NW
Y`80YZJV0P2TY:@20:>SX`80XZ:R0P2PX:0209nOW`80WIfM0P2LW9`209^KV`80VYZJ0P2HV9P209NG
U`80UIFE00<0U9BD09>CT`2CTi<00P2ATI42092@T080SXj>0P2<S8`208R8R080QHF50P21PH4207al
O080MgMg0P1dM7@2079bLP80L71`0P1^KVh206][J`0306YZJP1YJFT0JFUY0080J6QX0P1VIVH206EU
I@80I6AT0P1SHf<2069RHP@0Hf=S0P1TI6@206IVIP80IfMW0P1YJFT206a/K080Kfm_00<0Lg=c07Mg
M`1gMgL00P1kNg/207moO`80Q8B40P28R8P208f=S@80TY:B5@3oool001<0oooo0P2HV9P209ZJVP80
W9bL0P2NWYh20:2PX080Xj>S0P2UYJD20:NWY`030:VYZ@2[Zj/0Zj^[0080[Jf]0P2`/;020;:b/P80
];Bd0P2f][H20;Rh^080^k^k0P2m_Kd20;no_`80`/;20P34a<@20<O7a`80bLW90P3<c<`00`3?cll0
dM7A0=7Ad@020=CDe080e]KF0P3IfMT20=cLg080gmoO0P3QhN420>;RhP80i>CT0P3QhN420=cLg080
f=SH0P3AdM420<W9b@80`/;200<0^[Zj0;6a/@2a/K400P2ZZZX20:RXZ080YJFU102TY:@20:>SX`80
Y:BT102UYJD40:JVYP80YjNW102XZ:P30:VYZ@P0ZZZZ2P2[Zj/80:ZZZP80ZJVY0`2XZ:P20:NWY`80
YZJV0P2TY:@20:>SX`80XZ:R0P2PX:0209nOW`80WIfM0P2LW9`209^KV`80VYZJ0P2HV9P209NGU`80
UIFE00<0U9BD09>CT`2CTi<00P2ATI42092@T080SXj>0P2<S8`208R8R080QHF50P21PH4207alO080
MgMg0P1dM7@2079bLP80L71`0P1^KVh206][J`0306YZJP1YJFT0JFUY0080J6QX0P1VIVH206EUI@80
I6AT0P1SHf<2069RHP@0Hf=S0P1TI6@206IVIP80IfMW0P1YJFT206a/K080Kfm_00<0Lg=c07MgM`1g
MgL00P1kNg/207moO`80Q8B40P28R8P208f=S@80TY:B5@3oool001<0oooo0P2HV9P209ZJVP80WIfM
0P2OWil20:6QX@80Xj>S0P2UYJD20:RXZ0030:ZZZP2/[:`0[:b/0080[jn_0P2a/K420;>c/`80]KFe
0P2h^;P20;Zj^P80_;bl0P2o_kl20<71`@80a<C40P36a/H20<W9b@80c<c<0P3>c/h00`3AdM40e=CD
0=CDe0020=KFeP80fMWI0P3Lg=`20=oOg`80h^;R0P3Ti>@20>GUi@80inOW0P3Shn<20=oOg`80f][J
0P3Cdm<20<c<c080aLG500<0_Kfm0;Bd]02d];@00P2ZZZX40:BTY0H0Xj>S102TY:@20:FUY@80YZJV
102WYjL20:RXZ080ZJVY0`2ZZZX60:^[Za00[:b/102[Zj/20:ZZZP<0ZJVY0P2XZ:P20:NWY`80YJFU
0P2TY:@20:>SX`80XJ6Q0P2OWil209jNWP80W9bL0P2KVi/209ZJVP80V9RH0P2FUYH209FEU@0309>C
T`2ATI40TI6A0080T92@0P2>SXh208b<S080R8R80P25QHD207moO`80Ng]k0P1gMgL207=cL`80LG5a
0P1_Kfl206a/K080JVYZ0P1XJ6P00`1WIfL0IVIV06IVIP0206ATI080HV9R0P1QHF4:061PH080HV9R
0P1TI6@206EUI@80IfMW0P1[Jf/206i^KP03079bLP1fMWH0MWIf0080Ng]k0P1oOgl208B4Q080RHV9
0P2=SHd209:BTQD0oooo000C0?ooo`80V9RH0P2JVYX209fMW@80WinO0P2QXJ420:>SX`80YJFU0P2X
Z:P00`2ZZZX0[:b/0:b/[0020:n_[`80/K6a0P2c/k<20;Fe]@80^;Rh0P2j^[X20;bl_080_kno0P31
`L420<C4a080a/K60P39bLT20<c<c080c/k>00<0dM7A0=CDe03De=@00P3Fe]H20=WIf@80g=cL0P3O
gml20>;RhP80i>CT0P3UiND20>OWi`80hn?S0P3Ogml20=[JfP80dm?C0P3<c<`20<G5a@030;fm_@2d
];@0];Bd0080ZZZZ102TY:@60:>SX`@0Y:BT0P2UYJD20:JVYP@0YjNW0P2XZ:P20:VYZ@<0ZZZZ1P2[
Zj/@0:b/[0@0Zj^[0P2ZZZX30:VYZ@80Z:RX0P2WYjL20:FUY@80Y:BT0P2SXj<20:6QX@80WinO0P2N
WYh209bLW080Vi^K0P2JVYX209RHV080UYJF0P2EUID00`2CTi<0TI6A096AT@02092@T080SXj>0P2<
S8`208R8R080QHF50P1oOgl207]kN`80MgMg0P1cLg<2075aL@80Kfm_0P1/K6`206YZJP80J6QX00<0
IfMW06IVIP1VIVH00P1TI6@2069RHP80HF5Q2P1PH602069RHP80I6AT0P1UIFD206MWI`80Jf][0P1^
KVh00`1bLW80MWIf07IfMP0207]kN`80Ogmo0P24Q8@208V9R@80SHf=0P2BTY8E0?ooo`004`3oool2
09VIV@80Vi^K0P2MWId209nOW`80XZ:R0P2TY:@20:JVYP80Z:RX00<0Zj^[0:f][@2][Jd00P2`/;02
0;:b/P80];Bd0P2g]kL20;Vi^@80_;bl0P2n_[h20<71`@80`l?30P36a/H20<S8b080bl_;0P3>c/h2
0=7Ad@030=?Cd`3Fe]H0e]KF0080fMWI0P3Lg=`20=oOg`80h^;R0P3UiND20>OWi`80j>SX0P3YjNT2
0>GUi@80hN7Q0P3Kfm/20=GEe@80c/k>0P37alL00`2n_[h0]KFe0;Fe]@020:^[Z`@0XZ:R0P2QXJ44
0::RXP80Xj>S0P2TY:@20:FUY@80YZJV0P2WYjL20:RXZ080ZJVY0P2ZZZX30:^[Z`H0[:b/402][Jd4
0:b/[0<0Zj^[0P2ZZZX20:VYZ@80Z:RX0P2VYZH20:FUY@80Xj>S0P2QXJ4209nOW`80WYjN0P2MWId2
09^KV`80VIVI0P2GUiL209FEU@80Ti>C00<0TY:B08n?S`2?Shl00P2>SXh208^;R`80RHV90P23Ph<2
07moO`80NWYj0P1fMWH2079bLP80Kfm_0P1]KFd206][J`80JFUY0P1VIVH206ATI00306=SH`1RHV80
HV9R0080HF5Q0P1OGel405iNGPH0GEeM0P1NGUh2061PH080HF5Q0P1SHf<206IVIP80JFUY0P1]KFd0
0`1bLW80MWIf07IfMP0207]kN`80Ogmo0P24Q8@208V9R@80SHf=0P2BTY8E0?ooo`004`3oool209VI
V@80Vi^K0P2MWId209nOW`80XZ:R0P2TY:@20:JVYP80Z:RX00<0Zj^[0:f][@2][Jd00P2`/;020;:b
/P80];Bd0P2g]kL20;Vi^@80_;bl0P2n_[h20<71`@80`l?30P36a/H20<S8b080bl_;0P3>c/h20=7A
d@030=?Cd`3Fe]H0e]KF0080fMWI0P3Lg=`20=oOg`80h^;R0P3UiND20>OWi`80j>SX0P3YjNT20>GU
i@80hN7Q0P3Kfm/20=GEe@80c/k>0P37alL00`2n_[h0]KFe0;Fe]@020:^[Z`@0XZ:R0P2QXJ440::R
XP80Xj>S0P2TY:@20:FUY@80YZJV0P2WYjL20:RXZ080ZJVY0P2ZZZX30:^[Z`H0[:b/402][Jd40:b/
[0<0Zj^[0P2ZZZX20:VYZ@80Z:RX0P2VYZH20:FUY@80Xj>S0P2QXJ4209nOW`80WYjN0P2MWId209^K
V`80VIVI0P2GUiL209FEU@80Ti>C00<0TY:B08n?S`2?Shl00P2>SXh208^;R`80RHV90P23Ph<207mo
O`80NWYj0P1fMWH2079bLP80Kfm_0P1]KFd206][J`80JFUY0P1VIVH206ATI00306=SH`1RHV80HV9R
0080HF5Q0P1OGel405iNGPH0GEeM0P1NGUh2061PH080HF5Q0P1SHf<206IVIP80JFUY0P1]KFd00`1b
LW80MWIf07IfMP0207]kN`80Ogmo0P24Q8@208V9R@80SHf=0P2BTY8E0?ooo`004`3oool209VIV@80
Vi^K0P2NWYh20:2PX080XZ:R0P2TY:@20:NWY`80ZJVY00<0[:b/0:j^[P2^[Zh00P2a/K420;>c/`80
][Jf0P2h^;P20;^k^`80_Kfm0P30`<020<?3``80aLG50P38b<P20<[:bP80cLg=0P3@d=020=?Cd`03
0=KFeP3IfMT0fMWI0080g=cL0P3Ogml20>;RhP80iNGU0P3Xj>P20>[ZjP80k>c/0P3[jn/20>OWi`80
hn?S0P3MgMd20=KFeP80clo?0P38b<P00`2o_kl0][Jf0;Jf]P020:b/[080Xj>S102PX:020:6QX@80
XZ:R0P2SXj<20:BTY080YJFU0P2WYjL20:RXZ080ZJVY0P2ZZZX30:^[Z`80[:b/102][JdB0:j^[P@0
[Jf]0`2/[:`20:^[Z`80ZZZZ0P2YZJT20:NWY`80YJFU0P2SXj<20:6QX@80WinO0P2NWYh209fMW@80
Vi^K0P2HV9P209JFUP80U9BD0P2BTY800`2@T900SHf=08f=S@0208Z:RP80QhN70P23Ph<207inOP80
NWYj0P1fMWH2079bLP80KVi^0P1/K6`206YZJP80J6QX0P1UIFD206=SH`80HV9R00<0H61P05mOG`1O
Gel00P1NGUh205aLG0@0Fe]K101JFUX205]KF`80G5aL0P1NGUh205mOG`80HV9R0P1UIFD206UYJ@80
KFe]00<0LW9b07IfMP1fMWH00P1jNWX207moO`80Q8B40P28R8P208f=S@80TY:B5@3oool001<0oooo
0P2IVIT209^KV`80WYjN0P2PX:020::RXP80Y:BT0P2WYjL20:VYZ@030:b/[02^[Zh0[Zj^0080/K6a
0P2c/k<20;Jf]P80^;Rh0P2k^k/20;fm_@80`<300P33`l<20<G5a@80b<S80P3:b/X20<g=c@80d=3@
0P3Cdm<00`3Fe]H0fMWI0=WIf@020=cLg080gmoO0P3Rh^820>GUi@80j>SX0P3Zj^X20>c/k080jn_[
0P3WinL20>?Sh`80gMgM0P3Fe]H20<o?c`80b<S800<0_kno0;Jf]P2f][H00P2/[:`20:>SX`@0X:2P
0P2QXJ420::RXP80Xj>S0P2TY:@20:FUY@80YjNW0P2XZ:P20:VYZ@80ZZZZ0`2[Zj/20:b/[0@0[Jf]
4P2^[Zh40:f][@<0[:b/0P2[Zj/20:ZZZP80ZJVY0P2WYjL20:FUY@80Xj>S0P2QXJ4209nOW`80WYjN
0P2MWId209^KV`80V9RH0P2FUYH209BDU080TY:B00<0T92@08f=S@2=SHd00P2:RXX208N7Q`80Ph>3
0P1nOWh207YjNP80MWIf0P1bLW8206i^KP80K6a/0P1ZJVX206QXJ080IFEU0P1SHf<2069RHP03061P
H01OGel0GemO0080GUiN0P1LG5`405]KF`@0FUYJ0P1KFe/205aLG080GUiN0P1OGel2069RHP80IFEU
0P1YJFT206e]K@03079bLP1fMWH0MWIf0080NWYj0P1oOgl208B4Q080R8R80P2=SHd209:BTQD0oooo
000C0?ooo`80VIVI0P2LW9`209jNWP80X:2P0P2SXj<20:FUY@80YjNW0P2ZZZX00`2][Jd0[jn_0:n_
[`020;:b/P80];Bd0P2g]kL20;Zj^P80_;bl0P2o_kl20<71`@80a<C40P37alL20<[:bP80c<c<0P3?
cll20=;BdP80eMGE00<0f=SH0=_Kf`3Kfm/00P3Ng]h20>;RhP80iNGU0P3Xj>P20>_[j`80kNg]0P3^
k^h20>g]k@80j>SX0P3Ti>@20=gMg@80emOG0P3@d=020<S8b0030<30`02f][H0][Jf0080[Jf]0P2U
YJD209fMW@80WYjN0P2PX:020:6QX@80Xj>S0P2TY:@20:JVYP80YjNW0P2XZ:P20:VYZ@80Zj^[0`2/
[:`20:f][@@0[Zj^202_[jl40;2`/0P0[jn_0P2^[Zh30:f][@80[:b/0P2[Zj/20:ZZZP80Z:RX0P2V
YZH20:>SX`80XJ6Q0P2PX:0209nOW`80WIfM0P2IVIT209NGU`80UIFE0P2BTY82092@T00308f=S@28
R8P0R8R80080QXJ60P22PX8207inOP80NWYj0P1fMWH2079bLP80KVi^0P1[Jf/206QXJ080IfMW0P1T
I6@2069RHP80GemO0P1NGUh00`1LG5`0Fe]K05]KF`0205YJFP80FEUI0P1HF5P405MGE`80F5QH0P1I
FET205YJFP80G5aL0P1NGUh2065QH@80IFEU0P1XJ6P206e]K@03079bLP1fMWH0MWIf0080NWYj0P1o
Ogl208B4Q080R8R80P2=SHd209:BTQD0oooo000C0?ooo`80VIVI0P2LW9`209jNWP80X:2P0P2SXj<2
0:FUY@80YjNW0P2ZZZX00`2][Jd0[jn_0:n_[`020;:b/P80];Bd0P2g]kL20;Zj^P80_;bl0P2o_kl2
0<71`@80a<C40P37alL20<[:bP80c<c<0P3?cll20=;BdP80eMGE00<0f=SH0=_Kf`3Kfm/00P3Ng]h2
0>;RhP80iNGU0P3Xj>P20>_[j`80kNg]0P3^k^h20>g]k@80j>SX0P3Ti>@20=gMg@80emOG0P3@d=02
0<S8b0030<30`02f][H0][Jf0080[Jf]0P2UYJD209fMW@80WYjN0P2PX:020:6QX@80Xj>S0P2TY:@2
0:JVYP80YjNW0P2XZ:P20:VYZ@80Zj^[0`2/[:`20:f][@@0[Zj^202_[jl40;2`/0P0[jn_0P2^[Zh3
0:f][@80[:b/0P2[Zj/20:ZZZP80Z:RX0P2VYZH20:>SX`80XJ6Q0P2PX:0209nOW`80WIfM0P2IVIT2
09NGU`80UIFE0P2BTY82092@T00308f=S@28R8P0R8R80080QXJ60P22PX8207inOP80NWYj0P1fMWH2
079bLP80KVi^0P1[Jf/206QXJ080IfMW0P1TI6@2069RHP80GemO0P1NGUh00`1LG5`0Fe]K05]KF`02
05YJFP80FEUI0P1HF5P405MGE`80F5QH0P1IFET205YJFP80G5aL0P1NGUh2065QH@80IFEU0P1XJ6P2
06e]K@03079bLP1fMWH0MWIf0080NWYj0P1oOgl208B4Q080R8R80P2=SHd209:BTQD0oooo000C0?oo
o`80VIVI0P2LW9`209jNWP80XJ6Q0P2SXj<20:JVYP80Z:RX0P2[Zj/00`2^[Zh0/;2`0;2`/0020;>c
/`80]KFe0P2h^;P20;^k^`80_[jn0P30`<020<?3``80a/K60P39bLT20<c<c080c/k>0P3AdM420=CD
e080emOG00<0f][J0=kNgP3Ng]h00P3QhN420>CTi080inOW0P3[jn/20>g]k@@0l?3`0P3^k^h20>WY
j@80i>CT0P3Ng]h20=SHf080dM7A0P38b<P00`2o_kl0]kNg0;Ng]`020:n_[`80YZJV0P2KVi/209fM
W@80WinO0P2QXJ420:>SX`80YJFU0P2VYZH20:RXZ080ZJVY0P2ZZZX40:b/[0030:f][@2^[Zh0[Zj^
00@0[jn_202`/;080;6a/@80/;2`102_[jl30:j^[P80[Jf]0P2/[:`20:^[Z`80ZJVY0P2VYZH20:>S
X`@0XJ6Q0P2OWil209bLW080V9RH0P2FUYH209>CT`80T92@0P2=SHd00`28R8P0Q8B408B4Q0020861
P@80OWin0P1jNWX207IfMP80LW9b0P1_Kfl206YZJP80IfMW0P1UIFD206=SH`80HF5Q0P1NGUh205aL
G080Fe]K0`1IFET205MGE`80EUIF0P1EEED405ADE080EEEE0P1GEeL205QHF080FUYJ0P1MGEd2065Q
H@80I6AT0P1XJ6P206e]K@03075aL@1fMWH0MWIf0080NWYj0P1oOgl208B4Q080R8R80P2=SHd209:B
TQD0oooo000C0?ooo`80VIVI0P2LW9`209jNWP80XJ6Q0P2SXj<20:JVYP80Z:RX0P2[Zj/00`2^[Zh0
/;2`0;2`/0020;>c/`80]KFe0P2h^;P20;^k^`80_[jn0P30`<020<?3``80a/K60P39bLT20<c<c080
c/k>0P3AdM420=CDe080emOG00<0f][J0=kNgP3Ng]h00P3QhN420>CTi080inOW0P3[jn/20>g]k@@0
l?3`0P3^k^h20>WYj@80i>CT0P3Ng]h20=SHf080dM7A0P38b<P00`2o_kl0]kNg0;Ng]`020:n_[`80
YZJV0P2KVi/209fMW@80WinO0P2QXJ420:>SX`80YJFU0P2VYZH20:RXZ080ZJVY0P2ZZZX40:b/[003
0:f][@2^[Zh0[Zj^00@0[jn_202`/;080;6a/@80/;2`102_[jl30:j^[P80[Jf]0P2/[:`20:^[Z`80
ZJVY0P2VYZH20:>SX`@0XJ6Q0P2OWil209bLW080V9RH0P2FUYH209>CT`80T92@0P2=SHd00`28R8P0
Q8B408B4Q0020861P@80OWin0P1jNWX207IfMP80LW9b0P1_Kfl206YZJP80IfMW0P1UIFD206=SH`80
HF5Q0P1NGUh205aLG080Fe]K0`1IFET205MGE`80EUIF0P1EEED405ADE080EEEE0P1GEeL205QHF080
FUYJ0P1MGEd2065QH@80I6AT0P1XJ6P206e]K@03075aL@1fMWH0MWIf0080NWYj0P1oOgl208B4Q080
R8R80P2=SHd209:BTQD0oooo000C0?ooo`80VIVI0P2LW9`209jNWP80XJ6Q0P2SXj<20:JVYP80ZJVY
0P2/[:`00`2^[Zh0/K6a0;6a/@020;Bd]080][Jf0P2i^KT20;bl_080_kno0P32`/820<G5a@80b<S8
0P3;bl/20<g=c@80d=3@0P3Cdm<20=KFeP80fMWI00<0gMgM0>3Ph03Ph>000P3Shn<20>KViP80j^[Z
0P3]kNd20?3`l080l_;b0P3alO420>o_k`80j^[Z0P3UiND20=kNgP80f=SH0P3AdM420<S8b0030;no
_`2h^;P0^;Rh0080[jn_0P2VYZH209ZJVP80WIfM0P2OWil20:6QX@80Xj>S0P2UYJD20:JVYP80Z:RX
0P2ZZZX20:^[Z`80[:b/0P2][Jd00`2^[Zh0[jn_0:n_[`040;2`/0@0/K6a302b/[840;6a/@80/;2`
0`2_[jl20:j^[P80[Jf]0P2[Zj/20:VYZ@80YZJV0P2SXj<20::RXP80XJ6Q0P2NWYh209ZJVP80UiNG
0P2DU9@2096AT@80SHf=0P28R8P00`23Ph<0Ogmo07moO`0207alO080NGUi0P1fMWH2079bLP80KVi^
0P1[Jf/206MWI`80I6AT0P1RHV8205mOG`80GEeM0P1KFe/405UIF@0305MGE`1EEED0EEEE0080E5AD
0P1BDU86055AD@80De=C0P1DE5@205IFEP80FEUI0P1MGEd2061PH080I6AT0P1XJ6P206e]K@03075a
L@1fMWH0MWIf0080Ng]k0P1oOgl208B4Q080R8R80P2=SHd209:BTQD0oooo000C0?ooo`80VIVI0P2L
W9`209jNWP80XJ6Q0P2SXj<20:JVYP80ZJVY0P2/[:`00`2^[Zh0/K6a0;6a/@020;Bd]080][Jf0P2i
^KT20;bl_080_kno0P32`/820<G5a@80b<S80P3;bl/20<g=c@80d=3@0P3Cdm<20=KFeP80fMWI00<0
gMgM0>3Ph03Ph>000P3Shn<20>KViP80j^[Z0P3]kNd20?3`l080l_;b0P3alO420>o_k`80j^[Z0P3U
iND20=kNgP80f=SH0P3AdM420<S8b0030;no_`2h^;P0^;Rh0080[jn_0P2VYZH209ZJVP80WIfM0P2O
Wil20:6QX@80Xj>S0P2UYJD20:JVYP80Z:RX0P2ZZZX20:^[Z`80[:b/0P2][Jd00`2^[Zh0[jn_0:n_
[`040;2`/0@0/K6a302b/[840;6a/@80/;2`0`2_[jl20:j^[P80[Jf]0P2[Zj/20:VYZ@80YZJV0P2S
Xj<20::RXP80XJ6Q0P2NWYh209ZJVP80UiNG0P2DU9@2096AT@80SHf=0P28R8P00`23Ph<0Ogmo07mo
O`0207alO080NGUi0P1fMWH2079bLP80KVi^0P1[Jf/206MWI`80I6AT0P1RHV8205mOG`80GEeM0P1K
Fe/405UIF@0305MGE`1EEED0EEEE0080E5AD0P1BDU86055AD@80De=C0P1DE5@205IFEP80FEUI0P1M
GEd2061PH080I6AT0P1XJ6P206e]K@03075aL@1fMWH0MWIf0080Ng]k0P1oOgl208B4Q080R8R80P2=
SHd209:BTQD0oooo000C0?ooo`80VIVI0P2LW9`209nOW`80XZ:R0P2TY:@20:NWY`80ZZZZ0P2/[:`0
0`2_[jl0/[:b0;:b/P020;Fe]@80]kNg0P2k^k/20;jn_P80`L710P33`l<20<K6aP80bLW90P3<c<`2
0<o?c`80d];B0P3EeMD20=WIf@80g=cL00<0gmoO0>;RhP3Rh^800P3UiND20>WYj@80k>c/0P3`l?02
0?;blP80m?Cd0P3bl_820>o_k`80jn_[0P3UiND20=oOg`80f=SH0P3@d=020<O7a`030<30`02i^KT0
^KVi0080[jn_0P2UYJD209ZJVP80WIfM0P2OWil20:6QX@80Xj>S0P2UYJD20:NWY`80ZJVY0P2ZZZX2
0:b/[080[Jf]0P2^[Zh30;2`/080/K6a1P2b/[8<0;>c/`@0/[:b0P2a/K430;2`/080[jn_0P2][Jd2
0:b/[080ZJVY0P2VYZH20:BTY080Xj>S0P2PX:0209bLW080VIVI0P2EUID209:BTP80SHf=0P29RHT2
08B4Q00307moO`1jNWX0NWYj0080N7Qh0P1eMGD2079bLP80KVi^0P1[Jf/206QXJ080I6AT0P1RHV82
05iNGP80G5aL0P1IFET205QHF080EeMG0P1FEUH00`1DE5@0DU9B059BDP02055AD@80Cdm?101>CTh2
04m?C`80DE5A0P1BDU8205EEE@80F5QH0P1LG5`2061PH080I6AT0P1XJ6P206a/K003075aL@1fMWH0
MWIf0080Ng]k0P1oOgl208B4Q080R8R80P2=SHd209:BTQD0oooo000C0?ooo`80VIVI0P2LW9`209nO
W`80XZ:R0P2UYJD20:RXZ080ZZZZ0P2][Jd00`2`/;00/k>c0;>c/`020;Jf]P80^KVi0P2l_;`20;no
_`80`/;20P35aLD20<S8b080bl_;0P3>c/h20=7Ad@80e=CD0P3GemL20=_Kf`80g]kN00<0hN7Q0>CT
i03Ti>@00P3Xj>P20>_[j`80k^k^0P3bl_840?Gem@80lo?c0P3_knl20>_[j`80iNGU0P3Ng]h20=SH
f080clo?0P38b<P00`31`L40^KVi0;Vi^@020:j^[P80Y:BT0P2JVYX209bLW080WinO0P2QXJ420:>S
X`80YJFU0P2WYjL20:VYZ@80Zj^[0P2/[:`20:j^[P80[jn_00<0/;2`0;6a/@2a/K400P2b/[840;>c
/`P0];Bd0P2c/k<20;Bd]0@0/k>c102b/[820;6a/@030;2`/02_[jl0[jn_0080[Zj^0P2/[:`20:VY
Z@80YZJV0P2UYJD20::RXP80WYjN0P2JVYX209NGU`80Ti>C0P2>SXh208V9R@80QHF50P20P8000`1j
NWX0MWIf07IfMP0207=cL`80LG5a0P1^KVh206][J`80J6QX0P1UIFD2069RHP80GemO0P1KFe/205UI
F@80EUIF0P1EEED205ADE080De=C00<0DE5A04m?C`1?Cdl00P1>CTh204a<C080Bd];0P1<C4`204e=
C@80Cdm?0P1ADE4205EEE@80F5QH0P1KFe/205mOG`80Hf=S0P1XJ6P206a/K003075aL@1fMWH0MWIf
0080Ng]k0P1oOgl208B4Q080R8R80P2=SHd209:BTQD0oooo000C0?ooo`80VIVI0P2LW9`209nOW`80
XZ:R0P2UYJD20:RXZ080ZZZZ0P2][Jd00`2`/;00/k>c0;>c/`020;Jf]P80^KVi0P2l_;`20;no_`80
`/;20P35aLD20<S8b080bl_;0P3>c/h20=7Ad@80e=CD0P3GemL20=_Kf`80g]kN00<0hN7Q0>CTi03T
i>@00P3Xj>P20>_[j`80k^k^0P3bl_840?Gem@80lo?c0P3_knl20>_[j`80iNGU0P3Ng]h20=SHf080
clo?0P38b<P00`31`L40^KVi0;Vi^@020:j^[P80Y:BT0P2JVYX209bLW080WinO0P2QXJ420:>SX`80
YJFU0P2WYjL20:VYZ@80Zj^[0P2/[:`20:j^[P80[jn_00<0/;2`0;6a/@2a/K400P2b/[840;>c/`P0
];Bd0P2c/k<20;Bd]0@0/k>c102b/[820;6a/@030;2`/02_[jl0[jn_0080[Zj^0P2/[:`20:VYZ@80
YZJV0P2UYJD20::RXP80WYjN0P2JVYX209NGU`80Ti>C0P2>SXh208V9R@80QHF50P20P8000`1jNWX0
MWIf07IfMP0207=cL`80LG5a0P1^KVh206][J`80J6QX0P1UIFD2069RHP80GemO0P1KFe/205UIF@80
EUIF0P1EEED205ADE080De=C00<0DE5A04m?C`1?Cdl00P1>CTh204a<C080Bd];0P1<C4`204e=C@80
Cdm?0P1ADE4205EEE@80F5QH0P1KFe/205mOG`80Hf=S0P1XJ6P206a/K003075aL@1fMWH0MWIf0080
Ng]k0P1oOgl208B4Q080R8R80P2=SHd209:BTQD0oooo000C0?ooo`80VIVI0P2LW9`209nOW`80XZ:R
0P2UYJD20:RXZ080Zj^[0P2^[Zh00`2a/K40];Bd0;Bd]0020;Ng]`80^[Zj0P2m_Kd20<30`080`l?3
0P36a/H20<W9b@80c<c<0P3@d=020=?Cd`80e]KF0P3IfMT20=gMg@80h>3P00<0hn?S0>KViP3Vi^H0
0P3Zj^X20>g]k@80lO7a0P3dm?@20?Ogm`80m_Kf0P3clo<20?3`l080jn_[0P3Ti>@20=kNgP80emOG
0P3?cll20<S8b0030<30`02g]kL0]kNg0080[Jf]0P2TY:@209ZJVP80W9bL0P2OWil20:6QX@80Xj>S
0P2VYZH20:RXZ080ZZZZ0P2/[:`20:f][@80[jn_0P2`/;000`2a/K40/[:b0;:b/P020;>c/`H0];Bd
102e]KD:0;Bd]080/k>c102b/[800`2`/;00[jn_0:n_[`020:j^[P80[:b/0P2YZJT20:NWY`80Y:BT
0P2QXJ4209fMW@80VIVI0P2DU9@2092@T080Rh^;0P26QXH20861P@80Ng]k00<0MWIf079bLP1bLW80
0P1_Kfl206e]K@80JVYZ0P1XJ6P206EUI@80Hf=S0P1OGel205aLG080F5QH0P1EEED205=CD`80DU9B
0P1ADE42051@D00304i>CP1=CDd0CDe=0080Bd];1P19BDT204];B`80CDe=0P1@D50205ADE080EeMG
0P1KFe/205mOG`80Hf=S0P1XJ6P206a/K003075aL@1fMWH0MWIf0080NWYj0P1oOgl208B4Q080R8R8
0P2=SHd209:BTQD0oooo000C0?ooo`80VIVI0P2LW9`209nOW`80XZ:R0P2UYJD20:RXZ080Zj^[0P2^
[Zh00`2a/K40];Bd0;Bd]0020;Ng]`80^[Zj0P2m_Kd20<30`080`l?30P36a/H20<W9b@80c<c<0P3@
d=020=?Cd`80e]KF0P3IfMT20=gMg@80h>3P00<0hn?S0>KViP3Vi^H00P3Zj^X20>g]k@80lO7a0P3d
m?@20?Ogm`80m_Kf0P3clo<20?3`l080jn_[0P3Ti>@20=kNgP80emOG0P3?cll20<S8b0030<30`02g
]kL0]kNg0080[Jf]0P2TY:@209ZJVP80W9bL0P2OWil20:6QX@80Xj>S0P2VYZH20:RXZ080ZZZZ0P2/
[:`20:f][@80[jn_0P2`/;000`2a/K40/[:b0;:b/P020;>c/`H0];Bd102e]KD:0;Bd]080/k>c102b
/[800`2`/;00[jn_0:n_[`020:j^[P80[:b/0P2YZJT20:NWY`80Y:BT0P2QXJ4209fMW@80VIVI0P2D
U9@2092@T080Rh^;0P26QXH20861P@80Ng]k00<0MWIf079bLP1bLW800P1_Kfl206e]K@80JVYZ0P1X
J6P206EUI@80Hf=S0P1OGel205aLG080F5QH0P1EEED205=CD`80DU9B0P1ADE42051@D00304i>CP1=
CDd0CDe=0080Bd];1P19BDT204];B`80CDe=0P1@D50205ADE080EeMG0P1KFe/205mOG`80Hf=S0P1X
J6P206a/K003075aL@1fMWH0MWIf0080NWYj0P1oOgl208B4Q080R8R80P2=SHd209:BTQD0oooo000C
0?ooo`80VYZJ0P2MWId20:2PX080Xj>S0P2VYZH20:VYZ@80Zj^[0P2_[jl00`2b/[80]KFe0;Fe]@02
0;Rh^080^k^k0P2n_[h20<71`@80a<C40P38b<P20<_;b`80c/k>0P3AdM420=CDe080emOG0P3Kfm/2
0=kNgP80h^;R00<0iNGU0>SXj03Xj>P00P3/k>`20>o_k`80lo?c0P3fm_H20?Shn080m_Kf0P3dm?@2
0>o_k`80j^[Z0P3Shn<20=gMg@80e]KF0P3>c/h20<O7a`030<30`02f][H0][Jf0080[:b/0P2SXj<2
09VIV@80W9bL0P2NWYh20:6QX@80Xj>S0P2VYZH20:RXZ080ZZZZ0P2/[:`20:j^[P80[jn_0P2a/K40
0`2b/[80/k>c0;>c/`020;Bd]0@0]KFe1P2f][H80;Fe]@@0];Bd0P2c/k<20;:b/P030;6a/@2`/;00
/;2`0080[Zj^0P2[Zj/20:VYZ@80YjNW0P2SXj<209nOW`80Vi^K0P2FUYH209:BTP80SHf=0P28R8P2
08:2PP80O7al0P1gMgL00`1bLW80KVi^06i^KP0206][J`80J6QX0P1VIVH206ATI080Hf=S0P1QHF42
05eMG@80FEUI0P1EEED205=CD`80DE5A0P1?Cdl204i>CP80CDe=00<0C4a<04Y:BP1:BTX00P18B4P4
04I6AP80AdM70P19BDT204a<C080Cdm?0P1CDe<205MGE`80Fe]K0P1OGel206=SH`80J6QX0P1/K6`0
0`1aLG40MWIf07IfMP0207YjNP80Ogmo0P24Q8@208R8R080SHf=0P2BTY8E0?ooo`004`3oool209ZJ
VP80WIfM0P2PX:020:>SX`80YZJV0P2YZJT20:^[Z`80[jn_00<0/[:b0;Fe]@2e]KD00P2h^;P20;^k
^`80_[jn0P31`L420<C4a080b<S80P3;bl/20<k>cP80dM7A0P3De=@20=OGe`80fm_K0P3Ng]h20>;R
hP030>GUi@3Xj>P0j>SX0080k>c/0P3_knl20??cl`80m_Kf0P3hn?P20?KfmP80m?Cd0P3_knl20>[Z
jP80hn?S0P3MgMd20=KFeP80c/k>0P37alL00`30`<00][Jf0;Jf]P020:b/[080Xj>S0P2IVIT209bL
W080WYjN0P2QXJ420:>SX`80YZJV0P2XZ:P20:ZZZP80[:b/0P2^[Zh20:n_[`80/K6a00<0/[:b0;>c
/`2c/k<00P2d];@40;Fe]@H0][Jf202e]KD40;Bd]080/k>c0P2b/[800`2a/K40/;2`0;2`/0020:j^
[P80Zj^[0P2YZJT20:NWY`80Xj>S0P2OWil209^KV`80UYJF0P2BTY8208f=S@80R8R80P22PX8207al
O080MgMg00<0LW9b06i^KP1^KVh00P1[Jf/206QXJ080IVIV0P1TI6@206=SH`80HF5Q0P1MGEd205UI
F@80EEEE0P1CDe<2055AD@80Cdm?0P1>CTh204e=C@0304a<C01:BTX0BTY:0080B4Q81016ATH204M7
A`80BDU90P1<C4`204m?C`80De=C0P1GEeL205]KF`80GemO0P1SHf<206QXJ080K6a/00<0LG5a07If
MP1fMWH00P1jNWX207moO`80Q8B40P28R8P208f=S@80TY:B5@3oool001<0oooo0P2JVYX209fMW@80
X:2P0P2SXj<20:JVYP80ZJVY0P2/[:`20:n_[`030;:b/P2e]KD0]KFe0080^KVi0P2l_;`20;no_`80
`/;20P36a/H20<W9b@80c<c<0P3?cll20=?Cd`80e]KF0P3IfMT20=gMg@80h>3P0P3Shn<00`3WinL0
j^[Z0>[ZjP020>k^kP80lO7a0P3emOD20?Shn080nOWi0P3gmoL20??cl`80kno_0P3YjNT20>;RhP80
g=cL0P3De=@20<k>cP80alO700<0_kno0;Fe]@2e]KD00P2[Zj/20::RXP80VIVI0P2LW9`209jNWP80
XJ6Q0P2TY:@20:JVYP80ZJVY0P2[Zj/20:f][@80[jn_0P2`/;020;:b/P030;>c/`2d];@0];Bd0080
]KFe102f][H40;Ng]`P0][Jf102e]KD20;Bd]0@0/k>c00<0/K6a0:n_[`2_[jl00P2][Jd20:^[Z`80
ZJVY0P2VYZH20::RXP80WIfM0P2IVIT209BDU080Shn?0P2;Rh/208B4Q080OWin0P1hN7P207=cL`03
06m_K`1[Jf/0Jf][0080IfMW0P1TI6@206=SH`80HF5Q0P1OGel205iNGP80FUYJ0P1FEUH205=CD`80
D51@0P1>CTh404a<C080Bd];00<0BDU904M7A`17AdL00P15ADD204=3@`80A4A40P15ADD204Q8B080
Bd];0P1?Cdl2059BDP80EUIF0P1JFUX205mOG`80Hf=S0P1XJ6P206a/K003075aL@1fMWH0MWIf0080
NWYj0P1oOgl208B4Q080R8R80P2=SHd209:BTQD0oooo000C0?ooo`80VYZJ0P2MWId20:2PX080Xj>S
0P2VYZH20:VYZ@80[:b/0P2_[jl00`2b/[80]KFe0;Fe]@020;Vi^@80_;bl0P2o_kl20<;2`P80a/K6
0P39bLT20<c<c080clo?0P3Cdm<20=KFeP80fMWI0P3MgMd20>3Ph080hn?S00<0inOW0>[ZjP3Zj^X0
0P3^k^h20?7al@80mOGe0P3hn?P20?Win@80moOg0P3clo<20>o_k`80jNWY0P3Rh^820=cLg080e=CD
0P3>c/h20<O7a`030;no_`2e]KD0]KFe0080Zj^[0P2RXZ8209VIV@80W9bL0P2NWYh20:6QX@80Y:BT
0P2VYZH20:VYZ@80Zj^[0P2][Jd20:n_[`80/;2`0P2b/[800`2c/k<0];Bd0;Bd]0020;Fe]@@0][Jf
102g]kL80;Jf]P@0]KFe0P2d];@40;>c/`030;6a/@2_[jl0[jn_0080[Jf]0P2[Zj/20:VYZ@80YZJV
0P2RXZ8209fMW@80VIVI0P2DU9@208n?S`80Rh^;0P24Q8@207inOP80N7Qh0P1cLg<00`1_Kfl0Jf][
06][J`0206MWI`80I6AT0P1SHf<2065QH@80GemO0P1NGUh205YJFP80EUIF0P1CDe<2051@D080CTi>
101<C4`204];B`0304U9B@17AdL0AdM70080ADE50P13@d<204A4A080ADE50P18B4P204];B`80Cdm?
0P1BDU8205IFEP80FUYJ0P1OGel206=SH`80J6QX0P1/K6`00`1aLG40MWIf07IfMP0207YjNP80Ogmo
0P24Q8@208R8R080SHf=0P2BTY8E0?ooo`004`3oool209ZJVP80WIfM0P2PX:020:>SX`80YjNW0P2Z
ZZX20:f][@80/;2`00<0/k>c0;Jf]P2f][H00P2j^[X20;fm_@80`<300P34a<@20<O7a`80b/[:0P3>
c/h20=7Ad@80e=CD0P3GemL20=_Kf`80g]kN0P3Rh^820>GUi@030>WYj@3/k>`0k>c/0080l?3`0P3c
lo<20?Ogm`@0nOWi0P3gmoL20??cl`80k^k^0P3Xj>P20>7Qh@80fm_K0P3Cdm<20<g=c@80aLG500<0
_;bl0;:b/P2b/[800P2YZJT20:6QX@80V9RH0P2LW9`209jNWP80XJ6Q0P2TY:@20:NWY`80ZJVY0P2[
Zj/20:f][@80[jn_0P2a/K420;:b/P030;Bd]02e]KD0]KFe0080][Jf1P2g]kL20;Rh^0H0]kNg1P2f
][H20;Fe]@80];Bd0P2c/k<00`2a/K40[jn_0:n_[`020:f][@80ZZZZ0P2XZ:P20:FUY@80WinO0P2K
Vi/209NGU`80TY:B0P2=SHd208R8R080PH610P1iNGT207=cL`80L71`00<0K6a/06QXJ01XJ6P00P1T
I6@2065QH@80GemO0P1MGEd205aLG080Fe]K0P1HF5P205ADE080DE5A0P1>CTh204a<C0@0BDU90P18
B4P00`16ATH0A4A404A4A0020492@P80@4100P12@T8204A4A080AdM70P1:BTX204i>CP80DE5A0P1F
EUH205YJFP80GemO0P1SHf<206MWI`80K6a/00<0LG5a07IfMP1fMWH00P1jNWX207moO`80Q8B40P28
R8P208f=S@80TY:B5@3oool001<0oooo0P2JVYX209fMW@80X:2P0P2SXj<20:NWY`80ZZZZ0P2][Jd2
0;2`/0030;>c/`2f][H0][Jf0080^[Zj0P2m_Kd20<30`080a<C40P37alL20<[:bP80c/k>0P3AdM42
0=CDe080emOG0P3Kfm/20=kNgP80h^;R0P3UiND00`3YjNT0k>c/0>c/k0020?3`l080lo?c0P3gmoL4
0?Win@80moOg0P3clo<20>k^kP80j>SX0P3QhN420=_Kf`80dm?C0P3=cLd20<G5a@030;bl_02b/[80
/[:b0080ZJVY0P2QXJ4209RHV080W9bL0P2NWYh20:6QX@80Y:BT0P2WYjL20:VYZ@80Zj^[0P2][Jd2
0:n_[`80/K6a0P2b/[800`2d];@0]KFe0;Fe]@020;Jf]PH0]kNg0P2h^;P60;Ng]`H0][Jf0P2e]KD2
0;Bd]080/k>c00<0/K6a0:n_[`2_[jl00P2][Jd20:ZZZP80Z:RX0P2UYJD209nOW`80Vi^K0P2GUiL2
09:BTP80SHf=0P28R8P20861P@80NGUi0P1cLg<2071`L00306a/K01XJ6P0J6QX0080I6AT0P1QHF42
05mOG`80GEeM0P1LG5`205]KF`80F5QH0P1DE5@2055AD@80CTi>0P1<C4`404U9B@80B4Q800<0ATI6
04A4A014A4@00P12@T820410@080@T920P14A4@204M7A`80BTY:0P1>CTh2055AD@80EUIF0P1JFUX2
05mOG`80Hf=S0P1WIfL206a/K003075aL@1fMWH0MWIf0080NWYj0P1oOgl208B4Q080R8R80P2=SHd2
09:BTQD0oooo000C0?ooo`80VYZJ0P2MWId20:2PX080Y:BT0P2WYjL20:ZZZP80[Jf]0P2a/K400`2d
];@0]kNg0;Ng]`020;^k^`80_[jn0P31`L420<G5a@80b<S80P3<c<`20<o?c`80d];B0P3Fe]H20=WI
f@80g=cL0P3Ph>020>CTi080inOW00<0jn_[0>k^kP3^k^h00P3bl_820?Gem@80nOWi0P3jn_X20?Wi
n@80moOg0P3bl_820>g]k@80i^KV0P3Ph>020=WIf@80d];B0P3;bl/20<;2`P030;Vi^@2`/;00/;2`
0080Z:RX0P2PX:0209RHV080Vi^K0P2NWYh20:6QX@80Y:BT0P2WYjL20:VYZ@80Zj^[0P2][Jd20:n_
[`80/K6a0P2b/[800`2d];@0]KFe0;Fe]@040;Ng]`X0^;Rh102g]kL40;Jf]P80]KFe0P2d];@20;>c
/`030;6a/@2_[jl0[jn_0080[:b/0P2YZJT20:NWY`80Xj>S0P2MWId209VIV@80UIFE0P2@T90208Z:
RP80Ph>30P1lO7`207EeM@80L71`0P1]KFd00`1YJFT0IFEU06EUI@02065QH@80GEeM0P1KFe/205YJ
FP80FEUI0P1HF5P205EEE@80DU9B0P1@D50204a<C080BDU91017AdL204E5A@0304=3@`10@400@410
0080?clo0P0n?Sh20410@080@d=30P16ATH204U9B@80CDe=0P1ADE4205EEE@80FUYJ0P1NGUh206=S
H`80IfMW0P1/K6`00`1aLG40MWIf07IfMP0207YjNP80Ogmo0P24Q8@208R8R080SHf=0P2BTY8E0?oo
o`004`3oool209ZJVP80WIfM0P2PX:020:BTY080YjNW0P2ZZZX20:f][@80/K6a00<0];Bd0;Ng]`2g
]kL00P2k^k/20;jn_P80`L710P35aLD20<S8b080c<c<0P3?cll20=;BdP80e]KF0P3IfMT20=cLg080
h>3P0P3Ti>@20>OWi`030>_[j`3^k^h0k^k^0080l_;b0P3emOD20?Win@80n_[j0P3inOT20?Ogm`80
l_;b0P3]kNd20>KViP80h>3P0P3IfMT20=;BdP80bl_;0P32`/800`2i^KT0/;2`0;2`/0020:RXZ080
X:2P0P2HV9P209^KV`80WYjN0P2QXJ420:BTY080YjNW0P2YZJT20:^[Z`80[Jf]0P2_[jl20;6a/@80
/[:b00<0];Bd0;Fe]@2e]KD0102g]kL:0;Rh^0@0]kNg102f][H20;Fe]@80];Bd0P2c/k<00`2a/K40
[jn_0:n_[`020:b/[080ZJVY0P2WYjL20:>SX`80WIfM0P2IVIT209FEU@80T92@0P2:RXX208>3P`80
O7al0P1eMGD2071`L080KFe]00<0JFUY06EUI@1UIFD00P1QHF4205eMG@80Fe]K0P1JFUX205UIF@80
F5QH0P1EEED2059BDP80D51@0P1<C4`204U9B@@0AdM70P15ADD00`13@d<0@4100410@00203lo?`80
?Shn0P10@40204=3@`80ATI60P19BDT204e=C@80DE5A0P1EEED205YJFP80GUiN0P1SHf<206MWI`80
K6a/00<0LG5a07IfMP1fMWH00P1jNWX207moO`80Q8B40P28R8P208f=S@80TY:B5@3oool001<0oooo
0P2JVYX209fMW@80XJ6Q0P2TY:@20:NWY`80ZZZZ0P2^[Zh20;6a/@030;Fe]@2h^;P0^;Rh0080_;bl
0P2o_kl20<;2`P80a/K60P39bLT20<g=c@80d=3@0P3De=@20=OGe`80fm_K0P3Ng]h20>;RhP80iNGU
0P3YjNT00`3]kNd0l?3`0?3`l0020??cl`80moOg103jn_X20?Win@80m_Kf0P3`l?020>_[j`80i>CT
0P3MgMd20=OGe`80d=3@0P39bLT20;no_`030;Jf]P2^[Zh0[Zj^0080YZJV0P2NWYh209RHV080Vi^K
0P2OWil20::RXP80YJFU0P2WYjL20:ZZZP80[:b/0P2^[Zh20;2`/080/K6a0P2c/k<00`2d];@0][Jf
0;Jf]P020;Ng]`80^;Rh202i^KT60;Rh^080]kNg0P2f][H20;Fe]@80];Bd0P2c/k<00`2a/K40[Zj^
0:j^[P020:^[Z`80Z:RX0P2VYZH20:6QX@80Vi^K0P2GUiL209BDU080SHf=0P26QXH207inOP80NGUi
0P1bLW8206e]K@80JVYZ00<0IfMW06=SH`1SHf<00P1OGel205YJFP80F5QH101FEUH205EEE@80De=C
0P1ADE4204i>CP80BTY:0P16ATH204E5A@80A4A40P12@T800`10@400?Shn03hn?P0203dm?@80?3`l
0P0o?cl204=3@`80ADE50P19BDT204e=C@80DE5A0P1EEED205YJFP80GUiN0P1SHf<206MWI`80K6a/
00<0LG5a07EeM@1eMGD00P1jNWX207moO`80Q8B40P28R8P208f=S@80TY:B5@3oool001<0oooo0P2J
VYX209fMW@80XJ6Q0P2TY:@20:NWY`80ZZZZ0P2^[Zh20;6a/@030;Fe]@2h^;P0^;Rh0080_;bl0P2o
_kl20<;2`P80a/K60P39bLT20<g=c@80d=3@0P3De=@20=OGe`80fm_K0P3Ng]h20>;RhP80iNGU0P3Y
jNT00`3]kNd0l?3`0?3`l0020??cl`80moOg103jn_X20?Win@80m_Kf0P3`l?020>_[j`80i>CT0P3M
gMd20=OGe`80d=3@0P39bLT20;no_`030;Jf]P2^[Zh0[Zj^0080YZJV0P2NWYh209RHV080Vi^K0P2O
Wil20::RXP80YJFU0P2WYjL20:ZZZP80[:b/0P2^[Zh20;2`/080/K6a0P2c/k<00`2d];@0][Jf0;Jf
]P020;Ng]`80^;Rh202i^KT60;Rh^080]kNg0P2f][H20;Fe]@80];Bd0P2c/k<00`2a/K40[Zj^0:j^
[P020:^[Z`80Z:RX0P2VYZH20:6QX@80Vi^K0P2GUiL209BDU080SHf=0P26QXH207inOP80NGUi0P1b
LW8206e]K@80JVYZ00<0IfMW06=SH`1SHf<00P1OGel205YJFP80F5QH101FEUH205EEE@80De=C0P1A
DE4204i>CP80BTY:0P16ATH204E5A@80A4A40P12@T800`10@400?Shn03hn?P0203dm?@80?3`l0P0o
?cl204=3@`80ADE50P19BDT204e=C@80DE5A0P1EEED205YJFP80GUiN0P1SHf<206MWI`80K6a/00<0
LG5a07EeM@1eMGD00P1jNWX207moO`80Q8B40P28R8P208f=S@80TY:B5@3oool001<0oooo0P2JVYX2
09fMW@80XJ6Q0P2TY:@20:RXZ080Zj^[0P2_[jl20;:b/P030;Fe]@2i^KT0^KVi0080_;bl0P30`<02
0<C4a080alO70P3:b/X20<k>cP80d];B0P3EeMD20=WIf@80g=cL0P3Ogml20>?Sh`80inOW0P3[jn/0
0`3^k^h0l_;b0?;blP020?Gem@80nOWi0P3kno/20?[jnP80n?Sh0P3dm?@20>o_k`80jNWY0P3Rh^82
0=_Kf`80eMGE0P3=cLd20<K6aP80^k^k00<0/k>c0:^[Z`2[Zj/00P2SXj<209^KV`80VIVI0P2LW9`2
0:2PX080Xj>S0P2VYZH20:RXZ080Zj^[0P2][Jd20:n_[`80/;2`0P2b/[820;>c/`030;Fe]@2f][H0
][Jf0080]kNg0P2h^;P40;Vi^@80^[Zj1P2i^KT20;Rh^0@0]kNg0P2e]KD20;Bd]080/[:b00<0/K6a
0:j^[P2^[Zh00P2ZZZX20:JVYP80Xj>S0P2NWYh209VIV@80UYJF0P2ATI4208Z:RP80PX:20P1jNWX2
07IfMP80Kfm_0P1ZJVX206MWI`0306ATI01PH600H61P0080G5aL0P1GEeL205EEE@80De=C101BDU82
055AD@80Cdm?0P1=CDd204Q8B080A4A40P13@d<20451@@80?clo00<0?Cdm03`l?00l?3`0100k>c/2
03lo?`80@T920P15ADD204Q8B080C4a<0P1ADE4205EEE@80FUYJ0P1NGUh206=SH`80IfMW0P1/K6`0
0`1aLG40MGEe07EeM@0207YjNP80Ogmo0P24Q8@208R8R080SHf=0P2BTY8E0?ooo`004`3oool209ZJ
VP80WIfM0P2QXJ420:BTY080Z:RX0P2[Zj/20:n_[`80/[:b00<0]KFe0;Vi^@2i^KT00P2l_;`20<30
`080a<C40P37alL20<[:bP80c/k>0P3Bd]820=GEe@80fMWI0P3Lg=`20=oOg`80hn?S0P3WinL20>_[
j`030>k^kP3bl_80l_;b0080mOGe0P3inOT20?_kn`80n_[j0P3hn?P20?Cdm080kno_0P3YjNT20>;R
hP80fm_K0P3EeMD20<g=c@80a/K60P2k^k/00`2c/k<0Zj^[0:^[Z`020:>SX`80Vi^K0P2IVIT209bL
W080X:2P0P2SXj<20:JVYP80Z:RX0P2[Zj/20:f][@80[jn_0P2`/;020;:b/P80/k>c00<0]KFe0;Jf
]P2f][H00P2g]kL20;Rh^0@0^KVi0P2j^[X60;Vi^@80^;Rh102g]kL20;Fe]@80];Bd0P2b/[800`2a
/K40[Zj^0:j^[P020:ZZZP80YZJV0P2SXj<209jNWP80VIVI0P2FUYH2096AT@80RXZ:0P22PX8207Yj
NP80MWIf0P1_Kfl206YZJP80IfMW00<0I6AT061PH01PH6000P1LG5`205MGE`80EEEE0P1CDe<4059B
DP80DE5A0P1?Cdl204e=C@80B4Q80P14A4@204=3@`80@D510P0o?cl00`0m?Cd0?3`l03`l?00403/k
>`80?clo0P12@T8204E5A@80B4Q80P1<C4`2055AD@80EEEE0P1JFUX205iNGP80Hf=S0P1WIfL206a/
K003075aL@1eMGD0MGEe0080NWYj0P1oOgl208B4Q080R8R80P2=SHd209:BTQD0oooo000C0?ooo`80
VYZJ0P2NWYh20:6QX@80Y:BT0P2XZ:P20:b/[080[jn_0P2c/k<00`2f][H0^[Zj0;Zj^P020;fm_@80
`L710P35aLD20<S8b080c<c<0P3?cll20=?Cd`80e]KF0P3Jf]X20=kNgP80hN7Q0P3UiND20>WYj@80
k>c/00<0l?3`0??cl`3clo<00P3gmoL20?[jnP80no_k0P3jn_X20?Ogm`80lo?c0P3]kNd20>OWi`80
gmoO0P3IfMT20=7Ad@80bl_;0P31`L420;Ng]`030:n_[`2WYjL0YjNW0080WinO102KVi/209jNWP80
XZ:R0P2UYJD20:NWY`80ZZZZ0P2/[:`20:j^[P80[jn_0P2a/K420;>c/`80];Bd00<0]KFe0;Jf]P2f
][H00P2g]kL20;Rh^0@0^KVi1P2j^[X40;Vi^@80^;Rh0P2g]kL20;Jf]P80];Bd0P2c/k<00`2`/;00
[Jf]0:f][@020:ZZZP80YJFU0P2OWil209^KV`80UYJF0P2EUID208n?S`80R8R80P1oOgl207MgM`80
Lg=c0P1]KFd206QXJ080I6AT00<0HV9R05eMG@1MGEd00P1IFET205EEE@80DU9B0P1@D50604m?C`80
CTi>0P1:BTX204I6AP80@T920P11@D4203hn?P80?3`l00<0>c/k03Xj>P0j>SX00P0h>3P203Xj>P80
?Shn0P10@40204A4A080B4Q80P1<C4`2051@D080EEEE0P1JFUX205iNGP80Hf=S0P1WIfL206a/K003
075aL@1eMGD0MGEe0080NWYj0P1oOgl208B4Q080R8R80P2=SHd209:BTQD0oooo000C0?ooo`80VYZJ
0P2NWYh20:6QX@80Y:BT0P2XZ:P20:b/[080[jn_0P2c/k<00`2f][H0^[Zj0;Zj^P020;fm_@80`L71
0P35aLD20<S8b080c<c<0P3?cll20=?Cd`80e]KF0P3Jf]X20=kNgP80hN7Q0P3UiND20>WYj@80k>c/
00<0l?3`0??cl`3clo<00P3gmoL20?[jnP80no_k0P3jn_X20?Ogm`80lo?c0P3]kNd20>OWi`80gmoO
0P3IfMT20=7Ad@80bl_;0P31`L420;Ng]`030:n_[`2WYjL0YjNW0080WinO102KVi/209jNWP80XZ:R
0P2UYJD20:NWY`80ZZZZ0P2/[:`20:j^[P80[jn_0P2a/K420;>c/`80];Bd00<0]KFe0;Jf]P2f][H0
0P2g]kL20;Rh^0@0^KVi1P2j^[X40;Vi^@80^;Rh0P2g]kL20;Jf]P80];Bd0P2c/k<00`2`/;00[Jf]
0:f][@020:ZZZP80YJFU0P2OWil209^KV`80UYJF0P2EUID208n?S`80R8R80P1oOgl207MgM`80Lg=c
0P1]KFd206QXJ080I6AT00<0HV9R05eMG@1MGEd00P1IFET205EEE@80DU9B0P1@D50604m?C`80CTi>
0P1:BTX204I6AP80@T920P11@D4203hn?P80?3`l00<0>c/k03Xj>P0j>SX00P0h>3P203Xj>P80?Shn
0P10@40204A4A080B4Q80P1<C4`2051@D080EEEE0P1JFUX205iNGP80Hf=S0P1WIfL206a/K003075a
L@1eMGD0MGEe0080NWYj0P1oOgl208B4Q080R8R80P2=SHd209:BTQD0oooo000C0?ooo`80VYZJ0P2N
WYh20:6QX@80YJFU0P2XZ:P20:b/[080/;2`0P2c/k<00`2g]kL0^k^k0;^k^`020;jn_P80`/;20P36
a/H20<W9b@80cLg=0P3AdM420=CDe080f=SH0P3Lg=`20=oOg`80hn?S0P3WinL20>[ZjP80k^k^00<0
l_;b0?Gem@3emOD00P3hn?P20?_kn`80o?cl0P3inOT20?KfmP80lO7a0P3[jn/20>CTi080gMgM0P3F
e]H20<k>cP80alO70P2l_;`20;>c/`030:^[Z`2RXZ80XZ:R0080WYjN0P2MWId209nOW`80XJ6Q0P2T
Y:@20:NWY`80ZJVY0P2[Zj/20:f][@80[jn_0P2`/;020;:b/P80/k>c0P2d];@00`2e]KD0][Jf0;Jf
]P020;Ng]`80^;Rh102i^KT40;Zj^P80^k^k0P2j^[X40;Vi^@80]kNg0P2f][H20;Bd]080/k>c00<0
/;2`0:f][@2][Jd00P2YZJT20:>SX`80Vi^K0P2IVIT209>CT`80TY:B0P2<S8`208F5Q@80OGem0P1d
M7@206m_K`80K6a/0P1UIFD2069RHP0305mOG`1KFe/0Fe]K0080EeMG0P1CDe<2051@D080CTi>0P1<
C4`404e=C@80C4a<0P18B4P204A4A080@D510P0n?Sh203/k>`80>SXj00<0>CTi03Ph>00h>3P00P0g
=cL203Xj>P80?Cdm0P0o?cl204=3@`80AdM70P1<C4`2051@D080EEEE0P1IFET205iNGP80Hf=S0P1W
IfL206a/K003075aL@1eMGD0MGEe0080NWYj0P1oOgl208>3P`80R8R80P2=SHd209:BTQD0oooo000C
0?ooo`80VYZJ0P2NWYh20:6QX@80YJFU0P2XZ:P20:b/[080/;2`0P2c/k<00`2g]kL0^k^k0;^k^`02
0;jn_P80`/;20P36a/H20<W9b@80cLg=0P3AdM420=CDe080f=SH0P3Lg=`20=oOg`80hn?S0P3WinL2
0>[ZjP80k^k^00<0l_;b0?Gem@3emOD00P3hn?P20?_kn`80o?cl0P3inOT20?KfmP80lO7a0P3[jn/2
0>CTi080gMgM0P3Fe]H20<k>cP80alO70P2l_;`20;>c/`030:^[Z`2RXZ80XZ:R0080WYjN0P2MWId2
09nOW`80XJ6Q0P2TY:@20:NWY`80ZJVY0P2[Zj/20:f][@80[jn_0P2`/;020;:b/P80/k>c0P2d];@0
0`2e]KD0][Jf0;Jf]P020;Ng]`80^;Rh102i^KT40;Zj^P80^k^k0P2j^[X40;Vi^@80]kNg0P2f][H2
0;Bd]080/k>c00<0/;2`0:f][@2][Jd00P2YZJT20:>SX`80Vi^K0P2IVIT209>CT`80TY:B0P2<S8`2
08F5Q@80OGem0P1dM7@206m_K`80K6a/0P1UIFD2069RHP0305mOG`1KFe/0Fe]K0080EeMG0P1CDe<2
051@D080CTi>0P1<C4`404e=C@80C4a<0P18B4P204A4A080@D510P0n?Sh203/k>`80>SXj00<0>CTi
03Ph>00h>3P00P0g=cL203Xj>P80?Cdm0P0o?cl204=3@`80AdM70P1<C4`2051@D080EEEE0P1IFET2
05iNGP80Hf=S0P1WIfL206a/K003075aL@1eMGD0MGEe0080NWYj0P1oOgl208>3P`80R8R80P2=SHd2
09:BTQD0oooo000C0?ooo`80VYZJ0P2NWYh20:6QX@80YJFU0P2YZJT20:b/[080/;2`0P2d];@00`2h
^;P0^k^k0;^k^`020;no_`80`l?30P37alL20<_;b`80c/k>0P3Bd]820=KFeP80fMWI0P3MgMd20>7Q
h@80i>CT0P3Xj>P20>c/k080l?3`00<0lo?c0?Ogm`3gmoL00P3jn_X40?_kn`80n?Sh0P3dm?@20>o_
k`80j>SX0P3QhN420=[JfP80d];B0P3;bl/20<;2`P80]kNg0P2_[jl00`2VYZH0WinO09nOW`020:2P
X080XJ6Q0P2RXZ820:BTY080YjNW0P2YZJT20:^[Z`80[Jf]0P2_[jl20;2`/080/[:b0P2c/k<20;Bd
]0<0]KFe102g]kL40;Rh^080^KVi1P2j^[X20;^k^`80^[Zj0P2i^KT20;Rh^080]kNg0P2e]KD20;>c
/`030;2`/02/[:`0[:b/0080Z:RX0P2QXJ4209VIV@80UYJF0P2@T90208j>SP80RXZ:0P22PX8207Yj
NP80LW9b0P1/K6`206UYJ@80I6AT0P1PH6000`1MGEd0FEUI05UIF@0205EEE@80DU9B0P1>CTh204a<
C0P0BTY:0P17AdL20492@P80?clo0P0l?3`203Ti>@80>3Ph00<0=cLg03Hf=P0f=SH00P0f=SH203Ph
>080>c/k0P0o?cl204=3@`80AdM70P1<C4`2051@D080EEEE0P1IFET205iNGP80Hf=S0P1WIfL206a/
K003075aL@1eMGD0MGEe0080NWYj0P1oOgl208>3P`80R8R80P2=SHd209:BTQD0oooo000C0?ooo`80
VYZJ0P2NWYh20:6QX@80YJFU0P2YZJT20:b/[080/;2`0P2d];@00`2h^;P0^k^k0;^k^`020;no_`80
`l?30P37alL20<_;b`80c/k>0P3Bd]820=KFeP80fMWI0P3MgMd20>7Qh@80i>CT0P3Xj>P20>c/k080
l?3`00<0lo?c0?Ogm`3gmoL00P3jn_X40?_kn`80n?Sh0P3dm?@20>o_k`80j>SX0P3QhN420=[JfP80
d];B0P3;bl/20<;2`P80]kNg0P2_[jl00`2VYZH0WinO09nOW`020:2PX080XJ6Q0P2RXZ820:BTY080
YjNW0P2YZJT20:^[Z`80[Jf]0P2_[jl20;2`/080/[:b0P2c/k<20;Bd]0<0]KFe102g]kL40;Rh^080
^KVi1P2j^[X20;^k^`80^[Zj0P2i^KT20;Rh^080]kNg0P2e]KD20;>c/`030;2`/02/[:`0[:b/0080
Z:RX0P2QXJ4209VIV@80UYJF0P2@T90208j>SP80RXZ:0P22PX8207YjNP80LW9b0P1/K6`206UYJ@80
I6AT0P1PH6000`1MGEd0FEUI05UIF@0205EEE@80DU9B0P1>CTh204a<C0P0BTY:0P17AdL20492@P80
?clo0P0l?3`203Ti>@80>3Ph00<0=cLg03Hf=P0f=SH00P0f=SH203Ph>080>c/k0P0o?cl204=3@`80
AdM70P1<C4`2051@D080EEEE0P1IFET205iNGP80Hf=S0P1WIfL206a/K003075aL@1eMGD0MGEe0080
NWYj0P1oOgl208>3P`80R8R80P2=SHd209:BTQD0oooo000C0?ooo`80VYZJ0P2NWYh20::RXP80YJFU
0P2YZJT20:f][@80/K6a0P2e]KD00`2h^;P0_;bl0;bl_0020<30`080a<C40P38b<P20<_;b`80clo?
0P3Cdm<20=OGe`80fm_K0P3Ng]h20>;RhP80i^KV0P3Zj^X20>k^kP80l_;b00<0mOGe0?Shn03hn?P0
103kno/20?[jnP80moOg0P3bl_820>c/k080i^KV0P3Ng]h20=KFeP80c/k>0P37alL20;bl_080/k>c
0P2ZZZX00`2SXj<0XJ6Q0:6QX@020:>SX`80Y:BT0P2VYZH20:NWY`80ZJVY0P2[Zj/20:f][@80[jn_
0P2`/;020;6a/@80/k>c102d];@30;Fe]@80][Jf102g]kL40;Rh^0@0^KVi202j^[X20;Vi^@80]kNg
0P2e]KD20;>c/`030;2`/02/[:`0[:b/0080YZJV0P2PX:0209NGU`80TY:B0P2?Shl208Z:RP80QhN7
0P1oOgl207QhN080L71`0P1/K6`206MWI`80I6AT0P1OGel00`1KFe/0F5QH05QHF00205ADE080D51@
0P1=CDd204Y:BP80B4Q81017AdL204Q8B080ADE50P10@40203dm?@80>CTi0P0g=cL203Hf=P0303De
=@0d=3@0=3@d0080=3@d0P0g=cL203/k>`80?Shn0P13@d<204M7A`80Bd];0P1@D50205EEE@80FEUI
0P1NGUh2069RHP80IfMW0P1/K6`00`1`L700MGEe07EeM@0207YjNP80Ogmo0P23Ph<208R8R080SHf=
0P2BTY8E0?ooo`004`3oool209ZJVP80WYjN0P2RXZ820:FUY@80ZJVY0P2][Jd20;6a/@80]KFe00<0
^;Rh0;bl_02l_;`00P30`<020<C4a080b<S80P3;bl/20<o?c`80dm?C0P3GemL20=_Kf`80g]kN0P3R
h^820>KViP80j^[Z0P3^k^h20?;blP030?Gem@3hn?P0n?Sh00@0no_k0P3jn_X20?Ogm`80l_;b0P3/
k>`20>KViP80g]kN0P3Fe]H20<k>cP80alO70P2l_;`20;>c/`80ZZZZ00<0Xj>S0:6QX@2QXJ400P2S
Xj<20:BTY080YZJV0P2WYjL20:VYZ@80Zj^[0P2][Jd20:n_[`80/;2`0P2a/K420;>c/`@0];Bd0`2e
]KD20;Jf]P@0]kNg102h^;P40;Vi^@P0^[Zj0P2i^KT20;Ng]`80]KFe0P2c/k<00`2`/;00[:b/0:b/
[0020:JVYP80X:2P0P2GUiL209:BTP80Shn?0P2:RXX208N7Q`80Ogmo0P1hN7P2071`L080K6a/0P1W
IfL206ATI080GemO00<0Fe]K05QHF01HF5P00P1DE5@2051@D080CDe=0P1:BTX204Q8B0@0AdM70P18
B4P204E5A@80@4100P0m?Cd203Ti>@80=cLg0P0f=SH00`0e=CD0=3@d03@d=00203@d=080=cLg0P0k
>c/203hn?P80@d=30P17AdL204];B`80D51@0P1EEED205UIF@80GUiN0P1RHV8206MWI`80K6a/00<0
L71`07EeM@1eMGD00P1jNWX207moO`80Ph>30P28R8P208f=S@80TY:B5@3oool001<0oooo0P2JVYX2
09jNWP80XZ:R0P2VYZH20:ZZZP80[Zj^0P2b/[820;Fe]@030;Vi^@2m_Kd0_Kfm0080`L710P35aLD2
0<W9b@80cLg=0P3@d=020=CDe080f=SH0P3Lg=`20>3Ph080hn?S0P3WinL20>_[j`80kno_0P3clo<0
0`3fm_H0nOWi0?Win@020?_kn`80o?cl0P3inOT20?Gem@80l?3`0P3Zj^X20>;RhP80f][J0P3Cdm<2
0<[:bP80`L710P2f][H20:j^[P80YZJV00<0Xj>S0:BTY02TY:@00P2UYJD20:NWY`80ZJVY0P2ZZZX2
0:b/[080[Zj^0P2_[jl20;2`/080/K6a0P2b/[820;Bd]0L0]KFe102f][H40;Ng]`@0^;Rh102i^KT6
0;Zj^P80^KVi0P2h^;P20;Jf]P80/k>c00<0/;2`0:b/[02/[:`00P2VYZH209nOW`80UIFE0P2?Shl2
08f=S@80QhN70P22PX8207inOP80MWIf0P1`L70206][J`80IFEU0P1RHV8205iNGP0305YJFP1FEUH0
EUIF0080De=C0P1>CTh204];B`80B4Q80P16ATH604A4A080@d=30P0o?cl203/k>`80>3Ph0P0f=SH2
03<c<`<0<S8b0P0c<c<203Lg=`80>SXj0P0n?Sh20492@P80ATI60P1;Bd/2051@D080E5AD0P1IFET2
05iNGP80HV9R0P1WIfL206a/K003071`L01eMGD0MGEe0080NWYj0P1oOgl208>3P`80R8R80P2=SHd2
09:BTQD0oooo000C0?ooo`80VYZJ0P2NWYh20::RXP80YZJV0P2ZZZX20:j^[P80/[:b0P2e]KD00`2i
^KT0_Kfm0;fm_@020<71`@80aLG50P39bLT20<g=c@80d=3@0P3De=@20=SHf080g=cL0P3Ph>020>?S
h`80inOW0P3[jn/20>o_k`80lo?c00<0m_Kf0?Win@3inOT00P3kno/20?clo080nOWi0P3emOD20?3`
l080j^[Z0P3Rh^820=[JfP80dm?C0P3:b/X20<71`@80][Jf0P2^[Zh20:JVYP030:>SX`2TY:@0Y:BT
0080YJFU0P2WYjL20:VYZ@80ZZZZ0P2/[:`20:j^[P80[jn_0P2`/;020;6a/@80/[:b0P2d];@70;Fe
]@@0][Jf102g]kL40;Rh^0@0^KVi1P2j^[X20;Vi^@80^;Rh0P2f][H20;>c/`030;2`/02/[:`0[:b/
0080YZJV0P2OWil209FEU@80Shn?0P2=SHd208N7Q`80PX:20P1nOWh207IfMP80L71`0P1[Jf/206EU
I@80HV9R0P1NGUh00`1JFUX0EUIF05IFEP0205=CD`80CTi>0P1;Bd/204Q8B080ATI61P14A4@204=3
@`80?clo0P0k>c/203Ph>080=SHf0P0c<c<3038b<P80<c<c0P0g=cL203Xj>P80?Shn0P12@T8204I6
AP80Bd];0P1@D50205ADE080FEUI0P1NGUh2069RHP80IfMW0P1/K6`00`1`L700MGEe07EeM@0207Yj
NP80Ogmo0P23Ph<208R8R080SHf=0P2BTY8E0?ooo`004`3oool209ZJVP80WYjN0P2RXZ820:JVYP80
ZZZZ0P2^[Zh20;:b/P80][Jf00<0^[Zj0;jn_P2n_[h00P32`/820<K6aP80b/[:0P3>c/h20=7Ad@80
eMGE0P3IfMT20=gMg@80hN7Q0P3UiND20>WYj@80kNg]0P3alO420?Gem@030?Shn03jn_X0n_[j00@0
no_k0P3hn?P20??cl`80kNg]0P3Vi^H20=kNgP80e]KF0P3?cll20<G5a@80^k^k0P2a/K420:RXZ080
YJFU00<0YZJV0:NWY`2WYjL00P2XZ:P20:ZZZP80Zj^[0P2][Jd20:n_[`80/;2`0P2a/K420;:b/P80
/k>c102d];@=0;Fe]@@0][Jf0P2g]kL40;Rh^0P0^KVi0P2h^;P20;Jf]P80];Bd00<0/;2`0:^[Z`2[
Zj/00P2VYZH209jNWP80UIFE0P2=SHd208V9R@80Q8B40P1oOgl207YjNP80M7Ad0P1`L70206][J`80
IFEU0P1PH60205eMG@0305UIF@1FEUH0EUIF0080DU9B0P1=CDd204U9B@80ATI60P14A4@20492@PH0
@D510P0m?Cd203Ti>@80=SHf0P0d=3@2034a<@<0<30`0P0c<c<203Hf=P80>SXj0P0n?Sh20492@P80
ATI60P1;Bd/2051@D080E5AD0P1IFET205eMG@80HV9R0P1WIfL206a/K003071`L01eMGD0MGEe0080
NWYj0P1oOgl208>3P`80R8R80P2=SHd209:BTQD0oooo000C0?ooo`80VYZJ0P2NWYh20::RXP80YZJV
0P2ZZZX20:j^[P80/[:b0P2f][H00`2j^[X0_[jn0;jn_P020<;2`P80a/K60P3:b/X20<k>cP80dM7A
0P3EeMD20=WIf@80gMgM0P3QhN420>GUi@80jNWY0P3]kNd20?7al@80mOGe00<0n?Sh0?[jnP3jn_X0
103kno/20?Shn080lo?c0P3]kNd20>KViP80g]kN0P3Fe]H20<o?c`80aLG50P2k^k/20;6a/@80Z:RX
0P2UYJD00`2VYZH0YjNW0:NWY`020:RXZ080ZZZZ0P2[Zj/20:f][@80[jn_0P2`/;020;6a/@80/[:b
0P2c/k<40;Bd]0d0]KFe102f][H20;Ng]`@0^;Rh202i^KT20;Rh^080][Jf0P2d];@00`2`/;00Zj^[
0:^[Z`020:JVYP80WYjN0P2EUID208f=S@80RHV90P24Q8@207moO`80NWYj0P1dM7@2071`L080Jf][
0P1UIFD2061PH080GEeM00<0FEUI05IFEP1FEUH00P1BDU8204e=C@80BDU90P16ATH204A4A080@T92
1P11@D4203dm?@80>CTi0P0f=SH203@d=080<C4a0`0`<30203<c<`80=SHf0P0j>SX203hn?P80@T92
0P16ATH204];B`80D51@0P1DE5@205UIF@80GEeM0P1RHV8206MWI`80K6a/00<0L71`07EeM@1eMGD0
0P1jNWX207moO`80Ph>30P28R8P208f=S@80TY:B5@3oool001<0oooo0P2JVYX209jNWP80XZ:R0P2V
YZH20:ZZZP80[jn_0P2b/[820;Jf]P030;^k^`2o_kl0_kno0080`l?30P36a/H20<[:bP80clo?0P3C
dm<20=OGe`80fm_K0P3Ogml20>?Sh`80i^KV0P3Zj^X20>k^kP80l_;b0P3fm_H00`3inOT0n_[j0?[j
nP020?_kn`80n_[j0P3fm_H20?3`l080j^[Z0P3Shn<20=[JfP80d];B0P3:b/X20;no_`80]KFe0P2[
Zj/20:JVYP80YjNW00<0Z:RX0:VYZ@2YZJT00P2[Zj/20:f][@80[Zj^0P2`/;020;6a/@@0/[:b0P2c
/k<40;Bd]0T0]KFe202d];@40;Fe]@@0]kNg102h^;P20;Vi^@@0^;Rh0P2g]kL20;Fe]@030;6a/@2/
[:`0[:b/0080YZJV0P2NWYh209FEU@80S8b<0P25QHD208:2PP80OWin0P1gMgL207=cL`80KVi^0P1Z
JVX206ATI080GemO0P1LG5`00`1HF5P0EEEE05EEE@02051@D080C4a<0P17AdL204E5A@80@T920P10
@40203lo?`@0?Shn0P0k>c/203Ph>080=CDe0P0b<S8502l_;`80<S8b0P0e=CD203Xj>P80?Cdm0P12
@T8204I6AP80Bd];0P1?Cdl205ADE080FEUI0P1MGEd2069RHP80IfMW0P1[Jf/00`1`L700MGEe07Ee
M@0207YjNP80OWin0P23Ph<208R8R080SHf=0P2BTY8E0?ooo`004`3oool209ZJVP80WYjN0P2RXZ82
0:JVYP80ZZZZ0P2_[jl20;:b/P80][Jf00<0^k^k0;no_`2o_kl00P33`l<20<K6aP80b/[:0P3?cll2
0=?Cd`80emOG0P3Kfm/20=oOg`80hn?S0P3Vi^H20>[ZjP80k^k^0P3bl_820?KfmP030?Win@3jn_X0
n_[j0080no_k0P3jn_X20?KfmP80l?3`0P3Zj^X20>?Sh`80f][J0P3Bd]820<[:bP80_kno0P2e]KD2
0:^[Z`80YZJV0P2WYjL00`2XZ:P0ZJVY0:VYZ@020:^[Z`80[Jf]0P2^[Zh20;2`/080/K6a102b/[82
0;>c/`@0];Bd2@2e]KD80;Bd]0@0]KFe102g]kL40;Rh^080^KVi102h^;P20;Ng]`80]KFe00<0/K6a
0:b/[02/[:`00P2VYZH209jNWP80UIFE0P2<S8`208F5Q@80PX:20P1nOWh207MgM`80Lg=c0P1^KVh2
06YZJP80I6AT0P1OGel205aLG00305QHF01EEED0EEEE0080D51@0P1<C4`204M7A`80ADE50P12@T82
0410@080?clo100n?Sh203/k>`80>3Ph0P0e=CD2038b<PD0;bl_0P0b<S8203De=@80>SXj0P0m?Cd2
0492@P80ATI60P1;Bd/204m?C`80E5AD0P1IFET205eMG@80HV9R0P1WIfL206][J`03071`L01eMGD0
MGEe0080NWYj0P1nOWh208>3P`80R8R80P2=SHd209:BTQD0oooo000C0?ooo`80Vi^K0P2OWil20::R
XP80YjNW0P2[Zj/20:n_[`80/k>c0P2g]kL00`2k^k/0_kno0;no_`020<C4a080alO70P3<c<`20=3@
d080e=CD0P3Hf=P20=cLg080h>3P0P3Ti>@20>SXj080k>c/0P3`l?020?Cdm080n?Sh00<0n_[j0?_k
n`3kno/00P3kno/20?Win@80m?Cd0P3]kNd20>KViP80gmoO0P3Fe]H20<k>cP80a<C40P2j^[X20;2`
/080YjNW0P2XZ:P20:VYZ@030:ZZZP2[Zj/0Zj^[0080[Jf]0P2_[jl20;6a/@@0/k>c0P2b/[840;>c
/`@0];Bd202e]KD00`2d];@0/k>c0;>c/`060;:b/P80/k>c0P2d];@20;Fe]@80][Jf0P2g]kL60;Rh
^080]kNg0P2f][H20;Fe]@030;:b/P2][Jd0[Jf]0080YjNW0P2OWil209FEU@80Rh^;0P24Q8@207mo
O`80Ng]k0P1eMGD2075aL@80KFe]0P1XJ6P206ATI080GemO0P1KFe/00`1GEeL0E5AD05ADE002051@
D080Bd];0P16ATH204A4A080@D510P0n?Sh203`l?0@0>c/k0P0j>SX203Hf=P80=3@d0P0a<C4202h^
;P0302d];@0^;Rh0;Rh^0080<C4a0P0e=CD203Ti>@80?Cdm0P11@D4204I6AP80Bd];0P1?Cdl205AD
E080F5QH0P1MGEd2069RHP80IfMW0P1[Jf/00`1`L700MGEe07EeM@0207YjNP80OWin0P23Ph<208R8
R080SHf=0P2BTY8E0?ooo`004`3oool209^KV`80WinO0P2SXj<20:NWY`80Zj^[0P2_[jl20;>c/`80
^;Rh00<0_;bl0<30`030`<000P34a<@20<S8b080cLg=0P3AdM420=GEe@80fMWI0P3MgMd20>;RhP80
iNGU0P3Zj^X20>k^kP80l_;b0P3fm_H20?Win@D0no_k0P3gmoL20?7al@80j^[Z0P3Rh^820=_Kf`80
dM7A0P38b<P20;jn_P80];Bd0P2ZZZX20:JVYP80Z:RX0P2ZZZX00`2[Zj/0[Jf]0:f][@020:n_[`80
/[:b0P2c/k<20;Bd]080/k>c0P2a/K420;>c/`P0];Bd102e]KD20;Bd]0030;>c/`2b/[80/[:b0080
/K6a102`/;020;6a/@80/[:b0P2d];@20;Fe]@80][Jf202g]kL20;Jf]P80];Bd00<0/[:b0:j^[P2^
[Zh00P2XZ:P209nOW`80UYJF0P2<S8`208B4Q080O7al0P1iNGT207EeM@80Kfm_0P1/K6`206IVIP80
HV9R0P1OGel205YJFP0305IFEP1CDe<0De=C0080Cdm?0P1:BTX204I6AP80@T920P10@40203`l?080
>SXj1P0h>3P203De=@80<S8b0P0_;bl202`/;00302/[:`0^;Rh0;Rh^0080<C4a0P0e=CD203Ti>@80
?3`l0P11@D4204I6AP80BTY:0P1?Cdl205ADE080F5QH0P1MGEd2069RHP80IfMW0P1[Jf/00`1`L700
MGEe07EeM@0207YjNP80OWin0P23Ph<208R8R080SHf=0P2BTY8E0?ooo`004`3oool209^KV`80WinO
0P2SXj<20:NWY`80Zj^[0P2_[jl20;>c/`80^;Rh00<0_;bl0<30`030`<000P34a<@20<S8b080cLg=
0P3AdM420=GEe@80fMWI0P3MgMd20>;RhP80iNGU0P3Zj^X20>k^kP80l_;b0P3fm_H20?Win@D0no_k
0P3gmoL20?7al@80j^[Z0P3Rh^820=_Kf`80dM7A0P38b<P20;jn_P80];Bd0P2ZZZX20:JVYP80Z:RX
0P2ZZZX00`2[Zj/0[Jf]0:f][@020:n_[`80/[:b0P2c/k<20;Bd]080/k>c0P2a/K420;>c/`P0];Bd
102e]KD20;Bd]0030;>c/`2b/[80/[:b0080/K6a102`/;020;6a/@80/[:b0P2d];@20;Fe]@80][Jf
202g]kL20;Jf]P80];Bd00<0/[:b0:j^[P2^[Zh00P2XZ:P209nOW`80UYJF0P2<S8`208B4Q080O7al
0P1iNGT207EeM@80Kfm_0P1/K6`206IVIP80HV9R0P1OGel205YJFP0305IFEP1CDe<0De=C0080Cdm?
0P1:BTX204I6AP80@T920P10@40203`l?080>SXj1P0h>3P203De=@80<S8b0P0_;bl202`/;00302/[
:`0^;Rh0;Rh^0080<C4a0P0e=CD203Ti>@80?3`l0P11@D4204I6AP80BTY:0P1?Cdl205ADE080F5QH
0P1MGEd2069RHP80IfMW0P1[Jf/00`1`L700MGEe07EeM@0207YjNP80OWin0P23Ph<208R8R080SHf=
0P2BTY8E0?ooo`004`3oool209^KV`80WinO0P2SXj<20:NWY`80[:b/0P2`/;020;Bd]080^;Rh00<0
_Kfm0<71`@31`L400P35aLD20<W9b@80c/k>0P3Bd]820=KFeP80f][J0P3Ogml20>?Sh`80inOW0P3[
jn/20>o_k`80lo?c0P3hn?P20?[jnP<0o?cl0P3inOT20?Cdm080k^k^0P3Vi^H20=kNgP80e]KF0P3=
cLd20<?3``80^;Rh0P2^[Zh20:NWY`80Z:RX0P2YZJT20:^[Z`030:b/[02_[jl0[jn_0080/K6a102d
];@40;>c/`80/[:b0P2c/k<60;Bd]0@0]KFe0P2d];@20;>c/`<0/K6a0P2`/;020:n_[`80[Zj^0P2_
[jl20;2`/080/[:b0P2d];@20;Fe]@80][Jf0P2g]kL40;Jf]P80]KFe0P2c/k<00`2a/K40[Zj^0:j^
[P020:VYZ@80XJ6Q0P2HV9P208b<S080Q8B40P1kNg/207QhN080M7Ad0P1^KVh206YZJP80IFEU0P1P
H60205aLG080FUYJ00<0EUIF05=CD`1CDe<00P1>CTh204Y:BP80ADE50P11@D4203hn?P80>c/k0P0h
>3P603Hf=P80<c<c0P0`<30202d];@80:b/[00<0:RXZ02d];@0];Bd00P0`<30203@d=080>3Ph0P0l
?3`20451@@80ADE50P1:BTX204m?C`80De=C0P1HF5P205eMG@80HV9R0P1VIVH206][J`03071`L01e
MGD0MGEe0080NWYj0P1nOWh208>3P`80R8R80P2=SHd209:BTQD0oooo000C0?ooo`80Vi^K0P2OWil2
0:>SX`80YjNW0P2/[:`20;2`/080];Bd0P2h^;P00`2m_Kd0`L710<71`@020<G5a@80bLW90P3>c/h2
0=;BdP80e]KF0P3Jf]X20=oOg`80hn?S0P3WinL20>_[j`80kno_0P3clo<20?Shn080n_[j0`3lo?`2
0?Win@80m?Cd0P3^k^h20>KViP80g]kN0P3Fe]H20<g=c@80`l?30P2h^;P20:j^[P80YjNW0P2XZ:P2
0:VYZ@80Zj^[00<0[:b/0:n_[`2_[jl00P2a/K440;Bd]0@0/k>c0P2b/[820;>c/`H0];Bd102e]KD2
0;Bd]080/k>c0`2a/K420;2`/080[jn_0P2^[Zh20:n_[`80/;2`0P2b/[820;Bd]080]KFe0P2f][H2
0;Ng]`@0][Jf0P2e]KD20;>c/`030;6a/@2^[Zh0[Zj^0080ZJVY0P2QXJ4209RHV080S8b<0P24Q8@2
07]kN`80N7Qh0P1dM7@206i^KP80JVYZ0P1UIFD2061PH080G5aL0P1JFUX00`1FEUH0De=C05=CD`02
04i>CP80BTY:0P15ADD20451@@80?Shn0P0k>c/203Ph>0H0=SHf0P0c<c<2030`<080;Bd]0P0[:b/0
0`0Z:RX0;Bd]02d];@02030`<080=3@d0P0h>3P203`l?080@D510P15ADD204Y:BP80Cdm?0P1CDe<2
05QHF080GEeM0P1RHV8206IVIP80Jf][00<0L71`07EeM@1eMGD00P1jNWX207inOP80Ph>30P28R8P2
08f=S@80TY:B5@3oool001<0oooo0P2KVi/209nOW`80Xj>S0P2WYjL20:b/[080/;2`0P2d];@20;Vi
^@030;fm_@31`L40`L710080a/K60P3:b/X20<o?c`80dm?C0P3GemL20=cLg080h>3P0P3Ti>@20>SX
j080kNg]0P3alO420?Gem@80nOWi0P3kno/00`3lo?`0no_k0?_kn`020?Ogm`80l_;b0P3[jn/20>;R
hP80f][J0P3AdM420<O7a`80_;bl0P2b/[820:RXZ080YjNW0P2XZ:P20:ZZZP80Zj^[00<0[Jf]0;2`
/02`/;000P2b/[840;Bd]080/k>c102b/[860;>c/`H0];Bd0P2b/[820;6a/@<0/;2`0P2_[jl20:j^
[P@0[Jf]0P2_[jl20;6a/@80/k>c0P2d];@20;Fe]@@0][Jf0P2e]KD20;Bd]080/k>c00<0/K6a0:j^
[P2^[Zh00P2ZZZX20:>SX`80VYZJ0P2>SXh208B4Q080O7al0P1fMWH2079bLP80KVi^0P1XJ6P206EU
I@80GUiN0P1JFUX205QHF00305IFEP1ADE40DE5A0080CTi>0P19BDT204A4A080@4100P0m?Cd203Xj
>P80=SHf0P0d=3@403<c<`80<S8b0P0^;Rh202`/;0<0:BTY0P0/;2`2030`<080=3@d0P0h>3P203`l
?080@4100P15ADD204Y:BP80Cdm?0P1CDe<205QHF080GEeM0P1RHV8206IVIP80Jf][00<0L71`07Ee
M@1eMGD00P1jNWX207moO`80Ph>30P28R8P208f=S@80TY:B5@3oool001<0oooo0P2KVi/209nOW`80
Xj>S0P2WYjL20:b/[080/;2`0P2d];@20;Vi^@030;fm_@31`L40`L710080a/K60P3:b/X20<o?c`80
dm?C0P3GemL20=cLg080h>3P0P3Ti>@20>SXj080kNg]0P3alO420?Gem@80nOWi0P3kno/00`3lo?`0
no_k0?_kn`020?Ogm`80l_;b0P3[jn/20>;RhP80f][J0P3AdM420<O7a`80_;bl0P2b/[820:RXZ080
YjNW0P2XZ:P20:ZZZP80Zj^[00<0[Jf]0;2`/02`/;000P2b/[840;Bd]080/k>c102b/[860;>c/`H0
];Bd0P2b/[820;6a/@<0/;2`0P2_[jl20:j^[P@0[Jf]0P2_[jl20;6a/@80/k>c0P2d];@20;Fe]@@0
][Jf0P2e]KD20;Bd]080/k>c00<0/K6a0:j^[P2^[Zh00P2ZZZX20:>SX`80VYZJ0P2>SXh208B4Q080
O7al0P1fMWH2079bLP80KVi^0P1XJ6P206EUI@80GUiN0P1JFUX205QHF00305IFEP1ADE40DE5A0080
CTi>0P19BDT204A4A080@4100P0m?Cd203Xj>P80=SHf0P0d=3@403<c<`80<S8b0P0^;Rh202`/;0<0
:BTY0P0/;2`2030`<080=3@d0P0h>3P203`l?080@4100P15ADD204Y:BP80Cdm?0P1CDe<205QHF080
GEeM0P1RHV8206IVIP80Jf][00<0L71`07EeM@1eMGD00P1jNWX207moO`80Ph>30P28R8P208f=S@80
TY:B5@3oool001<0oooo0P2KVi/209nOW`80Xj>S0P2XZ:P20:b/[080/K6a0P2e]KD20;Vi^@030;jn
_P32`/80`/;20080alO70P3;bl/20<o?c`80e=CD0P3Hf=P20=gMg@80hN7Q0P3Vi^H20>[ZjP80k^k^
0P3clo<20?Ogm`80n_[j0`3lo?`20?Win@80mOGe0P3_knl20>OWi`80g]kN0P3EeMD20<_;b`80`L71
0P2f][H20:^[Z`80YjNW102XZ:P20:ZZZP80Zj^[00<0[Jf]0;2`/02`/;000P2`/;040;>c/``0/K6a
1P2b/[820;2`/080[jn_00<0[Zj^0:b/[02/[:`0102/[:`20:^[Z`80[:b/0P2^[Zh20;2`/080/[:b
102d];@60;Fe]@80];Bd0P2b/[800`2a/K40[Zj^0:j^[P020:^[Z`80YJFU0P2KVi/2092@T080QHF5
0P1mOGd207IfMP80LG5a0P1^KVh206QXJ080Hf=S0P1NGUh205QHF080EUIF00<0E5AD059BDP1BDU80
0P1=CDd204Q8B080A4A40P0o?cl203`l?080>3Ph0P0d=3@2038b<P80<C4a100`<30202d];@80:b/[
0`0X:2P202`/;080<30`0P0c<c<203Lg=`80>c/k0P10@40204E5A@80BTY:0P1>CTh205=CD`80F5QH
0P1MGEd2069RHP80IVIV0P1[Jf/00`1`L700MGEe07EeM@0207YjNP80OWin0P23Ph<208R8R080SHf=
0P2BTY8E0?ooo`004`3oool209^KV`80WinO0P2SXj<20:RXZ080[:b/0P2a/K420;Fe]@80^KVi00<0
_[jn0<;2`P32`/800P37alL20<_;b`80clo?0P3De=@20=SHf080gMgM0P3QhN420>KViP80j^[Z0P3^
k^h20??cl`80moOg0P3jn_X30?clo080nOWi0P3emOD20>o_k`80inOW0P3Ng]h20=GEe@80bl_;0P31
`L420;Jf]P80Zj^[0P2WYjL40:RXZ080ZZZZ0P2[Zj/00`2][Jd0/;2`0;2`/0020;2`/0@0/k>c302a
/K460;:b/P80/;2`0P2_[jl00`2^[Zh0[:b/0:b/[0040:b/[080Zj^[0P2/[:`20:j^[P80/;2`0P2b
/[840;Bd]0H0]KFe0P2d];@20;:b/P030;6a/@2^[Zh0[Zj^0080Zj^[0P2UYJD209^KV`80T92@0P25
QHD207emO@80MWIf0P1aLG4206i^KP80J6QX0P1SHf<205iNGP80F5QH0P1FEUH00`1DE5@0DU9B059B
DP0204e=C@80B4Q80P14A4@203lo?`80?3`l0P0h>3P203@d=080<S8b0P0a<C44030`<080;Bd]0P0[
:b/302PX:080;2`/0P0`<30203<c<`80=cLg0P0k>c/20410@080ADE50P1:BTX204i>CP80De=C0P1H
F5P205eMG@80HV9R0P1VIVH206][J`03071`L01eMGD0MGEe0080NWYj0P1nOWh208>3P`80R8R80P2=
SHd209:BTQD0oooo000C0?ooo`80Vi^K0P2OWil20:BTY080Z:RX0P2][Jd20;6a/@80]KFe0P2j^[X0
0`2n_[h0`l?30<?3``020<O7a`80c<c<0P3@d=020=GEe@80fMWI0P3Ng]h20>?Sh`80inOW0P3/k>`2
0?3`l080m?Cd0P3hn?P20?_kn`80oOgm00<0o?cl0?Shn03hn?P00P3bl_820>_[j`80h^;R0P3Jf]X2
0=3@d080a/K60P2k^k/20;6a/@H0YjNW0P2XZ:P20:ZZZP80Zj^[00<0[Jf]0:j^[P2^[Zh00P2_[jl4
0;6a/@`0/;2`0P2a/K440;2`/080[jn_0P2^[Zh00`2][Jd0[:b/0:b/[0060:b/[080[Jf]0P2^[Zh2
0;2`/080/[:b0P2c/k<40;Bd]080]KFe0P2d];@20;>c/`80/[:b00<0/;2`0:j^[P2^[Zh00P2[Zj/2
0:JVYP80WIfM0P2BTY8208J6QP80OWin0P1fMWH2075aL@80KFe]0P1YJFT2065QH@80GEeM0P1FEUH2
05=CD`03055AD@1@D500D51@0080Bd];0P18B4P204A4A080?clo0P0k>c/203Lg=`80<S8b0P0a<C46
02h^;P80:b/[0P0Y:BT202HV9P0302PX:00[:b/0:b/[0080;bl_0P0c<c<203Hf=P80>c/k0P10@402
04E5A@80BDU90P1>CTh205=CD`80F5QH0P1MGEd2065QH@80IVIV0P1[Jf/00`1`L700MGEe07EeM@02
07YjNP80OWin0P23Ph<208R8R080SHf=0P2BTY8E0?ooo`004`3oool209^KV`80WinO0P2TY:@20:RX
Z080[Jf]0P2a/K420;Fe]@80^[Zj00<0_[jn0<?3``33`l<00P37alL20<c<c080d=3@0P3EeMD20=WI
f@80g]kN0P3Shn<20>OWi`80k>c/0P3`l?020?Cdm080n?Sh0P3kno/20?gmo@030?clo03hn?P0n?Sh
0080l_;b0P3[jn/20>;RhP80f][J0P3@d=020<K6aP80^k^k0P2a/K460:NWY`80Z:RX0P2ZZZX20:^[
Z`030:f][@2^[Zh0[Zj^0080[jn_102a/K4<0;2`/080/K6a102`/;020:n_[`80[Zj^00<0[Jf]0:b/
[02/[:`01P2/[:`20:f][@80[Zj^0P2`/;020;:b/P80/k>c102d];@20;Fe]@80];Bd0P2c/k<20;:b
/P030;2`/02^[Zh0[Zj^0080Zj^[0P2VYZH209fMW@80TY:B0P26QXH207inOP80MWIf0P1aLG4206e]
K@80JFUY0P1QHF4205eMG@80EUIF0P1CDe<00`1ADE40D51@051@D00204];B`80B4Q80P14A4@203lo
?`80>c/k0P0g=cL2038b<P80<C4a1P0^;Rh202/[:`80:BTY0P0V9RH00`0X:2P0:b/[02/[:`0202l_
;`80<c<c0P0f=SH203/k>`80@4100P15ADD204U9B@80CTi>0P1CDe<205QHF080GEeM0P1QHF4206IV
IP80Jf][00<0L71`07EeM@1eMGD00P1jNWX207inOP80Ph>30P28R8P208f=S@80TY:B5@3oool001<0
oooo0P2KVi/209nOW`80Y:BT0P2XZ:P20:f][@80/K6a0P2f][H20;Zj^P030;no_`33`l<0`l?30080
b<S80P3=cLd20=7Ad@80e]KF0P3Kfm/20=oOg`80i>CT0P3YjNT20>g]k@80l_;b0P3fm_H20?[jnP80
o?cl0P3moOd00`3kno/0m_Kf0?KfmP020>o_k`80inOW0P3Ogml20=GEe@80bl_;0P30`<020;Jf]P80
Zj^[0P2UYJD20:JVYP80YjNW0P2XZ:P20:VYZ@80Zj^[00<0[:b/0:f][@2][Jd00P2^[Zh20:n_[`@0
/;2`1P2a/K420;:b/PP0/K6a0P2`/;020:n_[`030:j^[P2][Jd0[Jf]00H0[Jf]0P2^[Zh20:n_[`80
/;2`0P2b/[820;>c/`P0];Bd0P2c/k<20;:b/P030;2`/02^[Zh0[Zj^0080Zj^[0P2WYjL20:2PX080
U9BD0P28R8P207moO`80MgMg0P1aLG4206a/K080J6QX0P1QHF4205]KF`80EEEE0P1@D5000`1?Cdl0
CDe=04e=C@0204Y:BP80AdM70P13@d<203hn?P80>SXj0P0f=SH2038b<P80;Rh^0P0[:b/402`/;080
:RXZ0P0X:2P202@T900302LW9`0[:b/0:b/[0080;Rh^0P0b<S8203Hf=P80>c/k0P10@40204E5A@80
BDU90P1>CTh205=CD`80F5QH0P1MGEd2065QH@80IVIV0P1[Jf/00`1`L700MGEe07EeM@0207YjNP80
OWin0P23Ph<208R8R080SHf=0P2BTY8E0?ooo`004`3oool209^KV`80WinO0P2TY:@20:RXZ080[Jf]
0P2a/K420;Jf]P80^[Zj00<0_kno0<?3``33`l<00P38b<P20<g=c@80dM7A0P3Fe]H20=_Kf`80gmoO
0P3Ti>@20>WYj@80kNg]0P3bl_820?KfmP80n_[j0P3lo?`20?gmo@030?_kn`3fm_H0m_Kf0080kno_
0P3WinL20=oOg`80eMGE0P3;bl/20<30`080][Jf0P2[Zj/20:FUY@80YZJV0P2WYjL20:RXZ080ZJVY
0P2[Zj/00`2/[:`0[Jf]0:f][@020:j^[P80[jn_102`/;060;6a/@80/[:b202a/K420;2`/080[jn_
00<0[Zj^0:f][@2][Jd01P2][Jd20:j^[P80[jn_0P2`/;020;:b/P80/k>c202d];@20;>c/`80/[:b
00<0/;2`0:j^[P2^[Zh00P2[Zj/20:NWY`80X:2P0P2DU9@208R8R080Ogmo0P1gMgL2075aL@80K6a/
0P1XJ6P2065QH@80Fe]K0P1EEED2051@D00304m?C`1=CDd0CDe=0080BTY:0P17AdL204=3@`80?Shn
0P0j>SX203Hf=P80<S8b0P0^;Rh202/[:`@0;2`/0P0Z:RX202PX:08092@T00<09bLW02/[:`0[:b/0
0P0^;Rh2038b<P80=SHf0P0k>c/20410@080ADE50P19BDT204i>CP80De=C0P1HF5P205eMG@80HF5Q
0P1VIVH206][J`03071`L01eMGD0MGEe0080NWYj0P1nOWh208>3P`80R8R80P2=SHd209:BTQD0oooo
000C0?ooo`80Vi^K0P2OWil20:BTY080ZJVY0P2][Jd20;:b/P80][Jf0P2k^k/00`2o_kl0a<C40<C4
a0020<W9b@80cLg=0P3Bd]820=OGe`80g=cL0P3Ph>020>GUi@80j^[Z0P3_knl20??cl`80n?Sh0P3l
o?`40?gmo@030?Win@3clo<0lo?c0080k>c/0P3Shn<20=[JfP80d=3@0P36a/H20;bl_080/K6a0P2V
YZH20:FUY@@0YZJV0P2WYjL20:VYZ@80ZZZZ00<0Zj^[0:f][@2][Jd00P2^[Zh20:n_[`@0/;2`0P2a
/K440;:b/P80/k>c202b/[820;2`/080[jn_00<0[Zj^0:f][@2][Jd0102][Jd40:j^[P80/;2`0P2a
/K420;:b/P@0/k>c1P2d];@20;>c/`80/[:b00<0/;2`0:j^[P2^[Zh00P2[Zj/20:NWY`80XJ6Q0P2F
UYH208^;R`80P8200P1hN7P2079bLP80K6a/0P1WIfL2065QH@80FUYJ0P1EEED204m?C`0304a<C01:
BTX0BTY:0080BDU90P15ADD20492@P80?Cdm0P0i>CT203@d=080<30`0P0/;2`202XZ:P80:BTY0P0Z
:RX202PX:0809RHV0P0S8b<00`0V9RH0:RXZ02XZ:P0202h^;P80<C4a0P0f=SH203Xj>P80?clo0P14
A4@204U9B@80CTi>0P1CDe<205QHF080GEeM0P1QHF4206IVIP80Jf][00<0L71`07EeM@1eMGD00P1j
NWX207inOP80Ph>30P28R8P208f=S@80TY:B5@3oool001<0oooo0P2KVi/209nOW`80Y:BT0P2YZJT2
0:f][@80/[:b0P2f][H20;^k^`030;no_`34a<@0a<C40080bLW90P3=cLd20=;BdP80emOG0P3Lg=`2
0>3Ph080iNGU0P3Zj^X20>o_k`80lo?c0P3hn?P20?clo0@0oOgm00<0nOWi0??cl`3clo<00P3/k>`2
0>?Sh`80f][J0P3@d=020<K6aP80_;bl0P2a/K420:JVYP80YJFU102VYZH20:NWY`80ZJVY0P2ZZZX0
0`2[Zj/0[Jf]0:f][@020:j^[P80[jn_102`/;020;6a/@@0/[:b0P2c/k<80;:b/P80/;2`0P2_[jl0
0`2^[Zh0[Jf]0:f][@040:f][@@0[Zj^0P2`/;020;6a/@80/[:b102c/k<60;Bd]080/k>c0P2b/[80
0`2`/;00[Zj^0:j^[P020:^[Z`80YjNW0P2QXJ4209JFUP80Rh^;0P20P80207QhN080LW9b0P1/K6`2
06MWI`80HF5Q0P1JFUX205EEE@80Cdm?00<0C4a<04Y:BP1:BTX00P19BDT204E5A@80@T920P0m?Cd2
03Ti>@80=3@d0P0`<30202`/;080:RXZ0P0Y:BT202XZ:P80:2PX0P0V9RH202<S8`0302HV9P0Z:RX0
:RXZ0080;Rh^0P0a<C4203Hf=P80>SXj0P0o?cl204A4A080BDU90P1>CTh205=CD`80F5QH0P1MGEd2
065QH@80IVIV0P1[Jf/00`1`L700MGEe07EeM@0207YjNP80OWin0P23Ph<208R8R080SHf=0P2BTY8E
0?ooo`004`3oool209^KV`80X:2P0P2TY:@20:VYZ@80[Jf]0P2b/[820;Ng]`80_;bl00<0`<300<G5
a@35aLD00P3:b/X20<k>cP80dm?C0P3Hf=P20=gMg@80h^;R0P3WinL20>_[j`80l?3`0P3emOD20?[j
nP80oOgm0P3no_h20?_kn`030?Ogm`3`l?00l?3`0080j>SX0P3Ph>020=KFeP80c<c<0P31`L420;Ng
]`80[Jf]0P2SXj<20:BTY0@0YJFU0P2WYjL20:RXZ080ZJVY00<0Zj^[0:b/[02/[:`00P2][Jd20:n_
[`80/;2`102a/K420;:b/PX0/k>c0P2b/[820;2`/0<0[jn_0P2^[Zh40:f][@@0[Zj^0P2_[jl20;6a
/@80/[:b102c/k<40;Bd]0@0/k>c0P2b/[800`2`/;00[Zj^0:j^[P020:^[Z`80Z:RX0P2RXZ8209VI
V@80SXj>0P22PX8207UiN@80LW9b0P1/K6`206IVIP80HF5Q0P1JFUX205ADE080CTi>00<0BTY:04M7
A`17AdL00P15ADD204=3@`80@D510P0l?3`203Ti>@80<c<c0P0_;bl202XZ:P80:2PX100W9bL202HV
9P@08b<S00<09BDU02TY:@0Y:BT00P0];Bd2030`<080=CDe0P0j>SX203lo?`80A4A40P19BDT204i>
CP80De=C0P1HF5P205aLG080HF5Q0P1VIVH206][J`03071`L01eMGD0MGEe0080NWYj0P1nOWh208>3
P`80R8R80P2=SHd209:BTQD0oooo000C0?ooo`80Vi^K0P2PX:020:BTY080ZJVY0P2][Jd20;:b/P80
]kNg0P2l_;`00`30`<00aLG50<G5a@020<[:bP80c/k>0P3Cdm<20=SHf080gMgM0P3Rh^820>OWi`80
jn_[0P3`l?020?Gem@80n_[j0P3moOd20?knoP80no_k00<0moOg0?3`l03`l?000P3Xj>P20>3Ph080
e]KF0P3<c<`20<71`@80]kNg0P2][Jd20:>SX`80Y:BT102UYJD20:NWY`80Z:RX0P2YZJT00`2[Zj/0
[:b/0:b/[0020:f][@80[jn_0P2`/;040;6a/@80/[:b2P2c/k<20;:b/P80/;2`0`2_[jl20:j^[P@0
[Jf]102^[Zh20:n_[`80/K6a0P2b/[840;>c/`@0];Bd102c/k<20;:b/P030;2`/02^[Zh0[Zj^0080
Zj^[0P2XZ:P20::RXP80VIVI0P2>SXh208:2PP80NGUi0P1bLW8206a/K080IVIV0P1QHF4205YJFP80
E5AD0P1>CTh00`1:BTX0AdM704M7A`0204E5A@80@d=30P11@D4203`l?080>CTi0P0c<c<202l_;`80
:RXZ0P0X:2P402LW9`809RHV100S8b<00`0U9BD0:BTY02TY:@0202d];@80<30`0P0e=CD203Xj>P80
?clo0P14A4@204U9B@80CTi>0P1CDe<205QHF080G5aL0P1QHF4206IVIP80Jf][00<0L71`07EeM@1e
MGD00P1jNWX207inOP80Ph>30P28R8P208f=S@80TY:B5@3oool001<0oooo0P2KVi/20:2PX080Y:BT
0P2YZJT20:j^[P80/[:b0P2g]kL20;bl_0030<71`@36a/H0a/K60080b/[:0P3?cll20=CDe080fMWI
0P3Ng]h20>?Sh`80j>SX0P3]kNd20?;blP80moOg0P3kno/40?gmo@80n_[j00<0m?Cd0>g]k@3]kNd0
0P3UiND20=cLg080dM7A0P38b<P20;fm_@80/k>c0P2XZ:P20:2PX080XZ:R0P2TY:@20:FUY@80YZJV
0P2XZ:P20:VYZ@030:ZZZP2/[:`0[:b/0080[Jf]0P2^[Zh20;2`/080/K6a0P2b/[820;>c/`H0];Bd
102c/k<20;:b/P80/K6a0P2_[jl30:j^[P@0[Jf]102^[Zh20:n_[`80/K6a0P2b/[840;>c/`@0];Bd
102c/k<20;6a/@030;2`/02^[Zh0[Zj^0080Zj^[0P2XZ:P20:>SX`80Vi^K0P2?Shl208B4Q080NWYj
0P1cLg<206a/K080IVIV0P1PH60205]KF`80De=C0P1=CDd00`17AdL0A4A404A4A00204=3@`80@D51
0P0o?cl203/k>`80=cLg0P0a<C4202d];@80:BTY0P0W9bL202@T90809BDU0P0T92@2024Q8@808b<S
00<092@T02PX:00X:2P00P0/;2`2030`<080=CDe0P0j>SX203lo?`80A4A40P19BDT204i>CP80De=C
0P1GEeL205aLG080HF5Q0P1VIVH206][J`03071`L01eMGD0MGEe0080NGUi0P1nOWh208>3P`80R8R8
0P2=SHd209:BTQD0oooo000C0?ooo`80Vi^K0P2PX:020:BTY080ZJVY0P2^[Zh20;:b/P80]kNg0P2l
_;`00`31`L40a/K60<K6aP020<[:bP80clo?0P3De=@20=WIf@80g]kN0P3Shn<20>SXj080kNg]0P3b
l_820?Ogm`80no_k103moOd20?[jnP030?Cdm03]kNd0kNg]0080iNGU0P3Lg=`20=7Ad@80b<S80P2m
_Kd20;>c/`80Z:RX0P2PX:020::RXP80Y:BT0P2UYJD20:JVYP80Z:RX0P2YZJT00`2ZZZX0[:b/0:b/
[0020:f][@80[Zj^0P2`/;020;6a/@80/[:b0P2c/k<60;Bd]0@0/k>c0P2b/[820;6a/@80[jn_0`2^
[Zh40:f][@@0[Zj^0P2_[jl20;6a/@80/[:b102c/k<40;Bd]0@0/k>c0P2a/K400`2`/;00[Zj^0:j^
[P020:^[Z`80Z:RX0P2SXj<209^KV`80Shn?0P24Q8@207YjNP80Lg=c0P1/K6`206IVIP80H61P0P1K
Fe/205=CD`80CDe=00<0AdM704A4A014A4@00P13@d<20451@@80?clo0P0k>c/203Lg=`80<C4a0P0]
;Bd202TY:@809bLW0P0T92@202DU9@8092@T0P0Q8B4202<S8`0302@T900X:2P0:2PX0080;2`/0P0`
<30203De=@80>SXj0P0o?cl204A4A080BDU90P1>CTh205=CD`80EeMG0P1LG5`2065QH@80IVIV0P1[
Jf/00`1`L700MGEe07EeM@0207UiN@80OWin0P23Ph<208R8R080SHf=0P2BTY8E0?ooo`004`3oool2
09^KV`80X:2P0P2UYJD20:VYZ@80[Zj^0P2c/k<20;Rh^080_Kfm00<0`L710<K6aP36a/H00P3;bl/2
0=3@d080eMGE0P3Jf]X20=oOg`80i>CT0P3YjNT20>k^kP80lo?c0P3hn?P20?gmo@80o_kn0P3lo?`2
0?Shn0030?7al@3YjNT0jNWY0080hN7Q0P3Hf=P20<k>cP80`l?30P2i^KT20:n_[`80Xj>S0P2PX:02
0:6QX@80Xj>S0P2TY:@20:FUY@80YjNW0P2YZJT00`2ZZZX0[:b/0:b/[0020:f][@80[Zj^0P2`/;02
0;6a/@80/[:b0P2c/k<40;Bd]080]KFe0P2d];@20;>c/`80/[:b0P2`/;020:n_[`030:j^[P2][Jd0
[Jf]00H0[Jf]0P2^[Zh20:n_[`80/K6a102b/[820;>c/`@0];Bd102c/k<20;6a/@030;2`/02^[Zh0
[Zj^0080[:b/0P2XZ:P20:>SX`80W9bL0P2BTY8208J6QP80O7al0P1dM7@206a/K080IVIV0P1OGel2
05YJFP80De=C0P1=CDd00`14A4@0@d=304=3@`020410@0@0?Cdm0P0i>CT203Hf=P80<C4a0P0/;2`2
02PX:0809BDU1P0R8R82020P80808R8R00<092@T02PX:00X:2P00P0[:b/2030`<080=CDe0P0j>SX2
03lo?`80A4A40P19BDT204i>CP80De=C0P1GEeL205aLG080HF5Q0P1VIVH206][J`03071`L01eMGD0
MGEe0080NGUi0P1nOWh208>3P`80R8R80P2=SHd209:BTQD0oooo000C0?ooo`80Vi^K0P2PX:020:FU
Y@80ZJVY0P2^[Zh20;>c/`80^;Rh0P2m_Kd00`31`L40a/K60<K6aP020<_;b`80d=3@0P3EeMD20=[J
fP80gmoO0P3Ti>@20>WYj@80k^k^0P3clo<20?Shn080oOgm0P3no_h20?clo080n?Sh00<0lO7a0>WY
j@3YjNT00P3QhN420=SHf080c/k>0P33`l<20;Vi^@80[jn_0P2SXj<20:2PX080XJ6Q0P2SXj<20:BT
Y080YJFU0P2WYjL20:VYZ@030:ZZZP2/[:`0[:b/0080[Jf]0P2^[Zh20;2`/080/K6a0P2b/[820;>c
/`@0];Bd0P2e]KD20;Bd]080/k>c0P2b/[820;2`/080[jn_00<0[Zj^0:f][@2][Jd01P2][Jd20:j^
[P80[jn_0P2a/K440;:b/P80/k>c102d];@40;>c/`80/K6a00<0/;2`0:j^[P2^[Zh00P2/[:`20:RX
Z080Xj>S0P2LW9`209:BTP80QXJ60P1lO7`207AdM080K6a/0P1VIVH205mOG`80FUYJ0P1CDe<204e=
C@0304A4A013@d<0@d=30080@410100m?Cd203Ti>@80=SHf0P0a<C4202`/;080:2PX0P0U9BD6028R
8P80820P0P0R8R800`0T92@0:2PX02PX:00202/[:`80<30`0P0e=CD203Xj>P80?clo0P14A4@204U9
B@80CTi>0P1CDe<205MGE`80G5aL0P1QHF4206IVIP80Jf][00<0L71`07EeM@1eMGD00P1iNGT207in
OP80Ph>30P28R8P208f=S@80TY:B5@3oool001<0oooo0P2KVi/20:2PX080YJFU0P2ZZZX20:j^[P80
/k>c0P2h^;P20;fm_@030<;2`P37alL0alO70080c<c<0P3AdM420=KFeP80fm_K0P3Ph>020>GUi@80
j^[Z0P3_knl20?Cdm080n_[j103no_h20?_kn`80mOGe00<0k^k^0>KViP3Vi^H00P3MgMd20=CDe080
bLW90P2o_kl20;Jf]P80Zj^[102OWil20:2PX080XZ:R0P2SXj<20:FUY@80YZJV0P2XZ:P00`2ZZZX0
Zj^[0:^[Z`020:f][@80[Zj^0P2`/;020;:b/P80/k>c0P2b/[820;>c/`80];Bd102e]KD20;Bd]080
/[:b102`/;000`2^[Zh0[Jf]0:f][@040:b/[080[Jf]0P2^[Zh20:n_[`80/;2`102b/[880;>c/`80
/[:b0P2a/K400`2`/;00[Zj^0:j^[P020:b/[080Z:RX0P2TY:@209jNWP80UIFE0P28R8P207emO@80
M7Ad0P1/K6`206EUI@80GUiN0P1IFET205=CD`80Bd];00<0A4A40410@010@4000P0l?3`203/k>`80
>SXj0P0h>3P203@d=080<30`0P0[:b/202HV9P808R8R100P820201lO7`@08B4Q00<092@T02HV9P0V
9RH00P0Z:RX2030`<080=CDe0P0j>SX203lo?`80A4A40P19BDT204i>CP80De=C0P1GEeL205aLG080
HF5Q0P1VIVH206][J`03071`L01eMGD0MGEe0080NWYj0P1nOWh208>3P`80R8R80P2=SHd209:BTQD0
oooo000C0?ooo`80Vi^K0P2PX:020:FUY@80ZZZZ0P2^[Zh20;>c/`80^;Rh0P2m_Kd00`32`/80alO7
0<O7a`020<c<c080dM7A0P3Fe]H20=_Kf`80h>3P0P3UiND20>[ZjP80kno_0P3dm?@20?[jnP@0o_kn
0P3kno/20?Gem@030>k^kP3Vi^H0i^KV0080gMgM0P3De=@20<W9b@80_kno0P2f][H20:^[Z`@0WinO
0P2PX:020::RXP80Xj>S0P2UYJD20:JVYP80Z:RX00<0ZZZZ0:^[Z`2[Zj/00P2][Jd20:j^[P80/;2`
0P2b/[820;>c/`80/[:b0P2c/k<20;Bd]0@0]KFe0P2d];@20;:b/P@0/;2`00<0[Zj^0:f][@2][Jd0
102/[:`20:f][@80[Zj^0P2_[jl20;2`/0@0/[:b202c/k<20;:b/P80/K6a00<0/;2`0:j^[P2^[Zh0
0P2/[:`20:RXZ080Y:BT0P2NWYh209FEU@80R8R80P1mOGd207AdM080K6a/0P1UIFD205iNGP80FEUI
0P1CDe<204];B`0304A4A010@400@4100080?3`l0P0k>c/203Xj>P80>3Ph0P0d=3@2030`<080:b/[
0P0V9RH2028R8P@0820P0P0O7al4024Q8@0302@T900V9RH09RHV0080:RXZ0P0`<30203De=@80>SXj
0P0o?cl204A4A080BDU90P1>CTh205=CD`80EeMG0P1LG5`2065QH@80IVIV0P1[Jf/00`1`L700MGEe
07EeM@0207YjNP80OWin0P23Ph<208R8R080SHf=0P2BTY8E0?ooo`004`3oool209^KV`80X:2P0P2U
YJD20:ZZZP80[jn_0P2d];@20;Vi^@80_[jn00<0`/;20<S8b038b<P00P3<c<`20=7Ad@80e]KF0P3K
fm/20>7Qh@80i^KV0P3[jn/20?3`l080m_Kf0P3kno/20?ooo`80o_kn0P3inOT20?;blP030>_[j`3R
h^80h^;R0080fMWI0P3?cll20<G5a@80_;bl0P2b/[820:JVYP80W9bL0P2NWYh209nOW`80XJ6Q0P2R
XZ820:FUY@80YZJV0P2XZ:P00`2ZZZX0Zj^[0:^[Z`020:f][@80[Zj^0P2_[jl60;6a/@80/k>c0P2d
];@40;Fe]@80/k>c0P2a/K440;2`/0030:j^[P2/[:`0[:b/00@0[:b/0P2][Jd20:j^[P80[jn_0P2`
/;020;6a/@80/[:b202c/k<20;:b/P80/K6a00<0/;2`0:j^[P2^[Zh00P2/[:`20:RXZ080Y:BT0P2N
WYh209NGU`80RXZ:0P1nOWh207AdM080K6a/0P1TI6@205iNGP80EeMG0P1BDU8204];B`0304E5A@0l
?3`0?3`l0080>SXj0P0i>CT403Lg=`80<S8b0P0_;bl202TY:@8092@T0P0P820201hN7P807AdM0P0N
7Qh4020P8003028R8P0U9BD09BDU0080:RXZ0P0_;bl203De=@80>SXj0P0o?cl204A4A080BDU90P1>
CTh205=CD`80EeMG0P1LG5`2065QH@80IVIV0P1[Jf/00`1`L700MGEe07EeM@0207YjNP80OWin0P23
Ph<208R8R080SHf=0P2ATI4E0?ooo`004`3oool209^KV`80X:2P0P2UYJD20:ZZZP80[jn_0P2d];@2
0;Vi^@80_[jn00<0`/;20<S8b038b<P00P3<c<`20=7Ad@80e]KF0P3Kfm/20>7Qh@80i^KV0P3[jn/2
0?3`l080m_Kf0P3kno/20?ooo`80o_kn0P3inOT20?;blP030>_[j`3Rh^80h^;R0080fMWI0P3?cll2
0<G5a@80_;bl0P2b/[820:JVYP80W9bL0P2NWYh209nOW`80XJ6Q0P2RXZ820:FUY@80YZJV0P2XZ:P0
0`2ZZZX0Zj^[0:^[Z`020:f][@80[Zj^0P2_[jl60;6a/@80/k>c0P2d];@40;Fe]@80/k>c0P2a/K44
0;2`/0030:j^[P2/[:`0[:b/00@0[:b/0P2][Jd20:j^[P80[jn_0P2`/;020;6a/@80/[:b202c/k<2
0;:b/P80/K6a00<0/;2`0:j^[P2^[Zh00P2/[:`20:RXZ080Y:BT0P2NWYh209NGU`80RXZ:0P1nOWh2
07AdM080K6a/0P1TI6@205iNGP80EeMG0P1BDU8204];B`0304E5A@0l?3`0?3`l0080>SXj0P0i>CT4
03Lg=`80<S8b0P0_;bl202TY:@8092@T0P0P820201hN7P807AdM0P0N7Qh4020P8003028R8P0U9BD0
9BDU0080:RXZ0P0_;bl203De=@80>SXj0P0o?cl204A4A080BDU90P1>CTh205=CD`80EeMG0P1LG5`2
065QH@80IVIV0P1[Jf/00`1`L700MGEe07EeM@0207YjNP80OWin0P23Ph<208R8R080SHf=0P2ATI4E
0?ooo`004`3oool209^KV`80X:2P0P2UYJD20:ZZZP80[jn_0P2d];@20;Vi^@80_[jn00<0`l?30<S8
b038b<P00P3=cLd20=;BdP80emOG0P3Lg=`20>7Qh@80inOW0P3/k>`20?7al@80moOg0P3lo?`20?oo
o`80oOgm0P3gmoL20?3`l0030>OWi`3Ng]h0g]kN0080eMGE0P3;bl/20<;2`P80^KVi0P2][Jd20:6Q
X@80Vi^K0P2MWId209nOW`80XJ6Q0P2RXZ820:BTY080YZJV0P2XZ:P00`2ZZZX0Zj^[0:^[Z`020:b/
[080[Zj^0P2_[jl20;2`/0@0/K6a0P2c/k<20;Bd]0@0]KFe0P2c/k<20;:b/P@0/;2`00<0[Zj^0:b/
[02/[:`00P2[Zj/20:b/[080[Jf]0P2^[Zh20:n_[`80/;2`0P2a/K440;:b/PH0/k>c0P2b/[820;6a
/@030;2`/02^[Zh0[Zj^0080[:b/0P2XZ:P20:BTY080WinO0P2HV9P208^;R`80Ogmo0P1dM7@206][
J`80I6AT0P1NGUh205IFEP80DE5A0P1:BTX00`13@d<0>CTi03Ti>@0203Ph>080=CDe0P0d=3@203De
=@80<C4a0P0];Bd202PX:0808b<S0P0O7al201`L70806a/K0P0L71`401hN7P03020P800U9BD09BDU
0080:RXZ0P0_;bl203De=@80>SXj0P0o?cl204A4A080BDU90P1>CTh205=CD`80EeMG0P1LG5`2065Q
H@80IVIV0P1[Jf/00`1`L700MGEe07EeM@0207YjNP80OWin0P23Ph<208R8R080SHf=0P2BTY8E0?oo
o`004`3oool209^KV`80X:2P0P2UYJD20:ZZZP80[jn_0P2d];@20;Vi^@80_[jn00<0`l?30<S8b038
b<P00P3=cLd20=;BdP80emOG0P3Lg=`20>7Qh@80inOW0P3/k>`20?7al@80moOg0P3lo?`20?ooo`80
oOgm0P3gmoL20?3`l0030>OWi`3Ng]h0g]kN0080eMGE0P3;bl/20<;2`P80^KVi0P2][Jd20:6QX@80
Vi^K0P2MWId209nOW`80XJ6Q0P2RXZ820:BTY080YZJV0P2XZ:P00`2ZZZX0Zj^[0:^[Z`020:b/[080
[Zj^0P2_[jl20;2`/0@0/K6a0P2c/k<20;Bd]0@0]KFe0P2c/k<20;:b/P@0/;2`00<0[Zj^0:b/[02/
[:`00P2[Zj/20:b/[080[Jf]0P2^[Zh20:n_[`80/;2`0P2a/K440;:b/PH0/k>c0P2b/[820;6a/@03
0;2`/02^[Zh0[Zj^0080[:b/0P2XZ:P20:BTY080WinO0P2HV9P208^;R`80Ogmo0P1dM7@206][J`80
I6AT0P1NGUh205IFEP80DE5A0P1:BTX00`13@d<0>CTi03Ti>@0203Ph>080=CDe0P0d=3@203De=@80
<C4a0P0];Bd202PX:0808b<S0P0O7al201`L70806a/K0P0L71`401hN7P03020P800U9BD09BDU0080
:RXZ0P0_;bl203De=@80>SXj0P0o?cl204A4A080BDU90P1>CTh205=CD`80EeMG0P1LG5`2065QH@80
IVIV0P1[Jf/00`1`L700MGEe07EeM@0207YjNP80OWin0P23Ph<208R8R080SHf=0P2BTY8E0?ooo`00
4`3oool209^KV`80X:2P0P2UYJD20:ZZZP80[jn_0P2d];@20;Vi^@80_[jn00<0a<C40<W9b@39bLT0
0P3>c/h20=?Cd`80f=SH0P3MgMd20>;RhP80j>SX0P3]kNd20?;blP80n?Sh0P3moOd20?ooo`80no_k
0P3dm?@20>g]k@030>?Sh`3Kfm/0fm_K0080d];B0P38b<P20;no_`80]KFe0P2YZJT209fMW@80Vi^K
0P2LW9`209jNWP80X:2P0P2RXZ820:BTY080YZJV0P2XZ:P00`2YZJT0Zj^[0:^[Z`020:b/[080[Jf]
0P2^[Zh40;2`/080/K6a0P2c/k<20;Bd]0@0]KFe0P2d];@20;:b/P80/K6a0P2`/;000`2^[Zh0[Jf]
0:f][@040:b/[080[Jf]0P2^[Zh20:n_[`80/;2`0P2a/K440;:b/P@0/k>c102b/[820;6a/@030;2`
/02^[Zh0[Zj^0080[:b/0P2XZ:P20:BTY080WinO0P2IVIT208f=S@80P8200P1dM7@206a/K080Hf=S
0P1MGEd205EEE@80D51@0P18B4P00`11@D40>3Ph03Ph>00203Hf=P80<c<c100b<S8202l_;`80:b/[
0P0W9bL2028R8P807AdM0P0J6QX201TI6@@06a/K0P0M7Ad00`0P82009BDU02DU9@0202XZ:P80;bl_
0P0e=CD203Xj>P80?clo0P14A4@204U9B@80CTi>0P1CDe<205MGE`80G5aL0P1QHF4206IVIP80Jf][
00<0L71`07EeM@1eMGD00P1jNWX207inOP80Ph>30P28R8P208f=S@80TY:B5@3oool001<0oooo0P2K
Vi/20:2PX080YJFU0P2ZZZX20:n_[`80];Bd0P2i^KT20;jn_P030<C4a039bLT0bLW90080c/k>0P3C
dm<20=SHf080gMgM0P3Rh^820>SXj080kNg]0P3bl_820?Shn080oOgm0P3oool20?_kn`80m?Cd0P3]
kNd00`3Shn<0fm_K0=_Kf`020=;BdP80b<S80P2o_kl20;Fe]@80ZJVY0P2MWId209^KV`80W9bL0P2N
WYh20:2PX080XZ:R0P2TY:@20:JVYP80Z:RX00<0ZJVY0:^[Z`2[Zj/00P2/[:`20:f][@80[Zj^102`
/;020;6a/@80/k>c0P2d];@40;Fe]@80];Bd0P2b/[820;6a/@80/;2`00<0[Zj^0:f][@2][Jd0102/
[:`20:f][@80[Zj^0P2_[jl20;2`/080/K6a102b/[840;>c/`@0/[:b0P2a/K400`2`/;00[Zj^0:j^
[P020:b/[080Z:RX0P2TY:@209nOW`80VIVI0P2=SHd20820P080M7Ad0P1/K6`206=SH`80GEeM0P1E
EED2051@D080B4Q800<0@D5103Ph>00h>3P00P0f=SH203<c<`@0<S8b0P0_;bl202/[:`809bLW0P0R
8R8201dM7@806QXJ0P0I6AT401/K6`807AdM00<0820P02DU9@0U9BD00P0Z:RX202l_;`80=CDe0P0j
>SX203lo?`80A4A40P19BDT204i>CP80De=C0P1GEeL205aLG080HF5Q0P1VIVH206][J`03071`L01e
MGD0MGEe0080NWYj0P1nOWh208>3P`80R8R80P2=SHd209:BTQD0oooo000C0?ooo`80Vi^K0P2PX:02
0:FUY@80ZZZZ0P2_[jl20;Fe]@80^[Zj0P2o_kl00`34a<@0bLW90<W9b@020<k>cP80dm?C0P3Hf=P2
0=kNgP80hn?S0P3Xj>P20>k^kP80lo?c0P3inOT20?knoP80oooo0P3inOT20?;blP80jNWY00<0h>3P
0=OGe`3GemL00P3>c/h20<G5a@80_;bl0P2a/K420:FUY@80VIVI0P2KVi/209bLW080WYjN0P2PX:02
0::RXP80Y:BT0P2VYZH20:RXZ0030:VYZ@2[Zj/0Zj^[0080[:b/0P2][Jd20:j^[P80[jn_0P2`/;02
0;6a/@80/k>c0P2d];@40;Fe]@80];Bd0P2b/[820;6a/@80/;2`00<0[Zj^0:b/[02/[:`0102/[:`2
0:f][@80[Zj^0P2_[jl20;2`/0@0/K6a202b/[820;6a/@80/;2`00<0[jn_0:j^[P2^[Zh00P2[Zj/2
0:RXZ080Y:BT0P2OWil209VIV@80Shn?0P21PH4207EeM@80K6a/0P1SHf<205aLG080EEEE0P1?Cdl2
04M7A`030410@00h>3P0>3Ph0080<c<c0P0a<C42030`<0@0;bl_0P0Z:RX202HV9P80820P0P0K6a/4
01LG5`@06ATI0P0K6a/00`0P82009BDU02DU9@0202/[:`80<30`0P0e=CD203Xj>P80?clo0P14A4@2
04U9B@80CTi>0P1CDe<205QHF080G5aL0P1QHF4206IVIP80Jf][00<0L71`07EeM@1eMGD00P1jNWX2
07inOP80Ph>30P28R8P208f=S@80TY:B5@3oool001<0oooo0P2KVi/20:2PX080YJFU0P2ZZZX20:n_
[`80]KFe0P2j^[X20;no_`030<C4a039bLT0bLW90080c/k>0P3Cdm<20=SHf080g]kN0P3Shn<20>SX
j080k^k^0P3clo<20?Win@80o_kn0P3oool20?Win@80l_;b0P3YjNT00`3Ph>00emOG0=OGe`020<k>
cP80aLG50P2l_;`20;6a/@80YJFU0P2IVIT209^KV`80W9bL0P2NWYh20:2PX080XZ:R0P2TY:@20:JV
YP80Z:RX00<0ZJVY0:^[Z`2[Zj/00P2/[:`20:f][@80[Zj^0P2_[jl20;2`/080/K6a0P2c/k<20;Bd
]0@0]KFe0P2d];@20;:b/P80/K6a0P2`/;000`2^[Zh0[:b/0:b/[0040:b/[080[Jf]0P2^[Zh20:n_
[`80/;2`102a/K480;:b/P80/K6a0P2`/;000`2_[jl0[Zj^0:j^[P020:^[Z`80Z:RX0P2TY:@209nO
W`80VIVI0P2?Shl20861P@80MGEe0P1/K6`206=SH`80G5aL0P1EEED204m?C`80AdM700<0@41003Ph
>00h>3P00P0c<c<2034a<@80<30`100_;bl202XZ:P809RHV0P0P820201/K6`@05aLG100I6AT201/K
6`03020P800U9BD09BDU0080:b/[0P0`<30203De=@80>SXj0P0o?cl204A4A080BDU90P1>CTh205=C
D`80F5QH0P1LG5`2065QH@80IVIV0P1[Jf/00`1`L700MGEe07EeM@0207YjNP80OWin0P23Ph<208R8
R080SHf=0P2BTY8E0?ooo`004`3oool209^KV`80X:2P0P2UYJD20:^[Z`80/;2`0P2e]KD20;Zj^P80
_kno00<0a<C40<W9b@39bLT00P3?cll20=CDe080fMWI0P3Ng]h20>CTi080jNWY0P3_knl20?Cdm080
n_[j0P3oool20?gmo@80m_Kf0P3_knl20>GUi@030=cLg03Cdm<0dm?C0080bl_;0P32`/820;Rh^080
[:b/0P2QXJ4209NGU`80VYZJ0P2LW9`209nOW`80XJ6Q0P2SXj<20:BTY080YZJV0P2XZ:P00`2YZJT0
Zj^[0:^[Z`020:b/[080[Jf]0P2^[Zh20:n_[`80/;2`0P2a/K420;>c/`80];Bd102e]KD20;Bd]080
/[:b0P2a/K420:n_[`030:j^[P2][Jd0[Jf]0080[:b/0P2][Jd40:j^[P80[jn_0P2`/;060;6a/@H0
/[:b0P2a/K420;2`/0030:n_[`2][Jd0[Jf]0080Zj^[0P2XZ:P20:BTY080WinO0P2HV9P2092@T080
PX:20P1fMWH206a/K080Hf=S0P1KFe/205ADE080CDe=0P16ATH00`0n?Sh0=SHf03Hf=P02038b<P80
;bl_100];Bd202h^;P80:BTY0P0T92@201hN7P806ATI0P0F5QH201DE5@@05aLG0P0K6a/00`0P8200
9BDU02DU9@0202/[:`80<30`0P0e=CD203Xj>P80?clo0P14A4@204U9B@80CTi>0P1CDe<205QHF080
GEeM0P1QHF4206IVIP80Jf][00<0L71`07EeM@1eMGD00P1jNWX207inOP80Ph>30P28R8P208f=S@80
TY:B5@3oool001<0oooo0P2KVi/20:2PX080YZJV0P2[Zj/20;2`/080]KFe0P2j^[X20;no_`030<G5
a@3:b/X0b/[:0080clo?0P3EeMD20=[JfP80gmoO0P3Ti>@20>[ZjP80kno_0P3emOD20?[jnP80oooo
0P3kno/20?Cdm080jn_[0P3QhN400`3IfMT0d=3@0=3@d0020<O7a`80_kno0P2b/[820:NWY`80W9bL
0P2HV9P209^KV`80WIfM0P2OWil20:6QX@80Xj>S0P2UYJD20:JVYP80Z:RX00<0ZJVY0:^[Z`2[Zj/0
0P2/[:`20:f][@80[Zj^0P2_[jl20;2`/080/K6a0P2c/k<20;Bd]0@0]KFe0P2d];@20;:b/P80/K6a
0P2_[jl00`2^[Zh0[Jf]0:f][@020:f][@@0[Zj^102_[jl20;2`/0P0/K6a0P2b/[820;6a/@80/;2`
0P2_[jl00`2^[Zh0[:b/0:b/[0020:ZZZP80Z:RX0P2TY:@209jNWP80V9RH0P2@T90208>3P`80MgMg
0P1/K6`206=SH`80Fe]K0P1DE5@204];B`80ADE500<0?Cdm03De=@0e=CD00P0`<30202h^;P80;2`/
0P0[:b/202d];@80:2PX0P0S8b<201`L708061PH100C4a<201DE5@805QHF0P0K6a/00`0P82009BDU
02DU9@0202/[:`80<30`0P0e=CD203Xj>P80?clo0P14A4@204U9B@80CTi>0P1CDe<205QHF080GEeM
0P1RHV8206IVIP80Jf][00<0L71`07EeM@1eMGD00P1jNWX207inOP80Ph>30P28R8P208f=S@80TY:B
5@3oool001<0oooo0P2KVi/20:2PX080YZJV0P2[Zj/20;2`/080]KFe0P2j^[X20;no_`030<G5a@3:
b/X0b/[:0080clo?0P3EeMD20=[JfP80gmoO0P3Ti>@20>[ZjP80kno_0P3emOD20?[jnP80oooo0P3k
no/20?Cdm080jn_[0P3QhN400`3IfMT0d=3@0=3@d0020<O7a`80_kno0P2b/[820:NWY`80W9bL0P2H
V9P209^KV`80WIfM0P2OWil20:6QX@80Xj>S0P2UYJD20:JVYP80Z:RX00<0ZJVY0:^[Z`2[Zj/00P2/
[:`20:f][@80[Zj^0P2_[jl20;2`/080/K6a0P2c/k<20;Bd]0@0]KFe0P2d];@20;:b/P80/K6a0P2_
[jl00`2^[Zh0[Jf]0:f][@020:f][@@0[Zj^102_[jl20;2`/0P0/K6a0P2b/[820;6a/@80/;2`0P2_
[jl00`2^[Zh0[:b/0:b/[0020:ZZZP80Z:RX0P2TY:@209jNWP80V9RH0P2@T90208>3P`80MgMg0P1/
K6`206=SH`80Fe]K0P1DE5@204];B`80ADE500<0?Cdm03De=@0e=CD00P0`<30202h^;P80;2`/0P0[
:b/202d];@80:2PX0P0S8b<201`L708061PH100C4a<201DE5@805QHF0P0K6a/00`0P82009BDU02DU
9@0202/[:`80<30`0P0e=CD203Xj>P80?clo0P14A4@204U9B@80CTi>0P1CDe<205QHF080GEeM0P1R
HV8206IVIP80Jf][00<0L71`07EeM@1eMGD00P1jNWX207inOP80Ph>30P28R8P208f=S@80TY:B5@3o
ool001<0oooo0P2LW9`20:6QX@80YZJV0P2[Zj/20;2`/080]KFe0P2k^k/20<30`0030<G5a@3:b/X0
b/[:0080d=3@0P3EeMD20=[JfP80h>3P0P3UiND20>_[j`80l?3`0P3fm_H20?_kn`80o_kn0P3inOT2
0?7al@80inOW0P3Ng]h00`3Fe]H0cLg=0<g=c@020<C4a080^[Zj0P2^[Zh20:2PX0@0VYZJ0P2LW9`2
09jNWP80X:2P0P2RXZ820:BTY080YZJV0P2WYjL20:RXZ0030:ZZZP2[Zj/0Zj^[0080[:b/0P2][Jd2
0:j^[P80[jn_0P2`/;020;6a/@80/[:b0P2d];@40;Fe]@80];Bd0P2b/[820;6a/@80/;2`00<0[jn_
0:j^[P2^[Zh01P2^[Zh40:n_[`@0/;2`202a/K440;2`/080[jn_00<0[Jf]0:b/[02/[:`00P2YZJT2
0:NWY`80Y:BT0P2NWYh209NGU`80T92@0P24Q8@207MgM`80KFe]0P1SHf<205YJFP80De=C0P1:BTX2
04=3@`0303`l?00d=3@0=3@d0080;Rh^0P0];Bd202/[:`80:RXZ0P0[:b/202LW9`808R8R0P0J6QX2
01HF5P@04A4A0P0C4a<201HF5P806a/K00<0820P02HV9P0V9RH00P0[:b/2030`<080=CDe0P0j>SX2
03lo?`80A4A40P19BDT204i>CP80De=C0P1HF5P205eMG@80HV9R0P1WIfL206][J`03071`L01eMGD0
MGEe0080NWYj0P1nOWh208>3P`80R8R80P2=SHd209:BTQD0oooo000C0?ooo`80W9bL0P2QXJ420:JV
YP80Zj^[0P2`/;020;Fe]@80^k^k0P30`<000`35aLD0b/[:0<[:bP020=3@d080eMGE0P3Jf]X20>3P
h080iNGU0P3[jn/20?3`l080m_Kf0P3kno/20?knoP80nOWi0P3alO420>OWi`80g]kN00<0e]KF0<g=
c@3=cLd00P34a<@20;Zj^P80[Zj^0P2PX:0409ZJVP80W9bL0P2NWYh20:2PX080XZ:R0P2TY:@20:JV
YP80YjNW0P2XZ:P00`2ZZZX0Zj^[0:^[Z`020:b/[080[Jf]0P2^[Zh20:n_[`80/;2`0P2a/K420;:b
/P80];Bd102e]KD20;Bd]080/[:b0P2a/K420;2`/0030:n_[`2^[Zh0[Zj^00H0[Zj^102_[jl40;2`
/0P0/K6a102`/;020:n_[`030:f][@2/[:`0[:b/0080ZJVY0P2WYjL20:BTY080WYjN0P2GUiL2092@
T080Q8B40P1gMgL206e]K@80Hf=S0P1JFUX205=CD`80BTY:0P13@d<00`0l?3`0=3@d03@d=00202h^
;P80;Bd]0P0[:b/202XZ:P80:b/[0P0W9bL2028R8P806QXJ0P0F5QH4014A4@804a<C0P0F5QH201/K
6`03020P800V9RH09RHV0080:b/[0P0`<30203De=@80>SXj0P0o?cl204A4A080BDU90P1>CTh205=C
D`80F5QH0P1MGEd2069RHP80IfMW0P1[Jf/00`1`L700MGEe07EeM@0207YjNP80OWin0P23Ph<208R8
R080SHf=0P2BTY8E0?ooo`004`3oool209^KV`80XJ6Q0P2VYZH20:^[Z`80/;2`0P2f][H20;^k^`80
`<3000<0a/K60<_;b`3;bl/00P3@d=020=KFeP80fm_K0P3Ph>020>KViP80jn_[0P3alO420?KfmP80
oOgm0P3lo?`20?KfmP80k^k^0P3Shn<20=_Kf`030=;BdP39bLT0bLW90080`<300P2d];@20:VYZ@H0
W9bL0P2NWYh209nOW`80XJ6Q0P2SXj<20:FUY@80YjNW0P2XZ:P20:VYZ@030:ZZZP2[Zj/0Zj^[0080
Zj^[0P2/[:`20:f][@80[Zj^0P2_[jl20;2`/080/[:b0P2c/k<20;Bd]080]KFe0P2d];@20;:b/P80
/K6a0P2`/;030:n_[`@0[Zj^0P2_[jl40;2`/0P0/K6a102`/;040:n_[`80[Zj^00<0[Jf]0:^[Z`2[
Zj/00P2YZJT20:JVYP80Xj>S0P2NWYh209NGU`80Shn?0P25QHD207UiN@80KVi^0P1SHf<205YJFP80
DU9B0P1:BTX20492@P0303Xj>P0c<c<0<c<c0080;Rh^0P0/;2`202/[:`@0:BTY0P0V9RH2020P8080
61PH0P0C4a<400l?3`804Q8B0P0F5QH201/K6`03024Q8@0V9RH09RHV0080:b/[0P0`<30203De=@80
>SXj0P0o?cl204A4A080BDU90P1>CTh205=CD`80F5QH0P1MGEd2069RHP80IfMW0P1[Jf/00`1`L700
MGEe07EeM@0207YjNP80Ogmo0P23Ph<208R8R080SHf=0P2BTY8E0?ooo`004`3oool209^KV`80XJ6Q
0P2VYZH20:^[Z`80/;2`0P2f][H20;^k^`80`<3000<0a/K60<_;b`3;bl/00P3@d=020=KFeP80fm_K
0P3Ph>020>KViP80jn_[0P3alO420?KfmP80oOgm0P3lo?`20?KfmP80k^k^0P3Shn<20=_Kf`030=;B
dP39bLT0bLW90080`<300P2d];@20:VYZ@H0W9bL0P2NWYh209nOW`80XJ6Q0P2SXj<20:FUY@80YjNW
0P2XZ:P20:VYZ@030:ZZZP2[Zj/0Zj^[0080Zj^[0P2/[:`20:f][@80[Zj^0P2_[jl20;2`/080/[:b
0P2c/k<20;Bd]080]KFe0P2d];@20;:b/P80/K6a0P2`/;030:n_[`@0[Zj^0P2_[jl40;2`/0P0/K6a
102`/;040:n_[`80[Zj^00<0[Jf]0:^[Z`2[Zj/00P2YZJT20:JVYP80Xj>S0P2NWYh209NGU`80Shn?
0P25QHD207UiN@80KVi^0P1SHf<205YJFP80DU9B0P1:BTX20492@P0303Xj>P0c<c<0<c<c0080;Rh^
0P0/;2`202/[:`@0:BTY0P0V9RH2020P808061PH0P0C4a<400l?3`804Q8B0P0F5QH201/K6`03024Q
8@0V9RH09RHV0080:b/[0P0`<30203De=@80>SXj0P0o?cl204A4A080BDU90P1>CTh205=CD`80F5QH
0P1MGEd2069RHP80IfMW0P1[Jf/00`1`L700MGEe07EeM@0207YjNP80Ogmo0P23Ph<208R8R080SHf=
0P2BTY8E0?ooo`004`3oool209^KV`80XJ6Q0P2VYZH20:^[Z`80/;2`0P2f][H20;^k^`80`<3000<0
a/K60<_;b`3;bl/00P3@d=020=KFeP80fm_K0P3QhN420>KViP80k>c/0P3alO420?Ogm`80oOgm0P3i
nOT20?;blP80j^[Z0P3Ph>020=SHf0030<o?c`35aLD0aLG50080^k^k0P2`/;020:BTY080W9bL0P2M
WId209jNWP80X:2P0P2QXJ420:>SX`80Y:BT0P2VYZH20:NWY`80Z:RX0P2YZJT00`2ZZZX0Zj^[0:^[
Z`020:^[Z`80[:b/0P2][Jd20:j^[P80[jn_0P2`/;020;6a/@80/k>c0P2d];@40;Fe]@80/k>c0P2b
/[820;6a/@030;2`/02_[jl0[jn_00@0[jn_102`/;060;6a/@H0/;2`102_[jl20:j^[P80[Jf]00<0
[:b/0:ZZZP2ZZZX00P2XZ:P20:FUY@80XZ:R0P2NWYh209NGU`80Shn?0P26QXH207YjNP80KVi^0P1S
Hf<205YJFP80DE5A0P19BDT20492@P0303Ti>@0a<C40<C4a0080;Rh^0P0/;2`202XZ:P80:2PX0P0W
9bL202@T90807QhN0P0F5QH2014A4@803Ph>0P0=3@d2014A4@805QHF0P0K6a/00`0Q8B409RHV02HV
9P0202/[:`80<30`0P0e=CD203Xj>P80?clo0P14A4@204U9B@80CTi>0P1CDe<205QHF080GEeM0P1R
HV8206MWI`80Jf][00<0L71`07EeM@1eMGD00P1jNWX207moO`80Ph>30P28R8P208f=S@80TY:B5@3o
ool001<0oooo0P2KVi/20:6QX@80YZJV0P2[Zj/20;2`/080][Jf0P2k^k/20<30`0030<K6aP3;bl/0
bl_;0080d=3@0P3Fe]H20=_Kf`80hN7Q0P3Vi^H20>c/k080lO7a0P3gmoL20?gmo@80nOWi0P3bl_82
0>[ZjP80h>3P0P3Hf=P00`3?cll0aLG50<G5a@020;^k^`80/;2`0P2TY:@209bLW080WIfM0P2NWYh2
0:2PX080XJ6Q0P2SXj<20:BTY080YZJV0P2WYjL20:RXZ080ZJVY00<0ZZZZ0:^[Z`2[Zj/00P2[Zj/2
0:b/[080[Jf]0P2^[Zh20:n_[`80/;2`0P2a/K420;>c/`80];Bd102e]KD20;>c/`80/[:b0P2a/K40
0`2`/;00[jn_0:n_[`040:n_[`@0/;2`1P2a/K460;2`/0@0[jn_0P2^[Zh20:f][@030:b/[02ZZZX0
ZZZZ0080Z:RX0P2UYJD20::RXP80WYjN0P2GUiL208n?S`80QXJ60P1jNWX206i^KP80Hf=S0P1JFUX2
055AD@80BDU90P12@T800`0i>CT0<C4a034a<@0202h^;P80;2`/0P0Z:RX202PX:0809bLW0P0T92@2
01hN7P805QHF0P0A4A4200h>3P803@d=0P0A4A4201HF5P806a/K00<08B4Q02HV9P0V9RH00P0[:b/2
030`<080=CDe0P0j>SX203lo?`80A4A40P19BDT204i>CP80De=C0P1HF5P205eMG@80HV9R0P1WIfL2
06][J`03071`L01eMGD0MGEe0080NWYj0P1oOgl208>3P`80R8R80P2=SHd209:BTQD0oooo000C0?oo
o`80W9bL0P2QXJ420:JVYP80Zj^[0P2a/K420;Jf]P80^k^k0P31`L400`36a/H0bl_;0<_;b`020=7A
d@80e]KF0P3Lg=`20>7Qh@80inOW0P3/k>`20?;blP80moOg0P3lo?`20?KfmP80l?3`0P3WinL20=gM
g@80e=CD00<0bl_;0<;2`P32`/800P2f][H20:^[Z`80X:2P0P2NWYh209nOW`80X:2P0P2QXJ420:>S
X`80Y:BT0P2VYZH20:NWY`80Z:RX0P2YZJT20:ZZZPD0Zj^[102/[:`20:f][@80[Zj^0P2`/;020;6a
/@80/[:b0P2d];@40;Fe]@80];Bd0P2c/k<20;:b/P<0/K6a102`/;0<0;6a/@80/;2`102_[jl20:j^
[P80[Jf]0P2/[:`00`2[Zj/0ZJVY0:VYZ@020:NWY`80Y:BT0P2QXJ4209fMW@80UiNG0P2?Shl208J6
QP80Ng]k0P1_Kfl206ATI080FEUI0P1@D50204Q8B080@D5100<0>CTi030`<00`<3000P0^;Rh202/[
:`80:BTY0P0W9bL202@T90808b<S0P0K6a/201DE5@80410@100<30`2014A4@805QHF0P0K6a/00`0Q
8B409RHV02HV9P0202/[:`80<30`0P0e=CD203Xj>P80@4100P15ADD204Y:BP80Cdm?0P1CDe<205QH
F080GEeM0P1RHV8206MWI`80Jf][00<0L71`07EeM@1eMGD00P1jNWX207moO`80Ph>30P28R8P208f=
S@80TY:B5@3oool001<0oooo0P2LW9`20:6QX@80YZJV0P2[Zj/20;6a/@80][Jf0P2k^k/20<71`@03
0<K6aP3;bl/0bl_;0080dM7A0P3Fe]H20=cLg080hN7Q0P3WinL20>c/k080l_;b0P3gmoL20?clo080
m_Kf0P3`l?020>OWi`80gMgM0P3De=@00`3;bl/0`/;20<;2`P020;Jf]P80Zj^[0P2PX:0209jNWP80
WinO0P2PX:020:6QX@80Xj>S0P2TY:@20:JVYP80YjNW0P2XZ:P20:VYZ@80ZZZZ1@2[Zj/40:b/[080
[Jf]0P2^[Zh20;2`/080/K6a0P2b/[820;Bd]0@0]KFe0P2d];@20;>c/`80/[:b0`2a/K440;2`/0`0
/K6a0P2`/;040:n_[`80[Zj^0P2][Jd20:b/[0030:^[Z`2YZJT0ZJVY0080YjNW0P2TY:@20:6QX@80
WIfM0P2GUiL208n?S`80QXJ60P1kNg/206m_K`80I6AT0P1IFET2051@D080B4Q80P11@D400`0i>CT0
<30`030`<00202h^;P80:b/[0P0Y:BT202LW9`8092@T0P0S8b<201/K6`805ADE0P0@410400`<3080
4A4A0P0F5QH201/K6`03024Q8@0V9RH09RHV0080:b/[0P0`<30203De=@80>SXj0P10@40204E5A@80
BTY:0P1?Cdl205=CD`80F5QH0P1MGEd2069RHP80IfMW0P1[Jf/00`1`L700MGEe07EeM@0207YjNP80
Ogmo0P23Ph<208R8R080SHf=0P2BTY8E0?ooo`004`3oool209bLW080XJ6Q0P2VYZH20:^[Z`80/K6a
0P2f][H20;bl_080`L7100<0alO70<c<c03<c<`00P3AdM420=OGe`80g=cL0P3Rh^820>OWi`80kNg]
0P3clo<20?Shn080n_[j0P3clo<20>g]k@80i>CT0P3Kfm/20=7Ad@030<S8b02n_[h0_[jn0080/[:b
0P2VYZH20:2PX0@0XJ6Q0P2RXZ820:>SX`80Y:BT0P2VYZH20:NWY`80ZJVY102ZZZX;0:^[Z`80[:b/
0P2][Jd20:n_[`80/;2`0P2a/K420;>c/`80]KFe0P2f][H20;Fe]@80];Bd0P2c/k<30;:b/P@0/K6a
202b/[840;6a/@80/;2`0P2_[jl20:j^[P@0[:b/0P2[Zj/00`2YZJT0Z:RX0:RXZ0020:JVYP80Xj>S
0P2PX:0209bLW080UiNG0P2?Shl208J6QP80O7al0P1`L70206ATI080FEUI0P1?Cdl204Q8B080@410
00<0>3Ph02l_;`0_;bl00P0];Bd202/[:`80:2PX0P0V9RH2028R8P808B4Q0P0I6AT201<C4`803Ph>
100;2`/2014A4@805QHF0P0L71`00`0Q8B409RHV02HV9P0202/[:`80<30`0P0f=SH203/k>`80@410
0P15ADD204Y:BP80Cdm?0P1DE5@205UIF@80GEeM0P1RHV8206MWI`80K6a/00<0L71`07EeM@1eMGD0
0P1jNWX207moO`80Ph>30P28R8P208f=S@80TY:B5@3oool001<0oooo0P2LW9`20:6QX@80YZJV0P2[
Zj/20;6a/@80][Jf0P2l_;`20<71`@030<O7a`3<c<`0c<c<0080dM7A0P3GemL20=cLg080h^;R0P3W
inL20>g]k@80lo?c0P3hn?P20?[jnP80lo?c0P3]kNd20>CTi080fm_K0P3AdM400`38b<P0_[jn0;jn
_P020;:b/P80YZJV0P2PX:040:6QX@80XZ:R0P2SXj<20:BTY080YZJV0P2WYjL20:VYZ@@0ZZZZ2`2[
Zj/20:b/[080[Jf]0P2_[jl20;2`/080/K6a0P2c/k<20;Fe]@80][Jf0P2e]KD20;Bd]080/k>c0`2b
/[840;6a/@P0/[:b102a/K420;2`/080[jn_0P2^[Zh40:b/[080Zj^[00<0ZJVY0:RXZ02XZ:P00P2V
YZH20:>SX`80X:2P0P2LW9`209NGU`80Shn?0P26QXH207alO080L71`0P1TI6@205UIF@80Cdm?0P18
B4P20410@00303Ph>00_;bl0;bl_0080;Bd]0P0[:b/202PX:0809RHV0P0R8R82024Q8@806ATI0P0C
4a<200h>3P@02`/;0P0A4A4201HF5P8071`L00<08B4Q02HV9P0V9RH00P0[:b/2030`<080=SHf0P0k
>c/20410@080ADE50P1:BTX204m?C`80E5AD0P1IFET205eMG@80HV9R0P1WIfL206a/K003071`L01e
MGD0MGEe0080NWYj0P1oOgl208>3P`80R8R80P2=SHd209:BTQD0oooo000C0?ooo`80W9bL0P2QXJ42
0:JVYP80[:b/0P2a/K420;Jf]P80_;bl0P31`L400`37alL0c<c<0<c<c0020=;BdP80emOG0P3MgMd2
0>;RhP80j>SX0P3^k^h20??cl`80nOWi0P3gmoL20?7al@80j^[Z0P3Ph>020=SHf080clo?00<0aLG5
0;Vi^@2i^KT00P2^[Zh20:BTY080Xj>S102RXZ820:>SX`80YJFU0P2VYZH20:RXZ080ZJVY0P2ZZZX4
0:^[Z`80[:b/0`2[Zj/60:ZZZP80Zj^[0P2/[:`20:f][@80[jn_0P2a/K420;>c/`80]KFe102f][H2
0;Fe]@80];Bd00<0/k>c0;:b/P2b/[80102b/[880;>c/`80/[:b0P2a/K420;2`/080[Zj^0P2/[:`2
0:^[Z`80ZZZZ0P2YZJT00`2XZ:P0YZJV0:JVYP020:FUY@80XZ:R0P2OWil209^KV`80UYJF0P2?Shl2
08J6QP80OGem0P1`L70206ATI080FEUI0P1?Cdl204M7A`80?clo00<0=cLg02h^;P0^;Rh00P0/;2`2
02XZ:P809bLW0P0U9BD201hN7P807alO0P0G5aL2010@408030`<0P0:2PX200/;2`804A4A0P0F5QH2
01`L7003024Q8@0V9RH09RHV0080;2`/0P0a<C4203Hf=P80>c/k0P10@40204E5A@80BTY:0P1?Cdl2
05ADE080FEUI0P1NGUh2069RHP80IfMW0P1/K6`00`1aLG40MGEe07EeM@0207YjNP80Ogmo0P24Q8@2
08R8R080SHf=0P2BTY8E0?ooo`004`3oool209bLW080XJ6Q0P2VYZH20:b/[080/K6a0P2f][H20;bl
_080`L7100<0alO70<c<c03<c<`00P3Bd]820=OGe`80gMgM0P3Rh^820>SXj080k^k^0P3clo<20?Wi
n@80moOg0P3alO420>[ZjP80h>3P0P3Hf=P20<o?c`030<G5a@2i^KT0^KVi0080[Zj^0P2TY:@20:>S
X`@0XZ:R0P2SXj<20:FUY@80YZJV0P2XZ:P20:VYZ@80ZZZZ102[Zj/20:b/[0<0Zj^[1P2ZZZX20:^[
Z`80[:b/0P2][Jd20:n_[`80/K6a0P2c/k<20;Fe]@@0][Jf0P2e]KD20;Bd]0030;>c/`2b/[80/[:b
00@0/[:b202c/k<20;:b/P80/K6a0P2`/;020:j^[P80[:b/0P2[Zj/20:ZZZP80ZJVY00<0Z:RX0:JV
YP2VYZH00P2UYJD20::RXP80WinO0P2KVi/209JFUP80Shn?0P26QXH207emO@80L71`0P1TI6@205UI
F@80Cdm?0P17AdL203lo?`0303Lg=`0^;Rh0;Rh^0080;2`/0P0Z:RX202LW9`809BDU0P0N7Qh201lO
7`805aLG0P0@410200`<30802PX:0P0;2`/2014A4@805QHF0P0L71`00`0Q8B409RHV02HV9P0202`/
;080<C4a0P0f=SH203/k>`80@4100P15ADD204Y:BP80Cdm?0P1DE5@205UIF@80GUiN0P1RHV8206MW
I`80K6a/00<0LG5a07EeM@1eMGD00P1jNWX207moO`80Q8B40P28R8P208f=S@80TY:B5@3oool001<0
oooo0P2LW9`20:6QX@80YZJV0P2/[:`20;6a/@80]kNg0P2l_;`20<71`@030<O7a`3<c<`0c<c<0080
d];B0P3Hf=P20=gMg@80hn?S0P3Xj>P20>k^kP80lo?c0P3jn_X20??cl`80kno_0P3WinL20=kNgP80
e]KF0P3<c<`00`32`/80]KFe0;Fe]@020:^[Z`@0Y:BT102SXj<20:FUY@80YZJV0P2XZ:P20:ZZZP80
Zj^[2@2/[:`20:ZZZP80ZJVY102XZ:P20:VYZ@80Zj^[0P2/[:`20:f][@80/;2`0P2b/[820;Fe]@@0
]kNg0P2f][H20;Fe]@030;Bd]02c/k<0/k>c00@0/k>c0P2d];@40;Fe]@80];Bd0P2b/[820;6a/@80
[jn_0P2][Jd20:^[Z`@0ZJVY0P2XZ:P00`2VYZH0YJFU0:FUY@020:BTY080XJ6Q0P2NWYh209^KV`80
UIFE0P2?Shl208J6QP80OGem0P1aLG4206ATI080FEUI0P1>CTh204I6AP80?Shn00<0=SHf02h^;P0^
;Rh00P0[:b/202TY:@809RHV0P0S8b<201/K6`8071`L0P0E5AD200d=3@802PX:0P092@T200/;2`80
4A4A0P0F5QH201`L7003024Q8@0W9bL09bLW0080;2`/0P0a<C4203Hf=P80>c/k0P10@40204E5A@80
BTY:0P1?Cdl205ADE080FEUI0P1NGUh2069RHP80IfMW0P1/K6`00`1aLG40MGEe07EeM@0207YjNP80
Ogmo0P24Q8@208R8R080SHf=0P2BTY8E0?ooo`004`3oool209bLW080XJ6Q0P2VYZH20:b/[080/K6a
0P2g]kL20;bl_080`L7100<0alO70<c<c03<c<`00P3Bd]820=SHf080gMgM0P3Shn<20>SXj080k^k^
0P3clo<20?[jnP80lo?c0P3_knl20>OWi`80g]kN0P3Fe]H20<c<c0030<;2`P2e]KD0]KFe0080Zj^[
102TY:@40:>SX`80YJFU0P2VYZH20:RXZ080ZZZZ0P2[Zj/90:b/[080ZZZZ0P2YZJT40:RXZ080ZJVY
0P2[Zj/20:b/[080[Jf]0P2`/;020;:b/P80]KFe102g]kL20;Jf]P80]KFe00<0];Bd0;>c/`2c/k<0
102c/k<20;Bd]0@0]KFe0P2d];@20;:b/P80/K6a0P2_[jl20:f][@80Zj^[102YZJT20:RXZ0030:JV
YP2UYJD0YJFU0080Y:BT0P2QXJ4209jNWP80Vi^K0P2EUID208n?S`80QXJ60P1mOGd2075aL@80I6AT
0P1IFET204i>CP80ATI60P0n?Sh00`0f=SH0;Rh^02h^;P0202/[:`80:BTY0P0V9RH202<S8`806a/K
0P0L71`201DE5@803@d=0P0:2PX200T92@802`/;0P0A4A4201HF5P8071`L00<08B4Q02LW9`0W9bL0
0P0/;2`2034a<@80=SHf0P0k>c/20410@080ADE50P1:BTX204m?C`80E5AD0P1IFET205iNGP80HV9R
0P1WIfL206a/K003075aL@1eMGD0MGEe0080NWYj0P1oOgl208B4Q080R8R80P2=SHd209:BTQD0oooo
000C0?ooo`80W9bL0P2QXJ420:NWY`80[:b/0P2a/K420;Ng]`80_;bl0P32`/800`37alL0cLg=0<g=
c@020=;BdP80f=SH0P3MgMd20>?Sh`80jNWY0P3^k^h20??cl`80nOWi0P3alO420>g]k@80i>CT0P3L
g=`20=?Cd`80b/[:00<0_Kfm0;:b/P2b/[800P2YZJT20:NWY`80YJFU102TY:@20:JVYP80Z:RX0P2Z
ZZX20:b/[080[Jf]1P2^[Zh20:f][@030:b/[02ZZZX0ZZZZ00@0YjNW0P2VYZH20:NWY`80ZJVY0P2Z
ZZX20:b/[080[jn_0P2b/[820;Fe]@H0]kNg0P2f][H30;Fe]@80];Bd102e]KD40;Jf]P80]KFe0P2c
/k<20;2`/080[Zj^0P2/[:`20:ZZZP80YjNW102VYZH00`2UYJD0Xj>S0:>SX`020::RXP80X:2P0P2M
WId209ZJVP80UIFE0P2>SXh208J6QP80O7al0P1aLG4206EUI@80FEUI0P1=CDd204E5A@80?Cdm00<0
=CDe02d];@0];Bd00P0Z:RX202PX:08092@T0P0P820201PH60806QXJ0P0C4a<200/;2`802@T90P08
20P200/;2`804A4A0P0G5aL201`L7003028R8P0W9bL09bLW0080;2`/0P0a<C4203Lg=`80?3`l0P11
@D4204I6AP80Bd];0P1?Cdl205ADE080FEUI0P1NGUh206=SH`80IfMW0P1/K6`00`1aLG40MWIf07If
MP0207YjNP80Ogmo0P24Q8@208R8R080SHf=0P2BTY8E0?ooo`004`3oool209bLW080XJ6Q0P2WYjL2
0:b/[080/K6a0P2g]kL20;bl_080`/;200<0alO70<g=c@3=cLd00P3Bd]820=SHf080gMgM0P3Shn<2
0>WYj@80k^k^0P3clo<20?Win@80lO7a0P3]kNd20>CTi080g=cL0P3Cdm<20<[:bP030;fm_@2b/[80
/[:b0080ZJVY0P2WYjL20:FUY@@0Y:BT0P2VYZH20:RXZ080ZZZZ0P2/[:`20:f][@H0[Zj^0P2][Jd0
0`2/[:`0ZZZZ0:ZZZP040:NWY`80YZJV0P2WYjL20:VYZ@80ZZZZ0P2/[:`20:n_[`80/[:b0P2e]KD6
0;Ng]`80][Jf0`2e]KD20;Bd]0@0]KFe102f][H20;Fe]@80/k>c0P2`/;020:j^[P80[:b/0P2ZZZX2
0:NWY`@0YZJV00<0YJFU0:>SX`2SXj<00P2RXZ820:2PX080WIfM0P2JVYX209FEU@80SXj>0P26QXH2
07alO080LG5a0P1UIFD205UIF@80CDe=0P15ADD203dm?@0303De=@0];Bd0;Bd]0080:RXZ0P0X:2P2
02@T9080820P0P0H61P201XJ6P804a<C0P0;2`/200T92@8020P80P0;2`/2014A4@805aLG0P0L71`0
0`0R8R809bLW02LW9`0202`/;080<C4a0P0g=cL203`l?080@D510P16ATH204];B`80Cdm?0P1DE5@2
05UIF@80GUiN0P1SHf<206MWI`80K6a/00<0LG5a07IfMP1fMWH00P1jNWX207moO`80Q8B40P28R8P2
08f=S@80TY:B5@3oool001<0oooo0P2LW9`20:6QX@80YjNW0P2/[:`20;6a/@80]kNg0P2l_;`20<;2
`P030<O7a`3=cLd0cLg=0080d];B0P3Hf=P20=kNgP80hn?S0P3YjNT20>o_k`80mOGe0P3gmoL20?7a
l@80k>c/0P3Rh^820=WIf@80d=3@0P37alL00`2i^KT0[jn_0:n_[`040:VYZ@80YZJV0P2TY:@20:FU
Y@80YjNW0P2ZZZX20:b/[080[Zj^0P2_[jl20:j^[P80[Jf]0P2^[Zh20:f][@030:^[Z`2XZ:P0Z:RX
00@0YJFU0P2TY:@20:FUY@80YjNW0P2XZ:P20:ZZZP80[Zj^0P2a/K420;Fe]@80]kNg0P2h^;P40;Ng
]`030;Jf]P2h^;P0^;Rh0080][Jf102e]KD20;Jf]P80]kNg0P2f][H20;:b/P80[jn_0P2][Jd20:^[
Z`80Z:RX0P2UYJD40:BTY0030:>SX`2RXZ80XZ:R0080X:2P0P2OWil209bLW080VIVI0P2DU9@208f=
S@80QHF50P1lO7`2075aL@80IVIV0P1IFET204e=C@80A4A40P0k>c/00`0d=3@0;2`/02`/;00202TY
:@809RHV0P0R8R8201hN7P805QHF0P0G5aL2010@40802@T9100820P200`<30804Q8B0P0G5aL201dM
7@03028R8P0W9bL09bLW0080;Bd]0P0b<S8203Lg=`80?3`l0P11@D4204I6AP80Bd];0P1@D50205EE
E@80FUYJ0P1NGUh206=SH`80J6QX0P1/K6`00`1aLG40MWIf07IfMP0207YjNP80Ogmo0P24Q8@208R8
R080SHf=0P2BTY8E0?ooo`004`3oool209bLW080XJ6Q0P2WYjL20:b/[080/K6a0P2g]kL20;bl_080
`/;200<0alO70<g=c@3=cLd00P3Bd]820=SHf080g]kN0P3Shn<20>WYj@80kno_0P3emOD20?Ogm`80
lO7a0P3/k>`20>;RhP80fMWI0P3@d=020<O7a`030;Vi^@2_[jl0[jn_00@0ZJVY0P2VYZH20:BTY080
YJFU0P2WYjL20:ZZZP80[:b/0P2^[Zh20:n_[`80[Zj^0P2][Jd20:j^[P80[Jf]00<0Zj^[0:RXZ02X
Z:P0102UYJD20:BTY080YJFU0P2WYjL20:RXZ080ZZZZ0P2^[Zh20;6a/@80]KFe0P2g]kL20;Rh^0@0
]kNg00<0][Jf0;Rh^02h^;P00P2f][H40;Fe]@80][Jf0P2g]kL20;Jf]P80/[:b0P2_[jl20:f][@80
Zj^[0P2XZ:P20:FUY@@0Y:BT00<0Xj>S0::RXP2RXZ800P2PX:0209nOW`80W9bL0P2IVIT209BDU080
SHf=0P25QHD207alO080LG5a0P1VIVH205UIF@80CDe=0P14A4@203/k>`0303@d=00/;2`0;2`/0080
:BTY0P0V9RH2028R8P807QhN0P0F5QH201LG5`80410@0P092@T400P8208030`<0P0B4Q8201LG5`80
7AdM00<08R8R02LW9`0W9bL00P0];Bd2038b<P80=cLg0P0l?3`20451@@80ATI60P1;Bd/2051@D080
EEEE0P1JFUX205iNGP80Hf=S0P1XJ6P206a/K003075aL@1fMWH0MWIf0080NWYj0P1oOgl208B4Q080
R8R80P2=SHd209:BTQD0oooo000C0?ooo`80W9bL0P2QXJ420:NWY`80[:b/0P2b/[820;Ng]`80_;bl
0P32`/800`37alL0cLg=0<g=c@020=?Cd`80f=SH0P3Ng]h20>CTi080jNWY0P3_knl20?Gem@80m?Cd
0P3`l?020>[ZjP80hN7Q0P3Fe]H20<g=c@80a<C400<0^;Rh0:b/[02/[:`00P2[Zj/20:VYZ@80YZJV
0P2TY:@20:JVYP80Z:RX0P2[Zj/20:j^[P80/;2`0P2_[jl40:b/[080[jn_0P2][Jd00`2ZZZX0YZJV
0:JVYP020:BTY0H0XZ:R0P2TY:@20:JVYP80ZJVY0P2][Jd20;2`/080];Bd0P2f][H40;Rh^080^KVi
0`2h^;P20;Jf]P80/k>c0P2d];@40;Rh^080]KFe0P2`/;020:j^[P80Zj^[0P2ZZZX20:NWY`80Xj>S
0P2RXZ830:6QX@80X:2P0P2OWil209fMW@80Vi^K0P2HV9P209>CT`80S8b<0P24Q8@207]kN`80LG5a
0P1VIVH205UIF@80C4a<0P13@d<203Xj>P03038b<P0[:b/0:b/[00809bLW0P0T92@201lO7`806a/K
0P0D51@201DE5@803@d=100820P200L71`8030`<0P0B4Q8201PH60807AdM00<08b<S02PX:00X:2P0
0P0];Bd2038b<P80=cLg0P0l?3`20451@@80ATI60P1;Bd/2051@D080EEEE0P1JFUX205mOG`80Hf=S
0P1XJ6P206e]K@03075aL@1fMWH0MWIf0080Ng]k0P1oOgl208B4Q080RHV90P2=SHd209:BTQD0oooo
000C0?ooo`80W9bL0P2QXJ420:NWY`80[:b/0P2b/[820;Ng]`80_;bl0P32`/800`37alL0cLg=0<g=
c@020=?Cd`80f=SH0P3Ng]h20>CTi080jNWY0P3_knl20?Gem@80m?Cd0P3`l?020>[ZjP80hN7Q0P3F
e]H20<g=c@80a<C400<0^;Rh0:b/[02/[:`00P2[Zj/20:VYZ@80YZJV0P2TY:@20:JVYP80Z:RX0P2[
Zj/20:j^[P80/;2`0P2_[jl40:b/[080[jn_0P2][Jd00`2ZZZX0YZJV0:JVYP020:BTY0H0XZ:R0P2T
Y:@20:JVYP80ZJVY0P2][Jd20;2`/080];Bd0P2f][H40;Rh^080^KVi0`2h^;P20;Jf]P80/k>c0P2d
];@40;Rh^080]KFe0P2`/;020:j^[P80Zj^[0P2ZZZX20:NWY`80Xj>S0P2RXZ830:6QX@80X:2P0P2O
Wil209fMW@80Vi^K0P2HV9P209>CT`80S8b<0P24Q8@207]kN`80LG5a0P1VIVH205UIF@80C4a<0P13
@d<203Xj>P03038b<P0[:b/0:b/[00809bLW0P0T92@201lO7`806a/K0P0D51@201DE5@803@d=1008
20P200L71`8030`<0P0B4Q8201PH60807AdM00<08b<S02PX:00X:2P00P0];Bd2038b<P80=cLg0P0l
?3`20451@@80ATI60P1;Bd/2051@D080EEEE0P1JFUX205mOG`80Hf=S0P1XJ6P206e]K@03075aL@1f
MWH0MWIf0080Ng]k0P1oOgl208B4Q080RHV90P2=SHd209:BTQD0oooo000C0?ooo`80W9bL0P2QXJ42
0:NWY`80[:b/0P2b/[820;Ng]`80_Kfm0P32`/800`38b<P0cLg=0<g=c@020=?Cd`80fMWI0P3Ng]h2
0>CTi080j^[Z0P3_knl40??cl`80l?3`0P3Xj>P20=oOg`80dm?C0P3:b/X20<71`@030;Jf]P2[Zj/0
Zj^[0080Zj^[0P2YZJT20:JVYP80YJFU0P2VYZH20:VYZ@80[:b/0P2_[jl20;2`/080[jn_102[Zj/2
0:j^[P<0ZZZZ0P2SXj<20::RXPH0WinO0P2QXJ420:BTY080YjNW0P2/[:`20;2`/080/k>c0P2f][H2
0;Rh^0D0^KVi102g]kL20;Bd]080]KFe0P2i^KT40;Fe]@80[jn_0P2][Jd20:RXZ080ZZZZ0P2UYJD2
0:6QX@@0X:2P00<0WinO09jNWP2NWYh00P2NWYh209bLW080VYZJ0P2GUiL209:BTP80Rh^;0P23Ph<2
07YjNP80LG5a0P1UIFD205MGE`80Bd];0P11@D4203Ti>@03030`<00Z:RX0:RXZ00809RHV0P0R8R82
01`L708061PH0P0B4Q8201<C4`802PX:0P071`L200H61P801`L70P0=3@d201<C4`8061PH0P0N7Qh0
0`0S8b<0:2PX02PX:00202h^;P80<c<c0P0h>3P203dm?@80@T920P17AdL204a<C080D51@0P1EEED2
05YJFP80GemO0P1SHf<206QXJ080KFe]00<0LW9b07IfMP1fMWH00P1kNg/207moO`80Q8B40P29RHT2
08f=S@80TY:B5@3oool001<0oooo0P2LW9`20:6QX@80YjNW0P2/[:`20;:b/P80]kNg0P2m_Kd20<;2
`P030<S8b03=cLd0cLg=0080dm?C0P3IfMT20=kNgP80i>CT0P3Zj^X20>o_k`@0lo?c0P3`l?020>SX
j080gmoO0P3Cdm<20<[:bP80`L7100<0][Jf0:^[Z`2[Zj/00P2[Zj/20:VYZ@80YZJV0P2UYJD20:JV
YP80ZJVY0P2/[:`20:n_[`80/;2`0P2_[jl40:^[Z`80[Zj^0`2ZZZX20:>SX`80XZ:R1P2OWil20:6Q
X@80Y:BT0P2WYjL20:b/[080/;2`0P2c/k<20;Jf]P80^;Rh1@2i^KT40;Ng]`80];Bd0P2e]KD20;Vi
^@@0]KFe0P2_[jl20:f][@80Z:RX0P2ZZZX20:FUY@80XJ6Q102PX:000`2OWil0WYjN09jNWP0209jN
WP80W9bL0P2JVYX209NGU`80TY:B0P2;Rh/208>3P`80NWYj0P1aLG4206EUI@80EeMG0P1;Bd/20451
@@80>CTi00<0<30`02XZ:P0Z:RX00P0V9RH2028R8P8071`L0P0H61P2018B4P804a<C0P0:2PX200L7
1`801PH60P071`L200d=3@804a<C0P0H61P201hN7P0302<S8`0X:2P0:2PX0080;Rh^0P0c<c<203Ph
>080?Cdm0P12@T8204M7A`80C4a<0P1@D50205EEE@80FUYJ0P1OGel206=SH`80J6QX0P1]KFd00`1b
LW80MWIf07IfMP0207]kN`80Ogmo0P24Q8@208V9R@80SHf=0P2BTY8E0?ooo`004`3oool209bLW080
XJ6Q0P2WYjL20:b/[080/[:b0P2g]kL20;fm_@80`/;200<0b<S80<g=c@3=cLd00P3Cdm<20=WIf@80
gmoO0P3UiND20>_[j`80lO7a0P3bl_820??cl`80k^k^0P3Vi^H20=gMg@80d];B0P38b<P20;jn_P03
0;Bd]02/[:`0[:b/0080[:b/0P2YZJT20:JVYP80YJFU0P2VYZH20:VYZ@80[:b/0P2^[Zh20:n_[`80
[Jf]0P2ZZZX20:^[Z`80[:b/0P2XZ:P00`2WYjL0X:2P0:2PX00209nOW`@0W9bL0P2MWId209nOW`80
Xj>S0P2WYjL20:^[Z`80[jn_0P2b/[820;Fe]@80]kNg1@2i^KT40;Ng]`@0]KFe0P2h^;P40;Bd]080
[Jf]0P2[Zj/40:NWY`80XZ:R0P2OWil409jNWP<0WIfM0P2LW9`209^KV`80VIVI0P2EUID2096AT@80
RXZ:0P22PX8207UiN@80L71`0P1TI6@205IFEP80Bd];0P10@40203Lg=`0302h^;P0Y:BT0:BTY0080
92@T0P0O7al201XJ6P805ADE100@410200T92@801PH60P051@D200P820803Ph>0P0D51@201TI6@80
7QhN00<092@T02TY:@0Y:BT00P0^;Rh203<c<`80>3Ph0P0m?Cd20492@P80AdM70P1<C4`2055AD@80
EUIF0P1KFe/205mOG`80I6AT0P1YJFT206e]K@03079bLP1fMWH0MWIf0080Ng]k0P20P80208B4Q080
RHV90P2=SHd209:BTQD0oooo000C0?ooo`80W9bL0P2QXJ420:NWY`80[:b/0P2b/[820;Ng]`80_Kfm
0P32`/800`38b<P0cLg=0<g=c@020=?Cd`80fMWI0P3Ogml20>GUi@80jn_[0P3alO420?;blP80lo?c
0P3^k^h20>KViP80gMgM0P3Bd]820<S8b080_[jn00<0];Bd0:b/[02/[:`00P2/[:`20:VYZ@80YZJV
0P2UYJD20:JVYP80ZJVY0P2/[:`20:j^[P80[jn_0P2][Jd20:ZZZP80Zj^[0P2/[:`20:RXZ0030:NW
Y`2PX:00X:2P0080WinO102LW9`209fMW@80WinO0P2SXj<20:NWY`80Zj^[0P2_[jl20;:b/P80]KFe
0P2g]kL50;Vi^@@0]kNg102e]KD20;Rh^0@0];Bd0P2][Jd20:^[Z`@0YjNW0P2RXZ8209nOW`@0WYjN
0`2MWId209bLW080Vi^K0P2IVIT209FEU@80TI6A0P2:RXX208:2PP80NGUi0P1`L70206ATI080EUIF
0P1;Bd/20410@080=cLg00<0;Rh^02TY:@0Y:BT00P0T92@201lO7`806QXJ0P0E5AD4010@40802@T9
0P061PH200D51@8020P80P0>3Ph201@D50806ATI0P0N7Qh00`0T92@0:BTY02TY:@0202h^;P80<c<c
0P0h>3P203dm?@80@T920P17AdL204a<C080DE5A0P1FEUH205]KF`80GemO0P1TI6@206UYJ@80KFe]
00<0LW9b07IfMP1fMWH00P1kNg/20820P080Q8B40P29RHT208f=S@80TY:B5@3oool001<0oooo0P2L
W9`20:6QX@80YjNW0P2/[:`20;:b/P80]kNg0P2m_Kd20<;2`P030<S8b03>c/h0c/k>0080dm?C0P3I
fMT20=oOg`80iNGU0P3[jn/20?;blP@0lO7a0P3]kNd20>GUi@80f][J0P3@d=020<O7a`80_;bl00<0
/k>c0:f][@2][Jd00P2[Zj/20:RXZ080YJFU0P2TY:@20:FUY@80YjNW0P2YZJT20:^[Z`80[:b/0P2Z
ZZX40:VYZ@80YjNW0P2TY:@00`2RXZ80WYjN09jNWP0209bLW0@0Vi^K0P2LW9`209nOW`80XZ:R0P2V
YZH20:ZZZP80[Zj^0P2a/K420;Bd]080][Jf0P2h^;P20;Vi^@<0^;Rh0P2f][H20;Fe]@@0];Bd0P2a
/K420:n_[`80[:b/0P2YZJT20:JVYP80XZ:R0P2PX:0409jNWP<0WIfM102LW9`209ZJVP80V9RH0P2D
U9@208n?S`80R8R80P20P80207QhN080KVi^0P1SHf<205EEE@80BTY:0P10@40203De=@0302`/;00V
9RH09RHV00808R8R0P0M7Ad201LG5`804a<C0P0?3`l200h>3P8020P80P051@D200@410802@T90P0?
3`l201@D50806QXJ0P0O7al00`0U9BD0:RXZ02XZ:P0202l_;`80=3@d0P0i>CT203hn?P80@d=30P18
B4P204e=C@80DE5A0P1FEUH205]KF`80H61P0P1TI6@206UYJ@80KVi^00<0LW9b07MgM`1gMgL00P1k
Ng/20820P080Q8B40P29RHT208f=S@80TY:B5@3oool001<0oooo0P2LW9`20:6QX@80YjNW0P2/[:`2
0;:b/P80]kNg0P2m_Kd20<;2`P030<S8b03>c/h0c/k>0080dm?C0P3IfMT20=oOg`80iNGU0P3[jn/2
0?;blP@0lO7a0P3]kNd20>GUi@80f][J0P3@d=020<O7a`80_;bl00<0/k>c0:f][@2][Jd00P2[Zj/2
0:RXZ080YJFU0P2TY:@20:FUY@80YjNW0P2YZJT20:^[Z`80[:b/0P2ZZZX40:VYZ@80YjNW0P2TY:@0
0`2RXZ80WYjN09jNWP0209bLW0@0Vi^K0P2LW9`209nOW`80XZ:R0P2VYZH20:ZZZP80[Zj^0P2a/K42
0;Bd]080][Jf0P2h^;P20;Vi^@<0^;Rh0P2f][H20;Fe]@@0];Bd0P2a/K420:n_[`80[:b/0P2YZJT2
0:JVYP80XZ:R0P2PX:0409jNWP<0WIfM102LW9`209ZJVP80V9RH0P2DU9@208n?S`80R8R80P20P802
07QhN080KVi^0P1SHf<205EEE@80BTY:0P10@40203De=@0302`/;00V9RH09RHV00808R8R0P0M7Ad2
01LG5`804a<C0P0?3`l200h>3P8020P80P051@D200@410802@T90P0?3`l201@D50806QXJ0P0O7al0
0`0U9BD0:RXZ02XZ:P0202l_;`80=3@d0P0i>CT203hn?P80@d=30P18B4P204e=C@80DE5A0P1FEUH2
05]KF`80H61P0P1TI6@206UYJ@80KVi^00<0LW9b07MgM`1gMgL00P1kNg/20820P080Q8B40P29RHT2
08f=S@80TY:B5@3oool001<0oooo0P2LW9`20:6QX@80YjNW0P2/[:`20;:b/P80]kNg0P2m_Kd20<;2
`P030<S8b03>c/h0c/k>0080dm?C0P3IfMT20=oOg`80iNGU0P3[jn/20?7al@80l_;b0P3`l?020>c/
k080h^;R0P3Hf=P20<o?c`80a/K60P2k^k/00`2b/[80[Jf]0:f][@020:ZZZP80YjNW0P2TY:@20::R
XP80Y:BT0P2UYJD20:NWY`80Z:RX0P2YZJT20:RXZ080YjNW0P2VYZH20:BTY080XZ:R00<0WinO09fM
W@2MWId00P2LW9`209ZJVP80Vi^K0P2LW9`209nOW`80Xj>S0P2VYZH20:ZZZP80[Jf]0P2`/;020;>c
/`80]KFe0P2g]kL50;Rh^080][Jf0P2d];@20;:b/P80/K6a0P2_[jl20:f][@80ZZZZ0P2WYjL20:BT
Y080XJ6Q0P2PX:0409nOW`80WYjN00<0WIfM09bLW02LW9`00P2KVi/209VIV@80UYJF0P2CTi<208j>
SP80QhN70P1oOgl207IfMP80KFe]0P1QHF4205ADE080BDU90P0n?Sh203@d=00302XZ:P0T92@092@T
00808B4Q0P0K6a/201@D5080410@100=3@d200L71`800`<30P051@D200X:2P80410@0P0E5AD201/K
6`80820P00<09BDU02/[:`0[:b/00P0`<30203De=@80>SXj0P0o?cl204A4A080B4Q80P1=CDd2059B
DP80EeMG0P1KFe/2061PH080IFEU0P1YJFT206i^KP03079bLP1gMgL0MgMg0080Ng]k0P20P80208B4
Q080RHV90P2>SXh209:BTQD0oooo000C0?ooo`80W9bL0P2QXJ420:NWY`80[:b/0P2b/[820;Ng]`80
_Kfm0P32`/800`38b<P0c/k>0<k>cP020=?Cd`80fMWI0P3Ogml20>GUi@80jn_[0P3alO420?;blP80
l?3`0P3/k>`20>;RhP80f=SH0P3?cll20<K6aP80^k^k00<0/[:b0:f][@2][Jd00P2ZZZX20:NWY`80
Y:BT0P2RXZ820:BTY080YJFU0P2WYjL20:RXZ080ZJVY0P2XZ:P20:NWY`80YZJV0P2TY:@20::RXP03
09nOW`2MWId0WIfM0080W9bL0P2JVYX209^KV`80W9bL0P2OWil20:>SX`80YZJV0P2ZZZX20:f][@80
/;2`0P2c/k<20;Fe]@80]kNg1@2h^;P20;Jf]P80];Bd0P2b/[820;6a/@80[jn_0P2][Jd20:ZZZP80
YjNW0P2TY:@20:6QX@80X:2P102OWil209jNWP0309fMW@2LW9`0W9bL0080Vi^K0P2IVIT209JFUP80
Ti>C0P2>SXh208N7Q`80Ogmo0P1fMWH206e]K@80HF5Q0P1DE5@204U9B@80?Shn0P0d=3@00`0Z:RX0
92@T02@T9002024Q8@806a/K0P0D51@2010@40@03@d=0P071`L200<30`801@D50P0:2PX2010@4080
5ADE0P0K6a/2020P800302DU9@0[:b/0:b/[0080<30`0P0e=CD203Xj>P80?clo0P14A4@204Q8B080
CDe=0P1BDU8205MGE`80Fe]K0P1PH60206EUI@80JFUY0P1^KVh00`1bLW80MgMg07MgM`0207]kN`80
P8200P24Q8@208V9R@80SXj>0P2BTY8E0?ooo`004`3oool209bLW080XJ6Q0P2WYjL20:b/[080/[:b
0P2g]kL20;fm_@80`/;200<0b<S80<k>cP3>c/h00P3De=@20=[JfP80gmoO0P3UiND20>_[j`80l?3`
0P3fm_H20?3`l080jNWY0P3Ph>020=KFeP80cLg=0P35aLD20;Zj^P030;:b/P2][Jd0[Jf]0080ZJVY
0P2VYZH20::RXP80XJ6Q0P2RXZ820:>SX`80Y:BT0P2UYJD60:JVYP80YJFU0P2TY:@20::RXP030:2P
X02NWYh0WYjN0080W9bL0P2JVYX209^KV`80WIfM0P2PX:020:>SX`80YZJV0P2ZZZX20:b/[080[jn_
0P2b/[820;Bd]080][Jf1@2h^;P20;Jf]P80];Bd0P2a/K420:n_[`80[Jf]0P2[Zj/20:VYZ@80YjNW
0P2UYJD20:>SX`80XZ:R0P2QXJ420:2PX080WinO00<0WYjN09fMW@2MWId00P2JVYX209RHV080UIFE
0P2BTY8208b<S080QHF50P1nOWh207EeM@80Jf][0P1PH60205=CD`80AdM70P0m?Cd2038b<P0302PX
:00R8R808R8R00807alO0P0I6AT2018B4P803Ph>100;2`/200D51@800`<30P061PH200`<30804A4A
0P0F5QH201`L70808B4Q00<09RHV02/[:`0[:b/00P0a<C4203Hf=P80>c/k0P0o?cl204A4A080BDU9
0P1>CTh205=CD`80EeMG0P1LG5`2061PH080IFEU0P1ZJVX206i^KP0307=cL`1gMgL0MgMg0080O7al
0P20P80208F5Q@80RHV90P2>SXh209:BTQD0oooo000C0?ooo`80W9bL0P2QXJ420:NWY`80[:b/0P2a
/K420;Ng]`80_;bl0P32`/800`38b<P0c/k>0<k>cP020=CDe080f][J0P3Ogml20>KViP80jn_[0P3`
l?020?Ogm`80k^k^0P3WinL20=gMg@80e=CD0P3;bl/20<C4a080^KVi00<0/[:b0:b/[02/[:`00P2X
Z:P20:FUY@80XJ6Q0P2OWil20:2PX080XJ6Q0P2RXZ820:>SX`80Y:BT1P2UYJD20:BTY080XJ6Q00<0
WYjN09^KV`2KVi/0102JVYX209bLW080WYjN0P2QXJ420:BTY080YjNW0P2ZZZX20:b/[080[jn_0P2a
/K420;>c/`80]KFe0P2f][H30;Ng]`80]KFe0P2c/k<20;2`/080[Zj^0P2/[:`20:^[Z`80ZJVY0P2X
Z:P20:JVYP80YJFU0P2SXj<20::RXP80XJ6Q0P2PX:000`2OWil0W9bL09bLW00209ZJVP80V9RH0P2E
UID2092@T080Rh^;0P25QHD207emO@80M7Ad0P1ZJVX205iNGP80DU9B0P16ATH203Xj>P80;bl_00<0
9bLW024Q8@0Q8B400P0L71`201LG5`80410@0P0=3@d200X:2P802@T90P051@D200<30`801`L70P0=
3@d2018B4P8061PH0P0M7Ad2028R8P0302LW9`0/;2`0;2`/0080<C4a0P0f=SH203/k>`80@4100P15
ADD204Y:BP80CTi>0P1CDe<205QHF080G5aL0P1QHF4206EUI@80JVYZ0P1^KVh00`1cLg<0MgMg07Mg
M`0207alO080P8200P25QHD208V9R@80SXj>0P2BTY8E0?ooo`004`3oool209bLW080XJ6Q0P2WYjL2
0:b/[080/K6a0P2g]kL20;bl_080`/;200<0b<S80<k>cP3>c/h00P3De=@20=[JfP80gmoO0P3Vi^H2
0>_[j`80l?3`0P3gmoL20>k^kP80inOW0P3MgMd20=CDe080bl_;0P34a<@20;Vi^@030;:b/P2/[:`0
[:b/0080Z:RX0P2UYJD20:6QX@80WinO0P2PX:020:6QX@80XZ:R0P2SXj<20:BTY0H0YJFU0P2TY:@2
0:6QX@0309jNWP2KVi/0Vi^K00@0VYZJ0P2LW9`209jNWP80XJ6Q0P2TY:@20:NWY`80ZZZZ0P2/[:`2
0:n_[`80/K6a0P2c/k<20;Fe]@80][Jf0`2g]kL20;Fe]@80/k>c0P2`/;020:j^[P80[:b/0P2[Zj/2
0:VYZ@80Z:RX0P2VYZH20:FUY@80Xj>S0P2RXZ820:6QX@80X:2P00<0WinO09bLW02LW9`00P2JVYX2
09RHV080UIFE0P2@T90208^;R`80QHF50P1mOGd207AdM080JVYZ0P1NGUh2059BDP80ATI60P0j>SX2
02l_;`0302LW9`0Q8B408B4Q008071`L0P0G5aL2010@40803@d=0P0:2PX200T92@801@D50P030`<2
00L71`803@d=0P0B4Q8201PH60807AdM0P0R8R800`0W9bL0;2`/02`/;002034a<@80=SHf0P0k>c/2
0410@080ADE50P1:BTX204i>CP80De=C0P1HF5P205aLG080HF5Q0P1UIFD206YZJP80KVi^00<0Lg=c
07MgM`1gMgL00P1lO7`20820P080QHF50P29RHT208j>SP80TY:B5@3oool001<0oooo0P2LW9`20:6Q
X@80YZJV0P2/[:`20;6a/@80]kNg0P2l_;`20<;2`P030<S8b03=cLd0cLg=0080dm?C0P3Jf]X20>3P
h080i^KV0P3]kNd20>o_k`80mOGe0P3/k>`20>CTi080fm_K0P3Cdm<20<[:bP80`/;20P2i^KT00`2b
/[80[:b/0:b/[0020:NWY`80Xj>S0P2OWil209fMW@80WYjN102QXJ420::RXP@0Xj>S0P2TY:@20:>S
X`80WinO0P2MWId00`2LW9`0VYZJ09ZJVP0209^KV`80W9bL0P2MWId209nOW`80XZ:R0P2UYJD20:NW
Y`80ZZZZ0P2/[:`20:j^[P80/;2`0P2b/[820;>c/`D0]KFe0P2d];@20;:b/P80/;2`0P2^[Zh20:b/
[080Zj^[0P2ZZZX20:VYZ@80YjNW0P2VYZH20:FUY@80Y:BT0P2RXZ820:2PX00309jNWP2KVi/0Vi^K
0080VIVI0P2GUiL209BDU080Shn?0P29RHT208>3P`80Ng]k0P1cLg<206QXJ080G5aL0P1ADE4204E5
A@80>3Ph0P0];Bd00`0U9BD07alO01lO7`0201XJ6P805ADE0P0>3Ph200`<30802PX:0P071`L400<3
0`802@T90P0>3Ph201<C4`806ATI0P0N7Qh202<S8`0302PX:00];Bd0;Bd]0080<S8b0P0g=cL203`l
?080@D510P16ATH204Y:BP80Cdm?0P1DE5@205QHF080GEeM0P1QHF4206IVIP80JVYZ0P1_Kfl00`1c
Lg<0N7Qh07QhN00207alO080PH610P25QHD208V9R@80SXj>0P2BTY8E0?ooo`004`3oool209bLW080
XJ6Q0P2VYZH20:b/[080/K6a0P2g]kL20;bl_080`/;200<0b<S80<g=c@3=cLd00P3Cdm<20=[JfP80
h>3P0P3Vi^H20>g]k@80kno_0P3emOD20>c/k080i>CT0P3Kfm/20=?Cd`80b/[:0P32`/820;Vi^@03
0;:b/P2/[:`0[:b/0080YjNW0P2SXj<209nOW`80WIfM0P2NWYh40:6QX@80XZ:R102SXj<20:BTY080
Xj>S0P2OWil209fMW@0309bLW02JVYX0VYZJ0080Vi^K0P2LW9`209fMW@80WinO0P2RXZ820:FUY@80
YjNW0P2ZZZX20:b/[080[Zj^0P2`/;020;:b/P80/k>c1@2e]KD20;Bd]080/[:b0P2`/;020:j^[P80
[:b/0P2[Zj/20:ZZZP80ZJVY0P2WYjL20:JVYP80YJFU0P2TY:@20::RXP80X:2P00<0WYjN09^KV`2K
Vi/00P2IVIT209NGU`80U9BD0P2?Shl208V9R@80Ph>30P1kNg/207=cL`80J6QX0P1LG5`2055AD@80
ADE50P0h>3P202d];@0302DU9@0O7al07alO00806QXJ0P0E5AD200h>3P8030`<0P0:2PX200L71`@0
0`<30P092@T200h>3P804a<C0P0I6AT201hN7P808b<S00<0:2PX02d];@0];Bd00P0b<S8203Lg=`80
?3`l0P11@D4204I6AP80BTY:0P1?Cdl205ADE080F5QH0P1MGEd2065QH@80IVIV0P1ZJVX206m_K`03
07=cL`1hN7P0N7Qh0080O7al0P21PH4208F5Q@80RHV90P2>SXh209:BTQD0oooo000C0?ooo`80W9bL
0P2QXJ420:JVYP80[:b/0P2a/K420;Jf]P80_;bl0P32`/800`37alL0cLg=0<g=c@020=?Cd`80fMWI
0P3Ogml20>KViP80k^k^0P3`l?020?;blP80jNWY0P3QhN420=WIf@80d];B0P39bLT20<;2`P80^KVi
00<0/[:b0:b/[02/[:`00P2VYZH20:6QX@80WIfM0P2KVi/209bLW080WYjN0P2OWil20:2PX0@0XJ6Q
0P2PX:0209jNWPL0W9bL0P2MWId209jNWP80WinO0P2QXJ420:>SX`80YZJV0P2XZ:P20:ZZZP80[:b/
0P2^[Zh20:n_[`80/K6a0P2b/[820;>c/`<0];Bd0P2c/k<20;6a/@80/;2`0P2^[Zh20:b/[0@0ZZZZ
0P2YZJT20:NWY`80YZJV0P2UYJD20::RXP80XJ6Q0P2OWil00`2MWId0Vi^K09^KV`0209VIV@80UYJF
0P2CTi<208j>SP80R8R80P22PX8207YjNP80LW9b0P1VIVH205]KF`80D51@0P13@d<203Hf=P80:RXZ
00<08b<S01hN7P0N7Qh00P0H61P201<C4`803@d=0P0:2PX200T92@801@D50P010@4200@410802PX:
0P0?3`l201DE5@806QXJ0P0O7al202@T900302TY:@0^;Rh0;Rh^0080<c<c0P0h>3P203dm?@80@T92
0P17AdL204];B`80D51@0P1DE5@205UIF@80GEeM0P1RHV8206IVIP80Jf][0P1_Kfl00`1dM7@0N7Qh
07QhN00207alO080PH610P25QHD208V9R@80SXj>0P2BTY8E0?ooo`004`3oool209bLW080XJ6Q0P2V
YZH20:b/[080/K6a0P2f][H20;bl_080`/;200<0alO70<g=c@3=cLd00P3Cdm<20=WIf@80gmoO0P3V
i^H20>k^kP80l?3`0P3bl_820>WYj@80hN7Q0P3IfMT20=;BdP80bLW90P32`/820;Vi^@030;:b/P2/
[:`0[:b/0080YZJV0P2QXJ4209fMW@80Vi^K0P2LW9`209jNWP80WinO0P2PX:040:6QX@80X:2P0P2N
WYh709bLW080WIfM0P2NWYh209nOW`80XJ6Q0P2SXj<20:JVYP80Z:RX0P2ZZZX20:b/[080[Zj^0P2_
[jl20;6a/@80/[:b0P2c/k<30;Bd]080/k>c0P2a/K420;2`/080[Zj^0P2/[:`40:ZZZP80ZJVY0P2W
YjL20:JVYP80YJFU0P2RXZ820:6QX@80WinO00<0WIfM09^KV`2KVi/00P2IVIT209JFUP80Ti>C0P2>
SXh208R8R080PX:20P1jNWX2079bLP80IVIV0P1KFe/2051@D080@d=30P0f=SH202XZ:P0302<S8`0N
7Qh07QhN008061PH0P0C4a<200d=3@802PX:0P092@T200D51@800@410P0410@200X:2P803`l?0P0E
5AD201XJ6P807alO0P0T92@00`0Y:BT0;Rh^02h^;P0203<c<`80>3Ph0P0m?Cd20492@P80AdM70P1;
Bd/2051@D080E5AD0P1IFET205eMG@80HV9R0P1VIVH206][J`80Kfm_00<0M7Ad07QhN01hN7P00P1l
O7`20861P@80QHF50P29RHT208j>SP80TY:B5@3oool001<0oooo0P2LW9`20:6QX@80YZJV0P2[Zj/2
0;6a/@80][Jf0P2l_;`20<71`@030<O7a`3=cLd0cLg=0080dm?C0P3IfMT20=oOg`80i^KV0P3^k^h2
0?3`l080kNg]0P3Vi^H20=kNgP80f=SH0P3AdM420<W9b@80`L710P2i^KT00`2b/[80Zj^[0:^[Z`02
0:FUY@80X:2P0P2KVi/209VIV@80Vi^K0P2LW9`209fMW@H0WYjN0P2MWId409bLW0<0WIfM102NWYh2
09nOW`80XJ6Q0P2RXZ820:BTY080YZJV0P2XZ:P20:ZZZP80Zj^[0P2][Jd20:n_[`80/;2`0P2a/K47
0;:b/P80/K6a0P2_[jl20:j^[P80[Jf]102[Zj/20:VYZ@80YjNW0P2VYZH20:BTY080XZ:R0P2QXJ42
09nOW`0309fMW@2KVi/0Vi^K0080VIVI0P2FUYH209:BTP80S8b<0P27QhL20861P@80NGUi0P1`L702
06IVIP80FUYJ0P1>CTh20410@080<c<c0P0V9RH00`0R8R8071`L01`L700201DE5@804Q8B0P0=3@d2
00T92@8020P80P030`<2000000801PH60P0;2`/2014A4@805QHF0P0K6a/2020P80809BDU00<0:b/[
02l_;`0_;bl00P0d=3@203Ti>@80?Shn0P13@d<204M7A`80C4a<0P1ADE4205EEE@80FUYJ0P1NGUh2
06=SH`80IfMW0P1[Jf/2071`L00307AdM01hN7P0N7Qh0080OGem0P21PH4208F5Q@80RXZ:0P2>SXh2
09:BTQD0oooo000C0?ooo`80W9bL0P2QXJ420:JVYP80Zj^[0P2a/K420;Jf]P80_;bl0P31`L400`37
alL0cLg=0<g=c@020=?Cd`80fMWI0P3Ogml20>KViP80k^k^0P3`l?020>g]k@80i^KV0P3Ng]h20=SH
f080dM7A0P39bLT20<71`@80^KVi00<0/[:b0:^[Z`2[Zj/00P2UYJD20:2PX080Vi^K0P2IVIT209^K
V`80W9bL0P2MWId609jNWP80WIfM102LW9`309fMW@@0WYjN0P2OWil20:6QX@80XZ:R0P2TY:@20:JV
YP80Z:RX0P2ZZZX20:^[Z`80[Jf]0P2_[jl20;2`/080/K6a1`2b/[820;6a/@80[jn_0P2^[Zh20:f]
[@@0Zj^[0P2YZJT20:NWY`80YZJV0P2TY:@20::RXP80XJ6Q0P2OWil00`2MWId0Vi^K09^KV`0209VI
V@80UYJF0P2BTY8208b<S080QhN70P21PH4207UiN@80L71`0P1VIVH205YJFP80CTi>0P10@40203<c
<`809RHV00<08R8R01`L700L71`00P0E5AD2018B4P803@d=0P092@T200P820800`<30P00000200H6
1P802`/;0P0A4A4201HF5P806a/K0P0P820202DU9@0302/[:`0_;bl0;bl_0080=3@d0P0i>CT203hn
?P80@d=30P17AdL204a<C080DE5A0P1EEED205YJFP80GUiN0P1SHf<206MWI`80Jf][0P1`L7000`1d
M7@0N7Qh07QhN00207emO@80PH610P25QHD208Z:RP80SXj>0P2BTY8E0?ooo`004`3oool209bLW080
XJ6Q0P2VYZH20:^[Z`80/K6a0P2f][H20;^k^`80`L7100<0a/K60<c<c03<c<`00P3Bd]820=SHf080
gmoO0P3UiND20>g]k@80l?3`0P3Zj^X20>?Sh`80g=cL0P3GemL20=7Ad@80bLW90P31`L420;Vi^@03
0;:b/P2[Zj/0Zj^[0080Y:BT0P2OWil209ZJVP80V9RH0P2IVIT209ZJVP80Vi^K102LW9`809fMW@<0
WYjN0P2OWil20:2PX080XJ6Q0P2RXZ820:BTY080YJFU0P2WYjL20:VYZ@80ZZZZ0P2/[:`20:f][@80
[jn_0P2`/;040;6a/@<0/[:b102a/K440:n_[`80[Jf]0P2/[:`20:^[Z`80ZJVY0P2XZ:P20:NWY`80
YJFU0P2SXj<20::RXP80X:2P00<0WIfM09^KV`2KVi/00P2HV9P209FEU@80TI6A0P2;Rh/208J6QP80
P8200P1hN7P206m_K`80I6AT0P1HF5P204];B`80?Shn0P0a<C4202<S8`03020P800J6QX06QXJ0080
4a<C0P0A4A4200`<30@01`L710010@4200L71`803@d=0P0B4Q8201LG5`807AdM0P0R8R8202LW9`03
02`/;00a<C40<C4a0080=CDe0P0j>SX203lo?`80A4A40P18B4P204e=C@80DE5A0P1FEUH205YJFP80
GemO0P1SHf<206MWI`80K6a/0P1`L7000`1dM7@0NGUi07UiN@0207emO@80PH610P25QHD208Z:RP80
SXj>0P2BTY8E0?ooo`004`3oool209bLW080XJ6Q0P2VYZH20:^[Z`80/K6a0P2f][H20;^k^`80`L71
00<0a/K60<c<c03<c<`00P3Bd]820=SHf080gmoO0P3UiND20>g]k@80l?3`0P3Zj^X20>?Sh`80g=cL
0P3GemL20=7Ad@80bLW90P31`L420;Vi^@030;:b/P2[Zj/0Zj^[0080Y:BT0P2OWil209ZJVP80V9RH
0P2IVIT209ZJVP80Vi^K102LW9`809fMW@<0WYjN0P2OWil20:2PX080XJ6Q0P2RXZ820:BTY080YJFU
0P2WYjL20:VYZ@80ZZZZ0P2/[:`20:f][@80[jn_0P2`/;040;6a/@<0/[:b102a/K440:n_[`80[Jf]
0P2/[:`20:^[Z`80ZJVY0P2XZ:P20:NWY`80YJFU0P2SXj<20::RXP80X:2P00<0WIfM09^KV`2KVi/0
0P2HV9P209FEU@80TI6A0P2;Rh/208J6QP80P8200P1hN7P206m_K`80I6AT0P1HF5P204];B`80?Shn
0P0a<C4202<S8`03020P800J6QX06QXJ00804a<C0P0A4A4200`<30@01`L710010@4200L71`803@d=
0P0B4Q8201LG5`807AdM0P0R8R8202LW9`0302`/;00a<C40<C4a0080=CDe0P0j>SX203lo?`80A4A4
0P18B4P204e=C@80DE5A0P1FEUH205YJFP80GemO0P1SHf<206MWI`80K6a/0P1`L7000`1dM7@0NGUi
07UiN@0207emO@80PH610P25QHD208Z:RP80SXj>0P2BTY8E0?ooo`004`3oool209bLW080XJ6Q0P2V
YZH20:^[Z`80/;2`0P2e]KD20;^k^`80`<3000<0aLG50<_;b`3;bl/00P3AdM420=OGe`80gMgM0P3T
i>@20>_[j`80kno_0P3Xj>P20>;RhP80fm_K0P3Fe]H20=3@d080b<S80P31`L420;Vi^@030;:b/P2Z
ZZX0ZZZZ0080Xj>S0P2NWYh209VIV@80UiNG0P2HV9P209VIV@80VYZJ102KVi/409bLW080WIfM102N
WYh00`2OWil0X:2P0:2PX0020:6QX@80XZ:R0P2SXj<20:FUY@80YZJV0P2XZ:P20:VYZ@80Zj^[0P2/
[:`20:f][@80[Zj^0P2_[jl20;2`/0L0/K6a0P2`/;040:n_[`80[Zj^0P2][Jd20:^[Z`80ZZZZ0P2Y
ZJT20:NWY`80YZJV0P2TY:@20::RXP80X:2P00<0WYjN09^KV`2KVi/00P2HV9P209FEU@80T92@0P2:
RXX208F5Q@80Ogmo0P1gMgL206i^KP80HV9R0P1FEUH204Y:BP80?3`l0P0^;Rh2024Q8@0301hN7P0H
61P061PH00804Q8B0P0@410200`<30801PH60P051@D2000000800`<30P092@T200h>3P8051@D0P0I
6AT201hN7P808b<S0P0X:2P00`0];Bd0<S8b038b<P0203Lg=`80>c/k0P10@40204E5A@80BDU90P1>
CTh2059BDP80EeMG0P1KFe/205mOG`80I6AT0P1XJ6P206a/K080LG5a00<0MGEe07UiN@1iNGT00P1m
OGd20861P@80QXJ60P2:RXX208j>SP80TY:B5@3oool001<0oooo0P2LW9`20:6QX@80YZJV0P2[Zj/2
0;2`/080]KFe0P2k^k/20<30`0030<G5a@3;bl/0bl_;0080dM7A0P3GemL20=gMg@80i>CT0P3[jn/2
0>o_k`80j>SX0P3Rh^820=_Kf`80e]KF0P3@d=020<S8b080`L710P2i^KT00`2b/[80ZZZZ0:ZZZP02
0:>SX`80WYjN0P2IVIT209NGU`80V9RH0P2IVIT209ZJVP@0Vi^K102LW9`209fMW@@0WYjN00<0WinO
0:2PX02PX:000P2QXJ420::RXP80Xj>S0P2UYJD20:JVYP80Z:RX0P2YZJT20:^[Z`80[:b/0P2][Jd2
0:j^[P80[jn_0P2`/;070;6a/@80/;2`102_[jl20:j^[P80[Jf]0P2[Zj/20:ZZZP80ZJVY0P2WYjL2
0:JVYP80Y:BT0P2RXZ820:2PX00309jNWP2KVi/0Vi^K0080V9RH0P2EUID2092@T080RXZ:0P25QHD2
07moO`80MgMg0P1^KVh2069RHP80EUIF0P1:BTX203`l?080;Rh^0P0Q8B400`0N7Qh061PH01PH6002
018B4P80410@0P0<30`200H61P801@D50P00000200<30`802@T90P0>3Ph201@D50806ATI0P0N7Qh2
02<S8`80:2PX00<0;Bd]038b<P0b<S800P0g=cL203/k>`80@4100P15ADD204U9B@80CTi>0P1BDU82
05MGE`80Fe]K0P1OGel206ATI080J6QX0P1/K6`2075aL@0307EeM@1iNGT0NGUi0080OGem0P21PH42
08J6QP80RXZ:0P2>SXh209:BTQD0oooo000C0?ooo`80Vi^K0P2PX:020:FUY@80Zj^[0P2`/;020;Fe
]@80^[Zj0P2o_kl00`35aLD0b/[:0<[:bP020=3@d080e]KF0P3Lg=`20>;RhP80jNWY0P3^k^h20>OW
i`80hN7Q0P3Kfm/20=GEe@80clo?0P38b<P20<71`@80^KVi00<0/K6a0:ZZZP2ZZZX00P2RXZ8209fM
W@80VIVI0P2FUYH209NGU`80V9RH0P2IVIT209ZJVP80Vi^K102LW9`209fMW@80WYjN0P2OWil00`2P
X:00XJ6Q0:6QX@020::RXP80Xj>S0P2TY:@20:FUY@80YjNW0P2XZ:P20:ZZZP80Zj^[0P2/[:`20:f]
[@80[Zj^0P2_[jl=0;2`/080[jn_0P2^[Zh20:f][@80[:b/0P2ZZZX20:VYZ@80Z:RX0P2VYZH20:BT
Y080XZ:R0P2PX:000`2NWYh0Vi^K09^KV`0209RHV080U9BD0P2?Shl208Z:RP80Q8B40P1nOWh207If
MP80K6a/0P1PH60205EEE@80B4Q80P0j>SX202/[:`807alO00<06QXJ01HF5P0F5QH00P0A4A4200l?
3`802`/;0P061PH200820P8000000P051@D200/;2`80410@0P0E5AD201/K6`80820P0P0U9BD202XZ
:P0302h^;P0c<c<0<c<c0080>3Ph0P0m?Cd20451@@80ATI60P1:BTX204m?C`80De=C0P1GEeL205aL
G080H61P0P1TI6@206UYJ@80KFe]0P1aLG400`1eMGD0NGUi07UiN@0207inOP80PX:20P26QXH208Z:
RP80SXj>0P2BTY8E0?ooo`004`3oool209^KV`80X:2P0P2UYJD20:^[Z`80/;2`0P2e]KD20;Zj^P80
_kno00<0aLG50<[:bP3:b/X00P3@d=020=KFeP80g=cL0P3Rh^820>WYj@80k^k^0P3WinL20>7Qh@80
fm_K0P3EeMD20<o?c`80b<S80P31`L420;Vi^@030;6a/@2ZZZX0ZZZZ0080XZ:R0P2MWId209VIV@80
UYJF0P2GUiL209RHV080VIVI0P2JVYX209^KV`@0W9bL0P2MWId209jNWP80WinO00<0X:2P0:6QX@2Q
XJ400P2RXZ820:>SX`80Y:BT0P2UYJD20:NWY`80Z:RX0P2ZZZX20:^[Z`80[:b/0P2][Jd20:j^[P80
[jn_3@2`/;020:n_[`80[Zj^0P2][Jd20:b/[080ZZZZ0P2YZJT20:RXZ080YZJV0P2TY:@20::RXP80
X:2P00<0WYjN09^KV`2KVi/00P2HV9P209BDU080Shn?0P2:RXX208B4Q080OWin0P1fMWH206a/K080
H61P0P1EEED204Q8B080>SXj0P0[:b/201lO7`0301XJ6P0F5QH05QHF00804A4A0P0?3`l200/;2`80
1PH60P020P82000000801@D50P0;2`/2010@40805ADE0P0K6a/2020P80809BDU0P0Z:RX00`0^;Rh0
<c<c03<c<`0203Ph>080?Cdm0P11@D4204I6AP80BTY:0P1?Cdl205=CD`80EeMG0P1LG5`2061PH080
I6AT0P1YJFT206e]K@80LG5a00<0MGEe07UiN@1iNGT00P1nOWh208:2PP80QXJ60P2:RXX208j>SP80
TY:B5@3oool001<0oooo0P2KVi/20:2PX080YJFU0P2ZZZX20:n_[`80];Bd0P2i^KT20;jn_P030<C4
a039bLT0bLW90080clo?0P3De=@20=[JfP80h>3P0P3Vi^H20>g]k@80inOW0P3QhN420=[JfP80e=CD
0P3>c/h20<S8b080`<300P2i^KT00`2a/K40ZZZZ0:ZZZP020::RXP80WIfM0P2IVIT409JFUP80UiNG
0P2HV9P209VIV@80VYZJ0P2KVi/209bLW080WIfM0P2NWYh20:2PX0<0XJ6Q0P2SXj<20:BTY080YJFU
0P2VYZH20:RXZ080ZJVY0P2ZZZX20:^[Z`@0[Jf]0P2^[Zh40:n_[`T0/;2`102_[jl20:j^[P80[Jf]
0P2/[:`20:ZZZP80ZJVY0P2XZ:P20:JVYP80Y:BT0P2RXZ820:2PX00309jNWP2JVYX0VYZJ0080UiNG
0P2CTi<208j>SP80RHV90P23Ph<207alO080M7Ad0P1ZJVX205mOG`80De=C0P15ADD203Lg=`80:BTY
0P0M7Ad00`0H61P05ADE01DE5@0200l?3`803@d=0P092@T200D51@8000000P020P8200L71`803@d=
0P0B4Q8201LG5`8071`L0P0Q8B4202HV9P80:b/[00<0<30`03@d=00d=3@00P0i>CT203hn?P80@T92
0P17AdL204];B`80D51@0P1DE5@205QHF080GEeM0P1QHF4206EUI@80JFUY0P1]KFd2079bLP0307If
MP1jNWX0NWYj0080OWin0P22PX8208J6QP80RXZ:0P2>SXh209:BTQD0oooo000C0?ooo`80Vi^K0P2P
X:020:FUY@80ZZZZ0P2_[jl20;Bd]080^KVi0P2n_[h00`34a<@0bLW90<W9b@020<o?c`80e=CD0P3J
f]X20>3Ph080i^KV0P3]kNd20>OWi`80hN7Q0P3Jf]X20=CDe080c/k>0P38b<P20<30`080^KVi00<0
/K6a0:ZZZP2ZZZX00P2RXZ8209fMW@80VIVI102FUYH209NGU`80V9RH0P2IVIT209ZJVP80Vi^K0P2L
W9`209fMW@80WYjN0P2PX:030:6QX@80Xj>S0P2TY:@20:FUY@80YZJV0P2XZ:P20:VYZ@80ZZZZ0P2[
Zj/40:f][@80[Zj^102_[jl90;2`/0@0[jn_0P2^[Zh20:f][@80[:b/0P2ZZZX20:VYZ@80Z:RX0P2V
YZH20:BTY080XZ:R0P2PX:000`2NWYh0VYZJ09ZJVP0209NGU`80Ti>C0P2>SXh208V9R@80Ph>30P1l
O7`207AdM080JVYZ0P1OGel205=CD`80ADE50P0g=cL202TY:@807AdM00<061PH01DE5@0E5AD00P0?
3`l200d=3@802@T90P051@D2000000800P820P071`L200d=3@804Q8B0P0G5aL201`L70808B4Q0P0V
9RH202/[:`03030`<00d=3@0=3@d0080>CTi0P0n?Sh20492@P80AdM70P1;Bd/2051@D080E5AD0P1H
F5P205eMG@80HF5Q0P1UIFD206UYJ@80KFe]0P1bLW800`1fMWH0NWYj07YjNP0207inOP80PX:20P26
QXH208Z:RP80SXj>0P2BTY8E0?ooo`004`3oool209^KV`80X:2P0P2UYJD20:ZZZP80[jn_0P2c/k<2
0;Rh^080_Kfm00<0`l?30<S8b038b<P00P3=cLd20=?Cd`80f=SH0P3Ng]h20>CTi080jn_[0P3Vi^H2
0>3Ph080fMWI0P3De=@20<k>cP80alO70P30`<020;Vi^@030;6a/@2YZJT0ZJVY0080XZ:R0P2MWId2
09VIV@H0UYJF0P2HV9P209VIV@80VYZJ0P2KVi/209fMW@80WYjN0P2OWil20:2PX0030:6QX@2RXZ80
XZ:R0080Xj>S0P2UYJD20:JVYP80YjNW0P2XZ:P20:VYZ@80Zj^[0P2/[:`40:f][@80[Zj^102_[jl9
0;2`/080[jn_102^[Zh20:f][@80[:b/0P2ZZZX20:VYZ@80Z:RX0P2VYZH20:BTY080XZ:R0P2PX:00
0`2MWId0VYZJ09ZJVP0209NGU`80TY:B0P2=SHd208R8R080PX:20P1kNg/2079bLP80J6QX0P1MGEd2
051@D080@T920P0d=3@202HV9P8071`L00<05QHF01<C4`0C4a<00P0=3@d200X:2P801`L70P0410@2
0000008010@40P0:2PX200l?3`8051@D0P0I6AT201hN7P808b<S0P0X:2P202d];@03034a<@0f=SH0
=SHf0080>SXj0P0o?cl204=3@`80B4Q80P1<C4`2055AD@80EEEE0P1IFET205eMG@80HV9R0P1VIVH2
06YZJP80KVi^0P1bLW800`1fMWH0NWYj07YjNP0207inOP80PX:20P26QXH208Z:RP80SXj>0P2BTY8E
0?ooo`004`3oool209^KV`80X:2P0P2UYJD20:ZZZP80[jn_0P2c/k<20;Rh^080_Kfm00<0`l?30<S8
b038b<P00P3=cLd20=?Cd`80f=SH0P3Ng]h20>CTi080jn_[0P3Vi^H20>3Ph080fMWI0P3De=@20<k>
cP80alO70P30`<020;Vi^@030;6a/@2YZJT0ZJVY0080XZ:R0P2MWId209VIV@H0UYJF0P2HV9P209VI
V@80VYZJ0P2KVi/209fMW@80WYjN0P2OWil20:2PX0030:6QX@2RXZ80XZ:R0080Xj>S0P2UYJD20:JV
YP80YjNW0P2XZ:P20:VYZ@80Zj^[0P2/[:`40:f][@80[Zj^102_[jl90;2`/080[jn_102^[Zh20:f]
[@80[:b/0P2ZZZX20:VYZ@80Z:RX0P2VYZH20:BTY080XZ:R0P2PX:000`2MWId0VYZJ09ZJVP0209NG
U`80TY:B0P2=SHd208R8R080PX:20P1kNg/2079bLP80J6QX0P1MGEd2051@D080@T920P0d=3@202HV
9P8071`L00<05QHF01<C4`0C4a<00P0=3@d200X:2P801`L70P0410@20000008010@40P0:2PX200l?
3`8051@D0P0I6AT201hN7P808b<S0P0X:2P202d];@03034a<@0f=SH0=SHf0080>SXj0P0o?cl204=3
@`80B4Q80P1<C4`2055AD@80EEEE0P1IFET205eMG@80HV9R0P1VIVH206YZJP80KVi^0P1bLW800`1f
MWH0NWYj07YjNP0207inOP80PX:20P26QXH208Z:RP80SXj>0P2BTY8E0?ooo`004`3oool209^KV`80
X:2P0P2UYJD20:VYZ@80[Zj^0P2c/k<20;Rh^080_;bl00<0`L710<O7a`37alL00P3<c<`20=7Ad@80
e]KF0P3Lg=`20>;RhP80jNWY0P3Ti>@20=oOg`80f][J0P3De=@20<k>cP80alO70P30`<020;Rh^003
0;6a/@2YZJT0ZJVY0080XZ:R0P2MWId209VIV@80UiNG102FUYH209NGU`80VIVI0P2JVYX209bLW080
WIfM0P2NWYh209nOW`80XJ6Q00<0XZ:R0:>SX`2SXj<00P2TY:@20:JVYP80YjNW0P2XZ:P20:VYZ@80
ZZZZ0P2[Zj/20:b/[0@0[Jf]0P2^[Zh60:n_[`D0/;2`102_[jl20:j^[P@0[Jf]0P2[Zj/20:ZZZP80
ZJVY0P2WYjL20:JVYP80Xj>S0P2QXJ4209nOW`0309fMW@2IVIT0VIVI0080UYJF0P2BTY8208f=S@80
QhN70P20P80207UiN@80L71`0P1VIVH205]KF`80CDe=0P0o?cl2038b<P808b<S0P0K6a/00`0E5AD0
410@010@400200/;2`8020P80P051@D200<30`800P820P071`L200`<30804A4A0P0F5QH201/K6`80
820P0P0U9BD202XZ:P80;Rh^00<0<c<c03Lg=`0g=cL00P0l?3`20410@080ADE50P19BDT204e=C@80
DU9B0P1FEUH205YJFP80GUiN0P1RHV8206IVIP80Jf][0P1_Kfl207=cL`0307MgM`1kNg/0Ng]k0080
Ogmo0P23Ph<208N7Q`80Rh^;0P2?Shl209:BTQD0oooo000C0?ooo`80Vi^K0P2PX:020:FUY@80ZJVY
0P2^[Zh20;>c/`80^;Rh0P2l_;`00`31`L40alO70<O7a`020<c<c080dM7A0P3Fe]H20=cLg080h^;R
0P3YjNT20>CTi080gmoO0P3Jf]X20=CDe080c/k>0P37alL20<30`080^;Rh00<0/K6a0:VYZ@2YZJT0
0P2RXZ8209fMW@80VIVI0P2GUiL409JFUP80UiNG0P2IVIT209ZJVP80W9bL0P2MWId209jNWP80WinO
0P2QXJ400`2RXZ80Xj>S0:>SX`020:BTY080YZJV0P2WYjL20:RXZ080ZJVY0P2ZZZX20:^[Z`80[:b/
102][Jd20:j^[PH0[jn_1@2`/;040:n_[`80[Zj^102][Jd20:^[Z`80ZZZZ0P2YZJT20:NWY`80YZJV
0P2SXj<20:6QX@80WinO00<0WIfM09VIV@2IVIT00P2FUYH209:BTP80SHf=0P27QhL20820P080NGUi
0P1`L70206IVIP80Fe]K0P1=CDd203lo?`80<S8b0P0S8b<201/K6`0301DE5@0@4100410@00802`/;
0P0820P200D51@800`<30P020P8200L71`8030`<0P0A4A4201HF5P806a/K0P0P820202DU9@80:RXZ
0P0^;Rh00`0c<c<0=cLg03Lg=`0203`l?080@4100P15ADD204U9B@80CDe=0P1BDU8205IFEP80FUYJ
0P1NGUh2069RHP80IVIV0P1[Jf/206m_K`80Lg=c00<0MgMg07]kN`1kNg/00P1oOgl208>3P`80QhN7
0P2;Rh/208n?S`80TY:B5@3oool001<0oooo0P2KVi/20:2PX080Y:BT0P2YZJT20:f][@80/[:b0P2g
]kL20;^k^`030<30`035aLD0aLG50080b/[:0P3?cll20=CDe080fMWI0P3Ogml20>GUi@80i>CT0P3P
h>020=_Kf`80e=CD0P3>c/h20<O7a`80`<300P2h^;P00`2a/K40ZJVY0:VYZ@020::RXP80WIfM0P2J
VYX209NGU`80UYJF0P2GUiL209RHV080VIVI0P2KVi/209bLW080WIfM0P2OWil20:2PX080XZ:R00<0
Xj>S0:BTY02TY:@00P2UYJD20:NWY`80Z:RX102YZJT20:^[Z`@0[:b/0P2][Jd40:j^[PH0[jn_0`2`
/;040:n_[`@0[Zj^0P2][Jd20:b/[080Zj^[0P2ZZZX20:VYZ@80YjNW0P2UYJD20:>SX`80XJ6Q0P2N
WYh00`2LW9`0V9RH09RHV00209FEU@80TI6A0P2<S8`208F5Q@80Ogmo0P1gMgL206i^KP80I6AT0P1H
F5P204Y:BP80?3`l0P0_;bl2020P80806QXJ00<051@D00l?3`0?3`l00P0820P200H61P8010@40P02
0P8200D51@802PX:0P0?3`l201@D508061PH0P0M7Ad2028R8P809bLW0P0[:b/2030`<00303@d=00i
>CT0>CTi0080?Cdm0P12@T8204I6AP80BTY:0P1>CTh205=CD`80EeMG0P1KFe/205mOG`80Hf=S0P1W
IfL206][J`80Kfm_0P1cLg<00`1gMgL0Ng]k07]kN`0207moO`80Ph>30P27QhL208^;R`80Shn?0P2C
Ti<E0?ooo`004`3oool209^KV`80X:2P0P2TY:@20:VYZ@80[Jf]0P2b/[820;Ng]`80^k^k00<0`<30
0<G5a@35aLD00P3:b/X20<o?c`80e=CD0P3IfMT20=oOg`80iNGU0P3Ti>@20>3Ph080fm_K0P3De=@2
0<k>cP80alO70P30`<020;Rh^0030;6a/@2YZJT0ZJVY0080XZ:R0P2MWId209ZJVP80UiNG0P2FUYH2
09NGU`80V9RH0P2IVIT209^KV`80W9bL0P2MWId209nOW`80X:2P0P2RXZ800`2SXj<0Y:BT0:BTY002
0:FUY@80YjNW0P2XZ:P40:VYZ@80Zj^[102/[:`20:f][@@0[Zj^1P2_[jl30;2`/0@0[jn_102^[Zh2
0:f][@80[:b/0P2[Zj/20:ZZZP80ZJVY0P2WYjL20:FUY@80Xj>S0P2QXJ4209jNWP0309bLW02HV9P0
V9RH0080UIFE0P2ATI4208b<S080QHF50P1oOgl207MgM`80KVi^0P1TI6@205QHF080BTY:0P0l?3`2
02l_;`80820P0P0J6QX00`0D51@03`l?00l?3`0200P820801PH60P0410@200820P801@D50P0:2PX2
00l?3`8051@D0P0H61P201dM7@808R8R0P0W9bL202/[:`80<30`00<0=3@d03Ti>@0i>CT00P0m?Cd2
0492@P80ATI60P1:BTX204i>CP80De=C0P1GEeL205]KF`80GemO0P1SHf<206MWI`80Jf][0P1_Kfl2
07=cL`0307MgM`1kNg/0Ng]k0080Ogmo0P23Ph<208N7Q`80Rh^;0P2?Shl209>CTaD0oooo000C0?oo
o`80Vi^K0P2OWil20:BTY080Z:RX0P2][Jd20;6a/@80][Jf0P2j^[X00`2o_kl0a<C40<C4a0020<S8
b080cLg=0P3Bd]820=OGe`80g=cL0P3Ph>020>GUi@80h>3P0P3Kfm/20=CDe080c/k>0P37alL20<30
`080^;Rh00<0/K6a0:VYZ@2YZJT00P2RXZ8209jNWP80VYZJ0P2HV9P409NGU`80V9RH0P2JVYX209^K
V`80WIfM0P2NWYh209nOW`80XJ6Q0P2RXZ800`2SXj<0YJFU0:FUY@020:JVYP80YjNW0P2XZ:P20:VY
Z@80ZZZZ0P2[Zj/20:b/[0@0[Jf]102^[Zh60:n_[`030;2`/02_[jl0[jn_00@0[jn_0P2^[Zh40:f]
[@80[:b/102ZZZX20:RXZ080YjNW0P2TY:@20::RXP80X:2P0P2NWYh00`2KVi/0V9RH09RHV00209BD
U080Shn?0P2:RXX208B4Q080OGem0P1fMWH206a/K080HF5Q0P1EEED204M7A`80>CTi0P0/;2`201hN
7P806ATI00<04a<C00d=3@0=3@d00P061PH200@410@00`<30P0820P200d=3@804A4A0P0F5QH201/K
6`807alO0P0T92@202TY:@80;Bd]0P0b<S800`0f=SH0>SXj03Xj>P0203lo?`80@d=30P17AdL204a<
C080D51@0P1DE5@205QHF080G5aL0P1PH60206ATI080J6QX0P1/K6`2071`L080M7Ad00<0N7Qh07al
O01lO7`00P1oOgl208>3P`80QhN70P2;Rh/208n?S`80Ti>C5@3oool001<0oooo0P2KVi/209nOW`80
Y:BT0P2XZ:P20:f][@80/K6a0P2f][H20;Zj^P030;no_`34a<@0a<C40080b<S80P3=cLd20=;BdP80
emOG0P3Lg=`20>3Ph080iNGU0P3Ph>020=_Kf`80e=CD0P3>c/h20<O7a`80`<300P2h^;P00`2a/K40
ZJVY0:VYZ@020::RXP80WYjN0P2JVYX209RHV0@0UiNG0P2HV9P209ZJVP80Vi^K0P2MWId209jNWP80
WinO0P2QXJ420::RXP030:>SX`2UYJD0YJFU0080YZJV0P2WYjL20:RXZ080ZJVY0P2ZZZX20:^[Z`80
[:b/102][Jd40:j^[PH0[jn_00<0/;2`0:n_[`2_[jl0102_[jl20:j^[P@0[Jf]0P2/[:`40:ZZZP80
Z:RX0P2WYjL20:BTY080XZ:R0P2PX:0209jNWP0309^KV`2HV9P0V9RH0080U9BD0P2?Shl208Z:RP80
Q8B40P1mOGd207IfMP80K6a/0P1QHF4205EEE@80AdM70P0i>CT202`/;0807QhN0P0I6AT00`0C4a<0
3@d=00d=3@0200H61P8010@410030`<200P820803@d=0P0A4A4201HF5P806a/K0P0O7al202@T9080
:BTY0P0];Bd2038b<P0303Hf=P0j>SX0>SXj0080?clo0P13@d<204M7A`80C4a<0P1@D50205ADE080
F5QH0P1LG5`2061PH080I6AT0P1XJ6P206a/K080L71`0P1dM7@00`1hN7P0O7al07alO00207moO`80
Ph>30P27QhL208^;R`80Shn?0P2CTi<E0?ooo`004`3oool209^KV`80WinO0P2SXj<20:RXZ080[:b/
0P2`/;020;Fe]@80^KVi00<0_Kfm0<;2`P32`/800P36a/H20<_;b`80d=3@0P3De=@20=WIf@80gMgM
0P3Rh^820>3Ph080fm_K0P3De=@20<k>cP80alO70P30`<020;Vi^@030;6a/@2ZZZX0ZZZZ0080Xj>S
0P2OWil209^KV`80VIVI102HV9P209VIV@80Vi^K0P2LW9`209jNWP80WinO0P2PX:020::RXP80Xj>S
00<0Y:BT0:FUY@2UYJD00P2WYjL20:RXZ080ZJVY0P2ZZZX20:^[Z`@0[:b/0P2][Jd60:j^[P/0[jn_
102^[Zh20:f][@80[:b/0P2[Zj/20:ZZZP80ZJVY0P2XZ:P20:JVYP80Y:BT0P2QXJ4209nOW`80WIfM
00<0VYZJ09NGU`2GUiL00P2CTi<208j>SP80R8R80P22PX8207]kN`80Lg=c0P1YJFT205iNGP80DE5A
0P14A4@203Hf=P80:BTY0P0L71`201LG5`03018B4P0;2`/02`/;00801@D510030`<200H61P802`/;
0P0?3`l201@D508061PH0P0M7Ad2028R8P809RHV0P0[:b/202l_;`80<c<c00<0>3Ph03`l?00l?3`0
0P10@40204E5A@80BDU90P1=CDd2055AD@80EEEE0P1IFET205eMG@80HF5Q0P1UIFD206UYJ@80KFe]
0P1`L70207AdM00307QhN01lO7`0O7al0080P8200P24Q8@208N7Q`80Rh^;0P2?Shl209>CTaD0oooo
000C0?ooo`80Vi^K0P2OWil20:>SX`80Z:RX0P2/[:`20;2`/080]KFe0P2i^KT00`2m_Kd0`/;20<;2
`P020<K6aP80bl_;0P3@d=020=CDe080fMWI0P3MgMd20>;RhP80h>3P0P3Kfm/20=CDe080c/k>0P37
alL20<30`080^KVi00<0/K6a0:ZZZP2ZZZX00P2SXj<209nOW`80Vi^K0P2IVIT409RHV080VIVI0P2K
Vi/209bLW080WYjN0P2OWil20:2PX080XZ:R0P2SXj<00`2TY:@0YJFU0:FUY@020:NWY`80Z:RX0P2Y
ZJT20:ZZZP80Zj^[102/[:`20:f][@H0[Zj^2`2_[jl40:j^[P80[Jf]0P2/[:`20:^[Z`80ZZZZ0P2Y
ZJT20:RXZ080YZJV0P2TY:@20:6QX@80WinO0P2MWId00`2JVYX0UiNG09NGU`0209>CT`80SXj>0P28
R8P208:2PP80Ng]k0P1cLg<206UYJ@80GUiN0P1ADE4204A4A080=SHf0P0Y:BT201`L70805aLG00<0
4Q8B00/;2`0;2`/00P051@D400<30`801PH60P0;2`/200l?3`8051@D0P0H61P201dM7@808R8R0P0V
9RH202/[:`80;bl_0P0c<c<00`0h>3P0?3`l03`l?0020410@080ADE50P19BDT204e=C@80DE5A0P1E
EED205UIF@80GEeM0P1QHF4206EUI@80JFUY0P1]KFd2071`L080M7Ad00<0N7Qh07alO01lO7`00P20
P80208B4Q080QhN70P2;Rh/208n?S`80Ti>C5@3oool001<0oooo0P2KVi/209nOW`80Xj>S0P2WYjL2
0:^[Z`80[jn_0P2d];@20;Rh^0030;bl_030`<00`<300080aLG50P39bLT20<g=c@80dM7A0P3Fe]H2
0=[JfP80g]kN0P3Ph>020=_Kf`80e=CD0P3>c/h20<S8b080`L710P2j^[X00`2b/[80ZZZZ0:ZZZP02
0:BTY080WinO0P2LW9`209ZJVP80VIVI102JVYX209bLW080WIfM0P2NWYh20:2PX080XJ6Q0P2SXj<2
0:BTY0030:FUY@2WYjL0YjNW0080Z:RX0P2YZJT20:ZZZP80Zj^[102/[:`20:f][@H0[Zj^3@2_[jl2
0:j^[P@0[Jf]0P2/[:`20:^[Z`80ZZZZ0P2XZ:P20:NWY`80YJFU0P2SXj<20:2PX080WYjN0P2LW9`0
0`2IVIT0UIFE09FEU@02096AT@80S8b<0P26QXH20820P080NGUi0P1`L70206EUI@80FUYJ0P1>CTh2
0451@@80=3@d0P0W9bL201XJ6P805ADE00<0410@00T92@092@T00P051@D200<30`8010@40P092@T2
00d=3@804Q8B0P0F5QH201/K6`807alO0P0T92@202PX:080;Bd]0P0a<C4203De=@0303Xj>P0n?Sh0
?Shn0080@T920P16ATH204Y:BP80CTi>0P1BDU8205IFEP80FUYJ0P1NGUh2069RHP80IVIV0P1ZJVX2
06e]K@80LG5a0P1eMGD00`1iNGT0O7al07alO0020820P080Q8B40P28R8P208^;R`80Shn?0P2CTi<E
0?ooo`004`3oool209^KV`80WinO0P2SXj<20:NWY`80Zj^[0P2_[jl20;Bd]080^;Rh00<0_;bl0<30
`030`<000P35aLD20<W9b@80cLg=0P3AdM420=KFeP80f][J0P3Ng]h20>3Ph080fm_K0P3De=@20<k>
cP80b<S80P31`L420;Zj^P030;:b/P2ZZZX0ZZZZ0080Y:BT0P2OWil209bLW080VYZJ0P2IVIT409ZJ
VP80W9bL0P2MWId209jNWP80X:2P0P2QXJ420:>SX`80Y:BT00<0YJFU0:NWY`2WYjL00P2XZ:P20:VY
Z@80ZZZZ0P2[Zj/40:b/[080[Jf]1P2^[Zh=0:n_[`80[Zj^102][Jd20:b/[080Zj^[0P2ZZZX20:RX
Z080YjNW0P2UYJD20:>SX`80X:2P0P2NWYh209bLW00309VIV@2EUID0UIFE0080TI6A0P2<S8`208J6
QP80P8200P1iNGT2071`L080IFEU0P1JFUX204i>CP80@D510P0d=3@202LW9`806QXJ0P0E5AD00`0@
41002@T900T92@0200D51@800`<30P0410@200T92@803@d=0P0B4Q8201HF5P806a/K0P0O7al202@T
9080:2PX0P0];Bd2034a<@80=CDe00<0>SXj03hn?P0n?Sh00P12@T8204I6AP80BTY:0P1>CTh2059B
DP80EUIF0P1JFUX205iNGP80HV9R0P1VIVH206YZJP80KFe]0P1aLG4207EeM@0307UiN@1lO7`0O7al
0080P8200P24Q8@208R8R080Rh^;0P2?Shl209>CTaD0oooo000C0?ooo`80VYZJ0P2NWYh20::RXP80
YZJV0P2ZZZX20:j^[P80/k>c0P2g]kL00`2k^k/0_kno0;no_`020<?3``80alO70P3;bl/20<o?c`80
dm?C0P3Fe]H20=[JfP80g]kN0P3Jf]X20=GEe@80clo?0P39bLT20<;2`P80^k^k00<0/k>c0:b/[02/
[:`00P2UYJD20:2PX080WIfM0P2KVi/209ZJVP80Vi^K0P2LW9`209fMW@80WYjN0P2OWil20:6QX@80
XZ:R0P2TY:@20:FUY@030:JVYP2XZ:P0Z:RX0080ZJVY0P2ZZZX20:^[Z`@0[:b/0P2][Jd40:j^[Pl0
[jn_102^[Zh20:f][@80[:b/0P2[Zj/20:ZZZP80ZJVY0P2WYjL20:JVYP80Y:BT0P2RXZ8209nOW`80
WIfM0P2JVYX00`2GUiL0U9BD09BDU00208n?S`80RXZ:0P24Q8@207emO@80MWIf0P1]KFd2069RHP80
EeMG0P1;Bd/203hn?P80<S8b0P0U9BD201PH60804a<C00<03`l?00T92@092@T00P051@D200@41080
1PH60P0;2`/2010@408051@D0P0I6AT201dM7@808R8R0P0V9RH202XZ:P80;bl_0P0c<c<203Lg=`03
03/k>`0o?cl0?clo0080A4A40P18B4P204a<C080Cdm?0P1CDe<205MGE`80Fe]K0P1OGel206=SH`80
IfMW0P1ZJVX206i^KP80LW9b0P1fMWH00`1iNGT0OGem07emO@020861P@80Q8B40P28R8P208b<S080
Shn?0P2CTi<E0?ooo`004`3oool209ZJVP80WYjN0P2RXZ820:JVYP80ZZZZ0P2^[Zh20;>c/`80]kNg
00<0^k^k0;no_`2o_kl00P33`l<20<O7a`80bl_;0P3?cll20=?Cd`80e]KF0P3Jf]X20=kNgP80f][J
0P3EeMD20<o?c`80bLW90P32`/820;^k^`030;>c/`2/[:`0[:b/0080YJFU0P2PX:0209fMW@80Vi^K
0P2JVYX209^KV`80W9bL0P2MWId209jNWP80WinO0P2QXJ420::RXP80Y:BT0P2UYJD00`2VYZH0Z:RX
0:RXZ0020:VYZ@80ZZZZ0P2[Zj/40:b/[080[Jf]102^[Zh?0:n_[`@0[Zj^0P2][Jd20:b/[080Zj^[
0P2ZZZX20:VYZ@80YjNW0P2VYZH20:BTY080XZ:R0P2OWil209fMW@80VYZJ00<0UiNG09BDU02DU9@0
0P2?Shl208Z:RP80Q8B40P1mOGd207IfMP80KFe]0P1RHV8205MGE`80Bd];0P0n?Sh2038b<P809BDU
0P0H61P201<C4`0300l?3`092@T02@T900801@D50P0410@200H61P802`/;0P0@410201@D50806ATI
0P0M7Ad2028R8P809RHV0P0Z:RX202l_;`80<c<c0P0g=cL00`0k>c/0?clo03lo?`0204A4A080B4Q8
0P1<C4`204m?C`80De=C0P1GEeL205]KF`80GemO0P1SHf<206MWI`80JVYZ0P1^KVh2079bLP80MWIf
00<0NGUi07emO@1mOGd00P21PH4208B4Q080R8R80P2<S8`208n?S`80Ti>C5@3oool001<0oooo0P2J
VYX209jNWP80XZ:R0P2VYZH20:ZZZP80[Zj^0P2a/K420;Fe]@030;Vi^@2m_Kd0_Kfm0080`L710P35
aLD20<S8b080c<c<0P3@d=020=?Cd`80e]KF0P3IfMT20=SHf080eMGE0P3@d=020<[:bP80a<C40P2m
_Kd00`2e]KD0[Jf]0:f][@020:NWY`80XZ:R0P2NWYh609bLW080WIfM0P2NWYh209nOW`80XJ6Q0P2R
XZ820:>SX`80YJFU0P2VYZH00`2WYjL0ZJVY0:VYZ@020:ZZZP80Zj^[0P2/[:`40:f][@@0[Zj^1P2_
[jl40;2`/0L0[jn_0P2^[Zh20:f][@80[:b/0P2[Zj/20:ZZZP80ZJVY0P2XZ:P20:JVYP80YJFU0P2S
Xj<20:2PX080WYjN0P2LW9`209VIV@0309JFUP2BTY80TY:B0080SHf=0P28R8P208:2PP80NWYj0P1b
LW8206UYJ@80GUiN0P1CDe<204M7A`80>c/k0P0_;bl2028R8P805QHF0P0C4a<00`0>3Ph020P800P8
200400D51@802@T90P0>3Ph2018B4P805aLG0P0K6a/2020P808092@T0P0X:2P202d];@80<C4a0P0e
=CD203Ti>@0303dm?@11@D40@D510080ADE50P19BDT204e=C@80DE5A0P1EEED205UIF@80G5aL0P1P
H60206ATI080J6QX0P1[Jf/206m_K`80Lg=c0P1fMWH00`1jNWX0OGem07emO@020861P@80QHF50P28
R8P208b<S080Shn?0P2CTi<E0?ooo`004`3oool209ZJVP80WYjN0P2RXZ820:FUY@80ZJVY0P2][Jd2
0;2`/080];Bd00<0^;Rh0;bl_02l_;`00P2o_kl20<?3``80a/K60P3:b/X20<g=c@80d=3@0P3Cdm<2
0=CDe080e]KF0P3EeMD20=?Cd`80cLg=0P36a/H20;no_`030;Ng]`2_[jl0[jn_0080ZJVY0P2SXj<2
0:2PX080WYjN0P2MWId209jNWP@0WinO0P2QXJ420::RXP80Xj>S0P2UYJD20:JVYP80YjNW00<0Z:RX
0:ZZZP2ZZZX00P2[Zj/20:b/[0@0[Jf]0P2^[Zh40:n_[`X0/;2`1`2_[jl20:j^[P80[Jf]0P2/[:`2
0:^[Z`80ZZZZ0P2YZJT20:NWY`80YJFU0P2SXj<20:6QX@80WinO0P2MWId209ZJVP80UiNG00<0U9BD
08n?S`2?Shl00P2;Rh/208F5Q@80OWin0P1fMWH206i^KP80IFEU0P1KFe/2051@D080A4A40P0h>3P2
02/[:`807QhN0P0F5QH201<C4`0300d=3@0820P020P800801PH60P071`L200`<3080410@0P0E5AD2
01XJ6P807QhN0P0R8R8202HV9P80:b/[0P0_;bl203<c<`80=cLg0P0k>c/00`0o?cl0@d=304=3@`02
04M7A`80Bd];0P1?Cdl2059BDP80EUIF0P1JFUX205iNGP80HF5Q0P1UIFD206UYJ@80K6a/0P1`L702
07=cL`80MgMg00<0NWYj07inOP1nOWh00P21PH4208F5Q@80R8R80P2<S8`208n?S`80Ti>C5@3oool0
01<0oooo0P2JVYX209jNWP80XZ:R0P2UYJD20:VYZ@80[Jf]0P2`/;020;Bd]0030;Rh^02l_;`0_;bl
0080_kno0P33`l<20<K6aP80b/[:0P3=cLd20=3@d080dm?C0P3De=@20=KFeP80eMGE0P3Cdm<20<g=
c@80a/K60P2o_kl00`2g]kL0[jn_0:n_[`020:VYZ@80Xj>S0P2PX:0209jNWP80WIfM0P2NWYh409nO
W`80XJ6Q0P2RXZ820:>SX`80YJFU0P2VYZH20:NWY`030:RXZ02ZZZX0ZZZZ0080Zj^[0P2/[:`40:f]
[@80[Zj^102_[jl:0;2`/0L0[jn_0P2^[Zh20:f][@80[:b/0P2[Zj/20:ZZZP80ZJVY0P2WYjL20:FU
Y@80Xj>S0P2QXJ4209nOW`80WIfM0P2JVYX209NGU`0309BDU02?Shl0Shn?0080Rh^;0P25QHD207in
OP80MWIf0P1^KVh206EUI@80Fe]K0P1@D50204A4A080>3Ph0P0[:b/201hN7P805QHF0P0C4a<00`0=
3@d020P800P8200200H61P801`L70P0<30`2010@40805ADE0P0J6QX201hN7P808R8R0P0V9RH202/[
:`80;bl_0P0c<c<203Lg=`80>c/k00<0?clo04=3@`13@d<00P17AdL204];B`80Cdm?0P1BDU8205IF
EP80FUYJ0P1NGUh2065QH@80IFEU0P1YJFT206a/K080L71`0P1cLg<207MgM`0307YjNP1nOWh0OWin
0080PH610P25QHD208R8R080S8b<0P2?Shl209>CTaD0oooo000C0?ooo`80VYZJ0P2NWYh20:6QX@80
YJFU0P2XZ:P20:b/[080[jn_0P2c/k<00`2f][H0^[Zj0;Zj^P020;fm_@80`L710P34a<@20<O7a`80
b/[:0P3=cLd20=3@d080d];B0P3Cdm<20=GEe@80e]KF0P3AdM420<W9b@80`L7100<0^KVi0;6a/@2a
/K400P2[Zj/20:FUY@80XZ:R0P2PX:0209nOW`@0X:2P0P2QXJ420::RXP80Xj>S0P2UYJD20:JVYP80
YjNW0P2XZ:P00`2ZZZX0Zj^[0:^[Z`020:b/[080[Jf]102^[Zh20:n_[`H0/;2`102a/K460;2`/0<0
[jn_0P2^[Zh20:f][@80[:b/0P2[Zj/20:ZZZP80ZJVY0P2XZ:P20:JVYP80Y:BT0P2RXZ820:2PX080
WYjN0P2KVi/209RHV080UIFE00<0TY:B08f=S@2=SHd00P28R8P208:2PP80NWYj0P1bLW8206YZJP80
HF5Q0P1GEeL204a<C080@4100P0d=3@202HV9P8071`L0P0H61P201<C4`0300`<300820P020P80080
1`L70P0:2PX200l?3`804a<C0P0H61P201`L70808B4Q0P0U9BD202TY:@80;Bd]0P0a<C4203De=@80
>CTi0P0m?Cd00`11@D40ADE504E5A@0204U9B@80C4a<0P1@D50205ADE080EeMG0P1KFe/205mOG`80
HV9R0P1VIVH206UYJ@80KFe]0P1aLG4207AdM080N7Qh00<0Ng]k07inOP1nOWh00P22PX8208F5Q@80
RHV90P2<S8`2092@T080Ti>C5@3oool001<0oooo0P2JVYX209jNWP80XJ6Q0P2UYJD20:RXZ080[:b/
0P2_[jl20;>c/`030;Jf]P2j^[X0^[Zj0080_Kfm0P31`L420<C4a080alO70P3:b/X20<g=c@80d=3@
0P3Bd]820=?Cd`80eMGE0P3Fe]H20=7Ad@80bLW90P31`L400`2i^KT0/K6a0;6a/@020:^[Z`80YJFU
0P2RXZ820:2PX080WinO102PX:020:6QX@80XZ:R0P2SXj<20:FUY@80YZJV0P2WYjL20:RXZ0030:ZZ
ZP2[Zj/0Zj^[0080[:b/0P2][Jd40:j^[P80[jn_1P2`/;040;6a/@H0/;2`0`2_[jl20:j^[P80[Jf]
0P2/[:`20:^[Z`80ZZZZ0P2YZJT20:RXZ080YZJV0P2TY:@20::RXP80X:2P0P2NWYh209^KV`80V9RH
0P2EUID00`2BTY80SHf=08f=S@0208R8R080PX:20P1jNWX2079bLP80JVYZ0P1QHF4205MGE`80C4a<
0P10@40203@d=0809RHV0P0L71`201PH60804a<C00<030`<00P8200820P00P071`L200X:2P803`l?
0P0C4a<201PH608071`L0P0Q8B4202DU9@80:BTY0P0];Bd2034a<@80=CDe0P0i>CT203dm?@030451
@@15ADD0ADE50080BDU90P1<C4`2051@D080E5AD0P1GEeL205]KF`80GemO0P1RHV8206IVIP80JFUY
0P1]KFd2075aL@80M7Ad0P1hN7P00`1kNg/0OWin07inOP0208:2PP80QHF50P29RHT208b<S080T92@
0P2CTi<E0?ooo`004`3oool209ZJVP80WIfM0P2QXJ420:BTY080Z:RX0P2[Zj/20:j^[P80/[:b00<0
]KFe0;Rh^02h^;P00P2l_;`20;no_`80`/;20P35aLD20<S8b080bl_;0P3=cLd20<o?c`80dM7A0P3C
dm<20=KFeP80e=CD0P3:b/X20<;2`P030;^k^`2c/k<0/k>c0080[Jf]0P2XZ:P20:BTY080XZ:R102Q
XJ420::RXP80Xj>S0P2TY:@20:FUY@80YZJV0P2WYjL20:VYZ@80ZZZZ00<0Zj^[0:b/[02/[:`00P2]
[Jd20:j^[P@0[jn_0P2`/;0<0;6a/@@0/;2`0P2_[jl30:j^[P80[Jf]0P2[Zj/20:ZZZP80ZJVY0P2X
Z:P20:NWY`80YJFU0P2SXj<20:6QX@80WinO0P2LW9`209ZJVP80UYJF0P2CTi<00`2?Shl0RXZ:08Z:
RP0208B4Q080OWin0P1fMWH206i^KP80IFEU0P1LG5`205=CD`80B4Q80P0l?3`202l_;`8092@T0P0M
7Ad201PH60804Q8B00<030`<00T92@092@T00P092@T200d=3@804Q8B0P0F5QH201/K6`807alO0P0S
8b<202LW9`80;2`/0P0`<30203@d=080=cLg0P0k>c/203lo?`0304=3@`17AdL0AdM70080BTY:0P1>
CTh2059BDP80EEEE0P1IFET205aLG080H61P0P1SHf<206MWI`80Jf][0P1^KVh2075aL@80MGEe0P1h
N7P00`1lO7`0Ogmo07moO`0208:2PP80QXJ60P29RHT208b<S080T92@0P2CTi<E0?ooo`004`3oool2
09ZJVP80WIfM0P2QXJ420:BTY080Z:RX0P2[Zj/20:j^[P80/[:b00<0]KFe0;Rh^02h^;P00P2l_;`2
0;no_`80`/;20P35aLD20<S8b080bl_;0P3=cLd20<o?c`80dM7A0P3Cdm<20=KFeP80e=CD0P3:b/X2
0<;2`P030;^k^`2c/k<0/k>c0080[Jf]0P2XZ:P20:BTY080XZ:R102QXJ420::RXP80Xj>S0P2TY:@2
0:FUY@80YZJV0P2WYjL20:VYZ@80ZZZZ00<0Zj^[0:b/[02/[:`00P2][Jd20:j^[P@0[jn_0P2`/;0<
0;6a/@@0/;2`0P2_[jl30:j^[P80[Jf]0P2[Zj/20:ZZZP80ZJVY0P2XZ:P20:NWY`80YJFU0P2SXj<2
0:6QX@80WinO0P2LW9`209ZJVP80UYJF0P2CTi<00`2?Shl0RXZ:08Z:RP0208B4Q080OWin0P1fMWH2
06i^KP80IFEU0P1LG5`205=CD`80B4Q80P0l?3`202l_;`8092@T0P0M7Ad201PH60804Q8B00<030`<
00T92@092@T00P092@T200d=3@804Q8B0P0F5QH201/K6`807alO0P0S8b<202LW9`80;2`/0P0`<302
03@d=080=cLg0P0k>c/203lo?`0304=3@`17AdL0AdM70080BTY:0P1>CTh2059BDP80EEEE0P1IFET2
05aLG080H61P0P1SHf<206MWI`80Jf][0P1^KVh2075aL@80MGEe0P1hN7P00`1lO7`0Ogmo07moO`02
08:2PP80QXJ60P29RHT208b<S080T92@0P2CTi<E0?ooo`004`3oool209ZJVP80WIfM0P2PX:020:BT
Y080YjNW0P2ZZZX20:f][@80/K6a00<0];Bd0;Ng]`2g]kL00P2j^[X20;fm_@80`<300P33`l<20<K6
aP80b<S80P3;bl/20<g=c@80d=3@0P3Bd]820=KFeP80eMGE0P3<c<`20<C4a0030;fm_@2e]KD0]KFe
0080[jn_0P2ZZZX20:JVYP80Y:BT1P2SXj<20:BTY080YJFU0P2VYZH20:NWY`80Z:RX0P2ZZZX20:^[
Z`030:b/[02][Jd0[Jf]0080[Zj^0P2_[jl20;2`/0@0/K6a2P2b/[820;6a/@80/;2`102_[jl00`2^
[Zh0[Jf]0:f][@020:b/[080Zj^[0P2ZZZX20:RXZ080YjNW0P2UYJD20:>SX`80XJ6Q0P2OWil209fM
W@80VYZJ0P2GUiL209>CT`80T92@00<0S8b<08N7Q`27QhL00P21PH4207YjNP80LW9b0P1ZJVX2065Q
H@80F5QH0P1?Cdl204=3@`80=cLg0P0];Bd202<S8`807AdM0P0G5aL2018B4P0300d=3@0<30`030`<
008030`<0P0A4A4201DE5@806QXJ0P0N7Qh2028R8P809RHV0P0Z:RX202h^;P80<S8b0P0f=SH203Xj
>P80?Cdm0P11@D400`15ADD0BDU904U9B@0204a<C080D51@0P1CDe<205MGE`80FUYJ0P1NGUh2065Q
H@80IFEU0P1XJ6P206a/K080Kfm_0P1bLW8207IfMP80NGUi00<0O7al0820P020P8000P23Ph<208J6
QP80RHV90P2=SHd2092@T080Ti>C5@3oool001<0oooo0P2JVYX209fMW@80X:2P0P2TY:@20:NWY`80
ZZZZ0P2][Jd20;6a/@030;Bd]02g]kL0]kNg0080^[Zj0P2m_Kd20<30`080`l?30P36a/H20<S8b080
bl_;0P3=cLd20=3@d080d];B0P3Fe]H20=GEe@80c<c<0P34a<@00`2m_Kd0]KFe0;Fe]@020:n_[`80
ZZZZ0P2VYZH20:BTY0H0Xj>S0P2TY:@20:FUY@80YZJV0P2WYjL20:RXZ080ZZZZ0P2[Zj/00`2/[:`0
[Jf]0:f][@020:j^[P80[jn_0P2`/;040;6a/@X0/[:b0P2a/K420;2`/0@0[jn_00<0[Zj^0:f][@2]
[Jd00P2/[:`20:^[Z`80ZZZZ0P2XZ:P20:NWY`80YJFU0P2SXj<20:6QX@80WinO0P2MWId209ZJVP80
UiNG0P2CTi<2092@T00308b<S027QhL0QhN70080PH610P1jNWX2079bLP80JVYZ0P1QHF4205QHF080
Cdm?0P13@d<203Lg=`80;Bd]0P0S8b<201dM7@805aLG0P0B4Q800`0=3@d030`<00`<300200`<3080
4A4A0P0E5AD201XJ6P807QhN0P0R8R8202HV9P80:RXZ0P0^;Rh2038b<P80=SHf0P0j>SX203dm?@80
@D5100<0ADE504U9B@19BDT00P1<C4`2051@D080De=C0P1GEeL205YJFP80GUiN0P1QHF4206EUI@80
J6QX0P1/K6`206m_K`80LW9b0P1fMWH207UiN@0307alO020P800P8200080Ph>30P26QXH208V9R@80
SHf=0P2@T90209>CTaD0oooo000C0?ooo`80VYZJ0P2MWId20:2PX080Xj>S0P2VYZH20:VYZ@80[:b/
0P2_[jl00`2c/k<0][Jf0;Jf]P020;Rh^080^k^k0P2n_[h20<71`@80a<C40P36a/H20<W9b@80bl_;
0P3>c/h20=7Ad@80eMGE0P3Cdm<20<o?c`80a/K600<0_kno0;Rh^02h^;P00P2b/[820:b/[080ZJVY
0P2VYZH60:FUY@80YZJV102WYjL20:VYZ@80ZZZZ0P2/[:`20:f][@030:j^[P2_[jl0[jn_0080[jn_
0P2`/;020;6a/@@0/[:b202c/k<20;:b/P80/K6a0P2`/;040:n_[`030:j^[P2][Jd0[Jf]0080[:b/
0P2ZZZX20:VYZ@80YjNW0P2VYZH20:BTY080XZ:R0P2PX:0209fMW@80Vi^K0P2HV9P209FEU@80TI6A
0P2=SHd00`28R8P0PX:208:2PP0207emO@80MWIf0P1^KVh206EUI@80GEeM0P1DE5@204Y:BP80@410
0P0c<c<202`/;0808b<S0P0M7Ad201HF5P804a<C00<03`l?00h>3P0>3Ph00P0@410201DE5@806ATI
0P0M7Ad2024Q8@809BDU0P0Y:BT202d];@80<C4a0P0e=CD203Ph>080?3`l0P10@40204=3@`0304M7
A`1:BTX0BTY:0080CTi>0P1ADE4205EEE@80F5QH0P1LG5`205mOG`80HV9R0P1VIVH206UYJ@80KFe]
0P1`L70207=cL`80MWIf0P1jNWX00`1mOGd0P8200820P00208>3P`80QXJ60P2:RXX208f=S@80T92@
0P2CTi<E0?ooo`004`3oool209ZJVP80WIfM0P2PX:020:>SX`80YZJV0P2YZJT20:b/[080[jn_00<0
/k>c0;Jf]P2f][H00P2h^;P20;^k^`80_[jn0P31`L420<C4a080a/K60P39bLT20<_;b`80c/k>0P3A
dM420=GEe@80dm?C0P3?cll20<K6aP030;no_`2h^;P0^;Rh0080/[:b0P2/[:`20:VYZ@80YZJV1P2U
YJD20:JVYP@0YjNW0P2YZJT20:ZZZP80[:b/0P2][Jd00`2^[Zh0[jn_0:n_[`020:n_[`80/;2`0P2a
/K440;:b/PP0/k>c0P2b/[820;6a/@80/;2`102_[jl00`2^[Zh0[Jf]0:f][@020:b/[080ZZZZ0P2Y
ZJT20:NWY`80YZJV0P2TY:@20::RXP80X:2P0P2MWId209^KV`80V9RH0P2EUID2096AT@80SHf=00<0
R8R808:2PP22PX800P1mOGd207IfMP80KVi^0P1UIFD205eMG@80E5AD0P1:BTX20410@080<c<c0P0/
;2`202<S8`807AdM0P0F5QH201<C4`0300l?3`0>3Ph03Ph>0080410@0P0E5AD201TI6@807AdM0P0Q
8B4202DU9@80:BTY0P0];Bd2034a<@80=CDe0P0h>3P203`l?080@4100P13@d<00`17AdL0BTY:04Y:
BP0204i>CP80DE5A0P1EEED205QHF080G5aL0P1OGel2069RHP80IVIV0P1YJFT206e]K@80L71`0P1c
Lg<207IfMP80NWYj00<0OGem0820P020P8000P23Ph<208J6QP80RXZ:0P2=SHd2092@T080Ti>C5@3o
ool001<0oooo0P2IVIT209bLW080WinO0P2SXj<20:JVYP80Z:RX0P2[Zj/20:j^[P030;6a/@2d];@0
];Bd0080]kNg0P2j^[X20;bl_080_kno0P32`/820<C4a080alO70P39bLT20<c<c080c/k>0P3Bd]84
0=7Ad@80b<S800<0`<300;Zj^P2j^[X00P2d];@20:n_[`80Zj^[0P2XZ:P80:NWY`80Z:RX0P2YZJT2
0:ZZZP80[:b/0P2][Jd20:j^[P030:n_[`2`/;00/;2`00@0/K6a0P2b/[840;>c/`H0];Bd0P2c/k<2
0;:b/P80/K6a0P2`/;040:n_[`030:j^[P2/[:`0[:b/0080Zj^[0P2ZZZX20:RXZ080YZJV0P2TY:@2
0::RXP80X:2P0P2NWYh209^KV`80V9RH0P2EUID2096AT@80SHf=0P29RHT00`24Q8@0OWin07inOP02
07QhN080LG5a0P1YJFT2065QH@80F5QH0P1?Cdl204I6AP80>c/k0P0a<C4202/[:`808b<S0P0L71`2
01HF5P8051@D0`0A4A4201DE5@8061PH0P0M7Ad2020P808092@T0P0X:2P202`/;080<30`0P0d=3@2
03Lg=`80>c/k0P0n?Sh20492@P80ADE500<0BDU904a<C01<C4`00P1@D50205=CD`80EeMG0P1JFUX2
05eMG@80HF5Q0P1TI6@206MWI`80Jf][0P1^KVh2075aL@80M7Ad0P1gMgL207YjNP0307inOP21PH40
PH610080Q8B40P27QhL208Z:RP80SHf=0P2@T90209>CTaD0oooo000C0?ooo`80VIVI0P2LW9`209nO
W`80Xj>S0P2VYZH20:RXZ080Zj^[0P2^[Zh00`2a/K40];Bd0;Bd]0020;Ng]`80^[Zj0P2l_;`20;no
_`80`/;20P34a<@20<O7a`80bLW90P3<c<`20<k>cP80d];B103AdM420<S8b0030<30`02j^[X0^[Zj
0080];Bd0P2_[jl20:^[Z`80Z:RX202WYjL20:RXZ080ZJVY0P2ZZZX20:b/[080[Jf]0P2^[Zh00`2_
[jl0/;2`0;2`/0040;6a/@80/[:b102c/k<60;Bd]080/k>c0P2b/[820;6a/@80/;2`102_[jl00`2^
[Zh0[:b/0:b/[0020:^[Z`80ZZZZ0P2XZ:P20:JVYP80Y:BT0P2RXZ820:2PX080WYjN0P2KVi/209RH
V080UIFE0P2ATI4208f=S@80RHV900<0Q8B407inOP1nOWh00P1hN7P2075aL@80JFUY0P1QHF4205QH
F080Cdm?0P16ATH203/k>`80<C4a0P0[:b/202<S8`8071`L0P0F5QH201@D50<04A4A0P0E5AD201PH
60807AdM0P0P820202@T9080:2PX0P0/;2`2030`<080=3@d0P0g=cL203/k>`80?Shn0P12@T8204E5
A@0304U9B@1<C4`0C4a<0080D51@0P1CDe<205MGE`80FUYJ0P1MGEd2065QH@80I6AT0P1WIfL206][
J`80KVi^0P1aLG4207AdM080MgMg0P1jNWX00`1nOWh0PH610861P@0208B4Q080QhN70P2:RXX208f=
S@80T92@0P2CTi<E0?ooo`004`3oool209VIV@80W9bL0P2OWil20::RXP80YJFU0P2XZ:P20:^[Z`80
[Jf]00<0/;2`0;>c/`2c/k<00P2f][H20;Rh^080^k^k0P2m_Kd20<30`080`/;20P35aLD20<O7a`80
bLW90P3<c<`20<o?c`80dM7A0P3@d=020<W9b@030<;2`P2l_;`0_;bl0080]kNg0P2b/[820:j^[P80
Zj^[0P2YZJT20:RXZ0@0ZJVY102ZZZX20:b/[080[Jf]0P2^[Zh20;2`/0030;6a/@2b/[80/[:b0080
/[:b102c/k<<0;Bd]080/k>c0P2a/K420;2`/080[jn_0P2^[Zh00`2][Jd0Zj^[0:^[Z`020:ZZZP80
ZJVY0P2WYjL20:FUY@80Xj>S0P2PX:0209jNWP80Vi^K0P2HV9P209FEU@80TY:B0P2>SXh208V9R@80
QHF500<0P82007YjNP1jNWX00P1dM7@206e]K@80I6AT0P1LG5`205ADE080Bd];0P12@T8203Ph>080
<30`0P0Z:RX2028R8P807AdM0P0H61P201DE5@0301@D500E5AD05ADE00806ATI0P0L71`2020P8080
92@T0P0X:2P202/[:`80;bl_0P0c<c<203Hf=P80>SXj0P0m?Cd20451@@80A4A40P18B4P00`1;Bd/0
CTi>04i>CP02059BDP80EEEE0P1HF5P205]KF`80GemO0P1RHV8206EUI@80J6QX0P1/K6`206m_K`80
LW9b0P1eMGD207QhN080Ng]k00<0OWin0861P@21PH400P24Q8@208N7Q`80RXZ:0P2=SHd2092@T080
Ti>C5@3oool001<0oooo0P2IVIT209bLW080WinO0P2RXZ820:FUY@80Z:RX0P2[Zj/20:f][@030;2`
/02c/k<0/k>c0080][Jf0P2h^;P20;^k^`80_Kfm0P30`<020<;2`P80aLG50P37alL20<W9b@80c<c<
0P3?cll20=7Ad@80d=3@0P39bLT00`32`/80_;bl0;bl_0020;Ng]`80/[:b0P2^[Zh20:^[Z`80ZJVY
0P2XZ:P40:VYZ@@0ZZZZ0P2/[:`20:f][@80[Zj^0P2`/;000`2a/K40/[:b0;:b/P020;:b/P@0/k>c
302d];@20;>c/`80/K6a0P2`/;020:n_[`80[Zj^00<0[Jf]0:^[Z`2[Zj/00P2ZZZX20:VYZ@80YjNW
0P2UYJD20:>SX`80X:2P0P2NWYh209^KV`80V9RH0P2EUID209:BTP80SXj>0P29RHT208F5Q@030820
P01jNWX0NWYj0080M7Ad0P1]KFd206ATI080G5aL0P1DE5@204];B`80@T920P0h>3P2030`<080:RXZ
0P0R8R8201dM7@8061PH0P0E5AD00`0D51@05ADE01DE5@0201TI6@8071`L0P0P820202@T9080:2PX
0P0[:b/202l_;`80<c<c0P0f=SH203Xj>P80?Cdm0P11@D4204A4A080B4Q800<0Bd];04i>CP1>CTh0
0P1BDU8205EEE@80F5QH0P1KFe/205mOG`80HV9R0P1UIFD206QXJ080K6a/0P1_Kfl2079bLP80MGEe
0P1hN7P207]kN`0307inOP21PH40PH610080Q8B40P27QhL208Z:RP80SHf=0P2@T90209>CTaD0oooo
000C0?ooo`80VIVI0P2LW9`209nOW`80XJ6Q0P2TY:@20:NWY`80ZZZZ0P2/[:`00`2_[jl0/[:b0;:b
/P020;Bd]080]kNg0P2i^KT20;^k^`80_[jn0P30`<020<;2`P80aLG50P37alL20<W9b@80bl_;103=
cLd20<[:bP030<C4a02o_kl0_kno0080^[Zj0P2d];@20;6a/@80[Zj^0P2[Zj/60:ZZZP80Zj^[0P2/
[:`20:f][@80[jn_0P2`/;020;6a/@030;:b/P2c/k<0/k>c0080/k>c1P2d];@20;Fe]@P0];Bd0P2b
/[820;6a/@80[jn_0P2^[Zh20:f][@030:b/[02ZZZX0ZZZZ0080ZJVY0P2WYjL20:FUY@80Xj>S0P2P
X:0209jNWP80Vi^K0P2HV9P209FEU@80TY:B0P2>SXh208Z:RP80QXJ60P21PH400`1kNg/0MGEe07Ee
M@0206m_K`80J6QX0P1PH60205QHF080DE5A0P18B4P203lo?`80=SHf0P0_;bl202TY:@808R8R0P0M
7Ad201TI6@805aLG00<05QHF01TI6@0I6AT00P0M7Ad2020P808092@T0P0W9bL202/[:`80;bl_0P0b
<S8203Hf=P80>CTi0P0l?3`20410@080@d=30P17AdL204Y:BP0304e=C@1@D500D51@0080E5AD0P1G
EeL205YJFP80GEeM0P1PH60206=SH`80IVIV0P1YJFT206e]K@80L71`0P1cLg<207IfMP80NGUi0P1l
O7`00`1oOgl0PX:208:2PP0208F5Q@80R8R80P2;Rh/208j>SP80TI6A0P2CTi<E0?ooo`004`3oool2
09VIV@80W9bL0P2OWil20:6QX@80Y:BT0P2WYjL20:ZZZP80[:b/00<0[jn_0;:b/P2b/[800P2d];@2
0;Ng]`80^KVi0P2k^k/20;jn_P80`<300P32`/820<G5a@80alO70P39bLT20<_;b`@0cLg=0P3:b/X0
0`34a<@0_kno0;no_`020;Zj^P80];Bd0P2a/K420:j^[P80Zj^[1P2ZZZX20:^[Z`80[:b/0P2][Jd2
0:n_[`80/;2`0P2a/K400`2b/[80/k>c0;>c/`020;>c/`H0];Bd0P2e]KD80;Bd]080/[:b0P2a/K42
0:n_[`80[Zj^0P2][Jd00`2/[:`0ZZZZ0:ZZZP020:VYZ@80YjNW0P2UYJD20:>SX`80X:2P0P2NWYh2
09^KV`80V9RH0P2EUID209:BTP80SXj>0P2:RXX208J6QP80PH6100<0Ng]k07EeM@1eMGD00P1_Kfl2
06QXJ080H61P0P1HF5P2055AD@80B4Q80P0o?cl203Hf=P80;bl_0P0Y:BT2028R8P807AdM0P0I6AT2
01LG5`0301HF5P0I6AT06ATI00807AdM0P0P820202@T90809bLW0P0[:b/202l_;`80<S8b0P0f=SH2
03Ti>@80?3`l0P10@40204=3@`80AdM70P1:BTX00`1=CDd0D51@051@D00205ADE080EeMG0P1JFUX2
05eMG@80H61P0P1SHf<206IVIP80JFUY0P1]KFd2071`L080Lg=c0P1fMWH207UiN@80O7al00<0Ogmo
08:2PP22PX800P25QHD208R8R080Rh^;0P2>SXh2096AT@80Ti>C5@3oool001<0oooo0P2IVIT209bL
W080WYjN0P2QXJ420:BTY080YZJV0P2YZJT20:^[Z`030:j^[P2`/;00/;2`0080/k>c0P2e]KD20;Ng
]`80^[Zj0P2l_;`20;jn_P80`<300P33`l<20<G5a@80alO70P38b<P20<[:bP80bl_;0P39bLT00`37
alL0`/;20<;2`P020;fm_@80]kNg0P2c/k<20;6a/@80[Jf]0P2/[:`40:^[Z`80[:b/0P2^[Zh20:n_
[`80/K6a0P2b/[820;>c/`/0];Bd0P2e]KD60;Bd]080/k>c0P2b/[820;2`/080[Zj^0P2][Jd20:b/
[0030:ZZZP2XZ:P0Z:RX0080YjNW0P2UYJD20::RXP80X:2P0P2MWId209^KV`80V9RH0P2EUID209:B
TP80SXj>0P2;Rh/208J6QP80PH610P1lO7`00`1gMgL0LG5a075aL@0206][J`80I6AT0P1LG5`205EE
E@80CDe=0P15ADD203`l?080=3@d0P0^;Rh202PX:0808R8R0P0N7Qh201`L70806ATI00<06QXJ01dM
7@0M7Ad00P0Q8B4202@T9080:2PX0P0[:b/202h^;P80<S8b0P0e=CD203Ti>@80?3`l0P0o?cl20492
@P80ATI60P19BDT204a<C00304m?C`1BDU80DU9B0080EUIF0P1IFET205aLG080GemO0P1RHV8206EU
I@80J6QX0P1[Jf/206i^KP80LG5a0P1dM7@207MgM`80NWYj0P1mOGd00`1oOgl0PX:208:2PP0208F5
Q@80R8R80P2;Rh/208j>SP80TI6A0P2DU9@E0?ooo`004`3oool209VIV@80W9bL0P2NWYh20:6QX@80
Y:BT0P2VYZH20:VYZ@80Zj^[00<0[Zj^0;2`/02`/;000P2c/k<20;Fe]@80]kNg0P2j^[X20;bl_080
_[jn0P30`<020<?3``80aLG50P37alL20<S8b080b/[:0P3;bl/20<W9b@030<O7a`32`/80`/;20080
_Kfm0P2g]kL20;>c/`80/K6a0P2][Jd20:b/[0@0Zj^[0P2/[:`20:j^[P80[jn_0P2a/K420;:b/P80
/k>c2`2d];@20;Fe]@H0];Bd0P2c/k<20;:b/P80/;2`0P2^[Zh20:f][@80[:b/00<0ZZZZ0:RXZ02X
Z:P00P2WYjL20:FUY@80XZ:R0P2PX:0209fMW@80Vi^K0P2HV9P209FEU@80TY:B0P2>SXh208^;R`80
QXJ60P21PH4207alO00307MgM`1aLG40LG5a0080Jf][0P1TI6@205aLG080EEEE0P1=CDd204E5A@80
?3`l0P0d=3@202h^;P80:2PX0P0R8R8201hN7P8071`L0P0I6AT00`0J6QX07AdM01dM7@02024Q8@80
92@T0P0X:2P202/[:`80;Rh^0P0b<S8203De=@80>CTi0P0l?3`203lo?`80@T920P16ATH204U9B@80
C4a<00<0Cdm?059BDP1BDU800P1FEUH205UIF@80G5aL0P1OGel2069RHP80IFEU0P1XJ6P206][J`80
KVi^0P1aLG4207AdM080MgMg0P1jNWX207emO@0307moO`22PX80PX:20080QHF50P28R8P208^;R`80
SXj>0P2ATI4209BDU1D0oooo000C0?ooo`80VIVI0P2KVi/209jNWP80X:2P0P2SXj<20:FUY@80Z:RX
0P2ZZZX00`2][Jd0[jn_0:n_[`020;6a/@80];Bd0P2f][H20;Rh^080^[Zj0P2l_;`20;jn_P80`<30
0P32`/820<C4a080a/K60P37alL40<S8b0030<W9b@35aLD0aLG50080`<300P2j^[X20;Jf]P80/[:b
0P2_[jl20:j^[P80[Jf]102^[Zh20;2`/080/K6a0P2c/k<40;Bd]0D0]KFe302d];@20;>c/`80/[:b
0P2`/;020:n_[`80[Jf]0P2/[:`20:VYZ@030:RXZ02WYjL0YjNW0080YJFU0P2SXj<20:2PX080WIfM
0P2KVi/209VIV@80UIFE0P2BTY8208j>SP80Rh^;0P28R8P208:2PP80OGem0P1hN7P00`1cLg<0K6a/
06a/K00206IVIP80H61P0P1IFET2055AD@80BDU90P12@T8203Xj>P80<c<c0P0];Bd202PX:08092@T
0P0Q8B4201dM7@806a/K00<07QhN028R8P0R8R800P0U9BD202PX:080:b/[0P0_;bl2038b<P80=CDe
0P0h>3P203/k>`80?clo0P12@T8204E5A@80B4Q80P1;Bd/204i>CP03055AD@1EEED0EEEE0080F5QH
0P1KFe/205iNGP80HF5Q0P1SHf<206IVIP80JFUY0P1/K6`206m_K`80LW9b0P1eMGD207QhN080Ng]k
0P1mOGd00`20P800Ph>308>3P`0208J6QP80RHV90P2;Rh/208j>SP80TI6A0P2DU9@E0?ooo`004`3o
ool209VIV@80Vi^K0P2NWYh20:2PX080Xj>S0P2UYJD20:RXZ080ZZZZ00<0[Jf]0:n_[`2_[jl00P2a
/K420;Bd]080][Jf0P2h^;P20;Zj^P80_;bl0P2n_[h20<30`080`/;20P34a<@20<K6aP80alO71038
b<P00`39bLT0aLG50<G5a@020<30`080^[Zj0P2f][H20;:b/P80[jn_0P2^[Zh20:f][@@0[Zj^0P2`
/;020;6a/@80/k>c102d];@50;Fe]@`0];Bd0P2c/k<20;:b/P80/;2`0P2_[jl20:f][@80[:b/0P2Y
ZJT00`2XZ:P0YjNW0:NWY`020:FUY@80Xj>S0P2PX:0209fMW@80Vi^K0P2IVIT209FEU@80TY:B0P2>
SXh208^;R`80R8R80P22PX8207emO@80N7Qh00<0Lg=c06a/K01/K6`00P1VIVH2061PH080FEUI0P1A
DE4204U9B@80@T920P0j>SX203<c<`80;Bd]0P0X:2P202@T90808B4Q0P0M7Ad201/K6`0301hN7P0R
8R808R8R00809BDU0P0X:2P202/[:`80;bl_0P0b<S8203De=@80>3Ph0P0k>c/203lo?`80@T920P15
ADD204Q8B080Bd];0P1>CTh00`1ADE40EEEE05EEE@0205QHF080Fe]K0P1NGUh2065QH@80Hf=S0P1V
IVH206UYJ@80K6a/0P1_Kfl2079bLP80MGEe0P1hN7P207]kN`80OGem00<0P82008>3P`23Ph<00P26
QXH208V9R@80Rh^;0P2>SXh2096AT@80U9BD5@3oool001<0oooo0P2IVIT209^KV`80WYjN0P2PX:02
0::RXP80YJFU0P2WYjL20:VYZ@030:b/[02^[Zh0[Zj^0080/;2`0P2b/[820;Bd]080]kNg0P2i^KT2
0;^k^`80_;bl0P2n_[h20<30`080`/;20P33`l<20<G5a@80a/K60P37alL00`38b<P0alO70<O7a`02
0<;2`P80_[jn0P2i^KT20;Fe]@80/[:b0P2a/K440:n_[`80/;2`0P2a/K420;>c/`@0];Bd1`2e]KD6
0;Bd]0H0/k>c0P2b/[820;6a/@80[jn_0P2][Jd20:b/[080ZZZZ0P2XZ:P00`2VYZH0YJFU0:FUY@02
0::RXP80X:2P0P2NWYh209^KV`80VYZJ0P2FUYH209>CT`80Shn?0P2;Rh/208R8R080Q8B40P1nOWh2
07UiN@80M7Ad00<0KVi^06QXJ01XJ6P00P1RHV8205aLG080EEEE0P1=CDd204I6AP80?clo0P0h>3P2
038b<P80;Bd]0P0Z:RX202HV9P808R8R0P0N7Qh201lO7`0302<S8`0V9RH09RHV0080:BTY0P0/;2`2
02l_;`80<S8b0P0e=CD203Ph>080>c/k0P0n?Sh20492@P80ADE50P18B4P204];B`80CTi>0P1ADE40
0`1DE5@0EeMG05MGE`0205YJFP80G5aL0P1OGel2069RHP80IFEU0P1XJ6P206][J`80KVi^0P1`L702
07=cL`80MWIf0P1iNGT207]kN`80OWin00<0PH6108B4Q024Q8@00P26QXH208V9R@80S8b<0P2>SXh2
096AT@80U9BD5@3oool001<0oooo0P2IVIT209^KV`80WYjN0P2PX:020::RXP80YJFU0P2WYjL20:VY
Z@030:b/[02^[Zh0[Zj^0080/;2`0P2b/[820;Bd]080]kNg0P2i^KT20;^k^`80_;bl0P2n_[h20<30
`080`/;20P33`l<20<G5a@80a/K60P37alL00`38b<P0alO70<O7a`020<;2`P80_[jn0P2i^KT20;Fe
]@80/[:b0P2a/K440:n_[`80/;2`0P2a/K420;>c/`@0];Bd1`2e]KD60;Bd]0H0/k>c0P2b/[820;6a
/@80[jn_0P2][Jd20:b/[080ZZZZ0P2XZ:P00`2VYZH0YJFU0:FUY@020::RXP80X:2P0P2NWYh209^K
V`80VYZJ0P2FUYH209>CT`80Shn?0P2;Rh/208R8R080Q8B40P1nOWh207UiN@80M7Ad00<0KVi^06QX
J01XJ6P00P1RHV8205aLG080EEEE0P1=CDd204I6AP80?clo0P0h>3P2038b<P80;Bd]0P0Z:RX202HV
9P808R8R0P0N7Qh201lO7`0302<S8`0V9RH09RHV0080:BTY0P0/;2`202l_;`80<S8b0P0e=CD203Ph
>080>c/k0P0n?Sh20492@P80ADE50P18B4P204];B`80CTi>0P1ADE400`1DE5@0EeMG05MGE`0205YJ
FP80G5aL0P1OGel2069RHP80IFEU0P1XJ6P206][J`80KVi^0P1`L70207=cL`80MWIf0P1iNGT207]k
N`80OWin00<0PH6108B4Q024Q8@00P26QXH208V9R@80S8b<0P2>SXh2096AT@80U9BD5@3oool001<0
oooo0P2IVIT209^KV`80WIfM0P2OWil20::RXP80Y:BT0P2VYZH20:RXZ0030:^[Z`2][Jd0[Jf]0080
[jn_0P2a/K420;>c/`80]KFe0P2g]kL20;Vi^@80^k^k0P2l_;`20;jn_P80`<300P31`L420<;2`P80
`l?30P35aLD00`36a/H0alO70<O7a`020<G5a@80`L710P2l_;`20;Ng]`80]KFe0P2b/[840;6a/@80
/[:b0P2c/k<60;Fe]@80][Jf1@2e]KD40;Bd]080/k>c102b/[820;6a/@80/;2`0P2_[jl20:f][@80
Zj^[0P2ZZZX20:RXZ080YJFU00<0Y:BT0::RXP2RXZ800P2PX:0209jNWP80W9bL0P2JVYX209NGU`80
Ti>C0P2ATI4208b<S080R8R80P24Q8@207moO`80NWYj0P1eMGD206m_K`0306UYJ@1SHf<0Hf=S0080
GUiN0P1GEeL2051@D080BTY:0P12@T8203dm?@80=cLg0P0c<c<2030`<080:b/[0P0W9bL202<S8`80
820P0P0T92@00`0W9bL0:RXZ02XZ:P0202d];@80<30`0P0c<c<203Hf=P80>CTi0P0k>c/203hn?P80
@D510P14A4@204M7A`80BTY:0P1=CDd2051@D080De=C00<0EUIF05UIF@1IFET00P1LG5`205iNGP80
HF5Q0P1TI6@206MWI`80JFUY0P1/K6`206m_K`80LW9b0P1dM7@207MgM`80NWYj0P1lO7`207moO`03
08:2PP24Q8@0Q8B40080QhN70P29RHT208b<S080Shn?0P2ATI4209BDU1D0oooo000C0?ooo`80VIVI
0P2KVi/209fMW@80WinO0P2RXZ820:BTY080YZJV0P2XZ:P00`2[Zj/0[Jf]0:f][@020:n_[`80/K6a
0P2c/k<20;Fe]@80]kNg0P2i^KT20;^k^`80_;bl0P2n_[h20<30`080`L710P32`/820<?3``80aLG5
00<0a/K60<O7a`37alL00P35aLD20<71`@80_;bl0P2g]kL20;Fe]@80/[:b102a/K420;:b/P80/k>c
1P2e]KD20;Jf]PD0]KFe102d];@20;>c/`@0/[:b0P2a/K420;2`/080[jn_0P2][Jd20:^[Z`80ZZZZ
0P2XZ:P20:FUY@030:BTY02RXZ80XZ:R0080X:2P0P2NWYh209bLW080VYZJ0P2GUiL209>CT`80TI6A
0P2<S8`208R8R080Q8B40P1oOgl207YjNP80MGEe0P1_Kfl00`1YJFT0Hf=S06=SH`0205iNGP80EeMG
0P1@D50204Y:BP80@T920P0m?Cd203Lg=`80<c<c0P0`<30202/[:`809bLW0P0S8b<2020P808092@T
00<09bLW02XZ:P0Z:RX00P0];Bd2030`<080<c<c0P0f=SH203Ti>@80>c/k0P0n?Sh20451@@80A4A4
0P17AdL204Y:BP80CDe=0P1@D50205=CD`0305IFEP1IFET0FEUI0080G5aL0P1NGUh2065QH@80I6AT
0P1WIfL206UYJ@80K6a/0P1_Kfl2079bLP80M7Ad0P1gMgL207YjNP80O7al0P1oOgl00`22PX80Q8B4
08B4Q00208N7Q`80RHV90P2<S8`208n?S`80TI6A0P2DU9@E0?ooo`004`3oool209VIV@80Vi^K0P2M
WId209nOW`80XJ6Q0P2SXj<20:JVYP80Z:RX00<0ZZZZ0:b/[02/[:`00P2^[Zh20;2`/080/[:b0P2c
/k<20;Fe]@80]kNg0P2i^KT20;Zj^P80_;bl0P2n_[h20;no_`80`<300P32`/820<?3``030<C4a035
aLD0aLG50080alO70P34a<@20;no_`80^[Zj0P2h^;P20;Fe]@@0/[:b0P2c/k<20;Bd]0P0][Jf00<0
]KFe0;Bd]02d];@0102d];@20;>c/`@0/K6a0P2`/;020:n_[`80[Zj^0P2/[:`20:^[Z`80ZZZZ0P2W
YjL20:JVYP80Xj>S00<0XJ6Q09nOW`2OWil00P2NWYh209bLW080VYZJ0P2GUiL209BDU080TI6A0P2=
SHd208R8R080Q8B40P20P80207]kN`80MWIf0P1aLG4206][J`0306EUI@1OGel0GemO0080FEUI0P1C
De<204e=C@80AdM70P11@D4203dm?@80>3Ph0P0e=CD2034a<@80:RXZ0P0X:2P2028R8P8092@T0P0X
:2P00`0[:b/0;Rh^02h^;P02034a<@80<c<c0P0f=SH203Ti>@80?3`l0P0o?cl20492@P80ADE50P17
AdL204Y:BP80CDe=0P1@D50205=CD`80EEEE00<0F5QH05]KF`1KFe/00P1NGUh2061PH080Hf=S0P1U
IFD206QXJ080Jf][0P1^KVh2071`L080Lg=c0P1eMGD207QhN080Ng]k0P1mOGd20820P00308:2PP25
QHD0QHF50080QhN70P2:RXX208b<S080Shn?0P2ATI4209BDU1D0oooo000C0?ooo`80VIVI0P2KVi/2
09fMW@80WinO0P2QXJ420:>SX`80YZJV0P2XZ:P00`2ZZZX0[:b/0:b/[0020:j^[P80/;2`0P2b/[82
0;>c/`80]KFe0P2g]kL20;Vi^@80^[Zj0P2l_;`20;jn_P80_kno0P30`<020<;2`P80`l?300<0a<C4
0<G5a@35aLD00P37alL20<C4a080_kno0P2j^[X20;Rh^080]KFe102b/[820;>c/`80];Bd202f][H0
0`2e]KD0];Bd0;Bd]0040;Bd]080/k>c102a/K420;2`/080[jn_0P2^[Zh20:b/[080Zj^[0P2ZZZX2
0:NWY`80YZJV0P2SXj<00`2QXJ40WinO09nOW`0209jNWP80W9bL0P2JVYX209NGU`80U9BD0P2ATI42
08f=S@80R8R80P24Q8@20820P080Ng]k0P1fMWH2075aL@80Jf][00<0IFEU05mOG`1OGel00P1IFET2
05=CD`80CDe=0P17AdL20451@@80?Cdm0P0h>3P203De=@80<C4a0P0Z:RX202PX:0808R8R0P0T92@2
02PX:00302/[:`0^;Rh0;Rh^0080<C4a0P0c<c<203Hf=P80>CTi0P0l?3`203lo?`80@T920P15ADD2
04M7A`80BTY:0P1=CDd2051@D080De=C0P1EEED00`1HF5P0Fe]K05]KF`0205iNGP80H61P0P1SHf<2
06EUI@80J6QX0P1[Jf/206i^KP80L71`0P1cLg<207EeM@80N7Qh0P1kNg/207emO@80P82000<0PX:2
08F5Q@25QHD00P27QhL208Z:RP80S8b<0P2?Shl2096AT@80U9BD5@3oool001<0oooo0P2HV9P209^K
V`80WIfM0P2OWil20:6QX@80Xj>S0P2UYJD20:NWY`030:VYZ@2[Zj/0Zj^[0080[Jf]0P2^[Zh20;2`
/080/[:b0P2d];@20;Fe]@80]kNg0P2i^KT20;Zj^P80_;bl0P2m_Kd20;jn_P80`<300P31`L400`32
`/80`l?30<?3``020<G5a@80a/K60P31`L420;bl_080^[Zj0P2f][H20;Bd]080/k>c0P2d];@20;Fe
]@@0]kNg0P2f][H20;Fe]@D0];Bd0P2c/k<20;6a/@@0/;2`0P2^[Zh20:f][@80[:b/0P2ZZZX20:VY
Z@80YjNW0P2UYJD20:BTY080XZ:R00<0WinO09fMW@2MWId00P2KVi/209VIV@80UiNG0P2DU9@2096A
T@80SXj>0P29RHT208F5Q@80PH610P1lO7`207MgM`80LW9b0P1]KFd206MWI`03065QH@1KFe/0Fe]K
0080EUIF0P1ADE4204a<C080ATI60P12@T8203hn?P80>SXj0P0e=CD202l_;`80:b/[0P0W9bL202HV
9P80:BTY0P0/;2`00`0_;bl0<S8b038b<P0203@d=080=cLg0P0j>SX203dm?@80?clo0P12@T8204E5
A@80B4Q80P1:BTX204e=C@80D51@0P1BDU8205EEE@80F5QH00<0FUYJ05eMG@1MGEd00P1PH602069R
HP80IFEU0P1WIfL206YZJP80K6a/0P1_Kfl2079bLP80M7Ad0P1gMgL207UiN@80O7al0P1nOWh20861
P@0308>3P`25QHD0QHF50080R8R80P2:RXX208f=S@80Shn?0P2BTY8209BDU1D0oooo000C0?ooo`80
V9RH0P2KVi/209fMW@80WinO0P2QXJ420:>SX`80YJFU0P2WYjL00`2YZJT0Zj^[0:^[Z`020:f][@80
[Zj^0P2`/;020;:b/P80];Bd0P2e]KD20;Ng]`80^KVi0P2j^[X20;bl_080_Kfm0P2n_[h20<30`080
`L7100<0`/;20<?3``33`l<00P35aLD20<K6aP80`L710P2l_;`20;Zj^P80][Jf0P2d];@20;>c/`80
];Bd0P2e]KD40;Ng]`80][Jf0P2e]KD50;Bd]080/k>c0P2a/K440;2`/080[Zj^0P2][Jd20:b/[080
ZZZZ0P2YZJT20:NWY`80YJFU0P2TY:@20::RXP0309nOW`2MWId0WIfM0080Vi^K0P2IVIT209NGU`80
U9BD0P2ATI4208j>SP80RHV90P25QHD20861P@80O7al0P1gMgL2079bLP80KFe]0P1WIfL00`1QHF40
Fe]K05]KF`0205IFEP80DE5A0P1<C4`204I6AP80@T920P0n?Sh203Xj>P80=CDe0P0_;bl202/[:`80
9bLW0P0V9RH202TY:@80;2`/00<0;bl_038b<P0b<S800P0d=3@203Lg=`80>SXj0P0m?Cd203lo?`80
@T920P15ADD204Q8B080BTY:0P1=CDd2051@D080DU9B0P1EEED205QHF00305YJFP1MGEd0GEeM0080
H61P0P1RHV8206EUI@80IfMW0P1ZJVX206a/K080Kfm_0P1bLW8207AdM080MgMg0P1iNGT207alO080
OWin0P21PH400`23Ph<0QHF508F5Q@0208R8R080RXZ:0P2=SHd208n?S`80TY:B0P2DU9@E0?ooo`00
4`3oool209RHV080VYZJ0P2LW9`209jNWP80X:2P0P2RXZ820:BTY080YZJV00<0Z:RX0:ZZZP2ZZZX0
0P2[Zj/20:f][@80[jn_0P2a/K420;:b/P80];Bd0P2e]KD20;Ng]`80^;Rh0P2j^[X20;^k^`80_;bl
0P2n_[h20;no_`030<30`032`/80`/;20080`l?30P35aLD20<?3``80`<300P2l_;`20;Rh^080][Jf
0P2e]KD20;Bd]080]KFe0P2g]kL20;Rh^080][Jf0P2e]KD50;>c/`80/[:b102_[jl20:j^[P80[:b/
0P2[Zj/40:VYZ@80YJFU0P2TY:@20:>SX`80XJ6Q0P2PX:000`2LW9`0Vi^K09^KV`0209RHV080UYJF
0P2DU9@2096AT@80SXj>0P2:RXX208N7Q`80PX:20P1mOGd207QhN080Lg=c0P1^KVh206QXJ080Hf=S
00<0GUiN05QHF01HF5P00P1CDe<204m?C`80BTY:0P16ATH204=3@`80?clo0P0j>SX203@d=080;bl_
0P0Z:RX202PX:080:b/[0P0^;Rh2030`<00303<c<`0f=SH0=SHf0080>3Ph0P0k>c/203hn?P80@410
0P13@d<204E5A@80B4Q80P1;Bd/204e=C@80D51@0P1BDU8205EEE@80F5QH0P1JFUX00`1MGEd0GemO
05mOG`02069RHP80I6AT0P1WIfL206UYJ@80Jf][0P1^KVh2071`L080Lg=c0P1eMGD207QhN080NWYj
0P1mOGd207moO`80PH6100<0Q8B408J6QP26QXH00P28R8P208^;R`80SHf=0P2?Shl209:BTP80U9BD
5@3oool001<0oooo0P2HV9P209ZJVP80W9bL0P2NWYh20:2PX080XZ:R0P2TY:@20:JVYP030:RXZ02Z
ZZX0ZZZZ0080Zj^[0P2][Jd20:n_[`80/K6a0P2b/[820;Bd]080]KFe0P2g]kL20;Rh^080^[Zj0P2k
^k/20;bl_080_[jn0P2o_kl00`30`<00`/;20<;2`P020<?3``80aLG50P33`l<20<30`080_;bl0P2h
^;P20;Jf]P80]KFe0P2d];@20;Fe]@80]kNg0P2h^;P20;Jf]P80]KFe1@2c/k<20;:b/P@0[jn_0P2^
[Zh20:b/[080Zj^[102YZJT20:FUY@80Y:BT0P2SXj<20:6QX@80X:2P00<0W9bL09^KV`2KVi/00P2H
V9P209JFUP80U9BD0P2ATI4208j>SP80RXZ:0P27QhL208:2PP80OGem0P1hN7P207=cL`80KVi^0P1X
J6P206=SH`0305iNGP1HF5P0F5QH0080De=C0P1?Cdl204Y:BP80ATI60P13@d<203lo?`80>SXj0P0d
=3@202l_;`80:RXZ0P0X:2P202/[:`80;Rh^0P0`<3000`0c<c<0=SHf03Hf=P0203Ph>080>c/k0P0n
?Sh20410@080@d=30P15ADD204Q8B080Bd];0P1=CDd2051@D080DU9B0P1EEED205QHF080FUYJ00<0
GEeM05mOG`1OGel00P1RHV8206ATI080IfMW0P1YJFT206][J`80KVi^0P1`L70207=cL`80MGEe0P1h
N7P207YjNP80OGem0P1oOgl20861P@0308B4Q026QXH0QXJ60080R8R80P2;Rh/208f=S@80Shn?0P2B
TY8209BDU1D0oooo000C0?ooo`80V9RH0P2JVYX209bLW080WYjN0P2PX:020::RXP80Xj>S0P2UYJD0
0`2WYjL0ZJVY0:VYZ@020:ZZZP80[:b/0P2^[Zh20:n_[`80/K6a0P2b/[820;Bd]080]KFe0P2g]kL2
0;Rh^080^KVi0P2k^k/20;bl_080_Kfm00<0_[jn0<30`030`<000P31`L420<;2`P@0`l?30P2n_[h2
0;Zj^P80^;Rh0P2f][H20;Bd]080]KFe0P2g]kL20;Rh^080][Jf0P2d];@00`2c/k<0/K6a0;6a/@02
0;6a/@80/;2`0P2_[jl20:f][@80[:b/0P2ZZZX20:RXZ0@0YZJV0P2RXZ820:6QX@80X:2P0P2OWil2
09fMW@0309VIV@2HV9P0V9RH0080UIFE0P2CTi<2096AT@80SXj>0P2:RXX208N7Q`80Ph>30P1oOgl2
07YjNP80MGEe0P1`L70206YZJP80IFEU0P1PH6000`1KFe/0EeMG05MGE`0205=CD`80Cdm?0P1<C4`2
04U9B@80@d=30P0n?Sh203Ti>@80<c<c0P0_;bl202XZ:P80;Bd]0P0`<302038b<P80=CDe00<0=cLg
03Xj>P0j>SX00P0l?3`203lo?`80@D510P14A4@204I6AP80BDU90P1;Bd/204i>CP80D51@0P1CDe<2
05EEE@80F5QH0P1JFUX205eMG@0305mOG`1QHF40HF5Q0080I6AT0P1VIVH206QXJ080Jf][0P1]KFd2
071`L080LW9b0P1dM7@207MgM`80NGUi0P1kNg/207inOP80P8200P22PX800`24Q8@0QhN708N7Q`02
08V9R@80Rh^;0P2=SHd2092@T080TY:B0P2DU9@E0?ooo`004`3oool209RHV080VYZJ0P2LW9`209fM
W@80WinO0P2QXJ420:>SX`80Y:BT00<0YZJV0:RXZ02XZ:P00P2YZJT20:^[Z`80[:b/0P2^[Zh20:n_
[`80/K6a0P2b/[820;Bd]080]KFe0P2f][H20;Ng]`80^KVi0P2j^[X20;^k^`030;bl_02m_Kd0_Kfm
0080_kno0P30`<020<71`@80`l?30P31`L420;bl_080^KVi0P2f][H40;Fe]@80][Jf0P2g]kL20;Fe
]@80/[:b00<0/K6a0;2`/02`/;000P2_[jl20:j^[P80[Jf]0P2[Zj/20:VYZ@80Z:RX0P2UYJD20:BT
Y080XZ:R0P2PX:0209jNWP80W9bL0P2KVi/209ZJVP0309JFUP2EUID0UIFE0080TY:B0P2@T90208j>
SP80Rh^;0P27QhL208B4Q080Ogmo0P1lO7`207MgM`80LW9b0P1/K6`206MWI`80Hf=S0P1NGUh00`1J
FUX0EUIF05IFEP0205ADE080Cdm?0P1=CDd204U9B@80@D510P0l?3`203Lg=`80<c<c100^;Rh2038b
<P80=3@d0P0g=cL203Ti>@0303/k>`0n?Sh0?Shn0080@4100P12@T8204E5A@80AdM70P1:BTX204a<
C080CTi>0P1ADE4205=CD`80EUIF0P1HF5P205YJFP80GEeM0P1OGel00`1QHF40Hf=S06=SH`0206IV
IP80J6QX0P1ZJVX206e]K@80Kfm_0P1aLG4207=cL`80MWIf0P1hN7P207YjNP80O7al0P1oOgl20861
P@80Ph>300<0QHF508N7Q`27QhL00P29RHT208b<S080SXj>0P2@T90209:BTP80U9BD5@3oool001<0
oooo0P2HV9P209ZJVP80W9bL0P2MWId209nOW`80XJ6Q0P2SXj<20:BTY0030:JVYP2XZ:P0Z:RX0080
ZJVY0P2[Zj/20:b/[080[Zj^0P2_[jl20;6a/@80/[:b0P2d];@20;Fe]@80][Jf0P2g]kL20;Vi^@80
^[Zj0P2k^k/00`2l_;`0_Kfm0;fm_@020;no_`80`<300P31`L420<?3``80`L710P2l_;`20;Vi^@80
][Jf102e]KD20;Jf]P80]kNg0P2e]KD20;:b/P030;6a/@2`/;00/;2`0080[jn_0P2^[Zh20:f][@80
Zj^[0P2YZJT20:RXZ080YJFU0P2TY:@20::RXP80X:2P0P2NWYh209bLW080Vi^K0P2JVYX00`2FUYH0
UIFE09FEU@0209:BTP80T92@0P2>SXh208^;R`80QhN70P24Q8@207moO`80O7al0P1gMgL2079bLP80
K6a/0P1WIfL206=SH`80GUiN00<0FUYJ05IFEP1FEUH00P1DE5@204m?C`80CDe=0P19BDT20451@@80
?3`l0P0g=cL203<c<`@0;Rh^0P0b<S8203@d=080=cLg0P0i>CT00`0k>c/0?Shn03hn?P020410@080
@T920P15ADD204M7A`80BTY:0P1<C4`204i>CP80DE5A0P1CDe<205IFEP80F5QH0P1JFUX205eMG@80
GemO00<0HF5Q06=SH`1SHf<00P1VIVH206QXJ080JVYZ0P1]KFd206m_K`80LG5a0P1cLg<207IfMP80
N7Qh0P1jNWX207alO080Ogmo0P21PH4208>3P`0308F5Q@27QhL0QhN70080RHV90P2<S8`208j>SP80
T92@0P2BTY8209BDU1D0oooo000C0?ooo`80V9RH0P2JVYX209^KV`80WIfM0P2OWil20:2PX080XZ:R
0P2TY:@00`2UYJD0YjNW0:NWY`020:RXZ080ZZZZ0P2[Zj/20:f][@80[Zj^0P2_[jl20;6a/@80/[:b
0P2c/k<20;Fe]@80][Jf0P2g]kL20;Rh^080^KVi00<0^[Zj0;^k^`2k^k/00P2l_;`20;jn_P80_kno
0P30`<020<71`@80_[jn0P2k^k/20;Rh^080][Jf1P2d];@20;Fe]@80/[:b00<0/;2`0:n_[`2_[jl0
0P2^[Zh20:b/[080Zj^[0P2YZJT20:NWY`80YJFU0P2SXj<20:6QX@80WinO0P2MWId209^KV`80V9RH
0P2GUiL209JFUP0309BDU02BTY80TY:B0080Shn?0P2>SXh208^;R`80QhN70P24Q8@20861P@80OGem
0P1iNGT207AdM080Kfm_0P1[Jf/206MWI`80Hf=S0P1NGUh00`1KFe/0EeMG05MGE`0205EEE@80D51@
0P1<C4`204I6AP80?clo0P0k>c/203Lg=`@0<S8b0P0d=3@203Hf=P80>CTi0P0k>c/203dm?@030410
@012@T80@T920080A4A40P16ATH204Q8B080Bd];0P1=CDd204m?C`80DU9B0P1DE5@205IFEP80F5QH
0P1KFe/205eMG@80GemO0P1QHF400`1SHf<0IVIV06IVIP0206QXJ080JVYZ0P1/K6`206i^KP80L71`
0P1cLg<207EeM@80MgMg0P1iNGT207]kN`80OGem0P20P80208:2PP80Q8B400<0QXJ608R8R028R8P0
0P2:RXX208b<S080SXj>0P2@T90209:BTP80U9BD5@3oool001<0oooo0P2HV9P209ZJVP80Vi^K0P2M
WId209nOW`80X:2P0P2RXZ820:BTY0030:FUY@2WYjL0YjNW0080Z:RX0P2ZZZX20:^[Z`80[Jf]0P2^
[Zh20:n_[`80/K6a0P2b/[820;>c/`80]KFe0P2f][H20;Ng]`80^;Rh0P2i^KT00`2j^[X0^k^k0;^k
^`020;bl_080_[jn0P2o_kl20<30`080`L710P2n_[h20;^k^`80^;Rh0P2f][H60;Bd]080]KFe0P2b
/[800`2`/;00[jn_0:n_[`020:j^[P80[:b/0P2[Zj/20:VYZ@80YjNW0P2UYJD20:>SX`80XJ6Q0P2O
Wil209fMW@80Vi^K0P2HV9P209NGU`80UYJF00<0U9BD09:BTP2BTY800P2?Shl208j>SP80Rh^;0P27
QhL208B4Q080PH610P1mOGd207UiN@80M7Ad0P1_Kfl206][J`80IfMW0P1SHf<205iNGP0305]KF`1G
EeL0EeMG0080EEEE0P1@D50204a<C080ATI60P0o?cl203/k>`80=cLg100b<S8203@d=080=SHf0P0i
>CT203/k>`80?Cdm00<0@4100492@P12@T800P14A4@204I6AP80B4Q80P1;Bd/204e=C@80Cdm?0P1B
DU8205ADE080EUIF0P1HF5P205]KF`80GEeM0P1OGel2065QH@0306=SH`1VIVH0IVIV0080J6QX0P1Z
JVX206a/K080KVi^0P1`L70207=cL`80MGEe0P1gMgL207UiN@80Ng]k0P1mOGd20820P080PX:20P24
Q8@00`26QXH0R8R808R8R00208Z:RP80S8b<0P2>SXh2092@T080TY:B0P2DU9@E0?ooo`004`3oool2
09RHV080VYZJ0P2KVi/209fMW@80WYjN0P2PX:020:6QX@80Xj>S00<0Y:BT0:JVYP2VYZH00P2WYjL2
0:VYZ@80ZZZZ0P2[Zj/20:f][@80[Zj^0P2_[jl20;2`/080/[:b0P2c/k<20;Bd]080]KFe0P2f][H2
0;Ng]`030;Rh^02i^KT0^KVi0080^[Zj0P2k^k/20;bl_080_[jn102o_kl20;bl_080^KVi0P2f][H2
0;Bd]080/k>c102b/[820;6a/@030:j^[P2/[:`0[:b/0080Zj^[0P2ZZZX20:RXZ080YjNW0P2TY:@2
0::RXP80X:2P0P2NWYh209bLW080VYZJ0P2GUiL209FEU@80Ti>C0P2BTY800`2@T900Shn?08n?S`02
08f=S@80S8b<0P28R8P208B4Q080PX:20P1nOWh207]kN`80MgMg0P1cLg<206m_K`80Jf][0P1XJ6P2
06EUI@80H61P00<0G5aL05UIF@1IFET00P1DE5@204m?C`80BTY:0P14A4@203lo?`80>SXj0P0f=SH2
03De=@80=cLg0P0i>CT203/k>`80?Shn0P10@4020492@P0304A4A016ATH0ATI60080B4Q80P1:BTX2
04a<C080CTi>0P1ADE4205=CD`80EEEE0P1GEeL205UIF@80Fe]K0P1MGEd205mOG`80HV9R0P1TI6@0
0`1VIVH0J6QX06QXJ00206YZJP80K6a/0P1^KVh2071`L080LW9b0P1dM7@207IfMP80N7Qh0P1kNg/2
07emO@80Ogmo0P21PH4208>3P`80QHF500<0QhN708V9R@29RHT00P2;Rh/208f=S@80Shn?0P2ATI42
09:BTP80U9BD5@3oool001<0oooo0P2HV9P209ZJVP80Vi^K0P2MWId209jNWP80X:2P0P2QXJ420:>S
X`030:BTY02VYZH0YZJV0080YjNW0P2YZJT20:ZZZP80Zj^[0P2][Jd20:j^[P80[jn_0P2`/;020;:b
/P80/k>c0P2d];@20;Fe]@80][Jf0P2g]kL00`2h^;P0^KVi0;Vi^@020;Zj^P80^k^k0P2l_;`20;jn
_P@0_kno0P2l_;`20;Vi^@80][Jf0P2d];@20;>c/`@0/[:b0P2a/K400`2^[Zh0[:b/0:b/[0020:^[
Z`80ZZZZ0P2XZ:P20:NWY`80Y:BT0P2RXZ820:2PX080WYjN0P2LW9`209ZJVP80UiNG0P2EUID209>C
T`80TY:B00<0T92@08n?S`2?Shl00P2=SHd208b<S080R8R80P24Q8@208:2PP80OWin0P1kNg/207Mg
M`80Lg=c0P1_Kfl206][J`80J6QX0P1UIFD2061PH00305aLG01IFET0FEUI0080E5AD0P1?Cdl204Y:
BP80A4A40P0o?cl203Xj>P80=SHf0P0e=CD203Lg=`80>CTi0P0k>c/203hn?P80@4100P12@T800`14
A4@0ATI604I6AP0204Q8B080BTY:0P1<C4`204i>CP80DE5A0P1CDe<205EEE@80EeMG0P1IFET205]K
F`80GEeM0P1OGel2069RHP80I6AT00<0IVIV06QXJ01XJ6P00P1ZJVX206a/K080KVi^0P1`L702079b
LP80M7Ad0P1fMWH207QhN080Ng]k0P1mOGd207moO`80PH610P23Ph<208F5Q@0308N7Q`29RHT0RHV9
0080Rh^;0P2=SHd208n?S`80TI6A0P2BTY8209BDU1D0oooo000C0?ooo`80V9RH0P2IVIT209^KV`80
W9bL0P2NWYh209nOW`80XJ6Q0P2RXZ800`2SXj<0YJFU0:FUY@020:JVYP80Z:RX0P2YZJT20:ZZZP80
Zj^[0P2][Jd20:j^[P80[jn_0P2`/;020;6a/@80/[:b0P2c/k<20;Bd]080]KFe00<0][Jf0;Ng]`2g
]kL00P2h^;P20;Vi^@80^[Zj0P2k^k/20;bl_080_Kfm0P2l_;`20;Zj^P80][Jf0P2d];@20;:b/P80
/;2`0P2_[jl20:j^[P030:f][@2ZZZX0ZZZZ0080ZJVY0P2WYjL20:FUY@80Y:BT0P2QXJ4209nOW`80
WIfM0P2KVi/209VIV@80UiNG0P2CTi<209:BTP80T92@0P2?Shl00`2=SHd0S8b<08b<S00208b<S080
RHV90P26QXH208>3P`80P8200P1mOGd207YjNP80MgMg0P1dM7@2071`L080KFe]0P1ZJVX206EUI@80
HF5Q00<0G5aL05MGE`1GEeL00P1BDU8204a<C080AdM70P14A4@203lo?`80>SXj0P0i>CT203/k>`80
?Cdm0P0o?cl20410@080@d=30P15ADD204I6AP0304Q8B01:BTX0BTY:0080C4a<0P1>CTh2051@D080
DU9B0P1DE5@205IFEP80F5QH0P1JFUX205aLG080GUiN0P1PH602069RHP80I6AT0P1VIVH00`1XJ6P0
JVYZ06YZJP0206a/K080KVi^0P1`L702079bLP80M7Ad0P1fMWH207QhN080NWYj0P1lO7`207inOP80
P8200P22PX8208B4Q080QHF500<0QhN708V9R@29RHT00P2;Rh/208f=S@80Shn?0P2ATI4209>CT`80
UIFE5@3oool001<0oooo0P2HV9P209VIV@80Vi^K0P2LW9`209jNWP80WinO0P2QXJ420::RXP030:>S
X`2UYJD0YJFU0080YZJV0P2XZ:P20:VYZ@80ZZZZ0P2[Zj/20:f][@80[Zj^0P2_[jl20;2`/080/K6a
0P2b/[820;>c/`80];Bd0P2e]KD00`2f][H0]kNg0;Ng]`020;Rh^080^KVi0P2j^[X20;^k^`80_;bl
0P2m_Kd20;bl_080^[Zj0P2f][H20;Bd]080/[:b0P2`/;020:n_[`80[Zj^00<0[Jf]0:ZZZP2ZZZX0
0P2YZJT20:NWY`80YJFU0P2TY:@20:6QX@80WinO0P2MWId209^KV`80VIVI0P2GUiL209>CT`80TY:B
0P2@T90208n?S`0308f=S@2<S8`0S8b<0080S8b<0P29RHT208J6QP80Ph>30P20P80207emO@80NWYj
0P1gMgL207AdM080L71`0P1]KFd206YZJP80IFEU0P1QHF400`1LG5`0EeMG05MGE`02059BDP80C4a<
0P17AdL204A4A080?clo0P0j>SX203Ti>@80>c/k0P0m?Cd203lo?`80@4100P13@d<204E5A@80ATI6
00<0B4Q804Y:BP1:BTX00P1<C4`204i>CP80D51@0P1BDU8205ADE080EUIF0P1HF5P205YJFP80G5aL
0P1NGUh2061PH080HV9R0P1TI6@206IVIP0306QXJ01ZJVX0JVYZ0080K6a/0P1^KVh2071`L080LW9b
0P1dM7@207IfMP80N7Qh0P1jNWX207alO080OWin0P20P80208:2PP80Q8B40P25QHD00`27QhL0RHV9
08V9R@0208^;R`80SHf=0P2?Shl2096AT@80Ti>C0P2EUIDE0?ooo`004`3oool209RHV080VIVI0P2K
Vi/209bLW080WIfM0P2OWil20:2PX080XJ6Q00<0Xj>S0:BTY02TY:@00P2UYJD20:NWY`80Z:RX0P2Y
ZJT20:ZZZP80Zj^[0P2/[:`20:f][@80[jn_0P2`/;020;6a/@@0/[:b0P2c/k<00`2d];@0]KFe0;Fe
]@020;Jf]P@0]kNg0P2h^;P40;Vi^@80^[Zj0P2i^KT20;Ng]`80];Bd0P2b/[820:n_[`@0[:b/00<0
Zj^[0:RXZ02XZ:P00P2VYZH20:BTY080XZ:R0P2PX:0209jNWP80W9bL0P2KVi/209VIV@80UIFE0P2D
U9@2096AT@80Shn?102>SXh00`2<S8`0Rh^;08^;R`0208Z:RP80RHV90P25QHD208>3P`80PH610P1n
OWh207alO080NGUi0P1eMGD2075aL@80KVi^0P1YJFT206ATI080H61P00<0Fe]K05EEE@1EEED00P1@
D50204Y:BP80AdM70P14A4@203lo?`80?Cdm0P0o?cl20451@@80@T920P14A4@204I6AP80AdM70P19
BDT204];B`0304a<C01>CTh0CTi>0080D51@0P1BDU8205=CD`80EEEE0P1GEeL205YJFP80Fe]K0P1M
GEd205mOG`80HF5Q0P1SHf<206EUI@80IfMW0P1XJ6P00`1ZJVX0K6a/06a/K00206i^KP80L71`0P1b
LW8207AdM080MWIf0P1gMgL207UiN@80Ng]k0P1mOGd207moO`80PH610P23Ph<208B4Q080QXJ600<0
R8R808Z:RP2:RXX00P2<S8`208f=S@80Shn?0P2ATI4209>CT`80UIFE5@3oool001<0oooo0P2HV9P2
09VIV@80Vi^K0P2LW9`209fMW@80WinO0P2PX:020:6QX@030:>SX`2TY:@0Y:BT0080YJFU0P2WYjL2
0:RXZ080ZJVY0P2ZZZX20:^[Z`80[:b/0P2][Jd20:n_[`80/;2`0P2a/K440;:b/P80/k>c00<0];Bd
0;Fe]@2e]KD00P2f][H40;Ng]`80^;Rh102i^KT20;Zj^P80^KVi0P2g]kL20;Bd]080/[:b0P2_[jl4
0:b/[0030:^[Z`2XZ:P0Z:RX0080YZJV0P2TY:@20::RXP80X:2P0P2NWYh209bLW080Vi^K0P2IVIT2
09FEU@80U9BD0P2ATI4208n?S`@0SXj>00<0S8b<08^;R`2;Rh/00P2:RXX208V9R@80QHF50P23Ph<2
0861P@80OWin0P1lO7`207UiN@80MGEe0P1aLG4206i^KP80JFUY0P1TI6@2061PH00305]KF`1EEED0
EEEE0080D51@0P1:BTX204M7A`80A4A40P0o?cl203dm?@80?clo0P11@D420492@P80A4A40P16ATH2
04M7A`80BDU90P1;Bd/00`1<C4`0CTi>04i>CP02051@D080DU9B0P1CDe<205EEE@80EeMG0P1JFUX2
05]KF`80GEeM0P1OGel2065QH@80Hf=S0P1UIFD206MWI`80J6QX00<0JVYZ06a/K01/K6`00P1^KVh2
071`L080LW9b0P1dM7@207IfMP80MgMg0P1iNGT207]kN`80OGem0P1oOgl20861P@80Ph>30P24Q8@2
08J6QP0308R8R02:RXX0RXZ:0080S8b<0P2=SHd208n?S`80TI6A0P2CTi<209FEUAD0oooo000C0?oo
o`80V9RH0P2IVIT209ZJVP80W9bL0P2MWId209jNWP80WinO0P2QXJ400`2RXZ80Xj>S0:>SX`020:BT
Y080YZJV0P2WYjL20:RXZ080ZJVY0P2ZZZX20:^[Z`80[:b/0P2][Jd20:j^[P80[jn_0P2`/;020;6a
/@<0/[:b0P2c/k<40;Bd]0@0]KFe0P2f][H40;Ng]`@0][Jf0P2e]KD20;:b/P80[Zj^0P2[Zj/20:VY
Z@030:RXZ02WYjL0YjNW0080Xj>S0P2QXJ4209nOW`80WIfM0P2KVi/209ZJVP80V9RH0P2FUYH209:B
TP80TI6A0P2?Shl208j>SP@0SHf=00<0S8b<08Z:RP2:RXX00P2:RXX208R8R080QXJ60P25QHD208>3
P`80P8200P1mOGd207UiN@80MGEe0P1aLG4206e]K@80J6QX0P1SHf<205iNGP0305UIF@1DE5@0E5AD
0080Cdm?0P1;Bd/204I6AP80ADE50P13@d<204A4A080ADE50P16ATH204M7A`80BDU90P1:BTX204a<
C080CDe=0P1?Cdl00`1ADE40DU9B059BDP0205ADE080EEEE0P1GEeL205UIF@80Fe]K0P1MGEd205mO
G`80H61P0P1RHV8206ATI080IFEU0P1WIfL206UYJ@80Jf][00<0KFe]06i^KP1^KVh00P1`L702079b
LP80M7Ad0P1eMGD207MgM`80NGUi0P1kNg/207emO@80OWin0P20P80208:2PP80Q8B40P25QHD208N7
Q`0308V9R@2;Rh/0Rh^;0080S8b<0P2>SXh2092@T080TI6A0P2CTi<209FEUAD0oooo000C0?ooo`80
V9RH0P2IVIT209ZJVP80W9bL0P2MWId209jNWP80WinO0P2QXJ400`2RXZ80Xj>S0:>SX`020:BTY080
YZJV0P2WYjL20:RXZ080ZJVY0P2ZZZX20:^[Z`80[:b/0P2][Jd20:j^[P80[jn_0P2`/;020;6a/@<0
/[:b0P2c/k<40;Bd]0@0]KFe0P2f][H40;Ng]`@0][Jf0P2e]KD20;:b/P80[Zj^0P2[Zj/20:VYZ@03
0:RXZ02WYjL0YjNW0080Xj>S0P2QXJ4209nOW`80WIfM0P2KVi/209ZJVP80V9RH0P2FUYH209:BTP80
TI6A0P2?Shl208j>SP@0SHf=00<0S8b<08Z:RP2:RXX00P2:RXX208R8R080QXJ60P25QHD208>3P`80
P8200P1mOGd207UiN@80MGEe0P1aLG4206e]K@80J6QX0P1SHf<205iNGP0305UIF@1DE5@0E5AD0080
Cdm?0P1;Bd/204I6AP80ADE50P13@d<204A4A080ADE50P16ATH204M7A`80BDU90P1:BTX204a<C080
CDe=0P1?Cdl00`1ADE40DU9B059BDP0205ADE080EEEE0P1GEeL205UIF@80Fe]K0P1MGEd205mOG`80
H61P0P1RHV8206ATI080IFEU0P1WIfL206UYJ@80Jf][00<0KFe]06i^KP1^KVh00P1`L702079bLP80
M7Ad0P1eMGD207MgM`80NGUi0P1kNg/207emO@80OWin0P20P80208:2PP80Q8B40P25QHD208N7Q`03
08V9R@2;Rh/0Rh^;0080S8b<0P2>SXh2092@T080TI6A0P2CTi<209FEUAD0oooo000C0?ooo`80V9RH
0P2IVIT209ZJVP80Vi^K0P2MWId209jNWP80WinO0P2PX:000`2QXJ40XZ:R0::RXP020:>SX`80YJFU
0P2VYZH20:NWY`80Z:RX0P2YZJT20:ZZZP@0Zj^[0P2/[:`20:f][@80[Zj^0P2_[jl30;2`/080/K6a
102b/[860;>c/`H0];Bd0P2c/k<20;Bd]080/;2`0P2_[jl20:^[Z`80YjNW00<0YZJV0:BTY02TY:@0
0P2QXJ4209nOW`80WYjN0P2KVi/209ZJVP80V9RH0P2FUYH209FEU@80Ti>C0P2BTY82096AT@80Shn?
102>SXh00`2<S8`0Rh^;08^;R`0208^;R`80RHV90P27QhL208J6QP80Ph>30P1oOgl207emO@80N7Qh
0P1dM7@206m_K`80Jf][0P1VIVH2065QH@80G5aL00<0FEUI05ADE01DE5@00P1?Cdl204];B`80BDU9
0P1:BTX204U9B@80BTY:101;Bd/204e=C@80CTi>0P1?Cdl2055AD@80DU9B0P1CDe<00`1EEED0EUIF
05IFEP0205QHF080FEUI0P1KFe/205aLG080GUiN0P1PH602069RHP80Hf=S0P1UIFD206MWI`80J6QX
0P1ZJVX206a/K080KFe]00<0Kfm_075aL@1aLG400P1bLW8207AdM080MWIf0P1gMgL207UiN@80Ng]k
0P1lO7`207inOP80P8200P22PX8208>3P`80QHF50P26QXH208R8R00308Z:RP2;Rh/0Rh^;0080SHf=
0P2>SXh2092@T080TY:B0P2CTi<209FEUAD0oooo000C0?ooo`80V9RH0P2IVIT209ZJVP80Vi^K0P2M
WId209jNWP80WinO0P2PX:000`2QXJ40XZ:R0::RXP020:>SX`80YJFU0P2VYZH20:NWY`80Z:RX0P2Y
ZJT20:ZZZP@0Zj^[0P2/[:`20:f][@80[Zj^0P2_[jl30;2`/080/K6a102b/[860;>c/`H0];Bd0P2c
/k<20;Bd]080/;2`0P2_[jl20:^[Z`80YjNW00<0YZJV0:BTY02TY:@00P2QXJ4209nOW`80WYjN0P2K
Vi/209ZJVP80V9RH0P2FUYH209FEU@80Ti>C0P2BTY82096AT@80Shn?102>SXh00`2<S8`0Rh^;08^;
R`0208^;R`80RHV90P27QhL208J6QP80Ph>30P1oOgl207emO@80N7Qh0P1dM7@206m_K`80Jf][0P1V
IVH2065QH@80G5aL00<0FEUI05ADE01DE5@00P1?Cdl204];B`80BDU90P1:BTX204U9B@80BTY:101;
Bd/204e=C@80CTi>0P1?Cdl2055AD@80DU9B0P1CDe<00`1EEED0EUIF05IFEP0205QHF080FEUI0P1K
Fe/205aLG080GUiN0P1PH602069RHP80Hf=S0P1UIFD206MWI`80J6QX0P1ZJVX206a/K080KFe]00<0
Kfm_075aL@1aLG400P1bLW8207AdM080MWIf0P1gMgL207UiN@80Ng]k0P1lO7`207inOP80P8200P22
PX8208>3P`80QHF50P26QXH208R8R00308Z:RP2;Rh/0Rh^;0080SHf=0P2>SXh2092@T080TY:B0P2C
Ti<209FEUAD0oooo000C0?ooo`80V9RH0P2IVIT209ZJVP80Vi^K0P2LW9`209fMW@80WYjN0P2OWil0
0`2PX:00XZ:R0::RXP020:>SX`80Y:BT0P2UYJD20:JVYP@0YjNW0P2XZ:P20:VYZ@80ZZZZ0P2[Zj/2
0:b/[0@0[Jf]0P2^[Zh30:n_[`H0/;2`302a/K420;2`/080[jn_0P2^[Zh20:^[Z`80YjNW00<0Y:BT
0::RXP2RXZ800P2PX:0209jNWP80WIfM0P2KVi/209VIV@80UiNG0P2FUYH209BDU080Ti>C0P2BTY82
096AT@80T92@102?Shl00`2>SXh0S8b<08b<S00208^;R`80RXZ:0P27QhL208F5Q@80PX:20P1nOWh2
07]kN`80MWIf0P1cLg<206e]K@80J6QX0P1UIFD2065QH@80GEeM00<0FEUI05ADE01DE5@00P1ADE4:
04m?C`80D51@0P1ADE42059BDP80De=C0P1DE5@205EEE@80EUIF0P1HF5P00`1IFET0FUYJ05YJFP02
05aLG080GEeM0P1OGel2061PH080HV9R0P1SHf<206EUI@80IVIV0P1XJ6P206UYJ@80Jf][0P1/K6`2
06i^KP80L71`00<0LG5a07=cL`1cLg<00P1dM7@207IfMP80N7Qh0P1iNGT207]kN`80O7al0P1nOWh2
07moO`80PH610P23Ph<208B4Q080QXJ60P27QhL208V9R@0308Z:RP2<S8`0S8b<0080SHf=0P2?Shl2
092@T080TY:B0P2CTi<209FEUAD0oooo000C0?ooo`80V9RH0P2IVIT209ZJVP80Vi^K0P2LW9`209fM
W@80WYjN0P2OWil00`2PX:00XZ:R0::RXP020:>SX`80Y:BT0P2UYJD20:JVYP@0YjNW0P2XZ:P20:VY
Z@80ZZZZ0P2[Zj/20:b/[0@0[Jf]0P2^[Zh30:n_[`H0/;2`302a/K420;2`/080[jn_0P2^[Zh20:^[
Z`80YjNW00<0Y:BT0::RXP2RXZ800P2PX:0209jNWP80WIfM0P2KVi/209VIV@80UiNG0P2FUYH209BD
U080Ti>C0P2BTY82096AT@80T92@102?Shl00`2>SXh0S8b<08b<S00208^;R`80RXZ:0P27QhL208F5
Q@80PX:20P1nOWh207]kN`80MWIf0P1cLg<206e]K@80J6QX0P1UIFD2065QH@80GEeM00<0FEUI05AD
E01DE5@00P1ADE4:04m?C`80D51@0P1ADE42059BDP80De=C0P1DE5@205EEE@80EUIF0P1HF5P00`1I
FET0FUYJ05YJFP0205aLG080GEeM0P1OGel2061PH080HV9R0P1SHf<206EUI@80IVIV0P1XJ6P206UY
J@80Jf][0P1/K6`206i^KP80L71`00<0LG5a07=cL`1cLg<00P1dM7@207IfMP80N7Qh0P1iNGT207]k
N`80O7al0P1nOWh207moO`80PH610P23Ph<208B4Q080QXJ60P27QhL208V9R@0308Z:RP2<S8`0S8b<
0080SHf=0P2?Shl2092@T080TY:B0P2CTi<209FEUAD0oooo000C0?ooo`80UiNG0P2IVIT209ZJVP80
Vi^K0P2LW9`209fMW@80WYjN0P2OWil00`2PX:00XJ6Q0:6QX@020::RXP80Xj>S102TY:@20:FUY@80
YZJV0P2WYjL20:RXZ0@0ZJVY0P2ZZZX20:^[Z`@0[:b/0`2][Jd60:j^[PP0[jn_102^[Zh20:f][@80
[:b/0P2[Zj/20:ZZZP80YZJV00<0YJFU0::RXP2RXZ800P2OWil209fMW@80Vi^K0P2JVYX209RHV080
UiNG0P2EUID209BDU0@0TY:B102ATI44092@T00308j>SP2<S8`0S8b<0080RXZ:0P29RHT208N7Q`80
Q8B40P20P80207alO080NGUi0P1dM7@2075aL@80Jf][0P1XJ6P206EUI@80HF5Q0P1MGEd00`1JFUX0
EeMG05MGE`0205IFEPH0EEEE0P1DE5@405EEE@80EUIF0P1GEeL205QHF080FEUI0P1JFUX205]KF`80
G5aL00<0GEeM05iNGP1NGUh00P1PH602065QH@80HV9R0P1SHf<206EUI@80IVIV0P1XJ6P206UYJ@80
Jf][0P1/K6`206e]K@80Kfm_0P1aLG42079bLP0307AdM01eMGD0MGEe0080MgMg0P1hN7P207UiN@80
Ng]k0P1mOGd207inOP80Ogmo0P21PH4208:2PP80Q8B40P26QXH208N7Q`80R8R80P2:RXX00`2;Rh/0
S8b<08b<S00208j>SP80Shn?0P2ATI4209:BTP80U9BD0P2EUIDE0?ooo`004`3oool209NGU`80VIVI
0P2JVYX209^KV`80W9bL0P2MWId209jNWP80WinO00<0X:2P0:6QX@2QXJ400P2RXZ820:>SX`@0Y:BT
0P2UYJD20:JVYP80YjNW0P2XZ:P40:VYZ@80ZZZZ0P2[Zj/40:b/[0<0[Jf]1P2^[Zh80:n_[`@0[Zj^
0P2][Jd20:b/[080Zj^[0P2ZZZX20:JVYP030:FUY@2RXZ80XZ:R0080WinO0P2MWId209^KV`80VYZJ
0P2HV9P209NGU`80UIFE0P2DU9@409:BTP@0TI6A102@T9000`2>SXh0S8b<08b<S00208Z:RP80RHV9
0P27QhL208B4Q080P8200P1lO7`207UiN@80M7Ad0P1aLG4206][J`80J6QX0P1UIFD2065QH@80GEeM
00<0FUYJ05MGE`1GEeL00P1FEUH605EEE@80E5AD101EEED205IFEP80EeMG0P1HF5P205UIF@80FUYJ
0P1KFe/205aLG00305eMG@1NGUh0GUiN0080H61P0P1QHF42069RHP80Hf=S0P1UIFD206IVIP80J6QX
0P1YJFT206][J`80K6a/0P1]KFd206m_K`80LG5a0P1bLW800`1dM7@0MGEe07EeM@0207MgM`80N7Qh
0P1iNGT207]kN`80OGem0P1nOWh207moO`80PH610P22PX8208B4Q080QXJ60P27QhL208R8R080RXZ:
00<0Rh^;08b<S02<S8`00P2>SXh208n?S`80TI6A0P2BTY8209BDU080UIFE5@3oool001<0oooo0P2G
UiL209RHV080VIVI0P2JVYX209^KV`80W9bL0P2MWId209jNWP0309nOW`2PX:00X:2P0080XJ6Q0P2R
XZ840:>SX`80Y:BT0P2UYJD20:JVYP@0YjNW0P2XZ:P40:VYZ@@0ZZZZ0`2[Zj/80:b/[0@0[Jf]102/
[:`40:^[Z`80ZZZZ0P2XZ:P20:NWY`80YJFU00<0Y:BT0:2PX02PX:000P2NWYh209fMW@80Vi^K0P2I
VIT209RHV080UYJF0P2EUID209BDU0@0TY:B0P2ATI44092@T080Shn?00<0SHf=08^;R`2;Rh/00P2:
RXX208N7Q`80QHF50P23Ph<207inOP80NWYj0P1hN7P207AdM080L71`0P1/K6`206QXJ080IVIV0P1R
HV82061PH00305mOG`1MGEd0GEeM0080G5aL0P1KFe/:05YJFP80Fe]K101LG5`205eMG@80GUiN0P1O
Gel2061PH003065QH@1RHV80HV9R0080Hf=S0P1UIFD206IVIP80IfMW0P1XJ6P206YZJP80Jf][0P1/
K6`206e]K@80Kfm_0P1`L702079bLP80Lg=c0P1eMGD00`1fMWH0MgMg07MgM`0207UiN@80NWYj0P1k
Ng/207emO@80OWin0P20P8020861P@80PX:20P24Q8@208F5Q@80QhN70P28R8P208V9R@80Rh^;00<0
S8b<08f=S@2=SHd00P2>SXh2092@T080TI6A0P2BTY8209BDU080UIFE5@3oool001<0oooo0P2GUiL2
09RHV080VIVI0P2JVYX209^KV`80W9bL0P2MWId209jNWP0309nOW`2PX:00X:2P0080XJ6Q0P2RXZ84
0:>SX`80Y:BT0P2UYJD20:JVYP@0YjNW0P2XZ:P40:VYZ@@0ZZZZ0`2[Zj/80:b/[0@0[Jf]102/[:`4
0:^[Z`80ZZZZ0P2XZ:P20:NWY`80YJFU00<0Y:BT0:2PX02PX:000P2NWYh209fMW@80Vi^K0P2IVIT2
09RHV080UYJF0P2EUID209BDU0@0TY:B0P2ATI44092@T080Shn?00<0SHf=08^;R`2;Rh/00P2:RXX2
08N7Q`80QHF50P23Ph<207inOP80NWYj0P1hN7P207AdM080L71`0P1/K6`206QXJ080IVIV0P1RHV82
061PH00305mOG`1MGEd0GEeM0080G5aL0P1KFe/:05YJFP80Fe]K101LG5`205eMG@80GUiN0P1OGel2
061PH003065QH@1RHV80HV9R0080Hf=S0P1UIFD206IVIP80IfMW0P1XJ6P206YZJP80Jf][0P1/K6`2
06e]K@80Kfm_0P1`L702079bLP80Lg=c0P1eMGD00`1fMWH0MgMg07MgM`0207UiN@80NWYj0P1kNg/2
07emO@80OWin0P20P8020861P@80PX:20P24Q8@208F5Q@80QhN70P28R8P208V9R@80Rh^;00<0S8b<
08f=S@2=SHd00P2>SXh2092@T080TI6A0P2BTY8209BDU080UIFE5@3oool001<0oooo0P2GUiL209RH
V080VIVI0P2JVYX209^KV`80W9bL0P2MWId309jNWP80WinO0P2PX:020:6QX@@0XZ:R0P2SXj<20:BT
Y0@0YJFU102VYZH20:NWY`@0Z:RX0`2YZJT:0:ZZZP80Zj^[1P2ZZZX40:VYZ@80Z:RX0P2WYjL20:FU
Y@80Y:BT00<0XZ:R0:2PX02PX:00102NWYh209^KV`80VYZJ0P2HV9P209FEU@80U9BD0P2CTi<209:B
TP80TI6A102@T90208n?S`80SXj>00<0SHf=08^;R`2;Rh/00P28R8P208J6QP80Q8B40P22PX8207in
OP80Ng]k0P1hN7P207AdM080L71`0P1/K6`206YZJP80J6QX0P1WIfL206EUI@0306=SH`1RHV80HV9R
0080HF5Q101PH60805mOG`@0H61P0P1QHF44069RHP80Hf=S0P1TI6@00`1UIFD0IVIV06IVIP0206MW
I`80J6QX0P1YJFT206][J`80K6a/0P1]KFd206i^KP80Kfm_0P1aLG42079bLP80Lg=c0P1eMGD207If
MP80MgMg00<0N7Qh07YjNP1jNWX00P1kNg/207alO080OGem0P1oOgl20820P080PH610P22PX8208B4
Q080QHF50P27QhL208R8R080RHV90P2:RXX208^;R`0308f=S@2>SXh0SXj>0080Shn?0P2@T90209:B
TP80Ti>C0P2DU9@209FEUAD0oooo000C0?ooo`80UiNG0P2HV9P209VIV@80VYZJ0P2KVi/209bLW080
WIfM0`2NWYh209nOW`80X:2P0P2QXJ440::RXP80Xj>S0P2TY:@40:FUY@@0YZJV0P2WYjL40:RXZ0<0
ZJVY2P2ZZZX20:^[Z`H0ZZZZ102YZJT20:RXZ080YjNW0P2UYJD20:BTY0030::RXP2PX:00X:2P00@0
WYjN0P2KVi/209ZJVP80V9RH0P2EUID209BDU080Ti>C0P2BTY82096AT@@0T92@0P2?Shl208j>SP03
08f=S@2;Rh/0Rh^;0080R8R80P26QXH208B4Q080PX:20P1nOWh207]kN`80N7Qh0P1dM7@2071`L080
K6a/0P1ZJVX206QXJ080IfMW0P1UIFD00`1SHf<0HV9R069RHP02065QH@@0H61P201OGel4061PH080
HF5Q101RHV8206=SH`80I6AT00<0IFEU06IVIP1VIVH00P1WIfL206QXJ080JFUY0P1[Jf/206a/K080
KFe]0P1^KVh206m_K`80LG5a0P1bLW8207=cL`80MGEe0P1fMWH207MgM`0307QhN01jNWX0NWYj0080
Ng]k0P1lO7`207emO@80Ogmo0P20P8020861P@80PX:20P24Q8@208F5Q@80QhN70P28R8P208V9R@80
RXZ:0P2;Rh/00`2=SHd0SXj>08j>SP0208n?S`80T92@0P2BTY8209>CT`80U9BD0P2EUIDE0?ooo`00
4`3oool209NGU`80V9RH0P2IVIT209ZJVP@0Vi^K0P2LW9`209fMW@<0WYjN0P2OWil20:2PX0@0XJ6Q
0P2RXZ840:>SX`80Y:BT102UYJD40:JVYP@0YjNW2@2XZ:P40:VYZ@H0Z:RX102WYjL20:JVYP80YJFU
0P2TY:@20::RXP030:6QX@2PX:00X:2P0080WYjN0P2MWId209^KV`80VYZJ0P2GUiL209FEU@80U9BD
0P2BTY84096AT@@0T92@0P2?Shl208j>SP0308f=S@2:RXX0RXZ:0080R8R80P26QXH208B4Q080PX:2
0P1oOgl207]kN`80N7Qh0P1eMGD2079bLP80L71`0P1^KVh206a/K080Jf][0P1ZJVX00`1XJ6P0IfMW
06MWI`0206IVIP@0IFEU201TI6@606EUI@80IVIV101WIfL206QXJ00306UYJ@1ZJVX0JVYZ0080Jf][
0P1/K6`206e]K@80KVi^0P1_Kfl2071`L080LG5a0P1bLW8207AdM080MGEe0P1fMWH207MgM`80N7Qh
0P1iNGT00`1kNg/0O7al07alO00207emO@80OWin0P1oOgl20861P@80PX:20P23Ph<208B4Q080QHF5
0P27QhL208R8R080RHV90P2:RXX208^;R`80S8b<00<0SHf=08j>SP2>SXh00P2@T902096AT@80TY:B
0P2CTi<209BDU080UIFE5@3oool001<0oooo0P2GUiL209RHV080VIVI0P2JVYX409^KV`80W9bL0P2M
WId309jNWP80WinO0P2PX:040:6QX@80XZ:R102SXj<20:BTY0@0YJFU102VYZH40:NWY`T0Z:RX102Y
ZJT60:RXZ0@0YjNW0P2VYZH20:FUY@80Y:BT0P2RXZ800`2QXJ40X:2P0:2PX00209jNWP80WIfM0P2K
Vi/209ZJVP80UiNG0P2EUID209BDU080TY:B102ATI44092@T080Shn?0P2>SXh00`2=SHd0RXZ:08Z:
RP0208R8R080QXJ60P24Q8@208:2PP80Ogmo0P1kNg/207QhN080MGEe0P1bLW82071`L080KVi^0P1/
K6`206][J`80JVYZ00<0J6QX06MWI`1WIfL00P1VIVH406EUI@P0I6AT1P1UIFD206IVIP@0IfMW0P1X
J6P00`1YJFT0JVYZ06YZJP0206][J`80K6a/0P1]KFd206i^KP80Kfm_0P1`L702075aL@80LW9b0P1d
M7@207EeM@80MWIf0P1gMgL207QhN080NGUi00<0Ng]k07alO01lO7`00P1mOGd207inOP80Ogmo0P21
PH4208:2PP80Ph>30P24Q8@208F5Q@80QhN70P28R8P208V9R@80RXZ:0P2;Rh/208b<S00308f=S@2>
SXh0SXj>0080T92@0P2ATI4209:BTP80Ti>C0P2DU9@209FEUAD0oooo000C0?ooo`80UiNG0P2HV9P4
09VIV@80VYZJ0P2KVi/409bLW00309fMW@2NWYh0WYjN0080WYjN0P2OWil40:2PX080XJ6Q102RXZ84
0:>SX`80Y:BT1P2UYJD70:JVYPX0YjNW102VYZH40:FUY@80Y:BT0P2SXj<20::RXP80XJ6Q00<0X:2P
09nOW`2OWil00P2MWId209bLW080VYZJ0P2IVIT209NGU`80UIFE0P2DU9@209>CT`80TY:B0P2ATI44
092@T080Shn?0P2>SXh00`2<S8`0RXZ:08Z:RP0208R8R080QXJ60P24Q8@208:2PP80Ogmo0P1mOGd2
07YjNP80N7Qh0P1fMWH207AdM080LW9b0P1`L70206m_K`80KVi^00<0KFe]06a/K01/K6`00P1[Jf/2
06YZJPh0JFUY101ZJVX406][J`80K6a/00<0KFe]06i^KP1^KVh00P1_Kfl2071`L0@0LG5a0P1bLW82
07=cL`@0MGEe0P1fMWH207QhN080NGUi0P1jNWX207]kN`80O7al00<0OGem07inOP1nOWh00P1oOgl2
0820P080PH610P23Ph<208B4Q080QHF51026QXH208R8R080RHV90P2:RXX208^;R`80S8b<0P2=SHd0
0`2>SXh0Shn?08n?S`02092@T080TI6A0P2BTY8209>CT`80U9BD0P2EUIDE0?ooo`004`3oool209NG
U`80V9RH102IVIT209ZJVP80Vi^K102LW9`00`2MWId0WYjN09jNWP0209jNWP80WinO102PX:020:6Q
X@@0XZ:R102SXj<20:BTY0H0YJFU1`2VYZH:0:NWY`@0YZJV102UYJD20:BTY080Xj>S0P2RXZ820:6Q
X@030:2PX02OWil0WinO0080WIfM0P2LW9`209ZJVP80VIVI0P2GUiL209FEU@80U9BD0P2CTi<209:B
TP80TI6A102@T90208n?S`80SXj>00<0S8b<08Z:RP2:RXX00P28R8P208J6QP80Q8B40P22PX8207mo
O`80OGem0P1jNWX207QhN080MWIf0P1dM7@2079bLP80L71`0P1_Kfl206i^KP0306e]K@1/K6`0K6a/
0080Jf][0P1ZJVX>06UYJ@@0JVYZ101[Jf/206a/K00306e]K@1^KVh0KVi^0080Kfm_0P1`L704075a
L@80LW9b0P1cLg<407EeM@80MWIf0P1hN7P207UiN@80NWYj0P1kNg/207alO00307emO@1nOWh0OWin
0080Ogmo0P20P8020861P@80Ph>30P24Q8@208F5Q@@0QXJ60P28R8P208V9R@80RXZ:0P2;Rh/208b<
S080SHf=00<0SXj>08n?S`2?Shl00P2@T902096AT@80TY:B0P2CTi<209BDU080UIFE5@3oool001<0
oooo0P2GUiL409RHV080VIVI102JVYX209^KV`<0W9bL0P2MWId409jNWP@0WinO102PX:020:6QX@H0
XZ:R102SXj<50:BTY0h0YJFU1P2TY:@40:>SX`80XZ:R0P2QXJ420:2PX00309nOW`2MWId0WIfM0080
W9bL0P2KVi/209ZJVP80VIVI0P2GUiL209JFUP80U9BD0P2CTi<409:BTP80TI6A0P2@T90208n?S`80
SXj>00<0S8b<08^;R`2;Rh/00P29RHT208R8R080QXJ60P23Ph<20861P@80Ogmo0P1mOGd207]kN`80
NGUi0P1gMgL207EeM@80M7Ad0P1cLg<2079bLP03075aL@1`L700L71`0080Kfm_101^KVh806e]K@P0
KVi^0P1_Kfl4071`L003075aL@1bLW80LW9b00@0Lg=c0P1dM7@207EeM@80MWIf0P1gMgL207QhN0@0
NGUi0P1jNWX207]kN`80O7al0P1mOGd207inOP0307moO`20P800P8200080PH610P22PX8208>3P`@0
QHF50P26QXH208N7Q`80R8R80P29RHT208Z:RP80Rh^;0P2<S8`208f=S@80SXj>00<0Shn?092@T02@
T9000P2ATI4409:BTP80U9BD102EUIDE0?ooo`004`3oool209NGU`@0V9RH0P2IVIT409ZJVP80Vi^K
0`2LW9`209fMW@@0WYjN102OWil40:2PX080XJ6Q1P2RXZ840:>SX`D0Y:BT3P2UYJD60:BTY0@0Xj>S
0P2RXZ820:6QX@80X:2P00<0WinO09fMW@2MWId00P2LW9`209^KV`80VYZJ0P2IVIT209NGU`80UYJF
0P2DU9@209>CT`@0TY:B0P2ATI42092@T080Shn?0P2>SXh00`2<S8`0Rh^;08^;R`0208V9R@80R8R8
0P26QXH208>3P`80PH610P1oOgl207emO@80Ng]k0P1iNGT207MgM`80MGEe0P1dM7@207=cL`80LW9b
00<0LG5a071`L01`L7000P1_Kfl406i^KPP0KFe]201^KVh206m_K`@0L71`00<0LG5a079bLP1bLW80
101cLg<207AdM080MGEe0P1fMWH207MgM`80N7Qh101iNGT207YjNP80Ng]k0P1lO7`207emO@80OWin
00<0Ogmo0820P020P8000P21PH4208:2PP80Ph>31025QHD208J6QP80QhN70P28R8P208V9R@80RXZ:
0P2;Rh/208b<S080SHf=0P2>SXh00`2?Shl0T92@092@T002096AT@@0TY:B0P2DU9@409FEUAD0oooo
000C0?ooo`80UiNG102HV9P409VIV@80VYZJ102KVi/309bLW0@0WIfM102NWYh409nOW`@0X:2P102Q
XJ460::RXQD0Xj>S102RXZ820:6QX@80X:2P0P2OWil309jNWP80WIfM0P2LW9`209^KV`80VYZJ0P2H
V9P209NGU`80UYJF0P2EUID209BDU080Ti>C0P2BTY82096AT@80T92@0P2?Shl208j>SP0308f=S@2<
S8`0S8b<0080RXZ:0P29RHT208N7Q`80QHF50P23Ph<20861P@80P8200P1nOWh207alO080NWYj0P1i
NGT207QhN080MgMg0P1fMWH00`1eMGD0M7Ad07AdM00207AdM080Lg=c401bLW8407=cL`@0M7Ad00<0
MGEe07IfMP1fMWH00P1fMWH207MgM`@0N7Qh0P1iNGT207YjNP80Ng]k101lO7`207emO@80OWin0P1o
Ogl20820P080PH6100<0PX:208>3P`23Ph<00P23Ph<208B4Q080QHF50P26QXH208N7Q`80R8R81029
RHT208Z:RP80Rh^;102=SHd208j>SP80Shn?0`2@T902096AT@80TY:B0P2CTi<209BDU080UIFE0P2F
UYHE0?ooo`004`3oool209NGU`@0V9RH102IVIT209ZJVP@0Vi^K0`2LW9`409fMW@@0WYjN102OWil4
0:2PX0@0XJ6Q1P2RXZ8E0:>SX`@0XZ:R0P2QXJ420:2PX080WinO0`2NWYh209fMW@80W9bL0P2KVi/2
09ZJVP80V9RH0P2GUiL209JFUP80UIFE0P2DU9@209>CT`80TY:B0P2ATI42092@T080Shn?0P2>SXh0
0`2=SHd0S8b<08b<S00208Z:RP80RHV90P27QhL208F5Q@80Ph>30P21PH420820P080OWin0P1lO7`2
07YjNP80NGUi0P1hN7P207MgM`80MWIf00<0MGEe07AdM01dM7@00P1dM7@207=cLa00LW9b101cLg<4
07AdM00307EeM@1fMWH0MWIf0080MWIf0P1gMgL407QhN080NGUi0P1jNWX207]kN`@0O7al0P1mOGd2
07inOP80Ogmo0P20P8020861P@0308:2PP23Ph<0Ph>30080Ph>30P24Q8@208F5Q@80QXJ60P27QhL2
08R8R0@0RHV90P2:RXX208^;R`@0SHf=0P2>SXh208n?S`<0T92@0P2ATI4209:BTP80Ti>C0P2DU9@2
09FEU@80UYJF5@3oool001<0oooo102GUiL209RHV0@0VIVI102JVYX309^KV`@0W9bL1P2MWId409jN
WP@0WinO202PX:050:6QX@`0XZ:R202QXJ420:2PX0@0WinO0P2NWYh309fMW@80W9bL0P2KVi/209ZJ
VP80VIVI0P2HV9P209NGU`80UYJF0P2EUID209BDU080Ti>C102BTY82096AT@80T92@0P2?Shl00`2>
SXh0SHf=08f=S@0208^;R`80RXZ:0P29RHT208N7Q`80QHF50P24Q8@208:2PP80PH610P1oOgl207in
OP80OGem0P1lO7`407YjNP0307UiN@1hN7P0N7Qh0080N7Qh0P1gMgL>07IfMPH0MgMg101hN7P307Ui
N@@0NWYj0P1kNg/407alO080OGem0P1nOWh407moO`80P8201021PH4208:2PP80Ph>300<0Q8B408F5
Q@25QHD00P26QXH408N7Q`80R8R80P29RHT408Z:RP80Rh^;102<S8`408j>SP80Shn?0`2@T902096A
T@80TY:B102CTi<209BDU080UIFE0P2FUYHE0?ooo`004`3oool409NGU`@0V9RH102IVIT409ZJVPD0
Vi^K102LW9`609fMW@H0WYjN202OWilE0:2PX0@0WinO102NWYh409fMW@0309bLW02KVi/0Vi^K00@0
VYZJ0P2IVIT209RHV080UiNG0P2FUYH209FEU@@0U9BD0P2CTi<209:BTP@0TI6A0P2@T9000`2?Shl0
SXj>08j>SP0208f=S@80Rh^;0P2:RXX208V9R@80QhN70P26QXH208F5Q@80Q8B40P22PX820861P@80
P8200P1oOgl207inOP<0OGem101lO7`607]kN`P0NWYj201kNg/407alO0D0OGem101nOWh207moO`@0
P8200P21PH4408:2PP80Ph>31024Q8@208F5Q@<0QXJ60P27QhL208R8R0@0RHV90P2:RXX408^;R`@0
S8b<0P2=SHd408j>SP80Shn?0P2@T903096AT@@0TY:B0P2CTi<209BDU0@0UIFE0P2FUYHE0?ooo`00
4`3oool409NGU`@0V9RH102IVIT409ZJVPD0Vi^K102LW9`609fMW@H0WYjN202OWilE0:2PX0@0WinO
102NWYh409fMW@0309bLW02KVi/0Vi^K00@0VYZJ0P2IVIT209RHV080UiNG0P2FUYH209FEU@@0U9BD
0P2CTi<209:BTP@0TI6A0P2@T9000`2?Shl0SXj>08j>SP0208f=S@80Rh^;0P2:RXX208V9R@80QhN7
0P26QXH208F5Q@80Q8B40P22PX820861P@80P8200P1oOgl207inOP<0OGem101lO7`607]kN`P0NWYj
201kNg/407alO0D0OGem101nOWh207moO`@0P8200P21PH4408:2PP80Ph>31024Q8@208F5Q@<0QXJ6
0P27QhL208R8R0@0RHV90P2:RXX408^;R`@0S8b<0P2=SHd408j>SP80Shn?0P2@T903096AT@@0TY:B
0P2CTi<209BDU0@0UIFE0P2FUYHE0?ooo`004`3oool409NGU`H0V9RH102IVIT509ZJVPH0Vi^K1P2L
W9`809fMW@H0WYjN3`2OWil809jNWPH0WIfM102LW9`00`2KVi/0VYZJ09ZJVP0209ZJVP80VIVI102H
V9P209NGU`80UYJF102EUID209BDU080Ti>C102BTY84096AT@03092@T02?Shl0Shn?0080SXj>0P2=
SHd208b<S080Rh^;0P2:RXX408R8R080QXJ60P25QHD208B4Q0@0Ph>30P22PX830861P@@0P820201o
Ogl207inOP`0Ogmo1@20P8040861P@H0PX:21023Ph<208B4Q0@0QHF51026QXH408N7Q`80R8R80`29
RHT208Z:RP@0Rh^;102<S8`408f=S@@0SXj>102?Shl2092@T0@0TI6A0`2BTY8209>CT`@0U9BD102E
UID209JFUQD0oooo000C0?ooo`@0UiNG1P2HV9P409VIV@D0VYZJ1P2KVi/609bLW0P0WIfM1P2NWYh?
09nOW`P0WYjN1P2MWId409bLW00309^KV`2JVYX0VYZJ0080VYZJ0P2IVIT409RHV080UiNG0P2FUYH4
09FEU@80U9BD0P2CTi<409:BTP@0TI6A00<0T92@08n?S`2?Shl00P2>SXh208f=S@80S8b<0P2;Rh/2
08Z:RP@0R8R80P26QXH208F5Q@80Q8B41023Ph<208:2PP<0PH611020P80807moO`80OWin301oOgl5
0820P0@0PH611P22PX8408>3P`80Q8B41025QHD408J6QP@0QhN70P28R8P308V9R@80RXZ:102;Rh/4
08b<S0@0SHf=102>SXh408n?S`80T92@102ATI4309:BTP80Ti>C102DU9@409FEU@80UYJF5@3oool0
01<0oooo1P2GUiL609RHV0D0VIVI202JVYX609^KV`X0W9bL6@2MWId809bLW0@0Vi^K0`2JVYX209VI
V@@0V9RH102GUiL409JFUP80UIFE102DU9@409>CT`80TY:B0P2ATI43092@T080Shn?102>SXh208f=
S@80S8b<0P2;Rh/208Z:RP80RHV90P28R8P408N7Q`80QXJ61025QHD508B4Q0@0Ph>30P22PX8208>3
P`80PX:23023Ph<708B4Q0H0QHF51026QXH408N7Q`H0R8R81029RHT408Z:RP0308^;R`2<S8`0S8b<
0080S8b<1P2=SHd408j>SP@0Shn?102@T904096AT@@0TY:B0`2CTi<409BDU0H0UIFE0P2FUYHE0?oo
o`004`3oool609NGU`H0V9RH1@2IVIT809ZJVPH0Vi^K2P2LW9`I09fMW@P0W9bL102KVi/309ZJVP80
VIVI102HV9P409NGU`@0UYJF0P2EUID409BDU0@0Ti>C0P2BTY82096AT@<0T92@0P2?Shl408j>SP80
SHf=0P2<S8`208^;R`80RXZ:0P29RHT208R8R0@0QhN70P26QXH408F5Q@D0Q8B41023Ph<208:2PP80
Ph>30P22PX8<08>3P`L0Q8B41P25QHD408J6QP@0QhN71P28R8P408V9R@@0RXZ:00<0Rh^;08b<S02<
S8`00P2<S8`608f=S@@0SXj>102?Shl4092@T0@0TI6A102BTY8309>CT`@0U9BD1P2EUID209JFUQD0
oooo000C0?ooo`P0UiNG202HV9P709VIV@X0VYZJ2P2KVi/E09bLW0X0Vi^K102JVYX309VIV@@0V9RH
1P2GUiL409JFUP@0UIFE102DU9@409>CT`<0TY:B102ATI42092@T0@0Shn?0P2>SXh208f=S@@0S8b<
0P2;Rh/408Z:RP@0RHV91@28R8PL08N7Q`L0R8R81029RHT608Z:RPH0Rh^;1P2<S8`308f=S@@0SXj>
1P2?Shl4092@T0P0TI6A102BTY8509>CT`@0U9BD1P2EUID409JFUQD0oooo000C0?ooo`P0UiNG202H
V9P709VIV@X0VYZJ2P2KVi/E09bLW0X0Vi^K102JVYX309VIV@@0V9RH1P2GUiL409JFUP@0UIFE102D
U9@409>CT`<0TY:B102ATI42092@T0@0Shn?0P2>SXh208f=S@@0S8b<0P2;Rh/408Z:RP@0RHV91@28
R8PL08N7Q`L0R8R81029RHT608Z:RPH0Rh^;1P2<S8`308f=S@@0SXj>1P2?Shl4092@T0P0TI6A102B
TY8509>CT`@0U9BD1P2EUID409JFUQD0oooo000C0?ooo`X0UiNG2@2HV9P>09VIVBL0VYZJ1`2IVIT6
09RHV0H0UiNG1P2FUYH409FEU@H0U9BD0`2CTi<609:BTP@0TI6A0P2@T90408n?S`@0SXj>1P2=SHd5
08b<S240Rh^;202<S8`808f=S@H0SXj>1P2?Shl7092@T0H0TI6A202BTY8609>CT`L0U9BD202EUID4
09JFUQD0oooo000C0?ooo`X0UiNG2@2HV9P>09VIVBL0VYZJ1`2IVIT609RHV0H0UiNG1P2FUYH409FE
U@H0U9BD0`2CTi<609:BTP@0TI6A0P2@T90408n?S`@0SXj>1P2=SHd508b<S240Rh^;202<S8`808f=
S@H0SXj>1P2?Shl7092@T0H0TI6A202BTY8609>CT`L0U9BD202EUID409JFUQD0oooo000C0?oooa00
UiNG5@2HV9PU09VIV@D0V9RH302GUiL809JFUPH0UIFE2@2DU9@609>CT`@0TY:B202ATI46092@T0d0
Shn?0P2>SXh608n?S`80SXj>4@2?Shl<092@T0X0TI6A2@2BTY8609>CT`80U9BD0P2CTi<:09BDU0T0
UIFE2P2FUYHE0?ooo`004`3oool@09NGUaD0V9RH9@2IVIT509RHV0`0UiNG202FUYH609FEU@T0U9BD
1P2CTi<409:BTPP0TI6A1P2@T90=08n?S`80SXj>1P2?Shl208j>SQ40Shn?302@T90:096AT@T0TY:B
1P2CTi<209BDU080Ti>C2P2DU9@909FEU@X0UYJF5@3oool001<0oooo0P2FUYHS09NGUb<0V9RH3`2G
UiL209JFUP80UiNG3P2FUYH?09FEU@H0U9BD0P2CTi<409BDU140Ti>C102BTY8609>CT`80TY:B7`2C
Ti<E09BDU1@0UIFE3`2FUYHE0?ooo`004`3oool209JFUR<0UiNG8`2HV9P?09NGU`80UYJF0P2GUiL>
09JFUPl0UIFE1P2DU9@209>CT`@0U9BD4@2CTi<409:BTPH0Ti>C0P2BTY8O09>CTaD0U9BD502EUID?
09JFUQD0oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o
0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o
0?ooob40oooo002H0?ooo`900000QP3oool009X0oooo00=000000?ooo`3oool0P`3oool007/0oooo
0d0000030?ooo`=000000P3oool00d000000oooo0?ooo`050?ooo`=000000P3oool2@00000<0oooo
0d0000050?ooo`03@000003oool0oooo07d0oooo001k0?ooo`03@000003oool0oooo00@0oooo00I0
00000?ooo`3ooom000000?oood0000050?ooo`06@000003oool0oooo@000003ooom00000103oool0
14000000oooo0?oood0000250?ooo`00O03oool014000000oooo0?ooo`3oool4@00000040?oood00
0000oooo@00000D0oooo00E000000?ooo`3ooom000000?ooo`03@0000080oooo00A000000?ooo`3o
oom00000Q@3oool007`0oooo00M000000?ooo`3oool0oooo@000003ooom000000080oooo00=00000
0?oood0000001P3oool3@00000040?oood0000100000@00000<0oooo0d0000250?ooo`00N`3oool0
0d000000oooo@00000030?ooo`9000000P3oool00d000000oooo@00000080?ooo`03@000003oool0
oooo08d0oooo001l0?ooo`03@000003oool0oooo00<0oooo00E000000?ooo`3oool0oooo@0000008
0?ooo`900000S`3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3o
ool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3o
ool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.0250052, -0.0250052, 
  0.00365857, 0.00365857}, {{6.8125, 280.125}, {280.125, 
  6.8125}} -> {-10.161, -6.11446, 0.516914, 0.516914}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0238095 0.952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0238095 0.97619 0.97619 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00751202 0.0192308 0.00751202 [
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(300) show
81.000000 12.812500 moveto
(deg) show
99.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(.) show
105.000000 12.812500 moveto
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
128 string
128 128 8 [128 0 0 128 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
B0B0B0B0B0B0B0B0B0B0B0B0AFAFAFAFB0B0B0B0B0B0B1B2
B0B1B1B2B2B2B3B3B3B3B4B4B4B4B4B4B4B4B4B4B4B4B4B4
B4B4B4B4B4B4B4B4B4B4B4B4B4B4B4B3B3B4B3B3B3B3B3B4
B4B4B4B4B4B4B4B4B4B4B4B4B4B4B4B3B3B3B3B3B3B3B3B3
B3B3B3B3B3B3B3B3B2B3B2B2B2B2B2B1B1B0B0AFAFAFAEAE
AEAFAFAFAFAFAFB0
B0B0B0B1B0B0B0B0B0B0AFAFAEAEAFAFB0B0B0B1B1B2B2B2
B0B2B3B3B4B5B6B6B7B7B8B8B8B8B9B9B9B9B9B9B9B9B8B8
B7B7B8B8B8B8B8B8B8B8B8B8B8B8B7B7B7B7B7B7B7B7B7B7
B7B7B7B7B8B8B8B8B8B8B8B8B9B8B7B7B7B6B7B6B6B6B6B6
B6B6B6B5B5B6B5B5B5B5B5B5B4B4B3B3B2B1B0AEAEADADAC
ACAEAFAEAEAEAFB0
B0B0B0B0B0B0B0B0B0B0AFAFAEAEAEAFAFB0B0B1B2B2B2B1
B2B4B4B5B6B8B8B9BABBBCBCBCBDBDBEBEBDBDBDBDBCBCBB
BBBBBBBBBBBBBBBCBCBCBCBCBBBBBBBABABABABABABBBBBB
BBBBBBBBBBBBBBBBBCBCBCBCBDBCBAB7B9BABABAB9B8B9B9
B9B9B9B9B8B8B8B8B8B7B7B6B6B6B5B4B3B2B0AEADACACAC
ADADADADADAEAEAF
B0B0B0B0B0B0B0B0B0B0B0B0AFAEADAEAFB0B0B1B2B2B3B3
B2B3B5B7B8B9BBBCBEBFC0C0C1C1C2C2C2C2C2C1C1BFBFBE
BEBDBDBEBEBEBEBFBFBFBFBFBFBFBEBEBEBEBEBEBEBFBFBF
BFBFBFBFBFBFBFBFBFC0C0C0C0C0BFBDBCBCBDBCBCBCBCBB
BCBCBBBBBBBBBBBBBABAB9B9B8B8B7B6B4B2B0AEACACACAC
ADADADACACADAEAF
B0B0B0B0B1B1B1B1B1B1B1B0B0AFAFAEAEAFB0B1B1B2B3B3
B4B5B6B8BABCBEBFC1C2C4C5C6C6C6C6C6C6C6C6C4C3C2C1
C0C0BFC0C0C1C1C2C2C2C2C2C2C2C2C2C3C3C3C3C3C3C3C3
C3C3C3C3C3C3C3C3C3C3C4C3C3C3C3C2C1C0BFC0BFBFBFBF
BFBFBFBEBEBEBEBDBDBDBCBBBBBAB9B7B5B3B1AEADADADAD
ADACACABABABADAE
B0B0B0B1B1B1B1B1B2B2B2B2B1B0B0B0AFAFB0B1B2B2B3B5
B6B6B7BABCBEC0C2C5C6C8C9CACBCCCCCCCBCAC9C8C7C6C4
C3C3C2C2C2C3C4C4C4C4C5C5C5C5C5C6C6C6C6C7C8C8C8C8
C8C8C8C8C8C8C8C8C8C8C8C8C7C7C7C6C6C4C2C3C3C3C3C3
C3C3C3C2C2C1C1C1C0BFBFBEBDBCBBBAB8B5B2B0B0B0AFAF
AEACACAAA9ABADAE
B0B0B0B1B1B1B2B2B2B2B3B2B2B2B2B2B1B1B1B1B2B3B4B5
B7B8BABCBFC2C4C6C8CBCDCECFD0D0D1D0CFCECDCCCAC9C8
C7C6C5C5C5C5C6C6C6C7C7C8C8C9C9C9C9CACACBCCCCCCCC
CCCDCDCCCCCCCCCCCCCCCCCCCBCBCBCACAC9C7C6C6C7C8C8
C8C7C7C6C6C5C5C4C3C3C2C1C0BFBDBBB9B6B2B2B1B1AFAE
ADACABA9A9ABADAE
B0B0B1B1B2B2B2B3B3B3B4B4B4B4B4B4B4B4B4B3B4B5B6B7
B9BBBDBFC3C5C8CACDCFD1D3D4D5D5D4D3D2D1D0CFCECDCB
CAC9C9C8C8C8C8C8C9C9C9C9CACBCBCCCDCDCECFCFD0D0D0
D0D1D1D1D1D1D1D0D0D0D0D0CFCFCECECECDCDCCCCCCCCCC
CCCBCBCACAC9C8C7C7C6C5C4C3C1BEBBB8B4B3B3B2B1AEAD
ACABAAA9A9ABADAE
B0B0B1B1B2B2B3B4B4B4B4B5B5B5B6B6B6B6B6B6B6B7B8B9
BBBDBFC1C3C6CBCFD1D4D6D7D8D9D8D8D7D6D4D3D2D1D0CF
CECDCCCBCBCACACACACACBCBCCCCCCCDCECFD0D1D2D2D3D3
D3D4D4D4D4D4D4D4D4D3D3D2D2D1D1D1D1D1D1D1D0CFCFD0
D0CFCFCECDCDCCCBCBCAC8C7C5C1BDB8B5B4B2B1AFAEACAA
A9A9A8A8A9ABACAE
B0B1B1B2B3B3B4B4B5B5B6B6B6B7B7B8B8B9B9B9BABBBCBE
BFC1C4C6C8CACFD4D6D9DBDDDDDDDDDDDCDBD9D8D6D5D3D2
D1D0CFCECECECDCDCDCDCDCDCECECECFD0D0D1D1D2D2D3D4
D4D4D5D5D5D5D5D5D5D4D4D4D4D4D3D3D3D3D3D3D2D2D1D0
D0D2D2D1D0D0CFCFCECECCC9C4BEB9B6B3B1B0AFADABAAA9
A8A8A7A7A8AAACAE
B1B1B2B2B3B4B5B5B5B6B6B7B7B8B9BABABBBCBCBDBEC0C1
C3C6C8CACDD0D3D7DBDFE1E2E3E3E2E1E0DEDDDBD9D8D6D5
D4D3D2D1D1D0D0CFCFCFCFD0D0D1D1D2D2D3D4D4D4D5D5D6
D6D7D7D7D7D8D8D8D8D7D7D7D7D7D7D7D6D6D6D5D5D5D4D4
D2D0CED1D2D2D2D1CFCBC6C2BEBAB7B4B2AEADADABAAA8A6
A6A5A4A6A7AAACAE
B0B1B2B3B3B4B5B5B6B7B7B8B9BABBBBBCBDBEBFC0C2C3C5
C7C9CCCED1D4D7D9DEE2E5E8EAE9E8E7E5E3E1DFDDDBD9D7
D6D5D4D4D3D3D3D2D2D2D2D3D3D3D4D5D5D6D6D7D8D8D9D9
D9DADADBDBDBDBDBDBDBDBDBDBDBDADADAD9D9D9D8D8D7D7
D6D5D4D3D1CFD0CEC9C5C1BDB9B7B5B2AFACADABA9A7A5A4
A4A2A3A4A6A9ABAD
B1B1B2B3B4B5B6B6B7B8B9BABABBBCBDBEBFC1C2C3C5C7C9
CBCDCFD1D4D7DADDE0E5E9EDF0F0EEECEAE7E5E2E0DEDBDA
D8D7D7D6D6D5D5D5D4D4D4D5D6D6D7D7D8D8D9DADADBDCDD
DDDDDEDEDEDFDFDFDFDEDEDEDEDEDDDDDDDDDDDCDCDBDBDA
D9D8D7D6D5D2CDC7C3BFBBB8B5B2AFADABAAA9A7A5A4A2A2
A1A1A2A3A6A8AAAD
B1B2B3B4B4B5B6B7B8B9BABBBCBDBEBFC0C2C3C5C6C8CACC
CED0D2D5D8DBDDE0E3E8ECF0F2F5F5F2EFECE9E6E3E0DEDC
DBD9D9D8D8D7D7D7D7D7D7D8D9D9DADADBDBDCDDDDDEDFE0
E0E1E1E1E2E2E2E2E2E2E2E2E2E1E1E0E0E0E0DFDFDEDDDC
DBDAD8D5D1CBC6C1BDB9B7B4B0AEABAAA8A7A6A3A1A09F9F
9F9FA1A3A5A8ABAD
B1B2B3B4B5B6B7B8B9BABBBCBDBFC0C1C3C4C6C7C9CBCDCF
D1D3D5D8DBDEE1E4E8ECEFF2F4F6F9F8F4F0ECE8E5E2E0DE
DCDBDADADAD9D9D9D9D9DADADBDBDCDDDEDEDFDFE0E1E2E3
E3E4E4E5E5E6E6E6E6E6E5E5E5E4E4E4E3E3E2E2E2E1DFDE
DCD9D6D1CAC5C1BDB8B4B1AEACAAA8A7A5A3A09E9C9C9D9D
9C9EA0A3A5A8AAAD
B1B2B3B4B5B6B8B9BABBBCBDBFC0C2C3C5C6C7C9CBCDCFD2
D4D6D9DBDEE1E5E8EBEEF1F3F5F7F8F9F7F3EFEBE7E4E1DF
DDDDDCDBDBDBDBDBDBDBDCDCDDDEDFDFE0E1E2E2E3E4E5E6
E6E7E8E8E8E9E9E9E9E9E9E9E8E8E7E7E7E6E6E5E4E3E1DE
DCD8D3CCC4C0BCB8B4B0ACA9A8A7A4A2A09E9C9B99999A99
9B9DA0A2A4A7AAAD
B1B2B3B4B5B7B8B9BABCBEBFC0C2C3C5C6C8CACCCDD0D2D4
D7D9DCDFE2E5E8EBEEF1F4F5F7F7F7F7F9F7F2EDE9E5E2E0
DFDEDDDDDCDCDCDCDDDDDDDEDFDFE0E1E2E3E4E5E6E7E8E8
E9EAEBEBECECECECECECECECEBEBEAEAE9E8E6E5E4E2E0DD
D9D3CBC4C0BCB7B2AFACAAA7A4A19F9D9B9A989898989797
999C9FA1A4A7AAAD
B1B2B3B4B6B7B8BABBBDBFC0C2C3C5C6C8CACCCED0D2D4D6
D9DCDEE1E4E8EBEFF2F5F6F6F7F7F6F6F6F7F4EEE9E5E2E0
DFDEDDDDDDDDDDDDDEDEDFE0E1E1E2E3E4E5E6E7E8E9EAEB
EBECEDEEEFEFEFEFEEEEEEEEEEEDECEBEAE9E7E5E3E1DDD8
D2CAC3BEBBB8B3AFACAAA7A3A09D9A989795959494949496
989A9DA0A3A6A9AD
B1B2B4B5B6B8B9BBBCBEBFC1C3C4C6C8C9CBCED0D2D4D6D9
DBDEE1E4E7EAEEF1F4F7F7F7F7F6F5F4F4F2F2EEE8E4E2E0
DFDEDDDDDDDDDEDEDFE0E0E1E2E3E4E5E6E7E8E9EBEBECED
EEEFF0F0F1F1F2F1F1F1F1F0F0EFEEECEBE9E7E5E2DDD8D1
CAC4BEBBB7B3AFABA8A4A19E9B9896949392929191929495
979A9DA0A3A7AAAD
B1B2B4B6B7B9BABBBDBFC1C2C3C5C8CACBCDCFD2D4D6D9DB
DEE0E3E6EAEDF0F4F7F9F9F8F7F5F3F2F1EEEBE7E6E3E0DF
DEDDDDDDDDDEDEDFE0E1E2E2E3E4E5E6E7E9EAEBEDEDEEEF
F0F1F2F3F3F4F4F3F2F2F2F2F2F0EFEDEBE8E5E1DCD6D0C9
C4BFBAB7B3AFABA8A4A19E9B98959391908F8F8E8F909194
96999DA0A3A6A9AD
B1B3B4B6B8B9BBBCBEC0C1C3C5C7C8CBCDCFD2D4D6D8DBDD
E0E3E6E9ECF0F3F6FAFBF9F8F6F4F2F0EDEAE7E6E4E0DEDD
DCDCDCDDDDDEDFE0E1E1E2E3E5E6E7E8E9EAEBEDEEEFF0F1
F2F3F4F5F5F5F5F4F3F4F5F4F2F0EEECE9E5E1DCD5CEC8C3
BDB8B5B2AFABA7A5A29F9B989693908E8D8D8C8C8D8E9093
969A9DA0A3A6A9AD
B1B3B5B6B8B9BBBDBEC0C2C4C6C8CACCCED1D3D5D8DADDDF
E2E5E8EBEFF2F5F9FBFBFAF8F6F3F1EEEAE6E4E2DFDDDCDB
DBDBDCDDDDDEDFE0E1E2E3E4E6E7E8E9EAECEDEEEFF0F1F3
F4F5F5F6F7F6F5F5F5F6F5F2F1EFEDEBE6E0DBD5CFC9C4BF
BAB6B2AEABA8A4A19D9B9795928F8C8C8B8A8A8A8C8E9093
96999CA0A3A6A9AD
B2B3B5B6B8BABCBDBFC1C3C5C7C9CBCED0D2D4D7D9DCDEE1
E4E7EAEDF0F4F7FBFCFCFAF8F6F3F0ECE7E3E1DFDAD9D9DA
DADADBDCDCDDDFE0E1E3E4E5E6E8E9EAECEDEEEFF1F2F3F4
F5F6F7F7F7F7F6F6F8F7F5F2F0EEEAE6E0D9D4CEC9C4C0BB
B6B2AEABA6A29F9D9A9895928F8C8A89888787898B8E9093
96999DA0A3A6A9AD
B2B3B5B7B9BBBDBEC0C2C4C6C8CACDCFD1D4D6D8DBDDE0E3
E6E9ECEFF3F6F9FCFCFCF9F7F4F1EEE9E5E2DFDBD6D6D6D7
D8D8D9DADBDDDEDFE1E3E4E5E7E9EAEBECEEEFF0F1F2F3F4
F5F7F7F8F7F7F7F8F7F5F3F0EEEAE6DFD9D3CDC7C3BEB9B5
B1AEABA7A29E9C9A9794918E8B888786858587898B8E9094
96999DA0A3A6A9AD
B2B4B5B7B9BBBDBFC1C3C5C7CACCCED0D3D5D7DADDDFE2E5
E8EBEEF2F5F8FBFDFCFBF9F6F3EFEBE6E4E1DDD8D3D3D4D5
D6D6D7D9DBDCDDDFE1E2E4E6E7E9EAEBEDEEEFF0F1F3F4F4
F5F6F7F7F6F6F6F7F6F3F1EEEAE5DFDAD3CDC8C2BDB8B5B2
AEABA7A39F9C989693908D8B88868584838486888B8D9093
96999DA0A3A6AAAD
B2B4B6B8BABCBEC0C2C4C6C8CBCDCFD2D4D6D9DCDEE1E4E7
EAEDF0F3F6F9FCFEFDFBF8F5F1EEE9E5E3DFD9D4CFD0D1D2
D3D4D6D7D8DADCDEDFE1E3E5E6E8EAEBECEDEFF0F1F2F3F4
F5F5F6F6F5F5F6F5F3F0EDEAE5E0DBD5CEC8C2BDB8B4B0AE
ABA7A3A09C999694908D8B8785848282838587888A8D9093
96999DA0A3A6A9AD
B2B4B6B8BABDBFC1C3C5C7C9CCCED1D3D6D8DBDEE0E3E6E9
ECEFF2F5F8FBFEFEFDFBF8F4F0ECE7E3DFDBD5D0CCCDCECF
D0D2D3D5D6D8DADCDEDFE1E3E5E7E9EAEBEDEEEFF0F1F2F3
F4F5F5F4F4F4F3F1EFECE9E4DFDBD5CEC8C3BEB9B4B0ACA9
A6A3A09C999693908D8C898583818181838486888A8D9093
96999DA0A3A6A9AD
B2B4B7B9BBBDBFC1C3C6C8CBCDCFD2D4D7DADDDFE2E4E7EA
EDF0F3F7FAFDFFFEFCFAF6F1EEE9E4E0DDD7D2CDC8C9CACC
CDCFD0D2D4D6D7D9DBDDDFE1E3E5E7E9EAECEDEEEFF0F1F2
F3F3F3F2F2F2F1EEEAE7E3DFDBD5CEC8C3BEB9B4AFABA7A5
A29F9B999693908E8C898682807F7F80828486888A8D9093
969A9DA0A3A6A9AD
B2B4B6B9BBBDC0C2C4C6C9CBCED0D3D6D8DBDEE0E3E6E9EC
EFF2F5F8FBFEFFFEFCF8F5F0EBE6E2DED9D2CCC8C4C5C6C7
C9CBCDCFD1D2D4D6D8DADCDEE0E2E4E6E8E9EBECEDEEEFF0
F1F1F1F0EFEEECE9E6E2DFDCD7D0C9C2BDB9B5B1ACA8A4A0
9D9A979593908E8C8A86827F7E7D7E80818385878B8E9093
979A9DA0A3A6A9AD
B2B4B7B9BBBEC0C2C4C7CACCCFD1D4D7DADCDFE2E5E7EAEE
F1F3F7FAFDFFFFFDFBF7F2EDE8E3DFD9D3CCC6C2BEC0C1C3
C5C7C9CBCCCED0D2D4D6D9DBDDDFE1E3E5E6E8EAEBECEDEE
EEEDEDECEBEAE7E3E1DEDBD6CFC8C1BDBAB6B2ADA8A4A09E
9A969492908D8C8986837F7C7B7C7E7F818285878A8D9094
979A9DA0A3A6AAAD
B2B5B7BABCBEC1C3C5C8CBCDD0D2D5D8DBDDE0E3E6E9ECEF
F2F5F8FBFEFFFFFDF9F5EFEAE5E0DBD4CDC6C0BCB9BABCBE
C0C3C5C6C8CACCCED0D2D4D6D9DBDDDFE1E3E5E6E8E9EAEA
EBEBEAE8E7E5E1DEDCD9D4CEC7C0BCB8B4B1ADA9A5A19E9B
979492908D8A8885827E7C7A7A7B7D7E808285878A8D9094
979A9DA0A3A6A9AD
B3B5B7BABCBEC1C3C6C8CBCED1D3D6D9DBDEE1E4E7EAEDF0
F4F7F9FCFFFFFEFBF7F2ECE6E1DBD6CEC6BFBAB5B2B4B7BA
BCBFC1C3C5C7C9CACCCDCFD1D3D6D8DADCDFE1E3E4E5E6E6
E6E6E5E4E2DEDAD9D6D2CDC5C0BCB7B4B0ADA9A5A19E9A96
9492908E8B8886827F7C7A78797B7C7D7F8285888B8E9194
979A9DA0A3A6AAAD
B2B5B7BABCBEC1C4C6C9CCCED1D4D7DADDDFE2E5E8EBEEF2
F5F8FAFEFFFFFDF9F4F0EAE4DDD7D0C6BFB8B2ADACB0B4B8
BBBDC0C1C3C5C6C8C9CBCCCDCECFD2D4D7D9DBDDDFE0E1E2
E2E2E1DFDCD7D3D2CFCBC5BFBAB6B2AFACA8A5A19E9B9794
92908E8A8886837F7C7A7878797B7C7D7F8285888B8E9194
979A9DA0A3A6A9AC
B3B5B7BABCBFC2C4C7CACCCFD2D5D8DBDEE0E3E6E9ECF0F3
F6F9FCFEFFFEFBF7F2ECE5DFD9D2C9BFB8B0A8A5A9AFB3B7
BABDBFC1C3C5C6C7C8C9CACACBCCCCCED1D3D6D8D9DBDCDD
DEDDDCDAD6D1CDCBC8C4BFB9B4B0ADAAA7A3A09D9A979491
8F8E8B888684807D7B79767779797A7D7F8285888B8E9194
979A9DA0A3A7AAAD
B2B5B7BABDBFC2C5C8CBCDD0D3D6D9DCDEE1E4E7EAEDF1F4
F7FAFDFFFFFDF9F5F0E9E2DBD4CCC2B9B1A6A2A5ABB0B4B8
BBBDC0C2C4C5C6C7C7C7C8C8C9C9C9CACBCDD0D2D4D6D7D8
D9D8D7D4CFCCC7C3BFBBB7B3AFABA8A6A3A09D9A98959390
8E8B888683817D7B7977767777787A7D7F8285888B8E9194
979A9DA0A3A6A9AD
B2B5B8BABDC0C2C5C8CBCED1D4D7D9DCDFE2E5E8EBEFF2F5
F8FBFEFFFEFBF7F2ECE5DED7CFC6BBB3A9A4A6A9ADB1B5B9
BCBFC1C2C4C6C7C7C7C8C8C7C7C7C7C7C7C8C9CBCED0D2D3
D3D3D1CECAC5C1BEB9B5B0ABA8A5A2A19F9D9B989593918E
8B898784817E7B797776757576787A7D7F8285888B8E9194
979A9DA0A3A6AAAD
B3B5B8BBBDC0C3C6C9CBCED1D4D7DADDE0E3E6EAEDF0F4F7
FAFCFEFEFDF9F5EFE9E1DAD2C9BEB4ABA4A4A7ABAFB3B7BB
BEC1C3C4C6C7C7C8C8C7C6C6C5C5C4C4C4C4C4C6C7CACCCD
CECECCCAC5C1BDB8B2ACA9A7A5A3A19F9C9A989694918F8C
898784817E7B7A787674737476787A7D7F8285888B8E9194
979A9DA0A3A7AAAD
B2B5B8BBBDC0C3C6C9CCCFD2D5D8DADEE1E4E7EBEEF1F4F8
FBFDFEFEFCF8F3ECE5DCD5CCC2B6ACA4A2A6A9ADB1B5B9BD
C0C2C4C6C7C8C9C9C8C8C7C5C4C3C2C1C1C1C1C1C1C3C6C7
C8C8C7C4C1BEB9B4AFAAA5A1A19F9D9B9A989694918E8C8A
8884807E7C7978767372717375787A7C7F8285888B8D9194
979A9DA0A3A6A9AD
B2B5B8BBBEC1C3C6C9CCCFD2D5D8DBDEE2E5E9ECEFF2F6F9
FCFEFEFEFAF6F0E9E1D8D0C6BBB0A5A2A4A7ABAFB3B7BBBE
C1C3C5C7C8C9C9C8C8C7C6C4C2C1BFBFBEBEBEBDBDBDBEC0
C2C2C2C0BDBAB6B0ACA6A19F9D9C9A98969593908E8C8A88
85817F7B787776747271727375777A7C7F8285888B8E9194
979A9DA0A3A6A9AD
B3B6B8BBBEC1C4C6C9CCD0D2D6D9DCDFE3E6E9EDF0F4F7FA
FCFEFEFCF8F3ECE5DCD3CABEB3A7A1A4A6A9ACB0B4B8BCBE
C0C2C3C5C6C6C7C7C6C5C4C2C0BEBDBCBBBBBABABABABABB
BDBDBDBCBAB7B3AFABA5A19D999797959492908E8C8B8886
84807D7A78767472717072737577797C7F8285878A8D9093
969A9DA0A3A6AAAD
B3B6B8BBBEC1C4C7CACDD0D3D6DADDE0E3E7EAEEF1F5F8FB
FDFEFEFBF7F0E9E0D7CEC3B8ADA5A4A5A7AAADB1B5B9BCBD
BEBFBFC0C1C2C3C4C4C3C1BFBDBBBAB9B8B7B7B7B7B7B7B6
B6B8B8B8B6B4B1ADA7A4A09C9995939392908F8D8B898785
827F7C7A777573706F7071737577797C7F8284878A8D9093
96999DA0A3A6AAAD
B3B6B9BCBEC1C4C7CACDD1D4D7DADEE1E4E8EBEEF2F6F9FC
FEFFFEFAF4EDE5DCD2C8BCB1A5A1A4A5A7AAADB2B5B6B6B5
B6B9BABBBBBDBDBDBCBCBCBBB9B8B6B5B5B4B4B4B4B3B3B2
B1B1B3B3B2B1B0ACA7A4A19E9A9592908F8F8D8A89888683
817E7B79777572706E6E70727476797C7F8184878A8D9093
969A9DA0A3A6A9AD
B3B6B9BCBFC2C5C8CBCED1D4D7DBDEE1E5E8ECEFF3F7FBFE
FFFFFDF8F1EAE1D7CDC2B6AAA3A3A3A5A7A9ACAFB1B1B2B4
B6B6B6B8BABAB9B8B7B6B6B6B5B3B2B2B1B1B1B1B1B0B0AF
AEADAEAEAFAEACA9A8A5A19E9A97928F8E8C8A8A88868482
807D7A787572706F6D6E70727476797B7E8184878A8D9093
96999CA0A3A6A9AD
B3B6B9BCBFC2C5C8CBCED1D4D7DBDEE2E5E9ECF0F4F8FBFE
FFFDFAF5EEE5DCD2C7BBAFA4A1A3A3A4A6A8AAACACADADAD
AEAFB0B0B1B2B1B0B1B0AFAFAFAFAEAEAEAEAFAEAEAEADAC
ACABABACACAAAAA9A7A3A29F9C98948F8C8A898885848381
7E7B797673706F6D6C6E70727376787B7E8184878A8D9093
96999DA0A3A6A9AD
B3B6B9BCBFC2C5C8CBCED1D4D8DBDEE2E6E9EDF1F5F9FCFE
FEFCF8F2E9E0D7CCC0B5A8A2A3A3A3A3A4A4A2A2A2A1A2A3
A3A4A4A5A5A4A3A4A3A2A1A1A2A4A8AAABACACACABABABAA
AAA9A9A8A8A8A8A6A5A4A19F9D9996918D8A88868483817F
7C7A787573706E6B6B6D6F717375787B7E8083868A8D9093
96999DA0A3A6A9AD
B3B6B9BCBFC2C4C8CBCED1D4D8DBDFE2E6EAEEF2F6F9FCFE
FDFAF4EDE5DCD2C7BCB0A7A4A3A3A3A2A2A1A09E9B999999
9A9B9C9C9B9B9B9B9C9C9E9FA0A2A5A7A8A9A9A9AAA9A9A9
A8A7A7A6A6A5A4A4A4A3A2A09D9A97938E8A86848382807D
7B7A7774726F6E6B6B6D6E707274777A7D808386898C9093
96999C9FA3A6A9AD
B3B6B8BCBFC2C5C8CBCED1D4D8DCDFE3E6EAEEF2F6FAFDFD
FCF7F1EAE1D8CDC2B7ABA4A4A3A2A2A1A1A09F9E9D9C9B9B
9C9D9E9E9E9F9E9E9E9E9E9F9FA1A3A4A5A6A7A7A8A8A8A7
A7A6A6A5A5A3A2A2A1A09F9E9D9995928F8A8684827F7E7D
7B787472716E6C696A6C6E6F7174777A7D808386898C8F92
96999C9FA3A6A9AD
B3B6B9BCBFC2C5C8CBCED1D5D8DBDFE3E7EAEEF2F6FAFCFD
F9F3ECE5DCD2C8BEB4A9A5A4A3A2A1A1A0A09F9E9E9E9D9E
9E9FA0A0A0A0A09F9F9E9E9E9FA0A1A2A4A4A5A5A6A6A6A5
A5A5A4A4A2A1A2A2A1A1A09E9A9896938F8B8884807E7C7A
787573716F6D6A696A6B6D6F717476797C808385898C8F92
96999CA0A3A6A9AC
B3B6B9BBBEC1C4C8CBCED1D5D8DBDFE3E6EAEEF3F7FAFBF9
F5EFE8E0D7CEC4BAB0A8A5A3A2A1A1A0A09F9F9F9F9F9F9F
A0A1A2A2A2A2A1A0A09F9F9E9F9FA0A0A1A2A3A4A4A4A4A4
A4A4A4A3A2A1A09F9F9E9D9B999896928F8C8682807D7B78
7572716F6D6B6867686A6B6D707376797C7F8285888C8F92
96999C9FA2A6A9AD
B3B6B8BBBEC1C5C8CBCED2D5D8DCDFE3E7EAEEF3F7FAFAF7
F2EBE4DBD2C8BFB6ABA4A4A2A1A1A0A09F9F9F9F9F9FA0A1
A1A2A3A3A3A3A2A1A0A09F9F9E9E9FA0A1A1A1A2A2A2A3A2
A2A2A2A2A1A09F9E9E9D9C9A989693918D8886827F7B7976
74716F6C6A68656768696A6C6F7275797C7F8285888B8F92
95989C9FA3A6A9AD
B3B6B8BBBEC1C5C8CBCED1D5D8DCDFE2E6EAEEF2F6F8F8F4
EFE8E0D7CEC5BBB2A7A2A2A1A0A0A09F9F9F9F9FA0A0A1A1
A1A1A2A2A3A3A2A1A1A09F9E9E9E9E9F9F9FA0A0A0A1A1A1
A1A1A1A09F9F9F9F9D9C9A989593908E8B8985807C7A7774
72706E6A6865646667696A6C6F7275787B7E8185888B8E92
95989C9FA2A6A9AD
B3B6B9BCBFC2C5C8CBCED1D5D8DBDFE2E6EAEEF2F6F7F5F0
EAE3DBD2C8C0B8AFA5A2A1A0A09F9F9F9F9F9F9F9FA1A1A0
9E9FA0A1A2A1A0A1A09F9E9D9D9D9E9E9E9F9F9F9F9F9F9F
9F9F9F9F9E9D9D9B9B99989593908E8B8987817E7B787674
716E6B68666464646566686B6E7174787B7E8184888B8E91
95989C9FA2A6A9AD
B3B6B9BCBFC2C4C7CBCED1D4D8DBDFE2E6EAEEF2F5F5F1EB
E5DDD5CDC4BCB3A9A1A09F9F9E9F9F9F9F9F9F9F9F9E9C9C
9D9E9E9D9B9B9C9C9D9D9D9C9C9D9D9E9E9E9E9E9E9E9E9E
9E9E9D9C9C9B9B9998969492908E8B8887827E7C78767371
6E6B6866656464636363676A6D7174777A7E8184878B8E91
95989B9FA2A6A9AC
B2B5B8BBBEC1C4C7CACED1D4D7DBDEE2E6E9EDF1F3F2EEE8
E1D8D0C7C0B8AEA49E9E9E9E9E9E9E9E9F9F9F9F9F9E9D9C
9D9D9D9D9C9C9C9C9B9B9B9B9C9C9D9D9D9E9E9E9D9D9D9C
9C9C9C9B9A9999969492908E8C8A8885827D7B787574716E
6B6966646261605F606366696D7073777A7D8184878A8E91
95989B9FA2A5A9AC
B3B5B8BBBEC1C4C7CACDD0D4D7DADEE1E5E9ECF0F2EFE9E2
DBD3CBC3BCB3A99F9B9C9C9D9D9E9E9F9F9F9F9F9F9E9E9D
9E9E9E9E9D9D9D9C9B9A9A9B9C9C9D9D9D9D9D9D9D9C9C9B
9A9A9A9998979593918E8E8B888684817D79777472706E6B
696764615F5F5E5D5E6265696C6F73767A7D8083878A8E91
94989B9FA2A5A9AC
B3B6B8BBBEC1C4C7CACDD0D3D7DADDE1E4E8ECF0F0EBE6DF
D7CEC7BFB8AFA59C9B9B9C9D9D9E9F9F9F9F9F9F9F9F9F9F
9F9F9F9F9F9E9D9C9B9A9A9B9C9C9D9D9D9D9D9C9C9C9B9A
99989897969492908E8C89878582807C797673716F6C6B6A
6764615D5C5D5B5B5E6165686C6F7275797C8083868A8D91
94989B9FA2A5A9AC
B3B6B8BBBEC1C4C6C9CCCFD2D6D9DDE0E3E7EAEDECE7E1D8
D0C9C2BBB2A89E98999A9B9C9E9F9FA0A0A0A0A0A0A09F9F
9FA0A09F9E9D9C9C9B9A9B9C9C9D9D9E9E9D9D9D9C9B9A9A
999796959492908E8A88878582807C7875716F6D6B6A6967
65625F5C5A5857595D6064676A6E7175787C7F83868A8D91
94979B9EA2A5A9AC
B2B5B8BBBEC0C3C6C9CCCFD2D5D8DCDFE3E6E9EBE8E3DBD3
CCC5BDB4AAA0969397999B9D9E9FA0A0A1A1A1A1A0A0A09F
9F9F9F9F9E9D9C9C9B9B9C9C9D9E9E9E9E9E9E9D9D9B9A99
9897959492908E8B888684817E7C7975726E6B6A69686865
635F5C58575656595C6063666A6D7174787B7F8286898D90
94979B9EA2A5A9AC
B3B5B8BBBDC0C3C6C9CCCFD2D5D8DBDEE2E5E9EAE5DFD7CF
C7C0B8AFA497919497999C9D9FA0A1A2A2A2A2A2A1A0A09F
9F9F9F9F9E9D9D9D9D9D9D9E9E9F9FA0A09F9F9E9D9B9A99
97969492918F8C898582807E7C7975726F6B686867676663
615C5956545455585C5F6266696D7074777B7F8286898D90
94979A9EA2A5A9AC
B2B5B8BABDC0C2C5C8CBCED1D4D7DADDE0E4E9E8E2DBD2CB
C3BBB2A89D949495989B9D9EA0A2A3A3A3A3A3A3A2A1A1A0
A09F9F9F9F9E9E9E9E9F9FA0A0A1A1A1A1A1A09F9E9C9B99
98969492908E8B898582807D7A7773706C68666666656461
5E595553525254585B5E6265696C7073777A7E8185898C90
93979A9EA2A5A9AC
B2B5B7BABDBFC2C5C8CACDD0D3D6D9DCE0E3E5E2DCD6CDC6
BEB6ADA3989395979A9C9EA0A2A4A4A5A5A5A4A4A3A2A1A0
A0A0A09F9F9F9F9FA0A0A1A2A3A3A4A4A4A3A2A1A09E9C9A
98969492908D8B8885827F7C7975726E6B6765656462605E
5A5553514F5154575A5E6165686C6F73767A7E8185888C8F
93969A9EA1A5A9AC
B2B5B7BABDBFC2C4C7CACDCFD2D5D8DBDEE1E3DED8D0CAC3
BBB2A89D949396999B9EA0A2A4A5A6A7A8A7A6A6A4A3A2A1
A09F9F9FA0A0A0A1A2A2A3A4A5A5A6A6A6A5A5A3A19F9D9B
989694918F8C898784817E7B7774706D6A65646362615F5C
5853504E4D4F5356595D6064676B6F7276797D8184888C8F
93969A9EA1A5A9AC
B2B5B7B9BCBFC1C4C7C9CCCFD2D4D7DBDEE2E2DBD5CDC5BE
B7AEA4999497999B9DA0A2A4A6A8A9AAAAA9A8A7A5A3A2A1
A09F9F9FA0A0A1A2A3A4A5A6A7A8A9A9A9A9A7A5A3A19E9B
999694918F8C898683817D7A76726F6B6764636260605D5A
55504C4A4B4E5155585C5F63676A6E7275797D8084888B8F
93969A9DA1A5A9AC
B2B4B7B9BCBEC1C3C6C8CBCED1D4D7D9DCE0DDD6D1CAC3BC
B4AAA19A999A9B9D9FA1A4A6A9AAABACACABA9A8A5A3A2A0
9F9E9E9FA0A1A2A3A4A5A5A7A8AAACACACABAAA7A5A29F9C
9A9794918F8C898683807C7975716D69666261605F5D5956
514D4947484C5054575B5F62666A6E7175797C8084878B8F
92969A9DA1A5A8AC
B2B4B7B9BBBEC0C2C5C8CACDD0D3D6D8DBDEDAD5CEC7C1B9
B1A69D999C9C9D9FA1A4A6A9ABADAEAEADADAAA8A5A3A19F
9E9D9D9E9FA0A1A2A4A5A7A8AAACADAEAEAEACAAA7A3A09D
9A9794928F8C8986827E7B7774706C6864615F5E5D5A5452
4D494645474B4F52565A5E6266696D7174787C8083878B8E
92969A9DA1A5A8AC
B2B4B6B8BBBDBFC2C4C7C9CCCFD1D4D7D9DAD6D3CDC6BEB7
ADA49E9E9E9D9EA0A2A5A8ABADAFB0B0AFADAAA7A4A19F9D
9C9B9C9C9D9FA0A2A3A5A7A9ABACAEB0B0AEACA9A7A3A09D
9A9794928F8C8986827D7975726E6A66625F5D5C59554F4E
4A45444445494D5155595D6165686C7074787C7F83878A8E
9296999DA1A5A8AC
B2B4B6B8BABDBFC1C4C6C8CBCDD0D3D6DADAD4D1CBC4BCB4
AAA19D9F9E9E9FA1A3A6AAADADABABADAEABA7A5A39F9C9A
9999999A9B9C9DA0A2A7A9A9A8A9ACAEACABA9A8A5A29F9C
989694918F8C8985817D7875716C68645F5C5A5854514C4A
4540404144484C5054585C6064686C7074777B7F83878A8E
9296999DA1A5A8AC
B2B4B6B8BABCBEC0C2C5C7CACDCFD2D5D7D5D2CDC8C1B9B2
AAA3A09F9E9D9FA1A3A6A9AAA7A6A8A8A6A4A29F9C9A9997
9696979898999B9D9FA0A1A1A2A7A9A7A5A5A3A2A19E9C99
969492908E8B8884807C79756F6965615D595754504C4847
413E3E3E42474B4F53575B5F63676B6F73777B7F82868A8E
9295999DA1A5A8AC
B2B3B5B7B9BBBDBFC2C4C6C9CBCED1D3D3D2D1CCC6BEB7AF
A7A1A2A19F9E9EA0A2A4A5A6A5A4A49F9F9C9A9896949291
92939494959597989A9B9B9DA1A3A1A2A09F9C9D9B979695
9392908F8D8A87837F7A76716B67635E595654504B484443
3E3C3B3C41454A4E52565B5F63676B6F73767A7E82868A8E
9295999DA1A5A8AC
B2B3B5B7B9BBBDBFC1C3C5C8CACDD0D5D6D3CEC9C2BBB5AE
A7A3A3A19E9D9C9D9D9D9D9B9B9E9E9B968F8E8C8B8A8B8C
8E8F90919192929394959798999C9B99959595938F8E8F8F
8F8F8E8C8B8986827D78736D67625F5B56524F4C48433F3E
3A39383B4044494D51565A5E62666A6E72767A7E82868A8E
9295999DA1A4A8AC
B1B3B5B6B8BABCBEC0C2C4C6C9CBCED2D3D1CEC8C0BAB4AE
A8A4A3A09D9B9A9997959290908F8D8A8886848282848688
8A8C8D8E8E8E8E8E8F8F9091928F8B898988888684858789
8A8A8B8A8886837F7A76706B65605C57524E4B47433F3B3A
3736363A3E43484C5155595D62666A6E72767A7E8286898D
9195999DA1A4A8AC
B1B3B4B6B7B9BBBDBEC0C3C5C7CACCCDCED0CDC6BFB9B3AC
A7A5A3A09D9A989693908C888583817F7D7D7E7E7F818385
88898A8B8B8B8C8C8C8C8B8A888784817E7C7B7C7E808285
868888878583807C78746F69635D57534E4A47433E3B3837
343233383D42474B5054595D6165696E72767A7E8285898D
9195999DA1A4A8AC
B1B3B4B5B7B8BABBBDBFC1C3C6C8CACCCFCEC9C2BCB5B0AB
A7A4A29F9B989694928F8B8885838281807F7E7C7C7E8183
8587898989898888888A8A898784807E7C7B7C7D7F818384
8686858483807D7975716C66605B554F4A47433F3B383534
313033383D41464B4F54585C6165696D7175797D8185898D
9195999DA1A4A8AC
B1B2B3B5B6B7B9BABCBDBFC1C4C6C9CBCDC8C3BDB7B1ADA8
A5A3A09D99969492918E8C898786837F7B7875767A7D8083
858687888887868583828283838382807F7F7F8081828384
84838281807D7A76736F69635D57504945413F3B38353432
2F2F32373C41454A4F53585C6065696D7175797D8185898D
9195999DA0A4A8AC
B1B2B3B4B5B6B7B9BABCBEC0C2C4C9CAC9C3BDB6B2AEAAA6
A3A19E9A969391908F8E8C8A88837C76737375777A7D8083
8586878787868584817E7B79797B7E808182828283838382
807F7E7D7C7A77736F6B655F59544E47413E3B3734323131
2D2D32363B40454A4E53575C6064696D7175797D8185898D
9195999DA0A4A8AC
B1B2B2B3B4B5B6B7B9BABBBDBFC2C6C8C7BEB7B1ADA9A6A3
A09D9A9793908E8B888786847F7A76767677787A7D7F8183
8586868686868583817F7C7A77767576787B7D7E7E7D7C7C
7C7C7C7B797673706D68625E58524A423D3A3633302F2E2C
292C31363B4044494E52575B6064686D7175797D8185898D
9195999DA0A4A8AC
B1B1B2B3B3B4B5B6B7B8B9BABCBEC0C1BEB8B1ADA9A5A29F
9C9A9693908D8C8A8784807D7B7A79797A7A7C7D7F818384
868687878787868483807E7C7A7979797877767778797A7A
7A7A7A797774706D6965605B544C443C3935312F2D2B2A27
262B30353A3F44494D52575B5F64686C7175797D8185898D
9195999DA0A4A8AC
B0B1B1B2B2B3B4B4B5B5B6B7B9BABCBDB9B3ADAAA6A29F9C
999793918D8B8A888684817F7D7C7C7D7D7D7F8081838485
87878888888786858482817F7D7C7C7B7B7A7A7A7A7A7A7A
7A79787674726F6B66615C564F47403834312D2C2A282723
242A2F34393F43484D52565B5F64686C7075797D8185898D
9195999DA0A4A8AC
B0B0B1B1B1B2B2B2B3B3B4B4B5B6B6B6B2AEABA8A39F9C99
9794908E8B89888785848281807F7F7F7F80818283858687
888889898989888786858382807F7E7E7D7C7C7B7B7A7A79
79787675736F6D69656159524C453D35312D292826242320
23292E34393E43484D52565B5F64686C7075797D8185898D
9195999DA0A4A8AC
B0B0B0B0B0B1B1B1B1B1B1B1B1B1B1B1AEABA8A5A19D9A97
93908C8A8887878684838282818181818283848586878889
898A8B8B8B8A898987868584838281807F7E7D7C7C7B7A79
79787674716E6B68635D5650494139322E29262422201E1D
22282E33393E43484D51565B5F64686C7075797D8185898D
9195999DA0A4A8AC
B0B0B0AFAFAFAFAFAFAFAEAEAEADADADA9A6A39F9D9A9793
908D8A878685858484838383828283838485868788898A8B
8B8C8C8C8C8B8B8A898887868583828281807F7E7D7B7A79
787675726F6C6965605A544E453D352E2B2824201D1B191C
22282E33393E43484D51565B5F64686C7075797D8185898D
9195999DA0A4A8AC
B0AFAFAFAEAEAEADADACACABAAAAA9A8A4A19E9C9A979491
8D8A8785848483838383848484848585868788898A8B8C8C
8D8E8E8E8D8D8C8C8B8A89888685848381807F7E7D7C7A79
787673716E6B67635D5751494139302A2824201C1816151B
22282E33393E43484D51565B5F64686C7175797D8185898D
9195999DA1A4A8AC
AFAFAFAEADADACACABAAA9A8A7A6A4A49F9C9B999794918E
8C89858382828282838384848585868788888A8B8C8D8E8E
8F8F8F8F8F8F8E8D8C8C8B8A88878685838281807E7C7A79
777472706D6965615A544E453C332B2623211C191714151C
22282E33393E43484D52565B5F64686D7175797D8185898D
9195999DA1A4A8AC
AFAFAEADADACABAAA9A8A7A5A4A2A09C999A989694918E8C
888583818080818182838485868788898A8B8C8D8E8F8F90
919191919190908F8F8E8D8B8A898786848382807E7C7A78
7673716E6B66625D57514940372F26221F1C18151413171D
23292E34393E43484D52575B6064686D7175797D8185898D
9195999DA1A4A8AC
AFAEADACACABAAA9A7A6A5A3A19F9C99989693928F8D8B89
868381807F7F80818284858687888A8B8B8C8D8E8F909192
929393939392929191908E8D8C8A8987858482817F7D7A78
7573706C6864605B544D443B332B221E1B1814121113181E
23292F34393F44494E52575C6064696D71757A7E82868A8D
9195999DA1A5A8AC
AFAEADACABAAA8A7A6A4A2A19E9C9996938F8E8C8A898785
8482807F7E7E7F818284858788898B8C8D8E8F9192929394
94959595959494939391908F8E8C8B89878683817F7D7A78
75726E6B66615C564F473E362D261E1A1713100F0F13191F
242A2F353A3F44494E53575C6065696D72767A7E82868A8E
9295999DA1A5A8AC
AFAEADABAAA9A7A6A4A3A19E9C9996938E8C898786848382
817F7E7D7D7E7F8183858688898B8C8E8F90929394959596
979797979797969695949391908E8C8B898784827F7D7A77
74716D69645F59524A42393028211B17130F0D0D0F141A1F
252B30353B40454A4F53585C61656A6E72767A7E82868A8E
9296999DA1A5A8AC
AFADACABA9A8A6A5A3A19F9D9A9794908C8883818080807F
7E7D7D7D7D7E7F81838587898B8C8E8F9192949596979798
99999999999999989796959392908E8C8A888583807D7A77
74706C67625C554D453C342C241D1613100D0B0C0F151B20
262B31363B41464A4F54595D61666A6E72777B7F83868A8E
92969A9DA1A5A8AC
AEADACAAA9A7A5A4A2A09E9B9895928E89827C7B7B7C7D7D
7D7C7C7C7D7F80828486888A8C8E8F91939495969798999A
9B9B9C9C9C9C9B9A999897959492908E8C898683807D7A76
736F6A655F5850483F372E271F150F0E0C0A0A0B10161C21
272C32373C41464B5055595E62666B6F73777B7F83878B8F
92969A9DA1A5A9AC
AEADABAAA8A6A5A3A19F9C9A9794918D88837D797A7C7D7C
7C7B7C7C7D7F80838587898B8D8F9192949697989A9B9C9C
9D9E9E9E9E9E9D9C9C9B99979593918F8C8A8783807D7976
716C67625B534B433A322920170E0B0B0907080B11171D22
282D33383D42474C51555A5E63676B6F74787C7F83878B8F
93969A9EA1A5A9AC
AEADABA9A8A6A4A2A09E9B999693908C8884807D7C7C7D7C
7B7B7B7B7D7E818385888A8C8E9092949697999A9C9D9E9F
A0A1A1A1A1A0A09F9E9D9B99979593908D8A8784817D7974
6F6B655E564E453D342C23190E0909080504060B12181E24
292F34393E43484D52565B5F64686C7074787C8084888B8F
93979A9EA1A5A9AC
AEACABA9A7A5A3A19F9D9A9895928F8C8885817F7E7D7C7A
7A7A7A7B7D7F818386888B8D8F91939597999B9C9E9FA0A1
A2A3A3A4A3A3A2A1A09E9C9B989694918E8B8884807D7873
6E686159514940362E261C110B0906040203060C13191F25
2A30353B4045494E53575C6064696D7175797D8184888C90
93979A9EA2A5A9AC
AEACABA9A7A5A3A19F9C9A9794928E8B888582807F7D7A7B
7A797A7B7D7F828486898B8D90929497999B9D9EA0A1A2A3
A4A5A6A6A6A5A4A3A2A09E9C9A9896938F8C8884807B7671
6B645D554D443B33291E140D080503010003070D141A2126
2C31373C41464B4F54585D61656A6E7276797D8185898C90
94979B9EA2A5A9AC
AEACAAA8A7A5A2A09E9C999794918E8B888582807E7B7A79
78797A7B7D7F828487898C8E909395989A9C9EA0A1A3A4A5
A6A7A8A8A7A7A6A4A3A2A09E9C9A9793908C88847F7A746E
675F5850483F362C231A0F090604010000020810161C2228
2E33383D42474C51555A5E62666B6F72767A7E8286898D90
94989B9FA2A6A9AC
AEACAAA8A6A4A2A09E9B999694918E8B8885827F7C787876
7576787A7C7E818486898C8E919396989B9DA0A2A3A5A6A7
A8A8A9A8A8A7A7A6A5A3A19F9D9A97938F8B87827C77716A
635B534B41382F261D140D090502000001050B12181E242A
30353A3F44494E52575B5F64686C7073777B7F83868A8D91
94989B9FA2A6A9AC
AEACAAA8A6A4A2A09D9B999693918E8B8885817E7A777471
727375787B7E818386888B8E909396999C9EA1A2A4A5A7A8
A8A8A9A8A8A8A7A6A4A2A19E9C9996928E8A857F7A736C66
5F564E453B322B231A120D090402000103070E141B21272C
32373C41464A4F54585C6065696D7174787C8083878A8E91
95989C9FA2A6A9AD
AEACAAA8A6A4A2A09D9B999693918E8B8885817E7A74706E
6E717375787C80838587898C8F93979A9C9FA1A3A4A4A5A6
A7A7A7A7A6A5A4A3A2A09E9C9996928F8B86817C766F6860
58504840372F271F18100A0603010103060B11171D23292F
34393E43484C5155595E62666A6E7275797D8084888B8F92
95999C9FA3A6A9AD
AEACAAA8A6A4A2A09D9B989693918E8B8885817E7A756F6A
6A6D7174777A7D7F8285888C8F9396999C9E9FA0A1A3A3A3
A4A4A4A3A2A1A09F9D9A999693908C8985817C76716C655C
554C443B332C241A130E0A0603020404080E141A20262C31
363B4045494E52575B5F63676B6F73777A7E8285888C8F93
96999CA0A3A6A9AD
AEACAAA8A6A4A2A09D9B989693918E8B8885827E7A76726E
6D6D6E707476787D8085888B8F929597999B9D9E9FA0A0A0
A0A09F9E9D9C9A989694918E8C8986837E7A75706B655E57
4F473F372F271F18110C0805050605060C12181D23292E33
383D42474C5054595D6165696D7074787B7F8286898D9093
969A9DA0A3A6AAAD
AEACAAA8A6A4A29F9D9B989693918E8B8885827F7B777470
6C6B6D707376797C7F8285898D9093959798999A9B9C9C9B
9B9A999897969492908E8B888582817D7A75706B655E5852
4A423B332B231B140E0A09090908070A10161B21272C3136
3B4045494E52565B5F63666A6E7275797C8083878A8D9194
979A9DA0A4A7AAAD
AEACAAA8A6A4A29F9D9B999694918E8C8986837F7C797572
6F6B6B6E717377797C7F83868A8E90929394949596969695
959493918F8E8D8B898783817F7D7B7673706A645E574F48
413A332B241D15110E0D0E0D0A08080E14191F242A2F3439
3E42474C5054585C6064686C7073777A7E8184888B8E9194
989B9EA1A4A7AAAD
AEACAAA8A6A4A2A09D9B999694928F8C898784807D7A7774
716F6E6E7174777A7C7E8184878A8C8E8F8F90909090908F
8D8D8A8888858282807E7D7A7875726F6B65605B554E4842
3B342C241E18151310100E0A09080C12181D23282D32373C
41454A4E52565B5F62666A6E7175787B7F8285898C8F9295
989B9EA1A4A7AAAD
AEACAAA8A6A4A2A09E9B999794928F8D8A8784817E7B7875
73706D6E6E6F7276797C7E8183868889898A8A8A8A898987
868483827F7D7B79777573706E6B67645F5C58534C46403A
322B26211D19161615110C09070910161C21262B31353A3F
43484C5155595D6165686C6F73767A7D8083878A8D909396
999C9FA2A4A7AAAD
AEACAAA8A6A4A2A09E9C9A979593908E8B888583807D7A77
74716F6B6A6F717375797B7D7F8182838384848383828280
7F7D7B77757372706C6B686563605D5956524D48443E3731
2B26221E1A181816130F0C09080E141A20252A2F34393E42
474B4F53585C5F63676A6E7175787B7E8285888B8E919497
999C9FA2A5A8AAAD
AEACAAA8A6A4A2A09E9C9A989693918E8C898684817E7B78
7673706D69696E72747677797A7C7D7C7C7C7C7B7B7B7978
7673716E6C69666463605C5A5855514D4A46423E39342F2A
2522201E1D1D1A15100D0A090E13191E24292E33383C4146
4A4E52565A5E6265696C7073767A7D808386898C8F929597
9A9DA0A2A5A8AAAD
AEACAAA8A7A5A3A19F9D9B989694928F8D8A8885827F7D7A
7774716E6B69696C7072747676767676767576757473726F
6D6B6865635F5C58555453504D4945423D3935312D292725
23201F1F1E1B16120E0A080B12181E23282D32373C404549
4D5155595D6164686B6E7275787B7E8184888B8D90939598
9B9EA0A3A5A8ABAD
AEACAAA9A7A5A3A19F9D9B99979592908E8B898683817E7B
787673706D696666696D707272706F6F6F6E6D6C6B6A6867
64615F5D5955524E4B484644423E3B3835312D2A27262523
2323221F1C16110E0C090A11171D23282D32373C4044484D
5155595C6063676A6E7174777A7D808386898C8E91949699
9C9EA1A3A6A8ABAD
AEACABA9A7A5A3A1A09E9C9A989593918F8C8A878582807D
7A7774716E6A6664646668696A6A686666666463605F5D5C
5A5855534F4C4946423E3C3C393634312E2B292726262626
2524221D17110F0C080B12181E23282D32373C4044484D50
54585C5F63666A6D707376797C7F8285888A8D909295979A
9C9FA1A4A6A9ABAD
AEACABA9A7A6A4A2A09E9C9A98969492908D8B898684817F
7C797673706C686460616263646463605E5D5D5A58555251
504F4C4A4644413E3B383533302E2E2C2B29292829292724
221F1914100F0C090C12181E24292E33383C4145494C5054
585C5F6366696C6F7376797B7E818486898C8E919396989B
9D9FA2A4A7A9ABAE
AEADABA9A8A6A4A2A19F9D9B99979593918F8C8A88858380
7E7B7875716E6A66615C5C5F61615E5C595654524F4C4946
4443413F3D3B3A3A3939363431302F2F2F2F2E2C2A262320
1C1813100E0D0A0C141A1F252A2F34383D4145494D515559
5C5F6366696C6F7275787B7E808386888B8D90929597999C
9EA0A2A5A7A9ABAE
AEADABAAA8A6A5A3A1A09E9C9A98969492908E8C89878582
7F7D7A7773706C6864605B5A5B5B5B5A56534F4C49464342
3E3A363534353637363637363535363432302E2A27221E1A
1512100F0B0A0F151B21262B3035393E42464A4E5255595C
606366696C6F7275787B7D808285878A8C8F919396989A9D
9FA1A3A5A7A9ACAE
AEADABAAA8A7A5A4A2A09F9D9B99979593918F8D8B898684
817F7C7976726F6B67635F595456585756534F4B49474542
3F3E3D3C3B3A3939393A3A3A39383633312E2A27221C1814
13110F0C0E14191E23282D32363B3F43474B4F53565A5D60
6366696C6F7275787A7D80828587898C8E90929597999B9D
A0A2A4A6A8AAACAE
AEADACAAA9A7A6A4A3A19F9E9C9A98979593918F8D8B8886
84817E7B7875726E6B67625E595452535352514F4D4A4745
4342403F3E3E3E3E3E3D3C3B3A3936332F2926211D1A1716
14101013181D22262B3034393D4145494D5054585B5E6164
676A6D707375787B7D80828587898B8E90929496989A9C9E
A0A2A4A6A8AAACAE
AFADACAAA9A8A6A5A3A2A09F9D9B9A98969492908F8D8A88
8683817E7B7976726F6B67635E59534F4F5151504E4C4B49
484645444342434342403E3B3837332E2A26221E1C1B1915
14161A1E22272B2F33383C4044484B4F5256595D60636669
6C6E717376797B7E80838587898C8E90919396989A9C9E9F
A1A3A5A7A9AAACAE
AFADACABA9A8A7A5A4A3A1A09E9D9B9998969492908E8C8A
888683817E7C7976726F6B67635F5B56524E4C4E50504F4E
4B49484745444341403E3D3A35322E2B292725211E1B1A1C
1F2225282C3034383C4043474B4E5255595C5F6265686B6D
707275777A7C7E818385888A8C8E9092949698999B9D9FA0
A2A4A6A8A9ABACAE
AFADACABAAA9A7A6A5A3A2A19F9E9C9B9998969493918F8D
8B888684817F7C797673706C6965615D595654514E4F504F
4E4E4C4A49474542403E3C39373532312E2A262425262729
2B2D3033373A3D4144484B4F5255585B5E6164676A6D6F72
7477797C7E80838586888A8C8E90929496989A9B9D9EA0A2
A3A5A6A8A9ABADAE
AFAEACABAAA9A8A7A5A4A3A2A09F9E9C9B9998969493918F
8D8B89878582807D7A7774716E6B6764615E5C595754514F
4E4E4D4D4C4B4A494844413F3D3A3632302F2F3031323334
36383B3D404346494C505356595C5E6164676A6C6F717476
787B7D7F82848687898B8D8F9192949698999B9D9E9FA1A3
A4A6A7A8AAABADAE
AFAEADACABAAA8A7A6A5A4A3A1A09F9E9C9B999897959391
908E8C8A888683817E7C797673706E6B686563605E5C5958
5655545352514F4C4A484543413F3E3D3C3B3B3B3C3D3E40
424446484A4C4F5254575A5D606265676A6D70727476797B
7D7F81838587898B8C8E9092939597989A9B9C9EA0A1A2A4
A5A6A8A9ABACADAF
AFAEADACABAAA9A8A7A6A5A4A3A2A09F9E9D9B9A98979694
92918F8D8B89878583807E7B797674716F6C6A6866646260
5F5E5C5B5A59575553514F4E4C4B4948474747474748494B
4C4E50525456585B5D606264676A6C6E70737577797B7D7F
81838587898A8C8E8F9193949697999A9C9D9E9FA1A2A4A5
A6A7A8AAABACAEAF
AFAEADACACABAAA9A8A7A6A5A4A3A2A19F9E9D9C9B999897
959492908F8D8B89878583807E7C79777573726F6E6C6A68
6766656362615F5E5C5B5958565554535352525253545455
57585A5C5D5F626465686A6C6E70727577797A7C7E808284
8688898B8C8E909192949597999A9B9C9E9FA0A2A3A4A5A6
A7A8A9AAACADADAF
AFAEAEADACABAAAAA9A8A7A6A5A4A3A2A1A09F9E9D9C9B99
9897959492918F8D8B8A88868482807E7D7B797775737271
706E6D6C6B6A686765646362615F5E5E5D5D5D5D5E5E5F60
6162646566686A6C6E7071747678797B7D7F808283858789
8A8C8D8F909293949697989A9B9C9D9FA0A1A2A3A4A5A6A7
A8A9AAABACADAEAF
AFAFAEADACACABAAAAA9A8A7A6A6A5A4A3A2A1A09F9E9D9C
9B9A989796949391908E8D8B898886848381807E7C7B7A79
77767675737271706F6D6C6B6A6A69686868686868696A6B
6B6C6D6E7072737476787A7C7D7E808283858688898A8C8D
8F90929395969798999A9C9D9E9FA0A1A2A2A3A4A5A6A7A8
A9AAABACADADAEAF
AFAFAEAEADACACABAAAAA9A8A8A7A6A6A5A4A3A2A1A0A09F
9E9D9C9B99989796949392908F8D8C8B8988868584838281
807F7E7D7C7B7A7978777776757473737272727273737475
75767778797A7B7D7E80818384858788898B8C8E8F909193
9495969798999A9B9C9D9E9FA0A1A2A3A3A4A5A6A7A8A8A9
AAABABACADAEAFAF
AFAFAEAEADADACACABABAAAAA9A8A8A7A7A6A5A4A4A3A2A2
A1A09F9E9D9C9B9A9998969594939291908F8D8C8B8A8988
88878686858483828181807F7F7E7E7D7D7D7C7D7D7E7E7E
7F808182828385868788898A8B8D8E8F9091929394959797
98999B9B9C9D9E9FA0A1A2A2A3A4A4A5A6A7A7A8A8A9AAAA
ABABACADAEAEAEAF
AFAFAFAEAEADADADACACABABAAAAA9A9A8A8A7A7A6A6A5A5
A4A3A2A2A1A09F9E9D9C9B9B9A9998979695949392919190
908F8F8E8D8D8C8B8B8A8989888888878787878787878889
898A8A8B8B8C8D8E8F9091929293949596979898999A9B9C
9D9E9E9FA0A1A2A3A3A4A4A5A5A6A7A7A8A9A9A9AAAAABAB
ACACADADAEAEAFB0
B0AFAFAFAEAEAEADADADACACACABABABAAAAA9A9A8A8A8A7
A7A6A6A5A5A4A3A3A2A1A1A09F9E9E9D9C9B9B9A9A999998
989797979695959494949393929292919191919192929293
9393939494959697979898999A9B9B9C9C9D9D9E9FA0A0A1
A2A2A2A3A4A5A5A6A6A7A7A8A8A8A9A9AAAAABABABACACAC
ADADADAEAEAEAFB0
B0AFAFAFAFAFAEAEAEAEAEADADADADACACACABABABAAAAAA
AAAAA9A9A8A8A7A7A6A6A6A5A5A5A4A4A3A3A2A2A1A1A1A0
A0A09F9F9F9E9E9E9D9D9D9C9C9C9C9C9B9B9B9C9C9C9C9C
9D9D9D9E9E9E9E9F9FA0A0A1A2A2A2A3A3A4A4A4A4A5A5A6
A6A7A7A8A8A8A8A9A9AAAAAAABABABACACACACADADADADAE
AEAEAFAFAFAFB0B0
B0B0B0AFAFAFAFAFAFAFAFAFAEAEAEAEAEAEADADADADADAD
ADADACACACACACACABABABABABAAAAAAA9A9A9A8A8A8A8A8
A8A8A7A7A7A7A7A7A6A6A6A6A6A6A6A6A5A5A6A6A6A6A6A6
A6A6A7A7A7A7A7A7A7A8A8A8A9A9A9A9AAAAAAAAAAAAABAB
ABABACACACACACADADADADADADADADAEAEAEAEAEAEAEAEAE
AFAFAFAFAFB0B0B0
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[57]:=",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`004`3ooolG0;2`/0P0[jn_302`/;020;6a/@80/[:b
00<0/;2`0;6a/@2a/K400P2a/K460;:b/PP0/k>c>02d];@40;>c/`80];Bd2P2c/k<O0;Bd]240/k>c
00<0/[:b0;>c/`2c/k<02P2b/[840;6a/@@0/;2`1P2_[jl50:j^[P`0[jn_0P2`/;0E0?ooo`004`3o
oolG0;2`/0P0[jn_302`/;020;6a/@80/[:b00<0/;2`0;6a/@2a/K400P2a/K460;:b/PP0/k>c>02d
];@40;>c/`80];Bd2P2c/k<O0;Bd]240/k>c00<0/[:b0;>c/`2c/k<02P2b/[840;6a/@@0/;2`1P2_
[jl50:j^[P`0[jn_0P2`/;0E0?ooo`004`3oool60;2`/080/K6a2`2`/;040:n_[`@0[Zj^102_[jl6
0;2`/0@0/K6a1P2b/[800`2`/;00/[:b0;:b/P040;>c/`80];Bd0P2e]KD40;Jf]P@0]kNg202h^;P?
0;Vi^@@0^;Rh102g]kLG0;Rh^1/0]kNg402h^;P20;Vi^@80^;Rh1@2g]kL20;Jf]P80]kNg402f][H4
0;Fe]@80][Jf2`2e]KD40;Bd]0@0/k>c0P2b/[820;6a/@80/;2`102^[Zh40:f][@<0[:b/0P2^[Zh2
0:n_[`H0[Zj^0P2_[jl20;2`/1D0oooo000C0?ooo`H0/;2`0P2a/K4;0;2`/0@0[jn_102^[Zh40:n_
[`H0/;2`102a/K460;:b/P030;2`/02b/[80/[:b00@0/k>c0P2d];@20;Fe]@@0][Jf102g]kL80;Rh
^0l0^KVi102h^;P40;Ng]aL0^;Rh6`2g]kL@0;Rh^080^KVi0P2h^;P50;Ng]`80][Jf0P2g]kL@0;Jf
]P@0]KFe0P2f][H;0;Fe]@@0];Bd102c/k<20;:b/P80/K6a0P2`/;040:j^[P@0[Jf]0`2/[:`20:j^
[P80[jn_1P2^[Zh20:n_[`80/;2`5@3oool001<0oooo4`2`/;040:n_[`H0[Zj^102_[jl40;2`/080
/K6a1P2b/[820;6a/@030;:b/P2d];@0];Bd0080];Bd0P2e]KD20;Jf]P@0^;Rh0P2i^KT20;Zj^P80
^k^k1P2l_;`40;fm_@<0_[jn202m_Kd40;bl_100^k^k2@2l_;`60;^k^``0^[Zj5@2k^k/80;bl_080
_Kfm0P2l_;`20;Zj^P80]kNg00<0^KVi0;Zj^P2j^[X0102j^[X20;Vi^@80^;Rh302i^KT90;Rh^0@0
]kNg1P2f][H20;Fe]@80];Bd0P2c/k<20;:b/P80/;2`0P2^[Zh20:f][@H0[:b/2@2][Jd40:j^[P80
[jn_5@3oool001<0oooo4`2`/;040:n_[`H0[Zj^102_[jl40;2`/080/K6a1P2b/[820;6a/@030;:b
/P2d];@0];Bd0080];Bd0P2e]KD20;Jf]P@0^;Rh0P2i^KT20;Zj^P80^k^k1P2l_;`40;fm_@<0_[jn
202m_Kd40;bl_100^k^k2@2l_;`60;^k^``0^[Zj5@2k^k/80;bl_080_Kfm0P2l_;`20;Zj^P80]kNg
00<0^KVi0;Zj^P2j^[X0102j^[X20;Vi^@80^;Rh302i^KT90;Rh^0@0]kNg1P2f][H20;Fe]@80];Bd
0P2c/k<20;:b/P80/;2`0P2^[Zh20:f][@H0[:b/2@2][Jd40:j^[P80[jn_5@3oool001<0oooo5`2`
/;020:n_[`80[Zj^0P2][Jd20:j^[P80[jn_102`/;020;6a/@@0/[:b102c/k<00`2b/[80/k>c0;>c
/`020;Fe]@80]kNg0P2h^;P20;Vi^@80^k^k0P2l_;`20;jn_P80_kno1030`<040<71`@T0`/;21031
`L440;no_`@0_[jn102m_Kd80;jn_Pd0_kno3P2n_[hG0;no_`X0`<300P2o_kl20;fm_@<0_;bl0P2m
_Kd80;bl_080^k^k102l_;`<0;^k^`<0^[Zj102i^KT40;Rh^080]kNg0P2f][H20;Bd]080/[:b0P2`
/;020:j^[PP0[:b/1@2][Jd40:b/[080[Jf]0P2^[Zh20:n_[aD0oooo000C0?oooaL0/;2`0P2_[jl2
0:j^[P80[Jf]0P2^[Zh20:n_[`@0/;2`0P2a/K440;:b/P@0/k>c00<0/[:b0;>c/`2c/k<00P2e]KD2
0;Ng]`80^;Rh0P2i^KT20;^k^`80_;bl0P2n_[h20;no_`@0`<301031`L490<;2`P@0`L71102o_kl4
0;jn_P@0_Kfm202n_[h=0;no_`h0_[jn5`2o_kl:0<30`080_kno0P2m_Kd30;bl_080_Kfm202l_;`2
0;^k^`@0_;bl302k^k/30;Zj^P@0^KVi102h^;P20;Ng]`80][Jf0P2d];@20;:b/P80/;2`0P2^[Zh8
0:b/[0D0[Jf]102/[:`20:f][@80[Zj^0P2_[jlE0?ooo`004`3oool80;2`/0d0/K6a102`/;040:n_
[`@0[Zj^0P2_[jl20;2`/0@0/K6a0P2b/[840;>c/`030;Bd]02e]KD0]KFe0080][Jf0P2h^;P20;Zj
^P80_;bl0P2n_[h20;no_`80`L710P32`/820<C4a080aLG53`36a/H20<C4a080`l?30P32`/820<71
`@@0`<300P2o_kl40<30`0@0`L714@32`/8S0<?3``80a<C42033`l<20<;2`P030<71`@30`<00`<30
0080_kno0P30`<0>0;no_`P0_[jn1@2m_Kd20;bl_0@0^k^k0P2j^[X20;Vi^@80]kNg0P2e]KD20;>c
/`80/K6a0P2^[Zh90:f][@@0[:b/1P2[Zj/20:f][@80[Zj^5@3oool001<0oooo202`/;0=0;6a/@@0
/;2`102_[jl40:j^[P80[jn_0P2`/;040;6a/@80/[:b102c/k<00`2d];@0]KFe0;Fe]@020;Jf]P80
^;Rh0P2j^[X20;bl_080_[jn0P2o_kl20<71`@80`/;20P34a<@20<G5a@l0a/K60P34a<@20<?3``80
`/;20P31`L440<30`080_kno1030`<040<71`A40`/;28`33`l<20<C4a0P0`l?30P32`/800`31`L40
`<300<30`0020;no_`80`<303P2o_kl80;jn_PD0_Kfm0P2l_;`40;^k^`80^[Zj0P2i^KT20;Ng]`80
]KFe0P2c/k<20;6a/@80[Zj^2@2][Jd40:b/[0H0Zj^[0P2][Jd20:j^[QD0oooo000C0?ooo`H0/;2`
2P2a/K470;:b/P80/K6a1P2`/;040:n_[`80/;2`0P2a/K440;:b/P80/k>c0P2e]KD30;Jf]P80]kNg
0P2j^[X20;bl_080_[jn0P30`<020<;2`P80aLG50P36a/H20<S8b080bLW90P3:b/X20<_;b`D0c<c<
0P3;bl/20<[:bP80bLW90P38b<P20<O7a`80a/K60P34a<@40<?3``H0`/;20P33`l<70<C4a0X0aLG5
2036a/H20<O7aal0b<S81P37alL30<K6aP80a<C40P32`/8@0<?3``@0`/;21P31`L400`30`<00_kno
0;no_`020;no_`80_[jn0P2m_Kd20;bl_080^k^k0P2j^[X20;Rh^080]KFe0P2b/[860;2`/0@0[jn_
00<0[Zj^0:b/[02/[:`00P2/[:`20:ZZZP80ZJVY0P2[Zj/20:f][@80[Zj^5@3oool001<0oooo1P2`
/;0:0;6a/@L0/[:b0P2a/K460;2`/0@0[jn_0P2`/;020;6a/@@0/[:b0P2c/k<20;Fe]@<0][Jf0P2g
]kL20;Zj^P80_;bl0P2n_[h20<30`080`/;20P35aLD20<K6aP80b<S80P39bLT20<[:bP80bl_;1@3<
c<`20<_;b`80b/[:0P39bLT20<S8b080alO70P36a/H20<C4a0@0`l?31P32`/820<?3``L0a<C42P35
aLD80<K6aP80alO77`38b<P60<O7a`<0a/K60P34a<@20<;2`Q00`l?31032`/860<71`@030<30`02o
_kl0_kno0080_kno0P2n_[h20;fm_@80_;bl0P2k^k/20;Zj^P80^;Rh0P2e]KD20;:b/PH0/;2`102_
[jl00`2^[Zh0[:b/0:b/[0020:b/[080ZZZZ0P2YZJT20:^[Z`80[Jf]0P2^[ZhE0?ooo`004`3oool6
0;2`/0H0/K6a1`2b/[820;>c/`X0/[:b202a/K420;:b/P80/k>c0P2d];@20;Fe]@030;Ng]`2h^;P0
^;Rh0080^[Zj0P2l_;`20;no_`80`/;20P34a<@20<K6aP80b<S80P3;bl/20<g=c@80c/k>0P3?cll4
0=3@d080dM7A00<0d=3@0<o?c`3?cll00P3>c/h20<g=c@80c<c<0P3:b/X20<W9b@80b<S80P37alL2
0<K6aPP0aLG51@36a/H40<O7a`@0b<S82039bLT40<[:bP80bl_;2@3<c<`40<g=cA80c<c<1P3;bl/3
0<[:bP80bLW90P37alL40<K6aP80alO71P38b<P40<O7a`@0a/K61035aLD20<C4a0<0`l?30P32`/82
0<71`@80`<300P2o_kl20;fm_@80^k^k0P2i^KT20;Jf]P@0/[:b102a/K420:n_[`80[Zj^00<0[Jf]
0:b/[02/[:`00P2[Zj/40:VYZ@80Zj^[0P2][Jd20:j^[QD0oooo000C0?ooo`H0/;2`1P2a/K470;:b
/P80/k>c2P2b/[880;6a/@80/[:b0P2c/k<20;Bd]080]KFe00<0]kNg0;Rh^02h^;P00P2j^[X20;bl
_080_kno0P32`/820<C4a080a/K60P38b<P20<_;b`80cLg=0P3>c/h20<o?c`@0d=3@0P3AdM400`3@
d=00clo?0<o?c`020<k>cP80cLg=0P3<c<`20<[:bP80bLW90P38b<P20<O7a`80a/K62035aLD50<K6
aP@0alO71038b<P80<W9b@@0b/[:0P3;bl/90<c<c0@0cLg=4P3<c<`60<_;b`<0b/[:0P39bLT20<O7
a`@0a/K60P37alL60<S8b0@0alO71036a/H40<G5a@80a<C40`33`l<20<;2`P80`L710P30`<020;no
_`80_Kfm0P2k^k/20;Vi^@80][Jf102b/[840;6a/@80[jn_0P2^[Zh00`2][Jd0[:b/0:b/[0020:^[
Z`@0ZJVY0P2[Zj/20:f][@80[Zj^5@3oool001<0oooo102`/;040;6a/@H0/[:b1@2c/k<B0;Bd]080
/k>c0P2d];@20;Fe]@80][Jf0P2g]kL00`2i^KT0^k^k0;^k^`020;fm_@80_kno0P33`l<20<G5a@80
b<S80P3:b/X20<g=c@80clo?0P3AdM420=?Cd`80e=CD103EeMD20=CDe0030=?Cd`3Bd]80d];B0080
dM7A0P3@d=020<o?c`80c/k>0P3=cLd20<_;b`80b/[:1039bLT:0<S8b0L0bLW90P3:b/X40<_;b`80
c<c<103=cLd20<k>cP@0clo?1`3@d=0<0=7Ad@X0d=3@103?cll50<k>cP@0cLg=303<c<`40<_;b`@0
b/[:0P39bLT20<S8b0<0alO70P36a/H20<G5a@80a<C40P33`l<20<71`@80_[jn0P2k^k/20;Rh^080
];Bd102c/k<20;:b/P80/K6a0P2^[Zh20:f][@030:b/[02[Zj/0Zj^[0080ZZZZ102YZJT20:^[Z`80
[Jf]0P2^[ZhE0?ooo`004`3oool40;2`/0@0/K6a1P2b/[850;>c/a80];Bd0P2c/k<20;Bd]080]KFe
0P2f][H20;Ng]`030;Vi^@2k^k/0^k^k0080_Kfm0P2o_kl20<?3``80aLG50P38b<P20<[:bP80cLg=
0P3?cll20=7Ad@80dm?C0P3De=@40=GEe@80e=CD00<0dm?C0=;BdP3Bd]800P3AdM420=3@d080clo?
0P3>c/h20<g=c@80bl_;0P3:b/X40<W9b@X0b<S81`39bLT20<[:bP@0bl_;0P3<c<`40<g=c@80c/k>
103?cll70=3@d0`0dM7A2P3@d=040<o?c`D0c/k>103=cLd<0<c<c0@0bl_;103:b/X20<W9b@80b<S8
0`37alL20<K6aP80aLG50P34a<@20<?3``80`L710P2n_[h20;^k^`80^;Rh0P2d];@40;>c/`80/[:b
0P2a/K420:j^[P80[Jf]00<0[:b/0:^[Z`2[Zj/00P2ZZZX40:VYZ@80Zj^[0P2][Jd20:j^[QD0oooo
000C0?ooo`@0/;2`102a/K440;:b/P80/k>c1`2d];@60;Fe]@h0][Jf0P2g]kL20;Rh^080^KVi00<0
^k^k0;fm_@2m_Kd00P2o_kl20<71`@80`l?30P36a/H20<_;b`80clo?0P3AdM420=CDe080e]KF0P3G
emL20=SHf080fMWI103Hf=P00`3GemL0e]KF0=KFeP020=CDe080dm?C0P3Bd]820=7Ad@80d=3@0P3?
cll20<k>cP80cLg=0P3<c<`40<_;b`T0b/[:103;bl/60<c<c080cLg=0P3>c/h20<o?c`80d=3@0P3A
dM440=;BdPD0dm?C403De=@40=?Cd`@0d];B3@3AdM420=3@d0@0clo?103@d=040<o?c`80c/k>103=
cLd20<c<c0<0bl_;0P3:b/X20<S8b080alO70P35aLD20<71`@80_Kfm0P2h^;P20;Fe]@80];Bd0P2b
/[820;6a/@80[jn_0P2^[Zh20:b/[080ZZZZ0`2YZJT40:RXZ080ZJVY0P2[Zj/20:b/[080[Zj^5@3o
ool001<0oooo0P2`/;040;6a/@80/[:b102c/k<40;Bd]0<0]KFe1P2f][H40;Ng]`@0^;Rh1P2i^KT2
0;Zj^P80^k^k0P2l_;`20;jn_P030;no_`31`L40`L710080a<C40P36a/H20<S8b080b/[:0P3?cll2
0=CDe080e]KF0P3IfMT20=_Kf`X0gMgM00<0g=cL0=_Kf`3Kfm/00P3IfMT20=SHf080e]KF0P3EeMD2
0=?Cd`80d];B0P3AdM420=3@d080clo?1P3>c/h;0<g=c@H0c/k>0P3?cll40=3@d0@0dM7A103Bd]82
0=?Cd`D0e=CD3P3EeMD:0=CDe0/0dm?C103Bd]820=7Ad@@0d=3@103Bd]820=7Ad@@0d=3@103?cll3
0<k>cP80c<c<0P39bLT20<C4a080_[jn0P2i^KT20;Jf]P80/k>c0P2a/K420;2`/080[jn_0P2][Jd2
0:^[Z`80ZZZZ0P2YZJT30:RXZ0@0YjNW0P2XZ:P20:ZZZP80[:b/0P2^[ZhE0?ooo`004`3oool20;2`
/0@0/K6a0P2b/[840;>c/`@0];Bd0`2e]KD60;Jf]P@0]kNg102h^;P60;Vi^@80^[Zj0P2k^k/20;bl
_080_[jn00<0_kno0<71`@31`L400P34a<@20<K6aP80b<S80P3:b/X20<o?c`80e=CD0P3Fe]H20=WI
f@80fm_K2P3MgMd00`3Lg=`0fm_K0=_Kf`020=WIf@80f=SH0P3Fe]H20=GEe@80dm?C0P3Bd]820=7A
d@80d=3@0P3?cll60<k>cP/0cLg=1P3>c/h20<o?c`@0d=3@103AdM440=;BdP80dm?C1@3De=@>0=GE
e@X0e=CD2`3Cdm<40=;BdP80dM7A103@d=040=;BdP80dM7A103@d=040<o?c`<0c/k>0P3<c<`20<W9
b@80a<C40P2n_[h20;Vi^@80][Jf0P2c/k<20;6a/@80/;2`0P2_[jl20:f][@80Zj^[0P2ZZZX20:VY
Z@<0Z:RX102WYjL20:RXZ080ZZZZ0P2/[:`20:j^[QD0oooo000C0?ooo`@0/K6a102b/[820;>c/`80
];Bd1@2e]KD40;Jf]P@0]kNg0P2h^;P20;Vi^@@0^[Zj0P2k^k/40;bl_080_Kfm0P2n_[h20<30`080
`L7100<0`l?30<K6aP36a/H00P38b<P20<[:bP80cLg=0P3@d=020=?Cd`80emOG0P3Kfm/20=oOg`80
hN7Q0P3Rh^840>?Sh`80h^;R0P3QhN400`3Ph>00g]kN0=kNgP020=gMg@80fm_K0P3IfMT20=SHf080
e]KF0P3EeMD20=CDe080dm?C0P3Bd]840=7Ad@@0d=3@1`3?cll40=3@d0@0dM7A103Bd]820=?Cd`H0
e=CD103EeMD30=KFePP0emOG203Hf=P>0=OGe`D0e]KF1P3EeMD40=CDe080d];B0P3@d=020<k>cP80
dM7A1P3Bd]820=7Ad@030<o?c`3;bl/0bl_;0080a/K60P32`/820;jn_P80^[Zj0P2g]kL20;Bd]080
/[:b0P2^[Zh40:f][@80Zj^[0P2ZZZX20:RXZ0<0YZJV0P2UYJD20:BTY080YZJV0P2WYjL20:ZZZP80
[:b/0P2^[ZhE0?ooo`004`3oool40;6a/@@0/[:b0P2c/k<20;Bd]0D0]KFe102f][H40;Ng]`80^;Rh
0P2i^KT40;Zj^P80^k^k102l_;`20;fm_@80_[jn0P30`<020<71`@030<?3``36a/H0a/K60080b<S8
0P3:b/X20<g=c@80d=3@0P3Cdm<20=OGe`80fm_K0P3Ogml20>7Qh@80h^;R103Shn<20>;RhP80hN7Q
00<0h>3P0=kNgP3Ng]h00P3MgMd20=_Kf`80fMWI0P3Hf=P20=KFeP80eMGE0P3De=@20=?Cd`80d];B
103AdM440=3@d0L0clo?103@d=040=7Ad@@0d];B0P3Cdm<60=CDe0@0eMGE0`3Fe]H80=OGe`P0f=SH
3P3GemL50=KFePH0eMGE103De=@20=;BdP80d=3@0P3>c/h20=7Ad@H0d];B0P3AdM400`3?cll0bl_;
0<_;b`020<K6aP80`/;20P2n_[h20;Zj^P80]kNg0P2d];@20;:b/P80[Zj^102][Jd20:^[Z`80ZZZZ
0P2XZ:P30:JVYP80YJFU0P2TY:@20:JVYP80YjNW0P2ZZZX20:b/[080[Zj^5@3oool001<0oooo0P2`
/;020;6a/@80/[:b102c/k<20;Bd]0@0]KFe00<0][Jf0;Ng]`2g]kL00P2g]kL20;Rh^080^KVi0P2j
^[X40;^k^`80_;bl0P2m_Kd20;jn_P80_kno0P30`<020<;2`P80`l?30P35aLD00`37alL0bLW90<W9
b@020<c<c080c/k>0P3AdM420=CDe080emOG0P3IfMT20=kNgP80h^;R0P3UiND20>SXj080j^[Z0P3Y
jNT20>SXj080inOW00<0iNGU0>?Sh`3Shn<00P3QhN420=oOg`80gMgM0P3Kfm/20=WIf@80emOG0P3F
e]H20=GEe@@0e=CD1P3Cdm<70=;BdPH0dm?C0P3De=@40=GEe@@0e]KF0P3GemL40=SHf0D0fMWI103J
f]XF0=_Kf`D0f][J1P3IfMT40=SHf0@0emOG0P3Fe]H20=GEe@80e=CD0P3Cdm<20=7Ad@80clo?0P3@
d=020<k>cP030<W9b@35aLD0aLG50080`L710P2m_Kd20;Vi^@80]kNg0P2e]KD20;:b/P80[jn_0P2/
[:`20:f][@80Zj^[0P2YZJT20:NWY`80YJFU0`2TY:@20::RXP80Xj>S0P2TY:@20:JVYP80ZJVY0P2[
Zj/20:f][AD0oooo000C0?ooo`80/;2`0P2a/K420;:b/P@0/k>c0P2d];@40;Fe]@030;Jf]P2g]kL0
]kNg0080]kNg0P2h^;P20;Vi^@80^[Zj102k^k/20;bl_080_Kfm0P2n_[h20;no_`80`<300P32`/82
0<?3``80aLG500<0alO70<W9b@39bLT00P3<c<`20<k>cP80dM7A0P3De=@20=OGe`80fMWI0P3Ng]h2
0>;RhP80iNGU0P3Xj>P20>[ZjP80jNWY0P3Xj>P20>OWi`030>GUi@3Shn<0hn?S0080hN7Q0P3Ogml2
0=gMg@80fm_K0P3IfMT20=OGe`80e]KF0P3EeMD40=CDe0H0dm?C1`3Bd]860=?Cd`80e=CD103EeMD4
0=KFeP80emOG103Hf=P50=WIf@@0f][J5P3Kfm/50=[JfPH0fMWI103Hf=P40=OGe`80e]KF0P3EeMD2
0=CDe080dm?C0P3AdM420<o?c`80d=3@0P3>c/h00`39bLT0aLG50<G5a@020<71`@80_Kfm0P2i^KT2
0;Ng]`80]KFe0P2b/[820:n_[`80[:b/0P2][Jd20:^[Z`80ZJVY0P2WYjL20:FUY@<0Y:BT0P2RXZ82
0:>SX`80Y:BT0P2VYZH20:VYZ@80Zj^[0P2][JdE0?ooo`004`3oool40;6a/@80/[:b0P2c/k<20;Bd
]080]KFe102f][H00`2g]kL0^;Rh0;Rh^0020;Vi^@@0^[Zj0P2k^k/20;bl_080_Kfm0P2n_[h20;no
_`80`L710P32`/820<?3``80aLG50P37alL20<W9b@030<_;b`3=cLd0cLg=0080clo?0P3AdM420=CD
e080emOG0P3Jf]X20=gMg@80h>3P0P3UiND20>WYj@80kNg]103`l?020>k^kP80k>c/00<0j^[Z0>OW
i`3WinL00P3UiND20>;RhP80h>3P0P3Ng]h20=_Kf`80f][J0P3Hf=P40=OGe`@0e]KF1P3EeMD50=CD
e080eMGE103Fe]H40=OGe`@0f=SH0P3IfMT40=[JfP80fm_K0P3Lg=`50=gMg@H0g]kN203Ogml:0=kN
gPT0gMgM103Lg=`40=_Kf`80f][J0P3IfMT20=SHf080emOG0P3Fe]H20=GEe@80d];B0P3=cLd20<O7
a`030<?3``2o_kl0_kno0080^k^k0P2h^;P20;Fe]@80/[:b0P2_[jl20:f][@80Zj^[0P2ZZZX20:VY
Z@80YjNW0P2UYJD20:BTY0@0XZ:R0`2QXJ420::RXP80Xj>S0P2VYZH20:RXZ080ZZZZ0P2][JdE0?oo
o`004`3oool40;6a/@80/[:b0P2c/k<20;Bd]080]KFe102f][H00`2g]kL0^;Rh0;Rh^0020;Vi^@@0
^[Zj0P2k^k/20;bl_080_Kfm0P2n_[h20;no_`80`L710P32`/820<?3``80aLG50P37alL20<W9b@03
0<_;b`3=cLd0cLg=0080clo?0P3AdM420=CDe080emOG0P3Jf]X20=gMg@80h>3P0P3UiND20>WYj@80
kNg]103`l?020>k^kP80k>c/00<0j^[Z0>OWi`3WinL00P3UiND20>;RhP80h>3P0P3Ng]h20=_Kf`80
f][J0P3Hf=P40=OGe`@0e]KF1P3EeMD50=CDe080eMGE103Fe]H40=OGe`@0f=SH0P3IfMT40=[JfP80
fm_K0P3Lg=`50=gMg@H0g]kN203Ogml:0=kNgPT0gMgM103Lg=`40=_Kf`80f][J0P3IfMT20=SHf080
emOG0P3Fe]H20=GEe@80d];B0P3=cLd20<O7a`030<?3``2o_kl0_kno0080^k^k0P2h^;P20;Fe]@80
/[:b0P2_[jl20:f][@80Zj^[0P2ZZZX20:VYZ@80YjNW0P2UYJD20:BTY0@0XZ:R0`2QXJ420::RXP80
Xj>S0P2VYZH20:RXZ080ZZZZ0P2][JdE0?ooo`004`3oool20;6a/@80/[:b0P2c/k<40;Bd]080]KFe
0P2f][H20;Ng]`030;Rh^02i^KT0^KVi0080^[Zj0P2k^k/20;bl_080_Kfm0P2n_[h20;no_`80`<30
0P32`/820<?3``80aLG50P36a/H20<S8b080b/[:0P3<c<`00`3>c/h0d=3@0=3@d0020=;BdP80eMGE
0P3Hf=P20=_Kf`80gMgM0P3Ph>020>?Sh`80j>SX0P3/k>`20?3`l080l_;b103emOD20?;blP030>o_
k`3/k>`0k>c/0080jNWY0P3Vi^H20>?Sh`80h>3P0P3Ng]h20=cLg080fm_K103IfMT40=SHf0/0emOG
0P3Hf=P40=WIf@@0f][J103Kfm/20=cLg0@0gMgM0P3Ng]h20=oOg`<0h>3P1P3QhN4B0>;RhP@0hN7Q
1`3Ph>040=oOg`80g]kN0P3MgMd20=cLg080fm_K0P3Jf]X20=SHf080eMGE0P3AdM420<_;b`80a/K6
0P31`L400`2m_Kd0^KVi0;Vi^@020;Ng]`80];Bd0P2`/;020:j^[P80Zj^[0P2ZZZX20:RXZ080YjNW
0P2VYZH20:>SX`80XJ6Q0P2PX:0709nOW`80XJ6Q0P2SXj<20:FUY@80Z:RX0P2[Zj/20:f][AD0oooo
000C0?ooo`80/K6a0P2b/[820;>c/`@0];Bd0P2e]KD20;Jf]P80]kNg00<0^;Rh0;Vi^@2i^KT00P2j
^[X20;^k^`80_;bl0P2m_Kd20;jn_P80_kno0P30`<020<;2`P80`l?30P35aLD20<K6aP80b<S80P3:
b/X20<c<c0030<k>cP3@d=00d=3@0080d];B0P3EeMD20=SHf080fm_K0P3MgMd20>3Ph080hn?S0P3X
j>P20>c/k080l?3`0P3bl_840?Gem@80l_;b00<0kno_0>c/k03/k>`00P3YjNT20>KViP80hn?S0P3P
h>020=kNgP80g=cL0P3Kfm/40=WIf@@0f=SH2`3GemL20=SHf0@0fMWI103Jf]X40=_Kf`80g=cL103M
gMd20=kNgP80gmoO0`3Ph>060>7QhA80h^;R103QhN470>3Ph0@0gmoO0P3Ng]h20=gMg@80g=cL0P3K
fm/20=[JfP80f=SH0P3EeMD20=7Ad@80bl_;0P36a/H20<71`@030;fm_@2i^KT0^KVi0080]kNg0P2d
];@20;2`/080[Zj^0P2[Zj/20:ZZZP80Z:RX0P2WYjL20:JVYP80Xj>S0P2QXJ420:2PX0L0WinO0P2Q
XJ420:>SX`80YJFU0P2XZ:P20:^[Z`80[Jf]5@3oool001<0oooo0P2a/K420;:b/P80/k>c0P2d];@2
0;Fe]@80][Jf0P2g]kL20;Rh^0030;Vi^@2j^[X0^[Zj0080^k^k0P2l_;`20;fm_@80_kno0P30`<02
0<71`@80`l?30P34a<@20<K6aP80alO70P39bLT20<_;b`80cLg=0P3?cll00`3AdM40dm?C0=?Cd`02
0=GEe@80f=SH0P3Kfm/20=kNgP80hN7Q0P3Ti>@20>SXj080k>c/0P3_knl20?;blP80m?Cd0P3fm_H2
0?Win@80n?Sh00<0m?Cd0?3`l03`l?000P3/k>`20>SXj080iNGU0P3Rh^820>3Ph080g]kN0P3Lg=`2
0=_Kf`H0f][J2@3IfMT40=[JfP@0fm_K0P3Lg=`20=gMg@@0g]kN103Ogml20>3Ph080hN7Q0P3Rh^83
0>?Sh`@0i>CT103UiND:0>KViPH0iNGU1P3Ti>@30>?Sh`H0h^;R0P3QhN420=oOg`80g]kN0P3Lg=`2
0=WIf@80e]KF0P3AdM420<[:bP80aLG50P31`L420;fm_@030;Rh^02d];@0];Bd0080/K6a0P2^[Zh2
0:b/[080ZZZZ0P2XZ:P20:NWY`80YJFU0P2SXj<20:2PX080WYjN102LW9`409fMW@0309bLW02NWYh0
WYjN0080X:2P0P2SXj<20:FUY@80Z:RX0P2ZZZX20:f][AD0oooo000C0?ooo`80/K6a0P2b/[820;>c
/`80];Bd0P2e]KD20;Jf]P80]kNg0P2h^;P00`2i^KT0^[Zj0;Zj^P020;^k^`80_;bl0P2m_Kd20;no
_`80`<300P31`L420<?3``80a<C40P36a/H20<O7a`80bLW90P3;bl/20<g=c@80clo?00<0dM7A0=?C
d`3Cdm<00P3EeMD20=SHf080fm_K0P3Ng]h20>7Qh@80i>CT0P3Xj>P20>c/k080kno_0P3bl_820?Cd
m080m_Kf0P3inOT20?Shn0030?Cdm03`l?00l?3`0080k>c/0P3Xj>P20>GUi@80h^;R0P3Ph>020=kN
gP80g=cL0P3Kfm/60=[JfPT0fMWI103Jf]X40=_Kf`80g=cL0P3MgMd40=kNgP@0gmoO0P3Ph>020>7Q
h@80h^;R0`3Shn<40>CTi0@0iNGU2P3Vi^H60>GUi@H0i>CT0`3Shn<60>;RhP80hN7Q0P3Ogml20=kN
gP80g=cL0P3IfMT20=KFeP80dM7A0P3:b/X20<G5a@80`L710P2m_Kd00`2h^;P0];Bd0;Bd]0020;6a
/@80[Zj^0P2/[:`20:ZZZP80Z:RX0P2WYjL20:FUY@80Xj>S0P2PX:0209jNWP@0W9bL102MWId00`2L
W9`0WYjN09jNWP020:2PX080Xj>S0P2UYJD20:RXZ080ZZZZ0P2][JdE0?ooo`004`3oool20;6a/@80
/[:b0P2c/k<20;Bd]080]KFe0P2f][H20;Rh^080^KVi00<0^[Zj0;^k^`2k^k/00P2l_;`20;fm_@80
_kno0P30`<020<;2`P80`l?30P35aLD20<K6aP80alO70P39bLT20<_;b`80cLg=0P3?cll20=;BdP03
0=CDe03Fe]H0e]KF0080fMWI0P3Kfm/20=kNgP80hN7Q0P3UiND20>SXj080jn_[0P3^k^h20?7al@80
lo?c0P3emOD20?Ogm`80n?Sh0P3inOT00`3gmoL0lo?c0??cl`020>o_k`80jn_[0P3WinL20>CTi080
hN7Q0P3Ogml40=gMg@80g=cL3@3Kfm/40=cLg080gMgM0P3Ng]h40=oOg`80h>3P0P3QhN440>;RhP80
hn?S0P3Ti>@20>GUi@<0i^KV0P3WinL60>SXj0h0jNWY103Xj>P50>OWi`@0i^KV0P3UiND20>CTi080
hn?S0P3QhN420=kNgP80g=cL0P3Hf=P20=?Cd`80c<c<0P34a<@20<30`080_;bl0P2h^;P00`2d];@0
/;2`0;2`/0020:b/[080ZJVY0P2XZ:P20:NWY`80Y:BT0P2RXZ820:2PX080WYjN0P2LW9`209^KV`@0
VIVI0P2JVYX209VIV@0309^KV`2MWId0WIfM0080X:2P0P2RXZ820:BTY080YjNW0P2ZZZX20:f][AD0
oooo000C0?ooo`80/K6a0P2b/[820;>c/`80];Bd0P2e]KD20;Jf]P80^;Rh0P2i^KT00`2j^[X0^k^k
0;^k^`020;bl_080_Kfm0P2o_kl20<30`080`/;20P33`l<20<G5a@80a/K60P37alL20<W9b@80bl_;
0P3=cLd20<o?c`80d];B00<0e=CD0=KFeP3Fe]H00P3IfMT20=_Kf`80g]kN0P3QhN420>GUi@80j>SX
0P3[jn/20>k^kP80lO7a0P3clo<20?Gem@80moOg0P3hn?P20?Win@030?Ogm`3clo<0lo?c0080kno_
0P3[jn/20>OWi`80i>CT0P3QhN420=oOg`@0gMgM0P3Lg=`=0=_Kf`@0g=cL0P3MgMd20=kNgP@0gmoO
0P3Ph>020>7Qh@@0h^;R0P3Shn<20>CTi080iNGU0`3Vi^H20>OWi`H0j>SX3P3YjNT40>SXj0D0inOW
103Vi^H20>GUi@80i>CT0P3Shn<20>7Qh@80g]kN0P3Lg=`20=SHf080dm?C0P3<c<`20<C4a080`<30
0P2l_;`20;Rh^0030;Bd]02`/;00/;2`0080[:b/0P2YZJT20:RXZ080YjNW0P2TY:@20::RXP80X:2P
0P2NWYh209bLW080Vi^K102IVIT209ZJVP80VIVI00<0Vi^K09fMW@2MWId00P2PX:020::RXP80Y:BT
0P2WYjL20:ZZZP80[Jf]5@3oool001<0oooo0P2a/K420;:b/P80/k>c0P2d];@20;Fe]@80]kNg0P2h
^;P20;Vi^@030;Zj^P2l_;`0_;bl0080_[jn0P2o_kl20<30`080`/;20P33`l<20<G5a@80a/K60P38
b<P20<[:bP80c<c<0P3=cLd20=3@d080d];B0P3De=@00`3GemL0fMWI0=WIf@020=cLg080gmoO0P3R
h^820>GUi@80j>SX0P3[jn/20>k^kP80lO7a0P3dm?@20?Gem@P0moOg00<0nOWi0?Ogm`3gmoL00P3b
l_820>g]k@80jNWY0P3UiND20>;RhP80h>3P0P3Ogml20=kNgP@0gMgM203Lg=`50=gMg@80g]kN103O
gml20>3Ph080hN7Q0P3Rh^820>?Sh`80i>CT0P3UiND20>KViP80inOW103Xj>P00`3YjNT0j^[Z0>[Z
jP040>_[ja00k>c/103[jn/40>[ZjP030>WYj@3Xj>P0j>SX0080i^KV0P3UiND20>CTi080h^;R0P3P
h>020=gMg@80fMWI0P3Cdm<20<_;b`80a<C40P30`<020;bl_080]kNg0P2b/[800`2_[jl0[:b/0:b/
[0020:ZZZP80YjNW0P2TY:@20:6QX@80WinO0P2MWId209^KV`80VYZJ202HV9P409NGU`0309VIV@2L
W9`0W9bL0080WinO0P2QXJ420:BTY080YjNW0P2ZZZX20:f][AD0oooo000C0?ooo`80/K6a0P2b/[82
0;>c/`80];Bd0P2e]KD20;Ng]`80^;Rh0P2i^KT00`2j^[X0_;bl0;bl_0020;jn_P80_kno0P30`<02
0<;2`P80`l?30P35aLD20<K6aP80b<S80P3:b/X20<c<c080cLg=0P3@d=020=;BdP80e=CD00<0emOG
0=WIf@3IfMT00P3Lg=`20=oOg`80h^;R0P3UiND20>SXj080jn_[0P3^k^h20?7al@80m?Cd0P3emOD8
0?Ogm`030?Win@3gmoL0moOg0080l_;b0P3]kNd20>WYj@80iNGU0P3Rh^820>3Ph080gmoO0P3Ng]h4
0=gMg@P0g=cL1@3MgMd20=kNgP@0gmoO0P3Ph>020>7Qh@80h^;R0P3Shn<20>CTi080iNGU0P3Vi^H2
0>OWi`@0j>SX00<0jNWY0>[ZjP3Zj^X0103[jn/@0>c/k0@0jn_[103Zj^X00`3YjNT0j>SX0>SXj002
0>KViP80iNGU0P3Ti>@20>;RhP80h>3P0P3MgMd20=WIf@80dm?C0P3;bl/20<C4a080`<300P2l_;`2
0;Ng]`80/[:b00<0[jn_0:b/[02/[:`00P2ZZZX20:NWY`80Y:BT0P2QXJ4209nOW`80WIfM0P2KVi/2
09ZJVPP0V9RH102GUiL00`2IVIT0W9bL09bLW00209nOW`80XJ6Q0P2TY:@20:NWY`80ZZZZ0P2][JdE
0?ooo`004`3oool20;6a/@80/[:b0P2c/k<20;Bd]080][Jf0P2g]kL20;Rh^080^[Zj00<0^k^k0;fm
_@2m_Kd00P2o_kl20<30`080`/;20P33`l<20<G5a@80a/K60P38b<P20<[:bP80c<c<0P3>c/h20=3@
d080d];B0P3De=@20=KFeP030=WIf@3Lg=`0g=cL0080g]kN0P3QhN420>CTi080j>SX0P3[jn/20>o_
k`80l_;b0P3emOD40?KfmP@0moOg1@3fm_H20?Ogm`80m?Cd0P3^k^h20>WYj@80iNGU0P3Rh^820>3P
h080gmoO0P3Ng]h<0=gMg@<0g]kN0P3Ogml20>3Ph0@0hN7Q0P3Rh^820>?Sh`80i>CT0P3UiND20>KV
iP80inOW0P3Xj>P20>WYj@80j^[Z0`3[jn/20>c/k080kNg]0P3^k^h80>o_k`X0k^k^0P3]kNd20>c/
k080jn_[00<0j^[Z0>WYj@3YjNT00P3WinL20>GUi@80hn?S0P3QhN420=gMg@80f=SH0P3Bd]820<[:
bP80`l?30P2n_[h20;^k^`80^;Rh0P2c/k<20:n_[`030:b/[02ZZZX0ZZZZ0080YjNW0P2SXj<20:2P
X080WIfM0P2JVYX209RHV080UiNG102EUID809BDU080UYJF00<0V9RH09ZJVP2JVYX00P2MWId20:2P
X080Xj>S0P2VYZH20:VYZ@80[Jf]5@3oool001<0oooo0P2a/K420;:b/P80/k>c0P2d];@20;Jf]P80
]kNg0P2h^;P20;Zj^P030;^k^`2m_Kd0_Kfm0080_kno0P30`<020<;2`P80`l?30P35aLD20<K6aP80
b<S80P3:b/X20<c<c080c/k>0P3@d=020=;BdP80e=CD0P3Fe]H00`3IfMT0g=cL0=cLg0020=kNgP80
hN7Q0P3Ti>@20>SXj080jn_[0P3_knl20?;blP80mOGe103fm_H40?Ogm`D0m_Kf0P3gmoL20?Cdm080
k^k^0P3YjNT20>GUi@80h^;R0P3Ph>020=oOg`80g]kN303MgMd30=kNgP80gmoO0P3Ph>040>7Qh@80
h^;R0P3Shn<20>CTi080iNGU0P3Vi^H20>OWi`80j>SX0P3YjNT20>[ZjP<0jn_[0P3/k>`20>g]k@80
k^k^203_knl:0>k^kP80kNg]0P3/k>`20>_[j`030>[ZjP3YjNT0jNWY0080inOW0P3UiND20>?Sh`80
hN7Q0P3MgMd20=SHf080d];B0P3:b/X20<?3``80_[jn0P2k^k/20;Rh^080/k>c0P2_[jl00`2/[:`0
ZZZZ0:ZZZP020:NWY`80Xj>S0P2PX:0209fMW@80VYZJ0P2HV9P209NGU`@0UIFE202DU9@209JFUP03
09RHV02JVYX0VYZJ0080WIfM0P2PX:020:>SX`80YZJV0P2YZJT20:f][AD0oooo000C0?ooo`80/K6a
0P2b/[820;Bd]080]KFe0P2f][H20;Rh^080^KVi0P2k^k/00`2l_;`0_[jn0;jn_P020;no_`80`L71
0P33`l<20<C4a080a/K60P38b<P20<W9b@80bl_;0P3>c/h20=3@d080d];B0P3De=@20=KFeP80fMWI
00<0fm_K0=kNgP3Ng]h00P3QhN420>CTi080inOW0P3Zj^X20>k^kP80lO7a0P3dm?@80?Ogm`80m_Kf
0P3emOD30?Cdm0@0l_;b0P3^k^h20>SXj080i>CT0P3Rh^820>3Ph080gmoO0P3Ng]h80=gMg@@0g]kN
00<0gmoO0>3Ph03Ph>000P3Ph>020>7Qh@80h^;R0P3Shn<20>CTi080iNGU0P3Vi^H20>OWi`80j>SX
0P3YjNT40>_[j`80k>c/0P3]kNd00`3^k^h0kno_0>o_k`040?3`l0@0lO7a0P3bl_880?7al@@0l?3`
0P3_knl20>k^kP80k>c/00<0jn_[0>WYj@3YjNT00P3WinL20>GUi@80h^;R0P3MgMd20=SHf080dM7A
0P3:b/X20<C4a080_[jn0P2k^k/20;Ng]`80/k>c0P2_[jl20:^[Z`030:RXZ02TY:@0Y:BT0080XJ6Q
0P2NWYh209^KV`80V9RH0P2FUYH209BDU080Ti>C102BTY84096AT@80TY:B0P2DU9@209FEU@0309NG
U`2JVYX0VYZJ0080WIfM0P2PX:020:>SX`80YjNW0P2ZZZX20:f][AD0oooo000C0?ooo`80/K6a0P2b
/[820;Bd]080]KFe0P2f][H20;Rh^080^KVi0P2k^k/00`2l_;`0_[jn0;jn_P020;no_`80`L710P33
`l<20<C4a080a/K60P38b<P20<W9b@80bl_;0P3>c/h20=3@d080d];B0P3De=@20=KFeP80fMWI00<0
fm_K0=kNgP3Ng]h00P3QhN420>CTi080inOW0P3Zj^X20>k^kP80lO7a0P3dm?@80?Ogm`80m_Kf0P3e
mOD30?Cdm0@0l_;b0P3^k^h20>SXj080i>CT0P3Rh^820>3Ph080gmoO0P3Ng]h80=gMg@@0g]kN00<0
gmoO0>3Ph03Ph>000P3Ph>020>7Qh@80h^;R0P3Shn<20>CTi080iNGU0P3Vi^H20>OWi`80j>SX0P3Y
jNT40>_[j`80k>c/0P3]kNd00`3^k^h0kno_0>o_k`040?3`l0@0lO7a0P3bl_880?7al@@0l?3`0P3_
knl20>k^kP80k>c/00<0jn_[0>WYj@3YjNT00P3WinL20>GUi@80h^;R0P3MgMd20=SHf080dM7A0P3:
b/X20<C4a080_[jn0P2k^k/20;Ng]`80/k>c0P2_[jl20:^[Z`030:RXZ02TY:@0Y:BT0080XJ6Q0P2N
WYh209^KV`80V9RH0P2FUYH209BDU080Ti>C102BTY84096AT@80TY:B0P2DU9@209FEU@0309NGU`2J
VYX0VYZJ0080WIfM0P2PX:020:>SX`80YjNW0P2ZZZX20:f][AD0oooo000C0?ooo`80/K6a0P2b/[82
0;Bd]080][Jf0P2g]kL20;Vi^@80^[Zj0P2k^k/00`2m_Kd0_kno0;no_`020<71`@80`/;20P33`l<2
0<G5a@80b<S80P3:b/X20<_;b`80cLg=0P3?cll20=;BdP80e=CD0P3Fe]H20=WIf@80fm_K00<0g]kN
0>3Ph03Ph>000P3Shn<20>KViP80j^[Z0P3]kNd20?3`l080m?Cd0P3gmoL40?Win@80n?Sh0P3gmoL2
0?Gem@80lo?c0P3bl_800`3alO40k^k^0>k^kP020>_[j`80inOW0P3Vi^H20>?Sh`80h>3P0P3Ogml2
0=kNgPP0gMgM103Ng]h20=oOg`030>3Ph03QhN40hN7Q00@0h^;R0P3Shn<20>CTi080iNGU0P3Vi^H2
0>OWi`80jNWY0P3Zj^X20>_[j`@0kNg]0P3^k^h20>o_k`030?3`l03alO40lO7a0080l_;b103clo<4
0?Cdm080lo?c2P3bl_820?3`l080kno_0P3]kNd00`3[jn/0j>SX0>SXj0020>GUi@80hN7Q0P3Lg=`2
0=KFeP80d=3@0P39bLT20<C4a080_kno0P2j^[X20;Ng]`80/k>c0P2_[jl20:^[Z`80Z:RX00<0Y:BT
0:6QX@2QXJ400P2NWYh209^KV`80V9RH0P2EUID209>CT`80TI6A0P2@T90408n?S`80SXj>0P2?Shl2
092@T080TI6A0P2DU9@00`2FUYH0VIVI09VIV@0209fMW@80X:2P0P2SXj<20:JVYP80ZJVY0P2][JdE
0?ooo`004`3oool20;6a/@80/[:b0P2d];@20;Jf]P80]kNg0P2i^KT20;Zj^P80^k^k00<0_Kfm0;no
_`2o_kl00P31`L420<;2`P80`l?30P35aLD20<S8b080b/[:0P3;bl/20<g=c@80clo?0P3Bd]820=CD
e080e]KF0P3IfMT20=_Kf`030=kNgP3Ph>00h>3P0080hn?S0P3Vi^H20>[ZjP80kNg]0P3`l?020?Cd
m080moOg103inOT20?Shn080moOg0P3emOD20??cl`80l_;b00<0lO7a0>k^kP3^k^h00P3[jn/20>OW
i`80i^KV0P3Shn<20>3Ph080gmoO0P3Ng]h80=gMg@@0g]kN0P3Ogml00`3Ph>00hN7Q0>7Qh@040>;R
hP80hn?S0P3Ti>@20>GUi@80i^KV0P3WinL20>WYj@80j^[Z0P3[jn/40>g]k@80k^k^0P3_knl00`3`
l?00lO7a0?7al@020?;blP@0lo?c103dm?@20??cl`X0l_;b0P3`l?020>o_k`80kNg]00<0jn_[0>SX
j03Xj>P00P3UiND20>7Qh@80g=cL0P3Fe]H20=3@d080bLW90P34a<@20;no_`80^[Zj0P2g]kL20;>c
/`80[jn_0P2[Zj/20:RXZ0030:BTY02QXJ40XJ6Q0080WYjN0P2KVi/209RHV080UIFE0P2CTi<2096A
T@80T92@102?Shl208j>SP80Shn?0P2@T902096AT@80U9BD00<0UYJF09VIV@2IVIT00P2MWId20:2P
X080Xj>S0P2VYZH20:VYZ@80[Jf]5@3oool001<0oooo0P2a/K420;>c/`80];Bd0P2f][H20;Rh^080
^KVi0P2k^k/20;bl_0030;jn_P30`<00`<300080`L710P33`l<20<G5a@80alO70P38b<P20<_;b`80
cLg=0P3?cll20=;BdP80e=CD0P3Fe]H20=SHf080fm_K0P3MgMd00`3Ph>00hn?S0>?Sh`020>KViP80
jNWY0P3/k>`20?3`l080lo?c0P3fm_H20?[jnP80no_k0P3inOT20?Shn080m_Kf0P3dm?@20?;blP80
l?3`00<0kNg]0>[ZjP3Zj^X00P3WinL20>KViP80i>CT0P3Ph>020=kNgP80gMgM1P3Lg=`40=gMg@80
g]kN0P3Ogml20>3Ph0<0hN7Q0P3Rh^820>?Sh`80iNGU0P3Vi^H20>OWi`80j>SX0P3YjNT20>[ZjP80
jn_[0P3]kNd20>k^kP80kno_0P3`l?020?7al@030?;blP3clo<0lo?c0080m?Cd203emOD20?Cdm080
lo?c0P3dm?@20?Gem@80m?Cd0P3bl_820?3`l080k^k^0P3/k>`00`3YjNT0iNGU0>GUi@020>7Qh@80
g=cL0P3EeMD20<k>cP80b<S80P33`l<20;fm_@80^;Rh0P2e]KD20;:b/P80[jn_0P2[Zj/20:NWY`80
YJFU00<0XZ:R09nOW`2OWil00P2KVi/209RHV080UYJF0P2CTi<2092@T080SXj>102=SHd408b<S080
SHf=0P2>SXh2092@T080Ti>C00<0UYJF09ZJVP2JVYX00P2MWId20:2PX080Xj>S0P2VYZH20:VYZ@80
[Jf]5@3oool001<0oooo0P2a/K420;>c/`80];Bd0P2f][H20;Rh^080^KVi0P2k^k/20;bl_0030;jn
_P30`<00`<300080`L710P33`l<20<G5a@80alO70P38b<P20<_;b`80cLg=0P3?cll20=;BdP80e=CD
0P3Fe]H20=SHf080fm_K0P3MgMd00`3Ph>00hn?S0>?Sh`020>KViP80jNWY0P3/k>`20?3`l080lo?c
0P3fm_H20?[jnP80no_k0P3inOT20?Shn080m_Kf0P3dm?@20?;blP80l?3`00<0kNg]0>[ZjP3Zj^X0
0P3WinL20>KViP80i>CT0P3Ph>020=kNgP80gMgM1P3Lg=`40=gMg@80g]kN0P3Ogml20>3Ph0<0hN7Q
0P3Rh^820>?Sh`80iNGU0P3Vi^H20>OWi`80j>SX0P3YjNT20>[ZjP80jn_[0P3]kNd20>k^kP80kno_
0P3`l?020?7al@030?;blP3clo<0lo?c0080m?Cd203emOD20?Cdm080lo?c0P3dm?@20?Gem@80m?Cd
0P3bl_820?3`l080k^k^0P3/k>`00`3YjNT0iNGU0>GUi@020>7Qh@80g=cL0P3EeMD20<k>cP80b<S8
0P33`l<20;fm_@80^;Rh0P2e]KD20;:b/P80[jn_0P2[Zj/20:NWY`80YJFU00<0XZ:R09nOW`2OWil0
0P2KVi/209RHV080UYJF0P2CTi<2092@T080SXj>102=SHd408b<S080SHf=0P2>SXh2092@T080Ti>C
00<0UYJF09ZJVP2JVYX00P2MWId20:2PX080Xj>S0P2VYZH20:VYZ@80[Jf]5@3oool001<0oooo0P2a
/K420;>c/`80]KFe0P2f][H20;Rh^080^KVi0P2k^k/20;fm_@030;jn_P30`<00`<300080`/;20P34
a<@20<K6aP80b<S80P3:b/X20<c<c080c/k>0P3AdM420=?Cd`80eMGE0P3Hf=P20=[JfP80gMgM0P3O
gml00`3Rh^80iNGU0>GUi@020>SXj080jn_[0P3_knl20?;blP80mOGe0P3inOT40?_kn`80n_[j0P3h
n?P20?KfmP80lo?c0P3alO420>k^kP030>[ZjP3Vi^H0i^KV0080i>CT0P3Rh^820=oOg`80gMgM0P3L
g=`60=_Kf`80g=cL103MgMd20=kNgP80gmoO0P3Ph>000`3QhN40h^;R0>;RhP020>?Sh`80i>CT0P3V
i^H20>OWi`80j>SX0P3YjNT20>[ZjP80k>c/0P3]kNd20>k^kP80kno_0P3`l?020?7al@80lo?c00<0
m?Cd0?Gem@3emOD00P3emOD20?KfmP80moOg0P3fm_H60?Gem@80m_Kf0P3emOD20?;blP80lO7a0P3_
knl20>g]k@80jn_[00<0i^KV0>3Ph03Ph>000P3Kfm/20=GEe@80clo?0P39bLT20<C4a080_kno0P2j
^[X20;Jf]P80/[:b0P2^[Zh20:^[Z`80Z:RX0P2TY:@20:6QX@0309fMW@2KVi/0Vi^K0080UiNG0P2E
UID209:BTP80Shn?102<S8`208^;R`H0RXZ:0P2<S8`208j>SP80T92@0P2CTi<00`2FUYH0VIVI09VI
V@0209bLW080X:2P0P2SXj<20:JVYP80ZJVY0P2][JdE0?ooo`004`3oool20;6a/@80/k>c0P2e]KD2
0;Jf]P80^;Rh0P2i^KT20;^k^`80_Kfm00<0_[jn0<30`030`<000P32`/820<C4a080a/K60P38b<P2
0<[:bP80c<c<0P3>c/h20=7Ad@80dm?C0P3EeMD20=SHf080f][J0P3MgMd20=oOg`030>;RhP3UiND0
iNGU0080j>SX0P3[jn/20>o_k`80l_;b0P3emOD20?Win@@0no_k0P3jn_X20?Shn080m_Kf0P3clo<2
0?7al@80k^k^00<0j^[Z0>KViP3Vi^H00P3Ti>@20>;RhP80gmoO0P3MgMd20=cLg0H0fm_K0P3Lg=`4
0=gMg@80g]kN0P3Ogml20>3Ph0030>7Qh@3Rh^80h^;R0080hn?S0P3Ti>@20>KViP80inOW0P3Xj>P2
0>WYj@80j^[Z0P3/k>`20>g]k@80k^k^0P3_knl20?3`l080lO7a0P3clo<00`3dm?@0mOGe0?Gem@02
0?Gem@80m_Kf0P3gmoL20?KfmPH0mOGe0P3fm_H20?Gem@80l_;b0P3alO420>o_k`80kNg]0P3[jn/0
0`3Vi^H0h>3P0>3Ph0020=_Kf`80eMGE0P3?cll20<W9b@80a<C40P2o_kl20;Zj^P80][Jf0P2b/[82
0:j^[P80Zj^[0P2XZ:P20:BTY080XJ6Q00<0WIfM09^KV`2KVi/00P2GUiL209FEU@80TY:B0P2?Shl4
08b<S080Rh^;1P2:RXX208b<S080SXj>0P2@T90209>CT`0309JFUP2IVIT0VIVI0080W9bL0P2PX:02
0:>SX`80YZJV0P2YZJT20:f][AD0oooo000C0?ooo`80/[:b0P2c/k<20;Fe]@80][Jf0P2h^;P20;Zj
^P80_;bl0P2m_Kd00`2o_kl0`L710<71`@020<?3``80aLG50P37alL20<W9b@80bl_;0P3>c/h20=3@
d080d];B0P3De=@20=OGe`80fMWI0P3Lg=`20=kNgP80hN7Q00<0i>CT0>OWi`3WinL00P3Zj^X20>g]
k@80l?3`0P3dm?@20?Ogm`80no_k103lo?`20?[jnP80n?Sh0P3fm_H20??cl`80l?3`0P3/k>`00`3W
inL0hn?S0>?Sh`020>7Qh@80gmoO0P3Jf]X40=WIf@H0f][J0P3Kfm/40=cLg080gMgM0P3Ogml20>3P
h0030>7Qh@3Shn<0hn?S0080i>CT0P3UiND20>KViP80j>SX0P3YjNT20>[ZjP80k>c/0P3]kNd20>k^
kP80kno_0P3alO420?;blP80lo?c0P3dm?@00`3emOD0m_Kf0?KfmP080?Ogm`@0m_Kf0P3hn?P20?Og
m`80mOGe0P3bl_820?3`l080k^k^0P3Zj^X20>KViP030>3Ph03IfMT0fMWI0080e=CD0P3>c/h20<W9
b@80a<C40P30`<020;^k^`80][Jf0P2b/[820:j^[P80Zj^[0P2VYZH20::RXP80WinO0P2MWId00`2J
VYX0V9RH09RHV00209FEU@80TY:B0P2?Shl208b<S080RXZ:0P29RHT208R8R0@0QhN70P29RHT208^;
R`80SXj>0P2@T90209>CT`0309JFUP2IVIT0VIVI0080WIfM0P2PX:020:>SX`80YZJV0P2YZJT20:f]
[AD0oooo000C0?ooo`80/[:b0P2c/k<20;Fe]@80][Jf0P2h^;P20;Zj^P80_;bl0P2m_Kd00`2o_kl0
`L710<71`@020<?3``80aLG50P37alL20<W9b@80bl_;0P3>c/h20=3@d080d];B0P3De=@20=OGe`80
fMWI0P3Lg=`20=kNgP80hN7Q00<0i>CT0>OWi`3WinL00P3Zj^X20>g]k@80l?3`0P3dm?@20?Ogm`80
no_k103lo?`20?[jnP80n?Sh0P3fm_H20??cl`80l?3`0P3/k>`00`3WinL0hn?S0>?Sh`020>7Qh@80
gmoO0P3Jf]X40=WIf@H0f][J0P3Kfm/40=cLg080gMgM0P3Ogml20>3Ph0030>7Qh@3Shn<0hn?S0080
i>CT0P3UiND20>KViP80j>SX0P3YjNT20>[ZjP80k>c/0P3]kNd20>k^kP80kno_0P3alO420?;blP80
lo?c0P3dm?@00`3emOD0m_Kf0?KfmP080?Ogm`@0m_Kf0P3hn?P20?Ogm`80mOGe0P3bl_820?3`l080
k^k^0P3Zj^X20>KViP030>3Ph03IfMT0fMWI0080e=CD0P3>c/h20<W9b@80a<C40P30`<020;^k^`80
][Jf0P2b/[820:j^[P80Zj^[0P2VYZH20::RXP80WinO0P2MWId00`2JVYX0V9RH09RHV00209FEU@80
TY:B0P2?Shl208b<S080RXZ:0P29RHT208R8R0@0QhN70P29RHT208^;R`80SXj>0P2@T90209>CT`03
09JFUP2IVIT0VIVI0080WIfM0P2PX:020:>SX`80YZJV0P2YZJT20:f][AD0oooo000C0?ooo`80/[:b
0P2c/k<20;Fe]@80]kNg0P2i^KT20;^k^`80_Kfm0P2n_[h00`30`<00`/;20<;2`P020<C4a080a/K6
0P38b<P20<[:bP80cLg=0P3?cll20=7Ad@80e=CD0P3Fe]H20=SHf080fm_K0P3MgMd20>3Ph080hn?S
00<0i^KV0>WYj@3YjNT00P3/k>`20>o_k`80lo?c0P3fm_H20?Win@H0o?cl0P3inOT20?Ogm`80m?Cd
0P3alO420>k^kP80jNWY00<0iNGU0>;RhP3Rh^800P3Ogml20=_Kf`H0e]KF0P3GemL40=SHf080fMWI
0P3Jf]X20=_Kf`80gMgM0P3Ng]h20=oOg`030>7Qh@3Shn<0hn?S0080i>CT0P3UiND20>OWi`80jNWY
0P3Zj^X20>_[j`80k>c/0P3^k^h20>o_k`80l?3`0P3alO420?;blP80lo?c0P3dm?@00`3emOD0moOg
0?Ogm`020?Ogm`80n?Sh1P3gmoL20?Shn080moOg0P3emOD20??cl`80l?3`0P3^k^h20>[ZjP80i^KV
0P3Ogml00`3IfMT0dm?C0=?Cd`020<g=c@80alO70P33`l<20;jn_P80^KVi0P2e]KD20;6a/@80[Zj^
0P2[Zj/20:NWY`80XZ:R0P2NWYh209bLW080VYZJ00<0UiNG09BDU02DU9@00P2ATI4208j>SP80Rh^;
0P28R8P208N7Q`80QXJ61025QHD208N7Q`80RHV90P2;Rh/208j>SP80T92@0P2DU9@00`2FUYH0VIVI
09VIV@0209fMW@80X:2P0P2SXj<20:JVYP80ZJVY0P2][JdE0?ooo`004`3oool20;:b/P80/k>c0P2e
]KD20;Ng]`80^KVi0P2k^k/20;fm_@80_[jn00<0`<300<;2`P32`/800P34a<@20<K6aP80b<S80P3:
b/X20<g=c@80clo?0P3AdM420=CDe080e]KF0P3Hf=P20=_Kf`80gMgM0P3Ph>020>?Sh`030>KViP3Y
jNT0jNWY0080k>c/0P3_knl20??cl`80m_Kf0P3inOT60?clo080nOWi0P3gmoL20?Cdm080lO7a0P3^
k^h20>WYj@030>GUi@3Rh^80h^;R0080gmoO0P3Kfm/60=KFeP80emOG103Hf=P20=WIf@80f][J0P3K
fm/20=gMg@80g]kN0P3Ogml00`3QhN40hn?S0>?Sh`020>CTi080iNGU0P3WinL20>WYj@80j^[Z0P3[
jn/20>c/k080k^k^0P3_knl20?3`l080lO7a0P3bl_820??cl`80m?Cd00<0mOGe0?Ogm`3gmoL00P3g
moL20?Shn0H0moOg0P3hn?P20?Ogm`80mOGe0P3clo<20?3`l080k^k^0P3Zj^X20>KViP80gmoO00<0
fMWI0=?Cd`3Cdm<00P3=cLd20<O7a`80`l?30P2n_[h20;Vi^@80]KFe0P2a/K420:j^[P80Zj^[0P2W
YjL20::RXP80WYjN0P2LW9`209ZJVP0309NGU`2DU9@0U9BD0080TI6A0P2>SXh208^;R`80R8R80P27
QhL208J6QP@0QHF50P27QhL208V9R@80Rh^;0P2>SXh2092@T080U9BD00<0UYJF09VIV@2IVIT00P2M
WId20:2PX080Xj>S0P2VYZH20:VYZ@80[Jf]5@3oool001<0oooo0P2b/[820;Bd]080]KFe0P2g]kL2
0;Vi^@80^k^k0P2m_Kd20;no_`030<71`@33`l<0`l?30080aLG50P37alL20<[:bP80c<c<0P3>c/h2
0=3@d080dm?C0P3EeMD20=OGe`80f][J0P3MgMd20=oOg`80h^;R0P3UiND00`3Xj>P0jn_[0>_[j`02
0>k^kP80l_;b0P3emOD20?Shn080no_k0P3moOd20?clo080no_k0P3inOT20?KfmP80lo?c0P3_knl2
0>_[j`80i^KV00<0i>CT0>7Qh@3QhN400P3MgMd20=SHf0@0dm?C0P3De=@20=GEe@@0e]KF0P3GemL2
0=WIf@80fm_K0P3Lg=`20=gMg@80gmoO00<0hN7Q0>;RhP3Rh^800P3Ti>@20>KViP80inOW0P3YjNT2
0>[ZjP80jn_[0P3]kNd20>k^kP80kno_0P3`l?020?7al@80lo?c103dm?@00`3emOD0m_Kf0?KfmP04
0?Ogm`H0m_Kf0P3gmoL20?KfmP80lo?c0P3alO420>k^kP80j^[Z0P3UiND20=oOg`80f][J00<0dm?C
0<g=c@3=cLd00P38b<P20<;2`P80_Kfm0P2h^;P20;Fe]@80/[:b0P2^[Zh20:^[Z`80YjNW0P2SXj<2
09nOW`80W9bL0P2HV9P209JFUP0309>CT`2@T900T92@0080SHf=0P2;Rh/208R8R080QXJ60P25QHD2
08B4Q080Ph>30P24Q8@208J6QP80R8R80P2;Rh/208f=S@80T92@0P2CTi<00`2FUYH0VIVI09VIV@02
09fMW@80X:2P0P2SXj<20:JVYP80ZZZZ0P2][JdE0?ooo`004`3oool20;:b/P80];Bd0P2f][H20;Rh
^080^[Zj0P2l_;`20;jn_P80`<3000<0`/;20<C4a034a<@00P36a/H20<S8b080bl_;0P3=cLd20<o?
c`80d];B0P3De=@20=KFeP80fMWI0P3Lg=`20=kNgP80hN7Q0P3Ti>@20>OWi`030>[ZjP3]kNd0kNg]
0080l?3`0P3clo<20?KfmP80nOWi0P3lo?`20?knoP80oOgm0P3kno/20?Shn080mOGe0P3alO420>k^
kP80jNWY0P3UiND00`3Shn<0gmoO0=oOg`020=WIf@80e=CD0P3?cll20=3@d080dM7A0P3Bd]820=?C
d`80e=CD0P3Fe]H20=OGe`80f=SH0P3Jf]X20=cLg080g]kN00<0gmoO0>7Qh@3QhN400P3Shn<20>GU
i@80i^KV0P3Xj>P20>[ZjP80jn_[0P3/k>`20>g]k@80kno_0P3`l?020?7al@80l_;b0P3clo<20?Cd
m0<0mOGe103fm_H40?Gem@80m_Kf0P3emOD20??cl`80l?3`0P3]kNd20>[ZjP80iNGU0P3Ph>020=_K
f`80eMGE00<0c/k>0<S8b038b<P00P32`/820;fm_@80^;Rh0P2d];@20;2`/080[Zj^0P2[Zj/20:NW
Y`80Xj>S0P2PX:0209bLW080VIVI0P2FUYH209BDU003092@T02=SHd0SHf=0080Rh^;0P27QhL208F5
Q@80Q8B41022PX8208>3P`80QHF50P27QhL208R8R080RXZ:0P2=SHd2092@T080Ti>C00<0UYJF09VI
V@2IVIT00P2MWId20:2PX080Xj>S0P2VYZH20:VYZ@80[Jf]5@3oool001<0oooo0P2b/[820;Bd]080
][Jf0P2h^;P20;Zj^P80_;bl0P2n_[h20<30`0030<;2`P34a<@0a<C40080a/K60P38b<P20<_;b`80
cLg=0P3?cll20=;BdP80e=CD0P3Fe]H20=WIf@80g=cL0P3Ng]h20>7Qh@80i>CT0P3WinL00`3Zj^X0
kNg]0>g]k@020?3`l080lo?c0P3fm_H20?Win@80o?cl0P3no_h20?gmo@80no_k0P3hn?P20?Gem@80
lO7a0P3^k^h20>WYj@80iNGU00<0hn?S0=oOg`3Ogml00P3IfMT20=CDe080clo?0P3@d=020=7Ad@80
d];B0P3Cdm<20=CDe080e]KF0P3GemL20=SHf080f][J0P3Lg=`20=kNgP030=oOg`3QhN40hN7Q0080
hn?S0P3UiND20>KViP80j>SX0P3Zj^X20>_[j`80k>c/0P3]kNd20>o_k`80l?3`0P3alO420?;blP80
lo?c0P3dm?@30?Gem@@0m_Kf103emOD20?KfmP80mOGe0P3clo<20?3`l080kNg]0P3Zj^X20>GUi@80
h>3P0P3Kfm/20=GEe@030<k>cP38b<P0b<S80080`/;20P2m_Kd20;Rh^080];Bd0P2`/;020:j^[P80
Zj^[0P2WYjL20:>SX`80X:2P0P2LW9`209VIV@80UYJF0P2DU9@00`2@T900SHf=08f=S@0208^;R`80
QhN70P25QHD208B4Q0@0PX:20P23Ph<208F5Q@80QhN70P28R8P208Z:RP80SHf=0P2@T90209>CT`03
09JFUP2IVIT0VIVI0080WIfM0P2PX:020:>SX`80YZJV0P2YZJT20:f][AD0oooo000C0?ooo`80/[:b
0P2d];@20;Jf]P80^;Rh0P2j^[X20;fm_@80_kno0P31`L400`33`l<0aLG50<G5a@020<O7a`80bLW9
0P3<c<`20<k>cP80dM7A0P3Cdm<20=KFeP80f=SH0P3Kfm/20=kNgP80h>3P0P3Shn<20>KViP80jNWY
00<0k>c/0>o_k`3_knl00P3bl_820?Gem@80n?Sh0P3kno/40?knoP80oOgm0P3kno/20?Shn080m?Cd
0P3`l?020>c/k080inOW0P3Shn<00`3Ogml0fm_K0=_Kf`020=GEe@80d=3@0P3<c<`20<g=c@80c/k>
0P3?cll20=3@d080d];B0P3Cdm<20=GEe@80e]KF0P3Hf=P20=[JfP80g=cL00<0g]kN0=oOg`3Ogml0
0P3QhN420>?Sh`80iNGU0P3WinL20>WYj@80j^[Z0P3[jn/20>g]k@80k^k^0P3_knl20?3`l080lO7a
0P3bl_820??cl`030?Cdm03emOD0mOGe0080mOGe1P3dm?@20??cl`80lO7a0P3_knl20>c/k080jNWY
0P3Ti>@20=oOg`80fm_K0P3EeMD20<k>cP030<S8b033`l<0`l?30080_[jn0P2i^KT20;Bd]080/;2`
0P2/[:`20:VYZ@80YZJV0P2SXj<20:2PX080W9bL0P2IVIT209JFUP80Ti>C0P2@T9000`2=SHd0S8b<
08b<S00208V9R@80QHF50P23Ph<60861P@80Ph>30P24Q8@208J6QP80R8R80P2:RXX208f=S@80T92@
0P2CTi<00`2FUYH0VIVI09VIV@0209fMW@80X:2P0P2SXj<20:JVYP80ZJVY0P2][JdE0?ooo`004`3o
ool20;:b/P80];Bd0P2f][H20;Rh^080^[Zj0P2m_Kd20;no_`80`L7100<0`l?30<G5a@35aLD00P37
alL20<W9b@80c<c<0P3>c/h20=7Ad@80dm?C0P3Fe]H20=SHf080fm_K0P3Ng]h20>3Ph080hn?S0P3V
i^H20>WYj@030>c/k03_knl0kno_0080l_;b0P3emOD20?Shn080no_k103no_h20?gmo@80no_k0P3h
n?P20?Cdm080l?3`0P3/k>`20>OWi`80hn?S00<0gmoO0=_Kf`3Kfm/00P3EeMD20=3@d080c<c<0P3=
cLd20<k>cP80clo?0P3@d=020=;BdP80dm?C0P3EeMD20=KFeP80f=SH0P3Jf]X20=cLg0030=kNgP3O
gml0gmoO0080hN7Q0P3Shn<20>GUi@80inOW0P3YjNT20>[ZjP80jn_[0P3]kNd20>k^kP80kno_0P3`
l?020?7al@80l_;b0P3clo<00`3dm?@0mOGe0?Gem@020?Gem@H0m?Cd0P3clo<20?7al@80kno_0P3/
k>`20>WYj@80i>CT0P3Ogml20=_Kf`80eMGE0P3>c/h00`38b<P0`l?30<?3``020;jn_P80^KVi0P2d
];@20;2`/080[:b/0P2YZJT20:JVYP80Xj>S0P2PX:0209bLW080VIVI0P2FUYH209>CT`80T92@00<0
SHf=08b<S02<S8`00P29RHT208F5Q@80Ph>31P21PH4208>3P`80Q8B40P26QXH208R8R080RXZ:0P2=
SHd2092@T080Ti>C00<0UYJF09VIV@2IVIT00P2MWId20:2PX080Xj>S0P2VYZH20:VYZ@80[Jf]5@3o
ool001<0oooo0P2b/[820;Bd]080]kNg0P2i^KT20;^k^`80_Kfm0P2o_kl20<71`@030<?3``36a/H0
a/K60080b<S80P3;bl/20<g=c@80clo?0P3Bd]820=CDe080emOG0P3Jf]X20=gMg@80gmoO0P3Rh^82
0>CTi080inOW0P3Zj^X00`3]kNd0l?3`0?3`l0020??cl`80moOg0P3jn_X20?gmo@80oooo0P3no_h2
0?clo080n_[j0P3fm_H20?7al@80k^k^0P3YjNT20>CTi080h>3P00<0gMgM0=OGe`3GemL00P3Bd]82
0<g=c@80b<S80P39bLT20<[:bP80c<c<0P3=cLd20<o?c`80d=3@0P3Bd]820=CDe080e]KF0P3GemL2
0=WIf@030=_Kf`3MgMd0gMgM0080gmoO0P3QhN420>?Sh`80iNGU0P3WinL20>WYj@80j^[Z0P3/k>`2
0>g]k@80k^k^0P3_knl20?3`l080lO7a0P3bl_850??cl`H0l_;b0P3alO420>k^kP80j^[Z0P3WinL2
0>?Sh`80gmoO0P3Kfm/20=GEe@80c/k>0P38b<P00`33`l<0_[jn0;jn_P020;Vi^@80];Bd0P2_[jl2
0:^[Z`80YjNW0P2UYJD20::RXP80WinO0P2KVi/209VIV@80UYJF0P2CTi<2092@T080SXj>00<0S8b<
08V9R@29RHT00P26QXH208:2PP80P820101oOgl20820P080PX:20P24Q8@208J6QP80R8R80P2:RXX2
08f=S@80T92@0P2CTi<00`2FUYH0VYZJ09ZJVP0209fMW@80X:2P0P2SXj<20:JVYP80ZJVY0P2][JdE
0?ooo`004`3oool20;:b/P80];Bd0P2g]kL20;Vi^@80^k^k0P2m_Kd20;no_`80`L7100<0`l?30<K6
aP36a/H00P38b<P20<_;b`80cLg=0P3?cll20=;BdP80e=CD0P3GemL20=[JfP80gMgM0P3Ogml20>;R
hP80i>CT0P3WinL20>[ZjP030>g]k@3`l?00l?3`0080lo?c0P3gmoL20?[jnP80oOgm0P3oool20?kn
oP80o?cl0P3jn_X20?KfmP80lO7a0P3^k^h20>WYj@80i>CT0P3Ph>000`3MgMd0emOG0=OGe`020=;B
dP80cLg=0P38b<P20<W9b@80b/[:0P3<c<`20<g=c@80clo?0P3@d=020=;BdP80e=CD0P3Fe]H20=OG
e`80fMWI00<0fm_K0=gMg@3MgMd00P3Ogml20>7Qh@80hn?S0P3UiND20>OWi`80jNWY0P3Zj^X20>c/
k080kNg]0P3^k^h20>o_k`80l?3`0P3alO420?;blPD0lo?c1P3bl_820?7al@80k^k^0P3Zj^X20>OW
i`80hn?S0P3Ogml20=_Kf`80eMGE0P3>c/h20<S8b0030<?3``2n_[h0_[jn0080^KVi0P2d];@20:n_
[`80Zj^[0P2WYjL20:FUY@80XZ:R0P2OWil209^KV`80VIVI0P2FUYH209>CT`80T92@0P2>SXh00`2<
S8`0RHV908V9R@0208J6QP80PX:20P20P80407moO`80P8200P22PX8208B4Q080QXJ60P28R8P208Z:
RP80SHf=0P2@T90209>CT`0309JFUP2JVYX0VYZJ0080WIfM0P2PX:020:>SX`80YZJV0P2YZJT20:f]
[AD0oooo000C0?ooo`80/[:b0P2d];@20;Jf]P80^KVi0P2k^k/20;fm_@80`<300P32`/800`34a<@0
a/K60<K6aP020<W9b@80bl_;0P3>c/h20=3@d080dm?C0P3Fe]H20=SHf080fm_K0P3Ng]h20>3Ph080
hn?S0P3Vi^H20>WYj@80k>c/00<0kno_0?;blP3bl_800P3emOD20?Shn080no_k0P3no_h20?ooo`80
o_kn0P3lo?`20?Shn080mOGe0P3`l?020>_[j`80i^KV0P3Rh^820=kNgP030=WIf@3Bd]80d];B0080
c<c<0P38b<P20<C4a080aLG50P36a/H20<O7a`80bLW90P3;bl/20<g=c@80clo?0P3AdM420=;BdP80
e=CD0P3Fe]H00`3Hf=P0f][J0=[JfP020=cLg080g]kN0P3Ph>020>;RhP80i>CT0P3Vi^H20>SXj080
jNWY0P3[jn/20>c/k080kNg]0P3^k^h20>o_k`80l?3`1@3alO420?3`l080kno_0P3^k^h20>c/k080
jNWY0P3Vi^H20>;RhP80gmoO0P3Lg=`20=OGe`80d=3@0P39bLT20<;2`P030;fm_@2i^KT0^KVi0080
]KFe0P2a/K420:b/[080Z:RX0P2TY:@20:2PX080WIfM0P2JVYX209NGU`80UIFE0P2CTi<2092@T080
SXj>0P2<S8`00`2:RXX0QXJ608J6QP0208:2PP80Ogmo0P1nOWh207emO@80OWin0P20P8020861P@80
Ph>30P25QHD208N7Q`80Rh^;0P2>SXh2092@T080Ti>C00<0UiNG09ZJVP2JVYX00P2MWId20:2PX080
Xj>S0P2VYZH20:VYZ@80[Jf]5@3oool001<0oooo0P2b/[820;Bd]080][Jf0P2i^KT20;^k^`80_Kfm
0P30`<020<;2`P030<C4a036a/H0a/K60080bLW90P3;bl/20<k>cP80d=3@0P3Cdm<20=KFeP80f=SH
0P3Kfm/20=kNgP80h>3P0P3Shn<20>KViP80jNWY0P3/k>`00`3_knl0l_;b0?;blP020?Gem@80n?Sh
0P3kno/20?knoP80oooo0P3no_h20?clo080n?Sh0P3emOD20?3`l080jn_[0P3Vi^H20>;RhP80g]kN
00<0fMWI0=;BdP3Bd]800P3<c<`20<S8b080a<C40P35aLD20<K6aP80alO70P39bLT20<_;b`80cLg=
0P3?cll20=7Ad@80d];B0P3De=@20=KFeP030=SHf03Jf]X0f][J0080g=cL0P3Ng]h20>3Ph080h^;R
0P3Ti>@20>KViP80j>SX0P3YjNT20>_[j`80k>c/0P3]kNd20>k^kP80kno_0P3`l?050?7al@80l?3`
0P3_knl20>k^kP80k>c/0P3YjNT20>KViP80h^;R0P3Ogml20=cLg080emOG0P3@d=020<W9b@80`/;2
00<0_Kfm0;Vi^@2i^KT00P2e]KD20;6a/@80[:b/0P2XZ:P20:BTY080X:2P0P2MWId209ZJVP80UiNG
0P2EUID209>CT`80T92@0P2>SXh208b<S00308Z:RP26QXH0QXJ60080PX:20P1oOgl207inOP80OGem
0P1nOWh20820P080PH610P23Ph<208F5Q@80QhN70P2;Rh/208j>SP80T92@0P2CTi<00`2GUiL0VYZJ
09ZJVP0209fMW@80X:2P0P2SXj<20:JVYP80ZJVY0P2][JdE0?ooo`004`3oool20;:b/P80];Bd0P2g
]kL20;Vi^@80^k^k0P2n_[h20<30`080`/;200<0a<C40<O7a`37alL00P3:b/X20<c<c080clo?0P3A
dM420=CDe080emOG0P3Jf]X20=cLg080gmoO0P3Rh^820>GUi@80inOW0P3Zj^X20>k^kP030?7al@3c
lo<0lo?c0080moOg0P3jn_X20?gmo@@0oooo0P3moOd20?_kn`80moOg0P3bl_820>g]k@80j>SX0P3S
hn<20=oOg`80fMWI00<0dm?C0<c<c03<c<`00P36a/H20<;2`P80_[jn0P30`<020<71`@80`l?30P35
aLD20<O7a`80bLW90P3;bl/20<c<c080c/k>0P3@d=020=;BdP030=CDe03Fe]H0e]KF0080fMWI0P3K
fm/20=gMg@80gmoO0P3QhN420>?Sh`80iNGU0P3Vi^H20>SXj080j^[Z0P3[jn/20>c/k080kNg]0`3^
k^h40>g]k@80k>c/0P3[jn/20>[ZjP80inOW0P3Shn<20>7Qh@80g]kN0P3Kfm/20=KFeP80clo?0P38
b<P20<71`@80_Kfm00<0^[Zj0;Jf]P2f][H00P2b/[820:f][@80Z:RX0P2TY:@20:2PX080WYjN0P2J
VYX209JFUP80U9BD0P2BTY82092@T080SHf=0P2<S8`208V9R@0308J6QP23Ph<0Ph>30080Ogmo0P1l
O7`207]kN`80O7al0P1nOWh207moO`80PH610P22PX8208F5Q@80QhN70P2:RXX208f=S@80T92@0P2D
U9@00`2GUiL0VYZJ09ZJVP0209fMW@80X:2P0P2SXj<20:JVYP80ZZZZ0P2][JdE0?ooo`004`3oool2
0;:b/P80];Bd0P2g]kL20;Vi^@80^k^k0P2n_[h20<30`080`/;200<0a<C40<O7a`37alL00P3:b/X2
0<c<c080clo?0P3AdM420=CDe080emOG0P3Jf]X20=cLg080gmoO0P3Rh^820>GUi@80inOW0P3Zj^X2
0>k^kP030?7al@3clo<0lo?c0080moOg0P3jn_X20?gmo@@0oooo0P3moOd20?_kn`80moOg0P3bl_82
0>g]k@80j>SX0P3Shn<20=oOg`80fMWI00<0dm?C0<c<c03<c<`00P36a/H20<;2`P80_[jn0P30`<02
0<71`@80`l?30P35aLD20<O7a`80bLW90P3;bl/20<c<c080c/k>0P3@d=020=;BdP030=CDe03Fe]H0
e]KF0080fMWI0P3Kfm/20=gMg@80gmoO0P3QhN420>?Sh`80iNGU0P3Vi^H20>SXj080j^[Z0P3[jn/2
0>c/k080kNg]0`3^k^h40>g]k@80k>c/0P3[jn/20>[ZjP80inOW0P3Shn<20>7Qh@80g]kN0P3Kfm/2
0=KFeP80clo?0P38b<P20<71`@80_Kfm00<0^[Zj0;Jf]P2f][H00P2b/[820:f][@80Z:RX0P2TY:@2
0:2PX080WYjN0P2JVYX209JFUP80U9BD0P2BTY82092@T080SHf=0P2<S8`208V9R@0308J6QP23Ph<0
Ph>30080Ogmo0P1lO7`207]kN`80O7al0P1nOWh207moO`80PH610P22PX8208F5Q@80QhN70P2:RXX2
08f=S@80T92@0P2DU9@00`2GUiL0VYZJ09ZJVP0209fMW@80X:2P0P2SXj<20:JVYP80ZZZZ0P2][JdE
0?ooo`004`3oool20;:b/P80]KFe0P2g]kL20;Zj^P80_;bl0P2n_[h20<71`@80`l?300<0aLG50<S8
b038b<P00P3;bl/20<g=c@80d=3@0P3Bd]820=GEe@80f=SH0P3Kfm/20=gMg@80h>3P0P3Shn<20>KV
iP80jNWY0P3/k>`20>o_k`030?;blP3emOD0mOGe0080n?Sh0P3kno/20?knoP@0oooo0P3moOd20?Wi
n@80mOGe0P3_knl20>[ZjP80iNGU0P3Ph>020=_Kf`80e=CD00<0cLg=0<K6aP36a/H00P30`<020;bl
_080^KVi0P2j^[X20;bl_080_[jn0P30`<020<?3``80aLG50P36a/H20<S8b080b/[:0P3<c<`20<k>
cP030=3@d03Bd]80d];B0080e=CD0P3Fe]H20=WIf@80fm_K0P3MgMd20=oOg`80hN7Q0P3Shn<20>GU
i@80i^KV0P3Xj>P20>WYj@@0j^[Z0`3[jn/20>[ZjP80j>SX0P3WinL20>GUi@80hN7Q0P3Ng]h20=cL
g080fMWI0P3De=@20<k>cP80alO70P30`<020;bl_080^;Rh00<0];Bd0;6a/@2a/K400P2][Jd20:VY
Z@80YJFU0P2QXJ4209jNWP80Vi^K0P2GUiL209BDU080TY:B0P2@T90208f=S@80RXZ:0P28R8P208F5
Q@0308:2PP1nOWh0OWin0080O7al101jNWX207]kN`80OGem0P1nOWh20820P080PX:20P25QHD208N7
Q`80RXZ:0P2=SHd2092@T080U9BD00<0UiNG09ZJVP2JVYX00P2MWId20:2PX080Xj>S0P2VYZH20:VY
Z@80[Jf]5@3oool001<0oooo0P2b/[820;Fe]@80]kNg0P2j^[X20;bl_080_[jn0P31`L420<?3``03
0<G5a@38b<P0b<S80080bl_;0P3=cLd20=3@d080d];B0P3EeMD20=SHf080fm_K0P3MgMd20>3Ph080
hn?S0P3Vi^H20>WYj@80k>c/0P3_knl00`3bl_80mOGe0?Gem@020?Shn080no_k0P3no_h40?ooo`80
oOgm0P3inOT20?Gem@80kno_0P3Zj^X20>GUi@80h>3P0P3Kfm/20=CDe0030<g=c@36a/H0a/K60080
`<300P2l_;`20;Vi^@80^[Zj0P2l_;`20;jn_P80`<300P33`l<20<G5a@80a/K60P38b<P20<[:bP80
c<c<0P3>c/h00`3@d=00d];B0=;BdP020=CDe080e]KF0P3IfMT20=_Kf`80gMgM0P3Ogml20>7Qh@80
hn?S0P3UiND20>KViP80j>SX0P3YjNT40>[ZjP<0jn_[0P3Zj^X20>SXj080inOW0P3UiND20>7Qh@80
g]kN0P3Lg=`20=WIf@80e=CD0P3>c/h20<O7a`80`<300P2l_;`20;Rh^0030;Bd]02a/K40/K6a0080
[Jf]0P2YZJT20:FUY@80XJ6Q0P2NWYh209^KV`80UiNG0P2DU9@209:BTP80T92@0P2=SHd208Z:RP80
R8R80P25QHD00`22PX80OWin07inOP0207alO0@0NWYj0P1kNg/207emO@80OWin0P20P80208:2PP80
QHF50P27QhL208Z:RP80SHf=0P2@T90209BDU00309NGU`2JVYX0VYZJ0080WIfM0P2PX:020:>SX`80
YZJV0P2YZJT20:f][AD0oooo000C0?ooo`80/k>c0P2e]KD20;Ng]`80^[Zj0P2l_;`20;jn_P80`L71
0P33`l<00`36a/H0b<S80<S8b0020<_;b`80c/k>0P3AdM420=?Cd`80e]KF0P3IfMT20=_Kf`80g]kN
0P3QhN420>CTi080inOW0P3Zj^X20>g]k@80l?3`00<0m?Cd0?Ogm`3gmoL00P3inOT20?clo0@0oooo
0P3no_h20?_kn`80moOg0P3bl_820>c/k080i^KV0P3QhN420=_Kf`80e]KF0P3>c/h00`36a/H0_kno
0;no_`020;Zj^P80]KFe0P2b/[820;Bd]080]kNg0P2j^[X20;bl_080_kno0P31`L420<?3``80aLG5
0P37alL20<W9b@80b/[:00<0c<c<0<g=c@3=cLd00P3?cll20=7Ad@80dm?C0P3Fe]H20=SHf080f][J
0P3Lg=`20=oOg`80hN7Q0P3Shn<20>CTi080iNGU1`3Vi^H20>GUi@80i>CT0P3Rh^820=kNgP80f][J
0P3IfMT20=KFeP80d];B0P3=cLd20<G5a@80`<300P2l_;`20;Ng]`80];Bd00<0/;2`0:f][@2][Jd0
0P2YZJT20:FUY@80XJ6Q0P2NWYh209ZJVP80UYJF0P2DU9@209:BTP80T92@0P2>SXh208^;R`80R8R8
0P26QXH208:2PP0307moO`1lO7`0O7al0080NWYj0P1hN7P207UiN@80Ng]k0P1lO7`207emO@80Ogmo
0P22PX8208F5Q@80R8R80P2;Rh/208j>SP80TI6A0P2DU9@00`2GUiL0VYZJ09ZJVP0209fMW@80X:2P
0P2SXj<20:JVYP80ZZZZ0P2][JdE0?ooo`004`3oool20;>c/`80]KFe0P2g]kL20;Zj^P80_;bl0P2n
_[h20<71`@80`l?300<0a/K60<S8b038b<P00P3;bl/20<k>cP80dM7A0P3Cdm<20=KFeP80fMWI0P3K
fm/20=kNgP80hN7Q0P3Ti>@20>OWi`80j^[Z0P3]kNd20?3`l0030?Cdm03gmoL0moOg0080nOWi0P3l
o?`40?ooo`80o_kn0P3kno/20?Ogm`80l_;b0P3/k>`20>KViP80hN7Q0P3Kfm/20=KFeP80c/k>00<0
a/K60;no_`2o_kl00P2j^[X20;Fe]@80/[:b0P2d];@20;Ng]`80^[Zj0P2l_;`20;no_`80`L710P33
`l<20<G5a@80alO70P39bLT20<[:bP030<c<c03=cLd0cLg=0080clo?0P3AdM420=?Cd`80e]KF0P3H
f=P20=[JfP80g=cL0P3Ogml20>7Qh@80hn?S0P3Ti>@20>GUi@L0i^KV0P3UiND20>CTi080h^;R0P3N
g]h20=[JfP80fMWI0P3Fe]H20=;BdP80cLg=0P35aLD20<30`080_;bl0P2g]kL20;Bd]0030;2`/02]
[Jd0[Jf]0080ZJVY0P2UYJD20:6QX@80WYjN0P2JVYX209JFUP80U9BD0P2BTY82092@T080SXj>0P2;
Rh/208R8R080QXJ60P22PX800`1oOgl0O7al07alO00207YjNP80N7Qh0P1iNGT207]kN`80O7al0P1m
OGd207moO`80PX:20P25QHD208R8R080Rh^;0P2>SXh2096AT@80U9BD00<0UiNG09ZJVP2JVYX00P2M
WId20:2PX080Xj>S0P2VYZH20:ZZZP80[Jf]5@3oool001<0oooo0P2b/[820;Fe]@80]kNg0P2j^[X2
0;bl_080_[jn0P31`L420<C4a0030<K6aP39bLT0bLW90080c<c<0P3>c/h20=7Ad@80e=CD0P3GemL2
0=[JfP80gMgM0P3Ogml20>;RhP80iNGU0P3Xj>P20>_[j`80k^k^0P3bl_800`3emOD0n?Sh0?Shn002
0?[jnP80o_kn103oool20?gmo@80nOWi0P3dm?@20?3`l080j^[Z0P3Ti>@20=gMg@80emOG0P3@d=02
0<K6aP030;no_`2h^;P0^;Rh0080/[:b0P2][Jd20:b/[080/;2`0P2d];@20;Rh^080^k^k0P2m_Kd2
0<30`080`L710P33`l<20<G5a@80a/K60P38b<P00`39bLT0bl_;0<_;b`020<c<c080cLg=0P3>c/h2
0<o?c`80d];B0P3De=@20=OGe`80fMWI0P3Kfm/20=gMg@80gmoO0P3Ph>020>7Qh@D0h^;R0P3QhN42
0=oOg`80g=cL0P3GemL20=?Cd`80d];B0P3?cll20<_;b`80aLG50P2o_kl20;Zj^P80][Jf0P2b/[82
0:n_[`030:b/[02XZ:P0Z:RX0080YJFU0P2QXJ4209jNWP80Vi^K0P2GUiL209BDU080TY:B0P2@T902
08j>SP80RXZ:0P28R8P208J6QP80Ph>30P1oOgl00`1lO7`0NWYj07YjNP0407QhN080NGUi0P1kNg/2
07alO080OGem0P1oOgl208:2PP80QHF50P28R8P208^;R`80SXj>0P2ATI4209BDU00309NGU`2JVYX0
VYZJ0080WIfM0P2PX:020:>SX`80YZJV0P2YZJT20:b/[1D0oooo000C0?ooo`80/[:b0P2e]KD20;Ng
]`80^[Zj0P2l_;`20;jn_P80`L710P34a<@00`36a/H0bLW90<W9b@020<c<c080c/k>0P3AdM420=CD
e080emOG0P3Jf]X20=gMg@80gmoO0P3Rh^820>GUi@80j>SX0P3[jn/20>k^kP80l_;b00<0mOGe0?Sh
n03hn?P00P3jn_X20?knoP@0oooo0P3moOd20?Win@80m?Cd0P3`l?020>[ZjP80i>CT0P3MgMd20=OG
e`80d=3@0P36a/H00`2o_kl0^;Rh0;Rh^0020;:b/P80[Jf]0P2/[:`20;2`/080];Bd0P2h^;P20;^k
^`80_Kfm0P30`<020<71`@80`l?30P35aLD20<K6aP80b<S800<0bLW90<_;b`3;bl/00P3<c<`20<g=
c@80c/k>0P3?cll20=;BdP80e=CD0P3GemL20=WIf@80fm_K0P3MgMd20=oOg`80h>3P0P3QhN450>;R
hP80hN7Q0P3Ogml20=cLg080emOG0P3Cdm<20=;BdP80clo?0P3;bl/20<G5a@80_kno0P2j^[X20;Jf
]P80/[:b0P2_[jl00`2/[:`0Z:RX0:RXZ0020:FUY@80XJ6Q0P2NWYh209^KV`80UiNG0P2DU9@209:B
TP80T92@0P2>SXh208Z:RP80R8R80P26QXH208>3P`80Ogmo00<0O7al07YjNP1jNWX0101hN7P207Ui
N@80Ng]k0P1lO7`207emO@80Ogmo0P22PX8208F5Q@80R8R80P2;Rh/208j>SP80TI6A0P2DU9@00`2G
UiL0VYZJ09ZJVP0209fMW@80X:2P0P2SXj<20:JVYP80ZJVY0P2/[:`E0?ooo`004`3oool20;>c/`80
]KFe0P2g]kL20;Zj^P80_;bl0P2o_kl20<;2`P80a<C400<0alO70<[:bP3:b/X00P3<c<`20<o?c`80
d];B0P3EeMD20=SHf080fm_K0P3Ng]h20>3Ph080hn?S0P3Vi^H20>WYj@80k>c/0P3`l?020??cl`03
0?KfmP3inOT0nOWi0080o?cl0P3no_h20?ooo`80o_kn0P3kno/20?Ogm`80l_;b0P3/k>`20>GUi@80
gmoO0P3IfMT20=;BdP80bLW90P2o_kl00`2h^;P0/;2`0;2`/0020:RXZ080YJFU0P2YZJT20:n_[`80
/k>c0P2g]kL20;Zj^P80_Kfm0P2o_kl20<71`@80`l?30P35aLD20<K6aP80alO700<0b<S80<W9b@39
bLT0103:b/X20<_;b`@0c<c<0P3>c/h20=7Ad@80dm?C0P3Fe]H20=SHf080fMWI0P3Kfm/20=cLg080
gMgM00<0g]kN0=gMg@3MgMd00P3Lg=`20=[JfP80e]KF0P3AdM420<g=c@80bl_;0P38b<P20<C4a080
_kno0P2i^KT20;Bd]080/;2`0P2][Jd20:ZZZP030:NWY`2SXj<0Xj>S0080X:2P0P2MWId209ZJVP80
UiNG0P2DU9@2096AT@80Shn?0P2>SXh208^;R`80R8R80P26QXH208B4Q080P8200P1mOGd00`1kNg/0
NGUi07UiN@0207IfMP80MgMg101iNGT207YjNP80OGem0P1oOgl208:2PP80QHF50P28R8P208^;R`80
SXj>0P2ATI4209BDU00309NGU`2JVYX0VYZJ0080WIfM0P2PX:020:>SX`80YjNW0P2ZZZX20:f][AD0
oooo000C0?ooo`80/k>c0P2e]KD20;Ng]`80^[Zj0P2l_;`20;no_`80`/;20P34a<@00`37alL0b/[:
0<[:bP020<c<c080clo?0P3Bd]820=GEe@80f=SH0P3Kfm/20=kNgP80h>3P0P3Shn<20>KViP80jNWY
0P3/k>`20?3`l080lo?c00<0m_Kf0?Win@3inOT00P3lo?`20?knoP80oooo0P3no_h20?_kn`80moOg
0P3bl_820>c/k080iNGU0P3Ogml20=WIf@80d];B0P39bLT20;no_`030;Rh^02`/;00/;2`0080Z:RX
0P2UYJD20:VYZ@80[jn_0P2c/k<20;Ng]`80^[Zj0P2m_Kd20;no_`80`L710P33`l<20<G5a@80a/K6
0P37alL00`38b<P0bLW90<W9b@040<[:bP80bl_;103<c<`20<k>cP80dM7A0P3Cdm<20=KFeP80f=SH
0P3IfMT20=_Kf`80g=cL0P3MgMd00`3Ng]h0gMgM0=gMg@020=cLg080f][J0P3Fe]H20=7Ad@80cLg=
0P3;bl/20<S8b080a<C40P2o_kl20;Vi^@80];Bd0P2`/;020:f][@80ZZZZ00<0YjNW0:>SX`2SXj<0
0P2PX:0209fMW@80VYZJ0P2GUiL209BDU080TI6A0P2?Shl208j>SP80Rh^;0P28R8P208J6QP80Q8B4
0P20P80207emO@0307]kN`1iNGT0NGUi0080MWIf0P1gMgL407UiN@80NWYj0P1mOGd207moO`80PX:2
0P25QHD208R8R080Rh^;0P2>SXh2096AT@80U9BD00<0UiNG09ZJVP2JVYX00P2MWId20:2PX080Xj>S
0P2WYjL20:ZZZP80[Jf]5@3oool001<0oooo0P2b/[820;Fe]@80]kNg0P2j^[X20;fm_@80_kno0P32
`/820<G5a@030<S8b03;bl/0bl_;0080cLg=0P3@d=020=?Cd`80e]KF0P3IfMT20=cLg080g]kN0P3Q
hN420>CTi080inOW0P3Zj^X20>g]k@80lO7a0P3dm?@00`3gmoL0n_[j0?[jnP020?gmo@@0oooo0P3m
oOd20?Win@80mOGe0P3`l?020>WYj@80h^;R0P3Kfm/20=CDe080c<c<0P32`/820;Vi^@030;6a/@2V
YZH0YZJV0080XZ:R0P2UYJD20:^[Z`80/;2`0P2d];@20;Rh^080^k^k0P2m_Kd20<30`080`/;20P34
a<@20<G5a@80a/K61@37alL40<S8b0H0bLW90P3:b/X20<_;b`80cLg=0P3@d=020=;BdP80e=CD0P3F
e]H20=OGe`80f=SH00<0fMWI0=SHf03Hf=P00P3GemL20=CDe080clo?0P3<c<`20<O7a`80`l?30P2o
_kl20;^k^`80]kNg0P2c/k<20:n_[`80Zj^[0P2XZ:P20:JVYP030:>SX`2PX:00X:2P0080WIfM0P2J
VYX209RHV080UIFE0P2CTi<2092@T080SXj>0P2;Rh/208R8R080QXJ60P23Ph<20861P@80OGem0P1k
Ng/00`1iNGT0MgMg07MgM`0207IfMP@0MgMg0P1hN7P207YjNP80OGem0P1oOgl208:2PP80QHF50P28
R8P208^;R`80SXj>0P2ATI4209BDU00309NGU`2JVYX0VYZJ0080WIfM0P2PX:020:>SX`80YZJV0P2Y
ZJT20:f][AD0oooo000C0?ooo`80/[:b0P2e]KD20;Ng]`80^[Zj0P2m_Kd20;no_`80`/;20P35aLD0
0`38b<P0bl_;0<_;b`020<g=c@80d=3@0P3Cdm<20=KFeP80fMWI0P3Lg=`20=kNgP80hN7Q0P3Ti>@2
0>OWi`80j^[Z0P3]kNd20?7al@80m?Cd00<0moOg0?[jnP3jn_X00P3moOd40?ooo`80oOgm0P3inOT2
0?Gem@80l?3`0P3YjNT20>;RhP80fm_K0P3De=@20<c<c080`/;20P2i^KT00`2a/K40YZJV0:JVYP02
0::RXP80YJFU0P2[Zj/20;2`/080];Bd0P2h^;P20;^k^`80_Kfm0P30`<020<;2`P80a<C40P35aLD2
0<K6aPD0alO71038b<P60<W9b@80b/[:0P3;bl/20<g=c@80d=3@0P3Bd]820=CDe080e]KF0P3GemL2
0=SHf0030=WIf@3Hf=P0f=SH0080emOG0P3De=@20<o?c`80c<c<0P37alL20<?3``80_kno0P2k^k/2
0;Ng]`80/k>c0P2_[jl20:^[Z`80Z:RX0P2VYZH00`2SXj<0X:2P0:2PX00209fMW@80VYZJ0P2HV9P2
09FEU@80Ti>C0P2@T90208j>SP80Rh^;0P28R8P208J6QP80Ph>30P21PH4207emO@80Ng]k00<0NGUi
07MgM`1gMgL00P1fMWH407MgM`80N7Qh0P1jNWX207emO@80Ogmo0P22PX8208F5Q@80R8R80P2;Rh/2
08j>SP80TI6A0P2DU9@00`2GUiL0VYZJ09ZJVP0209fMW@80X:2P0P2SXj<20:JVYP80ZJVY0P2][JdE
0?ooo`004`3oool20;:b/P80]KFe0P2h^;P20;Zj^P80_Kfm0P30`<020<;2`P80aLG500<0b<S80<_;
b`3;bl/00P3>c/h20=7Ad@80e=CD0P3GemL20=WIf@80g=cL0P3Ogml20>;RhP80iNGU0P3Xj>P20>_[
j`80kno_0P3bl_820?Gem@030?Shn03kno/0no_k0080o_kn0P3oool20?knoP80no_k0P3gmoL20?;b
lP80k>c/0P3UiND20=kNgP80emOG0P3?cll20<K6aP80^k^k0P2c/k<00`2YZJT0Y:BT0:BTY0020:JV
YP80ZJVY0P2][Jd20;6a/@80]KFe0P2i^KT20;bl_080_kno0P31`L420<;2`P80a<C40P36a/H50<O7
a`@0b<S83037alL20<S8b080bLW90P3;bl/20<k>cP80d=3@0P3Bd]850=?Cd`80dM7A0P3>c/h20<[:
bP80aLG50P31`L420;jn_P80^KVi0P2e]KD20;2`/080Zj^[0P2XZ:P20:FUY@80XZ:R0P2QXJ400`2O
Wil0WIfM09fMW@0209^KV`80V9RH0P2EUID209>CT`80TI6A0P2>SXh208^;R`80RHV90P27QhL208B4
Q080PH610P1nOWh207]kN`80NGUi00<0MgMg07IfMP1fMWH0101eMGD207IfMP80N7Qh0P1jNWX207em
O@80Ogmo0P22PX8208F5Q@80R8R80P2;Rh/208j>SP80TI6A0P2DU9@00`2GUiL0VYZJ09ZJVP0209fM
W@80X:2P0P2SXj<20:JVYP80ZZZZ0P2][JdE0?ooo`004`3oool20;:b/P80]KFe0P2h^;P20;Zj^P80
_Kfm0P30`<020<;2`P80aLG500<0b<S80<_;b`3;bl/00P3>c/h20=7Ad@80e=CD0P3GemL20=WIf@80
g=cL0P3Ogml20>;RhP80iNGU0P3Xj>P20>_[j`80kno_0P3bl_820?Gem@030?Shn03kno/0no_k0080
o_kn0P3oool20?knoP80no_k0P3gmoL20?;blP80k>c/0P3UiND20=kNgP80emOG0P3?cll20<K6aP80
^k^k0P2c/k<00`2YZJT0Y:BT0:BTY0020:JVYP80ZJVY0P2][Jd20;6a/@80]KFe0P2i^KT20;bl_080
_kno0P31`L420<;2`P80a<C40P36a/H50<O7a`@0b<S83037alL20<S8b080bLW90P3;bl/20<k>cP80
d=3@0P3Bd]850=?Cd`80dM7A0P3>c/h20<[:bP80aLG50P31`L420;jn_P80^KVi0P2e]KD20;2`/080
Zj^[0P2XZ:P20:FUY@80XZ:R0P2QXJ400`2OWil0WIfM09fMW@0209^KV`80V9RH0P2EUID209>CT`80
TI6A0P2>SXh208^;R`80RHV90P27QhL208B4Q080PH610P1nOWh207]kN`80NGUi00<0MgMg07IfMP1f
MWH0101eMGD207IfMP80N7Qh0P1jNWX207emO@80Ogmo0P22PX8208F5Q@80R8R80P2;Rh/208j>SP80
TI6A0P2DU9@00`2GUiL0VYZJ09ZJVP0209fMW@80X:2P0P2SXj<20:JVYP80ZZZZ0P2][JdE0?ooo`00
4`3oool20;>c/`80]KFe0P2h^;P20;^k^`80_Kfm0P30`<020<?3``80a/K600<0bLW90<_;b`3;bl/0
0P3>c/h20=7Ad@80e=CD0P3GemL20=[JfP80gMgM0P3Ph>020>?Sh`80i^KV0P3Zj^X20>g]k@80l?3`
0P3dm?@20?Ogm`030?[jnP3lo?`0o?cl00@0o_kn0P3moOd20?Win@80mOGe0P3_knl20>WYj@80hN7Q
0P3Jf]X20=;BdP80bLW90P2n_[h20;Bd]080Zj^[0`2TY:@20:NWY`80Zj^[0P2_[jl20;>c/`80]kNg
0P2k^k/20;jn_P80`L710P33`l<20<C4a080a/K61037alL30<S8b080alO71036a/H40<G5a@X0a<C4
0P36a/H20<O7a`80b/[:0P3<c<`20<g=c@<0c/k>0P3<c<`20<[:bP80aLG50P31`L420;fm_@80^;Rh
0P2b/[820:b/[080ZJVY0P2WYjL20:FUY@80Xj>S0P2QXJ4209nOW`0309bLW02JVYX0VYZJ0080V9RH
0P2FUYH209BDU080TI6A0P2?Shl208b<S080RHV90P27QhL208B4Q080PH610P1nOWh207]kN`80NWYj
0P1hN7P00`1fMWH0M7Ad07AdM00207=cL`80M7Ad0P1fMWH207QhN080NWYj0P1mOGd207moO`80PX:2
0P25QHD208R8R080Rh^;0P2>SXh2096AT@80U9BD00<0UiNG09ZJVP2JVYX00P2MWId20:2PX080Xj>S
0P2WYjL20:ZZZP80[Jf]5@3oool001<0oooo0P2c/k<20;Fe]@80^;Rh0P2k^k/20;fm_@80`<300P33
`l<20<K6aP030<W9b@3;bl/0bl_;0080c/k>0P3AdM420=CDe080emOG0P3Jf]X20=gMg@80h>3P0P3S
hn<20>KViP80j^[Z0P3]kNd20?3`l080m?Cd0P3gmoL00`3jn_X0o?cl0?clo0040?knoP80oOgm0P3i
nOT20?Gem@80kno_0P3YjNT20>7Qh@80f][J0P3Bd]820<W9b@80_[jn0P2d];@20:^[Z`<0Y:BT0P2W
YjL20:^[Z`80[jn_0P2c/k<20;Ng]`80^k^k0P2n_[h20<71`@80`l?30P34a<@20<K6aP@0alO70`38
b<P20<O7a`@0a/K61035aLD:0<C4a080a/K60P37alL20<[:bP80c<c<0P3=cLd30<k>cP80c<c<0P3:
b/X20<G5a@80`L710P2m_Kd20;Rh^080/[:b0P2/[:`20:VYZ@80YjNW0P2UYJD20:>SX`80XJ6Q0P2O
Wil00`2LW9`0VYZJ09ZJVP0209RHV080UYJF0P2DU9@2096AT@80Shn?0P2<S8`208V9R@80QhN70P24
Q8@20861P@80OWin0P1kNg/207YjNP80N7Qh00<0MWIf07AdM01dM7@00P1cLg<207AdM080MWIf0P1h
N7P207YjNP80OGem0P1oOgl208:2PP80QHF50P28R8P208^;R`80SXj>0P2ATI4209BDU00309NGU`2J
VYX0VYZJ0080WIfM0P2PX:020:>SX`80YjNW0P2ZZZX20:f][AD0oooo000C0?ooo`80/[:b0P2e]KD2
0;Rh^080^k^k0P2m_Kd20<30`080`l?30P36a/H00`39bLT0c<c<0<c<c0020<o?c`80d];B0P3EeMD2
0=SHf080f][J0P3Ng]h20>7Qh@80i>CT0P3WinL20>_[j`80k^k^0P3alO420?Cdm080n?Sh00<0no_k
0?gmo@3moOd0103no_h20?clo080n?Sh0P3clo<20>c/k080iNGU0P3Lg=`20=GEe@80c<c<0P32`/82
0;Jf]P80[:b/0P2TY:@00`2RXZ80YZJV0:JVYP020:VYZ@80[Jf]0P2a/K420;Fe]@80^KVi0P2m_Kd2
0<30`080`/;20P34a<@20<K6aP80alO70P38b<P40<W9b@<0b<S80P37alL20<G5a@80a<C40P33`l<2
0<;2`P`0`L710P33`l<20<K6aP80alO70`38b<P20<O7a`80a<C40P31`L420;jn_P80^KVi0P2d];@2
0:n_[`80ZZZZ0P2UYJD40:6QX@80WinO0P2MWId209^KV`0309ZJVP2HV9P0V9RH0080UYJF0P2DU9@2
096AT@80SXj>0P2<S8`208Z:RP80R8R80P24Q8@20820P080OWin0P1lO7`207UiN@80N7Qh0P1fMWH0
0`1cLg<0LW9b079bLP02075aL@80Lg=c0P1eMGD207QhN080NWYj0P1lO7`207moO`80PX:20P25QHD2
08R8R080Rh^;0P2=SHd2096AT@80U9BD00<0UiNG09ZJVP2JVYX00P2MWId20:2PX080Xj>S0P2VYZH2
0:VYZ@80[Jf]5@3oool001<0oooo0P2b/[820;Fe]@80^;Rh0P2k^k/20;fm_@80`<300P33`l<20<K6
aP030<W9b@3<c<`0c<c<0080clo?0P3Bd]820=GEe@80f=SH0P3Jf]X20=kNgP80hN7Q0P3Ti>@20>OW
i`80jn_[0P3^k^h20?7al@80m?Cd0P3hn?P00`3kno/0oOgm0?gmo@040?knoP80o?cl0P3hn?P20??c
l`80k>c/0P3UiND20=cLg080eMGE0P3<c<`20<;2`P80][Jf0P2/[:`20:BTY0030::RXP2VYZH0YZJV
0080ZJVY0P2][Jd20;6a/@80]KFe0P2i^KT20;fm_@80`<300P32`/820<C4a080a/K60P37alL20<S8
b0@0bLW90`38b<P20<O7a`80aLG50P34a<@20<?3``80`/;23031`L420<?3``80a/K60P37alL30<S8
b080alO70P34a<@20<71`@80_[jn0P2i^KT20;Bd]080[jn_0P2ZZZX20:FUY@@0XJ6Q0P2OWil209fM
W@80Vi^K00<0VYZJ09RHV02HV9P00P2FUYH209BDU080TI6A0P2>SXh208b<S080RXZ:0P28R8P208B4
Q080P8200P1nOWh207alO080NGUi0P1hN7P207IfMP0307=cL`1bLW80LW9b0080LG5a0P1cLg<207Ee
M@80N7Qh0P1jNWX207alO080Ogmo0P22PX8208F5Q@80R8R80P2;Rh/208f=S@80TI6A0P2DU9@00`2G
UiL0VYZJ09ZJVP0209fMW@80X:2P0P2SXj<20:JVYP80ZJVY0P2][JdE0?ooo`004`3oool20;:b/P80
]KFe0P2h^;P20;^k^`80_[jn0P31`L420<?3``80a/K600<0bLW90<c<c03<c<`00P3?cll20=;BdP80
eMGE0P3Hf=P20=_Kf`80g]kN0P3Rh^820>GUi@80jNWY0P3/k>`20>o_k`80l_;b0P3fm_H20?Win@03
0?clo03no_h0o_kn00@0o_kn0P3jn_X20?KfmP80l?3`0P3YjNT20>7Qh@80f=SH0P3@d=020<K6aP80
^k^k0P2`/;020:FUY@80XZ:R00<0Y:BT0:NWY`2WYjL00P2[Zj/20:n_[`80/k>c0P2g]kL20;^k^`80
_[jn0P31`L420<?3``80aLG50P37alL20<S8b0@0bLW90`38b<P20<O7a`80a/K60P34a<@20<;2`P80
`L71102o_kl60;jn_PH0_Kfm0P2n_[h20<30`0D0`/;20P30`<020;fm_@80^[Zj0P2f][H20;2`/080
[:b/0P2VYZH20:6QX@80WinO0P2MWId209bLW080VYZJ0P2HV9P00`2FUYH0UIFE09FEU@0209>CT`80
T92@0P2>SXh208b<S080RXZ:0P28R8P208F5Q@80PH610P1oOgl207]kN`80N7Qh0P1gMgL207IfMP80
M7Ad00<0LW9b075aL@1aLG400P1bLW8207=cL`80MGEe0P1gMgL207YjNP80O7al0P1oOgl208:2PP80
QHF50P28R8P208^;R`80SXj>0P2ATI4209BDU00309NGU`2JVYX0VYZJ0080WIfM0P2PX:020:>SX`80
YZJV0P2YZJT20:f][AD0oooo000C0?ooo`80/[:b0P2e]KD20;Rh^080^k^k0P2n_[h20<71`@80`l?3
0P36a/H00`39bLT0c<c<0<c<c0020<o?c`80d];B0P3EeMD20=SHf080fm_K0P3Ng]h20>;RhP80iNGU
0P3YjNT20>c/k080kno_0P3bl_820?KfmP80nOWi00<0o?cl0?knoP3no_h0103no_h20?[jnP80m_Kf
0P3`l?020>WYj@80hN7Q0P3Hf=P20=3@d080a/K60P2k^k/20;2`/080YJFU0P2RXZ800`2TY:@0YjNW
0:NWY`020:^[Z`80[jn_0P2c/k<20;Ng]`80^k^k0P2n_[h20<71`@80`l?30P35aLD20<O7a`80b<S8
1039bLT30<S8b080alO70P36a/H20<C4a080`/;20P31`L440;no_`H0_[jn1P2m_Kd20;jn_P80`<30
1@32`/820<30`080_Kfm0P2j^[X20;Jf]P80/;2`0P2/[:`20:JVYP80XJ6Q0P2OWil209fMW@80W9bL
0P2JVYX209RHV00309JFUP2EUID0UIFE0080Ti>C0P2@T90208j>SP80S8b<0P2:RXX208R8R080QHF5
0P21PH4207moO`80Ng]k0P1hN7P207MgM`80MWIf0P1dM7@00`1bLW80LG5a075aL@02079bLP80Lg=c
0P1eMGD207MgM`80NWYj0P1lO7`207moO`80PX:20P25QHD208R8R080Rh^;0P2>SXh2096AT@80U9BD
00<0UiNG09ZJVP2JVYX00P2MWId20:2PX080Xj>S0P2VYZH20:VYZ@80[Jf]5@3oool001<0oooo0P2c
/k<20;Jf]P80^;Rh0P2k^k/20;jn_P80`L710P34a<@20<K6aP030<W9b@3<c<`0c<c<0080d=3@0P3B
d]820=KFeP80fMWI0P3Lg=`20=oOg`80hn?S0P3Vi^H20>WYj@80kNg]0P3`l?020?Cdm080moOg0P3j
n_X00`3lo?`0o_kn0?knoP020?knoP80o?cl0P3hn?P20??cl`80k>c/0P3UiND20=cLg080dm?C0P3:
b/X20;jn_P80/k>c0P2WYjL20:6QX@80Y:BT00<0YZJV0:VYZ@2YZJT00P2/[:`20;2`/080];Bd0P2h
^;P20;bl_080_[jn0P30`<020<;2`P80`l?30P35aLD40<K6aP@0alO700<0a/K60<G5a@35aLD00P34
a<@20<;2`P80`<300P2n_[h20;fm_@80_;bl102k^k/:0;Zj^P80^k^k1@2m_Kd20;bl_080^[Zj0P2g
]kL20;>c/`80[jn_0P2[Zj/20:FUY@80XJ6Q0P2MWId209VIV@@0UiNG0P2EUID00`2DU9@0TY:B09:B
TP02092@T080SXj>0P2<S8`208^;R`80R8R80P26QXH208B4Q080P8200P1mOGd207YjNP80N7Qh0P1f
MWH207AdM080LW9b00<0LG5a071`L01`L7000P1bLW8207=cL`80MGEe0P1gMgL207UiN@80O7al0P1o
Ogl208:2PP80QHF50P27QhL208Z:RP80SHf=0P2@T90209>CT`0309JFUP2JVYX0VYZJ0080WIfM0P2P
X:020:>SX`80YZJV0P2ZZZX20:f][AD0oooo000C0?ooo`80/k>c0P2f][H20;Rh^080^k^k0P2n_[h2
0<71`@80a<C40P36a/H00`39bLT0c<c<0<c<c0020=3@d080d];B0P3Fe]H20=WIf@80g=cL0P3Ogml2
0>?Sh`80i^KV0P3YjNT20>g]k@80l?3`0P3dm?@20?Ogm`80n_[j00<0o?cl0?knoP3no_h00P3no_h2
0?clo080n?Sh0P3clo<20>c/k080iNGU0P3Lg=`20=?Cd`80b/[:0P2n_[h20;>c/`80YjNW0P2QXJ42
0:BTY0030:JVYP2YZJT0ZJVY0080[:b/0P2`/;020;Bd]080^;Rh0P2l_;`20;jn_P80`<300P32`/82
0<?3``80aLG51036a/H40<O7a`030<K6aP35aLD0aLG50080a<C40P32`/820<30`080_[jn0P2m_Kd2
0;bl_0@0^k^k2P2j^[X20;^k^`D0_Kfm0P2l_;`20;Zj^P80]kNg0P2c/k<20:n_[`80Zj^[0P2UYJD2
0:6QX@80WIfM0P2IVIT409NGU`80UIFE00<0U9BD09:BTP2BTY800P2@T90208j>SP80S8b<0P2;Rh/2
08R8R080QXJ60P24Q8@20820P080OGem0P1jNWX207QhN080MWIf0P1dM7@2079bLP03075aL@1`L700
L71`0080LW9b0P1cLg<207EeM@80MgMg0P1iNGT207alO080Ogmo0P22PX8208F5Q@80QhN70P2:RXX2
08f=S@80T92@0P2CTi<00`2FUYH0VYZJ09ZJVP0209fMW@80X:2P0P2SXj<20:JVYP80ZZZZ0P2][JdE
0?ooo`004`3oool20;>c/`80][Jf0P2h^;P20;^k^`80_[jn0P31`L420<C4a080alO700<0b/[:0<g=
c@3=cLd00P3@d=020=?Cd`80e]KF0P3Jf]X20=gMg@80h>3P0P3Shn<20>OWi`80j^[Z0P3^k^h20?7a
l@80mOGe0P3hn?P20?_kn`030?gmo@3no_h0o_kn0080o_kn0P3kno/20?Ogm`80l?3`0P3YjNT20>3P
h080emOG0P3>c/h20<?3``80^;Rh0P2][Jd20:FUY@80Y:BT0P2UYJD00`2WYjL0ZZZZ0:ZZZP020:f]
[@80/K6a0P2e]KD20;Vi^@80_;bl0P2m_Kd20;jn_P@0_kno0P30`<020<71`@80`/;20P33`l<30<C4
a080`l?30P31`L420;no_`80_Kfm0P2k^k/20;Zj^P80^KVi0P2h^;P<0;Ng]`<0][Jf1P2h^;P20;Jf
]P80];Bd0P2a/K420:f][@80YjNW0P2TY:@20:2PX080W9bL0P2IVIT209FEU@@0Ti>C00<0TY:B092@
T02@T9000P2?Shl208f=S@80Rh^;0P29RHT208N7Q`80QHF50P22PX8207moO`80O7al0P1jNWX207Mg
M`80MGEe0P1cLg<2071`L00306m_K`1`L700L71`0080LG5a0P1cLg<207EeM@80MgMg0P1iNGT207al
O080Ogmo0P22PX8208B4Q080QhN70P2:RXX208f=S@80T92@0P2CTi<00`2FUYH0VIVI09VIV@0209fM
W@80X:2P0P2SXj<20:JVYP80ZZZZ0P2][JdE0?ooo`004`3oool20;>c/`80][Jf0P2i^KT20;bl_080
_[jn0P31`L420<C4a080alO700<0b/[:0<g=c@3=cLd00P3AdM420=CDe080emOG0P3Jf]X20=kNgP80
hN7Q0P3Ti>@20>SXj080jn_[0P3^k^h20?;blP80m_Kf0P3inOT20?clo0030?knoP3oool0oooo0080
o_kn0P3jn_X20?Cdm080kNg]0P3UiND20=cLg080d];B0P38b<P20;bl_080/K6a0P2UYJD20:6QX@80
Y:BT0P2UYJD00`2WYjL0ZZZZ0:ZZZP020:f][@80/[:b0P2e]KD40;Jf]P80]KFe0P2f][H20;Vi^@80
^[Zj102k^k/60;fm_@D0_;bl0P2k^k/20;Vi^@80^;Rh0P2f][H40;Fe]@P0];Bd102c/k<20;:b/P<0
/K6a102c/k<20;:b/P80/K6a0P2`/;020:b/[080YjNW0P2TY:@20:6QX@80WYjN0P2JVYX209FEU@80
TY:B0P2@T90308n?S`80SHf=0P2:RXX208V9R@80R8R80P26QXH208>3P`80PH610P1nOWh207]kN`80
NGUi0P1gMgL207EeM@80LW9b0P1`L70306i^KP80L71`0P1bLW8207AdM080MWIf0P1iNGT207alO080
Ogmo0P21PH4208B4Q080QhN70P2:RXX208f=S@80T92@0P2CTi<00`2FUYH0VYZJ09ZJVP0209fMW@80
X:2P0P2SXj<20:JVYP80ZJVY0P2][JdE0?ooo`004`3oool20;>c/`80][Jf0P2i^KT20;bl_080_[jn
0P31`L420<C4a080alO700<0b/[:0<g=c@3=cLd00P3AdM420=CDe080emOG0P3Jf]X20=kNgP80hN7Q
0P3Ti>@20>SXj080jn_[0P3^k^h20?;blP80m_Kf0P3inOT20?clo0030?knoP3oool0oooo0080o_kn
0P3jn_X20?Cdm080kNg]0P3UiND20=cLg080d];B0P38b<P20;bl_080/K6a0P2UYJD20:6QX@80Y:BT
0P2UYJD00`2WYjL0ZZZZ0:ZZZP020:f][@80/[:b0P2e]KD40;Jf]P80]KFe0P2f][H20;Vi^@80^[Zj
102k^k/60;fm_@D0_;bl0P2k^k/20;Vi^@80^;Rh0P2f][H40;Fe]@P0];Bd102c/k<20;:b/P<0/K6a
102c/k<20;:b/P80/K6a0P2`/;020:b/[080YjNW0P2TY:@20:6QX@80WYjN0P2JVYX209FEU@80TY:B
0P2@T90308n?S`80SHf=0P2:RXX208V9R@80R8R80P26QXH208>3P`80PH610P1nOWh207]kN`80NGUi
0P1gMgL207EeM@80LW9b0P1`L70306i^KP80L71`0P1bLW8207AdM080MWIf0P1iNGT207alO080Ogmo
0P21PH4208B4Q080QhN70P2:RXX208f=S@80T92@0P2CTi<00`2FUYH0VYZJ09ZJVP0209fMW@80X:2P
0P2SXj<20:JVYP80ZJVY0P2][JdE0?ooo`004`3oool20;>c/`80][Jf0P2i^KT20;bl_080_kno0P32
`/820<G5a@80b<S800<0bl_;0<k>cP3>c/h00P3AdM420=CDe080emOG0P3Kfm/20=kNgP80hN7Q0P3U
iND20>SXj080k>c/0P3_knl20??cl`80moOg0P3kno/20?knoP<0oooo0P3moOd20?Shn080lO7a0P3Z
j^X20>7Qh@80emOG0P3=cLd20<;2`P80][Jf0P2ZZZX60:>SX`80YJFU00<0YjNW0:VYZ@2YZJT00P2/
[:`20:n_[`@0/K6a0P2b/[820;Bd]0H0][Jf0P2h^;P40;Zj^P80^KVi0P2h^;P00`2g]kL0][Jf0;Jf
]P040;Jf]P80]KFe0P2c/k<40;:b/PX0/K6a102`/;020:n_[`030:j^[P2][Jd0[Jf]00@0[Zj^0P2_
[jl20:j^[P80[:b/0P2YZJT20:RXZ080YJFU0P2QXJ4209jNWP80VYZJ0P2GUiL209:BTP80Shn?00<0
SXj>08b<S02<S8`0102:RXX208R8R080QXJ60P24Q8@208:2PP80P8200P1mOGd207YjNP80N7Qh0P1e
MGD2079bLP80L71`0P1_Kfl00`1]KFd0KVi^06i^KP02071`L080LW9b0P1dM7@207IfMP80NGUi0P1k
Ng/207inOP80PH610P24Q8@208N7Q`80RXZ:0P2=SHd2092@T080Ti>C00<0UYJF09VIV@2IVIT00P2L
W9`20:2PX080Xj>S0P2VYZH20:VYZ@80[Jf]5@3oool001<0oooo0P2c/k<20;Jf]P80^KVi0P2l_;`2
0;no_`80`/;20P35aLD20<S8b0030<_;b`3>c/h0c/k>0080dM7A0P3De=@20=OGe`80fm_K0P3Ng]h2
0>7Qh@80iNGU0P3Xj>P20>c/k080kno_0P3clo<20?Ogm`80no_k0P3no_h30?ooo`80oOgm0P3hn?P2
0?7al@80j^[Z0P3QhN420=OGe`80cLg=0P32`/820;Jf]P80ZZZZ1P2SXj<20:FUY@030:NWY`2YZJT0
ZJVY0080[:b/0P2_[jl40;6a/@80/[:b0P2d];@60;Jf]P80^;Rh102j^[X20;Vi^@80^;Rh00<0]kNg
0;Jf]P2f][H0102f][H20;Fe]@80/k>c102b/[8:0;6a/@@0/;2`0P2_[jl00`2^[Zh0[Jf]0:f][@04
0:j^[P80[jn_0P2^[Zh20:b/[080ZJVY0P2XZ:P20:FUY@80XJ6Q0P2NWYh209ZJVP80UiNG0P2BTY82
08n?S`0308j>SP2<S8`0S8b<00@0RXZ:0P28R8P208J6QP80Q8B40P22PX820820P080OGem0P1jNWX2
07QhN080MGEe0P1bLW82071`L080Kfm_00<0KFe]06i^KP1^KVh00P1`L702079bLP80M7Ad0P1fMWH2
07UiN@80Ng]k0P1nOWh20861P@80Q8B40P27QhL208Z:RP80SHf=0P2@T90209>CT`0309JFUP2IVIT0
VIVI0080W9bL0P2PX:020:>SX`80YZJV0P2YZJT20:f][AD0oooo000C0?ooo`80/k>c0P2f][H20;Vi
^@80_;bl0P2o_kl20<;2`P80aLG50P38b<P00`3;bl/0c/k>0<k>cP020=7Ad@80e=CD0P3GemL20=_K
f`80g]kN0P3Rh^820>GUi@80jNWY0P3/k>`20?3`l080m?Cd0P3hn?P20?_kn`80o_kn00<0oooo0?gm
o@3moOd00P3jn_X20?Gem@80k^k^0P3UiND20=cLg080d];B0P37alL20;^k^`80[jn_0P2TY:@20:6Q
X@@0Xj>S0P2TY:@00`2VYZH0Z:RX0:RXZ0020:ZZZP@0[:b/1P2][Jd20:j^[P80[jn_102`/;020;6a
/@80/[:b0P2a/K420;2`/0030;6a/@2`/;00/;2`00P0[jn_202^[Zh20:n_[`H0[Zj^0P2][Jd30:b/
[0@0Zj^[102/[:`40:ZZZP80ZJVY0P2WYjL20:>SX`80XZ:R0P2OWil209bLW080V9RH0P2DU9@208n?
S`0308b<S02:RXX0RXZ:0080RHV90P28R8P208F5Q@80Q8B40P23Ph<20861P@80OWin0P1kNg/207Ui
N@80MWIf0P1cLg<2071`L080Kfm_0P1]KFd00`1/K6`0KVi^06i^KP02071`L080LW9b0P1cLg<207If
MP80N7Qh0P1kNg/207inOP80PH610P24Q8@208N7Q`80RXZ:0P2=SHd2092@T080Ti>C00<0UYJF09VI
V@2IVIT00P2MWId20:2PX080Xj>S0P2VYZH20:VYZ@80[Jf]5@3oool001<0oooo0P2c/k<20;Jf]P80
^KVi0P2l_;`20;no_`80`/;20P35aLD20<S8b0030<_;b`3>c/h0c/k>0080dM7A0P3De=@20=OGe`80
fm_K0P3Ng]h20>;RhP80iNGU0P3YjNT20>c/k080l?3`0P3dm?@20?Shn080no_k0P3no_h00`3oool0
oOgm0?gmo@020?[jnP80mOGe0P3^k^h20>GUi@80g=cL0P3Bd]820<O7a`80^k^k0P2_[jl20:BTY080
XJ6Q102SXj<20:BTY0030:JVYP2XZ:P0Z:RX0080ZZZZ102/[:`60:f][@80[Zj^0P2_[jl40;2`/080
/K6a0P2b/[820;6a/@80/;2`00<0/K6a0;2`/02`/;00202_[jl80:j^[P80[jn_1P2^[Zh20:f][@<0
[:b/102[Zj/40:b/[0@0ZZZZ0P2YZJT20:NWY`80Xj>S0P2RXZ8209nOW`80W9bL0P2HV9P209BDU080
Shn?00<0S8b<08Z:RP2:RXX00P29RHT208R8R080QHF50P24Q8@208>3P`80PH610P1nOWh207]kN`80
NGUi0P1fMWH207=cL`80L71`0P1_Kfl206e]K@0306a/K01^KVh0KVi^0080L71`0P1bLW8207=cL`80
MWIf0P1hN7P207]kN`80OWin0P21PH4208B4Q080QhN70P2:RXX208f=S@80T92@0P2CTi<00`2FUYH0
VIVI09VIV@0209fMW@80X:2P0P2SXj<20:JVYP80ZJVY0P2][JdE0?ooo`004`3oool20;>c/`80][Jf
0P2i^KT20;bl_080_kno0P32`/820<G5a@80b<S800<0bl_;0<k>cP3>c/h00P3AdM420=CDe080f=SH
0P3Kfm/20=kNgP80h^;R0P3Vi^H20>WYj@80kNg]0P3alO420?Gem@80nOWi0P3lo?`30?knoP80o?cl
0P3hn?P20?;blP80jNWY0P3Ph>020=OGe`80c<c<0P30`<020;Fe]@80Z:RX0P2RXZ880:>SX`<0Y:BT
1P2RXZ820:6QX@80XZ:R102SXj<40:BTY0@0YJFU0P2TY:@20:>SX`80Y:BT00<0Xj>S0::RXP2RXZ80
102QXJ420::RXP80Y:BT0P2XZ:P20:ZZZP80Zj^[1P2/[:`60:^[Z`<0ZZZZ102YZJT80:RXZ080YZJV
0P2UYJD20:BTY080XJ6Q0P2OWil209fMW@80VIVI0P2FUYH2096AT@0308f=S@2:RXX0RXZ:0080R8R8
0P26QXH208B4Q080Ph>30P21PH4207moO`80O7al0P1jNWX207QhN080MGEe0P1cLg<2071`L080KVi^
0`1[Jf/206e]K@80Kfm_0P1aLG4207=cL`80MGEe0P1hN7P207]kN`80OWin0P20P80208>3P`80QXJ6
0P2:RXX208f=S@80T92@0P2CTi<00`2FUYH0VIVI09VIV@0209fMW@80X:2P0P2SXj<20:JVYP80ZJVY
0P2][JdE0?ooo`004`3oool20;>c/`80][Jf0P2i^KT20;bl_080_kno0P32`/820<G5a@80b<S800<0
bl_;0<k>cP3>c/h00P3AdM420=CDe080f=SH0P3Kfm/20=kNgP80h^;R0P3Vi^H20>WYj@80kNg]0P3a
lO420?Gem@80nOWi0P3lo?`30?knoP80o?cl0P3hn?P20?;blP80jNWY0P3Ph>020=OGe`80c<c<0P30
`<020;Fe]@80Z:RX0P2RXZ880:>SX`<0Y:BT1P2RXZ820:6QX@80XZ:R102SXj<40:BTY0@0YJFU0P2T
Y:@20:>SX`80Y:BT00<0Xj>S0::RXP2RXZ80102QXJ420::RXP80Y:BT0P2XZ:P20:ZZZP80Zj^[1P2/
[:`60:^[Z`<0ZZZZ102YZJT80:RXZ080YZJV0P2UYJD20:BTY080XJ6Q0P2OWil209fMW@80VIVI0P2F
UYH2096AT@0308f=S@2:RXX0RXZ:0080R8R80P26QXH208B4Q080Ph>30P21PH4207moO`80O7al0P1j
NWX207QhN080MGEe0P1cLg<2071`L080KVi^0`1[Jf/206e]K@80Kfm_0P1aLG4207=cL`80MGEe0P1h
N7P207]kN`80OWin0P20P80208>3P`80QXJ60P2:RXX208f=S@80T92@0P2CTi<00`2FUYH0VIVI09VI
V@0209fMW@80X:2P0P2SXj<20:JVYP80ZJVY0P2][JdE0?ooo`004`3oool20;>c/`80][Jf0P2i^KT2
0;bl_080_kno0P32`/820<C4a080b<S800<0bl_;0<k>cP3>c/h00P3AdM420=CDe080f=SH0P3Kfm/2
0=oOg`80h^;R0P3Vi^H20>[ZjP80k^k^0P3bl_820?KfmP80nOWi0P3lo?`20?knoP030?gmo@3jn_X0
n_[j0080m?Cd0P3]kNd20>GUi@80g=cL0P3Bd]820<O7a`80_;bl0P2`/;020:NWY`80Y:BT1P2SXj<3
0::RXP80XJ6Q0P2PX:0209jNWP80Vi^K1P2IVIT209ZJVP80Vi^K102LW9`809^KV`<0W9bL0P2NWYh2
09nOW`80X:2P0P2RXZ820:FUY@80YjNW0P2XZ:P60:VYZ@80ZZZZ1P2YZJT00`2XZ:P0YjNW0:NWY`02
0:NWY`@0YZJV0P2UYJD60:BTY080Xj>S0P2RXZ820:2PX080WIfM0P2JVYX209NGU`80Ti>C00<0SXj>
08Z:RP2:RXX00P26QXH208B4Q080Ph>30P22PX820820P080OGem0P1kNg/207YjNP80MgMg0P1dM7@2
079bLP80Kfm_0P1^KVh306][J`80KFe]0P1^KVh2071`L080LW9b0P1dM7@207MgM`80NWYj0P1mOGd2
0820P080Ph>30P26QXH208V9R@80S8b<0P2@T90209>CT`0309JFUP2IVIT0VIVI0080W9bL0P2OWil2
0:>SX`80YZJV0P2YZJT20:f][AD0oooo000C0?ooo`80/k>c0P2f][H20;Vi^@80_;bl0P2o_kl20<;2
`P80a<C40P38b<P00`3;bl/0c/k>0<k>cP020=7Ad@80e=CD0P3Hf=P20=_Kf`80gmoO0P3Rh^820>KV
iP80j^[Z0P3^k^h20?;blP80m_Kf0P3inOT20?clo080o_kn00<0oOgm0?[jnP3jn_X00P3dm?@20>g]
k@80iNGU0P3Lg=`20=;BdP80alO70P2l_;`20;2`/080YjNW0P2TY:@60:>SX`<0XZ:R0P2QXJ420:2P
X080WYjN0P2KVi/609VIV@80VYZJ0P2KVi/409bLW0P0Vi^K0`2LW9`209jNWP80WinO0P2PX:020::R
XP80YJFU0P2WYjL20:RXZ0H0ZJVY0P2ZZZX60:VYZ@030:RXZ02WYjL0YjNW0080YjNW102VYZH20:FU
Y@H0Y:BT0P2SXj<20::RXP80X:2P0P2MWId209ZJVP80UiNG0P2CTi<00`2>SXh0RXZ:08Z:RP0208J6
QP80Q8B40P23Ph<208:2PP80P8200P1mOGd207]kN`80NWYj0P1gMgL207AdM080LW9b0P1_Kfl206i^
KP<0Jf][0P1]KFd206i^KP80L71`0P1bLW8207AdM080MgMg0P1jNWX207emO@80P8200P23Ph<208J6
QP80RHV90P2<S8`2092@T080Ti>C00<0UYJF09VIV@2IVIT00P2LW9`209nOW`80Xj>S0P2VYZH20:VY
Z@80[Jf]5@3oool001<0oooo0P2c/k<20;Jf]P80^;Rh0P2l_;`20;no_`80`/;20P35aLD20<S8b003
0<_;b`3>c/h0c/k>0080dM7A0P3De=@20=SHf080g=cL0P3Ogml20>?Sh`80i^KV0P3Zj^X20>k^kP80
l_;b0P3fm_H20?[jnP@0oOgm00<0o?cl0?Ogm`3gmoL00P3alO420>[ZjP80hN7Q0P3Hf=P20<g=c@80
`/;20P2g]kL20:^[Z`@0Y:BT0P2SXj<40::RXP<0XJ6Q0P2PX:0209nOW`80WYjN0P2MWId209bLW0@0
Vi^K0P2LW9`209fMW@H0WYjN0P2OWil909jNWP@0WinO0P2QXJ420:>SX`80Y:BT0P2UYJD20:JVYP@0
YjNW1P2XZ:P30:NWY`@0YZJV102UYJD20:>SX`@0XZ:R0P2QXJ420:2PX080WinO0P2NWYh209fMW@80
VIVI0P2EUID209:BTP0308n?S`2:RXX0RXZ:0080QXJ60P24Q8@208:2PP80Ogmo0P1nOWh207emO@80
Ng]k0P1hN7P207AdM080LW9b0P1aLG4206i^KP80K6a/0P1YJFT00`1ZJVX0K6a/06a/K00206i^KP80
Kfm_0P1aLG4207AdM080MgMg0P1jNWX207emO@80P8200P23Ph<208J6QP80RHV90P2<S8`208n?S`80
TY:B00<0UYJF09VIV@2IVIT00P2LW9`209nOW`80Xj>S0P2VYZH20:VYZ@80[Jf]5@3oool001<0oooo
0P2c/k<20;Jf]P80^;Rh0P2l_;`20;no_`80`/;20P35aLD20<S8b0030<_;b`3>c/h0c/k>0080dM7A
0P3De=@20=SHf080g=cL0P3Ogml20>?Sh`80i^KV0P3Zj^X20>k^kP80l_;b0P3fm_H20?[jnP@0oOgm
00<0o?cl0?Ogm`3gmoL00P3alO420>[ZjP80hN7Q0P3Hf=P20<g=c@80`/;20P2g]kL20:^[Z`@0Y:BT
0P2SXj<40::RXP<0XJ6Q0P2PX:0209nOW`80WYjN0P2MWId209bLW0@0Vi^K0P2LW9`209fMW@H0WYjN
0P2OWil909jNWP@0WinO0P2QXJ420:>SX`80Y:BT0P2UYJD20:JVYP@0YjNW1P2XZ:P30:NWY`@0YZJV
102UYJD20:>SX`@0XZ:R0P2QXJ420:2PX080WinO0P2NWYh209fMW@80VIVI0P2EUID209:BTP0308n?
S`2:RXX0RXZ:0080QXJ60P24Q8@208:2PP80Ogmo0P1nOWh207emO@80Ng]k0P1hN7P207AdM080LW9b
0P1aLG4206i^KP80K6a/0P1YJFT00`1ZJVX0K6a/06a/K00206i^KP80Kfm_0P1aLG4207AdM080MgMg
0P1jNWX207emO@80P8200P23Ph<208J6QP80RHV90P2<S8`208n?S`80TY:B00<0UYJF09VIV@2IVIT0
0P2LW9`209nOW`80Xj>S0P2VYZH20:VYZ@80[Jf]5@3oool001<0oooo0P2c/k<20;Jf]P80^KVi0P2l
_;`20;no_`80`/;20P35aLD20<S8b0030<_;b`3>c/h0c/k>0080dM7A0P3EeMD20=SHf080fm_K0P3O
gml20>?Sh`80inOW0P3Zj^X20>k^kP80l_;b0P3fm_H20?[jnP80o?cl0P3moOd00`3inOT0lo?c0??c
l`020>c/k080iNGU0P3Lg=`20=;BdP80b<S80P2n_[h20;Bd]080ZJVY0P2UYJD20:BTY080Xj>S0P2R
XZ840:6QX@<0X:2P0P2OWil609jNWP80WIfM102NWYh209nOW`X0X:2P0`2OWil609jNWP80WinO0P2P
X:020:6QX@80XZ:R102TY:@40:FUY@H0YZJV1@2UYJD40:BTY080XZ:R0P2QXJ440::RXP@0XJ6Q0P2P
X:0209jNWP80VYZJ0P2HV9P209JFUP80Ti>C00<0Shn?08^;R`2;Rh/00P28R8P208B4Q080P8200P1n
OWh207alO080NWYj0P1hN7P207EeM@80Lg=c0P1aLG4206m_K`80KFe]0P1ZJVX206UYJ@0306YZJP1[
Jf/0Jf][0080KFe]0P1_Kfl2075aL@80M7Ad0P1fMWH207UiN@80O7al0P20P80208>3P`80QHF50P29
RHT208b<S080Shn?0P2BTY800`2FUYH0VIVI09VIV@0209bLW080X:2P0P2SXj<20:JVYP80ZJVY0P2/
[:`E0?ooo`004`3oool20;>c/`80][Jf0P2i^KT20;bl_080_kno0P32`/820<G5a@80b<S800<0bl_;
0<k>cP3>c/h00P3AdM420=GEe@80f=SH0P3Kfm/20=oOg`80hn?S0P3WinL20>[ZjP80k^k^0P3bl_82
0?KfmP80n_[j0P3lo?`20?gmo@030?Win@3clo<0lo?c0080k>c/0P3UiND20=cLg080d];B0P38b<P2
0;jn_P80];Bd0P2YZJT20:FUY@80Y:BT0P2SXj<20::RXP@0XJ6Q0`2PX:0209nOW`H0WYjN0P2MWId4
09jNWP80WinO2P2PX:0309nOW`H0WYjN0P2OWil20:2PX080XJ6Q0P2RXZ840:BTY0@0YJFU1P2VYZH5
0:FUY@@0Y:BT0P2RXZ820:6QX@@0XZ:R102QXJ420:2PX080WYjN0P2JVYX209RHV080UYJF0P2CTi<0
0`2?Shl0Rh^;08^;R`0208R8R080Q8B40P20P80207inOP80O7al0P1jNWX207QhN080MGEe0P1cLg<2
075aL@80Kfm_0P1]KFd206YZJP80JFUY00<0JVYZ06][J`1[Jf/00P1]KFd206m_K`80LG5a0P1dM7@2
07IfMP80NGUi0P1lO7`20820P080Ph>30P25QHD208V9R@80S8b<0P2?Shl209:BTP0309JFUP2IVIT0
VIVI0080W9bL0P2PX:020:>SX`80YZJV0P2YZJT20:b/[1D0oooo000C0?ooo`80/k>c0P2f][H20;Vi
^@80^k^k0P2n_[h20<71`@80a<C40P38b<P00`3;bl/0c/k>0<k>cP020=7Ad@80eMGE0P3Hf=P20=_K
f`80gmoO0P3Shn<20>KViP80j^[Z0P3^k^h20??cl`80moOg0P3jn_X20?_kn`80nOWi00<0mOGe0>o_
k`3_knl00P3Xj>P20>3Ph080emOG0P3>c/h20<C4a080^[Zj0P2`/;020:RXZ080YJFU0P2SXj<20::R
XP@0XJ6Q0`2PX:0>09nOW`80X:2P0P2QXJ480::RXP80XJ6Q0`2PX:0409nOW`80WYjN102OWil40:2P
X080XJ6Q0P2RXZ820:>SX`l0Y:BT0P2SXj<20::RXP80XJ6Q0P2PX:0409nOW`80WYjN0P2MWId209^K
V`80VIVI0P2HV9P209JFUP80TY:B00<0Shn?08b<S02<S8`00P26QXH208:2PP80P8200P1mOGd207]k
N`80N7Qh0P1eMGD2079bLP80LG5a0P1_Kfl206e]K@80Jf][0P1XJ6P206MWI`0306QXJ01ZJVX0JVYZ
0080Jf][0P1]KFd2071`L080Lg=c0P1fMWH207UiN@80O7al0P1oOgl208:2PP80QHF50P28R8P208b<
S080Shn?0P2BTY800`2FUYH0VIVI09VIV@0209bLW080WinO0P2RXZ820:JVYP80ZJVY0P2][JdE0?oo
o`004`3oool20;>c/`80][Jf0P2i^KT20;^k^`80_[jn0P31`L420<C4a080b<S800<0bl_;0<k>cP3>
c/h00P3AdM420=GEe@80f=SH0P3Kfm/20=oOg`80hn?S0P3Vi^H20>[ZjP80k^k^0P3clo<20?Ogm`80
n_[j0P3kno/20?Win@030?Gem@3_knl0kno_0080j>SX0P3Ph>020=OGe`80c/k>0P34a<@20;Zj^P80
/;2`0P2XZ:P20:FUY@80Xj>S0P2RXZ840:6QX@<0X:2P3P2OWil20:2PX080XJ6Q202RXZ820:6QX@<0
X:2P102OWil209jNWP@0WinO102PX:020:6QX@80XZ:R0P2SXj<?0:BTY080Xj>S0P2RXZ820:6QX@80
X:2P102OWil209jNWP80WIfM0P2KVi/209VIV@80V9RH0P2FUYH209:BTP0308n?S`2<S8`0S8b<0080
QXJ60P22PX820820P080OGem0P1kNg/207QhN080MGEe0P1bLW82075aL@80Kfm_0P1]KFd206][J`80
J6QX0P1WIfL00`1XJ6P0JVYZ06YZJP0206][J`80KFe]0P1`L70207=cL`80MWIf0P1iNGT207alO080
Ogmo0P22PX8208F5Q@80R8R80P2<S8`208n?S`80TY:B00<0UYJF09VIV@2IVIT00P2LW9`209nOW`80
XZ:R0P2VYZH20:VYZ@80[Jf]5@3oool001<0oooo0P2c/k<20;Jf]P80^;Rh0P2k^k/20;jn_P80`L71
0P35aLD20<S8b0030<_;b`3>c/h0c/k>0080d];B0P3EeMD20=SHf080g=cL0P3Ogml20>?Sh`80inOW
0P3Zj^X20>k^kP80lo?c0P3gmoL40?[jnP80moOg00<0l_;b0>_[j`3[jn/00P3Ti>@20=_Kf`80d];B
0P38b<P20;no_`80][Jf0P2[Zj/40:BTY080XZ:R102QXJ440:2PX0/0WinO0P2PX:040:6QX@80XZ:R
202SXj<20::RXP80XJ6Q0`2PX:0409nOW`@0WYjN0P2OWil20:2PX0H0XJ6Q1P2RXZ820:>SX`T0XZ:R
0P2QXJ420:2PX080WinO102NWYh209fMW@80W9bL0P2JVYX209RHV080UYJF0P2CTi<2096AT@0308f=
S@28R8P0R8R80080QXJ60P22PX8207moO`80Ng]k0P1iNGT207IfMP80M7Ad0P1aLG4206m_K`80K6a/
0P1ZJVX206QXJ080IFEU0P1WIfL00`1XJ6P0JFUY06UYJ@0206YZJP80K6a/0P1_Kfl2079bLP80MGEe
0P1iNGT207alO080Ogmo0P22PX8208F5Q@80R8R80P2;Rh/208n?S`80TY:B00<0UIFE09RHV02HV9P0
0P2LW9`209nOW`80Xj>S0P2VYZH20:VYZ@80[Jf]5@3oool001<0oooo0P2c/k<20;Jf]P80^;Rh0P2k
^k/20;jn_P80`L710P35aLD20<S8b0030<_;b`3>c/h0c/k>0080d];B0P3EeMD20=SHf080g=cL0P3O
gml20>?Sh`80inOW0P3Zj^X20>k^kP80lo?c0P3gmoL40?[jnP80moOg00<0l_;b0>_[j`3[jn/00P3T
i>@20=_Kf`80d];B0P38b<P20;no_`80][Jf0P2[Zj/40:BTY080XZ:R102QXJ440:2PX0/0WinO0P2P
X:040:6QX@80XZ:R202SXj<20::RXP80XJ6Q0`2PX:0409nOW`@0WYjN0P2OWil20:2PX0H0XJ6Q1P2R
XZ820:>SX`T0XZ:R0P2QXJ420:2PX080WinO102NWYh209fMW@80W9bL0P2JVYX209RHV080UYJF0P2C
Ti<2096AT@0308f=S@28R8P0R8R80080QXJ60P22PX8207moO`80Ng]k0P1iNGT207IfMP80M7Ad0P1a
LG4206m_K`80K6a/0P1ZJVX206QXJ080IFEU0P1WIfL00`1XJ6P0JFUY06UYJ@0206YZJP80K6a/0P1_
Kfl2079bLP80MGEe0P1iNGT207alO080Ogmo0P22PX8208F5Q@80R8R80P2;Rh/208n?S`80TY:B00<0
UIFE09RHV02HV9P00P2LW9`209nOW`80Xj>S0P2VYZH20:VYZ@80[Jf]5@3oool001<0oooo0P2c/k<2
0;Jf]P80^;Rh0P2k^k/20;jn_P80`L710P35aLD20<S8b0030<_;b`3>c/h0c/k>0080dM7A0P3EeMD2
0=SHf080g=cL0P3Ogml20>;RhP80i^KV0P3Zj^X20>k^kP80l_;b0P3fm_H40?Shn080m?Cd00<0kno_
0>SXj03Xj>P00P3Ph>020=OGe`80c/k>0P35aLD20;^k^`80/[:b0P2WYjL40::RXP80XJ6Q1P2PX:09
09nOW`@0X:2P202QXJ440::RXP@0Xj>S0P2RXZ830:6QX@80X:2P0P2OWil809jNWPH0WinO1P2PX:0;
0:6QX@80X:2P202OWil209fMW@80W9bL0P2JVYX209RHV080UIFE0P2CTi<2092@T080SXj>00<0Rh^;
08V9R@29RHT00P25QHD20820P080O7al0P1jNWX207MgM`80M7Ad0P1bLW82071`L080KVi^0P1ZJVX2
06QXJ080IFEU0P1TI6@206IVIP0306MWI`1YJFT0JFUY0080JVYZ0P1/K6`206m_K`80LW9b0P1eMGD2
07QhN080Ng]k0P1nOWh20861P@80QHF50P28R8P208^;R`80SXj>0P2BTY800`2EUID0V9RH09RHV002
09bLW080WinO0P2RXZ820:JVYP80ZJVY0P2][JdE0?ooo`004`3oool20;>c/`80][Jf0P2h^;P20;^k
^`80_[jn0P31`L420<G5a@80b<S800<0bl_;0<k>cP3>c/h00P3AdM420=GEe@80f=SH0P3Lg=`20=oO
g`80h^;R0P3Vi^H20>[ZjP80k^k^0P3bl_820?KfmP@0n?Sh0P3dm?@00`3_knl0j>SX0>SXj0020>3P
h080emOG0P3>c/h20<G5a@80^k^k0P2b/[820:NWY`@0XZ:R0P2QXJ460:2PX0T0WinO102PX:080:6Q
X@@0XZ:R102SXj<20::RXP<0XJ6Q0P2PX:0209nOW`P0WYjN1P2OWil60:2PX0/0XJ6Q0P2PX:0809nO
W`80WIfM0P2LW9`209ZJVP80V9RH0P2EUID209>CT`80T92@0P2>SXh00`2;Rh/0RHV908V9R@0208F5
Q@80P8200P1lO7`207YjNP80MgMg0P1dM7@2079bLP80L71`0P1^KVh206YZJP80J6QX0P1UIFD206AT
I080IVIV00<0IfMW06UYJ@1YJFT00P1ZJVX206a/K080Kfm_0P1bLW8207EeM@80N7Qh0P1kNg/207in
OP80PH610P25QHD208R8R080Rh^;0P2>SXh209:BTP0309FEU@2HV9P0V9RH0080W9bL0P2OWil20::R
XP80YZJV0P2YZJT20:f][AD0oooo000C0?ooo`80/k>c0P2f][H20;Vi^@80_;bl0P2o_kl20<;2`P80
aLG50P38b<P00`3;bl/0c/k>0<k>cP020=7Ad@80eMGE0P3Hf=P20=_Kf`80gmoO0P3Rh^820>KViP80
j^[Z0P3^k^h20?;blP80m_Kf0P3gmoL20?Gem@80l?3`00<0j^[Z0>?Sh`3Shn<00P3Kfm/20=;BdP80
b<S80P30`<020;Rh^080[jn_0P2UYJD20::RXP80XJ6Q102PX:0?09nOW`@0XJ6Q0P2PX:0209jNWP80
WinO0P2PX:020:6QX@80XZ:R0P2QXJ420:2PX080XJ6Q00<0X:2P09nOW`2OWil00P2NWYh609fMW@H0
WYjN5@2OWil209jNWP@0WIfM102KVi/209VIV@80V9RH0P2EUID209>CT`80T92@0P2>SXh208^;R`03
08V9R@27QhL0QhN70080PH610P1nOWh207]kN`80N7Qh0P1fMWH207AdM080LG5a0P1^KVh206][J`80
J6QX0P1VIVH606ATI00306EUI@1VIVH0IVIV0080J6QX0P1[Jf/206i^KP80LG5a0P1dM7@207QhN080
Ng]k0P1nOWh20861P@80Q8B40P28R8P208^;R`80SXj>0P2ATI400`2EUID0V9RH09RHV00209bLW080
WinO0P2RXZ820:JVYP80ZJVY0P2][JdE0?ooo`004`3oool20;>c/`80][Jf0P2i^KT20;bl_080_kno
0P32`/820<G5a@80b<S800<0bl_;0<k>cP3>c/h00P3AdM420=GEe@80f=SH0P3Kfm/20=oOg`80h^;R
0P3Vi^H20>[ZjP80k^k^0P3bl_820?KfmP80moOg0P3emOD20?3`l0030>[ZjP3Shn<0hn?S0080fm_K
0P3Bd]820<S8b080`<300P2h^;P20:n_[`80YJFU0P2RXZ820:6QX@@0X:2P3`2OWil40:6QX@80X:2P
0P2NWYh209nOW`80X:2P0P2QXJ420::RXP80XJ6Q0P2PX:020:6QX@030:2PX02OWil0WinO0080WYjN
1P2MWId609jNWQD0WinO0P2NWYh409fMW@@0Vi^K0P2IVIT209RHV080UIFE0P2CTi<2092@T080SXj>
0P2;Rh/00`29RHT0QhN708N7Q`020861P@80OWin0P1kNg/207QhN080MWIf0P1dM7@2075aL@80KVi^
0P1[Jf/206QXJ080IVIV1P1TI6@00`1UIFD0IVIV06IVIP0206QXJ080Jf][0P1^KVh2075aL@80M7Ad
0P1hN7P207]kN`80OWin0P21PH4208B4Q080R8R80P2;Rh/208j>SP80TI6A00<0UIFE09RHV02HV9P0
0P2LW9`209nOW`80XZ:R0P2VYZH20:VYZ@80[Jf]5@3oool001<0oooo0P2c/k<20;Jf]P80^KVi0P2l
_;`20;no_`80`/;20P34a<@20<O7a`030<_;b`3>c/h0c/k>0080dM7A0P3De=@20=SHf080fm_K0P3O
gml20>;RhP80i^KV0P3Zj^X20>k^kP80l_;b103emOD20?7al@80jn_[00<0iNGU0=gMg@3MgMd00P3E
eMD20<g=c@80a<C40P2l_;`20;>c/`80ZJVY0P2QXJ420:2PX0@0WinO0P2NWYh?09nOW`80WYjN102L
W9`209fMW@@0WYjN0P2MWId409^KV`@0W9bL1@2MWId409bLW0@0WIfM5@2NWYh209fMW@@0W9bL102K
Vi/209VIV@80V9RH0P2FUYH209BDU080TY:B0P2@T90208j>SP80Rh^;0P28R8P00`27QhL0PX:208:2
PP0207inOP80O7al0P1hN7P207IfMP80Lg=c0P1aLG4206i^KP80Jf][0P1XJ6P206IVIP80IFEU101T
I6@506=SH`80IfMW0P1ZJVX206e]K@80LG5a0P1dM7@207MgM`80NWYj0P1nOWh20861P@80Q8B40P27
QhL208^;R`80SXj>0P2ATI400`2EUID0V9RH09RHV00209^KV`80WinO0P2RXZ820:JVYP80ZJVY0P2/
[:`E0?ooo`004`3oool20;>c/`80][Jf0P2i^KT20;bl_080_kno0P32`/820<C4a080alO700<0bl_;
0<k>cP3>c/h00P3AdM420=CDe080f=SH0P3Kfm/20=oOg`80h^;R0P3Vi^H20>[ZjP80k^k^0P3bl_84
0?Gem@80lO7a0P3[jn/00`3UiND0gMgM0=gMg@020=GEe@80cLg=0P34a<@20;bl_080/k>c0P2YZJT2
0:6QX@80X:2P102OWil209jNWPl0WinO0P2NWYh409bLW080WIfM102NWYh209fMW@@0Vi^K102LW9`5
09fMW@@0W9bL102MWIdE09jNWP80WIfM102LW9`409^KV`80VIVI0P2HV9P209JFUP80U9BD0P2BTY82
092@T080SXj>0P2;Rh/208R8R00308N7Q`22PX80PX:20080OWin0P1lO7`207QhN080MWIf0P1cLg<2
075aL@80KVi^0P1[Jf/206QXJ080IVIV0P1UIFD406ATI0D0Hf=S0P1WIfL206YZJP80KFe]0P1aLG42
07AdM080MgMg0P1jNWX207inOP80PH610P24Q8@208N7Q`80Rh^;0P2>SXh2096AT@0309FEU@2HV9P0
V9RH0080Vi^K0P2OWil20::RXP80YZJV0P2YZJT20:b/[1D0oooo000C0?ooo`80/[:b0P2e]KD20;Rh
^080^k^k0P2n_[h20<71`@80a<C40P37alL00`3:b/X0c/k>0<k>cP020=7Ad@80e=CD0P3GemL20=_K
f`80g]kN0P3Rh^820>KViP80jNWY0P3]kNd20?7al@80lo?c0P3bl_820>k^kP80j>SX00<0hN7Q0=SH
f03Hf=P00P3@d=020<O7a`80`<300P2h^;P20:j^[P80Y:BT402NWYh909nOW`80WYjN0P2MWId209bL
W0P0WIfM202LW9`709^KV`@0W9bL1P2MWId609jNWPH0WIfM1`2LW9`209^KV`80VYZJ102IVIT209JF
UP80U9BD0P2BTY82092@T080SXj>0P2<S8`208Z:RP80R8R80P25QHD00`22PX80OGem07emO@0207]k
N`80N7Qh0P1eMGD207AdM080LG5a0P1^KVh206][J`80JFUY0P1VIVH206ATI080HV9R0P1QHF42061P
H080GemO00<0H61P06=SH`1SHf<00P1VIVH206UYJ@80KFe]0P1`L70207=cL`80MgMg0P1jNWX207em
O@80PH610P24Q8@208N7Q`80RXZ:0P2>SXh2096AT@0309FEU@2HV9P0V9RH0080Vi^K0P2OWil20::R
XP80YJFU0P2YZJT20:b/[1D0oooo000C0?ooo`80/[:b0P2e]KD20;Rh^080^k^k0P2n_[h20<71`@80
a<C40P37alL00`3:b/X0c/k>0<k>cP020=7Ad@80e=CD0P3GemL20=_Kf`80g]kN0P3Rh^820>KViP80
jNWY0P3]kNd20?7al@80lo?c0P3bl_820>k^kP80j>SX00<0hN7Q0=SHf03Hf=P00P3@d=020<O7a`80
`<300P2h^;P20:j^[P80Y:BT402NWYh909nOW`80WYjN0P2MWId209bLW0P0WIfM202LW9`709^KV`@0
W9bL1P2MWId609jNWPH0WIfM1`2LW9`209^KV`80VYZJ102IVIT209JFUP80U9BD0P2BTY82092@T080
SXj>0P2<S8`208Z:RP80R8R80P25QHD00`22PX80OGem07emO@0207]kN`80N7Qh0P1eMGD207AdM080
LG5a0P1^KVh206][J`80JFUY0P1VIVH206ATI080HV9R0P1QHF42061PH080GemO00<0H61P06=SH`1S
Hf<00P1VIVH206UYJ@80KFe]0P1`L70207=cL`80MgMg0P1jNWX207emO@80PH610P24Q8@208N7Q`80
RXZ:0P2>SXh2096AT@0309FEU@2HV9P0V9RH0080Vi^K0P2OWil20::RXP80YJFU0P2YZJT20:b/[1D0
oooo000C0?ooo`80/k>c0P2e]KD20;Rh^080^k^k0P2n_[h20<71`@80a<C40P37alL00`3:b/X0cLg=
0<g=c@020=3@d080e=CD0P3GemL20=[JfP80g]kN0P3QhN420>GUi@80jNWY0P3/k>`20?3`l080l_;b
0P3_knl20>WYj@80h^;R00<0fm_K0=?Cd`3Cdm<00P3;bl/20<?3``80_;bl0P2c/k<20:VYZ@80WinO
0P2KVi/409bLW0@0WIfM102NWYh;09nOW`@0WYjN0P2MWId809jNWPH0WIfM0P2LW9`00`2KVi/0VYZJ
09ZJVP0209ZJVP80Vi^K102LW9`>09fMW@@0W9bL0P2KVi/509ZJVP80VIVI0P2HV9P209NGU`80UIFE
0P2CTi<2096AT@@0SXj>0P2;Rh/208R8R080QXJ60P24Q8@20861P@0307emO@1iNGT0NGUi0080MgMg
0P1dM7@2079bLP80L71`0P1^KVh206][J`80JFUY0P1WIfL206ATI080HF5Q101OGel205iNGP80GEeM
00<0GUiN069RHP1RHV800P1UIFD206UYJ@80K6a/0P1_Kfl207=cL`80MWIf0P1jNWX207emO@80P820
0P23Ph<208N7Q`80RXZ:0P2>SXh2096AT@0309BDU02HV9P0V9RH0080Vi^K0P2OWil20::RXP80YJFU
0P2YZJT20:b/[1D0oooo000C0?ooo`80/k>c0P2e]KD20;Rh^080^k^k0P2n_[h20<71`@80a<C40P37
alL00`3:b/X0cLg=0<g=c@020=3@d080e=CD0P3GemL20=[JfP80g]kN0P3QhN420>GUi@80jNWY0P3/
k>`20?3`l080l_;b0P3_knl20>WYj@80h^;R00<0fm_K0=?Cd`3Cdm<00P3;bl/20<?3``80_;bl0P2c
/k<20:VYZ@80WinO0P2KVi/409bLW0@0WIfM102NWYh;09nOW`@0WYjN0P2MWId809jNWPH0WIfM0P2L
W9`00`2KVi/0VYZJ09ZJVP0209ZJVP80Vi^K102LW9`>09fMW@@0W9bL0P2KVi/509ZJVP80VIVI0P2H
V9P209NGU`80UIFE0P2CTi<2096AT@@0SXj>0P2;Rh/208R8R080QXJ60P24Q8@20861P@0307emO@1i
NGT0NGUi0080MgMg0P1dM7@2079bLP80L71`0P1^KVh206][J`80JFUY0P1WIfL206ATI080HF5Q101O
Gel205iNGP80GEeM00<0GUiN069RHP1RHV800P1UIFD206UYJ@80K6a/0P1_Kfl207=cL`80MWIf0P1j
NWX207emO@80P8200P23Ph<208N7Q`80RXZ:0P2>SXh2096AT@0309BDU02HV9P0V9RH0080Vi^K0P2O
Wil20::RXP80YJFU0P2YZJT20:b/[1D0oooo000C0?ooo`80/k>c0P2f][H20;Rh^080^k^k0P2n_[h2
0<71`@80a<C40P37alL00`3:b/X0cLg=0<g=c@020=3@d080dm?C0P3GemL20=[JfP80gMgM0P3QhN42
0>CTi080j>SX0P3/k>`40?3`l080jn_[0P3Vi^H20=oOg`030=OGe`3>c/h0c/k>0080alO70P2o_kl2
0;Rh^080[jn_0P2UYJD209bLW0@0Vi^K0P2LW9`409fMW@80WYjN7@2OWil209jNWP80WIfM0P2LW9`0
0`2KVi/0VYZJ09ZJVP0209ZJVP80Vi^K102LW9`:09fMW@H0W9bL0P2KVi/209ZJVP0309VIV@2HV9P0
V9RH0080V9RH0P2GUiL209JFUP80U9BD0P2BTY82092@T080SXj>0P2<S8`208V9R@80QhN70P25QHD2
08:2PP80P8200P1lO7`00`1iNGT0MWIf07IfMP0207=cL`80LG5a0P1_Kfl206a/K080Jf][0P1ZJVX2
06MWI`80I6AT0P1QHF4205eMG@80G5aL0P1MGEd405]KF`0305iNGP1QHF40HF5Q0080IFEU0P1XJ6P2
06a/K080Kfm_0P1bLW8207EeM@80NGUi0P1lO7`20820P080Ph>30P26QXH208Z:RP80SHf=0P2ATI40
0`2DU9@0V9RH09RHV00209^KV`80WinO0P2RXZ820:FUY@80ZJVY0P2/[:`E0?ooo`004`3oool20;>c
/`80][Jf0P2h^;P20;^k^`80_[jn0P31`L420<C4a080alO700<0b/[:0<g=c@3=cLd00P3@d=020=?C
d`80emOG0P3Jf]X20=gMg@80hN7Q0P3Ti>@20>SXj080k>c/103`l?020>_[j`80i^KV0P3Ogml00`3G
emL0c/k>0<k>cP020<O7a`80_kno0P2h^;P20:n_[`80YJFU0P2LW9`409^KV`80W9bL102MWId209jN
WQd0WinO0P2NWYh209fMW@80W9bL00<0Vi^K09ZJVP2JVYX00P2JVYX209^KV`@0W9bL2P2MWId609bL
W080Vi^K0P2JVYX00`2IVIT0V9RH09RHV00209RHV080UiNG0P2FUYH209BDU080TY:B0P2@T90208j>
SP80S8b<0P29RHT208N7Q`80QHF50P22PX820820P080O7al00<0NGUi07IfMP1fMWH00P1cLg<2075a
L@80Kfm_0P1/K6`206][J`80JVYZ0P1WIfL206ATI080HF5Q0P1MGEd205aLG080GEeM101KFe/00`1N
GUh0HF5Q065QH@0206EUI@80J6QX0P1/K6`206m_K`80LW9b0P1eMGD207UiN@80O7al0P20P80208>3
P`80QXJ60P2:RXX208f=S@80TI6A00<0U9BD09RHV02HV9P00P2KVi/209nOW`80XZ:R0P2UYJD20:VY
Z@80[:b/5@3oool001<0oooo0P2c/k<20;Jf]P80^;Rh0P2k^k/20;jn_P80`L710P34a<@20<K6aP03
0<W9b@3<c<`0c<c<0080clo?0P3Bd]820=KFeP80fMWI0P3MgMd20>3Ph080hn?S0P3WinL20>[ZjP80
kNg]0P3/k>`20>OWi`80hN7Q0P3Hf=P00`3@d=00bLW90<W9b@020<;2`P80^k^k0P2b/[820:RXZ080
WYjN0P2HV9P209VIV@80VYZJ0P2KVi/209bLW080WYjN102OWil=0:2PX0H0WinO102PX:0209nOW`80
WYjN0P2MWId409bLW00309^KV`2JVYX0VYZJ0080Vi^K102LW9`409fMW@@0WYjN1P2MWId209bLW080
Vi^K102JVYX00`2IVIT0UiNG09NGU`0209JFUP80UIFE0P2DU9@209:BTP80T92@0P2>SXh208Z:RP80
R8R80P27QhL208F5Q@80PX:20P20P80207alO080N7Qh00<0MGEe075aL@1aLG400P1_Kfl206e]K@80
Jf][0P1ZJVX206UYJ@80IfMW0P1UIFD2069RHP80GemO0P1LG5`205YJFP80F5QH0P1GEeL205UIF@03
05eMG@1PH600H61P0080I6AT0P1WIfL206YZJP80KVi^0P1aLG4207EeM@80N7Qh0P1lO7`207moO`80
Ph>30P26QXH208Z:RP80SHf=0P2ATI400`2DU9@0UiNG09NGU`0209^KV`80WYjN0P2RXZ820:FUY@80
ZJVY0P2/[:`E0?ooo`004`3oool20;:b/P80]KFe0P2h^;P20;^k^`80_[jn0P30`<020<?3``80a/K6
00<0bLW90<c<c03<c<`00P3?cll20=;BdP80eMGE0P3Hf=P20=cLg080gmoO0P3Shn<20>KViP80jNWY
0P3[jn/20>SXj080hn?S0P3Kfm/20=?Cd`030<c<c035aLD0aLG50080_Kfm0P2d];@20:ZZZP80X:2P
0P2FUYH209>CT`80UiNG0P2IVIT209^KV`80WIfM0P2NWYh209nOW`@0X:2P1`2QXJ460:2PX0X0WinO
0P2NWYh209fMW@@0W9bL0`2KVi/409bLW080WIfM302NWYh409fMW@80Vi^K0P2JVYX209VIV@0309RH
V02GUiL0UiNG0080UIFE0P2DU9@209:BTP80T92@0P2>SXh208^;R`80R8R80P26QXH208B4Q080PH61
0P1nOWh207alO080NGUi0P1eMGD00`1bLW80KVi^06i^KP0206][J`80JVYZ0P1YJFT406QXJ080IFEU
0P1SHf<205mOG`80G5aL0P1HF5P205MGE`@0EUIF0P1IFET00`1LG5`0H61P061PH00206=SH`80IVIV
0P1ZJVX206e]K@80LG5a0P1dM7@207QhN080Ng]k0P1oOgl208:2PP80QXJ60P29RHT208f=S@80T92@
00<0U9BD09NGU`2GUiL00P2KVi/209jNWP80XZ:R0P2UYJD20:VYZ@80[:b/5@3oool001<0oooo0P2b
/[820;Fe]@80^;Rh0P2k^k/20;jn_P80`<300P33`l<20<K6aP030<W9b@3<c<`0c<c<0080clo?0P3B
d]820=GEe@80f=SH0P3Lg=`20=oOg`80hn?S0P3Vi^H20>WYj@80jn_[0P3Xj>P20>?Sh`80fm_K0P3C
dm<00`3<c<`0aLG50<G5a@020;fm_@80];Bd0P2ZZZX20:2PX080UYJF0P2CTi<209NGU`80VIVI0P2K
Vi/209fMW@80WYjN0P2OWil40:2PX0L0XJ6Q1P2PX:0:09nOW`80WYjN0P2MWId409bLW0<0Vi^K102L
W9`209fMW@`0WYjN102MWId209^KV`80VYZJ0P2IVIT00`2HV9P0UiNG09NGU`0209FEU@80U9BD0P2B
TY82092@T080SXj>0P2;Rh/208R8R080QXJ60P24Q8@20861P@80OWin0P1lO7`207UiN@80MGEe00<0
LW9b06i^KP1^KVh00P1[Jf/206YZJP80JFUY101XJ6P206EUI@80Hf=S0P1OGel205aLG080F5QH0P1G
EeL405IFEP80FEUI00<0G5aL061PH01PH6000P1SHf<206IVIP80JVYZ0P1]KFd2075aL@80M7Ad0P1h
N7P207]kN`80Ogmo0P22PX8208J6QP80RHV90P2=SHd2092@T00309BDU02GUiL0UiNG0080Vi^K0P2N
WYh20::RXP80YJFU0P2YZJT20:b/[1D0oooo000C0?ooo`80/k>c0P2e]KD20;Rh^080^k^k0P2m_Kd2
0<30`080`l?30P36a/H00`39bLT0c<c<0<c<c0020<o?c`80d];B0P3EeMD20=SHf080fm_K0P3Ng]h2
0>;RhP80iNGU0P3YjNT20>[ZjP80iNGU0P3Ogml20=OGe`80clo?00<0alO70<30`030`<000P2h^;P2
0:n_[`80Y:BT0P2GUiL2096AT@80U9BD0P2GUiL209VIV@80W9bL0P2MWId209nOW`80X:2P0P2QXJ49
0::RXP80XJ6Q102PX:0:09nOW`80WYjN2`2MWId409jNWP@0WinO102PX:0409nOW`80WYjN0P2MWId2
09^KV`80VYZJ0P2IVIT00`2GUiL0UYJF09JFUP0209BDU080TY:B0P2ATI4208n?S`80S8b<0P29RHT2
08F5Q@80PX:20P20P80207inOP80O7al0P1iNGT207EeM@80LW9b00<0Kfm_06][J`1[Jf/0101XJ6P4
06MWI`80IVIV0P1SHf<2065QH@80G5aL0P1IFET205IFEP@0E5AD0P1EEED205QHF00305aLG01OGel0
GemO0080HV9R0P1VIVH206UYJ@80KFe]0P1`L70207AdM080MgMg0P1kNg/207moO`80PX:20P26QXH2
08V9R@80SHf=0P2@T9000`2DU9@0UiNG09NGU`0209ZJVP80WYjN0P2RXZ820:FUY@80ZJVY0P2/[:`E
0?ooo`004`3oool20;>c/`80]KFe0P2h^;P20;^k^`80_Kfm0P30`<020<?3``80a/K600<0bLW90<c<
c03<c<`00P3?cll20=;BdP80eMGE0P3Hf=P20=_Kf`80g]kN0P3Rh^820>GUi@80jNWY0P3Zj^X20>GU
i@80gmoO0P3GemL20<o?c`030<O7a`30`<00`<300080^;Rh0P2_[jl20:BTY080UiNG0P2ATI4209BD
U080UiNG0P2IVIT209bLW080WIfM0P2OWil20:2PX080XJ6Q2@2RXZ820:6QX@@0X:2P2P2OWil209jN
WP/0WIfM102NWYh409nOW`@0X:2P102OWil209jNWP80WIfM0P2KVi/209ZJVP80VIVI00<0UiNG09JF
UP2FUYH00P2DU9@209:BTP80TI6A0P2?Shl208b<S080RHV90P25QHD208:2PP80P8200P1nOWh207al
O080NGUi0P1eMGD2079bLP0306m_K`1[Jf/0Jf][00@0J6QX101WIfL206IVIP80Hf=S0P1QHF4205aL
G080FEUI0P1FEUH405ADE080EEEE0P1HF5P00`1LG5`0GemO05mOG`02069RHP80IVIV0P1YJFT206e]
K@80L71`0P1dM7@207MgM`80Ng]k0P1oOgl208:2PP80QXJ60P29RHT208f=S@80T92@00<0U9BD09NG
U`2GUiL00P2JVYX209jNWP80XZ:R0P2UYJD20:VYZ@80[:b/5@3oool001<0oooo0P2b/[820;Fe]@80
^;Rh0P2j^[X20;fm_@80`<300P32`/820<G5a@030<S8b03;bl/0bl_;0080c/k>0P3AdM420=CDe080
emOG0P3Jf]X20=gMg@80h>3P0P3Ti>@20>WYj@80j>SX0P3Rh^820=_Kf`80d];B0P3;bl/00`33`l<0
^k^k0;^k^`020;:b/P80Z:RX0P2MWId409BDU080UIFE0P2HV9P209^KV`80WIfM0P2NWYh20:2PX080
XZ:R2`2SXj<20::RXP@0XJ6Q102PX:0809nOW`L0WYjN102OWil40:2PX0X0XJ6Q0P2PX:0209nOW`80
WYjN0P2LW9`209^KV`80VIVI00<0V9RH09JFUP2FUYH00P2DU9@209:BTP80T92@0P2>SXh208^;R`80
RHV90P25QHD208:2PP80P8200P1mOGd207YjNP80MgMg0P1cLg<2071`L00306a/K01XJ6P0J6QX00H0
IVIV0P1UIFD206ATI080HF5Q0P1NGUh205UIF@80EEEE0P1CDe<4059BDP80E5AD0P1HF5P00`1KFe/0
GUiN05iNGP02069RHP80IFEU0P1YJFT206a/K080L71`0P1cLg<207MgM`80NWYj0P1nOWh20861P@80
QHF50P29RHT208b<S080T92@00<0Ti>C09NGU`2GUiL00P2JVYX209jNWP80XZ:R0P2UYJD20:VYZ@80
[:b/5@3oool001<0oooo0P2b/[820;Fe]@80^;Rh0P2j^[X20;fm_@80`<300P32`/820<G5a@030<S8
b03;bl/0bl_;0080c/k>0P3AdM420=CDe080emOG0P3Jf]X20=gMg@80h>3P0P3Ti>@20>WYj@80j>SX
0P3Rh^820=_Kf`80d];B0P3;bl/00`33`l<0^k^k0;^k^`020;:b/P80Z:RX0P2MWId409BDU080UIFE
0P2HV9P209^KV`80WIfM0P2NWYh20:2PX080XZ:R2`2SXj<20::RXP@0XJ6Q102PX:0809nOW`L0WYjN
102OWil40:2PX0X0XJ6Q0P2PX:0209nOW`80WYjN0P2LW9`209^KV`80VIVI00<0V9RH09JFUP2FUYH0
0P2DU9@209:BTP80T92@0P2>SXh208^;R`80RHV90P25QHD208:2PP80P8200P1mOGd207YjNP80MgMg
0P1cLg<2071`L00306a/K01XJ6P0J6QX00H0IVIV0P1UIFD206ATI080HF5Q0P1NGUh205UIF@80EEEE
0P1CDe<4059BDP80E5AD0P1HF5P00`1KFe/0GUiN05iNGP02069RHP80IFEU0P1YJFT206a/K080L71`
0P1cLg<207MgM`80NWYj0P1nOWh20861P@80QHF50P29RHT208b<S080T92@00<0Ti>C09NGU`2GUiL0
0P2JVYX209jNWP80XZ:R0P2UYJD20:VYZ@80[:b/5@3oool001<0oooo0P2b/[820;Fe]@80]kNg0P2j
^[X20;fm_@80_kno0P32`/820<G5a@030<S8b03:b/X0b/[:0080cLg=0P3@d=020=?Cd`80e]KF0P3I
fMT20=cLg080h>3P0P3Shn<20>GUi@80h^;R0P3Lg=`20=KFeP80cLg=0P36a/H00`2n_[h0][Jf0;Jf
]P020:f][@80Xj>S0P2HV9P209>CT`80UIFE0P2GUiL209ZJVP80W9bL0P2NWYh20:2PX080XZ:R102T
Y:@50:FUY@@0Y:BT0P2SXj<20::RXP80XJ6Q202PX:0:09nOW`<0X:2P0P2QXJ420::RXP@0Xj>S1P2T
Y:@20:>SX`80XZ:R0P2QXJ420:2PX080WYjN0P2LW9`209ZJVP0309RHV02FUYH0UYJF0080U9BD0P2B
TY82092@T080SHf=0P2;Rh/208R8R080QHF50P22PX8207moO`80O7al0P1iNGT207EeM@80LW9b0P1^
KVh00`1[Jf/0IfMW06MWI`0406EUI@80I6AT0P1RHV82061PH080GUiN0P1JFUX205EEE@80De=C0P1A
DE4204m?C`80DE5A0P1DE5@205MGE`0305YJFP1NGUh0GUiN0080HF5Q0P1UIFD206QXJ080K6a/0P1_
Kfl207=cL`80MWIf0P1jNWX207inOP80PH610P25QHD208R8R080S8b<0P2?Shl00`2CTi<0UYJF09JF
UP0209ZJVP80WYjN0P2QXJ420:FUY@80ZJVY0P2/[:`E0?ooo`004`3oool20;:b/P80]KFe0P2g]kL2
0;Zj^P80_Kfm0P2o_kl20<;2`P80aLG500<0b<S80<[:bP3:b/X00P3=cLd20=3@d080dm?C0P3Fe]H2
0=WIf@80g=cL0P3Ph>020>?Sh`80iNGU0P3Rh^820=cLg080e]KF0P3=cLd20<K6aP030;jn_P2f][H0
][Jf0080[Jf]0P2SXj<209RHV080Ti>C0P2EUID209NGU`80VYZJ0P2LW9`209jNWP80X:2P0P2RXZ84
0:BTY0D0YJFU102TY:@20:>SX`80XZ:R0P2QXJ480:2PX0X0WinO0`2PX:020:6QX@80XZ:R102SXj<6
0:BTY080Xj>S0P2RXZ820:6QX@80X:2P0P2NWYh209bLW080VYZJ00<0V9RH09JFUP2FUYH00P2DU9@2
09:BTP80T92@0P2=SHd208^;R`80R8R80P25QHD208:2PP80Ogmo0P1lO7`207UiN@80MGEe0P1bLW82
06i^KP0306][J`1WIfL0IfMW00@0IFEU0P1TI6@2069RHP80H61P0P1NGUh205YJFP80EEEE0P1CDe<2
055AD@80Cdm?0P1ADE4205ADE080EeMG00<0FUYJ05iNGP1NGUh00P1QHF4206EUI@80J6QX0P1/K6`2
06m_K`80Lg=c0P1fMWH207YjNP80OWin0P21PH4208F5Q@80R8R80P2<S8`208n?S`0309>CT`2FUYH0
UYJF0080VYZJ0P2NWYh20:6QX@80YJFU0P2YZJT20:b/[1D0oooo000C0?ooo`80/[:b0P2e]KD20;Ng
]`80^[Zj0P2m_Kd20;no_`80`/;20P34a<@00`37alL0b/[:0<[:bP020<g=c@80clo?0P3Bd]820=GE
e@80f=SH0P3Kfm/20=kNgP80hN7Q0P3Shn<20=kNgP80f=SH0P3@d=020<[:bP80`l?300<0^k^k0;:b
/P2b/[800P2XZ:P209fMW@80U9BD0P2CTi<209JFUP80VIVI0P2KVi/209jNWP80X:2P0P2RXZ820:BT
Y080YJFU0P2VYZH20:NWY`030:RXZ02WYjL0YjNW00@0YZJV0P2TY:@20:>SX`80XZ:R0P2QXJ420:2P
X0H0WinO1P2PX:020:6QX@<0XZ:R0P2SXj<20:BTY0@0YJFU1P2VYZH40:FUY@80Xj>S0P2QXJ4209nO
W`80WIfM0P2KVi/00`2HV9P0UYJF09JFUP0209BDU080TI6A0P2?Shl208b<S080RHV90P27QhL208B4
Q080PH610P1nOWh207]kN`80MgMg0P1dM7@2071`L080KFe]00<0JVYZ06EUI@1UIFD00P1TI6@206=S
H`80HV9R0P1QHF4205mOG`80G5aL0P1HF5P205=CD`80D51@0P1>CTh204e=C@80Cdm?0P1CDe<205IF
EP0305UIF@1MGEd0GEeM0080H61P0P1TI6@206MWI`80Jf][0P1_Kfl2079bLP80MWIf0P1iNGT207em
O@80PH610P24Q8@208R8R080S8b<0P2?Shl00`2CTi<0UYJF09JFUP0209ZJVP80WYjN0P2QXJ420:FU
Y@80ZJVY0P2/[:`E0?ooo`004`3oool20;:b/P80]KFe0P2g]kL20;Zj^P80_Kfm0P2o_kl20<;2`P80
a<C400<0alO70<[:bP3:b/X00P3=cLd20<o?c`80d];B0P3EeMD20=SHf080fm_K0P3Ng]h20>7Qh@80
hn?S0P3Ng]h20=SHf080d=3@0P3:b/X20<?3``030;^k^`2b/[80/[:b0080Z:RX0P2MWId209BDU080
Ti>C0P2FUYH209VIV@80Vi^K0P2NWYh20:2PX080XZ:R0P2TY:@20:FUY@80YZJV0P2WYjL00`2XZ:P0
YjNW0:NWY`040:JVYP80Y:BT0P2SXj<20::RXP80XJ6Q0P2PX:0609nOW`H0X:2P0P2QXJ430::RXP80
Xj>S0P2TY:@40:FUY@H0YZJV102UYJD20:>SX`80XJ6Q0P2OWil209fMW@80Vi^K00<0V9RH09JFUP2F
UYH00P2DU9@2096AT@80Shn?0P2<S8`208V9R@80QhN70P24Q8@20861P@80OWin0P1kNg/207MgM`80
M7Ad0P1`L70206e]K@0306YZJP1UIFD0IFEU0080I6AT0P1SHf<2069RHP80HF5Q0P1OGel205aLG080
F5QH0P1CDe<2051@D080CTi>0P1=CDd204m?C`80De=C0P1FEUH00`1IFET0GEeM05eMG@02061PH080
I6AT0P1WIfL206][J`80Kfm_0P1bLW8207IfMP80NGUi0P1mOGd20861P@80Q8B40P28R8P208b<S080
Shn?00<0Ti>C09JFUP2FUYH00P2JVYX209jNWP80XJ6Q0P2UYJD20:VYZ@80[:b/5@3oool001<0oooo
0P2b/[820;Fe]@80]kNg0P2i^KT20;bl_080_kno0P31`L420<C4a0030<O7a`39bLT0bLW90080c<c<
0P3?cll20=;BdP80e=CD0P3GemL20=_Kf`80g]kN103Rh^820=_Kf`80eMGE0P3=cLd20<G5a@80_[jn
00<0]kNg0:j^[P2^[Zh00P2TY:@209VIV@80U9BD0P2GUiL209VIV@80Vi^K0P2MWId20:2PX080XZ:R
0P2TY:@20:JVYP80Z:RX0P2YZJT30:ZZZP80ZJVY0P2XZ:P20:NWY`80YJFU0P2SXj<20::RXP80XJ6Q
0P2PX:0609nOW`@0X:2P0P2QXJ420::RXP030:>SX`2TY:@0Y:BT0080YJFU0P2VYZH20:NWY`80Z:RX
202YZJT20:NWY`80YJFU0P2SXj<20:6QX@80WYjN0P2KVi/00`2IVIT0UYJF09JFUP0209BDU080TI6A
0P2?Shl208b<S080RHV90P26QXH208>3P`80PH610P1mOGd207YjNP80MWIf0P1bLW8206m_K`80Jf][
00<0IfMW06ATI01TI6@00P1SHf<2069RHP@0H61P0P1MGEd205YJFP80EEEE0P1@D50204a<C080BTY:
0P1;Bd/204i>CP80DE5A0P1EEED00`1HF5P0G5aL05aLG00205mOG`80Hf=S0P1WIfL206YZJP80KVi^
0P1bLW8207EeM@80NGUi0P1mOGd20820P080Q8B40P28R8P208^;R`80Shn?00<0Ti>C09JFUP2FUYH0
0P2JVYX209fMW@80XJ6Q0P2UYJD20:VYZ@80[:b/5@3oool001<0oooo0P2b/[820;Fe]@80]kNg0P2i
^KT20;bl_080_kno0P31`L420<C4a0030<O7a`39bLT0bLW90080c<c<0P3?cll20=;BdP80e=CD0P3G
emL20=_Kf`80g]kN103Rh^820=_Kf`80eMGE0P3=cLd20<G5a@80_[jn00<0]kNg0:j^[P2^[Zh00P2T
Y:@209VIV@80U9BD0P2GUiL209VIV@80Vi^K0P2MWId20:2PX080XZ:R0P2TY:@20:JVYP80Z:RX0P2Y
ZJT30:ZZZP80ZJVY0P2XZ:P20:NWY`80YJFU0P2SXj<20::RXP80XJ6Q0P2PX:0609nOW`@0X:2P0P2Q
XJ420::RXP030:>SX`2TY:@0Y:BT0080YJFU0P2VYZH20:NWY`80Z:RX202YZJT20:NWY`80YJFU0P2S
Xj<20:6QX@80WYjN0P2KVi/00`2IVIT0UYJF09JFUP0209BDU080TI6A0P2?Shl208b<S080RHV90P26
QXH208>3P`80PH610P1mOGd207YjNP80MWIf0P1bLW8206m_K`80Jf][00<0IfMW06ATI01TI6@00P1S
Hf<2069RHP@0H61P0P1MGEd205YJFP80EEEE0P1@D50204a<C080BTY:0P1;Bd/204i>CP80DE5A0P1E
EED00`1HF5P0G5aL05aLG00205mOG`80Hf=S0P1WIfL206YZJP80KVi^0P1bLW8207EeM@80NGUi0P1m
OGd20820P080Q8B40P28R8P208^;R`80Shn?00<0Ti>C09JFUP2FUYH00P2JVYX209fMW@80XJ6Q0P2U
YJD20:VYZ@80[:b/5@3oool001<0oooo0P2b/[820;Bd]080]kNg0P2i^KT20;bl_080_[jn0P31`L42
0<?3``030<K6aP38b<P0b<S80080bl_;0P3>c/h20=7Ad@80e=CD0P3GemL20=WIf@80g=cL0P3Ph>02
0=gMg@80e]KF0P3AdM420<[:bP80`l?30P2l_;`00`2d];@0ZZZZ0:ZZZP020:6QX@80VYZJ0P2IVIT2
09ZJVP80Vi^K0P2MWId209nOW`80XJ6Q0P2TY:@20:JVYP80ZJVY0P2ZZZX20:^[Z`<0[:b/0P2[Zj/2
0:VYZ@80Z:RX0P2UYJD20:>SX`80XZ:R0P2PX:0209nOW`@0WYjN0P2OWil20:2PX080XJ6Q0P2RXZ82
0:>SX`030:BTY02UYJD0YJFU0080YJFU0P2WYjL20:RXZ080ZZZZ1P2/[:`20:^[Z`80ZZZZ0P2WYjL2
0:FUY@80XZ:R0P2OWil209bLW00309ZJVP2GUiL0UiNG0080U9BD0P2ATI4208n?S`80S8b<0P29RHT2
08J6QP80Ph>30P20P80207alO080NGUi0P1eMGD2075aL@80KFe]0P1YJFT00`1VIVH0HV9R069RHP02
065QH@80H61P0P1OGel205eMG@80FEUI0P1FEUH2055AD@80CDe=0P19BDT204M7A`80B4Q80P1<C4`2
051@D080E5AD00<0EeMG05]KF`1KFe/00P1OGel2069RHP80IVIV0P1ZJVX206i^KP80LG5a0P1eMGD2
07UiN@80O7al0P20P80208B4Q080QhN70P2;Rh/208n?S`0309:BTP2FUYH0UYJF0080VYZJ0P2MWId2
0:6QX@80YJFU0P2XZ:P20:b/[1D0oooo000C0?ooo`80/[:b0P2d];@20;Ng]`80^KVi0P2l_;`20;jn
_P80`L710P33`l<00`36a/H0b<S80<S8b0020<_;b`80c/k>0P3AdM420=CDe080emOG0P3IfMT20=cL
g080h>3P0P3MgMd20=KFeP80dM7A0P3:b/X20<?3``80_;bl00<0];Bd0:ZZZP2ZZZX00P2QXJ4209ZJ
VP80VIVI0P2JVYX209^KV`80WIfM0P2OWil20:6QX@80Y:BT0P2VYZH20:VYZ@80ZZZZ0P2[Zj/30:b/
[080Zj^[0P2YZJT20:RXZ080YJFU0P2SXj<20::RXP80X:2P0P2OWil409jNWP80WinO0P2PX:020:6Q
X@80XZ:R0P2SXj<00`2TY:@0YJFU0:FUY@020:FUY@80YjNW0P2XZ:P20:ZZZPH0[:b/0P2[Zj/20:ZZ
ZP80YjNW0P2UYJD20::RXP80WinO0P2LW9`00`2JVYX0UiNG09NGU`0209BDU080TI6A0P2?Shl208b<
S080RHV90P26QXH208>3P`80P8200P1lO7`207UiN@80MGEe0P1aLG4206e]K@80JFUY00<0IVIV069R
HP1RHV800P1QHF42061PH080GemO0P1MGEd205UIF@80EUIF0P1ADE4204e=C@80BDU90P17AdL204Q8
B080C4a<0P1@D50205ADE00305MGE`1KFe/0Fe]K0080GemO0P1RHV8206IVIP80JVYZ0P1^KVh2075a
L@80MGEe0P1iNGT207alO080P8200P24Q8@208N7Q`80Rh^;0P2?Shl00`2BTY80UYJF09JFUP0209ZJ
VP80WIfM0P2QXJ420:FUY@80Z:RX0P2/[:`E0?ooo`004`3oool20;:b/P80];Bd0P2g]kL20;Vi^@80
^k^k0P2n_[h20<30`080`/;200<0aLG50<S8b038b<P00P3:b/X20<g=c@80d=3@0P3Cdm<20=KFeP80
f=SH0P3Kfm/20=kNgP80f][J0P3EeMD20<k>cP80alO70P31`L420;Vi^@030;6a/@2VYZH0YZJV0080
WIfM0P2IVIT409bLW080WIfM0P2OWil20:6QX@80Y:BT0P2VYZH20:VYZ@80Zj^[0P2][Jd40:j^[P<0
[Jf]0P2ZZZX20:RXZ080YJFU0P2SXj<20:6QX@80WinO0P2NWYh409fMW@80WYjN0P2OWil20:2PX080
XJ6Q0P2RXZ800`2TY:@0YJFU0:FUY@020:NWY`80Z:RX0P2ZZZX20:b/[080[Jf]1P2^[Zh20:b/[080
ZZZZ0P2WYjL20:>SX`80X:2P0P2MWId00`2JVYX0UiNG09NGU`0209BDU080TY:B0P2?Shl208b<S080
RHV90P26QXH208:2PP80OWin0P1kNg/207MgM`80M7Ad0P1`L70206a/K080J6QX00<0I6AT065QH@1Q
HF400P1OGel205iNGP80GEeM0P1JFUX205ADE080DU9B0P1=CDd204U9B@80ATI60P15ADD204M7A`80
Bd];0P1?Cdl2059BDP0305IFEP1JFUX0FUYJ0080GUiN0P1RHV8206IVIP80JFUY0P1]KFd2075aL@80
M7Ad0P1hN7P207alO080P8200P23Ph<208N7Q`80Rh^;0P2>SXh00`2BTY80UYJF09JFUP0209ZJVP80
WIfM0P2QXJ420:FUY@80Z:RX0P2/[:`E0?ooo`004`3oool20;:b/P80];Bd0P2g]kL20;Vi^@80^k^k
0P2n_[h20<30`080`/;200<0aLG50<S8b038b<P00P3:b/X20<g=c@80d=3@0P3Cdm<20=KFeP80f=SH
0P3Kfm/20=kNgP80f][J0P3EeMD20<k>cP80alO70P31`L420;Vi^@030;6a/@2VYZH0YZJV0080WIfM
0P2IVIT409bLW080WIfM0P2OWil20:6QX@80Y:BT0P2VYZH20:VYZ@80Zj^[0P2][Jd40:j^[P<0[Jf]
0P2ZZZX20:RXZ080YJFU0P2SXj<20:6QX@80WinO0P2NWYh409fMW@80WYjN0P2OWil20:2PX080XJ6Q
0P2RXZ800`2TY:@0YJFU0:FUY@020:NWY`80Z:RX0P2ZZZX20:b/[080[Jf]1P2^[Zh20:b/[080ZZZZ
0P2WYjL20:>SX`80X:2P0P2MWId00`2JVYX0UiNG09NGU`0209BDU080TY:B0P2?Shl208b<S080RHV9
0P26QXH208:2PP80OWin0P1kNg/207MgM`80M7Ad0P1`L70206a/K080J6QX00<0I6AT065QH@1QHF40
0P1OGel205iNGP80GEeM0P1JFUX205ADE080DU9B0P1=CDd204U9B@80ATI60P15ADD204M7A`80Bd];
0P1?Cdl2059BDP0305IFEP1JFUX0FUYJ0080GUiN0P1RHV8206IVIP80JFUY0P1]KFd2075aL@80M7Ad
0P1hN7P207alO080P8200P23Ph<208N7Q`80Rh^;0P2>SXh00`2BTY80UYJF09JFUP0209ZJVP80WIfM
0P2QXJ420:FUY@80Z:RX0P2/[:`E0?ooo`004`3oool20;:b/P80];Bd0P2f][H20;Rh^080^k^k0P2m
_Kd20;no_`80`/;200<0a<C40<O7a`37alL00P39bLT20<c<c080clo?0P3AdM420=CDe080emOG0P3I
fMT20=[JfP80e]KF0P3Cdm<20<g=c@80a/K60P2n_[h20;Ng]`030:f][@2TY:@0Y:BT00H0WYjN0P2M
WId209jNWP80X:2P0P2RXZ820:FUY@80Z:RX0P2[Zj/20:f][@80[jn_102`/;000`2_[jl0[Jf]0:f]
[@020:ZZZP80YjNW0P2TY:@20:6QX@80WinO0P2MWId209bLW080Vi^K102LW9`209fMW@80WinO0P2P
X:020::RXP030:>SX`2UYJD0YJFU0080YjNW0P2YZJT20:^[Z`80[:b/0P2^[Zh40;2`/080[Zj^0P2/
[:`20:VYZ@80YjNW0P2SXj<20:2PX080WIfM00<0VYZJ09NGU`2GUiL00P2DU9@209:BTP80Shn?0P2<
S8`208V9R@80QXJ60P22PX8207emO@80NGUi0P1eMGD2079bLP80KVi^0P1ZJVX206IVIP03069RHP1O
Gel0GemO0080GEeM0P1LG5`205UIF@80EEEE0P1?Cdl204i>CP80BTY:0P15ADD404A4A080ADE50P19
BDT204e=C@80DE5A00<0EEEE05UIF@1IFET00P1MGEd2065QH@80IFEU0P1XJ6P206a/K080L71`0P1d
M7@207QhN080O7al0P1oOgl208>3P`80QhN70P2:RXX208j>SP0309:BTP2FUYH0UYJF0080VIVI0P2M
WId20:6QX@80YJFU0P2XZ:P20:b/[1D0oooo000C0?ooo`80/[:b0P2d];@20;Jf]P80^;Rh0P2k^k/2
0;fm_@80_kno0P32`/800`34a<@0alO70<O7a`020<W9b@80c<c<0P3?cll20=7Ad@80e=CD0P3GemL2
0=WIf@80f][J0P3Fe]H20=?Cd`80cLg=0P36a/H20;jn_P80]kNg00<0[Jf]0:BTY02TY:@01P2NWYh2
09fMW@80WYjN0P2PX:020::RXP80YJFU0P2XZ:P20:^[Z`80[Jf]0P2_[jl40;2`/0030:n_[`2][Jd0
[Jf]0080ZZZZ0P2WYjL20:BTY080XJ6Q0P2OWil209fMW@80W9bL0P2KVi/409bLW080WIfM0P2OWil2
0:2PX080XZ:R00<0Xj>S0:FUY@2UYJD00P2WYjL20:VYZ@80Zj^[0P2/[:`20:j^[P@0/;2`0P2^[Zh2
0:b/[080ZJVY0P2WYjL20:>SX`80X:2P0P2MWId00`2JVYX0UiNG09NGU`0209BDU080TY:B0P2?Shl2
08b<S080RHV90P26QXH208:2PP80OGem0P1iNGT207EeM@80LW9b0P1^KVh206YZJP80IVIV00<0HV9R
05mOG`1OGel00P1MGEd205aLG080FEUI0P1EEED204m?C`80CTi>0P1:BTX204E5A@@0A4A40P15ADD2
04U9B@80CDe=0P1ADE400`1EEED0FEUI05UIF@0205eMG@80HF5Q0P1UIFD206QXJ080K6a/0P1`L702
07AdM080N7Qh0P1lO7`207moO`80Ph>30P27QhL208Z:RP80SXj>00<0TY:B09JFUP2FUYH00P2IVIT2
09fMW@80XJ6Q0P2UYJD20:RXZ080[:b/5@3oool001<0oooo0P2b/[820;Bd]080][Jf0P2h^;P20;Zj
^P80_Kfm0P2o_kl20<71`@030<C4a036a/H0a/K60080b<S80P3;bl/20<g=c@80d=3@0P3Cdm<20=KF
eP@0f][J0P3De=@20=7Ad@80bl_;0P34a<@20;bl_080];Bd00<0ZZZZ0:6QX@2QXJ400P2MWId209nO
W`@0WYjN0P2OWil20:6QX@80Xj>S0P2VYZH20:ZZZP@0[Jf]102[Zj/20:f][@030:j^[P2[Zj/0Zj^[
0080YjNW0P2UYJD20:>SX`80WinO0P2LW9`209ZJVPH0VIVI0P2JVYX209^KV`80W9bL0P2MWId20:2P
X0030::RXP2WYjL0YjNW00@0ZJVY0P2XZ:P20:VYZ@80[:b/0P2^[Zh20:b/[080Zj^[0P2YZJT20:RX
Z080YJFU0P2RXZ8209nOW`80W9bL00<0V9RH09JFUP2FUYH00P2DU9@2096AT@80Shn?0P2<S8`208V9
R@80QHF50P21PH4207emO@80N7Qh0P1eMGD2075aL@80K6a/0P1XJ6P206ATI00305mOG`1LG5`0G5aL
0080FUYJ0P1HF5P205ADE080DE5A0P1<C4`204Y:BP80ADE51010@4020451@@80A4A40P18B4P204a<
C080D51@00<0E5AD05QHF01HF5P00P1LG5`2061PH080I6AT0P1XJ6P206a/K080L71`0P1dM7@207Mg
M`80Ng]k0P1oOgl208>3P`80QhN70P2:RXX208j>SP0309:BTP2FUYH0UYJF0080VIVI0P2MWId20:6Q
X@80YJFU0P2XZ:P20:b/[1D0oooo000C0?ooo`80/[:b0P2d];@20;Jf]P80^;Rh0P2j^[X20;fm_@80
_kno0P31`L400`34a<@0a/K60<K6aP020<S8b080bl_;0P3=cLd20=3@d080dm?C0P3Fe]H40=[JfP80
e=CD0P3AdM420<_;b`80a<C40P2l_;`20;Bd]0030:ZZZP2QXJ40XJ6Q0080WIfM0P2OWil409jNWP80
WinO0P2QXJ420:>SX`80YZJV0P2ZZZX40:f][@@0Zj^[0P2][Jd00`2^[Zh0Zj^[0:^[Z`020:NWY`80
YJFU0P2SXj<209nOW`80W9bL0P2JVYX609VIV@80VYZJ0P2KVi/209bLW080WIfM0P2PX:000`2RXZ80
YjNW0:NWY`040:VYZ@80Z:RX0P2YZJT20:b/[080[Zj^0P2/[:`20:^[Z`80ZJVY0P2XZ:P20:FUY@80
XZ:R0P2OWil209bLW00309RHV02FUYH0UYJF0080U9BD0P2ATI4208n?S`80S8b<0P29RHT208F5Q@80
PH610P1mOGd207QhN080MGEe0P1aLG4206a/K080J6QX0P1TI6@00`1OGel0G5aL05aLG00205YJFP80
F5QH0P1DE5@2055AD@80C4a<0P1:BTX204E5A@@0@4100P11@D4204A4A080B4Q80P1<C4`2051@D003
05ADE01HF5P0F5QH0080G5aL0P1PH60206ATI080J6QX0P1/K6`2071`L080M7Ad0P1gMgL207]kN`80
Ogmo0P23Ph<208N7Q`80RXZ:0P2>SXh00`2BTY80UYJF09JFUP0209VIV@80WIfM0P2QXJ420:FUY@80
Z:RX0P2/[:`E0?ooo`004`3oool20;:b/P80];Bd0P2f][H20;Rh^080^[Zj0P2l_;`20;jn_P80`<30
00<0`/;20<G5a@35aLD00P37alL20<[:bP80cLg=0P3?cll20=;BdP80eMGE0P3GemL20=GEe@80d];B
0P3=cLd20<S8b080`L710P2i^KT20;:b/P030:ZZZP2SXj<0Xj>S0080X:2P0P2OWil209jNWP80WIfM
0P2OWil20:6QX@80Xj>S0P2VYZH20:VYZ@80ZZZZ0P2WYjL20:JVYP@0Z:RX00<0YZJV0:BTY02TY:@0
0P2RXZ8209nOW`80W9bL0P2JVYX209VIV@80UiNG102FUYH209NGU`@0V9RH0P2IVIT209^KV`80WIfM
00<0WinO0:2PX02PX:00102QXJ420::RXP80YjNW0P2YZJT20:NWY`@0YJFU0P2SXj<20::RXP80XJ6Q
0P2NWYh209bLW080VIVI00<0UYJF09BDU02DU9@00P2BTY82092@T080SXj>0P2;Rh/208R8R080Q8B4
0P20P80207alO080NGUi0P1eMGD206m_K`80JFUY0P1UIFD2065QH@0305eMG@1IFET0FEUI0080EeMG
0P1DE5@2051@D080C4a<0P18B4P204M7A`80@D511P0n?Sh20492@P80AdM70P1;Bd/204m?C`0305=C
D`1GEeL0EeMG0080Fe]K0P1OGel206=SH`80IfMW0P1[Jf/206m_K`80Lg=c0P1gMgL207]kN`80Ogmo
0P22PX8208J6QP80RXZ:0P2>SXh00`2BTY80UIFE09FEU@0209VIV@80WIfM0P2QXJ420:FUY@80Z:RX
0P2/[:`E0?ooo`004`3oool20;:b/P80];Bd0P2f][H20;Rh^080^[Zj0P2l_;`20;jn_P80`<3000<0
`/;20<G5a@35aLD00P37alL20<[:bP80cLg=0P3?cll20=;BdP80eMGE0P3GemL20=GEe@80d];B0P3=
cLd20<S8b080`L710P2i^KT20;:b/P030:ZZZP2SXj<0Xj>S0080X:2P0P2OWil209jNWP80WIfM0P2O
Wil20:6QX@80Xj>S0P2VYZH20:VYZ@80ZZZZ0P2WYjL20:JVYP@0Z:RX00<0YZJV0:BTY02TY:@00P2R
XZ8209nOW`80W9bL0P2JVYX209VIV@80UiNG102FUYH209NGU`@0V9RH0P2IVIT209^KV`80WIfM00<0
WinO0:2PX02PX:00102QXJ420::RXP80YjNW0P2YZJT20:NWY`@0YJFU0P2SXj<20::RXP80XJ6Q0P2N
WYh209bLW080VIVI00<0UYJF09BDU02DU9@00P2BTY82092@T080SXj>0P2;Rh/208R8R080Q8B40P20
P80207alO080NGUi0P1eMGD206m_K`80JFUY0P1UIFD2065QH@0305eMG@1IFET0FEUI0080EeMG0P1D
E5@2051@D080C4a<0P18B4P204M7A`80@D511P0n?Sh20492@P80AdM70P1;Bd/204m?C`0305=CD`1G
EeL0EeMG0080Fe]K0P1OGel206=SH`80IfMW0P1[Jf/206m_K`80Lg=c0P1gMgL207]kN`80Ogmo0P22
PX8208J6QP80RXZ:0P2>SXh00`2BTY80UIFE09FEU@0209VIV@80WIfM0P2QXJ420:FUY@80Z:RX0P2/
[:`E0?ooo`004`3oool20;:b/P80/k>c0P2e]KD20;Ng]`80^KVi0P2k^k/20;fm_@80_kno00<0`/;2
0<C4a034a<@00P36a/H20<W9b@80bl_;0P3>c/h20=7Ad@@0dm?C0P3Bd]820=7Ad@80c<c<0P36a/H2
0;jn_P80]kNg0P2_[jl00`2WYjL0XJ6Q0:6QX@020::RXP80XJ6Q0P2OWil409jNWP80X:2P0P2RXZ82
0:BTY080YJFU0P2VYZH20:FUY@@0Y:BT0`2OWil209bLW080VYZJ0P2HV9P209JFUP80U9BD0P2BTY82
096AT@80TY:B0P2CTi<409BDU0@0UIFE0P2GUiL209RHV00309ZJVP2KVi/0Vi^K0080Vi^K0P2MWId2
0:6QX@80Xj>S0P2QXJ420::RXP80X:2P0P2OWil209bLW080WIfM0P2KVi/209NGU`80UYJF0P2EUID0
0`2CTi<0TY:B09:BTP02092@T080Shn?0P2=SHd208Z:RP80QhN70P23Ph<207moO`80NWYj0P1fMWH2
075aL@80Jf][0P1WIfL206=SH`80GUiN00<0FEUI05IFEP1FEUH00P1DE5@2051@D080Bd];0P18B4P2
04A4A080@d=30P0n?Sh203`l?080>c/k0P0l?3`20451@@80ADE50P1:BTX204i>CP03059BDP1FEUH0
EUIF0080Fe]K0P1OGel206=SH`80IfMW0P1[Jf/206m_K`80Lg=c0P1fMWH207YjNP80OWin0P22PX82
08J6QP80RXZ:0P2>SXh00`2BTY80UIFE09FEU@0209VIV@80WIfM0P2QXJ420:FUY@80Z:RX0P2/[:`E
0?ooo`004`3oool20;:b/P80/k>c0P2e]KD20;Ng]`80^KVi0P2k^k/20;fm_@80_kno00<0`/;20<C4
a034a<@00P36a/H20<W9b@80bl_;0P3>c/h20=7Ad@@0dm?C0P3Bd]820=7Ad@80c<c<0P36a/H20;jn
_P80]kNg0P2_[jl00`2WYjL0XJ6Q0:6QX@020::RXP80XJ6Q0P2OWil409jNWP80X:2P0P2RXZ820:BT
Y080YJFU0P2VYZH20:FUY@@0Y:BT0`2OWil209bLW080VYZJ0P2HV9P209JFUP80U9BD0P2BTY82096A
T@80TY:B0P2CTi<409BDU0@0UIFE0P2GUiL209RHV00309ZJVP2KVi/0Vi^K0080Vi^K0P2MWId20:6Q
X@80Xj>S0P2QXJ420::RXP80X:2P0P2OWil209bLW080WIfM0P2KVi/209NGU`80UYJF0P2EUID00`2C
Ti<0TY:B09:BTP02092@T080Shn?0P2=SHd208Z:RP80QhN70P23Ph<207moO`80NWYj0P1fMWH2075a
L@80Jf][0P1WIfL206=SH`80GUiN00<0FEUI05IFEP1FEUH00P1DE5@2051@D080Bd];0P18B4P204A4
A080@d=30P0n?Sh203`l?080>c/k0P0l?3`20451@@80ADE50P1:BTX204i>CP03059BDP1FEUH0EUIF
0080Fe]K0P1OGel206=SH`80IfMW0P1[Jf/206m_K`80Lg=c0P1fMWH207YjNP80OWin0P22PX8208J6
QP80RXZ:0P2>SXh00`2BTY80UIFE09FEU@0209VIV@80WIfM0P2QXJ420:FUY@80Z:RX0P2/[:`E0?oo
o`004`3oool20;:b/P80/k>c0P2e]KD20;Ng]`80^KVi0P2k^k/20;fm_@80_kno00<0`L710<?3``33
`l<00P35aLD20<S8b080b/[:0P3=cLd20=3@d080eMGE0P3Fe]H20=?Cd`80c/k>0P39bLT20<;2`P80
^k^k0P2e]KD20:j^[P030:NWY`2SXj<0Xj>S0080Xj>S0P2QXJ4209jNWP80WIfM0P2LW9`809fMW@@0
Vi^K102NWYh209^KV`0309JFUP2?Shl0Shn?0080SXj>0P2<S8`208^;R`80RXZ:0P2;Rh/208b<S080
SXj>0P2?Shl2092@T0@0TI6A102BTY8209>CT`0309BDU02EUID0UIFE0080UiNG0P2HV9P209VIV@80
W9bL0P2KVi/209VIV@H0UIFE0P2CTi<208n?S`80SXj>1`2?Shl208j>SP80S8b<0P2;Rh/208V9R@80
QXJ60P22PX8207emO@80N7Qh0P1cLg<206e]K@80IfMW0P1RHV8205mOG`80Fe]K00<0EUIF059BDP1B
DU800P1?Cdl204a<C080B4Q80P13@d<203lo?`80?Shn0P0j>SX203Ti>@80>3Ph0P0k>c/20410@080
A4A40P19BDT204e=C@03055AD@1FEUH0EUIF0080FUYJ0P1NGUh2069RHP80IVIV0P1ZJVX206i^KP80
LW9b0P1fMWH207YjNP80OWin0P22PX8208J6QP80RXZ:0P2>SXh00`2BTY80UIFE09FEU@0209VIV@80
WIfM0P2QXJ420:BTY080Z:RX0P2/[:`E0?ooo`004`3oool20;:b/P80/k>c0P2e]KD20;Ng]`80^KVi
0P2k^k/20;fm_@80_kno00<0`L710<?3``33`l<00P35aLD20<S8b080b/[:0P3=cLd20=3@d080eMGE
0P3Fe]H20=?Cd`80c/k>0P39bLT20<;2`P80^k^k0P2e]KD20:j^[P030:NWY`2SXj<0Xj>S0080Xj>S
0P2QXJ4209jNWP80WIfM0P2LW9`809fMW@@0Vi^K102NWYh209^KV`0309JFUP2?Shl0Shn?0080SXj>
0P2<S8`208^;R`80RXZ:0P2;Rh/208b<S080SXj>0P2?Shl2092@T0@0TI6A102BTY8209>CT`0309BD
U02EUID0UIFE0080UiNG0P2HV9P209VIV@80W9bL0P2KVi/209VIV@H0UIFE0P2CTi<208n?S`80SXj>
1`2?Shl208j>SP80S8b<0P2;Rh/208V9R@80QXJ60P22PX8207emO@80N7Qh0P1cLg<206e]K@80IfMW
0P1RHV8205mOG`80Fe]K00<0EUIF059BDP1BDU800P1?Cdl204a<C080B4Q80P13@d<203lo?`80?Shn
0P0j>SX203Ti>@80>3Ph0P0k>c/20410@080A4A40P19BDT204e=C@03055AD@1FEUH0EUIF0080FUYJ
0P1NGUh2069RHP80IVIV0P1ZJVX206i^KP80LW9b0P1fMWH207YjNP80OWin0P22PX8208J6QP80RXZ:
0P2>SXh00`2BTY80UIFE09FEU@0209VIV@80WIfM0P2QXJ420:BTY080Z:RX0P2/[:`E0?ooo`004`3o
ool20;6a/@80/k>c0P2e]KD20;Jf]P80^;Rh0P2j^[X20;bl_080_[jn00<0`<300<;2`P32`/800P34
a<@20<K6aP80bLW90P3;bl/20<k>cP80d];B0P3Cdm<20=7Ad@80c/k>0P38b<P20<30`080^[Zj0P2d
];@20:j^[P030:RXZ02TY:@0Y:BT0080Xj>S0P2PX:0209fMW@80Vi^K0P2JVYX209VIV@80UiNG0P2E
UID209:BTP@0T92@0P2?Shl208f=S@80RXZ:00<0R8R808J6QP26QXH00P24Q8@408:2PP80Q8B40P26
QXH208R8R080RXZ:0P2<S8`208f=S@X0SXj>0`2?Shl2092@T080TI6A0P2BTY8208n?S`80Rh^;1029
RHT408R8R080QXJ60P24Q8@208F5Q@80QhN70P29RHT308Z:RP80Rh^;0P2:RXX208R8R080QXJ60P23
Ph<207moO`80NWYj0P1fMWH2071`L080Jf][0P1UIFD2061PH080G5aL0P1GEeL00`1BDU80CTi>04i>
CP0204];B`80AdM70P13@d<203lo?`80>c/k0P0j>SX203Lg=`@0=SHf0P0j>SX203hn?P80@d=30P18
B4P204a<C003055AD@1EEED0EEEE0080FEUI0P1MGEd2069RHP80IVIV0P1ZJVX206i^KP80LW9b0P1f
MWH207YjNP80OWin0P22PX8208J6QP80RHV90P2=SHd00`2ATI40UIFE09FEU@0209VIV@80WIfM0P2Q
XJ420:BTY080Z:RX0P2/[:`E0?ooo`004`3oool20;6a/@80/k>c0P2e]KD20;Jf]P80^;Rh0P2j^[X2
0;bl_080_[jn00<0`<300<;2`P32`/800P34a<@20<K6aP80bLW90P3;bl/20<k>cP80d];B0P3Cdm<2
0=7Ad@80c/k>0P38b<P20<30`080^[Zj0P2d];@20:j^[P030:RXZ02TY:@0Y:BT0080Xj>S0P2PX:02
09fMW@80Vi^K0P2JVYX209VIV@80UiNG0P2EUID209:BTP@0T92@0P2?Shl208f=S@80RXZ:00<0R8R8
08J6QP26QXH00P24Q8@408:2PP80Q8B40P26QXH208R8R080RXZ:0P2<S8`208f=S@X0SXj>0`2?Shl2
092@T080TI6A0P2BTY8208n?S`80Rh^;1029RHT408R8R080QXJ60P24Q8@208F5Q@80QhN70P29RHT3
08Z:RP80Rh^;0P2:RXX208R8R080QXJ60P23Ph<207moO`80NWYj0P1fMWH2071`L080Jf][0P1UIFD2
061PH080G5aL0P1GEeL00`1BDU80CTi>04i>CP0204];B`80AdM70P13@d<203lo?`80>c/k0P0j>SX2
03Lg=`@0=SHf0P0j>SX203hn?P80@d=30P18B4P204a<C003055AD@1EEED0EEEE0080FEUI0P1MGEd2
069RHP80IVIV0P1ZJVX206i^KP80LW9b0P1fMWH207YjNP80OWin0P22PX8208J6QP80RHV90P2=SHd0
0`2ATI40UIFE09FEU@0209VIV@80WIfM0P2QXJ420:BTY080Z:RX0P2/[:`E0?ooo`004`3oool20;6a
/@80/k>c0P2d];@20;Jf]P80]kNg0P2i^KT20;^k^`80_Kfm00<0_[jn0<30`030`<000P33`l<20<G5
a@80alO70P3:b/X20<c<c080cLg=0P3>c/h20=3@d080cLg=0P36a/H20;no_`80^KVi0P2c/k<20:b/
[0030:NWY`2UYJD0YJFU0080Xj>S0P2PX:0209fMW@80VYZJ0P2HV9P209JFUP80Ti>C0P2@T90208b<
S080R8R80P25QHD208>3P`80PH610P1oOgl307emO@@0OWin0P1oOgl20861P@80Ph>30P25QHD208R8
R080RHV90P2:RXX608^;R`L0S8b<0P2;Rh/208Z:RP80R8R80P27QhL208B4Q080PH610P1nOWh207al
O080Ng]k0P1lO7`207inOP80P8200P22PX8208F5Q@0308J6QP28R8P0R8R80080R8R80P27QhL208F5
Q@80Ph>30P20P80207alO080N7Qh0P1dM7@206m_K`80JFUY0P1SHf<205eMG@80EeMG0P1CDe<00`1>
CTh0BTY:04Y:BP0204M7A`80@d=30P0n?Sh203/k>`80>3Ph0P0g=cL203@d=080<S8b0P0c<c<203Ph
>080?Cdm0P12@T8204M7A`80Bd];00<0D51@05ADE01DE5@00P1IFET205eMG@80HF5Q0P1UIFD206UY
J@80KVi^0P1bLW8207IfMP80NWYj0P1nOWh208:2PP80QHF50P29RHT208f=S@03096AT@2EUID0UIFE
0080VIVI0P2MWId20:6QX@80Y:BT0P2XZ:P20:b/[1D0oooo000C0?ooo`80/K6a0P2c/k<20;Bd]080
][Jf0P2g]kL20;Vi^@80^k^k0P2m_Kd00`2n_[h0`<300<30`0020<?3``80aLG50P37alL20<[:bP80
c<c<0P3=cLd20<k>cP80d=3@0P3=cLd20<K6aP80_kno0P2i^KT20;>c/`80[:b/00<0YjNW0:FUY@2U
YJD00P2SXj<20:2PX080WIfM0P2JVYX209RHV080UYJF0P2CTi<2092@T080S8b<0P28R8P208F5Q@80
Ph>30P21PH4207moO`<0OGem101nOWh207moO`80PH610P23Ph<208F5Q@80R8R80P29RHT208Z:RPH0
Rh^;1`2<S8`208^;R`80RXZ:0P28R8P208N7Q`80Q8B40P21PH4207inOP80O7al0P1kNg/207alO080
OWin0P20P80208:2PP80QHF500<0QXJ608R8R028R8P00P28R8P208N7Q`80QHF50P23Ph<20820P080
O7al0P1hN7P207AdM080Kfm_0P1YJFT206=SH`80GEeM0P1GEeL205=CD`0304i>CP1:BTX0BTY:0080
AdM70P13@d<203hn?P80>c/k0P0h>3P203Lg=`80=3@d0P0b<S8203<c<`80>3Ph0P0m?Cd20492@P80
AdM70P1;Bd/00`1@D500E5AD05ADE00205UIF@80GEeM0P1QHF4206EUI@80JFUY0P1^KVh2079bLP80
MWIf0P1jNWX207inOP80PX:20P25QHD208V9R@80SHf=00<0TI6A09FEU@2EUID00P2IVIT209fMW@80
XJ6Q0P2TY:@20:RXZ080[:b/5@3oool001<0oooo0P2a/K420;>c/`80];Bd0P2e]KD20;Ng]`80^;Rh
0P2j^[X20;^k^`030;fm_@2o_kl0_kno0080`L710P33`l<20<K6aP80b<S80P3:b/X20<c<c080clo?
0P3>c/h20<W9b@80`/;20P2l_;`20;Fe]@80/;2`0P2[Zj/00`2WYjL0Y:BT0:BTY0020::RXP80WinO
0P2KVi/209RHV080UYJF0P2DU9@209:BTP80Shn?0P2;Rh/208R8R080QHF50P23Ph<208:2PP80PH61
00<0P82007moO`1oOgl00P1nOWh407alO080OWin0P21PH4208>3P`80QHF50P27QhL808V9R@D0R8R8
102:RXX208V9R@80QhN70P24Q8@20820P080OWin0P1lO7`207]kN`80O7al0P1mOGd207moO`80PH61
0P23Ph<208B4Q0<0QXJ60P25QHD208B4Q080Ph>30P20P80207emO@80NGUi0P1eMGD2075aL@80K6a/
0P1VIVH2061PH080Fe]K0P1EEED204m?C`0304Y:BP17AdL0AdM70080@d=30P0o?cl203/k>`80>3Ph
0P0e=CD203@d=080<C4a0P0`<30203<c<`80>3Ph0P0m?Cd20451@@80ATI60P1;Bd/00`1?Cdl0E5AD
05ADE00205QHF080G5aL0P1QHF4206EUI@80JFUY0P1]KFd2075aL@80MGEe0P1iNGT207emO@80PH61
0P25QHD208V9R@80SHf=00<0TI6A09FEU@2EUID00P2IVIT209fMW@80XJ6Q0P2TY:@20:RXZ080[:b/
5@3oool001<0oooo0P2a/K420;:b/P80/k>c0P2e]KD20;Jf]P80]kNg0P2i^KT20;Zj^P030;bl_02m
_Kd0_Kfm0080_kno0P31`L420<C4a080a/K60P39bLT20<_;b`80cLg=0P38b<P20<?3``80_Kfm0P2g
]kL20;6a/@80[Jf]0P2XZ:P00`2UYJD0Xj>S0:>SX`020:2PX080WIfM0P2IVIT209JFUP80U9BD0P2B
TY82096AT@80SXj>0P2<S8`208V9R@80QhN70P26QXH208>3P`80Ogmo00<0Ng]k07QhN01hN7P00P1e
MGD207IfMP80NWYj0P1mOGd20820P080Ph>30P25QHD208J6QP80QhN71028R8P208N7Q`80QXJ60P25
QHD00`23Ph<0PX:208:2PP0208:2PPH0Ph>30P22PX820820P0H0Ogmo0P20P8020861P@80PX:20P23
Ph<308B4Q080Ph>30P22PX820861P@80P8200P1mOGd207YjNP80MWIf0P1cLg<206m_K`80JFUY0P1S
Hf<205eMG@80EeMG0P1@D50204U9B@0304E5A@11@D40@D510080?clo0P0k>c/203Ph>080=CDe0P0d
=3@2038b<P@0;bl_0P0b<S8203Lg=`80?3`l0P11@D4204E5A@80BTY:00<0Cdm?05=CD`1CDe<00P1H
F5P205aLG080H61P0P1UIFD206UYJ@80KFe]0P1aLG4207EeM@80NGUi0P1mOGd20861P@80QHF50P29
RHT208f=S@03096AT@2EUID0UIFE0080VIVI0P2MWId20:2PX080Y:BT0P2XZ:P20:b/[1D0oooo000C
0?ooo`80/K6a0P2b/[820;>c/`80]KFe0P2f][H20;Ng]`80^KVi0P2j^[X00`2l_;`0_Kfm0;fm_@02
0;no_`80`L710P34a<@20<K6aP80bLW90P3;bl/20<g=c@80b<S80P33`l<20;fm_@80]kNg0P2a/K42
0:f][@80Z:RX00<0YJFU0:>SX`2SXj<00P2PX:0209fMW@80VIVI0P2FUYH209BDU080TY:B0P2ATI42
08j>SP80S8b<0P29RHT208N7Q`80QXJ60P23Ph<207moO`0307]kN`1hN7P0N7Qh0080MGEe0P1fMWH2
07YjNP80OGem0P20P80208>3P`80QHF50P26QXH208N7Q`@0R8R80P27QhL208J6QP80QHF500<0Ph>3
08:2PP22PX800P22PX8608>3P`80PX:20P20P80607moO`80P8200P21PH4208:2PP80Ph>30`24Q8@2
08>3P`80PX:20P21PH420820P080OGem0P1jNWX207IfMP80Lg=c0P1_Kfl206UYJ@80Hf=S0P1MGEd2
05MGE`80D51@0P19BDT00`15ADD0@D510451@@0203lo?`80>c/k0P0h>3P203De=@80=3@d0P0b<S84
02l_;`80<S8b0P0g=cL203`l?080@D510P15ADD204Y:BP0304m?C`1CDe<0De=C0080F5QH0P1LG5`2
061PH080IFEU0P1YJFT206e]K@80LG5a0P1eMGD207UiN@80OGem0P21PH4208F5Q@80RHV90P2=SHd0
0`2ATI40UIFE09FEU@0209VIV@80WIfM0P2PX:020:BTY080Z:RX0P2/[:`E0?ooo`004`3oool20;6a
/@80/[:b0P2c/k<20;Bd]080]KFe0P2f][H20;Ng]`80^KVi00<0^[Zj0;bl_02l_;`00P2n_[h20<30
`080`/;20P34a<@20<W9b@80b/[:0P39bLT20<?3``80_Kfm0P2f][H20;:b/P80[Zj^0P2ZZZX20:JV
YP030:>SX`2QXJ40XJ6Q0080WYjN0P2JVYX209JFUP80Ti>C0P2ATI42092@T080Shn?0P2>SXh208b<
S080RXZ:0P28R8P208>3P`80O7al0P1fMWH307=cL`80MGEe0P1gMgL207YjNP80OGem0P20P80208>3
P`80QHF50P26QXH608N7Q`80QXJ60P25QHD208B4Q0030861P@1nOWh0OWin0080Ng]k101iNGT207]k
N`80OWin0P20P8020861P@H0PX:21P23Ph<208:2PP030820P01oOgl0Ogmo0080OWin0P1mOGd207al
O080NWYj0P1gMgL207=cL`80Kfm_0P1[Jf/206EUI@80GemO0P1IFET205ADE080CTi>0P17AdL00`11
@D40?Shn03hn?P0203/k>`80=cLg0P0d=3@2038b<P@0<C4a100];Bd2038b<P80=SHf0P0k>c/20410
@080ADE50P1:BTX00`1>CTh0De=C05=CD`0205MGE`80G5aL0P1PH60206ATI080JFUY0P1]KFd2075a
L@80MGEe0P1iNGT207emO@80PH610P25QHD208V9R@80SHf=00<0TI6A09FEU@2EUID00P2IVIT209fM
W@80X:2P0P2TY:@20:RXZ080[:b/5@3oool001<0oooo0P2a/K420;:b/P80/k>c0P2d];@20;Fe]@80
][Jf0P2g]kL20;Vi^@030;Zj^P2l_;`0_;bl0080_[jn0P30`<020<;2`P80a<C40P39bLT20<[:bP80
bLW90P33`l<20;fm_@80][Jf0P2b/[820:j^[P80ZZZZ0P2VYZH00`2SXj<0XJ6Q0:6QX@0209jNWP80
VYZJ0P2FUYH209>CT`80TI6A0P2@T90208n?S`80SXj>0P2<S8`208Z:RP80R8R80P23Ph<207alO080
MWIf0`1cLg<207EeM@80MgMg0P1jNWX207emO@80P8200P23Ph<208F5Q@80QXJ61P27QhL208J6QP80
QHF50P24Q8@00`21PH40OWin07inOP0207]kN`@0NGUi0P1kNg/207inOP80P8200P21PH4608:2PPH0
Ph>30P22PX800`20P800Ogmo07moO`0207inOP80OGem0P1lO7`207YjNP80MgMg0P1cLg<206m_K`80
Jf][0P1UIFD205mOG`80FEUI0P1DE5@204i>CP80AdM700<0@D5103hn?P0n?Sh00P0k>c/203Lg=`80
=3@d0P0b<S84034a<@@0;Bd]0P0b<S8203Hf=P80>c/k0P10@40204E5A@80BTY:00<0CTi>05=CD`1C
De<00P1GEeL205aLG080H61P0P1TI6@206UYJ@80KFe]0P1aLG4207EeM@80NGUi0P1mOGd20861P@80
QHF50P29RHT208f=S@03096AT@2EUID0UIFE0080VIVI0P2MWId20:2PX080Y:BT0P2XZ:P20:b/[1D0
oooo000C0?ooo`80/K6a102b/[820;>c/`80];Bd0P2e]KD20;Jf]P80]kNg00<0^KVi0;Zj^P2j^[X0
0P2k^k/20;fm_@80_kno0P32`/820<K6aP80b<S80P37alL20;jn_P80]kNg0P2a/K420:f][@80ZJVY
0P2VYZH20:>SX`030:2PX02MWId0WIfM0080VYZJ0P2GUiL209>CT`80T92@0P2>SXh208^;R`80R8R8
0P27QhL208J6QP80Q8B40P1oOgl207YjNPD0MWIf0P1gMgL207QhN080NWYj0P1mOGd207moO`80PH61
0P23Ph<208F5Q@X0QXJ60P25QHD208>3P`030861P@1oOgl0Ogmo0080O7al0P1jNWX207MgM`80MWIf
0P1eMGD207IfMP80N7Qh0P1kNg/207emO@@0OWin0P1mOGd907alO080Ng]k0P1iNGT207IfMP80Lg=c
0P1`L70206e]K@80J6QX0P1RHV8205iNGP80F5QH0P1BDU8204Y:BP80@T9200<0?Cdm03Xj>P0j>SX0
0P0f=SH203<c<`80<30`0P0_;bl202h^;P80;2`/0P0Y:BT202`/;080<C4a0P0f=SH203/k>`80@410
0P14A4@204U9B@0304i>CP1BDU80DU9B0080EeMG0P1KFe/2061PH080I6AT0P1XJ6P206e]K@80LG5a
0P1eMGD207UiN@80OGem0P21PH4208F5Q@80RHV90P2=SHd00`2ATI40UIFE09FEU@0209VIV@80WIfM
0P2PX:020:BTY080Z:RX0P2/[:`E0?ooo`004`3oool20;6a/@@0/[:b0P2c/k<20;Bd]080]KFe0P2f
][H20;Ng]`030;Vi^@2j^[X0^[Zj0080^k^k0P2m_Kd20;no_`80`/;20P36a/H20<S8b080alO70P2n
_[h20;Ng]`80/K6a0P2][Jd20:VYZ@80YZJV0P2SXj<00`2PX:00WIfM09fMW@0209ZJVP80UiNG0P2C
Ti<2092@T080SXj>0P2;Rh/208R8R080QhN70P26QXH208B4Q080Ogmo0P1jNWX507IfMP80MgMg0P1h
N7P207YjNP80OGem0P1oOgl20861P@80Ph>30P25QHD:08J6QP80QHF50P23Ph<00`21PH40Ogmo07mo
O`0207alO080NWYj0P1gMgL207IfMP80MGEe0P1fMWH207QhN080Ng]k0P1mOGd407inOP80OGem2@1l
O7`207]kN`80NGUi0P1fMWH207=cL`80L71`0P1]KFd206QXJ080HV9R0P1NGUh205QHF080DU9B0P1:
BTX20492@P0303dm?@0j>SX0>SXj0080=SHf0P0c<c<2030`<080;bl_0P0^;Rh202`/;080:BTY0P0/
;2`2034a<@80=SHf0P0k>c/20410@080A4A40P19BDT00`1>CTh0DU9B059BDP0205MGE`80Fe]K0P1P
H60206ATI080J6QX0P1]KFd2075aL@80MGEe0P1iNGT207emO@80PH610P25QHD208V9R@80SHf=00<0
TI6A09FEU@2EUID00P2IVIT209fMW@80X:2P0P2TY:@20:RXZ080[:b/5@3oool001<0oooo102a/K42
0;:b/P@0/k>c0P2d];@20;Fe]@80][Jf00<0]kNg0;Rh^02h^;P00P2i^KT20;Zj^P80_;bl0P2n_[h2
0<30`080`L710P2n_[h20;Rh^080/K6a0P2][Jd20:VYZ@80YJFU0P2RXZ8209nOW`0309bLW02JVYX0
VYZJ0080UYJF0P2CTi<2092@T080SHf=0P2<S8`208Z:RP80QhN70P24Q8@20820P080OGem0P1kNg/2
07YjNP@0NGUi0`1jNWX207alO080OGem0P1oOgl20861P@80Ph>30P24Q8@408J6QPP0QhN70P26QXH2
08B4Q00308>3P`20P800P8200080OWin0P1lO7`207YjNPH0NGUi0P1hN7P207MgM`80MWIf0P1gMgL2
07QhN080NGUi2@1jNWX207UiN@80MgMg0P1dM7@2071`L080KFe]0P1YJFT206EUI@80H61P0P1KFe/2
05ADE080C4a<0P14A4@203`l?00303Ti>@0e=CD0=CDe0080<C4a0P0_;bl202d];@80:b/[0P0Z:RX2
02LW9`809RHV0P0[:b/2030`<080=CDe0P0j>SX203lo?`80A4A40P19BDT00`1=CDd0DU9B059BDP02
05MGE`80Fe]K0P1OGel206ATI080J6QX0P1/K6`2075aL@80MGEe0P1iNGT207emO@80PH610P25QHD2
08V9R@80SHf=00<0TI6A09FEU@2EUID00P2IVIT209fMW@80X:2P0P2TY:@20:RXZ080[:b/5@3oool0
01<0oooo102a/K420;:b/P@0/k>c0P2d];@20;Fe]@80][Jf00<0]kNg0;Rh^02h^;P00P2i^KT20;Zj
^P80_;bl0P2n_[h20<30`080`L710P2n_[h20;Rh^080/K6a0P2][Jd20:VYZ@80YJFU0P2RXZ8209nO
W`0309bLW02JVYX0VYZJ0080UYJF0P2CTi<2092@T080SHf=0P2<S8`208Z:RP80QhN70P24Q8@20820
P080OGem0P1kNg/207YjNP@0NGUi0`1jNWX207alO080OGem0P1oOgl20861P@80Ph>30P24Q8@408J6
QPP0QhN70P26QXH208B4Q00308>3P`20P800P8200080OWin0P1lO7`207YjNPH0NGUi0P1hN7P207Mg
M`80MWIf0P1gMgL207QhN080NGUi2@1jNWX207UiN@80MgMg0P1dM7@2071`L080KFe]0P1YJFT206EU
I@80H61P0P1KFe/205ADE080C4a<0P14A4@203`l?00303Ti>@0e=CD0=CDe0080<C4a0P0_;bl202d]
;@80:b/[0P0Z:RX202LW9`809RHV0P0[:b/2030`<080=CDe0P0j>SX203lo?`80A4A40P19BDT00`1=
CDd0DU9B059BDP0205MGE`80Fe]K0P1OGel206ATI080J6QX0P1/K6`2075aL@80MGEe0P1iNGT207em
O@80PH610P25QHD208V9R@80SHf=00<0TI6A09FEU@2EUID00P2IVIT209fMW@80X:2P0P2TY:@20:RX
Z080[:b/5@3oool001<0oooo0P2`/;040;6a/@@0/[:b0P2c/k<40;Bd]0<0]KFe0P2f][H20;Ng]`80
^KVi0P2j^[X20;bl_080_Kfm0P2i^KT20;>c/`80[Jf]0P2ZZZX20:JVYP80XZ:R0P2OWil209bLW003
09VIV@2GUiL0UiNG0080Ti>C0P2ATI4208f=S@80Rh^;0P2:RXX208R8R080QXJ60P24Q8@20861P@80
Ogmo0P1mOGd407alO0D0OGem0P1oOgl20820P080PH610P23Ph<208B4Q080QHF51027QhL608R8R080
QhN70P26QXH208F5Q@0308B4Q022PX80PX:20080PH610P1oOgl207emO@@0O7al101kNg/?07YjNP80
NGUi0P1hN7P207IfMP80M7Ad0P1bLW8206m_K`80Jf][0P1VIVH2065QH@80G5aL0P1FEUH204m?C`80
AdM70P10@40203Ph>00303@d=00a<C40<C4a0080;Bd]0P0/;2`202XZ:P80:2PX0P0W9bL202<S8`80
92@T0P0Z:RX202l_;`80=3@d0P0i>CT203lo?`80@d=30P18B4P00`1=CDd0DU9B059BDP0205IFEP80
Fe]K0P1OGel206ATI080J6QX0P1/K6`2071`L080MGEe0P1iNGT207emO@80PH610P25QHD208V9R@80
SHf=00<0TI6A09FEU@2EUID00P2IVIT209fMW@80X:2P0P2TY:@20:RXZ080[:b/5@3oool001<0oooo
0P2`/;040;6a/@@0/[:b0P2c/k<40;Bd]0<0]KFe0P2f][H20;Ng]`80^KVi0P2j^[X20;bl_080_Kfm
0P2i^KT20;>c/`80[Jf]0P2ZZZX20:JVYP80XZ:R0P2OWil209bLW00309VIV@2GUiL0UiNG0080Ti>C
0P2ATI4208f=S@80Rh^;0P2:RXX208R8R080QXJ60P24Q8@20861P@80Ogmo0P1mOGd407alO0D0OGem
0P1oOgl20820P080PH610P23Ph<208B4Q080QHF51027QhL608R8R080QhN70P26QXH208F5Q@0308B4
Q022PX80PX:20080PH610P1oOgl207emO@@0O7al101kNg/?07YjNP80NGUi0P1hN7P207IfMP80M7Ad
0P1bLW8206m_K`80Jf][0P1VIVH2065QH@80G5aL0P1FEUH204m?C`80AdM70P10@40203Ph>00303@d
=00a<C40<C4a0080;Bd]0P0/;2`202XZ:P80:2PX0P0W9bL202<S8`8092@T0P0Z:RX202l_;`80=3@d
0P0i>CT203lo?`80@d=30P18B4P00`1=CDd0DU9B059BDP0205IFEP80Fe]K0P1OGel206ATI080J6QX
0P1/K6`2071`L080MGEe0P1iNGT207emO@80PH610P25QHD208V9R@80SHf=00<0TI6A09FEU@2EUID0
0P2IVIT209fMW@80X:2P0P2TY:@20:RXZ080[:b/5@3oool001<0oooo102`/;060;6a/@H0/[:b0`2c
/k<40;Bd]080]KFe1P2f][H20;:b/P80[Zj^0P2[Zj/20:RXZ080Xj>S0P2OWil209bLW080VIVI00<0
UiNG09BDU02DU9@00P2@T90208j>SP80Rh^;0P29RHT208R8R080QhN70P25QHD208B4Q080PX:20P21
PH420820P0L0Ogmo0P20P8020861P@80PX:20P23Ph<208F5Q@80QXJ60P27QhL408R8R0P0RHV90P28
R8P208N7Q`0308J6QP25QHD0QHF50080Ph>30P22PX820820P080Ogmo101nOWh207emO@@0O7al101k
Ng/407YjNP<0NGUi0P1hN7P207IfMP80MGEe0P1cLg<206m_K`80KFe]0P1YJFT206EUI@80HF5Q0P1I
FET2059BDP80C4a<0P15ADD203dm?@80=CDe00<0<C4a02d];@0];Bd00P0Y:BT202PX:0809RHV0P0T
92@202<S8`80820P0P0S8b<202TY:@80;Rh^0P0d=3@203Ti>@80?Shn0P13@d<204Q8B00304e=C@1B
DU80DU9B0080EUIF0P1KFe/205mOG`80I6AT0P1XJ6P206a/K080L71`0P1eMGD207UiN@80OGem0P21
PH4208F5Q@80RHV90P2=SHd00`2ATI40UIFE09FEU@0209VIV@80WIfM0P2PX:020:BTY080Z:RX0P2/
[:`E0?ooo`004`3oool40;2`/0H0/K6a1P2b/[830;>c/`@0];Bd0P2e]KD60;Jf]P80/[:b0P2^[Zh2
0:^[Z`80Z:RX0P2SXj<209nOW`80W9bL0P2IVIT00`2GUiL0U9BD09BDU002092@T080SXj>0P2;Rh/2
08V9R@80R8R80P27QhL208F5Q@80Q8B40P22PX820861P@80P8201`1oOgl20820P080PH610P22PX82
08>3P`80QHF50P26QXH208N7Q`@0R8R82029RHT208R8R080QhN700<0QXJ608F5Q@25QHD00P23Ph<2
08:2PP80P8200P1oOgl407inOP80OGem101lO7`407]kN`@0NWYj0`1iNGT207QhN080MWIf0P1eMGD2
07=cL`80Kfm_0P1]KFd206UYJ@80IFEU0P1QHF4205UIF@80DU9B0P1<C4`204E5A@80?Cdm0P0e=CD0
0`0a<C40;Bd]02d];@0202TY:@80:2PX0P0V9RH202@T90808b<S0P0P820202<S8`80:BTY0P0^;Rh2
03@d=080>CTi0P0n?Sh204=3@`80B4Q800<0CDe=059BDP1BDU800P1FEUH205]KF`80GemO0P1TI6@2
06QXJ080K6a/0P1`L70207EeM@80NGUi0P1mOGd20861P@80QHF50P29RHT208f=S@03096AT@2EUID0
UIFE0080VIVI0P2MWId20:2PX080Y:BT0P2XZ:P20:b/[1D0oooo000C0?ooo`X0/;2`5@2a/K420:j^
[P80Zj^[0P2XZ:P20:FUY@80XJ6Q0P2MWId209ZJVP80UiNG00<0Ti>C092@T02@T9000P2<S8`208Z:
RP80R8R81027QhL208J6QP80Q8B40P23Ph<408:2PPP0PH6100<0PX:208>3P`23Ph<00P24Q8@208F5
Q@80QXJ60P27QhL208R8R0@0RHV90P2:RXX608^;R`80RXZ:1029RHT00`27QhL0QXJ608J6QP0208F5
Q@80Q8B40P23Ph<208:2PP80PH610P20P80207moO`80OWin0P1mOGd407alO080Ng]k0P1jNWX307Ui
N@80N7Qh0P1fMWH207AdM080LG5a0P1^KVh206][J`80J6QX0P1SHf<205eMG@80EUIF0P1@D50204U9
B@80@D510P0i>CT2038b<P0302h^;P0Y:BT0:BTY00809RHV0P0T92@2028R8P80820P0P0N7Qh201dM
7@808R8R0P0X:2P202h^;P80<c<c0P0i>CT203hn?P80@d=30P18B4P00`1=CDd0DE5A055AD@0205IF
EP80Fe]K0P1OGel206ATI080J6QX0P1/K6`2071`L080MGEe0P1iNGT207emO@80PH610P25QHD208V9
R@80SHf=00<0TI6A09FEU@2EUID00P2IVIT209fMW@80X:2P0P2TY:@20:RXZ080[:b/5@3oool001<0
oooo2P2`/;0E0;6a/@80[Zj^0P2[Zj/20:RXZ080YJFU0P2QXJ4209fMW@80VYZJ0P2GUiL00`2CTi<0
T92@092@T00208b<S080RXZ:0P28R8P408N7Q`80QXJ60P24Q8@208>3P`@0PX:22021PH400`22PX80
Ph>308>3P`0208B4Q080QHF50P26QXH208N7Q`80R8R81029RHT208Z:RPH0Rh^;0P2:RXX408V9R@03
08N7Q`26QXH0QXJ60080QHF50P24Q8@208>3P`80PX:20P21PH420820P080Ogmo0P1nOWh207emO@@0
O7al0P1kNg/207YjNP<0NGUi0P1hN7P207IfMP80M7Ad0P1aLG4206i^KP80Jf][0P1XJ6P206=SH`80
GEeM0P1FEUH2051@D080BDU90P11@D4203Ti>@80<S8b00<0;Rh^02TY:@0Y:BT00P0V9RH202@T9080
8R8R0P0P820201hN7P807AdM0P0R8R8202PX:080;Rh^0P0c<c<203Ti>@80?Shn0P13@d<204Q8B003
04e=C@1ADE40DE5A0080EUIF0P1KFe/205mOG`80I6AT0P1XJ6P206a/K080L71`0P1eMGD207UiN@80
OGem0P21PH4208F5Q@80RHV90P2=SHd00`2ATI40UIFE09FEU@0209VIV@80WIfM0P2PX:020:BTY080
Z:RX0P2/[:`E0?ooo`004`3oool60;2`/0d0[jn_1P2^[Zh60:f][@80ZJVY0P2VYZH20:>SX`80WinO
0P2MWId209ZJVP80UiNG0P2CTi<00`2@T900SHf=08f=S@0208Z:RP80QhN70P26QXH408F5Q@@0Q8B4
1P23Ph<408:2PP@0Ph>300<0Q8B408F5Q@25QHD00P26QXH208N7Q`80R8R80P29RHT208Z:RP@0Rh^;
202<S8`408^;R`80RXZ:00<0RHV908R8R028R8P00P27QhL208J6QP80QHF50P23Ph<408:2PP80PH61
0P20P80207moO`80OWin0P1mOGd207]kN`80NWYj0P1iNGT00`1hN7P0MWIf07IfMP0207EeM@80LW9b
0P1_Kfl206a/K080JFUY0P1UIFD2061PH080FUYJ0P1DE5@204i>CP80ADE50P0m?Cd203De=@80;Rh^
00<0:b/[02PX:00X:2P00P0T92@2020P80807AdM0P0K6a/201TI6@8071`L0P0R8R8202PX:080;Rh^
0P0c<c<203Ti>@80?Shn0P13@d<204Q8B00304e=C@1ADE40DE5A0080EUIF0P1KFe/205mOG`80I6AT
0P1XJ6P206a/K080L71`0P1eMGD207UiN@80OGem0P21PH4208F5Q@80RHV90P2=SHd00`2ATI40UIFE
09FEU@0209VIV@80WIfM0P2PX:020:BTY080Z:RX0P2/[:`E0?ooo`004`3oool60;2`/0d0[jn_1P2^
[Zh60:f][@80ZJVY0P2VYZH20:>SX`80WinO0P2MWId209ZJVP80UiNG0P2CTi<00`2@T900SHf=08f=
S@0208Z:RP80QhN70P26QXH408F5Q@@0Q8B41P23Ph<408:2PP@0Ph>300<0Q8B408F5Q@25QHD00P26
QXH208N7Q`80R8R80P29RHT208Z:RP@0Rh^;202<S8`408^;R`80RXZ:00<0RHV908R8R028R8P00P27
QhL208J6QP80QHF50P23Ph<408:2PP80PH610P20P80207moO`80OWin0P1mOGd207]kN`80NWYj0P1i
NGT00`1hN7P0MWIf07IfMP0207EeM@80LW9b0P1_Kfl206a/K080JFUY0P1UIFD2061PH080FUYJ0P1D
E5@204i>CP80ADE50P0m?Cd203De=@80;Rh^00<0:b/[02PX:00X:2P00P0T92@2020P80807AdM0P0K
6a/201TI6@8071`L0P0R8R8202PX:080;Rh^0P0c<c<203Ti>@80?Shn0P13@d<204Q8B00304e=C@1A
DE40DE5A0080EUIF0P1KFe/205mOG`80I6AT0P1XJ6P206a/K080L71`0P1eMGD207UiN@80OGem0P21
PH4208F5Q@80RHV90P2=SHd00`2ATI40UIFE09FEU@0209VIV@80WIfM0P2PX:020:BTY080Z:RX0P2/
[:`E0?ooo`004`3oool20;2`/0H0[jn_1P2^[Zh30:f][@@0[:b/0P2[Zj/40:ZZZP80ZJVY0P2XZ:P2
0:BTY080XJ6Q0P2NWYh209bLW080VYZJ0P2GUiL209BDU080TI6A00<0SHf=08Z:RP2:RXX00P27QhL2
08F5Q@@0Q8B42023Ph<808B4Q0@0QHF500<0QXJ608N7Q`27QhL00P28R8P208V9R@80RXZ:0P2;Rh/4
08b<S080SHf=1P2>SXh408f=S@@0S8b<00<0Rh^;08Z:RP2:RXX00P29RHT208R8R080QXJ60P25QHD2
08B4Q080Ph>30P21PH420820P080Ogmo0P1nOWh207emO@80O7al0P1jNWX207UiN@0307QhN01fMWH0
MWIf0080Lg=c0P1aLG4206i^KP80Jf][0P1WIfL206=SH`80GEeM0P1GEeL2055AD@80BDU90P11@D42
03Ti>@80<30`0P0Z:RX00`0X:2P092@T02@T9002020P808071`L0P0H61P201HF5P805ADE0P0K6a/2
028R8P80:2PX0P0^;Rh203<c<`80>CTi0P0n?Sh204=3@`80B4Q800<0CDe=055AD@1ADE400P1FEUH2
05]KF`80GemO0P1TI6@206QXJ080K6a/0P1aLG4207EeM@80NGUi0P1mOGd20861P@80QHF50P29RHT2
08f=S@03096AT@2EUID0UIFE0080VIVI0P2MWId20:6QX@80Y:BT0P2XZ:P20:b/[1D0oooo000C0?oo
o`80/;2`1P2_[jl60:j^[P<0[Jf]102/[:`20:^[Z`@0ZZZZ0P2YZJT20:RXZ080Y:BT0P2QXJ4209jN
WP80W9bL0P2JVYX209NGU`80U9BD0P2ATI400`2=SHd0RXZ:08Z:RP0208N7Q`80QHF51024Q8@808>3
P`P0Q8B41025QHD00`26QXH0QhN708N7Q`0208R8R080RHV90P2:RXX208^;R`@0S8b<0P2=SHd608j>
SP@0SHf=102<S8`00`2;Rh/0RXZ:08Z:RP0208V9R@80R8R80P26QXH208F5Q@80Q8B40P23Ph<20861
P@80P8200P1oOgl207inOP80OGem0P1lO7`207YjNP80NGUi00<0N7Qh07IfMP1fMWH00P1cLg<2075a
L@80KVi^0P1[Jf/206MWI`80Hf=S0P1MGEd205MGE`80DE5A0P19BDT20451@@80>CTi0P0`<30202XZ
:P0302PX:00T92@092@T0080820P0P0L71`201PH60805QHF0P0E5AD201/K6`808R8R0P0X:2P202h^
;P80<c<c0P0i>CT203hn?P80@d=30P18B4P00`1=CDd0DE5A055AD@0205IFEP80Fe]K0P1OGel206AT
I080J6QX0P1/K6`2075aL@80MGEe0P1iNGT207emO@80PH610P25QHD208V9R@80SHf=00<0TI6A09FE
U@2EUID00P2IVIT209fMW@80XJ6Q0P2TY:@20:RXZ080[:b/5@3oool001<0oooo1P2_[jl20:j^[P@0
[Jf]102/[:`00`2[Zj/0ZZZZ0:ZZZP020:VYZ@80Z:RX0P2WYjL20:JVYP@0Y:BT0P2OWil209bLW080
Vi^K0P2IVIT209NGU`80U9BD0P2ATI4208j>SP0308b<S029RHT0RHV90080QHF50P23Ph<808:2PP@0
Ph>31024Q8@408F5Q@80QXJ60P27QhL308R8R080RXZ:0P2;Rh/208b<S080SHf=102>SXh<08n?S`80
SXj>0P2=SHd308b<S080Rh^;0P2:RXX208R8R080QhN70P26QXH208F5Q@80Ph>30P22PX820861P@80
P8200P1nOWh207alO080NWYj0P1iNGT00`1gMgL0M7Ad07AdM002079bLP80L71`0P1]KFd206UYJ@80
IFEU0P1QHF4205YJFP80E5AD0P1>CTh204E5A@80?3`l0P0c<c<202/[:`809RHV00<08b<S024Q8@0Q
8B400P0L71`201TI6@805aLG0P0D51@201DE5@8071`L0P0R8R8202PX:080;Rh^0P0c<c<203Ti>@80
?Shn0P13@d<204Q8B00304e=C@1BDU80DU9B0080EUIF0P1KFe/205mOG`80I6AT0P1XJ6P206e]K@80
LG5a0P1eMGD207UiN@80OGem0P21PH4208F5Q@80RHV90P2=SHd00`2ATI40UIFE09FEU@0209VIV@80
WIfM0P2QXJ420:BTY080Z:RX0P2/[:`E0?ooo`004`3oool60:n_[`80[Zj^102][Jd40:b/[0030:^[
Z`2ZZZX0ZZZZ0080ZJVY0P2XZ:P20:NWY`80YZJV102TY:@209nOW`80W9bL0P2KVi/209VIV@80UiNG
0P2DU9@2096AT@80SXj>00<0S8b<08V9R@29RHT00P25QHD208>3P`P0PX:21023Ph<408B4Q0@0QHF5
0P26QXH208N7Q`<0R8R80P2:RXX208^;R`80S8b<0P2=SHd408j>SP`0Shn?0P2>SXh208f=S@<0S8b<
0P2;Rh/208Z:RP80R8R80P27QhL208J6QP80QHF50P23Ph<208:2PP80PH610P20P80207inOP80O7al
0P1jNWX207UiN@0307MgM`1dM7@0M7Ad0080LW9b0P1`L70206e]K@80JFUY0P1UIFD2065QH@80FUYJ
0P1DE5@204i>CP80ADE50P0l?3`203<c<`80:b/[0P0V9RH00`0S8b<08B4Q024Q8@0201`L70806ATI
0P0G5aL201@D50805ADE0P0L71`2028R8P80:2PX0P0^;Rh203<c<`80>CTi0P0n?Sh204=3@`80B4Q8
00<0CDe=059BDP1BDU800P1FEUH205]KF`80GemO0P1TI6@206QXJ080KFe]0P1aLG4207EeM@80NGUi
0P1mOGd20861P@80QHF50P29RHT208f=S@03096AT@2EUID0UIFE0080VIVI0P2MWId20:6QX@80Y:BT
0P2XZ:P20:b/[1D0oooo000C0?ooo`@0[jn_0P2^[Zh40:f][@80[:b/0P2[Zj/20:ZZZP030:VYZ@2X
Z:P0Z:RX0080YjNW0P2UYJD20:BTY080XZ:R0P2PX:0209bLW080VIVI0P2JVYX209RHV080UYJF0P2D
U9@2096AT@80SXj>0P2<S8`00`28R8P0QHF508F5Q@0208>3P`80PH611020P8040861P@80PX:20P23
Ph<208B4Q080QHF50P26QXH208N7Q`80R8R80P29RHT00`2:RXX0Rh^;08^;R`0208b<S080SHf=0P2>
SXh408n?S`80T92@2P2ATI44092@T0<0Shn?0P2>SXh208f=S@80Rh^;0P2:RXX208V9R@80QhN70P26
QXH208B4Q080Ph>30P22PX820820P080OWin0P1lO7`207YjNP80N7Qh00<0MWIf07=cL`1cLg<00P1a
LG4206i^KP80Jf][0P1VIVH2069RHP80GEeM0P1GEeL2055AD@80BDU90P10@40203Lg=`80;bl_0P0V
9RH2028R8P0301lO7`0L71`071`L008061PH0P0E5AD201@D50804a<C0P0G5aL201dM7@808b<S0P0Y
:BT202h^;P80=3@d0P0i>CT203hn?P80@d=30P18B4P00`1=CDd0DU9B059BDP0205MGE`80Fe]K0P1P
H60206ATI080J6QX0P1]KFd2075aL@80MGEe0P1iNGT207emO@80PH610P25QHD208V9R@80SHf=00<0
TI6A09FEU@2EUID00P2IVIT209fMW@80XJ6Q0P2TY:@20:RXZ080[:b/5@3oool001<0oooo102_[jl2
0:j^[P@0[Jf]0P2/[:`20:^[Z`80ZZZZ00<0ZJVY0:RXZ02XZ:P00P2WYjL20:FUY@80Y:BT0P2RXZ82
0:2PX080W9bL0P2IVIT209ZJVP80V9RH0P2FUYH209BDU080TI6A0P2>SXh208b<S00308R8R025QHD0
QHF50080Ph>30P21PH440820P0@0PH610P22PX8208>3P`80Q8B40P25QHD208J6QP80QhN70P28R8P2
08V9R@0308Z:RP2;Rh/0Rh^;0080S8b<0P2=SHd208j>SP@0Shn?0P2@T90:096AT@@0T92@0`2?Shl2
08j>SP80SHf=0P2;Rh/208Z:RP80RHV90P27QhL208J6QP80Q8B40P23Ph<208:2PP80P8200P1nOWh2
07alO080NWYj0P1hN7P00`1fMWH0Lg=c07=cL`02075aL@80KVi^0P1[Jf/206IVIP80HV9R0P1MGEd2
05MGE`80DE5A0P19BDT20410@080=cLg0P0_;bl202HV9P808R8R00<07alO01`L700L71`00P0H61P2
01DE5@8051@D0P0C4a<201LG5`807AdM0P0S8b<202TY:@80;Rh^0P0d=3@203Ti>@80?Shn0P13@d<2
04Q8B00304e=C@1BDU80DU9B0080EeMG0P1KFe/2061PH080I6AT0P1XJ6P206e]K@80LG5a0P1eMGD2
07UiN@80OGem0P21PH4208F5Q@80RHV90P2=SHd00`2ATI40UIFE09FEU@0209VIV@80WIfM0P2QXJ42
0:BTY080Z:RX0P2/[:`E0?ooo`004`3oool20:n_[`80[Zj^0P2][Jd40:b/[080Zj^[0P2ZZZX20:VY
Z@030:NWY`2VYZH0YZJV0080YJFU0P2SXj<20:6QX@80WinO0P2LW9`209VIV@80V9RH0P2FUYH209>C
T`80TY:B0P2?Shl208f=S@80Rh^;0P29RHT00`26QXH0Ph>308>3P`020861P@80P820101oOgl20820
P080PH610P22PX8208B4Q080QHF50P26QXH208N7Q`80R8R80P2:RXX308^;R`80S8b<0P2=SHd208j>
SP80Shn?0P2@T902096AT@@0TY:B202CTi<409:BTP<0TI6A0P2@T90208j>SP80SHf=0P2<S8`208Z:
RP80RHV90P27QhL208F5Q@80Q8B40P22PX820861P@80Ogmo0P1mOGd207YjNP80N7Qh00<0MGEe07=c
L`1cLg<00P1`L70206a/K080J6QX0P1TI6@2061PH080Fe]K0P1DE5@204e=C@80A4A40P0k>c/203<c
<`80:b/[0P0R8R8201hN7P0301/K6`0H61P061PH008051@D0P0B4Q82014A4@804a<C0P0H61P201hN
7P808b<S0P0Y:BT202l_;`80=3@d0P0i>CT203lo?`80A4A40P19BDT00`1>CTh0DU9B059BDP0205MG
E`80G5aL0P1PH60206ATI080JFUY0P1]KFd2075aL@80MGEe0P1jNWX207inOP80PX:20P26QXH208Z:
RP80SHf=00<0TI6A09FEU@2EUID00P2IVIT209fMW@80XJ6Q0P2UYJD20:RXZ080[:b/5@3oool001<0
oooo0P2_[jl20:j^[P80[Jf]102/[:`20:^[Z`80ZZZZ0P2YZJT00`2WYjL0YZJV0:JVYP020:FUY@80
Xj>S0P2QXJ4209nOW`80W9bL0P2IVIT209RHV080UYJF0P2CTi<209:BTP80Shn?0P2=SHd208^;R`80
RHV900<0QXJ608>3P`23Ph<00P21PH420820P0@0Ogmo0P20P8020861P@80PX:20P24Q8@208F5Q@80
QXJ60P27QhL208R8R080RXZ:0`2;Rh/208b<S080SHf=0P2>SXh208n?S`80T92@0P2ATI4409:BTPP0
Ti>C102BTY83096AT@80T92@0P2>SXh208f=S@80S8b<0P2:RXX208V9R@80QhN70P25QHD208B4Q080
PX:20P21PH4207moO`80OGem0P1jNWX207QhN00307EeM@1cLg<0Lg=c0080L71`0P1/K6`206QXJ080
I6AT0P1PH60205]KF`80E5AD0P1=CDd204A4A080>c/k0P0c<c<202/[:`808R8R0P0N7Qh00`0K6a/0
61PH01PH600201@D50804Q8B0P0A4A4201<C4`8061PH0P0N7Qh202<S8`80:BTY0P0_;bl203@d=080
>CTi0P0o?cl204A4A080BDU900<0CTi>059BDP1BDU800P1GEeL205aLG080H61P0P1TI6@206UYJ@80
KFe]0P1aLG4207EeM@80NWYj0P1nOWh208:2PP80QXJ60P2:RXX208f=S@03096AT@2EUID0UIFE0080
VIVI0P2MWId20:6QX@80YJFU0P2XZ:P20:b/[1D0oooo000C0?ooo`80[jn_0P2^[Zh20:f][@80[:b/
0P2[Zj/20:ZZZP80Z:RX0P2WYjL00`2VYZH0Y:BT0:BTY0020::RXP80XJ6Q0P2NWYh209bLW080VIVI
0P2FUYH209>CT`80Shn?0P2>SXh208b<S080RXZ:0P29RHT208N7Q`80QHF500<0Q8B408:2PP22PX80
0P20P80207moO`@0OWin0P1oOgl20861P@80PX:20P24Q8@208F5Q@80QhN70P28R8P208V9R@80Rh^;
0P2<S8`00`2=SHd0SXj>08j>SP0208n?S`80TI6A102BTY8209>CT`@0U9BD202EUID409BDU0<0Ti>C
0P2ATI42092@T080Shn?0P2>SXh208b<S080Rh^;0P29RHT208N7Q`80QXJ60P23Ph<20861P@80Ogmo
0P1mOGd207YjNP80N7Qh00<0MGEe079bLP1bLW800P1^KVh206][J`80IVIV0P1QHF4205aLG080EUIF
0P1?Cdl204M7A`80?Shn0P0f=SH202d];@809RHV0P0N7Qh201XJ6P0301LG5`0C4a<04a<C0080410@
100?3`l201<C4`806ATI0P0O7al202@T9080:RXZ0P0_;bl203De=@80>SXj0P0o?cl204A4A080BDU9
00<0CTi>05=CD`1CDe<00P1GEeL205aLG080H61P0P1UIFD206UYJ@80KFe]0P1bLW8207IfMP80NWYj
0P1nOWh208:2PP80QXJ60P2:RXX208j>SP0309:BTP2EUID0UIFE0080VIVI0P2MWId20:6QX@80YJFU
0P2XZ:P20:b/[1D0oooo000C0?ooo`80[jn_0P2^[Zh20:f][@80[:b/0P2[Zj/20:ZZZP80Z:RX0P2W
YjL00`2VYZH0Y:BT0:BTY0020::RXP80XJ6Q0P2NWYh209bLW080VIVI0P2FUYH209>CT`80Shn?0P2>
SXh208b<S080RXZ:0P29RHT208N7Q`80QHF500<0Q8B408:2PP22PX800P20P80207moO`@0OWin0P1o
Ogl20861P@80PX:20P24Q8@208F5Q@80QhN70P28R8P208V9R@80Rh^;0P2<S8`00`2=SHd0SXj>08j>
SP0208n?S`80TI6A102BTY8209>CT`@0U9BD202EUID409BDU0<0Ti>C0P2ATI42092@T080Shn?0P2>
SXh208b<S080Rh^;0P29RHT208N7Q`80QXJ60P23Ph<20861P@80Ogmo0P1mOGd207YjNP80N7Qh00<0
MGEe079bLP1bLW800P1^KVh206][J`80IVIV0P1QHF4205aLG080EUIF0P1?Cdl204M7A`80?Shn0P0f
=SH202d];@809RHV0P0N7Qh201XJ6P0301LG5`0C4a<04a<C0080410@100?3`l201<C4`806ATI0P0O
7al202@T9080:RXZ0P0_;bl203De=@80>SXj0P0o?cl204A4A080BDU900<0CTi>05=CD`1CDe<00P1G
EeL205aLG080H61P0P1UIFD206UYJ@80KFe]0P1bLW8207IfMP80NWYj0P1nOWh208:2PP80QXJ60P2:
RXX208j>SP0309:BTP2EUID0UIFE0080VIVI0P2MWId20:6QX@80YJFU0P2XZ:P20:b/[1D0oooo000C
0?ooo`80[jn_0P2^[Zh20:f][@80Zj^[0P2ZZZX20:VYZ@80YjNW0P2VYZH00`2TY:@0Xj>S0:>SX`02
0:6QX@80WYjN0P2LW9`209VIV@80UYJF0P2CTi<208j>SP80S8b<0P29RHT208N7Q`80QXJ60P24Q8@2
08>3P`80PX:200<0PH6107moO`1oOgl00P1nOWh407emO@80OWin0P1oOgl20861P@80Ph>30P25QHD2
08J6QP80R8R80P29RHT208^;R`80S8b<0P2>SXh00`2?Shl0T92@092@T00209:BTP80Ti>C0P2DU9@4
09FEU@80UYJF302GUiL409JFUP0309FEU@2DU9@0U9BD0080Ti>C0P2ATI42092@T080SXj>0P2<S8`2
08^;R`80RHV90P27QhL208B4Q080PX:20P1oOgl207emO@80NWYj0P1gMgL00`1dM7@0LG5a075aL@02
06e]K@80JFUY0P1TI6@205mOG`80FEUI0P1BDU8204Y:BP80@T920P0i>CT2030`<080:2PX0P0Q8B42
01/K6`805aLG00<04a<C00l?3`0?3`l0100=3@d200l?3`8051@D0P0J6QX201lO7`809BDU0P0[:b/2
030`<080=CDe0P0k>c/20410@080ADE50P1:BTX00`1?Cdl0De=C05=CD`0205QHF080G5aL0P1QHF42
06EUI@80JVYZ0P1^KVh2079bLP80MWIf0P1jNWX207inOP80PX:20P26QXH208Z:RP80SXj>00<0TY:B
09JFUP2FUYH00P2IVIT209fMW@80XJ6Q0P2UYJD20:RXZ080[:b/5@3oool001<0oooo0P2_[jl20:j^
[P80[Jf]0P2[Zj/20:ZZZP80ZJVY0P2WYjL20:JVYP030:BTY02SXj<0Xj>S0080XJ6Q0P2NWYh209bL
W080VIVI0P2FUYH209>CT`80SXj>0P2<S8`208V9R@80QhN70P26QXH208B4Q080Ph>30P22PX800`21
PH40Ogmo07moO`0207inOP@0OGem0P1nOWh207moO`80PH610P23Ph<208F5Q@80QXJ60P28R8P208V9
R@80Rh^;0P2<S8`208j>SP0308n?S`2@T900T92@0080TY:B0P2CTi<209BDU0@0UIFE0P2FUYH<09NG
U`@0UYJF00<0UIFE09BDU02DU9@00P2CTi<2096AT@80T92@0P2>SXh208b<S080Rh^;0P29RHT208N7
Q`80Q8B40P22PX8207moO`80OGem0P1jNWX207MgM`0307AdM01aLG40LG5a0080KFe]0P1YJFT206AT
I080GemO0P1IFET2059BDP80BTY:0P12@T8203Ti>@80<30`0P0X:2P2024Q8@806a/K0P0G5aL00`0C
4a<03`l?00l?3`0400d=3@803`l?0P0D51@201XJ6P807alO0P0U9BD202/[:`80<30`0P0e=CD203/k
>`80@4100P15ADD204Y:BP0304m?C`1CDe<0De=C0080F5QH0P1LG5`2065QH@80IFEU0P1ZJVX206i^
KP80LW9b0P1fMWH207YjNP80OWin0P22PX8208J6QP80RXZ:0P2>SXh00`2BTY80UYJF09JFUP0209VI
V@80WIfM0P2QXJ420:FUY@80Z:RX0P2/[:`E0?ooo`004`3oool20:n_[`80[Jf]0P2/[:`20:^[Z`80
ZJVY0P2XZ:P20:JVYP80YJFU00<0Xj>S0:6QX@2QXJ400P2OWil209fMW@80VYZJ0P2GUiL209BDU080
T92@0P2<S8`208R8R080Ph>30P21PH460820P080Ogmo00<0OWin07emO@1mOGd01P1mOGd207inOP80
Ogmo0P21PH4208>3P`80QHF50P27QhL208V9R@80Rh^;0P2<S8`208j>SP80Shn?00<0TI6A09:BTP2B
TY800P2DU9@209FEU@80UYJF102GUiL209RHV0h0VIVI0P2HV9P00`2GUiL0UYJF09JFUP0209FEU@80
Ti>C0P2BTY82092@T080SXj>0P2<S8`208Z:RP80R8R80P25QHD208>3P`80P8200P1mOGd207YjNP80
MgMg00<0M7Ad071`L01`L7000P1/K6`206MWI`80HV9R0P1LG5`205EEE@80CDe=0P15ADD203`l?080
=3@d0P0/;2`202@T90807AdM0P0F5QH201<C4`03010@400=3@d03@d=00802`/;0P0<30`200l?3`80
5ADE0P0K6a/2020P80809RHV0P0[:b/2034a<@80=SHf0P0k>c/20451@@80ATI60P1:BTX00`1?Cdl0
E5AD05ADE00205UIF@80GEeM0P1QHF4206IVIP80JVYZ0P1^KVh2079bLP80MgMg0P1kNg/207moO`80
Ph>30P26QXH208Z:RP80SXj>00<0TY:B09JFUP2FUYH00P2JVYX209fMW@80XJ6Q0P2UYJD20:RXZ080
[:b/5@3oool001<0oooo0P2_[jl20:f][@80[:b/0P2[Zj/20:VYZ@80Z:RX0P2VYZH20:FUY@030:>S
X`2QXJ40XJ6Q0080WinO0P2MWId209ZJVP80UiNG0P2DU9@2092@T080S8b<0P28R8P208>3P`80PH61
1P20P80207moO`0307inOP1mOGd0OGem00H0OGem0P1nOWh207moO`80PH610P23Ph<208F5Q@80QhN7
0P29RHT208^;R`80S8b<0P2>SXh208n?S`03096AT@2BTY80TY:B0080U9BD0P2EUID209JFUP@0UiNG
0P2HV9P>09VIV@80V9RH00<0UiNG09JFUP2FUYH00P2EUID209>CT`80TY:B0P2@T90208j>SP80S8b<
0P2:RXX208R8R080QHF50P23Ph<20820P080OGem0P1jNWX207MgM`0307AdM01`L700L71`0080K6a/
0P1WIfL2069RHP80G5aL0P1EEED204e=C@80ADE50P0l?3`203@d=080;2`/0P0T92@201dM7@805QHF
0P0C4a<00`0@41003@d=00d=3@0200/;2`8030`<0P0?3`l201DE5@806a/K0P0P820202HV9P80:b/[
0P0a<C4203Hf=P80>c/k0P11@D4204I6AP80BTY:00<0Cdm?05ADE01DE5@00P1IFET205eMG@80HF5Q
0P1VIVH206YZJP80KVi^0P1bLW8207MgM`80Ng]k0P1oOgl208>3P`80QXJ60P2:RXX208j>SP0309:B
TP2FUYH0UYJF0080VYZJ0P2MWId20:6QX@80YJFU0P2XZ:P20:b/[1D0oooo000C0?ooo`80[Zj^0P2]
[Jd20:b/[080ZZZZ0P2YZJT20:NWY`80YJFU0P2TY:@00`2RXZ80X:2P0:2PX00209jNWP80Vi^K0P2H
V9P209FEU@80TY:B0P2>SXh208V9R@80PX:20P1lO7`407]kN`80O7al1@1mOGd607alO080OGem0P1o
Ogl20820P080PX:20P24Q8@208J6QP80R8R80P2:RXX208b<S080SXj>0P2?Shl2096AT@0309>CT`2D
U9@0U9BD0080UIFE0P2FUYH209NGU`80V9RH0P2IVIT209ZJVP@0Vi^K202LW9`209^KV`80VYZJ00<0
VIVI09RHV02HV9P00P2GUiL209FEU@80U9BD0P2BTY82092@T080SXj>0P2<S8`208V9R@80QXJ60P23
Ph<20820P080OGem0P1jNWX207IfMP0307=cL`1_Kfl0Kfm_0080JVYZ0P1UIFD205mOG`80F5QH0P1@
D50204Q8B080?clo0P0g=cL202h^;P809bLW0P0O7al201DE5@803`l?0P0>3Ph00`0<30`02PX:00X:
2P0200X:2P802`/;0P0@410201HF5P8071`L0P0Q8B4202LW9`80;2`/0P0b<S8203Lg=`80?3`l0P11
@D4204I6AP80Bd];00<0D51@05EEE@1EEED00P1IFET205iNGP80HV9R0P1VIVH206][J`80Kfm_0P1c
Lg<207MgM`80Ng]k0P1oOgl208>3P`80QhN70P2;Rh/208n?S`0309:BTP2FUYH0UYJF0080VYZJ0P2M
WId20:6QX@80YJFU0P2YZJT20:b/[1D0oooo000C0?ooo`80[Zj^0P2][Jd20:^[Z`80ZZZZ0P2XZ:P2
0:JVYP80YJFU0P2SXj<00`2QXJ40WinO09nOW`0209bLW080VYZJ0P2GUiL209BDU080TI6A0P2=SHd2
08R8R080Ph>30P1mOGd207UiN@80NWYj0P1lO7`207emO@<0O7al0P1kNg/407alO080OGem0P1oOgl2
0820P080Ph>30P25QHD208N7Q`80RHV90P2;Rh/208f=S@80Shn?0P2ATI4209:BTP0309BDU02FUYH0
UYJF0080UiNG0P2HV9P209ZJVP80Vi^K102LW9`209fMW@X0WYjN0P2MWId309bLW080Vi^K0P2IVIT2
09NGU`80UIFE0P2CTi<2096AT@80Shn?0P2<S8`208Z:RP80QhN70P23Ph<20820P080OGem0P1iNGT2
07IfMP03075aL@1/K6`0K6a/0080IfMW0P1RHV8205]KF`80De=C0P1;Bd/204=3@`80>SXj0P0b<S82
02TY:@80820P0P0G5aL200h>3P@02`/;00<02@T900L71`071`L00P0820P200/;2`804A4A0P0G5aL2
01dM7@808R8R0P0X:2P202d];@80<c<c0P0h>3P203dm?@80@T920P17AdL204a<C003055AD@1EEED0
EEEE0080FUYJ0P1NGUh206=SH`80IfMW0P1[Jf/206m_K`80M7Ad0P1hN7P207alO080Ogmo0P23Ph<2
08N7Q`80Rh^;0P2?Shl00`2CTi<0UYJF09JFUP0209ZJVP80WYjN0P2QXJ420:FUY@80ZJVY0P2/[:`E
0?ooo`004`3oool20:j^[P80[Jf]0P2[Zj/20:ZZZP80Z:RX0P2VYZH20:FUY@80Xj>S00<0XJ6Q09nO
W`2OWil00P2LW9`209ZJVP80UiNG0P2DU9@2096AT@80SHf=0P28R8P208>3P`80OGem0P1iNGT207Yj
NP80O7al0P1mOGd307alO080Ng]k101lO7`207emO@80Ogmo0P20P80208>3P`80QHF50P27QhL208V9
R@80Rh^;0P2=SHd208n?S`80TI6A0P2BTY800`2DU9@0UYJF09JFUP0209NGU`80V9RH0P2JVYX209^K
V`@0W9bL0P2MWId:09jNWP80WIfM0`2LW9`209^KV`80VIVI0P2GUiL209FEU@80Ti>C0P2ATI4208n?
S`80S8b<0P2:RXX208N7Q`80Ph>30P20P80207emO@80NGUi0P1fMWH00`1aLG40K6a/06a/K00206MW
I`80HV9R0P1KFe/205=CD`80Bd];0P13@d<203Xj>P80<S8b0P0Y:BT2020P80805aLG0P0>3Ph400/;
2`0300T92@071`L01`L7008020P80P0;2`/2014A4@805aLG0P0M7Ad2028R8P80:2PX0P0];Bd203<c
<`80>3Ph0P0m?Cd20492@P80AdM70P1<C4`00`1ADE40EEEE05EEE@0205YJFP80GUiN0P1SHf<206MW
I`80Jf][0P1_Kfl207AdM080N7Qh0P1lO7`207moO`80Ph>30P27QhL208^;R`80Shn?00<0Ti>C09JF
UP2FUYH00P2JVYX209jNWP80XJ6Q0P2UYJD20:VYZ@80[:b/5@3oool001<0oooo0P2^[Zh20:f][@80
Zj^[0P2YZJT20:RXZ080YZJV0P2TY:@20::RXP030:2PX02NWYh0WYjN0080Vi^K0P2IVIT209JFUP80
Ti>C0P2@T90208b<S080R8R80P24Q8@20820P080OGem101lO7`207emO@80O7al1`1kNg/207emO@80
OWin0P21PH4208>3P`80QHF50P28R8P208Z:RP80S8b<0P2>SXh2092@T080TY:B0P2DU9@00`2FUYH0
UiNG09NGU`0209VIV@80VYZJ0P2LW9`209fMW@80WYjN0P2OWil20:2PX0P0XJ6Q102PX:0209nOW`03
09jNWP2MWId0WIfM0080Vi^K0P2IVIT209NGU`80UIFE0P2CTi<2092@T080SHf=0P2:RXX208N7Q`80
Q8B40P21PH4207emO@80NGUi0P1dM7@00`1_Kfl0Jf][06][J`0206EUI@80GUiN0P1FEUH204i>CP80
ADE50P0m?Cd203@d=080;2`/0P0S8b<201TI6@803Ph>10092@T200P8200300D51@0410@010@40080
1PH60P0;2`/2018B4P8061PH0P0N7Qh202@T9080:BTY0P0_;bl203@d=080>CTi0P0n?Sh204=3@`80
B4Q80P1=CDd00`1BDU80EUIF05IFEP0205]KF`80GemO0P1TI6@206QXJ080K6a/0P1`L70207AdM080
N7Qh0P1lO7`20820P080Q8B40P28R8P208^;R`80Shn?00<0Ti>C09NGU`2GUiL00P2JVYX209jNWP80
XJ6Q0P2UYJD20:VYZ@80[:b/5@3oool001<0oooo0P2^[Zh20:f][@80Zj^[0P2YZJT20:RXZ080YZJV
0P2TY:@20::RXP030:2PX02NWYh0WYjN0080Vi^K0P2IVIT209JFUP80Ti>C0P2@T90208b<S080R8R8
0P24Q8@20820P080OGem101lO7`207emO@80O7al1`1kNg/207emO@80OWin0P21PH4208>3P`80QHF5
0P28R8P208Z:RP80S8b<0P2>SXh2092@T080TY:B0P2DU9@00`2FUYH0UiNG09NGU`0209VIV@80VYZJ
0P2LW9`209fMW@80WYjN0P2OWil20:2PX0P0XJ6Q102PX:0209nOW`0309jNWP2MWId0WIfM0080Vi^K
0P2IVIT209NGU`80UIFE0P2CTi<2092@T080SHf=0P2:RXX208N7Q`80Q8B40P21PH4207emO@80NGUi
0P1dM7@00`1_Kfl0Jf][06][J`0206EUI@80GUiN0P1FEUH204i>CP80ADE50P0m?Cd203@d=080;2`/
0P0S8b<201TI6@803Ph>10092@T200P8200300D51@0410@010@400801PH60P0;2`/2018B4P8061PH
0P0N7Qh202@T9080:BTY0P0_;bl203@d=080>CTi0P0n?Sh204=3@`80B4Q80P1=CDd00`1BDU80EUIF
05IFEP0205]KF`80GemO0P1TI6@206QXJ080K6a/0P1`L70207AdM080N7Qh0P1lO7`20820P080Q8B4
0P28R8P208^;R`80Shn?00<0Ti>C09NGU`2GUiL00P2JVYX209jNWP80XJ6Q0P2UYJD20:VYZ@80[:b/
5@3oool001<0oooo0P2^[Zh20:b/[080Zj^[0P2YZJT20:NWY`80YJFU0P2SXj<20:6QX@0309nOW`2M
WId0WIfM0080VYZJ0P2HV9P209FEU@80TY:B0P2?Shl208b<S080R8R80P25QHD20861P@80Ogmo0P1n
OWh207emO@80O7al1`1jNWX207]kN`80OGem0P1oOgl20861P@80Ph>30P26QXH208R8R080Rh^;0P2=
SHd208n?S`80TI6A0P2CTi<209FEU@0309NGU`2IVIT0VIVI0080Vi^K0P2LW9`209jNWP80WinO0P2P
X:020:6QX@80XZ:R102SXj<20:BTY0@0Xj>S0P2RXZ820:6QX@030:2PX02NWYh0WYjN0080W9bL0P2K
Vi/209RHV080UYJF0P2DU9@2096AT@80SXj>0P2;Rh/208R8R080Q8B40P20P80207emO@80N7Qh0P1c
Lg<00`1^KVh0J6QX06QXJ002065QH@80FEUI0P1ADE4204U9B@80@4100P0f=SH202h^;P809RHV0P0L
71`2014A4@802`/;0P092@T200H61P8010@400<00P8200<30`030`<00P061PH200`<30804a<C0P0I
6AT201lO7`809BDU0P0Z:RX2030`<080=CDe0P0k>c/20410@080ADE50P19BDT204i>CP0305=CD`1G
EeL0EeMG0080G5aL0P1PH60206ATI080JFUY0P1]KFd2075aL@80MGEe0P1iNGT207emO@80PH610P24
Q8@208R8R080S8b<0P2@T9000`2CTi<0UiNG09NGU`0209ZJVP80WYjN0P2RXZ820:FUY@80ZJVY0P2/
[:`E0?ooo`004`3oool20:j^[P80[:b/0P2[Zj/20:VYZ@80YjNW0P2UYJD20:>SX`80XJ6Q00<0WinO
09fMW@2MWId00P2JVYX209RHV080UIFE0P2BTY8208n?S`80S8b<0P28R8P208F5Q@80PH610P1oOgl2
07inOP80OGem0P1lO7`707YjNP80Ng]k0P1mOGd207moO`80PH610P23Ph<208J6QP80R8R80P2;Rh/2
08f=S@80Shn?0P2ATI4209>CT`80UIFE00<0UiNG09VIV@2IVIT00P2KVi/209bLW080WYjN0P2OWil2
0:2PX080XJ6Q0P2RXZ840:>SX`80Y:BT102SXj<20::RXP80XJ6Q00<0X:2P09jNWP2NWYh00P2LW9`2
09^KV`80V9RH0P2FUYH209BDU080TI6A0P2>SXh208^;R`80R8R80P24Q8@20820P080OGem0P1hN7P2
07=cL`0306i^KP1XJ6P0J6QX0080HF5Q0P1IFET2055AD@80BDU90P10@40203Hf=P80;Rh^0P0V9RH2
01`L70804A4A0P0;2`/200T92@801PH60P0410@00`020P800`<300<30`0200H61P8030`<0P0C4a<2
01TI6@807alO0P0U9BD202XZ:P80<30`0P0e=CD203/k>`80@4100P15ADD204U9B@80CTi>00<0De=C
05MGE`1GEeL00P1LG5`2061PH080I6AT0P1YJFT206e]K@80LG5a0P1eMGD207UiN@80OGem0P21PH42
08B4Q080R8R80P2<S8`2092@T00309>CT`2GUiL0UiNG0080VYZJ0P2NWYh20::RXP80YJFU0P2YZJT2
0:b/[1D0oooo000C0?ooo`80[Zj^0P2/[:`20:^[Z`80ZJVY0P2WYjL20:FUY@80Xj>S0P2QXJ400`2O
Wil0W9bL09bLW00209ZJVP80UiNG0P2DU9@209:BTP80SXj>0P2;Rh/208R8R080QHF50P22PX820820
P080Ogmo0P1mOGd207YjNP80Ng]k00<0NWYj07UiN@1iNGT00P1jNWX207]kN`80OGem0P1oOgl208:2
PP80Q8B40P26QXH208V9R@80Rh^;0P2=SHd2092@T080TY:B0P2DU9@209NGU`0309VIV@2KVi/0Vi^K
0080WIfM0P2NWYh20:2PX080XJ6Q0P2RXZ820:>SX`80Y:BT0P2UYJD60:JVYP80YJFU0P2TY:@20:>S
X`030::RXP2PX:00X:2P0080WYjN0P2LW9`209ZJVP80V9RH0P2FUYH209>CT`80Shn?0P2<S8`208R8
R080Q8B40P20P80207]kN`80MWIf0P1aLG400`1[Jf/0I6AT06ATI00205eMG@80EEEE0P1=CDd204A4
A080>c/k0P0c<c<202TY:@807QhN0P0D51@200d=3@8020P80P051@D200<30`800@4100<0000000<3
0`030`<00P071`L200d=3@8051@D0P0J6QX2024Q8@809RHV0P0/;2`2034a<@80=cLg0P0l?3`20451
@@80ATI60P1;Bd/204m?C`0305ADE01HF5P0F5QH0080GEeM0P1QHF4206EUI@80JVYZ0P1^KVh2079b
LP80MWIf0P1iNGT207emO@80PH610P25QHD208V9R@80S8b<0P2@T9000`2DU9@0UiNG09NGU`0209^K
V`80WYjN0P2RXZ820:FUY@80ZJVY0P2/[:`E0?ooo`004`3oool20:j^[P80[:b/0P2[Zj/20:VYZ@80
YjNW0P2UYJD20:>SX`80XJ6Q00<0WinO09bLW02LW9`00P2JVYX209NGU`80U9BD0P2BTY8208j>SP80
Rh^;0P28R8P208F5Q@80PX:20P20P80207moO`80OGem0P1jNWX207]kN`0307YjNP1iNGT0NGUi0080
NWYj0P1kNg/207emO@80Ogmo0P22PX8208B4Q080QXJ60P29RHT208^;R`80SHf=0P2@T90209:BTP80
U9BD0P2GUiL00`2IVIT0Vi^K09^KV`0209fMW@80WYjN0P2PX:020:6QX@80XZ:R0P2SXj<20:BTY080
YJFU1P2VYZH20:FUY@80Y:BT0P2SXj<00`2RXZ80X:2P0:2PX00209jNWP80W9bL0P2JVYX209RHV080
UYJF0P2CTi<208n?S`80S8b<0P28R8P208B4Q080P8200P1kNg/207IfMP80LG5a00<0Jf][06ATI01T
I6@00P1MGEd205EEE@80CDe=0P14A4@203/k>`80<c<c0P0Y:BT201hN7P8051@D0P0=3@d200P82080
1@D50P030`<200410@03000000030`<00`<300801`L70P0=3@d201@D50806QXJ0P0Q8B4202HV9P80
;2`/0P0a<C4203Lg=`80?3`l0P11@D4204I6AP80Bd];0P1?Cdl00`1DE5@0F5QH05QHF00205eMG@80
HF5Q0P1UIFD206YZJP80KVi^0P1bLW8207IfMP80NGUi0P1mOGd20861P@80QHF50P29RHT208b<S080
T92@00<0U9BD09NGU`2GUiL00P2KVi/209jNWP80XZ:R0P2UYJD20:VYZ@80[:b/5@3oool001<0oooo
0P2^[Zh20:b/[080ZZZZ0P2XZ:P20:NWY`80YJFU0P2RXZ820:2PX00309jNWP2LW9`0W9bL0080VIVI
0P2GUiL209BDU080TI6A0P2>SXh208^;R`80R8R80P25QHD208:2PP80P8200P1nOWh207]kN`80NWYj
0P1iNGT00`1hN7P0NGUi07UiN@0207YjNP80Ng]k0P1mOGd207moO`80PX:20P24Q8@208N7Q`80RHV9
0P2<S8`208j>SP80T92@0P2CTi<209FEU@80V9RH00<0VYZJ09bLW02LW9`00P2NWYh20:2PX080XJ6Q
0P2SXj<20:BTY080YJFU0P2VYZH20:NWY`@0Z:RX102WYjL20:JVYP80Y:BT00<0Xj>S0::RXP2RXZ80
0P2PX:0209jNWP80W9bL0P2JVYX209NGU`80Ti>C0P2@T90208b<S080R8R80P24Q8@207moO`80NWYj
0P1dM7@206i^KP0306MWI`1OGel0GemO0080F5QH0P1@D50204Q8B080?clo0P0f=SH202`/;0808b<S
0P0J6QX200l?3`802@T90P061PH200@410800@410`00000200820P8020P80P0@410201HF5P8071`L
0P0R8R8202PX:080;Rh^0P0c<c<203Ph>080?Cdm0P12@T8204M7A`80C4a<0P1ADE400`1EEED0FUYJ
05YJFP0205iNGP80HV9R0P1VIVH206][J`80Kfm_0P1bLW8207IfMP80NWYj0P1nOWh208:2PP80QXJ6
0P29RHT208f=S@80T92@00<0U9BD09RHV02HV9P00P2KVi/209nOW`80XZ:R0P2VYZH20:VYZ@80[:b/
5@3oool001<0oooo0P2^[Zh20:b/[080ZZZZ0P2XZ:P20:NWY`80YJFU0P2RXZ820:2PX00309jNWP2L
W9`0W9bL0080VIVI0P2GUiL209BDU080TI6A0P2>SXh208^;R`80R8R80P25QHD208:2PP80P8200P1n
OWh207]kN`80NWYj0P1iNGT00`1hN7P0NGUi07UiN@0207YjNP80Ng]k0P1mOGd207moO`80PX:20P24
Q8@208N7Q`80RHV90P2<S8`208j>SP80T92@0P2CTi<209FEU@80V9RH00<0VYZJ09bLW02LW9`00P2N
WYh20:2PX080XJ6Q0P2SXj<20:BTY080YJFU0P2VYZH20:NWY`@0Z:RX102WYjL20:JVYP80Y:BT00<0
Xj>S0::RXP2RXZ800P2PX:0209jNWP80W9bL0P2JVYX209NGU`80Ti>C0P2@T90208b<S080R8R80P24
Q8@207moO`80NWYj0P1dM7@206i^KP0306MWI`1OGel0GemO0080F5QH0P1@D50204Q8B080?clo0P0f
=SH202`/;0808b<S0P0J6QX200l?3`802@T90P061PH200@410800@410`00000200820P8020P80P0@
410201HF5P8071`L0P0R8R8202PX:080;Rh^0P0c<c<203Ph>080?Cdm0P12@T8204M7A`80C4a<0P1A
DE400`1EEED0FUYJ05YJFP0205iNGP80HV9R0P1VIVH206][J`80Kfm_0P1bLW8207IfMP80NWYj0P1n
OWh208:2PP80QXJ60P29RHT208f=S@80T92@00<0U9BD09RHV02HV9P00P2KVi/209nOW`80XZ:R0P2V
YZH20:VYZ@80[:b/5@3oool001<0oooo0P2^[Zh20:b/[080ZZZZ0P2XZ:P20:JVYP80Y:BT0P2RXZ82
0:2PX00309jNWP2KVi/0Vi^K0080VIVI0P2FUYH209BDU080TI6A0P2>SXh208^;R`80R8R80P25QHD2
08:2PP80Ogmo0P1lO7`407QhN080MWIf00<0MGEe07IfMP1fMWH00P1hN7P207YjNP80O7al0P1nOWh2
0861P@80Q8B40P26QXH208V9R@80S8b<0P2>SXh2096AT@80Ti>C0P2FUYH209RHV00309^KV`2MWId0
WIfM0080X:2P0P2RXZ820:>SX`80YJFU0P2VYZH20:NWY`@0Z:RX0P2YZJT40:RXZ0@0YjNW0P2VYZH0
0`2UYJD0Xj>S0:>SX`020:6QX@80WinO0P2MWId209ZJVP80UiNG0P2CTi<208n?S`80Rh^;0P27QhL2
08:2PP80O7al0P1gMgL2075aL@80JVYZ00<0Hf=S05]KF`1KFe/00P1CDe<204];B`80@D510P0h>3P2
02l_;`809RHV0P0M7Ad201@D50803@d=0P092@T200D51@800P82100000000`010@401@D500D51@02
00/;2`804Q8B0P0H61P201hN7P8092@T0P0Z:RX2030`<080=CDe0P0j>SX203lo?`80A4A40P19BDT2
04i>CP80DU9B00<0EeMG05]KF`1KFe/00P1OGel206ATI080J6QX0P1/K6`2071`L080Lg=c0P1gMgL2
07]kN`80Ogmo0P23Ph<208J6QP80RXZ:0P2=SHd2096AT@0309BDU02HV9P0V9RH0080Vi^K0P2OWil2
0::RXP80YZJV0P2YZJT20:b/[1D0oooo000C0?ooo`80[Zj^0P2/[:`20:ZZZP80Z:RX0P2VYZH20:BT
Y080XZ:R0P2PX:000`2NWYh0Vi^K09^KV`0209VIV@80UYJF0P2DU9@2096AT@80SXj>0P2;Rh/208R8
R080QHF50P22PX8207moO`80O7al101hN7P207IfMP0307EeM@1fMWH0MWIf0080N7Qh0P1jNWX207al
O080OWin0P21PH4208B4Q080QXJ60P29RHT208b<S080SXj>0P2ATI4209>CT`80UYJF0P2HV9P00`2K
Vi/0WIfM09fMW@020:2PX080XZ:R0P2SXj<20:FUY@80YZJV0P2WYjL40:RXZ080ZJVY102XZ:P40:NW
Y`80YZJV00<0YJFU0:>SX`2SXj<00P2QXJ4209nOW`80WIfM0P2JVYX209NGU`80Ti>C0P2?Shl208^;
R`80QhN70P22PX8207alO080MgMg0P1aLG4206YZJP0306=SH`1KFe/0Fe]K0080De=C0P1;Bd/20451
@@80>3Ph0P0_;bl202HV9P807AdM0P0D51@200d=3@802@T90P051@D200820P@0000000<00@4100D5
1@051@D00P0;2`/2018B4P8061PH0P0N7Qh202@T9080:RXZ0P0`<30203De=@80>SXj0P0o?cl204A4
A080BDU90P1>CTh2059BDP0305MGE`1KFe/0Fe]K0080GemO0P1TI6@206QXJ080K6a/0P1`L70207=c
L`80MgMg0P1kNg/207moO`80Ph>30P26QXH208Z:RP80SHf=0P2ATI400`2DU9@0V9RH09RHV00209^K
V`80WinO0P2RXZ820:JVYP80ZJVY0P2/[:`E0?ooo`004`3oool20:j^[P80[:b/0P2ZZZX20:RXZ080
YZJV0P2TY:@20::RXP80X:2P00<0WIfM09^KV`2KVi/00P2IVIT209JFUP80Ti>C0P2ATI4208j>SP80
Rh^;0P28R8P208F5Q@80PH610P1nOWh207YjNP80MgMg0P1dM7@2075aL@03079bLP1cLg<0Lg=c0080
MGEe0P1hN7P207]kN`80OWin0P21PH4208>3P`80QXJ60P28R8P208^;R`80SXj>0P2@T90209>CT`80
UYJF0P2IVIT00`2LW9`0WYjN09jNWP020:6QX@80XZ:R0P2TY:@20:FUY@80YjNW1P2XZ:P20:VYZ@H0
Z:RX0P2WYjL20:JVYP030:BTY02RXZ80XZ:R0080XJ6Q0P2NWYh209bLW080VIVI0P2FUYH209:BTP80
SXj>0P2:RXX208F5Q@80Ogmo0P1jNWX207=cL`80K6a/0P1VIVH00`1OGel0EUIF05IFEP0204i>CP80
ADE50P0k>c/2038b<P80:b/[0P0S8b<201XJ6P804Q8B0P0=3@d200T92@8010@40P020P8200000080
0@4100<00`<300L71`071`L00P0>3Ph201@D50806a/K0P0Q8B4202LW9`80;2`/0P0b<S8203Lg=`80
?3`l0P11@D4204I6AP80BTY:0P1?Cdl205ADE00305QHF01LG5`0G5aL0080H61P0P1UIFD206UYJ@80
KFe]0P1aLG4207AdM080N7Qh0P1lO7`20820P080Ph>30P27QhL208Z:RP80SXj>0P2ATI400`2EUID0
V9RH09RHV00209bLW080WinO0P2RXZ820:JVYP80ZJVY0P2][JdE0?ooo`004`3oool20:j^[P80[:b/
0P2ZZZX20:RXZ080YZJV0P2TY:@20::RXP80X:2P00<0WIfM09^KV`2KVi/00P2IVIT209JFUP80Ti>C
0P2ATI4208j>SP80Rh^;0P28R8P208F5Q@80PH610P1nOWh207YjNP80MgMg0P1dM7@2075aL@03079b
LP1cLg<0Lg=c0080MGEe0P1hN7P207]kN`80OWin0P21PH4208>3P`80QXJ60P28R8P208^;R`80SXj>
0P2@T90209>CT`80UYJF0P2IVIT00`2LW9`0WYjN09jNWP020:6QX@80XZ:R0P2TY:@20:FUY@80YjNW
1P2XZ:P20:VYZ@H0Z:RX0P2WYjL20:JVYP030:BTY02RXZ80XZ:R0080XJ6Q0P2NWYh209bLW080VIVI
0P2FUYH209:BTP80SXj>0P2:RXX208F5Q@80Ogmo0P1jNWX207=cL`80K6a/0P1VIVH00`1OGel0EUIF
05IFEP0204i>CP80ADE50P0k>c/2038b<P80:b/[0P0S8b<201XJ6P804Q8B0P0=3@d200T92@8010@4
0P020P82000000800@4100<00`<300L71`071`L00P0>3Ph201@D50806a/K0P0Q8B4202LW9`80;2`/
0P0b<S8203Lg=`80?3`l0P11@D4204I6AP80BTY:0P1?Cdl205ADE00305QHF01LG5`0G5aL0080H61P
0P1UIFD206UYJ@80KFe]0P1aLG4207AdM080N7Qh0P1lO7`20820P080Ph>30P27QhL208Z:RP80SXj>
0P2ATI400`2EUID0V9RH09RHV00209bLW080WinO0P2RXZ820:JVYP80ZJVY0P2][JdE0?ooo`004`3o
ool20:j^[P80[:b/0P2ZZZX20:RXZ080YZJV0P2TY:@20::RXP80X:2P00<0WIfM09^KV`2KVi/00P2I
VIT209JFUP80Ti>C0P2ATI4208j>SP80Rh^;0P28R8P208F5Q@80PH610P1nOWh207YjNP80M7Ad0P1`
L70306i^KP80LG5a0P1cLg<207EeM@80N7Qh0P1lO7`20820P080Ph>30P25QHD208N7Q`80RHV90P2<
S8`208n?S`80Ti>C0P2GUiL209ZJVP0309bLW02OWil0WinO0080XJ6Q0P2SXj<40:BTY080YJFU0P2V
YZH80:NWY`80YZJV0P2UYJD20:BTY080Xj>S00<0XZ:R0:2PX02PX:000P2NWYh209bLW080VIVI0P2F
UYH209:BTP80Shn?0P2;Rh/208J6QP80PH610P1lO7`207IfMP80Kfm_0P1XJ6P2061PH00305QHF01@
D500D51@0080B4Q80P10@40203Lg=`80;bl_0P0W9bL201lO7`8061PH0P0@410200X:2P801PH60P03
0`<400410@800`<300<01PH600/;2`0;2`/00P0A4A4201LG5`807AdM0P0S8b<202TY:@80;bl_0P0d
=3@203Ti>@80?Shn0P13@d<204Q8B080C4a<0P1ADE4205EEE@0305UIF@1NGUh0GUiN0080HV9R0P1V
IVH206YZJP80KVi^0P1bLW8207EeM@80NGUi0P1mOGd20820P080Q8B40P28R8P208^;R`80Shn?0P2B
TY800`2EUID0VIVI09VIV@0209bLW080WinO0P2SXj<20:JVYP80ZJVY0P2][JdE0?ooo`004`3oool2
0:j^[P80[:b/0P2ZZZX20:RXZ080YZJV0P2TY:@20::RXP80X:2P00<0WIfM09^KV`2KVi/00P2IVIT2
09JFUP80Ti>C0P2ATI4208j>SP80Rh^;0P28R8P208F5Q@80PH610P1nOWh207YjNP80M7Ad0P1`L703
06i^KP80LG5a0P1cLg<207EeM@80N7Qh0P1lO7`20820P080Ph>30P25QHD208N7Q`80RHV90P2<S8`2
08n?S`80Ti>C0P2GUiL209ZJVP0309bLW02OWil0WinO0080XJ6Q0P2SXj<40:BTY080YJFU0P2VYZH8
0:NWY`80YZJV0P2UYJD20:BTY080Xj>S00<0XZ:R0:2PX02PX:000P2NWYh209bLW080VIVI0P2FUYH2
09:BTP80Shn?0P2;Rh/208J6QP80PH610P1lO7`207IfMP80Kfm_0P1XJ6P2061PH00305QHF01@D500
D51@0080B4Q80P10@40203Lg=`80;bl_0P0W9bL201lO7`8061PH0P0@410200X:2P801PH60P030`<4
00410@800`<300<01PH600/;2`0;2`/00P0A4A4201LG5`807AdM0P0S8b<202TY:@80;bl_0P0d=3@2
03Ti>@80?Shn0P13@d<204Q8B080C4a<0P1ADE4205EEE@0305UIF@1NGUh0GUiN0080HV9R0P1VIVH2
06YZJP80KVi^0P1bLW8207EeM@80NGUi0P1mOGd20820P080Q8B40P28R8P208^;R`80Shn?0P2BTY80
0`2EUID0VIVI09VIV@0209bLW080WinO0P2SXj<20:JVYP80ZJVY0P2][JdE0?ooo`004`3oool20:j^
[P80[:b/0P2ZZZX20:RXZ080YZJV0P2TY:@20::RXP80X:2P00<0WIfM09^KV`2KVi/00P2HV9P209JF
UP80Ti>C0P2ATI4208j>SP80Rh^;0P28R8P208F5Q@80PH610P1nOWh207YjNP80MGEe0P1_Kfl306YZ
JP80KFe]0P1aLG4207AdM080MgMg0P1jNWX207emO@80Ogmo0P22PX8208F5Q@80R8R80P2<S8`208n?
S`80Ti>C0P2FUYH209VIV@0309bLW02NWYh0WYjN0080WinO0P2PX:020:6QX@H0Xj>S1P2TY:@20:>S
X`80XZ:R0P2QXJ420:2PX080WinO00<0WIfM09ZJVP2JVYX00P2IVIT209JFUP80Ti>C0P2@T90208b<
S080RHV90P25QHD20861P@80O7al0P1fMWH2075aL@80K6a/0P1UIFD205aLG00305EEE@1<C4`0C4a<
0080A4A40P0k>c/203<c<`80;2`/0P0T92@201XJ6P804a<C0P0>3Ph200X:2P801PH60P030`<20082
0P@010@400<020P800h>3P0>3Ph00P0D51@201XJ6P80820P0P0V9RH202`/;080<C4a0P0f=SH203/k
>`80@4100P15ADD204U9B@80CTi>0P1BDU8205MGE`0305]KF`1OGel0GemO0080Hf=S0P1WIfL206][
J`80Kfm_0P1cLg<207MgM`80NWYj0P1nOWh208:2PP80QHF50P28R8P208b<S080Shn?0P2CTi<00`2F
UYH0VIVI09VIV@0209bLW080X:2P0P2SXj<20:JVYP80ZJVY0P2][JdE0?ooo`004`3oool20:j^[P80
[:b/0P2ZZZX20:RXZ080YZJV0P2TY:@20::RXP80X:2P00<0WIfM09^KV`2KVi/00P2HV9P209JFUP80
Ti>C0P2ATI4208j>SP80Rh^;0P28R8P208F5Q@80PH610P1nOWh207YjNP80MGEe0P1_Kfl306YZJP80
KFe]0P1aLG4207AdM080MgMg0P1jNWX207emO@80Ogmo0P22PX8208F5Q@80R8R80P2<S8`208n?S`80
Ti>C0P2FUYH209VIV@0309bLW02NWYh0WYjN0080WinO0P2PX:020:6QX@H0Xj>S1P2TY:@20:>SX`80
XZ:R0P2QXJ420:2PX080WinO00<0WIfM09ZJVP2JVYX00P2IVIT209JFUP80Ti>C0P2@T90208b<S080
RHV90P25QHD20861P@80O7al0P1fMWH2075aL@80K6a/0P1UIFD205aLG00305EEE@1<C4`0C4a<0080
A4A40P0k>c/203<c<`80;2`/0P0T92@201XJ6P804a<C0P0>3Ph200X:2P801PH60P030`<200820P@0
10@400<020P800h>3P0>3Ph00P0D51@201XJ6P80820P0P0V9RH202`/;080<C4a0P0f=SH203/k>`80
@4100P15ADD204U9B@80CTi>0P1BDU8205MGE`0305]KF`1OGel0GemO0080Hf=S0P1WIfL206][J`80
Kfm_0P1cLg<207MgM`80NWYj0P1nOWh208:2PP80QHF50P28R8P208b<S080Shn?0P2CTi<00`2FUYH0
VIVI09VIV@0209bLW080X:2P0P2SXj<20:JVYP80ZJVY0P2][JdE0?ooo`004`3oool20:j^[P80[:b/
0P2ZZZX20:RXZ080YZJV0P2TY:@20::RXP80X:2P00<0WIfM09^KV`2KVi/00P2HV9P209JFUP80Ti>C
0P2ATI4208j>SP80Rh^;0P28R8P208F5Q@80PX:20P1nOWh207YjNP80MWIf0P1bLW8206i^KP<0KFe]
0P1^KVh2071`L080M7Ad0P1fMWH207QhN080OGem0P20P80208F5Q@80R8R80P2;Rh/208n?S`80TY:B
0P2EUID209NGU`0309VIV@2KVi/0Vi^K0080WIfM0P2NWYh209nOW`X0X:2P0P2OWil209jNWP80WIfM
0P2LW9`209ZJVP80V9RH00<0UYJF09BDU02DU9@00P2ATI4208j>SP80S8b<0P29RHT208J6QP80Ph>3
0P1nOWh207YjNP80MGEe0P1`L70206][J`80IFEU0P1NGUh205MGE`0304m?C`17AdL0AdM70080?clo
0P0g=cL202l_;`809bLW0P0O7al201PH60804A4A0P0<30`200P820@01@D50P061PH200D51@801PH6
00<030`<018B4P0B4Q800P0H61P201dM7@808b<S0P0Y:BT202h^;P80<c<c0P0h>3P203dm?@80@T92
0P17AdL204a<C080D51@0P1DE5@205UIF@0305eMG@1QHF40HF5Q0080IFEU0P1YJFT206e]K@80L71`
0P1dM7@207QhN080Ng]k0P1oOgl208:2PP80QXJ60P29RHT208f=S@80T92@0P2CTi<00`2FUYH0VYZJ
09ZJVP0209fMW@80X:2P0P2SXj<20:JVYP80ZZZZ0P2][JdE0?ooo`004`3oool20:j^[P80[:b/0P2Z
ZZX20:RXZ080YZJV0P2TY:@20::RXP80X:2P00<0WIfM09^KV`2KVi/00P2HV9P209JFUP80Ti>C0P2A
TI4208j>SP80Rh^;0P28R8P208F5Q@80PX:20P1nOWh207YjNP80MWIf0P1bLW8206i^KP<0KFe]0P1^
KVh2071`L080M7Ad0P1fMWH207QhN080OGem0P20P80208F5Q@80R8R80P2;Rh/208n?S`80TY:B0P2E
UID209NGU`0309VIV@2KVi/0Vi^K0080WIfM0P2NWYh209nOW`X0X:2P0P2OWil209jNWP80WIfM0P2L
W9`209ZJVP80V9RH00<0UYJF09BDU02DU9@00P2ATI4208j>SP80S8b<0P29RHT208J6QP80Ph>30P1n
OWh207YjNP80MGEe0P1`L70206][J`80IFEU0P1NGUh205MGE`0304m?C`17AdL0AdM70080?clo0P0g
=cL202l_;`809bLW0P0O7al201PH60804A4A0P0<30`200P820@01@D50P061PH200D51@801PH600<0
30`<018B4P0B4Q800P0H61P201dM7@808b<S0P0Y:BT202h^;P80<c<c0P0h>3P203dm?@80@T920P17
AdL204a<C080D51@0P1DE5@205UIF@0305eMG@1QHF40HF5Q0080IFEU0P1YJFT206e]K@80L71`0P1d
M7@207QhN080Ng]k0P1oOgl208:2PP80QXJ60P29RHT208f=S@80T92@0P2CTi<00`2FUYH0VYZJ09ZJ
VP0209fMW@80X:2P0P2SXj<20:JVYP80ZZZZ0P2][JdE0?ooo`004`3oool20:j^[P80[:b/0P2ZZZX2
0:RXZ080YZJV0P2TY:@20::RXP80WinO00<0WIfM09^KV`2KVi/00P2HV9P209JFUP80Ti>C0P2ATI42
08j>SP80Rh^;0P28R8P208F5Q@80PX:20P1oOgl207]kN`80MgMg0P1dM7@2071`L00306a/K01[Jf/0
Jf][0080KFe]0P1`L70207=cL`80MWIf0P1iNGT207alO080Ogmo0P22PX8208F5Q@80RHV90P2=SHd2
092@T080Ti>C0P2EUID00`2GUiL0V9RH09RHV00209VIV@80VYZJ0P2KVi/409bLW0@0Vi^K0P2JVYX2
09VIV@80V9RH0P2GUiL209JFUP80U9BD0P2BTY800`2@T900SXj>08j>SP0208^;R`80R8R80P25QHD2
08:2PP80PH610P1mOGd207YjNP80MGEe0P1`L70206][J`80IFEU0P1NGUh205QHF080DU9B00<0BTY:
0492@P12@T800P0k>c/203<c<`80:b/[0P0S8b<201/K6`8051@D0P0>3Ph200X:2PH02@T90P0820P2
00L71`802PX:00<0410@01HF5P0F5QH00P0K6a/2024Q8@809bLW0P0/;2`2034a<@80=SHf0P0k>c/2
0410@080ADE50P19BDT204i>CP80DU9B0P1FEUH205]KF`0305mOG`1SHf<0Hf=S0080IVIV0P1ZJVX2
06i^KP80LW9b0P1eMGD207UiN@80O7al0P20P80208>3P`80QhN70P2:RXX208f=S@80TI6A0P2DU9@0
0`2GUiL0VYZJ09ZJVP0209fMW@80X:2P0P2TY:@20:NWY`80ZZZZ0P2][JdE0?ooo`004`3oool20:j^
[P80[:b/0P2ZZZX20:RXZ080YZJV0P2TY:@20::RXP80WinO00<0WIfM09^KV`2KVi/00P2HV9P209JF
UP80Ti>C0P2ATI4208j>SP80Rh^;0P28R8P208F5Q@80PX:20P1oOgl207]kN`80MgMg0P1dM7@2071`
L00306a/K01[Jf/0Jf][0080KFe]0P1`L70207=cL`80MWIf0P1iNGT207alO080Ogmo0P22PX8208F5
Q@80RHV90P2=SHd2092@T080Ti>C0P2EUID00`2GUiL0V9RH09RHV00209VIV@80VYZJ0P2KVi/409bL
W0@0Vi^K0P2JVYX209VIV@80V9RH0P2GUiL209JFUP80U9BD0P2BTY800`2@T900SXj>08j>SP0208^;
R`80R8R80P25QHD208:2PP80PH610P1mOGd207YjNP80MGEe0P1`L70206][J`80IFEU0P1NGUh205QH
F080DU9B00<0BTY:0492@P12@T800P0k>c/203<c<`80:b/[0P0S8b<201/K6`8051@D0P0>3Ph200X:
2PH02@T90P0820P200L71`802PX:00<0410@01HF5P0F5QH00P0K6a/2024Q8@809bLW0P0/;2`2034a
<@80=SHf0P0k>c/20410@080ADE50P19BDT204i>CP80DU9B0P1FEUH205]KF`0305mOG`1SHf<0Hf=S
0080IVIV0P1ZJVX206i^KP80LW9b0P1eMGD207UiN@80O7al0P20P80208>3P`80QhN70P2:RXX208f=
S@80TI6A0P2DU9@00`2GUiL0VYZJ09ZJVP0209fMW@80X:2P0P2TY:@20:NWY`80ZZZZ0P2][JdE0?oo
o`004`3oool20:j^[P80[:b/0P2ZZZX20:RXZ080YZJV0P2TY:@20::RXP80WinO00<0WIfM09^KV`2K
Vi/00P2IVIT209JFUP80U9BD0P2ATI4208j>SP80S8b<0P29RHT208J6QP80Ph>30P1oOgl207alO080
NGUi0P1eMGD2079bLP0306m_K`1[Jf/0Jf][0080Jf][0P1^KVh2075aL@80Lg=c0P1gMgL207UiN@80
O7al0P1oOgl208>3P`80QXJ60P2:RXX208j>SP80T92@0P2BTY800`2CTi<0U9BD09BDU00209BDU080
UIFE1P2FUYH409FEU@80U9BD0P2CTi<2096AT@80Shn?0P2>SXh208f=S@80Rh^;00<0RHV908N7Q`27
QhL00P23Ph<20861P@80Ogmo0P1mOGd207]kN`80MWIf0P1cLg<2071`L080JVYZ0P1TI6@205iNGP80
EeMG0P1?Cdl204Q8B0030451@@0j>SX0>SXj0080<c<c0P0[:b/202@T90807AdM0P0E5AD2014A4@80
3Ph>0P0=3@d200h>3P803@d=0P0:2PX400P820803Ph>00<051@D01TI6@0I6AT00P0O7al202@T9080
:RXZ0P0_;bl203@d=080>CTi0P0n?Sh20492@P80AdM70P1<C4`2051@D080E5AD0P1HF5P205aLG003
061PH01TI6@0I6AT0080J6QX0P1/K6`2071`L080Lg=c0P1gMgL207YjNP80OWin0P21PH4208B4Q080
R8R80P2;Rh/208j>SP80TI6A0P2DU9@00`2HV9P0Vi^K09^KV`0209jNWP80XJ6Q0P2TY:@20:NWY`80
ZZZZ0P2][JdE0?ooo`004`3oool20:j^[P80[:b/0P2ZZZX20:RXZ080YZJV0P2TY:@20::RXP80WinO
00<0WIfM09^KV`2KVi/00P2IVIT209JFUP80U9BD0P2ATI4208j>SP80S8b<0P29RHT208J6QP80Ph>3
0P1oOgl207alO080NGUi0P1eMGD2079bLP0306m_K`1[Jf/0Jf][0080Jf][0P1^KVh2075aL@80Lg=c
0P1gMgL207UiN@80O7al0P1oOgl208>3P`80QXJ60P2:RXX208j>SP80T92@0P2BTY800`2CTi<0U9BD
09BDU00209BDU080UIFE1P2FUYH409FEU@80U9BD0P2CTi<2096AT@80Shn?0P2>SXh208f=S@80Rh^;
00<0RHV908N7Q`27QhL00P23Ph<20861P@80Ogmo0P1mOGd207]kN`80MWIf0P1cLg<2071`L080JVYZ
0P1TI6@205iNGP80EeMG0P1?Cdl204Q8B0030451@@0j>SX0>SXj0080<c<c0P0[:b/202@T90807AdM
0P0E5AD2014A4@803Ph>0P0=3@d200h>3P803@d=0P0:2PX400P820803Ph>00<051@D01TI6@0I6AT0
0P0O7al202@T9080:RXZ0P0_;bl203@d=080>CTi0P0n?Sh20492@P80AdM70P1<C4`2051@D080E5AD
0P1HF5P205aLG003061PH01TI6@0I6AT0080J6QX0P1/K6`2071`L080Lg=c0P1gMgL207YjNP80OWin
0P21PH4208B4Q080R8R80P2;Rh/208j>SP80TI6A0P2DU9@00`2HV9P0Vi^K09^KV`0209jNWP80XJ6Q
0P2TY:@20:NWY`80ZZZZ0P2][JdE0?ooo`004`3oool20:j^[P80[:b/0P2ZZZX20:RXZ080YZJV0P2T
Y:@20::RXP80X:2P00<0WIfM09^KV`2KVi/00P2IVIT209JFUP80U9BD0P2BTY8208n?S`80S8b<0P29
RHT208N7Q`80Q8B40P20P80207emO@80NWYj0P1gMgL207AdM003075aL@1_Kfl0Kfm_00@0KVi^0P1a
LG4207AdM080MgMg0P1jNWX207alO080OWin0P21PH4208B4Q080QhN70P2:RXX208b<S080SXj>0`2?
Shl:092@T080Shn?102=SHd208Z:RP@0R8R80P25QHD408:2PP030820P01nOWh0OWin0080OGem0P1j
NWX207QhN080MGEe0P1bLW8206m_K`80Jf][0P1UIFD2061PH080Fe]K0P1EEED204i>CP80B4Q80P12
@T800`0k>c/0=3@d03@d=00202`/;08092@T0P0N7Qh201PH60805ADE0P0C4a<4010@40803Ph>0P0:
2PX200T92@8020P80P0<30`2018B4P0301PH600M7Ad07AdM00808b<S0P0X:2P202d];@80<S8b0P0g
=cL203`l?080@D510P15ADD204Y:BP80CTi>0P1BDU8205IFEP80Fe]K0P1OGel00`1RHV80IVIV06IV
IP0206YZJP80KVi^0P1aLG4207EeM@80N7Qh0P1kNg/207moO`80PX:20P25QHD208V9R@80S8b<0P2?
Shl209:BTP80UIFE00<0V9RH09^KV`2KVi/00P2NWYh20:6QX@80Y:BT0P2WYjL20:ZZZP80[Jf]5@3o
ool001<0oooo0P2^[Zh20:b/[080ZZZZ0P2XZ:P20:JVYP80Y:BT0P2RXZ820:2PX00309fMW@2KVi/0
Vi^K0080VIVI0P2FUYH209BDU080TY:B0P2?Shl208b<S080RHV90P27QhL208B4Q080P8200P1mOGd2
07YjNP80MgMg0P1dM7@00`1aLG40Kfm_06m_K`0406i^KP80LG5a0P1dM7@207MgM`80NWYj0P1lO7`2
07inOP80PH610P24Q8@208N7Q`80RXZ:0P2<S8`208j>SP<0Shn?2P2@T90208n?S`@0SHf=0P2:RXX4
08R8R080QHF51022PX800`20P800OWin07inOP0207emO@80NWYj0P1hN7P207EeM@80LW9b0P1_Kfl2
06][J`80IFEU0P1PH60205]KF`80EEEE0P1>CTh204Q8B080@T9200<0>c/k03@d=00d=3@00P0/;2`2
02@T90807QhN0P0H61P201DE5@804a<C100@410200h>3P802PX:0P092@T200P8208030`<0P0B4Q80
0`0H61P07AdM01dM7@0202<S8`80:2PX0P0];Bd2038b<P80=cLg0P0l?3`20451@@80ADE50P1:BTX2
04i>CP80DU9B0P1FEUH205]KF`80GemO00<0HV9R06IVIP1VIVH00P1ZJVX206i^KP80LG5a0P1eMGD2
07QhN080Ng]k0P1oOgl208:2PP80QHF50P29RHT208b<S080Shn?0P2BTY8209FEU@0309RHV02KVi/0
Vi^K0080WYjN0P2QXJ420:BTY080YjNW0P2ZZZX20:f][AD0oooo000C0?ooo`80[Zj^0P2/[:`20:ZZ
ZP80Z:RX0P2VYZH20:BTY080XZ:R0P2PX:000`2NWYh0Vi^K09^KV`0209VIV@80UiNG0P2DU9@209:B
TP80Shn?0P2=SHd208Z:RP80QhN70P24Q8@20861P@80OWin0P1kNg/207QhN080MGEe00<0Lg=c071`
L01`L7000P1]KFd406i^KP80Kfm_0P1bLW8207IfMP80NGUi0P1lO7`207inOP80PH610P23Ph<208J6
QP80R8R80`29RHT808Z:RP@0RHV90P27QhL208J6QP80Q8B40P23Ph<208:2PP80Ogmo0P1mOGd207]k
N`80NGUi00<0MgMg07EeM@1eMGD00P1cLg<2071`L080KVi^0P1[Jf/206MWI`80I6AT0P1OGel205aL
G080F5QH0P1CDe<204a<C080ATI60P10@40203Xj>P03038b<P0[:b/0:b/[00809RHV0P0Q8B4201dM
7@806ATI100F5QH201DE5@804A4A0P0<30`200T92@801`L70P092@T2010@40805QHF00<071`L024Q
8@0Q8B400P0V9RH202/[:`80<C4a0P0e=CD203Xj>P80?clo0P13@d<204Q8B080C4a<0P1ADE4205EE
E@80FEUI0P1MGEd2065QH@0306EUI@1XJ6P0J6QX0080K6a/0P1_Kfl207=cL`80MWIf0P1jNWX207em
O@80P8200P23Ph<208N7Q`80RXZ:0P2=SHd2092@T080Ti>C0P2FUYH00`2IVIT0W9bL09bLW00209nO
W`80XZ:R0P2TY:@20:NWY`80ZZZZ0P2][JdE0?ooo`004`3oool20:j^[P80[:b/0P2ZZZX20:RXZ080
YZJV0P2TY:@20::RXP80X:2P00<0WYjN09^KV`2KVi/00P2IVIT209NGU`80U9BD0P2BTY8208n?S`80
SHf=0P2:RXX208N7Q`80Q8B40P21PH4207inOP80Ng]k0P1hN7P207EeM@0307=cL`1`L700L71`0080
KFe]101^KVh206m_K`80LW9b0P1fMWH207UiN@80O7al0P1nOWh20861P@80Ph>30P26QXH208R8R0<0
RHV9202:RXX408V9R@80QhN70P26QXH208B4Q080Ph>30P22PX8207moO`80OGem0P1kNg/207UiN@03
07MgM`1eMGD0MGEe0080Lg=c0P1`L70206i^KP80Jf][0P1WIfL206ATI080GemO0P1LG5`205QHF080
De=C0P1<C4`204I6AP80@4100P0j>SX00`0b<S80:b/[02/[:`0202HV9P808B4Q0P0M7Ad201TI6@@0
5QHF0P0E5AD2014A4@8030`<0P092@T200L71`802@T90P0@410201HF5P0301`L700Q8B408B4Q0080
9RHV0P0[:b/2034a<@80=CDe0P0j>SX203lo?`80@d=30P18B4P204a<C080DE5A0P1EEED205UIF@80
GEeM0P1QHF400`1UIFD0J6QX06QXJ00206a/K080Kfm_0P1cLg<207IfMP80NWYj0P1mOGd20820P080
Ph>30P27QhL208Z:RP80SHf=0P2@T90209>CT`80UYJF00<0VIVI09bLW02LW9`00P2OWil20::RXP80
Y:BT0P2WYjL20:ZZZP80[Jf]5@3oool001<0oooo0P2^[Zh20:b/[080ZZZZ0P2XZ:P20:JVYP80Y:BT
0P2RXZ820:2PX00309jNWP2LW9`0W9bL0080VYZJ0P2GUiL209FEU@80Ti>C0P2@T90208j>SP80Rh^;
0P28R8P208F5Q@80Ph>30P20P80207emO@80NWYj0P1gMgL00`1dM7@0LG5a075aL@0206m_K`80Jf][
0P1ZJVX206m_K`80LG5a0P1cLg<207EeM@80NGUi0P1kNg/207emO@80Ogmo0P21PH4208:2PP<0Ph>3
1024Q8@408>3P`@0PX:20P20P80207moO`80OGem0P1kNg/207MgM`80MGEe0P1cLg<2079bLP80L71`
00<0K6a/06][J`1[Jf/00P1XJ6P206EUI@80Hf=S0P1PH60205eMG@80FEUI0P1FEUH2059BDP80CDe=
0P18B4P204A4A080?Shn0P0g=cL2034a<@0302/[:`0V9RH09RHV00808R8R0P0N7Qh201XJ6P@061PH
0P0F5QH201<C4`803`l?0P0<30`200T92@8020P80P0>3Ph201@D50806QXJ00<0820P02DU9@0U9BD0
0P0Z:RX202l_;`80=3@d0P0i>CT203hn?P80@T920P17AdL204];B`80Cdm?0P1CDe<205QHF080G5aL
0P1OGel206=SH`0306MWI`1ZJVX0JVYZ0080KVi^0P1aLG4207EeM@80N7Qh0P1kNg/207inOP80PX:2
0P25QHD208R8R080Rh^;0P2>SXh2096AT@80U9BD0P2GUiL00`2IVIT0W9bL09bLW00209nOW`80XZ:R
0P2UYJD20:RXZ080ZZZZ0P2][JdE0?ooo`004`3oool20:j^[P80[:b/0P2ZZZX20:RXZ080YZJV0P2T
Y:@20::RXP80X:2P00<0WYjN09bLW02LW9`00P2JVYX209NGU`80UIFE0P2CTi<2092@T080SXj>0P2;
Rh/208R8R080QHF50P23Ph<20820P080OGem0P1jNWX207MgM`0307AdM01aLG40LG5a0080Kfm_0P1[
Jf/206YZJP80Kfm_0P1aLG4207=cL`80MGEe0P1iNGT207]kN`80OGem0P1oOgl20861P@80PX:20`23
Ph<408B4Q0@0Ph>31022PX820820P080Ogmo0P1mOGd207]kN`80MgMg0P1eMGD207=cL`80LW9b0P1`
L7000`1/K6`0Jf][06][J`0206QXJ080IFEU0P1SHf<2061PH080GEeM0P1IFET205IFEP80DU9B0P1=
CDd204Q8B080A4A40P0n?Sh203Lg=`80<C4a00<0:b/[02HV9P0V9RH00P0R8R8201hN7P806QXJ100H
61P201HF5P804a<C0P0?3`l200`<30802@T90P0820P200h>3P8051@D0P0J6QX00`0P82009BDU02DU
9@0202XZ:P80;bl_0P0d=3@203Ti>@80?Shn0P12@T8204M7A`80Bd];0P1?Cdl205=CD`80F5QH0P1L
G5`205mOG`80Hf=S00<0IfMW06YZJP1ZJVX00P1^KVh2075aL@80MGEe0P1hN7P207]kN`80OWin0P22
PX8208F5Q@80R8R80P2;Rh/208j>SP80TI6A0P2DU9@209NGU`0309VIV@2LW9`0W9bL0080WinO0P2R
XZ820:FUY@80Z:RX0P2ZZZX20:f][AD0oooo000C0?ooo`80[Zj^0P2/[:`20:ZZZP80Z:RX0P2VYZH2
0:BTY080XZ:R0P2PX:000`2NWYh0W9bL09bLW00209ZJVP80V9RH0P2FUYH209>CT`80TI6A0P2>SXh2
08b<S080RHV90P26QXH208B4Q080PH610P1nOWh207]kN`80N7Qh00<0MWIf07=cL`1cLg<00P1`L702
06e]K@@0JFUY0P1^KVh2079bLP80M7Ad0P1fMWH207MgM`80NGUi0P1jNWX207alO080OGem1`1lO7`6
07]kN`80NGUi0P1hN7P207IfMP80Lg=c0P1aLG4206i^KP80K6a/0P1YJFT206IVIP80I6AT00<0Hf=S
061PH01PH6000P1LG5`205YJFP80F5QH0P1EEED2055AD@80CDe=0P1:BTX204I6AP80@T920P0n?Sh2
03Ti>@80=3@d0P0_;bl202XZ:P0302DU9@0R8R808R8R0080820P0P0N7Qh401dM7@806QXJ0P0E5AD2
010@40803@d=0P0:2PX200T92@803Ph>0P0C4a<201TI6@807QhN00<092@T02TY:@0Y:BT00P0^;Rh2
03<c<`80>3Ph0P0l?3`20451@@80ATI60P1:BTX204i>CP80DU9B0P1FEUH205YJFP80GUiN0P1RHV82
06EUI@0306UYJ@1/K6`0K6a/0080L71`0P1cLg<207IfMP80NWYj0P1mOGd20820P080Ph>30P26QXH2
08V9R@80S8b<0P2?Shl209:BTP80UIFE0P2GUiL00`2JVYX0WIfM09fMW@020:2PX080XZ:R0P2UYJD2
0:RXZ080ZZZZ0P2][JdE0?ooo`004`3oool20:j^[P80[:b/0P2ZZZX20:RXZ080YjNW0P2UYJD20:>S
X`80XJ6Q00<0WinO09fMW@2MWId00P2KVi/209RHV080UYJF0P2DU9@209:BTP80Shn?0P2=SHd208Z:
RP80R8R80P25QHD208:2PP80Ogmo0P1mOGd207YjNP0307MgM`1dM7@0M7Ad0080LG5a0P1^KVh206][
J`@0JFUY0P1/K6`2071`L080LW9b0P1dM7@;07IfMP80MGEe0P1fMWH207EeM@80M7Ad0P1cLg<2079b
LP80Kfm_0P1]KFd206][J`80J6QX0P1UIFD206=SH`80GemO0P1LG5`205QHF00305EEE@1DE5@0E5AD
0080De=C0P1@D50204e=C@80BDU90P15ADD20492@P80?Cdm0P0i>CT203De=@80<C4a0P0];Bd202TY
:@809bLW0P0U9BD00`0S8b<0820P020P800401lO7`807QhN0P0K6a/201HF5P804Q8B0P0>3Ph200X:
2P8020P80P0;2`/2018B4P8061PH0P0N7Qh202<S8`0302PX:00];Bd0;Bd]0080<S8b0P0g=cL203`l
?080@4100P15ADD204U9B@80CDe=0P1ADE4205EEE@80FEUI0P1MGEd2065QH@80I6AT0P1XJ6P00`1[
Jf/0KVi^06i^KP02079bLP80MGEe0P1hN7P207]kN`80OWin0P21PH4208B4Q080R8R80P2;Rh/208f=
S@80T92@0P2CTi<209FEU@80V9RH00<0Vi^K09jNWP2NWYh00P2PX:020:>SX`80YJFU0P2XZ:P20:^[
Z`80[Jf]5@3oool001<0oooo0P2^[Zh20:b/[080ZZZZ0P2XZ:P20:NWY`80YJFU0P2SXj<20:6QX@03
09nOW`2MWId0WIfM0080Vi^K0P2HV9P209JFUP80U9BD0P2BTY8208n?S`80SHf=0P2:RXX208R8R080
QHF50P22PX8207moO`80OGem0P1jNWX00`1gMgL0M7Ad07AdM002075aL@80KVi^0P1[Jf/406UYJ@80
K6a/0P1`L702079bLP80M7Ad2`1fMWH207EeM@80MWIf0P1eMGD207AdM080Lg=c0P1bLW8206m_K`80
KFe]0P1[Jf/206QXJ080IFEU0P1SHf<205mOG`80G5aL0P1HF5P00`1EEED0E5AD05ADE00205=CD`80
D51@0P1=CDd204U9B@80ADE50P12@T8203dm?@80>CTi0P0e=CD2034a<@80;Bd]0P0Y:BT202LW9`80
9BDU00<08b<S020P800P8200100O7al201hN7P806a/K0P0F5QH2018B4P803Ph>0P0:2PX200P82080
2`/;0P0B4Q8201PH60807QhN0P0S8b<00`0X:2P0;Bd]02d];@02038b<P80=cLg0P0l?3`20410@080
ADE50P19BDT204e=C@80DE5A0P1EEED205UIF@80GEeM0P1QHF4206ATI080J6QX00<0Jf][06i^KP1^
KVh00P1bLW8207EeM@80N7Qh0P1kNg/207inOP80PH610P24Q8@208R8R080Rh^;0P2=SHd2092@T080
Ti>C0P2EUID209RHV00309^KV`2NWYh0WYjN0080X:2P0P2SXj<20:FUY@80Z:RX0P2[Zj/20:f][AD0
oooo000C0?ooo`80[Zj^0P2/[:`20:ZZZP80ZJVY0P2WYjL20:FUY@80Xj>S0P2QXJ400`2OWil0WIfM
09fMW@0209^KV`80VIVI0P2GUiL209FEU@80TY:B0P2@T90208j>SP80Rh^;0P29RHT208J6QP80Ph>3
0P21PH4207inOP80Ng]k00<0N7Qh07IfMP1fMWH00P1cLg<2071`L080KFe]0P1YJFT406IVIP80JFUY
0P1]KFd2071`L0@0LW9b0P1`L70506m_K`80KVi^0P1]KFd206a/K080Jf][0P1ZJVX206QXJ080IfMW
0P1TI6@2065QH@80GemO0P1MGEd205UIF@80EEEE0P1BDU8204i>CP0304];B`18B4P0B4Q80080ATI6
0P14A4@20492@P80?Shn0P0k>c/203Ph>080=CDe0P0a<C4202d];@80:RXZ0P0W9bL202HV9P809BDU
1@0S8b<2028R8P807alO0P0L71`201HF5P804A4A0P0>3Ph200`<30802@T90P0:2PX2014A4@805aLG
0P0M7Ad202<S8`80:2PX00<0;Bd]038b<P0b<S800P0g=cL203`l?080@4100P14A4@204Q8B080CDe=
0P1ADE4205EEE@80FEUI0P1LG5`2061PH080Hf=S0P1WIfL206YZJP0306i^KP1aLG40LG5a0080M7Ad
0P1gMgL207YjNP80OGem0P20P80208>3P`80QXJ60P29RHT208b<S080SXj>0P2ATI4209BDU080UYJF
0P2IVIT00`2LW9`0WYjN09jNWP020:6QX@80Xj>S0P2VYZH20:RXZ080Zj^[0P2][JdE0?ooo`004`3o
ool20:j^[P80[:b/0P2ZZZX20:VYZ@80YjNW0P2UYJD20:>SX`80XJ6Q00<0WinO09fMW@2MWId00P2K
Vi/209VIV@80UiNG0P2EUID209:BTP80T92@0P2>SXh208^;R`80RHV90P26QXH208>3P`80PH610P1n
OWh207]kN`0307QhN01fMWH0MWIf0080Lg=c0P1`L70206e]K@80JFUY101VIVH206UYJ@80KFe]0P1`
L704079bLP80L71`1@1_Kfl206i^KP80KFe]0P1/K6`206][J`80JVYZ0P1XJ6P206MWI`80I6AT0P1Q
HF4205mOG`80GEeM0P1IFET205EEE@80DU9B0P1>CTh00`1;Bd/0B4Q804Q8B00204I6AP80A4A40P12
@T8203hn?P80>c/k0P0h>3P203De=@80<C4a0P0];Bd202XZ:P809bLW0P0V9RH202DU9@D08b<S0P0R
8R8201lO7`8071`L0P0F5QH2014A4@803Ph>0P0<30`200T92@802PX:0P0A4A4201LG5`807AdM0P0S
8b<202PX:00302d];@0b<S80<S8b0080=cLg0P0l?3`20410@080A4A40P18B4P204e=C@80DE5A0P1E
EED205UIF@80G5aL0P1PH60206=SH`80IfMW0P1ZJVX00`1^KVh0LG5a075aL@0207AdM080MgMg0P1j
NWX207emO@80P8200P23Ph<208J6QP80RHV90P2<S8`208j>SP80TI6A0P2DU9@209JFUP80VIVI00<0
W9bL09jNWP2NWYh00P2QXJ420:>SX`80YZJV0P2XZ:P20:^[Z`80[Jf]5@3oool001<0oooo0P2^[Zh2
0:b/[080Zj^[0P2YZJT20:NWY`80YJFU0P2SXj<20:6QX@030:2PX02NWYh0WYjN0080W9bL0P2JVYX2
09RHV080UIFE0P2CTi<2096AT@80Shn?0P2<S8`208Z:RP80QhN70P25QHD208:2PP80P8200P1mOGd0
0`1jNWX0MgMg07MgM`0207AdM080LG5a0P1^KVh206YZJP80IVIV101TI6@206IVIP80J6QX0P1YJFT4
06YZJP80J6QX1@1VIVH206ATI080Hf=S0P1PH60205mOG`80GEeM0P1LG5`205YJFP80F5QH0P1EEED2
05=CD`80Cdm?0P1<C4`204U9B@80ATI600<0@T9203hn?P0n?Sh0100l?3`203Ti>@80=SHf0P0d=3@2
034a<@80;Rh^0P0[:b/202TY:@809bLW200V9RH00`0U9BD092@T02@T9002028R8P807AdM0P0G5aL2
014A4@803`l?0P0<30`200P820802`/;0P0B4Q8201PH60807QhN0P0S8b<202PX:080;Bd]00<0<S8b
03Lg=`0g=cL00P0l?3`20410@080A4A40P18B4P204e=C@80D51@0P1DE5@205QHF080G5aL0P1OGel2
06=SH`80IVIV0P1ZJVX206e]K@03071`L01cLg<0Lg=c0080MWIf0P1iNGT207alO080Ogmo0P22PX82
08F5Q@80R8R80P2:RXX208f=S@80T92@0P2BTY8209FEU@80UiNG0P2JVYX00`2LW9`0WinO09nOW`02
0:6QX@80Y:BT0P2VYZH20:VYZ@80Zj^[0P2][JdE0?ooo`004`3oool20:j^[P80[:b/0P2[Zj/20:VY
Z@80YjNW0P2UYJD20:>SX`80XJ6Q00<0X:2P09jNWP2NWYh00P2LW9`209ZJVP80V9RH0P2EUID209>C
T`80TI6A0P2?Shl208b<S080RXZ:0P27QhL208F5Q@80PX:20P20P80207emO@0307YjNP1gMgL0MgMg
0080M7Ad0P1aLG4206i^KP80JVYZ0P1VIVH406ATI080IVIV0P1XJ6P206UYJ@@0JVYZ0P1XJ6P506IV
IP80I6AT0P1SHf<2061PH080GemO0P1MGEd205aLG080FUYJ0P1HF5P205EEE@80De=C0P1?Cdl204a<
C080BDU90P16ATH00`12@T80?Shn03hn?P0403`l?080>CTi0P0f=SH203@d=080<C4a0P0^;Rh202/[
:`80:BTY0P0W9bL802HV9P0302DU9@0T92@092@T00808R8R0P0M7Ad201LG5`804A4A0P0?3`l200`<
308020P80P0;2`/2018B4P8061PH0P0N7Qh202<S8`80:2PX0P0];Bd00`0b<S80=cLg03Lg=`0203`l
?080@4100P14A4@204Q8B080CDe=0P1@D50205ADE080F5QH0P1LG5`205mOG`80Hf=S0P1VIVH206YZ
JP80KFe]00<0L71`07=cL`1cLg<00P1fMWH207UiN@80O7al0P1oOgl208:2PP80QHF50P28R8P208Z:
RP80SHf=0P2@T90209:BTP80UIFE0P2GUiL209ZJVP0309bLW02OWil0WinO0080XJ6Q0P2TY:@20:JV
YP80ZJVY0P2[Zj/20:f][AD0oooo000C0?ooo`80[Zj^0P2/[:`20:^[Z`80ZJVY0P2WYjL20:JVYP80
Y:BT0P2RXZ800`2PX:00WYjN09jNWP0209bLW080VYZJ0P2HV9P209JFUP80U9BD0P2BTY82092@T080
SHf=0P2;Rh/208V9R@80QXJ60P24Q8@20861P@80Ogmo00<0O7al07UiN@1iNGT00P1fMWH207=cL`80
L71`0P1/K6`206QXJ080I6AT0P1PH602065QH@80HV9R0P1SHf<406ATI080Hf=S0P1PH6000`1NGUh0
GEeM05eMG@0205eMG@80FUYJ0P1HF5P205EEE@80DU9B0P1ADE42051@D080Cdm?0P1<C4`204Y:BP80
ATI60P14A4@20451@@80?Shn00<0>c/k03Ph>00h>3P00P0e=CD203<c<`80<30`100^;Rh202`/;080
:b/[100Y:BT202PX:0@0:BTY0P0W9bL202@T9003028R8P0O7al07alO00806ATI0P0D51@2010@4080
3`l?0P0<30`200T92@8030`<0P0B4Q8201PH60807QhN0P0T92@202TY:@80;Rh^0P0c<c<00`0h>3P0
?3`l03`l?0020451@@80ADE50P19BDT204a<C080D51@0P1DE5@205QHF080G5aL0P1OGel206=SH`80
IVIV0P1YJFT206a/K080Kfm_00<0Lg=c07IfMP1fMWH00P1iNGT207]kN`80OWin0P21PH4208B4Q080
QXJ60P29RHT208b<S080SXj>0P2ATI4209>CT`80UYJF0P2HV9P209^KV`0309fMW@2OWil0WinO0080
XZ:R0P2TY:@20:NWY`80ZJVY0P2[Zj/20:j^[QD0oooo000C0?ooo`80[Zj^0P2/[:`20:^[Z`80ZJVY
0P2WYjL20:JVYP80Y:BT0P2RXZ800`2PX:00WYjN09jNWP0209bLW080VYZJ0P2HV9P209JFUP80U9BD
0P2BTY82092@T080SHf=0P2;Rh/208V9R@80QXJ60P24Q8@20861P@80Ogmo00<0O7al07UiN@1iNGT0
0P1fMWH207=cL`80L71`0P1/K6`206QXJ080I6AT0P1PH602065QH@80HV9R0P1SHf<406ATI080Hf=S
0P1PH6000`1NGUh0GEeM05eMG@0205eMG@80FUYJ0P1HF5P205EEE@80DU9B0P1ADE42051@D080Cdm?
0P1<C4`204Y:BP80ATI60P14A4@20451@@80?Shn00<0>c/k03Ph>00h>3P00P0e=CD203<c<`80<30`
100^;Rh202`/;080:b/[100Y:BT202PX:0@0:BTY0P0W9bL202@T9003028R8P0O7al07alO00806ATI
0P0D51@2010@40803`l?0P0<30`200T92@8030`<0P0B4Q8201PH60807QhN0P0T92@202TY:@80;Rh^
0P0c<c<00`0h>3P0?3`l03`l?0020451@@80ADE50P19BDT204a<C080D51@0P1DE5@205QHF080G5aL
0P1OGel206=SH`80IVIV0P1YJFT206a/K080Kfm_00<0Lg=c07IfMP1fMWH00P1iNGT207]kN`80OWin
0P21PH4208B4Q080QXJ60P29RHT208b<S080SXj>0P2ATI4209>CT`80UYJF0P2HV9P209^KV`0309fM
W@2OWil0WinO0080XZ:R0P2TY:@20:NWY`80ZJVY0P2[Zj/20:j^[QD0oooo000C0?ooo`80[Zj^0P2]
[Jd20:^[Z`80ZJVY0P2XZ:P20:JVYP80Y:BT0P2RXZ800`2QXJ40WinO09nOW`0209fMW@80Vi^K0P2I
VIT209NGU`80UIFE0P2CTi<2096AT@80Shn?0P2<S8`208Z:RP80R8R80P25QHD208>3P`80P82000<0
OWin07]kN`1kNg/00P1hN7P207EeM@80LG5a0P1^KVh206YZJP80IVIV0P1QHF4405aLG080GemO101Q
HF4205iNGP80G5aL00<0FEUI05IFEP1FEUH00P1DE5@2059BDP80Cdm?0P1<C4`204U9B@80ATI60P14
A4@204=3@`80@D510P0o?cl203dm?@80>c/k100j>SX303Ti>@80=SHf0P0d=3@2034a<@80<30`200_
;bl202h^;P80;2`/0P0Z:RX202HV9P808b<S0P0P82000`0L71`061PH01PH600201<C4`80410@0P0>
3Ph200d=3@802PX:0P0<30`201@D50806QXJ0P0O7al202DU9@80:RXZ0P0_;bl203@d=080>3Ph00<0
?Cdm0451@@11@D400P15ADD204U9B@80CDe=0P1ADE4205EEE@80FEUI0P1LG5`205mOG`80Hf=S0P1V
IVH206UYJ@80K6a/0P1_Kfl2079bLP0307EeM@1hN7P0N7Qh0080Ng]k0P1nOWh20820P080Ph>30P26
QXH208R8R080Rh^;0P2=SHd2092@T080TY:B0P2EUID209NGU`80VIVI0P2LW9`00`2NWYh0X:2P0:2P
X0020::RXP80YJFU0P2WYjL20:VYZ@80Zj^[0P2^[ZhE0?ooo`004`3oool20:j^[P80[Jf]0P2[Zj/2
0:VYZ@80Z:RX0P2VYZH20:BTY080XZ:R00<0XJ6Q09nOW`2OWil00P2MWId209^KV`80VIVI0P2GUiL2
09FEU@80Ti>C0P2ATI4208n?S`80S8b<0P2:RXX208R8R080QHF50P23Ph<20820P00307inOP1kNg/0
Ng]k0080N7Qh0P1eMGD2075aL@80KVi^0P1ZJVX206IVIP80HF5Q101LG5`205mOG`@0HF5Q0P1NGUh2
05aLG00305UIF@1FEUH0EUIF0080E5AD0P1BDU8204m?C`80C4a<0P19BDT204I6AP80A4A40P13@d<2
0451@@80?clo0P0m?Cd203/k>`@0>SXj0`0i>CT203Hf=P80=3@d0P0a<C42030`<0P0;bl_0P0^;Rh2
02`/;080:RXZ0P0V9RH202<S8`80820P00<071`L01PH600H61P00P0C4a<2010@40803Ph>0P0=3@d2
00X:2P8030`<0P0D51@201XJ6P807alO0P0U9BD202XZ:P80;bl_0P0d=3@203Ph>00303dm?@11@D40
@D510080ADE50P19BDT204e=C@80DE5A0P1EEED205UIF@80G5aL0P1OGel206=SH`80IVIV0P1YJFT2
06a/K080Kfm_0P1bLW800`1eMGD0N7Qh07QhN00207]kN`80OWin0P20P80208>3P`80QXJ60P28R8P2
08^;R`80SHf=0P2@T90209:BTP80UIFE0P2GUiL209VIV@80W9bL00<0WYjN0:2PX02PX:000P2RXZ82
0:FUY@80YjNW0P2YZJT20:^[Z`80[Zj^5@3oool001<0oooo0P2^[Zh20:f][@80Zj^[0P2ZZZX20:RX
Z080YZJV0P2UYJD20:>SX`030:6QX@2PX:00X:2P0080WYjN0P2LW9`209ZJVP80V9RH0P2FUYH209BD
U080TY:B0P2@T90208j>SP80S8b<0P29RHT208N7Q`80QHF50P22PX800`1oOgl0OGem07emO@0207Yj
NP80MgMg0P1cLg<2071`L080K6a/0P1XJ6P206ATI080H61P0P1KFe/205YJFPH0Fe]K0P1JFUX00`1F
EUH0De=C05=CD`0204m?C`80C4a<0P19BDT204I6AP80@d=30P12@T8203hn?P80>SXj0P0f=SH203De
=@80=3@d0P0e=CD203Hf=P80=cLg0`0f=SH203Lg=`80=SHf100e=CD203Hf=P80=3@d0P0b<S82030`
<080;Rh^0P0Z:RX202LW9`808R8R0P0N7Qh201XJ6P0301DE5@0B4Q804Q8B0080410@0P0?3`l200/;
2`802PX:0P0?3`l201DE5@806a/K0P0Q8B4202HV9P80:b/[0P0`<30203De=@80>CTi0P0n?Sh00`12
@T80ATI604I6AP0204Y:BP80CTi>0P1BDU8205EEE@80FEUI0P1LG5`2061PH080Hf=S0P1VIVH206UY
J@80K6a/0P1_Kfl2079bLP80MGEe00<0N7Qh07]kN`1kNg/00P1mOGd20820P080PX:20P25QHD208N7
Q`80RXZ:0P2<S8`208n?S`80TI6A0P2CTi<209JFUP80V9RH0P2JVYX209fMW@0309nOW`2QXJ40XJ6Q
0080Xj>S0P2UYJD20:NWY`80ZJVY0P2/[:`20:j^[QD0oooo000C0?ooo`80[Zj^0P2][Jd20:^[Z`80
ZZZZ0P2XZ:P20:JVYP80YJFU0P2SXj<00`2QXJ40X:2P0:2PX00209jNWP80W9bL0P2JVYX209RHV080
UYJF0P2DU9@209:BTP80T92@0P2>SXh208b<S080RHV90P27QhL208F5Q@80PX:200<0Ogmo07emO@1m
OGd00P1jNWX207MgM`80Lg=c0P1`L70206a/K080J6QX0P1TI6@2061PH080Fe]K0P1JFUX605]KF`80
FUYJ00<0EUIF05=CD`1CDe<00P1?Cdl204a<C080BDU90P16ATH204=3@`80@T920P0n?Sh203Xj>P80
=SHf0P0e=CD203@d=080=CDe0P0f=SH203Lg=`<0=SHf0P0g=cL203Hf=P@0=CDe0P0f=SH203@d=080
<S8b0P0`<30202h^;P80:RXZ0P0W9bL2028R8P807QhN0P0J6QX00`0E5AD04Q8B018B4P02010@4080
3`l?0P0;2`/200X:2P803`l?0P0E5AD201/K6`808B4Q0P0V9RH202/[:`80<30`0P0e=CD203Ti>@80
?Shn00<0@T9204I6AP16ATH00P1:BTX204i>CP80DU9B0P1EEED205UIF@80G5aL0P1PH60206=SH`80
IVIV0P1YJFT206a/K080Kfm_0P1bLW8207EeM@0307QhN01kNg/0Ng]k0080OGem0P20P80208:2PP80
QHF50P27QhL208Z:RP80S8b<0P2?Shl2096AT@80Ti>C0P2FUYH209RHV080VYZJ0P2MWId00`2OWil0
XJ6Q0:6QX@020:>SX`80YJFU0P2WYjL20:VYZ@80[:b/0P2^[ZhE0?ooo`004`3oool20:j^[P80[Jf]
0P2[Zj/20:ZZZP80Z:RX0P2WYjL20:FUY@80Y:BT00<0XZ:R0:2PX02PX:000P2OWil209fMW@80Vi^K
0P2IVIT209NGU`80UIFE0P2CTi<2096AT@80Shn?0P2=SHd208^;R`80RHV90P26QXH208B4Q0030861
P@1oOgl0Ogmo0080O7al0P1iNGT207IfMP80LW9b0P1_Kfl206][J`80IfMW0P1SHf<205mOG`80FEUI
0P1DE5@205IFEP80F5QH0P1GEeL00`1FEUH0De=C05=CD`0204m?C`80Bd];0P19BDT204M7A`80ADE5
0P12@T8203lo?`80?Shn0P0m?Cd203`l?080>c/k0P0j>SX503Ti>@H0>SXj0P0i>CT203Ph>080=SHf
0P0c<c<2034a<@80;Rh^0P0Z:RX202LW9`808R8R0P0L71`201PH608051@D00<04a<C014A4@0A4A40
0P0?3`l200`<30803Ph>0P0D51@201TI6@807QhN0P0S8b<202PX:080;Bd]0P0b<S8203Hf=P80>c/k
0P0o?cl204=3@`0304M7A`1;Bd/0Bd];0080Cdm?0P1CDe<205IFEP80FUYJ0P1MGEd2061PH080Hf=S
0P1VIVH206UYJ@80K6a/0P1_Kfl2079bLP80MGEe0P1hN7P00`1jNWX0OGem07emO@020820P080PX:2
0P25QHD208N7Q`80RHV90P2<S8`208j>SP80T92@0P2BTY8209FEU@80UiNG0P2IVIT209^KV`80WIfM
00<0X:2P0::RXP2RXZ800P2TY:@20:JVYP80Z:RX0P2ZZZX20:b/[080[Zj^5@3oool001<0oooo0P2^
[Zh20:f][@80Zj^[0P2ZZZX20:RXZ080YjNW0P2UYJD20:BTY0030::RXP2PX:00X:2P0080WinO0P2M
WId209^KV`80VIVI0P2GUiL209FEU@80Ti>C0P2ATI4208n?S`80SHf=0P2;Rh/208V9R@80QXJ60P24
Q8@00`21PH40Ogmo07moO`0207alO080NGUi0P1fMWH2079bLP80Kfm_0P1[Jf/206MWI`80Hf=S0P1O
Gel205UIF@80E5AD0P1FEUH205QHF080EeMG00<0EUIF05=CD`1CDe<00P1?Cdl204];B`80BDU90P17
AdL204E5A@80@T920P0o?cl203hn?P80?Cdm0P0l?3`203/k>`80>SXj1@0i>CT603Xj>P80>CTi0P0h
>3P203Hf=P80<c<c0P0a<C4202h^;P80:RXZ0P0W9bL2028R8P8071`L0P0H61P201@D500301<C4`0A
4A404A4A00803`l?0P0<30`200h>3P8051@D0P0I6AT201hN7P808b<S0P0X:2P202d];@80<S8b0P0f
=SH203/k>`80?clo0P13@d<00`17AdL0Bd];04];B`0204m?C`80De=C0P1FEUH205YJFP80GEeM0P1P
H60206=SH`80IVIV0P1YJFT206a/K080Kfm_0P1bLW8207EeM@80N7Qh00<0NWYj07emO@1mOGd00P20
P80208:2PP80QHF50P27QhL208V9R@80S8b<0P2>SXh2092@T080TY:B0P2EUID209NGU`80VIVI0P2K
Vi/209fMW@030:2PX02RXZ80XZ:R0080Y:BT0P2VYZH20:RXZ080ZZZZ0P2/[:`20:j^[QD0oooo000C
0?ooo`80[Zj^0P2][Jd20:b/[080ZZZZ0P2YZJT20:NWY`80YZJV0P2TY:@00`2SXj<0XJ6Q0:6QX@02
09nOW`80WYjN0P2LW9`209ZJVP80V9RH0P2GUiL209FEU@80Ti>C0P2ATI4208n?S`80SHf=0P2;Rh/2
08R8R080QXJ600<0Q8B40861P@21PH400P1nOWh207]kN`80N7Qh0P1eMGD2079bLP80KVi^0P1[Jf/2
06MWI`80HV9R0P1NGUh205UIF@80E5AD0P1BDU8305=CD`80DU9B0P1ADE4204m?C`80CDe=0P1:BTX2
04M7A`80ADE50P13@d<20492@P80@4100P0o?cl903hn?P80?Cdm0P0l?3`203/k>`80>SXj0P0i>CT2
03Hf=P80<c<c0P0_;bl202TY:@809RHV0P0Q8B4201dM7@806QXJ0P0G5aL201HF5P0301@D500@4100
410@0080410@0P0C4a<201PH60807AdM0P0R8R8202HV9P80:b/[0P0`<30203@d=080>CTi0P0m?Cd2
0451@@80ADE50P19BDT00`1=CDd0D51@051@D00205ADE080F5QH0P1KFe/205iNGP80HF5Q0P1TI6@2
06MWI`80JVYZ0P1]KFd2071`L080Lg=c0P1eMGD207QhN080Ng]k00<0OGem0820P020P8000P22PX82
08F5Q@80QhN70P29RHT208^;R`80SXj>0P2@T90209:BTP80U9BD0P2FUYH209RHV080VYZJ0P2LW9`2
09jNWP030:2PX02RXZ80XZ:R0080Y:BT0P2VYZH20:RXZ080ZZZZ0P2/[:`20:j^[QD0oooo000C0?oo
o`80[Zj^0P2][Jd20:b/[080ZZZZ0P2YZJT20:NWY`80YZJV0P2TY:@00`2SXj<0XJ6Q0:6QX@0209nO
W`80WYjN0P2LW9`209ZJVP80V9RH0P2GUiL209FEU@80Ti>C0P2ATI4208n?S`80SHf=0P2;Rh/208R8
R080QXJ600<0Q8B40861P@21PH400P1nOWh207]kN`80N7Qh0P1eMGD2079bLP80KVi^0P1[Jf/206MW
I`80HV9R0P1NGUh205UIF@80E5AD0P1BDU8305=CD`80DU9B0P1ADE4204m?C`80CDe=0P1:BTX204M7
A`80ADE50P13@d<20492@P80@4100P0o?cl903hn?P80?Cdm0P0l?3`203/k>`80>SXj0P0i>CT203Hf
=P80<c<c0P0_;bl202TY:@809RHV0P0Q8B4201dM7@806QXJ0P0G5aL201HF5P0301@D500@4100410@
0080410@0P0C4a<201PH60807AdM0P0R8R8202HV9P80:b/[0P0`<30203@d=080>CTi0P0m?Cd20451
@@80ADE50P19BDT00`1=CDd0D51@051@D00205ADE080F5QH0P1KFe/205iNGP80HF5Q0P1TI6@206MW
I`80JVYZ0P1]KFd2071`L080Lg=c0P1eMGD207QhN080Ng]k00<0OGem0820P020P8000P22PX8208F5
Q@80QhN70P29RHT208^;R`80SXj>0P2@T90209:BTP80U9BD0P2FUYH209RHV080VYZJ0P2LW9`209jN
WP030:2PX02RXZ80XZ:R0080Y:BT0P2VYZH20:RXZ080ZZZZ0P2/[:`20:j^[QD0oooo000C0?ooo`80
[jn_0P2][Jd20:b/[080ZZZZ0P2YZJT20:RXZ080YZJV0P2UYJD00`2SXj<0XZ:R0::RXP020:2PX080
WinO0P2MWId209^KV`80VYZJ0P2HV9P209JFUP80U9BD0P2BTY82092@T080Shn?0P2=SHd208Z:RP80
R8R800<0QXJ608>3P`23Ph<00P21PH4207inOP80Ng]k0P1iNGT207IfMP80LW9b0P1_Kfl206][J`80
IfMW0P1SHf<205iNGP80FEUI0P1CDe<304m?C`@0DE5A0P1@D50204i>CP80C4a<0P1;Bd/204U9B@80
B4Q80P16ATH204E5A@80A4A40P13@d<20492@P@0@d=300<0@T920410@010@4000P0n?Sh203/k>`80
>3Ph0P0g=cL203<c<`80;Rh^0P0Z:RX202HV9P808R8R0P0N7Qh201`L70806a/K0P0I6AT201DE5@03
01@D500F5QH05QHF00806QXJ0P0N7Qh2028R8P809bLW0P0[:b/202l_;`80<c<c0P0h>3P203`l?080
@4100P14A4@204Q8B080Bd];0P1?Cdl00`1BDU80EUIF05IFEP0205UIF@80GEeM0P1PH60206=SH`80
IVIV0P1YJFT206a/K080KVi^0P1aLG4207=cL`80MWIf0P1iNGT207]kN`80OWin00<0P82008>3P`23
Ph<00P25QHD208N7Q`80RHV90P2<S8`208j>SP80T92@0P2ATI4209>CT`80UYJF0P2HV9P209ZJVP80
W9bL0P2NWYh209nOW`030:6QX@2SXj<0Xj>S0080YJFU0P2WYjL20:VYZ@80ZZZZ0P2/[:`20:j^[QD0
oooo000C0?ooo`80[jn_0P2][Jd20:b/[080ZZZZ0P2YZJT20:RXZ080YZJV0P2UYJD00`2SXj<0XZ:R
0::RXP020:2PX080WinO0P2MWId209^KV`80VYZJ0P2HV9P209JFUP80U9BD0P2BTY82092@T080Shn?
0P2=SHd208Z:RP80R8R800<0QXJ608>3P`23Ph<00P21PH4207inOP80Ng]k0P1iNGT207IfMP80LW9b
0P1_Kfl206][J`80IfMW0P1SHf<205iNGP80FEUI0P1CDe<304m?C`@0DE5A0P1@D50204i>CP80C4a<
0P1;Bd/204U9B@80B4Q80P16ATH204E5A@80A4A40P13@d<20492@P@0@d=300<0@T920410@010@400
0P0n?Sh203/k>`80>3Ph0P0g=cL203<c<`80;Rh^0P0Z:RX202HV9P808R8R0P0N7Qh201`L70806a/K
0P0I6AT201DE5@0301@D500F5QH05QHF00806QXJ0P0N7Qh2028R8P809bLW0P0[:b/202l_;`80<c<c
0P0h>3P203`l?080@4100P14A4@204Q8B080Bd];0P1?Cdl00`1BDU80EUIF05IFEP0205UIF@80GEeM
0P1PH60206=SH`80IVIV0P1YJFT206a/K080KVi^0P1aLG4207=cL`80MWIf0P1iNGT207]kN`80OWin
00<0P82008>3P`23Ph<00P25QHD208N7Q`80RHV90P2<S8`208j>SP80T92@0P2ATI4209>CT`80UYJF
0P2HV9P209ZJVP80W9bL0P2NWYh209nOW`030:6QX@2SXj<0Xj>S0080YJFU0P2WYjL20:VYZ@80ZZZZ
0P2/[:`20:j^[QD0oooo000C0?ooo`80[jn_0P2][Jd20:b/[080Zj^[0P2YZJT20:RXZ080YjNW0P2U
YJD00`2TY:@0Xj>S0:>SX`020:6QX@80X:2P0P2NWYh209fMW@80Vi^K0P2IVIT209RHV080UYJF0P2D
U9@209:BTP80T92@0P2>SXh208b<S080RXZ:00<0R8R808J6QP26QXH00P23Ph<20861P@80OWin0P1l
O7`207UiN@80MWIf0P1bLW8206m_K`80Jf][0P1WIfL206=SH`80GemO0P1KFe/205IFEP03059BDP1>
CTh0CTi>0080C4a<0P1>CTh4051@D080Cdm?0P1>CTh204];B`80BDU90P18B4P204M7A`80ADE50P14
A4@204=3@`80@D5100<0@41003hn?P0n?Sh00P0m?Cd203Xj>P80=CDe0P0b<S8202h^;P80:b/[0P0Y
:BT202LW9`809BDU0P0Q8B4201hN7P806a/K0P0J6QX201`L700301lO7`0R8R808R8R00809BDU0P0X
:2P202`/;080<30`0P0d=3@203Ph>080?3`l0P10@40204=3@`80AdM70P1;Bd/204i>CP80DU9B0P1E
EED00`1IFET0G5aL05aLG00205mOG`80HV9R0P1UIFD206QXJ080Jf][0P1]KFd2071`L080LW9b0P1e
MGD207MgM`80NWYj0P1lO7`207inOP80PH6100<0Ph>308F5Q@25QHD00P28R8P208Z:RP80S8b<0P2>
SXh2092@T080TY:B0P2DU9@209JFUP80V9RH0P2IVIT209^KV`80WIfM0P2OWil20:2PX0030::RXP2T
Y:@0Y:BT0080YZJV0P2XZ:P20:VYZ@80Zj^[0P2/[:`20:j^[QD0oooo000C0?ooo`80[jn_0P2][Jd2
0:b/[080Zj^[0P2YZJT20:RXZ080YjNW0P2UYJD00`2TY:@0Xj>S0:>SX`020:6QX@80X:2P0P2NWYh2
09fMW@80Vi^K0P2IVIT209RHV080UYJF0P2DU9@209:BTP80T92@0P2>SXh208b<S080RXZ:00<0R8R8
08J6QP26QXH00P23Ph<20861P@80OWin0P1lO7`207UiN@80MWIf0P1bLW8206m_K`80Jf][0P1WIfL2
06=SH`80GemO0P1KFe/205IFEP03059BDP1>CTh0CTi>0080C4a<0P1>CTh4051@D080Cdm?0P1>CTh2
04];B`80BDU90P18B4P204M7A`80ADE50P14A4@204=3@`80@D5100<0@41003hn?P0n?Sh00P0m?Cd2
03Xj>P80=CDe0P0b<S8202h^;P80:b/[0P0Y:BT202LW9`809BDU0P0Q8B4201hN7P806a/K0P0J6QX2
01`L700301lO7`0R8R808R8R00809BDU0P0X:2P202`/;080<30`0P0d=3@203Ph>080?3`l0P10@402
04=3@`80AdM70P1;Bd/204i>CP80DU9B0P1EEED00`1IFET0G5aL05aLG00205mOG`80HV9R0P1UIFD2
06QXJ080Jf][0P1]KFd2071`L080LW9b0P1eMGD207MgM`80NWYj0P1lO7`207inOP80PH6100<0Ph>3
08F5Q@25QHD00P28R8P208Z:RP80S8b<0P2>SXh2092@T080TY:B0P2DU9@209JFUP80V9RH0P2IVIT2
09^KV`80WIfM0P2OWil20:2PX0030::RXP2TY:@0Y:BT0080YZJV0P2XZ:P20:VYZ@80Zj^[0P2/[:`2
0:j^[QD0oooo000C0?ooo`80[jn_0P2][Jd20:b/[080Zj^[0P2ZZZX20:VYZ@80YjNW0P2VYZH00`2U
YJD0Xj>S0:>SX`020::RXP80XJ6Q0P2OWil209jNWP80W9bL0P2KVi/209VIV@80V9RH0P2FUYH209BD
U080Ti>C0P2ATI4208n?S`80SHf=00<0Rh^;08R8R028R8P00P26QXH208B4Q080PH610P1oOgl207al
O080NGUi0P1fMWH207=cL`80L71`0P1/K6`206UYJ@80IFEU0P1QHF4205eMG@0305UIF@1FEUH0EUIF
0080E5AD0P1ADE4204i>CP80Cdm?0P1@D50204m?C`@0CTi>0P1<C4`204Y:BP80BDU90P17AdL204E5
A@80@T9200<0@41003hn?P0n?Sh00P0l?3`203Ti>@80=cLg0P0e=CD2038b<P80<C4a0P0^;Rh202XZ
:P809RHV0P0T92@202DU9@809RHV0P0W9bL202TY:@0302/[:`0];Bd0;Bd]0080<30`0P0c<c<203Lg
=`80>SXj0P0m?Cd20451@@80A4A40P18B4P204];B`80Cdm?0P1BDU8205EEE@80F5QH0P1KFe/00`1N
GUh0HF5Q065QH@0206ATI080IfMW0P1ZJVX206e]K@80Kfm_0P1bLW8207AdM080MgMg0P1iNGT207al
O080OWin0P20P80208>3P`80QHF500<0QXJ608R8R028R8P00P2:RXX208b<S080SXj>0P2@T90209:B
TP80U9BD0P2FUYH209RHV080VYZJ0P2KVi/209fMW@80WYjN0P2PX:020::RXP030:>SX`2UYJD0YJFU
0080YZJV0P2XZ:P20:VYZ@80Zj^[0P2][Jd20:j^[QD0oooo000C0?ooo`80[jn_0P2][Jd20:b/[080
Zj^[0P2ZZZX20:VYZ@80YjNW0P2VYZH00`2UYJD0Xj>S0:>SX`020::RXP80XJ6Q0P2OWil209jNWP80
W9bL0P2KVi/209VIV@80V9RH0P2FUYH209BDU080Ti>C0P2ATI4208n?S`80SHf=00<0Rh^;08R8R028
R8P00P26QXH208B4Q080PH610P1oOgl207alO080NGUi0P1fMWH207=cL`80L71`0P1/K6`206UYJ@80
IFEU0P1QHF4205eMG@0305UIF@1FEUH0EUIF0080E5AD0P1ADE4204i>CP80Cdm?0P1@D50204m?C`@0
CTi>0P1<C4`204Y:BP80BDU90P17AdL204E5A@80@T9200<0@41003hn?P0n?Sh00P0l?3`203Ti>@80
=cLg0P0e=CD2038b<P80<C4a0P0^;Rh202XZ:P809RHV0P0T92@202DU9@809RHV0P0W9bL202TY:@03
02/[:`0];Bd0;Bd]0080<30`0P0c<c<203Lg=`80>SXj0P0m?Cd20451@@80A4A40P18B4P204];B`80
Cdm?0P1BDU8205EEE@80F5QH0P1KFe/00`1NGUh0HF5Q065QH@0206ATI080IfMW0P1ZJVX206e]K@80
Kfm_0P1bLW8207AdM080MgMg0P1iNGT207alO080OWin0P20P80208>3P`80QHF500<0QXJ608R8R028
R8P00P2:RXX208b<S080SXj>0P2@T90209:BTP80U9BD0P2FUYH209RHV080VYZJ0P2KVi/209fMW@80
WYjN0P2PX:020::RXP030:>SX`2UYJD0YJFU0080YZJV0P2XZ:P20:VYZ@80Zj^[0P2][Jd20:j^[QD0
oooo000C0?ooo`80[jn_0P2^[Zh20:b/[080Zj^[0P2ZZZX20:VYZ@80Z:RX0P2WYjL00`2UYJD0Y:BT
0:BTY0020:>SX`80XZ:R0P2PX:0209nOW`80WYjN0P2LW9`209^KV`80VIVI0P2HV9P209JFUP80U9BD
0P2CTi<2096AT@80Shn?00<0SHf=08^;R`2;Rh/00P29RHT208N7Q`80QHF50P22PX820820P080OGem
0P1jNWX207MgM`80M7Ad0P1aLG4206i^KP80Jf][0P1WIfL206ATI003065QH@1NGUh0GUiN0080G5aL
0P1IFET205MGE`80E5AD0P1ADE4204m?C`@0CTi>101=CDd204a<C080Bd];0P1:BTX204U9B@0304Q8
B014A4@0A4A40080@D510P0o?cl203dm?@80>SXj0P0f=SH2038b<P80<30`100_;bl2030`<080<C4a
0P0b<S8203<c<`80=3@d00<0=SHf03Ph>00h>3P00P0k>c/203dm?@80@4100P13@d<204I6AP80BDU9
0P1<C4`2051@D080De=C0P1FEUH205UIF@80G5aL0P1NGUh2065QH@0306ATI01WIfL0IfMW0080JVYZ
0P1/K6`206m_K`80LG5a0P1dM7@207IfMP80N7Qh0P1kNg/207emO@80Ogmo0P22PX8208B4Q080QXJ6
0P27QhL00`29RHT0Rh^;08^;R`0208f=S@80Shn?0P2ATI4209:BTP80U9BD0P2FUYH209RHV080VIVI
0P2KVi/209fMW@80WYjN0P2OWil20:6QX@80Xj>S00<0Y:BT0:JVYP2VYZH00P2WYjL20:RXZ080ZZZZ
0P2[Zj/20:f][@80[Zj^5@3oool001<0oooo0P2_[jl20:j^[P80[:b/0P2[Zj/20:ZZZP80ZJVY0P2X
Z:P20:NWY`030:FUY@2TY:@0Y:BT0080Xj>S0P2RXZ820:2PX080WinO0P2NWYh209bLW080Vi^K0P2I
VIT209RHV080UYJF0P2DU9@209>CT`80TI6A0P2?Shl00`2=SHd0Rh^;08^;R`0208V9R@80QhN70P25
QHD208:2PP80P8200P1mOGd207YjNP80MgMg0P1dM7@2075aL@80KVi^0P1[Jf/206MWI`80I6AT00<0
HF5Q05iNGP1NGUh00P1LG5`205UIF@80EeMG0P1DE5@2055AD@80Cdm?101>CTh404e=C@80C4a<0P1;
Bd/204Y:BP80BDU900<0B4Q804A4A014A4@00P11@D4203lo?`80?Cdm0P0j>SX203Hf=P80<S8b0P0`
<30402l_;`80<30`0P0a<C42038b<P80<c<c0P0d=3@00`0f=SH0>3Ph03Ph>00203/k>`80?Cdm0P10
@40204=3@`80ATI60P19BDT204a<C080D51@0P1CDe<205IFEP80FEUI0P1LG5`205iNGP80HF5Q00<0
I6AT06MWI`1WIfL00P1ZJVX206a/K080Kfm_0P1aLG4207AdM080MWIf0P1hN7P207]kN`80OGem0P1o
Ogl208:2PP80Q8B40P26QXH208N7Q`0308V9R@2;Rh/0Rh^;0080SHf=0P2?Shl2096AT@80TY:B0P2D
U9@209JFUP80V9RH0P2IVIT209^KV`80WIfM0P2NWYh209nOW`80XJ6Q0P2SXj<00`2TY:@0YZJV0:JV
YP020:NWY`80Z:RX0P2ZZZX20:^[Z`80[Jf]0P2^[ZhE0?ooo`004`3oool20:n_[`80[Zj^0P2][Jd2
0:b/[080Zj^[0P2ZZZX20:RXZ080YjNW00<0YZJV0:FUY@2UYJD00P2TY:@20:>SX`80XJ6Q0P2PX:02
09nOW`80WYjN0P2LW9`209^KV`80VIVI0P2HV9P209NGU`80UIFE0P2CTi<2096AT@03092@T02>SXh0
SXj>0080S8b<0P2:RXX208R8R080QXJ60P23Ph<20861P@80OWin0P1lO7`207UiN@80MWIf0P1cLg<2
071`L080KVi^0P1[Jf/00`1XJ6P0IFEU06EUI@0206=SH`80H61P0P1NGUh205aLG080FEUI0P1HF5P2
05IFEP80EEEE0P1DE5@205=CD`80DU9B0P1ADE4204m?C`80C4a<00<0BTY:04Q8B018B4P00P15ADD2
04=3@`80@D510P0o?cl203hn?P80?Cdm0P0l?3`603/k>`80?3`l0P0m?Cd203hn?P80@41000<0@T92
04A4A014A4@00P16ATH204Q8B080BTY:0P1<C4`204m?C`80DU9B0P1DE5@205MGE`80FUYJ0P1MGEd2
061PH080HV9R0P1UIFD206MWI`0306YZJP1]KFd0KFe]0080L71`0P1bLW8207AdM080MWIf0P1iNGT2
07]kN`80OGem0P1oOgl20861P@80Ph>30P25QHD208N7Q`80RHV90P2;Rh/00`2<S8`0SXj>08j>SP02
092@T080TY:B0P2CTi<209FEU@80UiNG0P2HV9P209ZJVP80Vi^K0P2LW9`209jNWP80X:2P0P2QXJ42
0::RXP80Y:BT00<0YJFU0:JVYP2VYZH00P2XZ:P20:VYZ@80Zj^[0P2/[:`20:f][@80[jn_5@3oool0
01<0oooo0P2_[jl20:j^[P80[Jf]0P2/[:`20:^[Z`80ZZZZ0P2XZ:P20:NWY`030:JVYP2UYJD0YJFU
0080Y:BT0P2SXj<20:6QX@80X:2P0P2OWil209jNWP80W9bL0P2KVi/209VIV@80V9RH0P2GUiL209FE
U@80Ti>C0P2ATI400`2@T900SXj>08j>SP0208b<S080RXZ:0P28R8P208J6QP80Ph>30P21PH4207in
OP80O7al0P1iNGT207IfMP80Lg=c0P1`L70206i^KP80Jf][00<0J6QX06EUI@1UIFD00P1SHf<2061P
H080GUiN0P1LG5`205UIF@80F5QH0P1FEUH205EEE@80E5AD0P1CDe<2059BDP80DE5A0P1?Cdl204a<
C00304Y:BP18B4P0B4Q80080ADE50P13@d<20451@@80?clo0P0n?Sh203dm?@80?3`l1P0k>c/203`l
?080?Cdm0P0n?Sh20410@0030492@P14A4@0A4A40080ATI60P18B4P204Y:BP80C4a<0P1?Cdl2059B
DP80E5AD0P1GEeL205YJFP80GEeM0P1PH602069RHP80IFEU0P1WIfL00`1ZJVX0KFe]06e]K@02071`
L080LW9b0P1dM7@207IfMP80NGUi0P1kNg/207emO@80Ogmo0P21PH4208>3P`80QHF50P27QhL208V9
R@80Rh^;00<0S8b<08j>SP2>SXh00P2@T90209:BTP80Ti>C0P2EUID209NGU`80V9RH0P2JVYX209^K
V`80W9bL0P2NWYh20:2PX080XJ6Q0P2RXZ820:BTY0030:FUY@2VYZH0YZJV0080Z:RX0P2YZJT20:^[
Z`80[:b/0P2][Jd20:n_[aD0oooo000C0?ooo`80[jn_0P2^[Zh20:f][@80[:b/0P2[Zj/20:ZZZP80
ZJVY0P2XZ:P00`2WYjL0YZJV0:JVYP020:FUY@80Y:BT0P2SXj<20::RXP80X:2P0P2OWil209jNWP80
WIfM0P2KVi/209ZJVP80V9RH0P2GUiL209JFUP80U9BD00<0TY:B096AT@2ATI400P2?Shl208f=S@80
Rh^;0P29RHT208N7Q`80QHF50P23Ph<20820P080OWin0P1kNg/207UiN@80MWIf0P1dM7@2075aL@03
06m_K`1/K6`0K6a/0080JVYZ0P1XJ6P206IVIP80I6AT0P1RHV82061PH080GemO0P1NGUh205aLG080
Fe]K0P1JFUX205UIF@80EeMG0P1EEED00`1CDe<0DE5A055AD@0204m?C`80CTi>0P1<C4`204];B`80
BDU90P18B4P:04M7A`80B4Q80P19BDT204];B`0304a<C01>CTh0CTi>0080D51@0P1BDU8205ADE080
EUIF0P1HF5P205]KF`80GEeM0P1PH602069RHP80I6AT0P1WIfL206YZJP80K6a/0P1^KVh00`1`L700
Lg=c07=cL`0207EeM@80MgMg0P1iNGT207]kN`80OGem0P1oOgl20861P@80Ph>30P25QHD208N7Q`80
RHV90P2:RXX208b<S080SXj>00<0Shn?096AT@2ATI400P2CTi<209BDU080UYJF0P2GUiL209VIV@80
VYZJ0P2LW9`209fMW@80WYjN0P2OWil20:6QX@80XZ:R0P2TY:@20:FUY@030:JVYP2WYjL0YjNW0080
Z:RX0P2ZZZX20:^[Z`80[:b/0P2^[Zh20:n_[aD0oooo000C0?ooo`80[jn_0P2^[Zh20:f][@80[:b/
0P2[Zj/20:ZZZP80ZJVY0P2XZ:P00`2WYjL0YZJV0:JVYP020:FUY@80Y:BT0P2SXj<20::RXP80X:2P
0P2OWil209jNWP80WIfM0P2KVi/209ZJVP80V9RH0P2GUiL209JFUP80U9BD00<0TY:B096AT@2ATI40
0P2?Shl208f=S@80Rh^;0P29RHT208N7Q`80QHF50P23Ph<20820P080OWin0P1kNg/207UiN@80MWIf
0P1dM7@2075aL@0306m_K`1/K6`0K6a/0080JVYZ0P1XJ6P206IVIP80I6AT0P1RHV82061PH080GemO
0P1NGUh205aLG080Fe]K0P1JFUX205UIF@80EeMG0P1EEED00`1CDe<0DE5A055AD@0204m?C`80CTi>
0P1<C4`204];B`80BDU90P18B4P:04M7A`80B4Q80P19BDT204];B`0304a<C01>CTh0CTi>0080D51@
0P1BDU8205ADE080EUIF0P1HF5P205]KF`80GEeM0P1PH602069RHP80I6AT0P1WIfL206YZJP80K6a/
0P1^KVh00`1`L700Lg=c07=cL`0207EeM@80MgMg0P1iNGT207]kN`80OGem0P1oOgl20861P@80Ph>3
0P25QHD208N7Q`80RHV90P2:RXX208b<S080SXj>00<0Shn?096AT@2ATI400P2CTi<209BDU080UYJF
0P2GUiL209VIV@80VYZJ0P2LW9`209fMW@80WYjN0P2OWil20:6QX@80XZ:R0P2TY:@20:FUY@030:JV
YP2WYjL0YjNW0080Z:RX0P2ZZZX20:^[Z`80[:b/0P2^[Zh20:n_[aD0oooo000C0?ooo`80[jn_0P2^
[Zh20:f][@@0[:b/0P2[Zj/20:ZZZP80ZJVY00<0Z:RX0:NWY`2WYjL00P2VYZH20:FUY@80Y:BT0P2S
Xj<20::RXP80XJ6Q0P2OWil209jNWP80WIfM0P2LW9`209^KV`80VIVI0P2HV9P209NGU`0309FEU@2D
U9@0U9BD0080TY:B0P2@T90208n?S`80SHf=0P2;Rh/208V9R@80QhN70P25QHD208>3P`80P8200P1n
OWh207alO080NGUi0P1gMgL00`1eMGD0Lg=c07=cL`02079bLP80Kfm_0P1^KVh206a/K080JVYZ0P1X
J6P206MWI`80IVIV0P1UIFD206=SH`80HV9R0P1QHF4205mOG`80GUiN00<0G5aL05]KF`1KFe/00P1I
FET205QHF080EUIF0P1EEED205ADE0@0De=C1P1BDU8205=CD`@0E5AD0P1EEED00`1GEeL0F5QH05QH
F00205YJFP80G5aL0P1MGEd205mOG`80HV9R0P1TI6@206EUI@80J6QX0P1ZJVX206a/K080KVi^0P1`
L702079bLP80MGEe00<0MgMg07UiN@1iNGT00P1jNWX207alO080OWin0P20P80208:2PP80Q8B40P26
QXH208R8R080RHV90P2;Rh/208b<S080SXj>0P2@T902096AT@0309:BTP2DU9@0U9BD0080UIFE0P2G
UiL209VIV@80VYZJ0P2KVi/209bLW080WYjN0P2OWil20:2PX080XZ:R0P2SXj<20:BTY080YJFU0P2V
YZH00`2WYjL0Z:RX0:RXZ0020:VYZ@80ZZZZ0P2/[:`40:f][@80[jn_5@3oool001<0oooo0P2_[jl2
0:j^[P80[Jf]102/[:`20:^[Z`80ZZZZ0P2YZJT00`2XZ:P0YjNW0:NWY`020:JVYP80YJFU0P2TY:@2
0:>SX`80XZ:R0P2QXJ4209nOW`80WYjN0P2MWId209bLW080Vi^K0P2IVIT209RHV080UiNG00<0UIFE
09BDU02DU9@00P2BTY82092@T080Shn?0P2=SHd208^;R`80RHV90P27QhL208F5Q@80Ph>30P20P802
07inOP80O7al0P1iNGT207MgM`0307EeM@1cLg<0Lg=c0080LW9b0P1_Kfl206i^KP80K6a/0P1ZJVX2
06QXJ080IfMW0P1VIVH206EUI@80Hf=S0P1RHV82065QH@80GemO0P1NGUh00`1LG5`0Fe]K05]KF`02
05UIF@80F5QH0P1FEUH205EEE@80E5AD101CDe<6059BDP80De=C101DE5@205EEE@0305MGE`1HF5P0
F5QH0080FUYJ0P1LG5`205eMG@80GemO0P1RHV8206ATI080IFEU0P1XJ6P206YZJP80K6a/0P1^KVh2
071`L080LW9b0P1eMGD00`1gMgL0NGUi07UiN@0207YjNP80O7al0P1nOWh20820P080PX:20P24Q8@2
08J6QP80R8R80P29RHT208^;R`80S8b<0P2>SXh2092@T080TI6A00<0TY:B09BDU02DU9@00P2EUID2
09NGU`80VIVI0P2JVYX209^KV`80W9bL0P2NWYh209nOW`80X:2P0P2RXZ820:>SX`80Y:BT0P2UYJD2
0:JVYP030:NWY`2XZ:P0Z:RX0080ZJVY0P2ZZZX20:b/[0@0[Jf]0P2_[jlE0?ooo`004`3oool20:n_
[`@0[Zj^0P2][Jd20:b/[080Zj^[102ZZZX00`2YZJT0Z:RX0:RXZ0020:NWY`80YZJV0P2UYJD20:BT
Y080Xj>S0P2RXZ820:6QX@80X:2P0P2OWil209jNWP80WIfM0P2LW9`209^KV`80VIVI00<0V9RH09NG
U`2GUiL00P2EUID209BDU080TY:B0P2ATI4208n?S`80SHf=0P2;Rh/208Z:RP80R8R80P26QXH208B4
Q080PX:20P20P80207inOP0307emO@1kNg/0Ng]k0080NGUi0P1gMgL207EeM@80Lg=c0P1bLW82075a
L@80L71`0P1^KVh206e]K@80K6a/0P1[Jf/206YZJP80J6QX0P1WIfL00`1UIFD0I6AT06ATI00206=S
H`80HV9R0P1QHF4205mOG`@0GUiN201MGEd405iNGP80GemO0P1PH6000`1QHF40HV9R069RHP0206AT
I080IFEU0P1VIVH206QXJ080JVYZ0P1/K6`206i^KP80L71`0P1aLG4207AdM080MWIf0P1hN7P207Ui
N@80Ng]k00<0OGem07moO`1oOgl00P20P80208:2PP80Ph>30P25QHD208N7Q`80RHV90P2:RXX208b<
S080SHf=0P2?Shl2092@T080TY:B0P2CTi<209BDU00309JFUP2GUiL0UiNG0080V9RH0P2JVYX209^K
V`80W9bL0P2MWId209nOW`80X:2P0P2QXJ420::RXP80Xj>S0P2TY:@20:FUY@80YZJV0P2WYjL00`2X
Z:P0ZJVY0:VYZ@020:ZZZP80Zj^[0P2/[:`20:f][@80[Zj^0P2_[jlE0?ooo`004`3oool40:n_[`80
[Zj^0P2][Jd40:b/[080Zj^[0`2ZZZX20:VYZ@80Z:RX0P2WYjL40:JVYP80YJFU0P2TY:@20:>SX`80
XZ:R0P2QXJ420:2PX080WinO0P2NWYh209fMW@80W9bL00<0Vi^K09ZJVP2JVYX00P2HV9P209NGU`80
UYJF0P2DU9@209>CT`80TI6A0P2@T90208j>SP80SHf=0P2;Rh/208V9R@80R8R80P26QXH208B4Q003
08>3P`21PH40PH610080P8200P1nOWh207alO080Ng]k0P1jNWX207UiN@80MgMg101fMWH207EeM@80
Lg=c0P1bLW82075aL@80L71`00<0Kfm_06e]K@1]KFd00P1/K6`206][J`@0JVYZ0P1YJFT<06QXJ080
JFUY0P1ZJVX306][J`80K6a/0P1]KFd206i^KP80L71`0P1bLW8207=cL`80M7Ad0P1fMWH207QhN080
NWYj0P1lO7`207emO@80OWin0P20P80208:2PP0308>3P`25QHD0QHF50080QXJ60P28R8P208V9R@80
RXZ:0P2<S8`208f=S@80Shn?0P2@T90209:BTP80Ti>C0P2EUID209JFUP80UiNG0P2HV9P00`2IVIT0
VYZJ09ZJVP0209bLW080WIfM0P2NWYh209nOW`80X:2P0P2QXJ440::RXP80Xj>S0P2TY:@20:FUY@80
YZJV0P2WYjL20:RXZ0030:VYZ@2ZZZX0ZZZZ0080Zj^[0P2/[:`40:f][@80[Zj^0P2_[jlE0?ooo`00
4`3oool40:n_[`80[Zj^0P2][Jd40:b/[080Zj^[0`2ZZZX20:VYZ@80Z:RX0P2WYjL40:JVYP80YJFU
0P2TY:@20:>SX`80XZ:R0P2QXJ420:2PX080WinO0P2NWYh209fMW@80W9bL00<0Vi^K09ZJVP2JVYX0
0P2HV9P209NGU`80UYJF0P2DU9@209>CT`80TI6A0P2@T90208j>SP80SHf=0P2;Rh/208V9R@80R8R8
0P26QXH208B4Q00308>3P`21PH40PH610080P8200P1nOWh207alO080Ng]k0P1jNWX207UiN@80MgMg
101fMWH207EeM@80Lg=c0P1bLW82075aL@80L71`00<0Kfm_06e]K@1]KFd00P1/K6`206][J`@0JVYZ
0P1YJFT<06QXJ080JFUY0P1ZJVX306][J`80K6a/0P1]KFd206i^KP80L71`0P1bLW8207=cL`80M7Ad
0P1fMWH207QhN080NWYj0P1lO7`207emO@80OWin0P20P80208:2PP0308>3P`25QHD0QHF50080QXJ6
0P28R8P208V9R@80RXZ:0P2<S8`208f=S@80Shn?0P2@T90209:BTP80Ti>C0P2EUID209JFUP80UiNG
0P2HV9P00`2IVIT0VYZJ09ZJVP0209bLW080WIfM0P2NWYh209nOW`80X:2P0P2QXJ440::RXP80Xj>S
0P2TY:@20:FUY@80YZJV0P2WYjL20:RXZ0030:VYZ@2ZZZX0ZZZZ0080Zj^[0P2/[:`40:f][@80[Zj^
0P2_[jlE0?ooo`004`3oool40:n_[`@0[Zj^0P2][Jd40:b/[080Zj^[0`2ZZZX20:VYZ@@0Z:RX0P2W
YjL40:JVYP80YJFU0P2TY:@20:>SX`80XZ:R0P2QXJ440:2PX080WinO00<0WYjN09fMW@2MWId00P2L
W9`209^KV`80VIVI0P2HV9P209NGU`80UYJF0P2DU9@209>CT`80TY:B0P2@T90208n?S`80SHf=0P2<
S8`208^;R`0308V9R@28R8P0R8R80080QXJ60P25QHD208B4Q080Ph>30P22PX820861P@80P8200P1o
Ogl207inOP80OGem0P1lO7`207]kN`80NWYj0P1iNGT00`1hN7P0MgMg07MgM`0207MgM`80MWIf0P1e
MGD207AdM0@0Lg=c201bLW8407=cL`80M7Ad0`1eMGD207IfMP80MgMg0P1hN7P207UiN@80NWYj0P1k
Ng/207emO@80OWin0P20P8020861P@80Ph>30P24Q8@208F5Q@80QhN70P28R8P00`29RHT0Rh^;08^;
R`0208b<S080SXj>0P2?Shl2092@T080TI6A0P2CTi<209BDU080UIFE0P2FUYH209NGU`80V9RH0P2I
VIT209ZJVP80Vi^K00<0W9bL09fMW@2MWId00P2NWYh209nOW`80X:2P0P2QXJ420::RXP@0Xj>S0P2T
Y:@20:FUY@80YZJV0P2WYjL40:RXZ080ZJVY00<0ZZZZ0:^[Z`2[Zj/00P2[Zj/20:b/[080[Jf]0P2^
[Zh40:n_[aD0oooo000C0?ooo`@0[jn_102^[Zh20:f][@@0[:b/0P2[Zj/30:ZZZP80ZJVY102XZ:P2
0:NWY`@0YZJV0P2UYJD20:BTY080Xj>S0P2RXZ820:6QX@@0X:2P0P2OWil00`2NWYh0WIfM09fMW@02
09bLW080Vi^K0P2IVIT209RHV080UiNG0P2FUYH209BDU080Ti>C0P2BTY82092@T080Shn?0P2=SHd2
08b<S080Rh^;00<0RHV908R8R028R8P00P26QXH208F5Q@80Q8B40P23Ph<208:2PP80PH610P20P802
07moO`80OWin0P1mOGd207alO080Ng]k0P1jNWX207UiN@0307QhN01gMgL0MgMg0080MgMg0P1fMWH2
07EeM@80M7Ad101cLg<8079bLP@0Lg=c0P1dM7@307EeM@80MWIf0P1gMgL207QhN080NGUi0P1jNWX2
07]kN`80OGem0P1nOWh20820P080PH610P23Ph<208B4Q080QHF50P27QhL208R8R00308V9R@2;Rh/0
Rh^;0080S8b<0P2>SXh208n?S`80T92@0P2ATI4209>CT`80U9BD0P2EUID209JFUP80UiNG0P2HV9P2
09VIV@80VYZJ0P2KVi/00`2LW9`0WIfM09fMW@0209jNWP80WinO0P2PX:020:6QX@80XZ:R102SXj<2
0:BTY080YJFU0P2VYZH20:NWY`@0Z:RX0P2YZJT00`2ZZZX0Zj^[0:^[Z`020:^[Z`80[:b/0P2][Jd2
0:j^[P@0[jn_5@3oool001<0oooo102_[jl40:j^[P@0[Jf]102/[:`30:^[Z`@0ZZZZ0P2YZJT40:RX
Z0@0YjNW0P2VYZH20:FUY@@0Y:BT0P2SXj<40::RXP030:6QX@2PX:00X:2P0080WinO0P2NWYh209fM
W@80W9bL0P2KVi/209ZJVP80VIVI0P2HV9P209JFUP80UIFE0P2DU9@209>CT`80TY:B0P2ATI400`2@
T900Shn?08n?S`0208f=S@80S8b<0P2;Rh/208Z:RP80RHV91028R8P208N7Q`@0QXJ60P25QHD208B4
Q080Ph>30P22PX830861P@80P820101oOgl407inOPH0OGem0P1lO7`407emO@H0OWin00<0Ogmo0820
P020P8000P21PH4408:2PP80Ph>30P25QHD208J6QP80QhN70P28R8P208V9R@80RXZ:0P2;Rh/208f=
S@80SXj>0P2?Shl00`2@T900TI6A096AT@0209:BTP80Ti>C0P2DU9@209FEU@@0UiNG0P2HV9P209VI
V@@0Vi^K0P2LW9`209fMW@80WYjN0P2OWil00`2PX:00XJ6Q0:6QX@040::RXP80Xj>S102TY:@20:FU
Y@80YZJV102WYjL40:RXZ080ZJVY102ZZZX30:^[Z`80[:b/0P2][Jd60:j^[P80[jn_5@3oool001<0
oooo102_[jl40:j^[P@0[Jf]102/[:`30:^[Z`@0ZZZZ0P2YZJT40:RXZ0@0YjNW0P2VYZH20:FUY@@0
Y:BT0P2SXj<40::RXP030:6QX@2PX:00X:2P0080WinO0P2NWYh209fMW@80W9bL0P2KVi/209ZJVP80
VIVI0P2HV9P209JFUP80UIFE0P2DU9@209>CT`80TY:B0P2ATI400`2@T900Shn?08n?S`0208f=S@80
S8b<0P2;Rh/208Z:RP80RHV91028R8P208N7Q`@0QXJ60P25QHD208B4Q080Ph>30P22PX830861P@80
P820101oOgl407inOPH0OGem0P1lO7`407emO@H0OWin00<0Ogmo0820P020P8000P21PH4408:2PP80
Ph>30P25QHD208J6QP80QhN70P28R8P208V9R@80RXZ:0P2;Rh/208f=S@80SXj>0P2?Shl00`2@T900
TI6A096AT@0209:BTP80Ti>C0P2DU9@209FEU@@0UiNG0P2HV9P209VIV@@0Vi^K0P2LW9`209fMW@80
WYjN0P2OWil00`2PX:00XJ6Q0:6QX@040::RXP80Xj>S102TY:@20:FUY@80YZJV102WYjL40:RXZ080
ZJVY102ZZZX30:^[Z`80[:b/0P2][Jd60:j^[P80[jn_5@3oool001<0oooo1P2_[jl40:j^[PH0[Jf]
0`2/[:`40:^[Z`@0ZZZZ102YZJT40:RXZ0@0YjNW102VYZH40:FUY@030:BTY02SXj<0Xj>S00@0XZ:R
0P2QXJ420:2PX080WinO0P2NWYh209fMW@80W9bL102KVi/209ZJVP80VIVI0P2HV9P209NGU`0309JF
UP2EUID0UIFE0080U9BD0P2CTi<209:BTP@0TI6A102@T90408n?S`80SXj>102=SHd208b<S0<0Rh^;
0P2:RXX408V9R@H0R8R83P27QhL208R8R0<0RHV9102:RXX408^;R`80S8b<0P2=SHd208j>SP80Shn?
0P2@T902096AT@@0TY:B0P2CTi<209BDU080UIFE00<0UYJF09NGU`2GUiL0102HV9P209VIV@80VYZJ
0P2KVi/209bLW080WIfM102NWYh209nOW`80X:2P0P2QXJ420::RXP<0Xj>S102TY:@40:FUY@80YZJV
102WYjL20:RXZ0H0ZJVY102ZZZX40:^[Z`<0[:b/102][Jd40:j^[P80[jn_0P2`/;0E0?ooo`004`3o
ool60:n_[`@0[Zj^1P2][Jd30:b/[0@0Zj^[102ZZZX40:VYZ@@0Z:RX102WYjL40:JVYP@0YJFU00<0
Y:BT0:>SX`2SXj<0102RXZ820:6QX@80X:2P0P2OWil209jNWP80WIfM0P2LW9`409^KV`80VYZJ0P2I
VIT209RHV080UiNG00<0UYJF09FEU@2EUID00P2DU9@209>CT`80TY:B102ATI44092@T0@0Shn?0P2>
SXh408f=S@80S8b<0`2;Rh/208Z:RP@0RHV91P28R8P>08N7Q`80R8R80`29RHT408Z:RP@0Rh^;0P2<
S8`208f=S@80SXj>0P2?Shl2092@T080TI6A102BTY8209>CT`80U9BD0P2EUID00`2FUYH0UiNG09NG
U`0409RHV080VIVI0P2JVYX209^KV`80W9bL0P2MWId409jNWP80WinO0P2PX:020:6QX@80XZ:R0`2S
Xj<40:BTY0@0YJFU0P2VYZH40:NWY`80Z:RX1P2YZJT40:ZZZP@0Zj^[0`2/[:`40:f][@@0[Zj^0P2_
[jl20;2`/1D0oooo000C0?ooo`80/;2`1P2_[jl60:j^[PD0[Jf]1P2/[:`60:^[Z`@0ZZZZ102YZJT6
0:RXZ0<0YjNW102VYZH40:FUY@80Y:BT102SXj<20::RXP@0XJ6Q0P2PX:0209nOW`@0WYjN0P2MWId0
0`2LW9`0Vi^K09^KV`0209^KV`@0VYZJ102IVIT409RHV0H0UiNG0P2FUYH409FEU@D0U9BD102CTi<6
09:BTPX0TI6A1P2BTY8709>CT`@0U9BD0P2EUID209JFUP@0UiNG102HV9P209VIV@80VYZJ102KVi/3
09bLW0@0WIfM0P2NWYh209nOW`@0X:2P0P2QXJ460::RXP80Xj>S0P2TY:@40:FUY@<0YZJV102WYjL6
0:RXZ0@0ZJVY102ZZZX60:^[Z`H0[:b/1@2][Jd60:j^[P80[jn_0P2`/;0E0?ooo`004`3oool20;2`
/0H0[jn_1P2^[Zh50:f][@H0[:b/1P2[Zj/40:ZZZP@0ZJVY1P2XZ:P30:NWY`@0YZJV102UYJD20:BT
Y0@0Xj>S0P2RXZ840:6QX@80X:2P0P2OWil409jNWP80WIfM00<0W9bL09^KV`2KVi/00P2KVi/409ZJ
VP@0VIVI102HV9P609NGU`80UYJF102EUID509BDU0@0Ti>C1P2BTY8:096AT@H0TY:B1`2CTi<409BD
U080UIFE0P2FUYH409NGU`@0V9RH0P2IVIT209ZJVP@0Vi^K0`2LW9`409fMW@80WYjN0P2OWil40:2P
X080XJ6Q1P2RXZ820:>SX`80Y:BT102UYJD30:JVYP@0YjNW1P2XZ:P40:VYZ@@0ZZZZ1P2[Zj/60:b/
[0D0[Jf]1P2^[Zh20:n_[`80/;2`5@3oool001<0oooo0P2`/;0:0:n_[`T0[Zj^202][Jd60:b/[0H0
Zj^[2@2ZZZX40:VYZ@@0Z:RX102WYjL60:JVYPH0YJFU102TY:@30:>SX`@0XZ:R1P2QXJ460:2PX0H0
WinO1P2NWYh509fMW@X0W9bL1P2KVi/:09bLW0D0WIfM202NWYh409nOW`@0X:2P0P2QXJ460::RXP<0
Xj>S202TY:@40:FUY@@0YZJV102WYjL80:RXZ0<0ZJVY1P2ZZZX60:^[Z`P0[:b/202][Jd50:j^[PP0
[jn_102`/;0E0?ooo`004`3oool20;2`/0X0[jn_2@2^[Zh80:f][@H0[:b/1P2[Zj/90:ZZZP@0ZJVY
102XZ:P40:NWY`H0YZJV1P2UYJD40:BTY0<0Xj>S102RXZ860:6QX@H0X:2P1P2OWil609jNWPD0WIfM
2P2LW9`609^KV`X0W9bL1@2MWId809jNWP@0WinO102PX:020:6QX@H0XZ:R0`2SXj<80:BTY0@0YJFU
102VYZH40:NWY`P0Z:RX0`2YZJT60:ZZZPH0Zj^[202/[:`80:f][@D0[Zj^202_[jl40;2`/1D0oooo
000C0?ooo`H0/;2`4@2_[jl<0:j^[Pl0[Jf]302/[:`:0:^[Z`H0ZZZZ1@2YZJT>0:RXZ0`0YjNW3`2V
YZH40:FUY@l0YZJV3P2WYjL60:RXZ0P0ZJVY2`2ZZZX80:^[Z`X0[:b/3`2][JdB0:j^[PT0[jn_1P2`
/;0E0?ooo`004`3oool60;2`/140[jn_302^[Zh?0:f][@`0[:b/2P2[Zj/60:ZZZPD0ZJVY3P2XZ:P<
0:NWY`l0YZJV102UYJD?0:JVYPh0YjNW1P2XZ:P80:VYZ@/0ZZZZ202[Zj/:0:b/[0l0[Jf]4P2^[Zh9
0:n_[`H0/;2`5@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3o
ool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3o
ool00?l0oooo8@3oool009P0oooo0T0000260?ooo`00VP3oool00d000000oooo0?ooo`230?ooo`00
N`3oool2@00000@0oooo00=000000?ooo`3oool00P3oool00d000000oooo0?ooo`050?ooo`=00000
0P3oool2@00000<0oooo0d0000050?ooo`03@000003oool0oooo07d0oooo001m0?ooo`06@000003o
ool0oooo@000003ooom000000P3oool00d000000oooo@00000050?ooo`06@000003oool0oooo@000
003ooom00000103oool014000000oooo0?oood0000250?ooo`00O03oool01d000000oooo0?ooo`3o
oom000000?oood0000000P3oool00d000000oooo@00000050?ooo`05@000003oool0oooo@000003o
ool00d0000020?ooo`04@000003oool0oooo@00008D0oooo001m0?ooo`06@000003oool0oooo@000
003ooom000000P3oool00d000000oooo@00000060?ooo`=0000000@0oooo@0000400001000000`3o
ool3@00008D0oooo001k0?ooo`03@000003ooom000000080oooo00=000000?oood0000000P3oool0
0d000000oooo@00000080?ooo`03@000003oool0oooo08d0oooo001l0?ooo`03@000003oool0oooo
0080oooo00=000000?ooo`3oool00P3oool00d000000oooo0?ooo`060?ooo`900000S`3oool00?l0
oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0
oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.0250052, -0.0250052, 
  0.00365857, 0.00365857}, {{6.8125, 280.125}, {280.125, 
  6.8125}} -> {-10.161, -6.11446, 0.516914, 0.516914}}]
}, Closed]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["2.10 Summary",
  FontFamily->"Times New Roman",
  FontSize->18]], "Section"],

Cell[TextData[{
  StyleBox["\t",
    FontFamily->"Times New Roman",
    FontSize->10.5],
  StyleBox[
  "This chapter has described about the image processing techniques based on \
the classical field theory. As a result, it has been shown that the vectored \
approach not the simple spatial derivatives leads to the fruitful results. \
For example, the characteristic vector distribution has been derived by means \
of the Helmholtz's theorem. Simple magnitude computation of the \
characteristic vectors has yielded the sketch image. Further, an application \
of vector field nature to the characteristic vectors of an image has worked \
out one of the angled lighting images. Namely, we have worked out the unit \
directional vectors, and then a set of inner products between the \
characteristic and unit vectors has yielded the images as if lighted up from \
the different directions. \n\tThe other important result of this chapter is \
that we have derived the static monochrome image governing equation. This \
governing equation is one of the Poisson's equations, which is able to \
produce the different resolution images, freely.",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell[CellGroupData[{

Cell[TextData[StyleBox["REFERENCES", "Section",
  FontFamily->"Century",
  FontSize->12]], "Subsection"],

Cell[TextData[{
  StyleBox["[1] Stephen Wolfram, ",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Century",
    FontSize->10],
  StyleBox["The Mathematica Book",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Century",
    FontSize->10,
    FontSlant->"Italic"],
  StyleBox[
  ", 3rd ed. (Wolfram Media/Cambridge University Press, 1996).\n[2] \
J.D.Jackson, \"Classical Electrodynamics 3",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Century",
    FontSize->10],
  StyleBox["rd",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Century",
    FontSize->10,
    FontVariations->{"CompatibilityType"->"Superscript"}],
  StyleBox[" Edition,\" John Wiley & Sons, New York (1998).",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Century",
    FontSize->10]
}], "Text",
  TextAlignment->Left,
  TextJustification->1]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"Microsoft Windows 3.0",
ScreenRectangle->{{0, 1024}, {0, 740}},
ScreenStyleEnvironment->"Working",
WindowToolbars->{"RulerBar", "EditBar"},
WindowSize->{788, 602},
WindowMargins->{{0, Automatic}, {Automatic, 5}},
PrintingCopies->1,
PrintingStartingPageNumber->10,
PrintingPageRange->{Automatic, Automatic},
PageHeaders->{{Cell[ 
        TextData[ {
          CounterBox[ "Page"]}], "PageNumber"], Inherited, Cell[ 
        TextData[ {
          OptionValueBox[ "FileName"]}], "Header"]}, {Cell[ 
        TextData[ {
          OptionValueBox[ "FileName"]}], "Header"], Inherited, Cell[ 
        TextData[ {
          CounterBox[ "Page"]}], "PageNumber"]}},
PrintingOptions->{"FirstPageHeader"->False,
"FacingPages"->True},
ShowCellLabel->False,
StyleDefinitions -> "Textbook.nb"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 282, 9, 52, "Title"],

Cell[CellGroupData[{
Cell[2038, 64, 160, 4, 84, "Section"],
Cell[2201, 70, 2152, 37, 245, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4390, 112, 256, 9, 85, "Section"],
Cell[4649, 123, 752, 18, 59, "Text"],

Cell[CellGroupData[{
Cell[5426, 145, 206, 8, 37, "Subsubsection"],
Cell[5635, 155, 225, 7, 112, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5897, 167, 213, 8, 37, "Subsubsection"],
Cell[6113, 177, 760, 19, 42, "Text"],
Cell[6876, 198, 463, 8, 190, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7376, 211, 217, 8, 37, "Subsubsection"],
Cell[7596, 221, 811, 24, 42, "Text"],
Cell[8410, 247, 458, 10, 170, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[8905, 262, 215, 8, 37, "Subsubsection"],
Cell[9123, 272, 517, 14, 42, "Text"],
Cell[9643, 288, 375, 7, 130, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[10067, 301, 98, 1, 84, "Section"],
Cell[10168, 304, 509, 14, 42, "Text"],
Cell[10680, 320, 75, 1, 32, "Input"],
Cell[10758, 323, 497, 14, 42, "Text"],
Cell[11258, 339, 167, 5, 72, "Input"],
Cell[11428, 346, 472, 14, 25, "Text"],
Cell[11903, 362, 202, 6, 92, "Input"],
Cell[12108, 370, 724, 17, 59, "Text"],

Cell[CellGroupData[{
Cell[12857, 391, 158, 4, 52, "Input"],
Cell[13018, 397, 301798, 4466, 199, 139981, 2463, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[314865, 4869, 110, 1, 84, "Section"],
Cell[314978, 4872, 1475, 26, 110, "Text"],

Cell[CellGroupData[{
Cell[316478, 4902, 213, 8, 37, "Subsubsection"],
Cell[316694, 4912, 2059, 73, 124, "NumberedEquation"],
Cell[318756, 4987, 503, 13, 232, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[319296, 5005, 213, 8, 37, "Subsubsection"],
Cell[319512, 5015, 645, 16, 42, "Text"],
Cell[320160, 5033, 2371, 84, 126, "NumberedEquation"],
Cell[322534, 5119, 492, 13, 232, "Input"],
Cell[323029, 5134, 835, 20, 59, "Text"],

Cell[CellGroupData[{
Cell[323889, 5158, 587, 17, 312, "Input"],
Cell[324479, 5177, 356700, 13977, 200, 247533, 12624, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[681194, 19157, 499, 14, 42, "Text"],

Cell[CellGroupData[{
Cell[681718, 19175, 174, 5, 72, "Input"],
Cell[681895, 19182, 209, 5, 28, "Print"]
}, Open  ]],
Cell[682119, 19190, 896, 19, 93, "Text"],
Cell[683018, 19211, 1924, 73, 101, "NumberedEquation"],

Cell[CellGroupData[{
Cell[684967, 19288, 244, 8, 132, "Input"],
Cell[685214, 19298, 660587, 26946, 296, 481707, 24732, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[1345862, 46251, 93, 1, 84, "Section"],
Cell[1345958, 46254, 1189, 23, 94, "Text"],

Cell[CellGroupData[{
Cell[1347172, 46281, 199, 8, 34, "Subsubsection"],
Cell[1347374, 46291, 257, 7, 59, "Input"],
Cell[1347634, 46300, 556, 14, 45, "Text"],

Cell[CellGroupData[{
Cell[1348215, 46318, 190, 6, 66, "Input"],
Cell[1348408, 46326, 199101, 2903, 294, 35989, 884, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[1547570, 49236, 132, 2, 108, "Section"],
Cell[1547705, 49240, 472, 13, 33, "Text"],

Cell[CellGroupData[{
Cell[1548202, 49257, 221, 8, 34, "Subsubsection"],
Cell[1548426, 49267, 421, 11, 32, "Text"],
Cell[1548850, 49280, 230, 5, 51, "Input"],
Cell[1549083, 49287, 508, 14, 32, "Text"],
Cell[1549594, 49303, 139, 5, 52, "Input"],
Cell[1549736, 49310, 503, 10, 32, "Text"],
Cell[1550242, 49322, 136, 4, 38, "Input"],
Cell[1550381, 49328, 578, 15, 46, "Text"],
Cell[1550962, 49345, 325, 9, 83, "Input"],

Cell[CellGroupData[{
Cell[1551312, 49358, 292, 7, 79, "Input"],

Cell[CellGroupData[{
Cell[1551629, 49369, 287291, 3808, 294, 102860, 1526, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1838923, 53179, 536598, 9240, 301, 214577, 5259, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],
Cell[2375548, 62423, 436, 13, 34, "Text"],
Cell[2375987, 62438, 121, 3, 24, "Input"],
Cell[2376111, 62443, 245, 7, 79, "Input"],

Cell[CellGroupData[{
Cell[2376381, 62454, 294, 7, 79, "Input"],

Cell[CellGroupData[{
Cell[2376700, 62465, 288589, 3824, 294, 102862, 1526, "GraphicsData", 
"PostScript", "Graphics"],
Cell[2665292, 66291, 539717, 9279, 301, 214577, 5259, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],
Cell[3205036, 75574, 693, 22, 33, "Text"],

Cell[CellGroupData[{
Cell[3205754, 75600, 95, 1, 24, "Input"],

Cell[CellGroupData[{
Cell[3205874, 75605, 212906, 3087, 294, 36031, 898, "GraphicsData", 
"PostScript", "Graphics"],
Cell[3418783, 78694, 219275, 3166, 296, 36032, 898, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[3638061, 81862, 217382, 3143, 296, 36034, 898, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[3855446, 85007, 209606, 3047, 296, 36034, 898, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[4065055, 88056, 211841, 3074, 296, 36034, 898, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[4276899, 91132, 212870, 3087, 296, 36034, 898, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False]
}, Closed]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[4489842, 94227, 118, 1, 46, "Section"],
Cell[4489963, 94230, 1666, 41, 127, "Text"],

Cell[CellGroupData[{
Cell[4491654, 94275, 337, 14, 36, "Subsubsection"],
Cell[4491994, 94291, 939, 32, 85, "NumberedEquation"],
Cell[4492936, 94325, 545, 16, 203, "Input"],
Cell[4493484, 94343, 386, 12, 33, "Text"],

Cell[CellGroupData[{
Cell[4493895, 94359, 187, 6, 66, "Input"],
Cell[4494085, 94367, 223075, 3200, 294, 36032, 886, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[4717175, 97570, 1254, 24, 115, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4718466, 97599, 217, 8, 34, "Subsubsection"],
Cell[4718686, 97609, 628, 21, 81, "NumberedEquation"],
Cell[4719317, 97632, 855, 24, 313, "Input"],
Cell[4720175, 97658, 1006, 26, 70, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4721218, 97689, 219, 8, 34, "Subsubsection"],
Cell[4721440, 97699, 973, 27, 57, "Text"],
Cell[4722416, 97728, 470, 15, 189, "Input"],
Cell[4722889, 97745, 790, 24, 32, "Text"],

Cell[CellGroupData[{
Cell[4723704, 97773, 114, 4, 38, "Input"],
Cell[4723821, 97779, 95, 2, 18, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4723953, 97786, 160, 4, 38, "Input"],
Cell[4724116, 97792, 175380, 2612, 294, 36033, 886, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[4899511, 100407, 325, 8, 32, "Text"],

Cell[CellGroupData[{
Cell[4899861, 100419, 74, 1, 24, "Input"],
Cell[4899938, 100422, 83, 2, 19, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[4900082, 100431, 131, 3, 111, "Section"],
Cell[4900216, 100436, 694, 17, 66, "Text"],

Cell[CellGroupData[{
Cell[4900935, 100457, 86, 1, 24, "Input"],
Cell[4901024, 100460, 95, 2, 18, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4901156, 100467, 87, 1, 24, "Input"],
Cell[4901246, 100470, 95, 2, 18, "Output"]
}, Open  ]],
Cell[4901356, 100475, 259, 8, 21, "Text"],

Cell[CellGroupData[{
Cell[4901640, 100487, 425, 10, 121, "Input"],
Cell[4902068, 100499, 277843, 4388, 196, 72942, 1853, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[5179926, 104890, 524, 14, 45, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5180487, 104909, 101, 1, 108, "Section"],
Cell[5180591, 104912, 707, 16, 78, "Text"],
Cell[5181301, 104930, 118, 4, 38, "Input"],
Cell[5181422, 104936, 811, 18, 70, "Text"],
Cell[5182236, 104956, 242, 7, 112, "Input"],

Cell[CellGroupData[{
Cell[5182503, 104967, 193, 5, 72, "Input"],
Cell[5182699, 104974, 574433, 9719, 304, 215067, 5277, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[5757147, 114696, 693, 22, 59, "Text"],

Cell[CellGroupData[{
Cell[5757865, 114722, 97, 1, 32, "Input"],

Cell[CellGroupData[{
Cell[5757987, 114727, 230143, 3300, 296, 36031, 898, "GraphicsData", 
"PostScript", "Graphics"],
Cell[5988133, 118029, 233466, 3341, 296, 36032, 898, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[6221602, 121372, 234910, 3359, 20, 36034, 898, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[6456515, 124733, 230447, 3304, 20, 36034, 898, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[6686965, 128039, 233578, 3343, 20, 36034, 898, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[6920546, 131384, 234930, 3359, 20, 36034, 898, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False]
}, Closed]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[7155537, 134750, 100, 2, 52, "Section"],
Cell[7155640, 134754, 1285, 24, 203, "Text"],

Cell[CellGroupData[{
Cell[7156950, 134782, 104, 2, 38, "Subsection"],
Cell[7157057, 134786, 918, 32, 54, "Text"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

